// Copyright (c) 2009 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// Created by postproc-shortwords 1.8 on 2010-01-18 13:17:33
// From input file /export/hda3/cld/text_2008_quads_plus_sort.utf8
// See compact_lang_det.cc for usage
//

#include "encodings/compact_lang_det/cldutil.h"

// Included:
//      af-Latn ar-Arab be-Cyrl bg-Cyrl bs-Latn ca-Latn cs-Latn cy-Latn da-Latn de-Latn el-Grek en-Latn es-Latn et-Latn fa-Arab fi-Latn fr-Latn ga-Latn hi-Deva hr-Latn hu-Latn id-Latn is-Latn is-Latn it-Latn iw-Hebr ja-Hani ko-Hani lt-Latn lv-Latn mk-Cyrl ms-Latn nl-Latn no-Latn pl-Latn pt-Latn ro-Latn ru-Cyrl sh-Cyrl sh-Latn sk-Latn sl-Latn sr-Cyrl sv-Latn sw-Latn th-Thai tl-Latn tr-Latn uk-Cyrl vi-Latn xxx-Latn yi-Hebr zh-Hani zh-TW

// Remapped:
//      xxx-Latn=>ut-Latn sh-Latn=>hr-Latn sh-Cyrl=>sr-Cyrl

static const int kQuadTableBuildDate = 20100118;    // yyyymmdd

COMPILE_ASSERT(MONTENEGRIN == 160, k_montenegrin_changed);
COMPILE_ASSERT(EXT_NUM_LANGUAGES == 209, k_ext_num_languages_changed);

// Nil-grams: 18 languages
//     GREEK MALAYALAM TELUGU TAMIL GUJARATI THAI KANNADA PUNJABI
//     GEORGIAN SINHALESE ARMENIAN LAOTHIAN KHMER DHIVEHI CHEROKEE
//     SYRIAC ORIYA INUKTITUT

// Uni-grams: 6 languages
//     Japanese Korean Chinese VIETNAMESE ChineseT ZHUANG

// Words/Quads/Gibberish: 47 languages in range ENGLISH..AFRIKAANS:
//     ENGLISH DANISH DUTCH FINNISH FRENCH GERMAN HEBREW ITALIAN
//     NORWEGIAN POLISH PORTUGUESE RUSSIAN SPANISH SWEDISH CZECH
//     ICELANDIC LATVIAN LITHUANIAN ROMANIAN HUNGARIAN ESTONIAN
//     Ignore BULGARIAN CROATIAN SERBIAN IRISH TAGALOG TURKISH
//     UKRAINIAN HINDI MACEDONIAN INDONESIAN LATIN MALAY WELSH
//     BELARUSIAN ARABIC CATALAN SWAHILI SLOVENIAN MARATHI VIETNAMESE
//     SLOVAK PERSIAN NORWEGIAN_N YIDDISH AFRIKAANS

//  ENGLISH 5057
//  DANISH 3791
//  DUTCH 3895
//  FINNISH 4759
//  FRENCH 4398
//  GERMAN 4886
//  HEBREW 6248
//  ITALIAN 3006
//  NORWEGIAN 3700
//  POLISH 5221
//  PORTUGUESE 3767
//  RUSSIAN 5175
//  SPANISH 3710
//  SWEDISH 4463
//  CZECH 5205
//  ICELANDIC 4863
//  LATVIAN 4966
//  LITHUANIAN 4805
//  ROMANIAN 4283
//  HUNGARIAN 5354
//  ESTONIAN 4866
//  Ignore 92
//  BULGARIAN 5082
//  CROATIAN 4742
//  SERBIAN 5201
//  IRISH 3764
//  TAGALOG 2869
//  TURKISH 4921
//  UKRAINIAN 5466
//  HINDI 5512
//  MACEDONIAN 4869
//  INDONESIAN 3454
//  LATIN 2
//  MALAY 3279
//  WELSH 4716
//  BELARUSIAN 5553
//  ARABIC 6104
//  CATALAN 3578
//  SWAHILI 2845
//  SLOVENIAN 4145
//  MARATHI 449
//  VIETNAMESE 4102
//  SLOVAK 4577
//  PERSIAN 5665
//  NORWEGIAN_N 696
//  YIDDISH 4602
//  AFRIKAANS 3357


static const int kQuadTableSize = 65536;    // Bucket count
static const int kQuadTableKeyMask = 0xffff0000;    // Mask hash key

// 521808 possible entries:
// 195135 filled (37%), 925 merged (0%), 325748 dropped (62%)
static const cld::IndirectProbBucket4 kQuadTable[kQuadTableSize] = {
  // key[4], words[4] in UTF-8
  // value[4]
  { {0xcb670001,0x69260002,0xbddb0003,0x00000000}},	// [000] шате_, имаа, rtèr,
  { {0x20070004,0xbddb0005,0x7bc40006,0x00000000}},	//   _kuni_, stèr, sniu,
  { {0x65630007,0xddc40008,0xbddb0003,0x00000000}},	//   denh, _križ, ptèr,
  { {0x63bb0009,0x07a6000a,0x2007000b,0x00000000}},	//   jiun, јадн, _muni_,
  { {0x2007000c,0xa773000d,0x63a9000e,0x00000000}},	//   _luni_, ўліч, dhen,
  { {0xef1f000f,0x6fdd0010,0x64430011,0x00000000}},	//   tjük_, léct, funi,
  { {0x64430012,0x24510013,0x63a90014,0x00000000}},	//   guni, _cơm_, fhen,
  { {0xef1f000f,0x63bb0015,0xdb0d0016,0x00000000}},	//   rjük_, giun, riaç,
  { {0x36670017,0x65630018,0x32060003,0x00000000}},	//   _като_, benh, _quoy_,
  { {0x63a90019,0x2007001a,0x3f730013,0x00000000}},	//   ahen, _buni_, _ệu_,
  { {0x2b9c001b,0x3ff9000a,0x7528001c,0x00000000}},	//   _tích_, лноќ_, _iedz,
  { {0x63bb000c,0x63a9001d,0x6f1d001e,0x00000000}},	//   ciun, chen, ubsc,
  { {0x69c5001f,0x6fdd0003,0x69dc0020,0x00000000}},	//   ynhe, xécu, _okre,
  { {0x71730021,0x75280022,0x23640023,0x00000000}},	//   _وهنا, _jedz, lemj_,
  { {0x75280024,0x212c0025,0x6d470026,0x00000000}},	//   _medz, madh_, rgja,
  { {0x212c0027,0x6d470026,0x69dc0028,0x00000000}},	//   ladh_, sgja, _akre,
  { {0x6b8d0029,0xafb8002a,0x6e24002b,0x00000000}},	// [010] rjag, _خطوط_, _gwib,
  { {0x212c0027,0x6443002c,0x63bb000c,0x00000000}},	//   nadh_, yuni, ziun,
  { {0x6563002d,0x63a9002e,0x27ed002f,0x00000000}},	//   venh, yhen, _phen_,
  { {0x63bb000c,0x212c0025,0x69dc0030,0x00000000}},	//   xiun, hadh_, _ekre,
  { {0x63a90031,0xd6ab0032,0x65630033,0x00000000}},	//   vhen, خدام_, tenh,
  { {0x27ed0034,0x26df0035,0x64430036,0x00000000}},	//   _when_, _vyuo_, tuni,
  { {0x27ed0037,0x63bb0038,0x65630039,0x00000000}},	//   _then_, tiun, renh,
  { {0x7e6d003a,0xdce5003b,0x6563003c,0x00000000}},	//   _osap, _zahă, senh,
  { {0x6729003d,0x63a9003e,0x212c0025,0x00000000}},	//   _ieej, rhen, fadh_,
  { {0x212c0027,0x2475001c,0xdb090026,0x00000000}},	//   gadh_, _tām_, _ánæg,
  { {0xddc4003f,0x2a690040,0xc50c0041,0x00000000}},	//   _priž, hwab_, _סלאָ,
  { {0xedb20042,0xf3740043,0x23740044,0x00000000}},	//   ुच्छ, _وطند, _وانح,
  { {0x66010045,0x7e6d000f,0x67ea0046,0x00000000}},	//   _kilk, _csap, nýja,
  { {0x212c0027,0xb2760047,0xd5f90047,0x00000000}},	//   cadh_, _לענג_, רפֿר,
  { {0x5cb7000d,0x66010048,0x10150049,0x00000000}},	//   блёў_, _milk, _ابتد,
  { {0xee3f004a,0x645c004b,0x98ab004c,0x00000000}},	//   brý_, _ärie, ůměr_,
  { {0x6d410025,0x68e3004d,0x2d8c004e,0x00000000}},	// [020] ólac, ündn, ödes_,
  { {0x0ae90021,0x4425004f,0x66010050,0x00000000}},	//   شرقي_, _owl_, _nilk,
  { {0x7528003d,0x79950051,0x2a690052,0x00000000}},	//   _redz, _dozw, awab_,
  { {0xbb860032,0xa3e70053,0xf62a0054,0x00000000}},	//   _الحي, _मील_, гіки_,
  { {0x65940055,0x67290056,0x65a60014,0x00000000}},	//   жалу, _deej, _aðha,
  { {0x69dc0057,0x291e0026,0xdb160026,0x00000000}},	//   _ukre, _ýta_, ábær,
  { {0xb8960021,0xe6440058,0x212c0059,0x00000000}},	//   _الزع, ğlığ, vadh_,
  { {0x5398005a,0xe644005b,0xdb0d0026,0x00000000}},	//   рвия_, şlığ, nnað,
  { {0x212c0025,0x6601005c,0xb355005d,0x00000000}},	//   tadh_, _filk, تینا_,
  { {0xdbde003b,0x316a005e,0x27ea005f,0x00000000}},	//   nţân, ушио_, šinė_,
  { {0x212c0027,0xdb0d0014,0x98b80058,0x00000000}},	//   radh_, knað, _karı_,
  { {0x212c0027,0x7bc80060,0xee3f0061,0x00000000}},	//   sadh_, édul, trý_,
  { {0x27fc0024,0x212c0025,0x6ea80062,0x00000000}},	//   ívny_, padh_, бърг_,
  { {0x81670062,0x98b8005b,0xe56e000d,0x00000000}},	//   _гръб_, _ları_, дзi_,
  { {0x79950045,0xdb0d0026,0x71bb0063,0x00000000}},	//   _rozw, fnað, _תצוג,
  { {0x2d8c0064,0xdb0d0014,0x80370044,0x00000000}},	//   öder_, gnað, _اسوأ_,
  { {0x79950045,0x7e6d002c,0xedd50044,0x00000000}},	// [030] _pozw, _usap, _ويبد,
  { {0x67290019,0x5a340065,0x67ea0066,0x00000000}},	//   _seej, янут, výja,
  { {0xe7190067,0x66010068,0xa3ca0042,0x00000000}},	//   ليات_, _rilk, ोवा_,
  { {0xe00b0053,0x66010069,0xddc4005f,0x00000000}},	//   _संसद_, _silk, _isiš,
  { {0xd246006a,0x6601006b,0xbddb006c,0x00000000}},	//   _تن_, _pilk, crèc,
  { {0x75ed006d,0x4415006e,0xa2cc0042,0x00000000}},	//   dúzc, офит, _तख़्,
  { {0x2d91006f,0x66010070,0x6729004e,0x00000000}},	//   ijze_, _vilk, _teej,
  { {0x13090071,0xe3b1002a,0x66090072,0x00000000}},	//   шний_, برت_, _tuek,
  { {0x6609004b,0x66010073,0x6790005d,0x00000000}},	//   _uuek, _tilk, _سیوط,
  { {0x11d60021,0x86980074,0x98b80075,0x00000000}},	//   يوية_, _укус_, _zarı_,
  { {0x98b8005b,0xe2a8005d,0xfbd90042,0x00000000}},	//   _yarı_, لاین_, भकाम,
  { {0x22590076,0x14d60047,0x9f06005d,0x00000000}},	//   _виды_, _וועל_, توحو,
  { {0xddc40077,0xc8e60042,0x00000000,0x00000000}},	//   _asiš, _कर्म_,   ,
  { {0x853c0078,0xa156005e,0x8024005d,0x00000000}},	//   _alėj, _даљу_, _کروم,
  { {0x3b960079,0xdb0d007a,0x8fe60032,0x00000000}},	//   ојат, tnað, _وأعم,
  { {0x69cb0003,0x3b95007b,0x7c3a007c,0x00000000}},	//   égen, пјут, štro,
  { {0xdb0d0014,0x7c29007d,0xda660021,0x00000000}},	// [040] rnað, ćera, غاري,
  { {0x2b58007e,0x99920066,0x98b80058,0x00000000}},	//   _گیرد_, kryť_, _sarı_,
  { {0xd90d007e,0xd70a007f,0x9f42004c,0x00000000}},	//   ایف_, анее_, elké_,
  { {0xddcd0080,0xe8e00013,0xa6e60081,0x00000000}},	//   _vrať, hiệu_, ожел,
  { {0x3ce80082,0x00000000,0x00000000,0x00000000}},	//   ज़ेरे_,   ,   ,
  { {0x7aeb004d,0xdb210072,0x45b70083,0x00000000}},	//   ügte, ätöv, огію_,
  { {0x07a60084,0x53460085,0x00000000,0x00000000}},	//   _давн, охпа,   ,
  { {0xd3260086,0x957c0022,0xd3d70044,0x00000000}},	//   цьки, _skąd, يبيا_,
  { {0xdcfe003d,0x67220087,0x32660054,0x00000000}},	//   _kopē, mboj, ітив,
  { {0xd2570088,0x2a620089,0x27e6008a,0x00000000}},	//   іцы_, _mpkb_, llon_,
  { {0xdb06000f,0xc0ca0001,0x2610008b,0x00000000}},	//   _elké, рупе_, _hào_,
  { {0x75ed008c,0x9f490046,0x28bd0042,0x00000000}},	//   púzc, _thaí_, ्पति,
  { {0xa2d6006a,0xd2500032,0x5f94005a,0x00000000}},	//   _بيشت, _أنت_, фият,
  { {0x2610008d,0x27e6008e,0x98a3008f,0x00000000}},	//   _mào_, hlon_, _lejā_,
  { {0x2610008b,0x2ca50090,0xac950091,0x00000000}},	//   _lào_, áld_, чавш,
  { {0x68e3004b,0x7dc90066,0x7b880092,0x00000000}},	//   ündm, oľsk, ољуб_,
  { {0x2610001b,0x27e6001f,0xdc3c008f,0x00000000}},	// [050] _nào_, dlon_, kšķe,
  { {0x27e60003,0xceb20047,0x3ea40093,0x00000000}},	//   elon_, _ניי_, ømte_,
  { {0x9783005d,0x984b0094,0xfeb80043,0x00000000}},	//   ویسه, ряза_, _هایت_,
  { {0x201e0006,0x2610008b,0xdc880063,0x00000000}},	//   ipti_, _bào_, _וְשָ,
  { {0x79a70095,0xff7c0047,0x26100013,0x00000000}},	//   _дрве, יטאמ, _cào_,
  { {0x27e60096,0x5a340097,0x99640098,0x00000000}},	//   alon_, _інст, _отсл,
  { {0x96bb0053,0x27e60099,0xf992009a,0x00000000}},	//   _शेरॉ, blon_, _ארם_,
  { {0xf773009b,0x00000000,0x00000000,0x00000000}},	//   _غاز_,   ,   ,
  { {0x76420003,0xf677007e,0x2610008d,0x00000000}},	//   croy, _بازخ, _gào_,
  { {0xd6c6007e,0x14190021,0x31a9009c,0x00000000}},	//   _عملی, _هيئة_, _búza_,
  { {0xe8e00013,0x3cdb0042,0x77f5009d,0x00000000}},	//   riệu_, _खुले_, ּמָד_,
  { {0x6d410026,0x645c004b,0x9404009e,0x00000000}},	//   ólan, _äria, _قوله,
  { {0xd5c8008b,0xdb0d004b,0x2610008d,0x00000000}},	//   iền_, nnaõ, _xào_,
  { {0xdd92006a,0x67e3004b,0x427a009f,0x00000000}},	//   روز_, mõju, _לאנג,
  { {0xa0a500a0,0xdb0d00a1,0xc0e20086,0x00000000}},	//   _хайд, chaë, _пошк,
  { {0x5f76007e,0xeef60085,0x09d40082,0x00000000}},	//   _رابر, _няпэ, थव्य,
  { {0x4a46000d,0x672200a2,0x0b43000d,0x00000000}},	// [060] янав, vboj, энтн,
  { {0x26100013,0xfa490021,0x27e600a3,0x00000000}},	//   _rào_, تشفى_, wlon_,
  { {0x661b00a4,0x3ea200a5,0x6d5c00a6,0x00000000}},	//   _atuk, lykt_, mfra,
  { {0x2d9a0034,0x764200a7,0x644300a8,0x00000000}},	//   _hope_, troy, drni,
  { {0x6722003d,0xa6130086,0x644300a9,0x00000000}},	//   rboj, еміч, erni,
  { {0x261000aa,0x63ab0019,0x6d5c00ab,0x00000000}},	//   _vào_, _algn, nfra,
  { {0x6d4e00ac,0x291800ad,0x661b0072,0x00000000}},	//   igba, _ifra_, _etuk,
  { {0x764200ae,0x2d9a00af,0x34370021,0x00000000}},	//   proy, _lope_, أسود_,
  { {0x6d5c00b0,0x41e6000d,0x644300b1,0x00000000}},	//   kfra, зіна, arni,
  { {0x6d4e006f,0x644300b2,0x56370047,0x00000000}},	//   jgba, brni, _מאמע_,
  { {0x30a3005a,0xf9930063,0xe8df008b,0x00000000}},	//   еряв, תרת_, _trục_,
  { {0xd36f00b3,0x201e0006,0x69de00b4,0x00000000}},	//   _مهم_, rpti_, hope,
  { {0xe3b300b5,0x644a007c,0x69de00b6,0x00000000}},	//   _אױף_, lufi, kope,
  { {0x72eb00b7,0xdb0d0003,0x6d4e00b8,0x00000000}},	//   _פֿאַ, phaë, ggba,
  { {0xd5c8001b,0x3ce500b9,0x645800ba,0x00000000}},	//   yền_, ælv_, ntvi,
  { {0x6d4e00bb,0x69de00bc,0x6d5c0026,0x00000000}},	//   agba, eope, afra,
  { {0x6d5c00bd,0xdb0d00be,0x4a550085,0x00000000}},	// [070] bfra, nhaé, ькас,
  { {0x5c0700bf,0x7ae600c0,0xc1780006,0x00000000}},	//   _няма, _dykt, ndė_,
  { {0x3ea6003d,0x661b00c1,0x661c00c2,0x00000000}},	//   _ļoti_, _stuk, _črka,
  { {0x644300c3,0x7c3a0003,0x2d9a008d,0x00000000}},	//   vrni, âtre, _zope_,
  { {0xa5090002,0xb5fd008f,0xc1780078,0x00000000}},	//   оела_, _apša, kdė_,
  { {0x69de00c4,0x7bdf00c5,0x7bcd00c6,0x00000000}},	//   cope, loqu, lnau,
  { {0x645800c7,0x644300c8,0x7bcd00c9,0x00000000}},	//   gtvi, urni, onau,
  { {0x61e800ca,0x7bcd00cb,0x8235005d,0x00000000}},	//   eldl, nnau, ورخا,
  { {0x6d5c001f,0x645800cc,0x645c004b,0x00000000}},	//   yfra, atvi, _ärin,
  { {0x644300c2,0xeeeb0013,0x81f60021,0x00000000}},	//   prni, ýờng_, وفير_,
  { {0xbddb00cd,0x7bcd0078,0xc9480063,0x00000000}},	//   trèn, knau, הֲרֹ,
  { {0xd24e007e,0xe291007e,0x201800ce,0x00000000}},	//   دنی_, _لذت_, íria_,
  { {0x2d9a0034,0x69de0035,0xbddb00cd,0x00000000}},	//   _pope_, yope, rrèn,
  { {0x7ae600cf,0xdce50066,0xdb0400ca,0x00000000}},	//   _rykt, _dohľ, skië,
  { {0x6d5c00d0,0xed57005a,0x7e7d00d1,0x00000000}},	//   rfra, ьор_, avsp,
  { {0x8ffa007e,0x6c070021,0x6d5c00d2,0x00000000}},	//   _برتر_, ِيِّ_, sfra,
  { {0x69de00d3,0x2d9a00d4,0x8f8b009a,0x00000000}},	// [080] tope, _tope_, _וְיֵ,
  { {0x7bcd00d5,0x7ae60078,0x4c6a00d6,0x00000000}},	//   anau, _vykt, _дион_,
  { {0x8b2600d7,0x69de00d8,0xeb9a00d9,0x00000000}},	//   _одне, rope, _дин_,
  { {0x46ea00da,0xfaa60085,0x7bdf00db,0x00000000}},	//   оден_, _жамо, coqu,
  { {0x69de00dc,0xe67700dd,0xd61700de,0x00000000}},	//   pope, _aţâţ, وتوا_,
  { {0x645800df,0x644a00e0,0x5ee9009d,0x00000000}},	//   ttvi, tufi, הַצְ,
  { {0x645800d1,0xd90d007e,0x799c002b,0x00000000}},	//   utvi, _ایم_, _iorw,
  { {0xc27400e1,0x02a600e2,0x74690054,0x00000000}},	//   елиј, дром, ярів_,
  { {0x6aa400e3,0x200e00e4,0x026a0054,0x00000000}},	//   nyif, _sufi_, іший_,
  { {0xb5aa0021,0xc1780078,0x680c0058,0x00000000}},	//   _بارك_, udė_, _eşde,
  { {0xc1780006,0x61e800e5,0x799c00e6,0x00000000}},	//   rdė_, rldl, _morw,
  { {0xdce50024,0xd5c80013,0x68e300e7,0x00000000}},	//   _pohľ, iềm_, ündi,
  { {0x799c00e8,0x7bdf00e9,0x69cb00ea,0x00000000}},	//   _oorw, voqu, égek,
  { {0x290700eb,0x6282004b,0x799c00ec,0x00000000}},	//   žnai_, _iroo, _norw,
  { {0x7bcd0006,0x7bdf00ed,0x3a2b00ee,0x00000000}},	//   tnau, toqu, _swcp_,
  { {0x628200ef,0x442c002b,0x26ee0042,0x00000000}},	//   _kroo, _mwd_, _जरूर_,
  { {0x2aab0086,0x8ff8007e,0x7bcd00f0,0x00000000}},	// [090] цтво_, _ترور_, rnau,
  { {0xdb0d0003,0x799c00f1,0xf99300f2,0x00000000}},	//   chaî, _corw, خبر_,
  { {0x200900f3,0x7bdf00f4,0xddcd0078,0x00000000}},	//   _kiai_, poqu, _kraž,
  { {0x6e2d00f5,0xa6350086,0x99890066,0x00000000}},	//   _kwab, енді, dsať_,
  { {0x799c00f6,0x68e70022,0xcfb8009a,0x00000000}},	//   _forw, _wyjd, ולאי_,
  { {0xba430006,0xc58b0076,0x799c001f,0x00000000}},	//   žįst, ющее_, _gorw,
  { {0x645c0019,0x7659001f,0xc01c008b,0x00000000}},	//   _äril, stwy, rước_,
  { {0x6f0d00f7,0x58050021,0x7c3a00f8,0x00000000}},	//   _ngac, _أورك, átri,
  { {0x628200f9,0x6b9d00fa,0x020500fb,0x00000000}},	//   _croo, _mosg, нзин,
  { {0x69c5007a,0x7c3a00fc,0xe5c400fd,0x00000000}},	//   nihe, štri, _исхо,
  { {0x69c500fe,0xf99200ff,0x3cf90042,0x00000000}},	//   iihe, ארי_, ंधों_,
  { {0x62820100,0x32070022,0x43840044,0x00000000}},	//   _froo, _winy_, _للمق,
  { {0xee370101,0x62820102,0x32070034,0x00000000}},	//   ння_, _groo, _tiny_,
  { {0x63a90103,0x00000000,0x00000000,0x00000000}},	//   lken,   ,   ,
  { {0x61d60063,0xe3c90013,0x6b9d0104,0x00000000}},	//   _אוסף_, hằm_, _bosg,
  { {0xebe30086,0x2009008b,0x63a90105,0x00000000}},	//   госп, _giai_, nken,
  { {0x799c0106,0x661c00c3,0x7bc4004b,0x00000000}},	// [0a0] _porw, _črko, riiu,
  { {0xf2d200b5,0x61e10107,0x63a90108,0x00000000}},	//   װעב_, noll, hken,
  { {0x799c00bd,0x7c960021,0x63a90109,0x00000000}},	//   _vorw, _أشخا, kken,
  { {0x63a9006f,0x69c500fe,0xf4f30086,0x00000000}},	//   jken, aihe, _якiй_,
  { {0x63a9010a,0x99800006,0x7d11004c,0x00000000}},	//   dken, usių_, řesň,
  { {0x63a9010b,0x61e1010c,0xcb0a005d,0x00000000}},	//   eken, joll, _ويگن_,
  { {0x61e100fe,0x1867010d,0xb198008b,0x00000000}},	//   doll, _пари_, _nhưỡ,
  { {0x6282010e,0x645c004b,0x61e10072,0x00000000}},	//   _proo, _ärim, eoll,
  { {0x81c60062,0x61e1010f,0x660800b8,0x00000000}},	//   ещне, foll, _tidk,
  { {0x6282006f,0xbddb0110,0x7abb0063,0x00000000}},	//   _vroo, trèm, פציו,
  { {0x69cb00ea,0x79b70047,0xddcd0111,0x00000000}},	//   égei, גליד_, _praž,
  { {0x62820112,0x657a0113,0xd3790086,0x00000000}},	//   _troo, _hath, _очі_,
  { {0x71a60088,0xddcd0114,0x657a0115,0x00000000}},	//   _падз, _vraž, _kath,
  { {0xd12f006a,0x61e10116,0x40940021,0x00000000}},	//   _همه_, coll, _للتر,
  { {0xddcd0117,0x6b9d0118,0x62800119,0x00000000}},	//   _traž, _posg, lvmo,
  { {0x657a011a,0xddcd011b,0x00000000,0x00000000}},	//   _lath, _uraž,   ,
  { {0x3df5011c,0xef64005a,0xb9550062,0x00000000}},	// [0b0] _изис, _също, кващ,
  { {0xdb0d0025,0xd944005e,0x3eb30058,0x00000000}},	//   mhaí, леђи, ıntı_,
  { {0xf84b000d,0x69c5011d,0x63a9011e,0x00000000}},	//   ячай_, rihe, yken,
  { {0x07a40054,0x2eab009a,0xdc88009a,0x00000000}},	//   лаєн, ּשַּ, _נְתָ,
  { {0x8b9a0063,0x657a011f,0x61e10058,0x00000000}},	//   _חברת, _bath, yoll,
  { {0x65940086,0x657a0120,0xb6a20121,0x00000000}},	//   лачу, _cath, ришл,
  { {0x69d50122,0x657a0123,0x20180124,0x00000000}},	//   _ijze, _dath, íril_,
  { {0x68e300bd,0xc1780006,0x657a0025,0x00000000}},	//   ündu, klės_, _eath,
  { {0x657a0125,0x853c0006,0x63a90126,0x00000000}},	//   _fath, _plėt, rken,
  { {0x657a0127,0x61e10072,0x36040021,0x00000000}},	//   _gath, uoll, _موقف,
  { {0x63a900ac,0x61e10128,0x9f42004c,0x00000000}},	//   pken, roll, elká_,
  { {0x61e100fe,0x43740129,0x00000000,0x00000000}},	//   soll, _бушт,   ,
  { {0x61e1012a,0x63a6012b,0xe298012c,0x00000000}},	//   poll, ökne, _паї_,
  { {0x6145012d,0xddcd0022,0x67f8011b,0x00000000}},	//   _река, _graż, míje,
  { {0xb024001b,0xfce6012e,0xc1780078,0x00000000}},	//   _trườ, тово, alės_,
  { {0x1e86012f,0x69d50130,0xbb430131,0x00000000}},	//   _алим, _ajze, иеск,
  { {0xc3320132,0xdcfe008f,0x7f7700ff,0x00000000}},	// [0c0] יון_, _kopī, _יעקב_,
  { {0xe9d70133,0xa96a0044,0xadfa0044,0x00000000}},	//   вку_, ظمام_, _تربط_,
  { {0xdd05000c,0x657a0134,0x777b0135,0x00000000}},	//   ăsăt, _rath, _baux,
  { {0x62840006,0xe3b8005b,0x7bda0003,0x00000000}},	//   _šiom, _atın_, étud,
  { {0x657a0136,0x0af60085,0x29050046,0x00000000}},	//   _path, _шчоў, _úlan_,
  { {0x7c3a0024,0x645c0019,0xdce7008f,0x00000000}},	//   štru, _ärik, lejā,
  { {0xd4670001,0xe5a3005e,0x629d0137,0x00000000}},	//   вије_, рији, äson,
  { {0x07a30138,0xdb040139,0x853c0078,0x00000000}},	//   _касн, dhiú, _plės,
  { {0xa665013a,0x657a013b,0xe2840043,0x00000000}},	//   _مطلو, _tath, اطبی,
  { {0x601e003d,0x657a0027,0x7c3e00c2,0x00000000}},	//   _līme, _uath, _ovpr,
  { {0x9f35013c,0xdb04013d,0x8937009a,0x00000000}},	//   лені, ghiú, כריע_,
  { {0xdb0d0027,0xddcd0051,0x67f8004c,0x00000000}},	//   thaí, _wraż, bíje,
  { {0x7c220066,0xc1780078,0xdce7008f,0x00000000}},	//   _čora, ulės_, dejā,
  { {0xdcf5001c,0x3134013e,0xc237009a,0x00000000}},	//   edzā, _секр, _ירדו_,
  { {0x3ead004c,0xc1780078,0xa3d60042,0x00000000}},	//   šet_, slės_, _सदा_,
  { {0x644a0025,0xbddb0003,0xc1780078,0x00000000}},	//   irfi, guèr, plės_,
  { {0x62840006,0xdd910021,0x8ae70054,0x00000000}},	// [0d0] _šioj, _هوة_, тівл,
  { {0x23b10024,0x3ea40137,0x4c95013f,0x00000000}},	//   _mája_, ämte_, _биос,
  { {0x98140021,0x29070140,0x645c004b,0x00000000}},	//   لبنا, äna_, _ärih,
  { {0xc8640141,0x47350142,0x8c1a009a,0x00000000}},	//   ртфи, ундс, _רורי,
  { {0x7bda0003,0x644a0143,0x9f440003,0x00000000}},	//   étue, erfi, ômé_,
  { {0x2731001b,0x6d550144,0x601e001c,0x00000000}},	//   ạn_, ngza, _zīme,
  { {0xe8940076,0x87db007e,0x19580145,0x00000000}},	//   _карь, _قبرس_, _шары_,
  { {0x29070078,0xb8f70042,0xe3e9005d,0x00000000}},	//   žnas_, ाप_, رکان_,
  { {0x443e0146,0x11e50062,0x38780051,0x00000000}},	//   _evt_, лжим, _zsrr_,
  { {0x443e0147,0x67f80066,0xdb040139,0x00000000}},	//   _fvt_, ríje, thiú,
  { {0x8fa60148,0xcea90149,0x9fca014a,0x00000000}},	//   гане, _צי_, егна_,
  { {0x2619008d,0x99de014b,0xa8a8009a,0x00000000}},	//   _kèo_, бiла_, דֹשִ,
  { {0xe1ee014c,0x29cf0023,0x2bc60042,0x00000000}},	//   _гг_, aļai_, रोफा,
  { {0x26190013,0xd00e005d,0x2bc60082,0x00000000}},	//   _mèo_, _کلي_, रोना,
  { {0x225f00ea,0x26190013,0xec16014d,0x00000000}},	//   ltuk_, _lèo_, اورد,
  { {0xc052014e,0x753800a8,0x8b08011b,0x00000000}},	//   _הזה_, zavz, jpří,
  { {0x225f014f,0xdd04005b,0x5b350085,0x00000000}},	// [0e0] ntuk_, ırıs, рэсу,
  { {0x6e24005b,0x44270150,0x62840078,0x00000000}},	//   _itib, kpn_, _šiok,
  { {0x601e003d,0x574a0062,0x31360041,0x00000000}},	//   _tīme, езем_, רנעם_,
  { {0x645c0019,0xbddb0003,0x26190013,0x00000000}},	//   _ärii, quèr, _bèo_,
  { {0x47330086,0x443e0151,0xe5c60152,0x00000000}},	//   сніс, _svt_, лско,
  { {0x225f00ea,0x8b080080,0x2816007e,0x00000000}},	//   dtuk_, apří, _موسس,
  { {0x67dc00a8,0xf8780063,0xb4660044,0x00000000}},	//   ečje, _בְּל, ادته,
  { {0x7f440153,0x722a0154,0x5c370041,0x00000000}},	//   _ndiq, нцов_, ארקן_,
  { {0xd214005e,0x8556002a,0x27e60155,0x00000000}},	//   јмоћ, _مخاط, moon_,
  { {0x104a0156,0x27e60157,0x9a420013,0x00000000}},	//   нями_, loon_, _đẳn,
  { {0x2a600019,0x645e00cd,0x6e240035,0x00000000}},	//   htib_, àpid, _atib,
  { {0x27e60158,0x236600a8,0x41b4005d,0x00000000}},	//   noon_, _uboj_, امگر,
  { {0x63a20159,0xf194015a,0x6234015b,0x00000000}},	//   _ioon, _виль, _телу,
  { {0x63a20019,0x27e6015c,0x3cb5000d,0x00000000}},	//   _hoon, hoon_, айгр,
  { {0x63a20019,0x27e6015d,0x14d8009d,0x00000000}},	//   _koon, koon_, דַּמ,
  { {0x63a20019,0x764b001f,0x30130062,0x00000000}},	//   _joon, yrgy, _удър,
  { {0x63a2015e,0x27e6015f,0xc9870160,0x00000000}},	// [0f0] _moon, doon_, лужи,
  { {0x7e6d00bb,0x2bc60161,0x60d3001c,0x00000000}},	//   _ipap, रोबा, ņemš,
  { {0x27e60162,0x6d450035,0x225f0163,0x00000000}},	//   foon_, _idha, ztuk_,
  { {0x63a2002c,0xd5b60001,0xbddb0164,0x00000000}},	//   _noon, cикл, ssèd,
  { {0x69cb00ea,0xbb3a0165,0xe6c7005d,0x00000000}},	//   éges, _בערי, دتاي,
  { {0x3a290089,0xd5bb000d,0x64a50121,0x00000000}},	//   mpap_, эсе_, иала,
  { {0x63a20166,0x9f420167,0x27e60168,0x00000000}},	//   _boon, soké_, boon_,
  { {0x225f00ea,0xc2450169,0xdb04013d,0x00000000}},	//   ttuk_, аник, lkiá,
  { {0xa3d6016a,0x6d45016b,0x63a2016c,0x00000000}},	//   _सदर_, _odha, _doon,
  { {0x6d450035,0xb5fd007d,0x7c250139,0x00000000}},	//   _ndha, _opši, _othr,
  { {0x229a00eb,0x4049005a,0x225f016d,0x00000000}},	//   ešką_, ъпно_, stuk_,
  { {0x225f00ea,0x3861002b,0xc49a016e,0x00000000}},	//   ptuk_, ithr_, _בשעת,
  { {0x7c25016f,0x69c7007d,0x00000000,0x00000000}},	//   _athr, _omje,   ,
  { {0x63a20170,0x27e60171,0x291f0058,0x00000000}},	//   _zoon, zoon_, _şuan_,
  { {0x4174006a,0x2d840080,0x30790047,0x00000000}},	//   _دانس, ěme_, _יאַנ,
  { {0x4b26000d,0x69c70130,0x63a20172,0x00000000}},	//   рмав, _amje, _xoon,
  { {0x9a250021,0xdce7003b,0xba230062,0x00000000}},	// [100] معلن, tejă, ждук,
  { {0x1e3b014e,0x64410080,0x27e60173,0x00000000}},	//   _שגיא, _ovli, woon_,
  { {0xa3e50053,0xe73a0174,0xb607008f,0x00000000}},	//   पका_, вее_, _mašī,
  { {0x78a300fe,0xd8230086,0xd62a0175,0x00000000}},	//   änva, ідчи, воде_,
  { {0x27e60176,0x6d410026,0x64410177,0x00000000}},	//   roon_, ðlag, _avli,
  { {0x224d004b,0x3619000d,0xef1f0058,0x00000000}},	//   drek_, уццю_, zcü_,
  { {0xb7960001,0x63a20178,0x9423005e,0x00000000}},	//   _краћ, _poon, омје,
  { {0x67f80066,0x987b016e,0x224d0046,0x00000000}},	//   bíja, _באלט, frek_,
  { {0xe57a0001,0xfbb70063,0x64410058,0x00000000}},	//   _иза_, יפקת_, _evli,
  { {0x63a20179,0x2bc60053,0xdce70022,0x00000000}},	//   _woon, रोता, leją,
  { {0x63a2017a,0x09f70063,0x60f70121,0x00000000}},	//   _toon, שמים_, инья_,
  { {0x3f800016,0x224d017b,0x9f530058,0x00000000}},	//   _caiu_, brek_, _ödül_,
  { {0x539b0063,0xef1f0058,0x6253017c,0x00000000}},	//   _שידו, rcü_, ržoá,
  { {0xdb0d017d,0x3ea40137,0x7bd6017e,0x00000000}},	//   lhaç, ämta_, enyu,
  { {0xab950138,0xd1380051,0xddc4003b,0x00000000}},	//   бављ, ając_, _spiţ,
  { {0x69c7017f,0xbf35005a,0xdb0d017d,0x00000000}},	//   _smje, _унищ, nhaç,
  { {0x6d410014,0xe3b80075,0x2bc60042,0x00000000}},	// [110] ólas, _atık_, रोधा,
  { {0x6d450035,0xdcb1008b,0x2887005e,0x00000000}},	//   _udha, ở_, ићев,
  { {0xcd760063,0xa34c0078,0x4dda0063,0x00000000}},	//   _העתק_, dėžė_, _תחתו,
  { {0x2d8300ea,0x645700cd,0x44250180,0x00000000}},	//   ldje_, àxim, _rtl_,
  { {0x2d810019,0x7bcd0006,0x65b400cd,0x00000000}},	//   _kahe_, miau, _sàha,
  { {0x69c7017f,0x7bcd0006,0x85e80086,0x00000000}},	//   _umje, liau, адів_,
  { {0x23b1000f,0x69d700ac,0x628600b9,0x00000000}},	//   _fájl_, mnxe, ækon,
  { {0x2d810019,0x224d0181,0x7bcd0182,0x00000000}},	//   _lahe_, trek_, niau,
  { {0x27ed0058,0x61e8002b,0x11390183,0x00000000}},	//   _iken_, fodl, ляны_,
  { {0x224d00e8,0x3f800016,0x2d8100bd,0x00000000}},	//   rrek_, _saiu_, _nahe_,
  { {0x600a0184,0x7bcd0006,0xa069005e,0x00000000}},	//   лном_, kiau, ћама_,
  { {0x25a50185,0x224d0186,0xdb0d017d,0x00000000}},	//   _holl_, prek_, chaç,
  { {0x21690187,0x73c40021,0x25a50188,0x00000000}},	//   _били_, _بينم, _koll_,
  { {0x2d83017f,0x41260189,0xdce70022,0x00000000}},	//   gdje_, _лошо_, zeją,
  { {0x645c0019,0x27ed018a,0x765d00a5,0x00000000}},	//   _ärit, _oken_, _åsyf,
  { {0x7bcd0006,0x8b95018b,0x25a5004b,0x00000000}},	//   giau, оруч, _loll_,
  { {0xdb1d00b9,0x3946000d,0x63bb004d,0x00000000}},	// [120] _omsæ, йнаг, ihun,
  { {0x25a500c7,0x2fc900c2,0x645c018c,0x00000000}},	//   _noll_, _zmag_, _årig,
  { {0x6c860032,0xddd60006,0x7bcd0006,0x00000000}},	//   _الجم, _kryž, biau,
  { {0x27ff018d,0xb73a0021,0x7bcd0003,0x00000000}},	//   _chun_, اثاء_, ciau,
  { {0x95ca018e,0x66e60086,0x25a5018f,0x00000000}},	//   лука_, щода, _boll_,
  { {0x27ed0190,0x63bb00bd,0x7a410080,0x00000000}},	//   _eken_, ehun, sátý,
  { {0x628b0191,0x29cf008f,0x6e36002b,0x00000000}},	//   _argo, aļas_, _lwyb,
  { {0x29150058,0x6b840192,0xb8cc0042,0x00000000}},	//   ğdaş_, ndig, गह_,
  { {0xd1300032,0x1a9a00b5,0x61e80058,0x00000000}},	//   ومة_, ריִע, todl,
  { {0x361b0063,0x25a5001f,0x2fc900b9,0x00000000}},	//   _עובד, _goll_, _smag_,
  { {0x63bb0025,0x2d83007d,0x9f990193,0x00000000}},	//   bhun, vdje_, авну_,
  { {0xf8b3014e,0x753a0194,0x6b84006f,0x00000000}},	//   פשר_, _hetz, jdig,
  { {0x753a004d,0xddc40195,0x7bcd00d5,0x00000000}},	//   _ketz, _spiš, viau,
  { {0x753a00bd,0x645c0019,0x6b840196,0x00000000}},	//   _jetz, _äris, edig,
  { {0x7bcd0197,0x2d810019,0xe0d3005e,0x00000000}},	//   tiau, _vahe_, _ношњ,
  { {0xddc40198,0x753a0199,0x6b84006f,0x00000000}},	//   _vpiš, _letz, gdig,
  { {0x6e360185,0x7bcd019a,0xaa59019b,0x00000000}},	// [130] _gwyb, riau, ризу_,
  { {0x753a0199,0x7bcd0006,0x26360051,0x00000000}},	//   _netz, siau, dło_,
  { {0xddc4017f,0x90d5008b,0x213e0139,0x00000000}},	//   _upiš, hàn, iath_,
  { {0x25a50199,0xaa95019c,0x2bf40085,0x00000000}},	//   _soll_, _димч, _няўр,
  { {0xb5fd0117,0x9599019d,0x25a5019e,0x00000000}},	//   _opšt, итку_, _poll_,
  { {0x7afd019f,0x5e580063,0xe9180054,0x00000000}},	//   _izst, מידע_, _горі_,
  { {0x799500bd,0x25a500bd,0x27ff004d,0x00000000}},	//   _inzw, _voll_, _thun_,
  { {0x27ed0031,0x213e01a0,0x63bb01a1,0x00000000}},	//   _uken_, eath_, uhun,
  { {0x25a5010e,0xdcfc008f,0x63bb01a2,0x00000000}},	//   _toll_, idrā, rhun,
  { {0xdb1d0014,0x63bb01a3,0x504501a4,0x00000000}},	//   _umsæ, shun, оеоб,
  { {0xc952014e,0x00e20088,0x32050034,0x00000000}},	//   ומי_, джэн, rmly_,
  { {0x661b01a5,0x628b01a6,0xe3b301a7,0x00000000}},	//   _kuuk, _trgo, _عرض_,
  { {0x644300c7,0x333f0164,0x645c0019,0x00000000}},	//   lsni, maux_, _ärir,
  { {0x333f01a8,0x661b01a9,0x1167005d,0x00000000}},	//   laux_, _muuk, _طلبی_,
  { {0x8fa601aa,0x644301ab,0x70520021,0x00000000}},	//   _маке, nsni, _قنوا,
  { {0x333f0164,0x6b840173,0x26360051,0x00000000}},	//   naux_, udig, yło_,
  { {0x49ca0001,0x6b8401ac,0xba290021,0x00000000}},	// [140] алан_, rdig, مسلم_,
  { {0x6b8401ad,0x644301ae,0x00000000,0x00000000}},	//   sdig, ksni,   ,
  { {0x2d950088,0x3e6400fe,0x644301af,0x00000000}},	//   _хрыс, löt_, jsni,
  { {0x753a00bd,0x644301b0,0x6d5c01b1,0x00000000}},	//   _setz, dsni, lgra,
  { {0x7c2e00e8,0x96b70001,0x3e6401b2,0x00000000}},	//   lpbr, жују_, nöt_,
  { {0x64430146,0x2738001b,0xc7b900ea,0x00000000}},	//   fsni, ẩn_, _elő_,
  { {0x26360045,0x291801b3,0xe73a01b4,0x00000000}},	//   sło_, _igra_, _веб_,
  { {0x6d5c001f,0x333f0003,0x8c1b0063,0x00000000}},	//   hgra, gaux_, סופי,
  { {0x82a6000d,0xd6250021,0x644301b5,0x00000000}},	//   юшке, _فعلي, asni,
  { {0x62840006,0x644301b6,0xa158005e,0x00000000}},	//   _šios, bsni, љану_,
  { {0x333f0003,0x6d5c01b7,0xdfd100f2,0x00000000}},	//   baux_, dgra, فيد_,
  { {0x442e00bd,0x333f0164,0x4fc7000d,0x00000000}},	//   mpf_, caux_, існа,
  { {0x2294005a,0x645801b8,0x9f4e013d,0x00000000}},	//   _хиля, luvi, ónál_,
  { {0x6d5c01b9,0x64580080,0xe2a9007e,0x00000000}},	//   ggra, ouvi, _دامن_,
  { {0xe0d40047,0x6021001c,0x2ba70095,0x00000000}},	//   _מײַ_, _tēma, ојав,
  { {0x6d5c01ba,0x3f85001c,0x2d9e01bb,0x00000000}},	//   agra, ēlus_, öter_,
  { {0x201c0019,0xaa550062,0x6443008f,0x00000000}},	// [150] _huvi_, яваш, zsni,
  { {0x644301bc,0x645800fe,0xdce70051,0x00000000}},	//   ysni, kuvi, zeję,
  { {0x7d7a0063,0x333f0003,0xe7190021,0x00000000}},	//   _הנתו, yaux_, ميات_,
  { {0x644301b9,0x6c7a0047,0x2cac0137,0x00000000}},	//   vsni, _פארפ, ädde_,
  { {0x333f0164,0x7afd003d,0xcb9a0063,0x00000000}},	//   vaux_, _uzst, _הסרט,
  { {0x201c017d,0xae7c0063,0x3d190053,0x00000000}},	//   _ouvi_, שְׁת, _दलों_,
  { {0x333f0164,0x8cd10053,0xe3b10021,0x00000000}},	//   taux_, _डेमो, فرة_,
  { {0x644301bd,0xdb1d004d,0x3e640072,0x00000000}},	//   rsni, _umsä, yöt_,
  { {0x333f0164,0x644301be,0x6d5c01bf,0x00000000}},	//   raux_, ssni, ygra,
  { {0x644300eb,0x23b10066,0x64580078,0x00000000}},	//   psni, _máji_, buvi,
  { {0x333f0164,0x645c0019,0xc9520047,0x00000000}},	//   paux_, _ärip, עמט_,
  { {0xb4fa0063,0x3e640072,0x6d5c01c0,0x00000000}},	//   _הפעי, töt_, wgra,
  { {0x3fc9007e,0x6d5c01c1,0xcaea0042,0x00000000}},	//   تگوی_, tgra, _झुंड_,
  { {0xd1840054,0xda1f0042,0x91f700de,0x00000000}},	//   _олій, _बढ़त_, _بأصا,
  { {0x3e6400fe,0x9f9201c2,0x224600c2,0x00000000}},	//   söt_, lší_, _zvok_,
  { {0x6d5c01c3,0xba260085,0x9f42011b,0x00000000}},	//   sgra, здак, boká_,
  { {0x6e460032,0x6d5c01c4,0x9f920114,0x00000000}},	// [160] _عندم, pgra, nší_,
  { {0x7c2e01c5,0x67f80066,0x2b4001c6,0x00000000}},	//   ppbr, ríjm, saic_,
  { {0x9f920066,0x08c6005e,0x9d1b016e,0x00000000}},	//   hší_, џбен, _לויט,
  { {0x78720026,0x9f4b01a8,0xd70a0121,0x00000000}},	//   _aðvö, gocè_, бнее_,
  { {0x9f920114,0x9b17009a,0x28de0082,0x00000000}},	//   jší_, _מחכה_, _मशवि,
  { {0x8afb0063,0x645801c7,0x9f9201c8,0x00000000}},	//   _להכי, tuvi, dší_,
  { {0x69ce01c9,0xdd570047,0x986c008f,0x00000000}},	//   _imbe, לבסט_, rķēt_,
  { {0x7d0701ca,0x645801cb,0x03c30121,0x00000000}},	//   léré, ruvi, есьм,
  { {0x645801cc,0x201c01cd,0x518601ce,0x00000000}},	//   suvi, _suvi_, пуна,
  { {0x7d070164,0x645801cf,0x9f42004c,0x00000000}},	//   néré, puvi, voká_,
  { {0x9f920080,0x601e001c,0xf9930063,0x00000000}},	//   aší_, _zīmj, גרת_,
  { {0x60280080,0x78fb0047,0xb4fb0047,0x00000000}},	//   _něme, מפיו, _פלאר,
  { {0x69ce01d0,0x7e7d006f,0x7d0700ea,0x00000000}},	//   _ombe, uwsp, kéré,
  { {0x127b0041,0x9f4201d1,0x256f0075,0x00000000}},	//   _לאדע, roká_, cılı_,
  { {0x7d070164,0x6b8601d2,0x9f42004a,0x00000000}},	//   déré, _bakg, soká_,
  { {0x442c0089,0x69ce01d3,0x60db009a,0x00000000}},	//   _mtd_, _ambe, _לקונ,
  { {0xdcf2001c,0x7d0701d4,0x6a1501d5,0x00000000}},	// [170] īgāk, féré, дмау,
  { {0xceb20047,0x6e2d01d6,0x7d070003,0x00000000}},	//   _סיי_, _itab, géré,
  { {0xdcee000c,0xf1b30047,0x9f92004c,0x00000000}},	//   rebă, עסע_, zší_,
  { {0x256f005b,0x69ce01d7,0x6282004b,0x00000000}},	//   zılı_, _embe, _osoo,
  { {0x442c0080,0x644800c2,0xeafa0053,0x00000000}},	//   _atd_, _avdi, ्धृत_,
  { {0xcb1201d8,0x93b5001b,0x9f9201d9,0x00000000}},	//   _שלך_, _cũn, vší_,
  { {0x628200e8,0x6592007b,0x9f42004c,0x00000000}},	//   _asoo, тају, elký_,
  { {0x9f9201da,0xdcfe001c,0x442c01db,0x00000000}},	//   tší_, _japā, _dtd_,
  { {0x256f005b,0xa3be0053,0x69ce01dc,0x00000000}},	//   tılı_, ीफ़_, _ymbe,
  { {0xdcfe003d,0xab5b00bd,0x9f920114,0x00000000}},	//   _lapā, _flüg, rší_,
  { {0x41050055,0xd3710032,0x256f005b,0x00000000}},	//   ьзов, _لها_, rılı_,
  { {0x256f005b,0x9f920114,0x2252005b,0x00000000}},	//   sılı_, pší_, ünkü_,
  { {0xee3700a0,0xa29401dd,0x256f0058,0x00000000}},	//   мня_, _паці, pılı_,
  { {0x79870045,0x63ab01de,0x6e2d0025,0x00000000}},	//   _najw, _hogn, _dtab,
  { {0x2c870080,0x6e2d01df,0x7d0701e0,0x00000000}},	//   vídá_, _etab, véré,
  { {0x7076007e,0x672901e1,0xeb9701e2,0x00000000}},	//   _آميز_, _nfej, мис_,
  { {0x63a601e3,0x7d0701ca,0xc9aa000d,0x00000000}},	// [180] ökni, téré, овае_,
  { {0xc8d60044,0x00000000,0x00000000,0x00000000}},	//   وزاع,   ,   ,
  { {0x1d0a0002,0x07a60121,0x2a69004b,0x00000000}},	//   _фени_, мажн, atab_,
  { {0x7d070003,0xe73701e4,0x2d8a009c,0x00000000}},	//   séré, дец_, ldbe_,
  { {0x7d070164,0x47330086,0x442c01e5,0x00000000}},	//   péré, тніс, _std_,
  { {0x442c0089,0x69ce01e6,0x2d8a013d,0x00000000}},	//   _ptd_, _umbe, ndbe_,
  { {0xd8230062,0x644d008f,0xd75a0044,0x00000000}},	//   _адси, ņain, _ولست_,
  { {0x63ab01e7,0x8c1b009a,0xdc89009a,0x00000000}},	//   _cogn, חוקי, לְפָ,
  { {0x63ab00a8,0xa2940085,0x5313005d,0x00000000}},	//   _dogn, хапі, پذير,
  { {0x442c0150,0x60280080,0x2d8a00a8,0x00000000}},	//   _ttd_, _němc, jdbe_,
  { {0x63ab00ea,0x19570063,0xf9570063,0x00000000}},	//   _fogn, וביל_, וסית_,
  { {0xe29a01e8,0x33930021,0x78a301e9,0x00000000}},	//   _мае_, _للمز, änvi,
  { {0x31c601ea,0xc333009a,0x81a60044,0x00000000}},	//   _оскв, _סוס_, _يحتل,
  { {0xe0cf006a,0x12fb0063,0x00000000,0x00000000}},	//   ازی_, _והדב,   ,
  { {0xdb06000f,0xfbab0085,0x1df801eb,0x00000000}},	//   _elkü, отай_, феры_,
  { {0x9fe70021,0x2a6901ec,0x2cac0137,0x00000000}},	//   _تسته, ttab_, ädda_,
  { {0xdd950088,0x9e070086,0x6e2d0035,0x00000000}},	// [190] _запы, _очол, _utab,
  { {0x3df40121,0x6f000058,0x89340044,0x00000000}},	//   _изыс, ümce, نعما,
  { {0x2a690004,0x917b001b,0x22510051,0x00000000}},	//   stab_, _hệ_, ązki_,
  { {0xaad00042,0x957c0022,0xf093009a,0x00000000}},	//   _सेवक, _skąp, כנע_,
  { {0xcb36014e,0xc5f50062,0x63ab01ed,0x00000000}},	//   _ראשי_, някъ, _rogn,
  { {0x63ab01ee,0x659401ef,0xd7c9005d,0x00000000}},	//   _sogn, качу, _کوره_,
  { {0x917b001b,0x63ab01f0,0x7bdf01f1,0x00000000}},	//   _lệ_, _pogn, onqu,
  { {0xd2a90121,0x9992014b,0xf804014b,0x00000000}},	//   зкие_, лiзм_, _ачун,
  { {0x63ab01f2,0x7bda0003,0x645c00cf,0x00000000}},	//   _vogn, étui, _årin,
  { {0xd1c60121,0x1515000d,0xe50701f3,0x00000000}},	//   елье_, _здзя, _قباي,
  { {0x63ab01f4,0x672401f5,0xddcb0075,0x00000000}},	//   _togn, žije, _şişe,
  { {0x8fa601f6,0xa856009a,0xdd92005d,0x00000000}},	//   хаме, עירה_, گوس_,
  { {0xf1a8005d,0xeef50085,0x00000000,0x00000000}},	//   سایه_, вярэ,   ,
  { {0x92c101f7,0xc0e501f8,0xd245005d,0x00000000}},	//   ığın, _полк, یچ_,
  { {0xddcd000c,0x61e600ea,0x1d070002,0x00000000}},	//   _spaţ, ékle, еери_,
  { {0xfaa6014b,0xba1a00de,0x00000000,0x00000000}},	//   набо, كيرا_,   ,
  { {0x3956000a,0xc33201f9,0xf4120047,0x00000000}},	// [1a0] ењет, טון_, רפן_,
  { {0xac860079,0xdcfe000c,0x7bdf01fa,0x00000000}},	//   _згол, _capă, anqu,
  { {0xc1720063,0xa81a01fb,0xbb4601fc,0x00000000}},	//   רחב_, ستار_, _пенк,
  { {0xfaa601fd,0x999f008f,0xe66601f6,0x00000000}},	//   _замо, āršo_, етко,
  { {0x3c3e004c,0xcb150085,0xd5c50054,0x00000000}},	//   lův_, _афры, _кiмн,
  { {0xa4d4013c,0xe3b80058,0xe5a301fe,0x00000000}},	//   колі, _atıp_, личи,
  { {0x3c3e004c,0xa3cc0042,0xe44f0044,0x00000000}},	//   nův_, रफल_, مضي_,
  { {0x76690072,0x6f0401ff,0xc2980200,0x00000000}},	//   ösyö, _ozic, дких_,
  { {0xdac20054,0x66e30201,0x28020023,0x00000000}},	//   кцiя_, _бота, ārnē_,
  { {0x64a60202,0x2fc0013d,0x98ba003b,0x00000000}},	//   _паза, _alig_, capă_,
  { {0x7bd60089,0x8f35000d,0x320c002b,0x00000000}},	//   kiyu, кенц, rmdy_,
  { {0x83360021,0x3c3e004c,0x83690044,0x00000000}},	//   _أراض, dův_, _يصنف_,
  { {0x644a0203,0xddcd0078,0x82b3007e,0x00000000}},	//   lsfi, _apaš, _محوط,
  { {0x9f4b0080,0x917b008b,0x661a004c,0x00000000}},	//   mocí_, _vệ_, _jitk,
  { {0x661a00fe,0x644a0196,0x4c840085,0x00000000}},	//   _mitk, nsfi, ллёв,
  { {0xd13800eb,0x7bdf0204,0x749b0047,0x00000000}},	//   lbą_, unqu, הילפ,
  { {0x66d3000f,0x9f4b006d,0x4fd80063,0x00000000}},	// [1b0] _műkö, nocí_, _רוחב_,
  { {0x644a0205,0x317e0206,0x661a0207,0x00000000}},	//   ksfi, netz_, _nitk,
  { {0x20090208,0x6d470209,0x2fc000d1,0x00000000}},	//   _khai_, maja, _ylig_,
  { {0x6d47020a,0x7bc4020b,0x644a020c,0x00000000}},	//   laja, chiu, dsfi,
  { {0x6b9d00bd,0x46a40086,0x661a020d,0x00000000}},	//   _insg, лаїв, _bitk,
  { {0xab5b00bd,0x6d47020e,0x6b8d020f,0x00000000}},	//   _flüc, naja, ldag,
  { {0xab5b00bd,0x6d470210,0x6b8d0003,0x00000000}},	//   _glüc, iaja, odag,
  { {0xe65d005b,0x6d470211,0x6b8d0212,0x00000000}},	//   ştığ, haja, ndag,
  { {0x7412007e,0x6b8d0019,0x64580213,0x00000000}},	//   جويا, idag, arvi,
  { {0x27fd001f,0x93bc003b,0x6d470214,0x00000000}},	//   llwn_, _stăt, jaja,
  { {0x6d470215,0xf992014e,0x7659001f,0x00000000}},	//   daja, ברי_, lrwy,
  { {0x6b8d006f,0x20090216,0x1fb60217,0x00000000}},	//   jdag, _chai_, тсор,
  { {0x63a90117,0x93b6014e,0xddcd007d,0x00000000}},	//   mjen, _שלנו_, _spaš,
  { {0x6b8d0218,0x63a90219,0x865a0063,0x00000000}},	//   edag, ljen, ודשי,
  { {0x22510051,0xc5f20063,0x6b8d0014,0x00000000}},	//   ązku_, ידך_, fdag,
  { {0x6b8d00bb,0x69d7021a,0x63a9021b,0x00000000}},	//   gdag, eixe, njen,
  { {0x4b23019d,0x6d47021c,0x63bb0035,0x00000000}},	// [1c0] рмув, baja, ikun,
  { {0xfe1e0053,0x6b8d021d,0x63a9021e,0x00000000}},	//   _यूएस_, adag, hjen,
  { {0x7659021f,0x63a90220,0x8c43005b,0x00000000}},	//   erwy, kjen, üşte,
  { {0x69d700cd,0x6e240035,0x7659002b,0x00000000}},	//   aixe, _kuib, frwy,
  { {0x76590185,0x661a00fe,0x443e003e,0x00000000}},	//   grwy, _pitk, _swt_,
  { {0x69c50221,0x799c0222,0x6458007d,0x00000000}},	//   chhe, _unrw, trvi,
  { {0xd5b1008b,0x7659002b,0x661a0223,0x00000000}},	//   _tín_, arwy, _vitk,
  { {0x63a90224,0x64a30001,0xfe1e0053,0x00000000}},	//   gjen, раћа, _यूऍस_,
  { {0x20090185,0xfbd3014e,0x6d470035,0x00000000}},	//   _rhai_, יתה_, yaja,
  { {0xa3f50080,0x661a0173,0xdcfe0024,0x00000000}},	//   ější_, _uitk, _dopĺ,
  { {0xd1380006,0x6d470225,0x20090013,0x00000000}},	//   rbą_, vaja, _phai_,
  { {0x63bb00bd,0x317e00bd,0x63a90226,0x00000000}},	//   ckun, setz_, cjen,
  { {0x6d470227,0x42540021,0x6e24003b,0x00000000}},	//   taja, _إنتر, _cuib,
  { {0x3df40094,0x20d600de,0x00000000,0x00000000}},	//   изяс, _لتعج,   ,
  { {0x6d470228,0x80a3007e,0x6b8d0229,0x00000000}},	//   raja, _نمون, tdag,
  { {0x7659002b,0x5f7701fb,0x6d47022a,0x00000000}},	//   yrwy, _شاعر, saja,
  { {0xbf9b00ac,0x6b8d022b,0xf96b022c,0x00000000}},	// [1d0] glêe, rdag, дрей_,
  { {0x68fc022d,0x6b8d022e,0x49540044,0x00000000}},	//   _byrd, sdag, لخمس,
  { {0x6b8d022f,0x3eb90230,0xf795000d,0x00000000}},	//   pdag, lyst_, лажэ,
  { {0x76590185,0x98b8003b,0x3dcf0022,0x00000000}},	//   trwy, _seră_, żową_,
  { {0x61e1001f,0x6d450231,0xe736005e,0x00000000}},	//   ynll, _keha, ћеш_,
  { {0xe6180086,0x63bb006f,0x66d2005b,0x00000000}},	//   вді_, wkun, _sıkç,
  { {0x63a90232,0x7659001f,0x63bb0233,0x00000000}},	//   tjen, srwy, tkun,
  { {0x93bc000c,0x7c250150,0x7afd0234,0x00000000}},	//   _stăr, _muhr, _kyst,
  { {0x59b70235,0x63a90236,0x63bb0237,0x00000000}},	//   _आकार, rjen, rkun,
  { {0x6d4500c3,0x7afd0238,0xf0a90239,0x00000000}},	//   _neha, _myst, екол_,
  { {0x7afd023a,0xf1c30006,0x0467023b,0x00000000}},	//   _lyst, _ryšį_, _штам,
  { {0xdb0f017d,0xdb06023c,0x08760047,0x00000000}},	//   _você, _loká, נערט_,
  { {0x4425021f,0x69d50122,0x4e270062,0x00000000}},	//   _hul_, _omze, лоян_,
  { {0x6145000a,0x4ed50086,0x4425023d,0x00000000}},	//   _сека, рюют, _kul_,
  { {0x224d0150,0x4425023e,0xe0550021,0x00000000}},	//   lsek_, _jul_, _إختب,
  { {0x44250019,0xdcf5001c,0x7afd023f,0x00000000}},	//   _mul_, edzē, _byst,
  { {0xdcfc0240,0x7afd0241,0xa95a0242,0x00000000}},	// [1e0] merč, _cyst, فجار_,
  { {0x3f820004,0xd5b1001b,0x386100bd,0x00000000}},	//   leku_, _nó_, fuhr_,
  { {0x9f4b017d,0xdb06004a,0x31ba0047,0x00000000}},	//   locá_, _doká, עזענ,
  { {0x224d01f7,0x3f820019,0xc66a0001,0x00000000}},	//   ksek_, neku_, ешке_,
  { {0x7f3b00b5,0x7afd001f,0x68fc002b,0x00000000}},	//   גענו, _gyst, _wyrd,
  { {0xd5b100aa,0x4425005b,0x6441002b,0x00000000}},	//   _có_, _bul_, _bwli,
  { {0xd4670001,0x44250243,0x7afd0244,0x00000000}},	//   гије_, _cul_, _zyst,
  { {0x44250027,0x3f82017f,0x53980245,0x00000000}},	//   _dul_, jeku_, твия_,
  { {0x9f4b00cd,0xdb0600ea,0x316a0062,0x00000000}},	//   vocà_, _elkö, ншно_,
  { {0x6021001c,0xdb0f00cd,0x6441002b,0x00000000}},	//   _lēmu, _docè, _fwli,
  { {0x09f70063,0x44250246,0x798e002b,0x00000000}},	//   רמים_, _gul_, _mabw,
  { {0x6d45014f,0xdcf5001c,0x98b80006,0x00000000}},	//   _seha, zdzē, _gerą_,
  { {0x6d450247,0x44250248,0x00000000,0x00000000}},	//   _peha, _zul_,   ,
  { {0xbb1b0164,0xeb9f00d1,0x7afd000e,0x00000000}},	//   _maît, _snø_, _ryst,
  { {0x6c540054,0x6d450130,0x3f820249,0x00000000}},	//   йкру, _veha, beku_,
  { {0x7afd024a,0xdb06013d,0xa09b0063,0x00000000}},	//   _pyst, _soká, _טיוט,
  { {0x6d450019,0x79d50086,0xbb1b0003,0x00000000}},	// [1f0] _teha, ажає, _naît,
  { {0xdcf5008f,0x5d67005e,0x85420078,0x00000000}},	//   udzē, _стиз, šėja,
  { {0x7afd0045,0xd7c8007e,0xdb06024b,0x00000000}},	//   _wyst, گونه_, _voká,
  { {0x31e1024c,0x4425024d,0xe7190021,0x00000000}},	//   _पद्ध, _rul_, نيات_,
  { {0x4425024e,0x98aa001c,0xb6a50121,0x00000000}},	//   _sul_, ējām_, рилл,
  { {0x93bc000c,0x2d83024f,0x69d500ac,0x00000000}},	//   _stăp, neje_, _umze,
  { {0xe3b10032,0x75d2005d,0xf8b90042,0x00000000}},	//   قرة_, تيوا, _इथिय,
  { {0xdb1d0026,0x44250250,0x224d00a4,0x00000000}},	//   _umsó, _vul_, tsek_,
  { {0x290c0025,0xa235000d,0xdcfc0006,0x00000000}},	//   _údar_, шэйш, verč,
  { {0x601f0078,0x41b50251,0x224d0252,0x00000000}},	//   _rūma, рсит, rsek_,
  { {0x3f820253,0x66ca00ea,0xa069005e,0x00000000}},	//   teku_, _töké, њама_,
  { {0xe0d6005a,0x52d90121,0xdb1d0046,0x00000000}},	//   рвю_, _имею_, _alsí,
  { {0xab5b004d,0x3f8200a8,0x2d830254,0x00000000}},	//   _plün, reku_, feje_,
  { {0xae870002,0x3f820255,0x7bc8008f,0x00000000}},	//   јбрз_, seku_, īdum,
  { {0xdd0e005b,0x8c460256,0x7bc80023,0x00000000}},	//   _dışa, ребе, ūdum,
  { {0xc0520063,0xb92b0013,0x3ff30044,0x00000000}},	//   _וזה_, _thuỵ_, _وكور,
  { {0xeab70257,0x39460258,0xaae50044,0x00000000}},	// [200] айт_, инаг, مسكو,
  { {0xc8960259,0x2896005e,0x7d09004c,0x00000000}},	//   ирењ, ијес, řesa,
  { {0xc8ca01fb,0x8726025a,0xfeba005d,0x00000000}},	//   خوان_, амеж, _ساکت_,
  { {0x628b001f,0xeef60047,0x6d410046,0x00000000}},	//   _osgo, ֱמַר_, ðlav,
  { {0x6b84025b,0xb8fd0042,0x20020046,0x00000000}},	//   meig, _ते_, ilki_,
  { {0x6b84025c,0x9980005f,0xd5e30054,0x00000000}},	//   leig, rpių_, ожчи,
  { {0x29270024,0x26c0025d,0x6feb0022,0x00000000}},	//   ávať_, šio_, hęca,
  { {0x6b84025e,0x25b20078,0x290a025f,0x00000000}},	//   neig, _žalą_, _izba_,
  { {0xc1a600e1,0xbddb006c,0xa3c70042,0x00000000}},	//   ајни, isèr, _उतर_,
  { {0x6299002b,0xda160053,0x22590260,0x00000000}},	//   _drwo, थगित_, áska_,
  { {0xc95301f9,0x629900bd,0x2d830261,0x00000000}},	//   חמת_, _erwo, veje_,
  { {0x27e60262,0x03a30263,0x04db009a,0x00000000}},	//   nnon_, _михо, _בקבל,
  { {0x5f94011c,0x22580076,0x2005001c,0x00000000}},	//   цият, _силы_, ēli_,
  { {0x7bc6024a,0x27e60089,0x6b84004d,0x00000000}},	//   _alku, hnon_, eeig,
  { {0x6b840264,0x2d830265,0x705401fb,0x00000000}},	//   feig, reje_, _انبا,
  { {0x628b0185,0x2ba4000a,0xe0fb0063,0x00000000}},	//   _ysgo, ојув, _שלהל,
  { {0x0a6b0062,0x29050266,0x8ed8007e,0x00000000}},	// [210] ърви_, _šla_, _پذير_,
  { {0x7bc6013d,0x780f0042,0x99d40044,0x00000000}},	//   _elku, िष्क_, يتلا,
  { {0x6b84003d,0x6d410014,0x63a20267,0x00000000}},	//   beig, ðlau, _onon,
  { {0x20140268,0x27e60269,0x7d08004b,0x00000000}},	//   _èxit_, gnon_, üdse,
  { {0x23da0053,0xdcfc0023,0x4b7a009d,0x00000000}},	//   _बग़द, merā, _גארו,
  { {0xce38014e,0x63a2026a,0xdcfe004c,0x00000000}},	//   סאות_, _anon, _napě,
  { {0xd795005a,0x97a7026b,0x0574007e,0x00000000}},	//   _ливъ, _крал, تاند,
  { {0xc2450086,0xdcfc008f,0x69c7007d,0x00000000}},	//   бник, nerā, _hlje,
  { {0x248c0150,0xdd2c0078,0x6587026c,0x00000000}},	//   _esdm_, vėži, _выез,
  { {0x6b840199,0xbec40078,0x63a2026d,0x00000000}},	//   zeig, šūki, _enon,
  { {0x7dc20024,0x69c7007d,0xeae40042,0x00000000}},	//   _dôsl, _mlje, _गश्त_,
  { {0x7dc20024,0x87790047,0x20020072,0x00000000}},	//   _pôso, נאָי, ulki_,
  { {0x69c7026e,0xdcfc008f,0x8287005d,0x00000000}},	//   _olje, derā, _خجال,
  { {0xb6da0047,0x6b84026f,0x8e070054,0x00000000}},	//   אַלט, weig, йняв_,
  { {0x7d090080,0xdb1d01a8,0x27e600f1,0x00000000}},	//   řesn, _alsà, ynon_,
  { {0x6fc60139,0xdcfe017c,0x69c70270,0x00000000}},	//   _fóca, _topľ, _alje,
  { {0x7f3b0047,0x6b840271,0x69c7007d,0x00000000}},	// [220] _געפו, reig, _blje,
  { {0x6b840272,0xbddb0003,0x5d860021,0x00000000}},	//   seig, ssèr, _الدل,
  { {0x6d4e00bb,0x3f92003e,0x291c0140,0x00000000}},	//   maba, _kayu_, äva_,
  { {0x6d4e0273,0x78a30137,0x3a2601a8,0x00000000}},	//   laba, ånva, íops_,
  { {0xef1f0058,0x27e60274,0xdd070075,0x00000000}},	//   ldür_, rnon_, _köşk,
  { {0x6d4e0275,0x3f920150,0x225f0276,0x00000000}},	//   naba, _layu_, druk_,
  { {0xef1f005b,0x225f0089,0x2bbf0053,0x00000000}},	//   ndür_, eruk_, _एकमा,
  { {0x6d4e0277,0xa3d20053,0x69de0278,0x00000000}},	//   haba, हों_, lipe,
  { {0xe6430079,0x6d4e0279,0x7dcb005b,0x00000000}},	//   _нетп, kaba, _hüse,
  { {0x018a015a,0x6d4e027a,0x9f420240,0x00000000}},	//   ущий_, jaba, roký_,
  { {0x6d4e027b,0x672d027c,0x9f42027d,0x00000000}},	//   daba, žaje, soký_,
  { {0x69de027e,0x225f027f,0x926a0002,0x00000000}},	//   hipe, bruk_, _брка_,
  { {0x69de0280,0x394a007d,0x2bbf0042,0x00000000}},	//   kipe, _oebs_, _एकबा,
  { {0x6d4e0281,0x3fc9007e,0xbd450021,0x00000000}},	//   gaba, ادگی_, تنسي,
  { {0x69de0282,0x2a600019,0xdcfc008f,0x00000000}},	//   dipe, erib_, terā,
  { {0x69c70117,0x69de006f,0x6e460014,0x00000000}},	//   _slje, eipe, ðubú,
  { {0x6d4e00bb,0x59d9000d,0xddeb007e,0x00000000}},	// [230] baba, адаў_, _مرده_,
  { {0x24890051,0x49bb007e,0x6d4e0283,0x00000000}},	//   łami_, دارد_, caba,
  { {0x20100051,0x6d410058,0xdcfc008f,0x00000000}},	//   łnił_, ılad, perā,
  { {0x61fa006f,0x645700f8,0x225f0058,0x00000000}},	//   hotl, áxim, yruk_,
  { {0x7bdf0284,0xe611005d,0x7bcd0285,0x00000000}},	//   miqu, وشت_, mhau,
  { {0x7bdf0286,0x69c7007d,0x69de0287,0x00000000}},	//   liqu, _ulje, cipe,
  { {0xddcc00eb,0x9965004c,0xf992009a,0x00000000}},	//   _žiūr, _kůži_, _קרל_,
  { {0x61e80288,0x7bdf0289,0x7bcd028a,0x00000000}},	//   endl, niqu, nhau,
  { {0x66030024,0x3f920089,0x6d4e028b,0x00000000}},	//   plnk, _rayu_, yaba,
  { {0x7bdf0164,0x225f00d1,0x3f920089,0x00000000}},	//   hiqu, rruk_, _sayu_,
  { {0xbddb0268,0x0fda0021,0x6d4e028c,0x00000000}},	//   ipèd, لبحث_, vaba,
  { {0x6d4e028d,0x61fa0019,0x69de0035,0x00000000}},	//   waba, aotl, zipe,
  { {0x7bdf028e,0x6d4e028f,0xbf9b017d,0x00000000}},	//   diqu, taba, plên,
  { {0x112b0086,0x7bcd004d,0xf1940121,0x00000000}},	//   _сюди_, ehau, _ничь,
  { {0x6d4e027b,0x7f4f0290,0xdcfc003b,0x00000000}},	//   raba, bacq, deră,
  { {0x7bdf0291,0x6d410026,0x27ed01b3,0x00000000}},	//   giqu, ðlar, _njen_,
  { {0x6d4e0292,0x2d9300b9,0x69de0293,0x00000000}},	// [240] paba, _faxe_, tipe,
  { {0xdcfc000c,0xdcf5005b,0x6f040058,0x00000000}},	//   geră, _çağr, _iyic,
  { {0x881a000d,0x32050294,0x7bdf01fa,0x00000000}},	//   аўду_, illy_, biqu,
  { {0x394a0295,0xfaa6000d,0x7bcd0296,0x00000000}},	//   _webs_, _дамо, chau,
  { {0xdcfc003b,0x7f8d0047,0x61e80046,0x00000000}},	//   beră, טנאַ, yndl,
  { {0x27ed00e3,0xfc4b0080,0xfe9b0041,0x00000000}},	//   _ejen_, říž_, יינמ,
  { {0x60280080,0x69dc0025,0xab5b004d,0x00000000}},	//   _těmi, _imre, _blüh,
  { {0x78a10297,0x442200c7,0xd3770076,0x00000000}},	//   _álva, ök_, очь_,
  { {0x61fa0298,0x7bc40078,0x41ea0299,0x00000000}},	//   totl, ikiu, ифом_,
  { {0x2fc9029a,0x443c01f4,0x61e8029b,0x00000000}},	//   _slag_, ppv_, undl,
  { {0x6f0d0051,0xdb0f029c,0x399b0047,0x00000000}},	//   _szac, _rocí, בייד,
  { {0x32050037,0x9325006a,0x7bdf0164,0x00000000}},	//   ally_, _فرهن, xiqu,
  { {0x2fc90179,0x69dc029d,0x6b96001f,0x00000000}},	//   _vlag_, _omre, ddyg,
  { {0x72e90047,0x6e3d029e,0x442c029f,0x00000000}},	//   _פֿײַ, rpsb, _kud_,
  { {0x7bdf02a0,0x3a23006f,0x4c9402a1,0x00000000}},	//   tiqu, _rijp_, мирс,
  { {0x5a3502a2,0x6e3d00df,0xbf9b00be,0x00000000}},	//   знат, ppsb, olêm,
  { {0x7bdf02a3,0x2d9302a4,0x6d41005b,0x00000000}},	// [250] riqu, _taxe_, ılab,
  { {0x442c0173,0x7bdf02a5,0x7bcd02a6,0x00000000}},	//   _oud_, siqu, shau,
  { {0x7bdf02a7,0x442c02a8,0x20ca0042,0x00000000}},	//   piqu, _nud_, ानिध,
  { {0xdcfc003b,0x69dc0058,0x5a470085,0x00000000}},	//   seră, _emre, _мэга,
  { {0xd6db02a9,0x6448002b,0xdcfc003b,0x00000000}},	//   јте_, _awdi, peră,
  { {0x442c02aa,0x3aba0063,0xdcf5008f,0x00000000}},	//   _bud_, _המשנ, jdzī,
  { {0x27ed02ab,0xdd7c0047,0x6d5a0139,0x00000000}},	//   _tjen_, יטגל, ótai,
  { {0xdcf5008f,0x398a0022,0xc24502ac,0x00000000}},	//   edzī, rósł_, пник,
  { {0x2362000f,0x69dc002b,0xe6880044,0x00000000}},	//   ókja_, _ymre, _ونفى_,
  { {0xdb060024,0x69c500bd,0x442c0025,0x00000000}},	//   _pokú, nkhe, _fud_,
  { {0x7bc40006,0x442c02ad,0xddc60078,0x00000000}},	//   ykiu, _gud_, sukū,
  { {0x27fd0034,0x764902ae,0x547a0063,0x00000000}},	//   nown_, _kwey, _לטעו,
  { {0xadf80053,0x69c502af,0xf2a501ce,0x00000000}},	//   ंकलन_, kkhe, _хилп,
  { {0x69c502b0,0x79950045,0x64600078,0x00000000}},	//   jkhe, _nazw, ūziš,
  { {0xdca302b1,0x61e102b2,0x1d0a02b3,0x00000000}},	//   нари, mill, севи_,
  { {0x61e102b4,0x67290150,0x60d60063,0x00000000}},	//   lill, _ngej, _מוצא_,
  { {0x3c190088,0x6b63000d,0x61e102b5,0x00000000}},	// [260] іўся_, экта, oill,
  { {0x6d41005b,0x3ea00150,0xa96a0021,0x00000000}},	//   ılac, _irit_, إمام_,
  { {0x7995004d,0x778602b6,0x61e10072,0x00000000}},	//   _dazw, злез, iill,
  { {0x442c0027,0x2d9802b7,0x2d8a02b8,0x00000000}},	//   _rud_, ldre_, lebe_,
  { {0x96b70001,0xd5ba026c,0x61e102b9,0x00000000}},	//   зују_, йск_, kill,
  { {0x2d9802ba,0x61e102bb,0x46390086,0x00000000}},	//   ndre_, jill, іччя_,
  { {0x7c260035,0x9553007e,0x628202bc,0x00000000}},	//   _kikr, رخوا, _spoo,
  { {0x9f590164,0x82380002,0x79950051,0x00000000}},	//   posé_, озис_, _zazw,
  { {0x6033000c,0x63b902bd,0xe3af0044,0x00000000}},	//   _răma, _down, ارى_,
  { {0xe1d80086,0xdcf5001c,0x61e102be,0x00000000}},	//   ідні_, udzī, gill,
  { {0x442c00f3,0xdcf5001c,0x61ef0003,0x00000000}},	//   _uud_, rdzī, écla,
  { {0x61e102bf,0x2d9802c0,0x3ea002c1,0x00000000}},	//   aill, edre_, _brit_,
  { {0x61e102c2,0x1ee7007e,0x3ea002c3,0x00000000}},	//   bill, سوسی_, _crit_,
  { {0x44260035,0x61e102c4,0x2d8a0244,0x00000000}},	//   _hio_, cill, gebe_,
  { {0x317b0063,0x717b0063,0x7c2602c5,0x00000000}},	//   _הרומ, _הנוס, _bikr,
  { {0x2d9802c6,0x3ea002c7,0xcf270021,0x00000000}},	//   adre_, _frit_, _عربي,
  { {0x61eb000f,0x442602c8,0x7c26017e,0x00000000}},	// [270] _állí, _mio_, _dikr,
  { {0x2d8a0016,0xeb9f01e1,0xdb0f01a8,0x00000000}},	//   cebe_, _skød_, _vocà,
  { {0x27fd02c9,0x9d190092,0x7c2602ca,0x00000000}},	//   town_, _фонт_, _fikr,
  { {0x629b0006,0xc794000d,0x442602cb,0x00000000}},	//   yvuo, ершы, _nio_,
  { {0x27fd0034,0x63b9001f,0x0f580063,0x00000000}},	//   rown_, _rown, ליאם_,
  { {0xd1260032,0x06f4007e,0x7c2602cc,0x00000000}},	//   _لم_, رسنج, _zikr,
  { {0x44260117,0x9475007e,0x61e102cd,0x00000000}},	//   _bio_, بگذا, vill,
  { {0x61e102ce,0x7c38006c,0x29110077,0x00000000}},	//   will, _évre, _izza_,
  { {0x61e102cf,0x442602d0,0x3f8b007d,0x00000000}},	//   till, _dio_, decu_,
  { {0x61e102d1,0x629b0078,0x7dd002d2,0x00000000}},	//   uill, rvuo, _käse,
  { {0x7dd0024a,0x63b90034,0x4426017d,0x00000000}},	//   _jäse, _town, _fio_,
  { {0x3ea00164,0x2d8a004d,0x442602d3,0x00000000}},	//   _prit_, webe_, _gio_,
  { {0x7dd000c7,0x61e102d4,0x2f55014b,0x00000000}},	//   _läse, pill, этэс,
  { {0x7c2602ab,0x44260290,0x3e7600b9,0x00000000}},	//   _sikr, _zio_, ræt_,
  { {0x3e760146,0x3b96000a,0x9fa000ac,0x00000000}},	//   sæt_, мјат, _léés_,
  { {0x6ff60021,0xea010013,0x2d8a02d5,0x00000000}},	//   _تستط, _đạp_, sebe_,
  { {0x3b07011c,0x7c2602d6,0x3a2602d7,0x00000000}},	// [280] дето_, _vikr, дмаг,
  { {0x60280080,0xc9860021,0x7dcb0058,0x00000000}},	//   _těmt, بشري, _hüsn,
  { {0x8cb50161,0x7c2600eb,0xbddb0110,0x00000000}},	//   _उपयो, _tikr, spèc,
  { {0x672d017f,0xb0b60047,0xebe602d8,0x00000000}},	//   žajn, ופעס_, _цомп,
  { {0x442602d9,0x667302da,0x501b009a,0x00000000}},	//   _rio_, ندور, קונו,
  { {0x44260035,0x15140085,0x00000000,0x00000000}},	//   _sio_, ндля,   ,
  { {0x442602db,0xe5a3005e,0xd49702dc,0x00000000}},	//   _pio_, тији, дры_,
  { {0xc1780078,0x29180022,0xdb0d0014,0x00000000}},	//   ynės_, ągać_, okað,
  { {0x442602dd,0xd166005a,0x8cb50053,0x00000000}},	//   _vio_, мъни, _उपभो,
  { {0xe29f007a,0x7c3e017f,0x7dd00137,0x00000000}},	//   æða_, _otpr, _läsb,
  { {0x442602de,0xf9930063,0xf946000d,0x00000000}},	//   _tio_, דרת_, чнiк_,
  { {0xdb0d0026,0x443e02df,0x442600d1,0x00000000}},	//   kkað, _itt_, _uio_,
  { {0x441b0047,0x645802e0,0xff0402e1,0x00000000}},	//   _וואס, lsvi, вярн,
  { {0x7ae900c3,0x443e0150,0x3f8b02e2,0x00000000}},	//   _žeto, _ktt_, secu_,
  { {0xc1780006,0x7e6600d1,0x645802ad,0x00000000}},	//   snės_, arkp, nsvi,
  { {0x5f95005a,0x69ce02e3,0x6fc60139,0x00000000}},	//   _чиит, _albe, _nóch,
  { {0x6feb0045,0xda150095,0xda7802e4,0x00000000}},	// [290] jęci, едањ, дях_,
  { {0x62770063,0x645802e5,0x443e02e6,0x00000000}},	//   וגמא_, ksvi, _ott_,
  { {0xab5b00bd,0x6d5502e7,0x443e02e8,0x00000000}},	//   _blüt, maza, _ntt_,
  { {0x6d5502e9,0x645802ea,0x7dd00137,0x00000000}},	//   laza, dsvi, _väse,
  { {0x443e02eb,0x6fc60025,0x4648000d,0x00000000}},	//   _att_, _dóch, дзін_,
  { {0x6d5502ec,0xdcee0006,0x6b8d02ed,0x00000000}},	//   naza, gebė, leag,
  { {0x26c9017f,0xd1380051,0x67d50121,0x00000000}},	//   šao_, dcą_, _зову,
  { {0x6d5502ee,0xa3d90053,0x6b8d02ef,0x00000000}},	//   haza, डों_, neag,
  { {0x443e02f0,0x645802f1,0x6d5502f2,0x00000000}},	//   _ett_, asvi, kaza,
  { {0xf1b10021,0x6d5502f3,0x66e4005e,0x00000000}},	//   اءة_, jaza, _рођа,
  { {0x672402f4,0x657c0137,0x6d5502f5,0x00000000}},	//   žijt, _örha, daza,
  { {0x72d50002,0xd4360047,0x649a0063,0x00000000}},	//   _поеф, _טרעק_, _מסעד,
  { {0xe1ee005a,0x63ab002c,0x3f9e0080,0x00000000}},	//   _бг_, _ingn, ětu_,
  { {0x7bcf02f6,0x443e00df,0x200b02f7,0x00000000}},	//   _alcu, _ytt_, alci_,
  { {0xb042001b,0xc5f20063,0x6feb0022,0x00000000}},	//   _trưở, אדם_, zęci,
  { {0x212b004c,0x8b2602f8,0x9f99013d,0x00000000}},	//   ěchu_, едбе, _táás_,
  { {0xada602f9,0x7dd000a5,0x4d3a02fa,0x00000000}},	// [2a0] _запл, _väsb, _няня_,
  { {0xdb0d007a,0x6d5e00b9,0x200200fe,0x00000000}},	//   rkað, _udpa, loki_,
  { {0x7c3e02fb,0x7dcb005b,0x7dc20066,0x00000000}},	//   _utpr, _müsl, _dôst,
  { {0x2ca50146,0x601602fc,0x645802fd,0x00000000}},	//   ælde_, lámb, vsvi,
  { {0xdcee0006,0x569402fe,0x69d1008f,0x00000000}},	//   tebė, талт, _ūdeņ,
  { {0xab5b00bd,0x245a001c,0x443e02ff,0x00000000}},	//   _flüs, tīm_, _ptt_,
  { {0x64580072,0x7d09004c,0x2d9a0300,0x00000000}},	//   usvi, řesv, _mape_,
  { {0xf753007e,0x987b0047,0xd1380051,0x00000000}},	//   _منفج, _מאלט, wcą_,
  { {0x20020301,0x249c0078,0x9f420072,0x00000000}},	//   doki_, _žymė_, inkä_,
  { {0x27e60302,0x91e30001,0x64580303,0x00000000}},	//   lion_, лоње, psvi,
  { {0x443e001c,0xc0570304,0xc32a0021,0x00000000}},	//   _utt_, нія_, _فكان_,
  { {0x27e60305,0xde59000d,0xd65e0054,0x00000000}},	//   nion_, мамі_, _вiдд,
  { {0x0e340076,0x6d550306,0xdb060066,0x00000000}},	//   лняю, taza, _poký,
  { {0x7d030307,0x27e6001f,0xbbc90053,0x00000000}},	//   _ønsk, hion_, रस्क,
  { {0x5ff5005a,0xfc640062,0x6d550308,0x00000000}},	//   _изку, лътн, raza,
  { {0xfc300032,0x6d5a0026,0x2cac0137,0x00000000}},	//   صحف_, ótar, ådda_,
  { {0x27e60309,0x6b8d030a,0x7dc200be,0x00000000}},	// [2b0] dion_, reag, _pôst,
  { {0x601602dd,0xd91b030b,0x22f7009d,0x00000000}},	//   ráme, пье_, תזמן_,
  { {0x27e6001f,0x6fc6017d,0x4ddc0063,0x00000000}},	//   fion_, _sóci, _מחזו,
  { {0x7659001f,0x27e60287,0xbcb60063,0x00000000}},	//   tswy, gion_, _ספרו_,
  { {0xa3b40161,0x601600ea,0x9f4b006d,0x00000000}},	//   ञान_, lámc, locó_,
  { {0x8578005a,0x7e7d030c,0x7d09004c,0x00000000}},	//   есът_, itsp, řesu,
  { {0x27e60185,0xcd980063,0xa8020058,0x00000000}},	//   bion_, גדות_, ğıra,
  { {0x27e6030d,0x7e7d030e,0x6443030f,0x00000000}},	//   cion_, ktsp, rpni,
  { {0x7dd000c7,0xdb160072,0xe7840094,0x00000000}},	//   _läsa, shyö, _щуро,
  { {0x7e7d01e1,0x64430310,0x10a502f8,0x00000000}},	//   dtsp, ppni, вион,
  { {0x63ab00a4,0x2d9a00e5,0x20020311,0x00000000}},	//   _tngn, _rape_, toki_,
  { {0x34b60063,0x7e7d0312,0xe4580054,0x00000000}},	//   _בפעם_, ftsp, _їжі_,
  { {0x2d9a0313,0x66030019,0x7e7d01e1,0x00000000}},	//   _pape_, oonk, gtsp,
  { {0x27e60314,0x66030315,0x2259004c,0x00000000}},	//   zion_, nonk, ásku_,
  { {0x7e7d030c,0x7dd0004d,0x40320131,0x00000000}},	//   atsp, _cäsa, _кејс,
  { {0x27e60316,0x66030317,0x290a0318,0x00000000}},	//   xion_, honk, _ryba_,
  { {0x3ae8006a,0x2d9a0319,0x27e6031a,0x00000000}},	// [2c0] ربری_, _tape_, vion_,
  { {0xdcfc001c,0x24920051,0x2b4900c6,0x00000000}},	//   ndrī, łymi_, abac_,
  { {0xdcfc001c,0x27e6031b,0xdb060051,0x00000000}},	//   idrī, tion_, _pokó,
  { {0x6c57009a,0x4c79009a,0x00000000,0x00000000}},	//   _ביטא_, _אָשׁ,   ,
  { {0x6441031c,0xa3ab0161,0x7d090080,0x00000000}},	//   _atli, खाई_, řest,
  { {0x27e6031d,0xdb060051,0xd943031e,0x00000000}},	//   sion_, _wokó, _вери,
  { {0x27e6031f,0x9f59013d,0x09e30320,0x00000000}},	//   pion_, őzés_, _торн,
  { {0xc274000a,0x32980002,0xdcfc001c,0x00000000}},	//   глиј, евиќ_, edrī,
  { {0x877b0047,0x64410321,0xdb0d0014,0x00000000}},	//   _קאמי, _etli, skaö,
  { {0x75d3007e,0xc05a0085,0x6453013d,0x00000000}},	//   _پيما, мім_, údió,
  { {0x799c0322,0xc60e0053,0x43860044,0x00000000}},	//   _marw, ितीय_, _للاق,
  { {0x9f4b006d,0x6d41005b,0x7e7d0323,0x00000000}},	//   vocó_, ılam, ttsp,
  { {0x7ee40054,0xdbdc0046,0x2e4b030b,0x00000000}},	//   ацре, _ráðn, ьяно_,
  { {0x2d850195,0x3d950121,0x644100a5,0x00000000}},	//   ýle_, ыигр, _ytli,
  { {0x61e802ab,0x2ca50026,0x9f5900cd,0x00000000}},	//   midl, íld_, posà_,
  { {0xef67011c,0x3ec70088,0xa3ab0053,0x00000000}},	//   _ръко, _асоб, खाए_,
  { {0x799c0324,0x5b1502e4,0x2009008f,0x00000000}},	// [2d0] _barw, умат, _ikai_,
  { {0xc27b0063,0x799c002b,0xdb1d0325,0x00000000}},	//   ורמי, _carw, _josé,
  { {0x2d910326,0x6f0d0327,0xa9280085,0x00000000}},	//   meze_, _hyac, віце_,
  { {0x2d91000c,0x1b4b0021,0x7bd601a8,0x00000000}},	//   leze_, _تؤدي_, chyu,
  { {0x799c001f,0x7bcd0328,0xd24601f3,0x00000000}},	//   _farw, mkau, _دن_,
  { {0x2d91000c,0xca7a0047,0x7bcb0014,0x00000000}},	//   neze_, _אנשט, öguf,
  { {0x60160026,0x66030329,0x2009013d,0x00000000}},	//   háma, ronk, _okai_,
  { {0xe2b90001,0xddc60078,0x61e8008f,0x00000000}},	//   ећој_, iukš, eidl,
  { {0x2fc0032a,0x56f50002,0x6603032b,0x00000000}},	//   _roig_, _спаѓ, ponk,
  { {0x2d83006f,0x2d91001a,0xe573002a,0x00000000}},	//   jfje_, jeze_, _خطر_,
  { {0x7bcd00fe,0x9f4b0290,0x2d91032c,0x00000000}},	//   kkau, vocò_, deze_,
  { {0xeb9f00b9,0xbb1b0003,0x5275032d,0x00000000}},	//   _skøn_, _abîm, _буку,
  { {0xee370062,0x61e80139,0xd5a70054,0x00000000}},	//   лня_, bidl, _пiдп,
  { {0x63bb032e,0x6da6005e,0x61e8032f,0x00000000}},	//   ljun, ћива, cidl,
  { {0xdca10086,0x8fa60330,0x6f0d0331,0x00000000}},	//   остi_, _байе, _eyac,
  { {0x6b9d0185,0x7bcd002c,0xdb0f017d,0x00000000}},	//   _casg, gkau, _incê,
  { {0xc3320132,0x4b550062,0xa3b40053,0x00000000}},	// [2e0] מון_, ръст, ञात_,
  { {0xfd4a0086,0x7bcd0332,0x63bb004b,0x00000000}},	//   _язок_, akau, hjun,
  { {0x63bb0026,0xe4e30053,0x6b9d002b,0x00000000}},	//   kjun, _केलि_, _fasg,
  { {0x6b9d0333,0x6033003b,0x18670002,0x00000000}},	//   _gasg, _cămi, ѓачи_,
  { {0x63bb0334,0x799c0335,0xdcfe0078,0x00000000}},	//   djun, _tarw, _papė,
  { {0xd49a0336,0x6b840337,0x09e6030b,0x00000000}},	//   ери_, lfig, _согн,
  { {0x61e80114,0x395a0338,0xdb1d00f4,0x00000000}},	//   vidl, maps_, _rosé,
  { {0x2d910339,0x7dcb0058,0x6f090022,0x00000000}},	//   zeze_, _püsk, żeci,
  { {0xd1300032,0xdb0f0003,0xdb1d00f4,0x00000000}},	//   يمة_, _ancê, _posé,
  { {0xfa970047,0x2d91000c,0xda7b0047,0x00000000}},	//   נדיש_, xeze_, עניר,
  { {0xe475000d,0x33860062,0x2d91033a,0x00000000}},	//   _вучэ, _булв, veze_,
  { {0x2d910035,0x61e8033b,0x8f4702dc,0x00000000}},	//   weze_, sidl, ыход,
  { {0x61e8033c,0x2d91033d,0x6b9d033e,0x00000000}},	//   pidl, teze_, _rasg,
  { {0x7dcb0004,0x60160025,0x6aa9007d,0x00000000}},	//   _küsi, ráma, _šefo,
  { {0x6b9d0186,0x6b84033f,0xa1570063,0x00000000}},	//   _pasg, ffig, _גבוה_,
  { {0x2d910340,0x7bcd0341,0x62800229,0x00000000}},	//   seze_, ukau, otmo,
  { {0x6b9d00e8,0x63bd0137,0xb9550062,0x00000000}},	// [2f0] _vasg, ösni, иващ,
  { {0x7bcd0342,0x6b9d002b,0x00000000,0x00000000}},	//   skau, _wasg,   ,
  { {0x6b9d002b,0x61ef0343,0xdbdc013d,0x00000000}},	//   _tasg, écli, _ráön,
  { {0x3ea90344,0x6b9d0139,0xf77300f2,0x00000000}},	//   _krat_, _uasg, صاص_,
  { {0x9f82006f,0x29180345,0x9f4c013d,0x00000000}},	//   _zóó_, _ezra_, élék_,
  { {0xb5fd0080,0x4ade0161,0x628000d1,0x00000000}},	//   _ovše, _नेटव, dtmo,
  { {0xdb0600ea,0xb465007e,0x628000ca,0x00000000}},	//   _inká, شگاه, etmo,
  { {0xea01008b,0xd2650330,0x63bb0346,0x00000000}},	//   _đẹp_, акий, ujun,
  { {0x7c2f0347,0x63bb0348,0xd7f80349,0x00000000}},	//   _micr, rjun, _сур_,
  { {0x6ff2008f,0x7dcb004b,0x98a10058,0x00000000}},	//   māci, _füsi, lahı_,
  { {0x7dd000c7,0x6ff2001c,0xf9920063,0x00000000}},	//   _säso, lāci, חרי_,
  { {0x3ea9034a,0x08760041,0xff26034b,0x00000000}},	//   _brat_, סערט_, имно,
  { {0x6ff2001c,0x9404007e,0x3205034c,0x00000000}},	//   nāci, _اونه, poly_,
  { {0xc5f20047,0x69c30058,0x8e0701d5,0x00000000}},	//   ַדן_, önel, иняв_,
  { {0x2d9e034d,0x442f0146,0xa3cc0053,0x00000000}},	//   ľte_, _kig_, _रकम_,
  { {0x6ff2003d,0x2d9e0114,0xaec60054,0x00000000}},	//   kāci, žte_, _вбил,
  { {0x3ea9034e,0x3e7f003b,0x601600ea,0x00000000}},	// [300] _grat_, cît_, lámo,
  { {0x442f034f,0x6ff2008f,0xdb1d013d,0x00000000}},	//   _lig_, dāci, _alsó,
  { {0x6d4e00ea,0x6fcd0003,0xd910007e,0x00000000}},	//   mbba, _bûch, سیر_,
  { {0x6d5c0350,0xc60e0042,0x6016013d,0x00000000}},	//   lara, ित्य_, zámn,
  { {0xeb97005a,0x6ff2001c,0x2d8500cd,0x00000000}},	//   _тия_, gāci, òleg_,
  { {0x7dcb0019,0x6594000a,0x6d5c0351,0x00000000}},	//   _püsi, саку, nara,
  { {0x601d0164,0x442f0352,0x39580353,0x00000000}},	//   léme, _big_, _iers_,
  { {0x395800f6,0x442f001f,0x62800354,0x00000000}},	//   _hers_, _cig_, ttmo,
  { {0x442f0355,0x6d5c0356,0x601d0164,0x00000000}},	//   _dig_, kara, néme,
  { {0x6d5c0357,0x91b80002,0x6033003b,0x00000000}},	//   jara, угот_, _lămu,
  { {0xdfd10021,0x225f014f,0x54730021,0x00000000}},	//   كيد_, asuk_, _وهكذ,
  { {0x3ea90358,0x644a0359,0x442f035a,0x00000000}},	//   _prat_, mpfi, _gig_,
  { {0x6d5c035b,0x7c2f0290,0x7c24035c,0x00000000}},	//   fara, _ricr, dmir,
  { {0x7c2f0185,0x6d5c035d,0x3f55008b,0x00000000}},	//   _sicr, gara, ấu_,
  { {0x6ff2003d,0x61ef0164,0x69c30058,0x00000000}},	//   zāci, ècle, önem,
  { {0x3ea900bd,0x60290051,0xc1780078,0x00000000}},	//   _trat_, _ośmi, lgė_,
  { {0x6d5c035e,0xba550021,0x6d57035f,0x00000000}},	// [310] bara, صناع, _texa,
  { {0xe29f007a,0xc1780006,0x6d990076,0x00000000}},	//   æði_, ngė_, _своё_,
  { {0x2a600360,0x39580361,0x9f42004c,0x00000000}},	//   asib_, _ders_, liká_,
  { {0x395800e8,0x6ff2001c,0x7c24003b,0x00000000}},	//   _eers_, tāci, cmir,
  { {0x601600ea,0x442f015e,0xb6a50086,0x00000000}},	//   zámo, _rig_, силл,
  { {0x6ff2003d,0x442f0362,0xe5780054,0x00000000}},	//   rāci, _sig_, изі_,
  { {0xe3b10021,0x6ff2008f,0xd4660363,0x00000000}},	//   كرة_, sāci, бище_,
  { {0x1bf90053,0x3941004d,0x6d5c0364,0x00000000}},	//   ्किल_, lchs_, zara,
  { {0x6d5c0365,0x36d40366,0xa567007e,0x00000000}},	//   yara, _дотр, _ندان,
  { {0x6d5c0367,0x7c240368,0xd628005e,0x00000000}},	//   xara, zmir, _вође_,
  { {0x442f0025,0x3941004d,0x225f00ea,0x00000000}},	//   _tig_, ichs_, ssuk_,
  { {0xcdc9014e,0x6d5c0369,0x672d007d,0x00000000}},	//   _אך_, wara, žaju,
  { {0x6d5c0357,0xdb24005b,0x1e83000d,0x00000000}},	//   tara, üsün, плям,
  { {0x32b80032,0x7dd000fe,0xddd40066,0x00000000}},	//   _خدمة_, _täsm, ťažo,
  { {0x2fd7006a,0x8c46036a,0x6d5c036b,0x00000000}},	//   _گويد_, себе, rara,
  { {0x6d5c036c,0x9f820026,0x6bb50086,0x00000000}},	//   sara, _góð_, осує,
  { {0x3958036d,0x7c24036e,0x09360021,0x00000000}},	// [320] _pers_, rmir, مراج,
  { {0x6016000f,0x601d0164,0x8d560001,0x00000000}},	//   záml, réme, _утич,
  { {0x88860076,0x601d0164,0x3958036f,0x00000000}},	//   слеж, séme, _vers_,
  { {0x39410370,0x3958002b,0xc8850058,0x00000000}},	//   achs_, _wers_, daşı_,
  { {0xe5c60371,0x39580058,0x6d410058,0x00000000}},	//   йско, _ters_, ılav,
  { {0xa5f8005e,0xa3ca0053,0x7bc60372,0x00000000}},	//   јеку_, रॉन_, _hoku,
  { {0xe9d702a1,0x22460373,0x7bc60374,0x00000000}},	//   _укр_, _stok_, _koku,
  { {0x7dcb004e,0xebd6009a,0x00000000,0x00000000}},	//   _hüst, מֵ֥י_,   ,
  { {0x7ae9007a,0x7dcb0375,0x60290051,0x00000000}},	//   _þett, _küst, _uśmi,
  { {0xdcfc001c,0x104a0376,0xba9b0063,0x00000000}},	//   nerē, лями_, נסיי,
  { {0x672d00c2,0xe4520049,0xdb1d0061,0x00000000}},	//   žajt, _رضا_, _rosí,
  { {0x7bc600e8,0x601600ea,0x9f420066,0x00000000}},	//   _noku, lámj, tiká_,
  { {0xdb1d02f4,0x7f5d006c,0x5f940062,0x00000000}},	//   _posí, rasq, чият,
  { {0x270700aa,0x63a20139,0xdb110003,0x00000000}},	//   ống_, _haon, _âgée,
  { {0x7a290006,0xb1e50021,0xdcfc001c,0x00000000}},	//   _užti, _بأنه, derē,
  { {0x4a55000d,0x7c150054,0x2737004c,0x00000000}},	//   жкас, ідає, ižní_,
  { {0x63a20009,0x39410164,0x200b01f5,0x00000000}},	// [330] _maon, tchs_, moci_,
  { {0x200b0377,0x39a7005e,0x3941004d,0x00000000}},	//   loci_, љшав, uchs_,
  { {0xdcf5008f,0x7dcb0378,0x6016013d,0x00000000}},	//   iezī, _düst, zámm,
  { {0x61c50161,0xc885005b,0x63a20139,0x00000000}},	//   _लक्ष, vaşı_, _naon,
  { {0x4ae4000d,0xb5fd0240,0x7dcb013d,0x00000000}},	//   _еўра, _avša, _füst,
  { {0x96280021,0x7bc600ac,0xdcfc001c,0x00000000}},	//   مكنك_, _zoku, cerē,
  { {0xdb060137,0x7bc60379,0x200b037a,0x00000000}},	//   _enkä, _yoku, koci_,
  { {0xc245032d,0x7dcb02d2,0x04560044,0x00000000}},	//   оник, _küss, آلية_,
  { {0x69c70117,0x63a20025,0x85b9037b,0x00000000}},	//   _koje, _daon, _клас_,
  { {0x7dcb0199,0x91e50086,0x8065037c,0x00000000}},	//   _müss, іоне, овож,
  { {0x7e640026,0x8c43005b,0x76490072,0x00000000}},	//   _svip, üşle, _htey,
  { {0x200b0268,0x6d45037d,0x2465001c,0x00000000}},	//   goci_, _afha, mēm_,
  { {0xa2940097,0x2465001c,0x68e1004b,0x00000000}},	//   _наці, lēm_, _üldf,
  { {0x7dd0037e,0xe29f0026,0x63a20035,0x00000000}},	//   _käsi, æðu_, _zaon,
  { {0x7bc6037f,0x63a20380,0x7dcb0378,0x00000000}},	//   _poku, _yaon, _rüst,
  { {0x7dcb0004,0x1b4a000a,0xb06801fb,0x00000000}},	//   _süst, рзаи_, _اصول_,
  { {0x7e640035,0x7dcb0019,0x39ea0001,0x00000000}},	// [340] _uvip, _püst, адао_,
  { {0xfd120021,0x7dcb0381,0x27ef0046,0x00000000}},	//   _يجد_, _düss, eign_,
  { {0x764900a4,0x291c0137,0x2d980382,0x00000000}},	//   _atey, åva_, mere_,
  { {0x510c00b7,0x2465001c,0x7dcb004d,0x00000000}},	//   נהאַ, dēm_, _wüst,
  { {0xd5ba0055,0x63a20268,0x601d0003,0x00000000}},	//   иск_, _raon, néma,
  { {0xe4520032,0x2d980383,0x69c70384,0x00000000}},	//   وضع_, nere_, _goje,
  { {0x26090053,0xf7460002,0x291c004b,0x00000000}},	//   ाक़ी_, _мево, üvad_,
  { {0x2d980385,0x98ba00eb,0x9faf0080,0x00000000}},	//   here_, lapį_, tří_,
  { {0x2d980386,0x200b0387,0xa294000d,0x00000000}},	//   kere_, voci_, чапі,
  { {0x2d980388,0x601d0164,0x27330013,0x00000000}},	//   jere_, déma, _ảng_,
  { {0x63a20389,0x2d98038a,0x200b038b,0x00000000}},	//   _taon, dere_, toci_,
  { {0x8c430058,0x7a290078,0x683a005f,0x00000000}},	//   üşme, _užtv, _cįdi,
  { {0x2d98038c,0x200b038d,0x57fb009a,0x00000000}},	//   fere_, roci_, שלכו,
  { {0x2d98038e,0xddcf000c,0x68e1004b,0x00000000}},	//   gere_, ducţ, _üldg,
  { {0xa1770063,0x69c7038f,0xa802005b,0x00000000}},	//   _ועוד_, _roje, şıya,
  { {0x69c700b2,0x320c0390,0x7dcb004b,0x00000000}},	//   _soje, lody_, _püss,
  { {0x2465001c,0x539b0063,0x61fa00ac,0x00000000}},	// [350] zēm_, סימו, ontl,
  { {0x2d980391,0x61fa004d,0x3f990392,0x00000000}},	//   cere_, nntl, lesu_,
  { {0xdb1d0080,0x69c7004a,0x61fa0206,0x00000000}},	//   _dosá, _voje, intl,
  { {0x69c70045,0x3f990393,0x4c9a0063,0x00000000}},	//   _woje, nesu_, _פברו,
  { {0x9bba0063,0x320c0022,0x501c009a,0x00000000}},	//   _הצרפ, kody_, בואו,
  { {0x53a30394,0x85e80086,0x2465001c,0x00000000}},	//   _खोजश, одів_, tēm_,
  { {0x6aa30023,0xf77301f3,0x94790085,0x00000000}},	//   ānfu, _يار_, ёску_,
  { {0x3f99007d,0x7dd0004b,0x2d980395,0x00000000}},	//   jesu_, _väsi, zere_,
  { {0x2d980031,0x27ed00c3,0x2465001c,0x00000000}},	//   yere_, _imen_, sēm_,
  { {0x320c0051,0x2d980396,0x2465008f,0x00000000}},	//   gody_, xere_, pēm_,
  { {0x224d0397,0x601602dd,0x2d980398,0x00000000}},	//   spek_, lámi, vere_,
  { {0x25a50399,0x224d00ea,0xd8d60063,0x00000000}},	//   _hall_, ppek_, פורט_,
  { {0x25a5039a,0x320c039b,0x6016039c,0x00000000}},	//   _kall_, body_, námi,
  { {0x7bcb0026,0x44d70013,0x2d98039d,0x00000000}},	//   ögun, õ_, uere_,
  { {0x2d98039e,0x81bc001c,0xdb1d039f,0x00000000}},	//   rere_, kmēj, _rosá,
  { {0x2d9803a0,0x9e6600e1,0x6376005b,0x00000000}},	//   sere_, _евид, münü,
  { {0x6d4101f7,0x6376005b,0xdb1d027d,0x00000000}},	// [360] ılar, lünü, _posá,
  { {0xddcf000c,0xdb0403a1,0x8d560121,0x00000000}},	//   rucţ, ndié, _этич,
  { {0x6d5e003d,0x6376005b,0x9c830066,0x00000000}},	//   _iepa, nünü, éčti,
  { {0xf1ba0013,0x6d5e03a2,0x7bdf0206,0x00000000}},	//   _nhơn_, _hepa, chqu,
  { {0x6d5e0397,0x44d7008b,0xbddb0003,0x00000000}},	//   _kepa, ẽ_, mpèr,
  { {0x6d5e00f3,0xdb1d00b9,0x25a503a3,0x00000000}},	//   _jepa, _bosæ, _call_,
  { {0x25a502f6,0x320c0114,0x39130085,0x00000000}},	//   _dall_, vody_, _змёр,
  { {0x6d5e0397,0x320c0051,0x53340121,0x00000000}},	//   _lepa, wody_, мейт,
  { {0x44d7008b,0x320c03a4,0xdb040003,0x00000000}},	//   ã_, tody_, udiè,
  { {0x67200117,0x20030117,0x6d5e03a5,0x00000000}},	//   _izmj, čkim_, _nepa,
  { {0x6376005b,0x3f99007d,0x9f9903a6,0x00000000}},	//   günü, tesu_, овну_,
  { {0x68e1004b,0x2d8103a7,0x67200053,0x00000000}},	//   _ülde, _sche_, _बराक_,
  { {0x6d5e03a8,0xb80d0161,0x7c3e0164,0x00000000}},	//   _bepa, िकतम_, _aupr,
  { {0x6d5e003e,0x224b0024,0x7ae40024,0x00000000}},	//   _cepa, ícke_, dzit,
  { {0x7c3e000c,0x3f990019,0x6d5e03a9,0x00000000}},	//   _cupr, pesu_, _depa,
  { {0xec340086,0x69dc03aa,0x601d0003,0x00000000}},	//   енсь, _alre, mémo,
  { {0x5a35010d,0x25ed0053,0x9f4b004c,0x00000000}},	// [370] днат, _अगली_, nicí_,
  { {0x443e03ab,0x11590047,0x6d5e03ac,0x00000000}},	//   _out_, ַדױע, _gepa,
  { {0xdb0d004b,0xdcfc005f,0x99d40044,0x00000000}},	//   ljaü, derė, رتكا,
  { {0x69dc00ea,0x81bc0023,0x37890054,0x00000000}},	//   _elre, umēj, ібло_,
  { {0x81bc001c,0x999f00ea,0x63760058,0x00000000}},	//   rmēj, őről_, zünü,
  { {0x443e0034,0xf6500032,0x601603ad,0x00000000}},	//   _but_, ائن_, rámi,
  { {0x64a2005a,0x443e03ae,0x25a503af,0x00000000}},	//   ваща, _cut_, _vall_,
  { {0x7dd003b0,0x25a50127,0x443e0005,0x00000000}},	//   _häst, _wall_, _dut_,
  { {0x443e0164,0x25a503b1,0x6d470051,0x00000000}},	//   _eut_, _tall_, kcja,
  { {0x443e03b2,0x6376005b,0xdb04004d,0x00000000}},	//   _fut_, tünü, heiß,
  { {0x656303b3,0x443e0359,0x7dd00137,0x00000000}},	//   manh, _gut_, _mäst,
  { {0x7bcb007a,0x637601f7,0x6d5e03a2,0x00000000}},	//   ögul, rünü, _sepa,
  { {0x2e2400bd,0x6d5e0360,0x7dcb00ea,0x00000000}},	//   höfe_, _pepa, _püsp,
  { {0x7dd001e3,0x63a903b4,0x3f5c0013,0x00000000}},	//   _näst, lden, ậu_,
  { {0x628903b5,0x31780022,0x63a903b6,0x00000000}},	//   lteo, órze_, oden,
  { {0x7bc40035,0x63a903b7,0x62890072,0x00000000}},	//   ujiu, nden, oteo,
  { {0x7dd000c7,0x6d5e014f,0x628903b8,0x00000000}},	// [380] _bäst, _tepa, nteo,
  { {0x673b03b9,0x63a900fe,0xbddb00f4,0x00000000}},	//   _aguj, hden, spèr,
  { {0xdb0f00cd,0xd7ef03ba,0xbddb0003,0x00000000}},	//   _encà, ву_, ppèr,
  { {0xf98900b5,0x63a903bb,0xdb1d0137,0x00000000}},	//   יר_, jden, _bosä,
  { {0x443e0185,0x7dd000c7,0x96b7005e,0x00000000}},	//   _sut_, _fäst, дују_,
  { {0x63a903bc,0x443e03bd,0x7dd003be,0x00000000}},	//   eden, _put_, _gäst,
  { {0xa4d80086,0x78450006,0x6feb0051,0x00000000}},	//   ядку_, _tėva, ręcz,
  { {0x7a290006,0x63a903bf,0x60080058,0x00000000}},	//   _užtr, gden, nımd,
  { {0xa80201f7,0x6563017d,0x443e004d,0x00000000}},	//   ğıda, banh, _wut_,
  { {0x63a903c0,0x9f4b0139,0x7abb0063,0x00000000}},	//   aden, ricí_, קציו,
  { {0x7dd000bd,0x443e03c1,0x60080058,0x00000000}},	//   _läss, _uut_, kımd,
  { {0x601d0164,0x291803c2,0xd25a0094,0x00000000}},	//   rémo, _myra_, _дцк_,
  { {0x62890331,0x03d703c3,0x7dd003c4,0x00000000}},	//   cteo, _קודם_, _näss,
  { {0xdb04004d,0x76400075,0x9999011b,0x00000000}},	//   weiß, _mumy, _rusů_,
  { {0x2ba7000a,0xab950001,0x2bbb0021,0x00000000}},	//   мјав, нављ, يارة_,
  { {0x6e2001a8,0x8b5b0044,0xe451009a,0x00000000}},	//   ïmbr, تجسس_, רֶם_,
  { {0x160e0053,0x6b8d03c5,0xdb04004d,0x00000000}},	// [390] ाकार_, rfag, reiß,
  { {0x442603c6,0x6aad004b,0x63a903c7,0x00000000}},	//   _lho_, rvaf, zden,
  { {0x7dd003c8,0x60080058,0x63a903c9,0x00000000}},	//   _väst, bımd, yden,
  { {0x291803ca,0x4426008b,0xb794005e,0x00000000}},	//   _dyra_, _nho_, вршћ,
  { {0xda67006a,0x20030117,0x7dd0024a,0x00000000}},	//   _تاجي, čkih_, _täst,
  { {0x291800c7,0x7c2d03cb,0x7e60003b,0x00000000}},	//   _fyra_, lmar, âmpi,
  { {0xfc460024,0x683a0080,0x656303cc,0x00000000}},	//   žíva_, _vůdc, ranh,
  { {0x442600aa,0x628903cd,0x7c2d03ce,0x00000000}},	//   _cho_, tteo, nmar,
  { {0x66f30235,0x65630016,0x9f4b00cd,0x00000000}},	//   _अधिक_, panh, dicà_,
  { {0x7e7d0019,0x63a903cf,0x628903d0,0x00000000}},	//   dusp, sden, rteo,
  { {0x94a803d1,0x9f4b00cd,0x628903d2,0x00000000}},	//   _отца_, ficà_, steo,
  { {0x2a690019,0x644103d3,0x656103d4,0x00000000}},	//   ksab_, _iuli, _helh,
  { {0x644103d5,0x201e001c,0x81d503d6,0x00000000}},	//   _huli, ēti_, _подх,
  { {0x270e001b,0x644103d7,0x442d03d8,0x00000000}},	//   ộng_, _kuli, lme_,
  { {0x656103d9,0x442d03da,0x644103db,0x00000000}},	//   _melh, ome_, _juli,
  { {0xf062005a,0x644103dc,0x442d005b,0x00000000}},	//   _скъп, _muli, nme_,
  { {0x291e0117,0x160f0161,0x442d03dd,0x00000000}},	// [3a0] _šta_, िवार_, ime_,
  { {0xdb0602f4,0x442d03de,0x7c2d03df,0x00000000}},	//   _jaké, hme_, amar,
  { {0x644103e0,0x7c2d03e1,0x442d03e2,0x00000000}},	//   _nuli, bmar, kme_,
  { {0x7dd0024a,0x3f820397,0xe853007e,0x00000000}},	//   _täss, ngku_, انند,
  { {0xceb30063,0x442d03e3,0x4426008e,0x00000000}},	//   ָיו_, dme_, _rho_,
  { {0x99160088,0x442d03e4,0x659403e5,0x00000000}},	//   _зьбі, eme_, таку,
  { {0xdcfc003d,0xb7960001,0xd49703e6,0x00000000}},	//   derī, _праћ, еры_,
  { {0x9f4b00cd,0x442d03e7,0x68e1004b,0x00000000}},	//   xicà_, gme_, _ülda,
  { {0x656103e8,0x179b0047,0x2327005e,0x00000000}},	//   _felh, _צימב, ноћи_,
  { {0x442603e9,0x7e7d0019,0xef1f03ea,0x00000000}},	//   _who_, vusp, ngüe_,
  { {0x33d6019d,0x9f4b00cd,0xdfd103eb,0x00000000}},	//   _підт, ticà_, ليد_,
  { {0xa2e603ec,0x9f4b017d,0x442d0025,0x00000000}},	//   _поед, ficá_, cme_,
  { {0x9f4b0268,0x7c2d0137,0x644103ed,0x00000000}},	//   ricà_, vmar, _zuli,
  { {0x2d85005b,0x69ce03ee,0x3f710013,0x00000000}},	//   üle_, _nobe, ễu_,
  { {0x7e7d03ef,0x246c004c,0xac1903f0,0x00000000}},	//   susp, něm_, дову_,
  { {0x7e7d00a4,0x7c2d03f1,0xdb06013d,0x00000000}},	//   pusp, umar, _zaké,
  { {0x7c2d03f2,0x9f4b0019,0x99630066,0x00000000}},	// [3b0] rmar, öjõu_, ríži_,
  { {0x69ce03f3,0x7c2d03f4,0x601d004c,0x00000000}},	//   _cobe, smar, kémk,
  { {0xe3c301f7,0x69ce03f5,0x99840021,0x00000000}},	//   ngıç_, _dobe, المو,
  { {0x64410034,0x2d8303f6,0x65610080,0x00000000}},	//   _ruli, lgje_, _selh,
  { {0x644103f7,0xe72e0001,0xb6a50076,0x00000000}},	//   _suli, ре_, тилл,
  { {0x69ce03f8,0x644103f9,0x7b07003b,0x00000000}},	//   _gobe, _puli, ăptă,
  { {0x656103fa,0xdb06013d,0xd61800f2,0x00000000}},	//   _velh, _raké, رتها_,
  { {0x7bcf000c,0x656103fb,0x442d03fc,0x00000000}},	//   _jocu, _welh, ume_,
  { {0x69d8000f,0x1309019d,0x442d03fd,0x00000000}},	//   öveg, ьний_, rme_,
  { {0x7bcf03fe,0x442d03ff,0x64410400,0x00000000}},	//   _locu, sme_, _tuli,
  { {0xdb1d0027,0x644100a4,0xf8e10053,0x00000000}},	//   _cosú, _uuli, पनिय,
  { {0x13a7007e,0x6008005b,0x3165004d,0x00000000}},	//   _سنتی_, dımc, salz_,
  { {0xdb060024,0x3f8c0051,0x69c40053,0x00000000}},	//   _také, ędu_, रामी,
  { {0x82760047,0x63ab0026,0x7e6d0401,0x00000000}},	//   _יענע_, _hagn, _dvap,
  { {0xa0a50086,0xa3d50053,0x69ce0287,0x00000000}},	//   _райд, _सका_, _robe,
  { {0x7ff6007e,0x69ce0402,0xd00f00f2,0x00000000}},	//   _جستا, _sobe, _ولو_,
  { {0xd9460001,0x69ce0403,0x63ab01e7,0x00000000}},	// [3c0] вези, _pobe, _magn,
  { {0xdb0d0026,0x7e60003b,0x38560062,0x00000000}},	//   rjað, âmpu, въдс,
  { {0x7bcf00d8,0xfeba007e,0x81bc008f,0x00000000}},	//   _focu, _راکت_, mmēt,
  { {0x69ce0404,0x27e00405,0x63ab0406,0x00000000}},	//   _wobe, óin_, _nagn,
  { {0x68e1004b,0xe7f30042,0x20020407,0x00000000}},	//   _üldn, _आगरा_, inki_,
  { {0xa613000d,0x69d8013d,0x6b84004e,0x00000000}},	//   аміч, öved, lgig,
  { {0x63ab0408,0x44a30021,0x9f420066,0x00000000}},	//   _bagn, لموق, ahké_,
  { {0x63ab0409,0x6016013d,0x6b84040a,0x00000000}},	//   _cagn, zámr, ngig,
  { {0x41e6000d,0x81bc008f,0x99830078,0x00000000}},	//   віна, kmēt, _gijų_,
  { {0xdb1d0024,0x6008005b,0xf1ba0013,0x00000000}},	//   _posú, yımc, _khơi_,
  { {0xb97b014e,0x601d040b,0x30a30062,0x00000000}},	//   וניי, lémi, аряв,
  { {0x63ab040c,0xfe7f01a8,0xe3c30058,0x00000000}},	//   _gagn, tuï_, rgıç_,
  { {0xd3360088,0xd2500021,0x7bcf017d,0x00000000}},	//   _рэжы, _انت_, _rocu,
  { {0x63ab040d,0x6b84004b,0x6280040e,0x00000000}},	//   _zagn, egig, mumo,
  { {0x7dcb00ea,0x9f42004c,0x601d040f,0x00000000}},	//   _küsz, liký_, hémi,
  { {0x63a00410,0x60080058,0x313700ff,0x00000000}},	//   nemn, rımc, _ברוך_,
  { {0x3b640062,0x7c34007b,0x63a00022,0x00000000}},	// [3d0] ръсв, ретх, iemn,
  { {0x6b8400a4,0x6016006d,0x3ea900a4,0x00000000}},	//   agig, lámp, _isat_,
  { {0xf1ba008b,0xf775013c,0x62800411,0x00000000}},	//   _chơi_, гулю, humo,
  { {0xf09300b5,0x2e240026,0x63a00412,0x00000000}},	//   ינע_, nöfn_, jemn,
  { {0x6280001c,0x6008005b,0xdb04017d,0x00000000}},	//   jumo, nıma, rdiã,
  { {0x27e600a4,0x68e1004b,0x16a60413,0x00000000}},	//   ahon_, _üldo, увши_,
  { {0x63ab0414,0x478b0001,0x7c3d0150,0x00000000}},	//   _pagn, _осам_, _kisr,
  { {0x2496007e,0x3d3c0063,0x3ea900fe,0x00000000}},	//   انيد_, וגוס, _osat_,
  { {0x62800006,0x63ab0415,0x25ac01a8,0x00000000}},	//   gumo, _vagn, _fadl_,
  { {0x228b00d1,0xb0ae0053,0x3f89002b,0x00000000}},	//   røk_, टिंग, _acau_,
  { {0x228b0031,0xf484000d,0x7052007e,0x00000000}},	//   søk_, _вучн, ینیا,
  { {0xdb0d0019,0x5f76007e,0x653a0041,0x00000000}},	//   ljaõ, دادر, _װענד,
  { {0x3ea9003b,0x7f190054,0xfeba005d,0x00000000}},	//   _csat_, віру_, راحت_,
  { {0xdb1d006c,0x81bc0023,0xc332009a,0x00000000}},	//   _insè, umēt, _הוד_,
  { {0x3ea9003d,0x7c3d0150,0x81bc001c,0x00000000}},	//   _esat_, _bisr, rmēt,
  { {0xfaa60416,0x81bc0417,0xdb04017c,0x00000000}},	//   лабо, smēt, ediá,
  { {0xac070076,0x7c3d0034,0xda650021,0x00000000}},	// [3e0] унта_, _disr, لالي,
  { {0x7a220024,0x443d002b,0xf1ba0013,0x00000000}},	//   rôto, _liw_, _phơi_,
  { {0x81bc0418,0x6d5c0419,0x68e1004b,0x00000000}},	//   slēg, mbra, _üldl,
  { {0x4b55005a,0xd70a0121,0x601d0003,0x00000000}},	//   _върт, ннее_, témi,
  { {0xddc400c3,0xcc3b0047,0x6d5c041a,0x00000000}},	//   _zviš, _רעכט, obra,
  { {0xe9df0027,0x8675000d,0x7d1e01cf,0x00000000}},	//   _dtús_, рыцц, _kyps,
  { {0xe0c7041b,0x601d0003,0x63a0041c,0x00000000}},	//   _از_, sémi, temn,
  { {0xb9080235,0xc274041d,0x443d002b,0x00000000}},	//   यन_, алиј, _ciw_,
  { {0x26c200c2,0x6d5c041e,0x63a0041f,0x00000000}},	//   _škof_, kbra, remn,
  { {0x81bc001c,0xe617000d,0x63a00420,0x00000000}},	//   emēr, _бду_, semn,
  { {0x4386007e,0xe97b0047,0xb97b0047,0x00000000}},	//   _ملاق, ענטש, ענטי,
  { {0x7528003d,0x273a005b,0x7525004d,0x00000000}},	//   _izdz, _günü_, ühze,
  { {0x7a2b02d2,0x6d5c0244,0x74130043,0x00000000}},	//   lüte, fbra, _اونا,
  { {0x2fc00421,0x656a0229,0xf1a30062,0x00000000}},	//   _enig_, nafh, _грън,
  { {0xdb1d0164,0x721b0063,0x61fa0422,0x00000000}},	//   _insé, _רווח, mitl,
  { {0x3b55000a,0x81bc001c,0x61fa0423,0x00000000}},	//   ркар, slēd, litl,
  { {0x6d5c0424,0x3ea900cd,0xef1f004d,0x00000000}},	// [3f0] bbra, _usat_, afür_,
  { {0x6d5c0016,0x61fa0425,0xdcfc001c,0x00000000}},	//   cbra, nitl, sgrā,
  { {0xdb04006d,0xa8020058,0xa3d50042,0x00000000}},	//   rdiá, ğına, _सकल_,
  { {0x7e7d0229,0xa802005b,0x68e1004b,0x00000000}},	//   orsp, şına, _üldm,
  { {0xa6350054,0xa7640085,0x61fa0426,0x00000000}},	//   анді, скід, kitl,
  { {0xaaa8005a,0xab5b004d,0x81bc001c,0x00000000}},	//   _съюз_, _unüb, zmēr,
  { {0x7aed0427,0x7e7d004d,0x7a2b004d,0x00000000}},	//   lzat, hrsp, güte,
  { {0x7bcd0397,0x6d5c040d,0x6d41005b,0x00000000}},	//   njau, zbra, ılay,
  { {0x7aed0428,0x11e50429,0xd1b901fb,0x00000000}},	//   nzat, ижим, نادا_,
  { {0x8467011c,0x4375006a,0x20090089,0x00000000}},	//   _бъде, _چهار, _ajai_,
  { {0x23c50053,0xe5c4042a,0x7e7d042b,0x00000000}},	//   वादद, _усто, ersp,
  { {0x2295042c,0x61fa0139,0x7aed013d,0x00000000}},	//   _видя, aitl, kzat,
  { {0x81bc001c,0x78450078,0x1e830330,0x00000000}},	//   rmēr, _dėvi, олям,
  { {0x61fa033c,0xdb04017d,0x7aed0066,0x00000000}},	//   citl, ldiç, dzat,
  { {0x6d5c042d,0x8f7601dd,0xabf60330,0x00000000}},	//   rbra, _купі, ачащ,
  { {0xdb0403d9,0x2fc00185,0x35c70161,0x00000000}},	//   ndiç, _unig_, लाड़,

  { {0x4b55005a,0x896602a9,0x68e1042e,0x00000000}},	// [400] съст, икаж, _üldj,
  { {0x48b6005a,0x7edb0047,0x7d1e01bb,0x00000000}},	//   ищет, _סקיצ, _typs,
  { {0x32050034,0x9874004c,0x672900a8,0x00000000}},	//   inly_, _týče_, _azej,
  { {0x2cac0014,0x7bdf042f,0xa6e7008d,0x00000000}},	//   æddu_, ckqu, _trứ,
  { {0x46f60002,0xe5c60430,0xbad50085,0x00000000}},	//   јчет, иско, _ліры,
  { {0x5d7a00b5,0xd49a0431,0x6729008f,0x00000000}},	//   דאַק, ври_, _dzej,
  { {0x53e60432,0x26c2004c,0x94aa0121,0x00000000}},	//   ициа, _škod_, ттла_,
  { {0x656a01b0,0x7a2b0433,0x7afb0130,0x00000000}},	//   safh, rüte, _žuti,
  { {0x61fa0434,0x31670435,0x7a2b013d,0x00000000}},	//   titl, _benz_, süte,
  { {0x645800b8,0x6b96002b,0x9f59006c,0x00000000}},	//   ppvi, hfyg, misé_,
  { {0x7aed02f6,0x9f5903b2,0x30150054,0x00000000}},	//   zzat, lisé_, йдор,
  { {0x61fa0436,0xf8b30063,0x44200437,0x00000000}},	//   sitl, קשר_, _ói_,
  { {0x7e7d0438,0x9f590003,0x64480439,0x00000000}},	//   ursp, nisé_, _hudi,
  { {0x752d0080,0x6008005b,0xdef8000d,0x00000000}},	//   řaze, lıml, рыю_,
  { {0x7b670076,0x7bcd001c,0x31570063,0x00000000}},	//   итае, tjau, _דיון_,
  { {0x7aed0268,0x600801f7,0x8bc4043a,0x00000000}},	//   tzat, nıml, осуд,
  { {0x6e95043b,0x7bcd024a,0x5e950032,0x00000000}},	// [410] _الخا, rjau, _الخط,
  { {0x68e10019,0xa802005b,0x2019043c,0x00000000}},	//   _üldk, şıla, losi_,
  { {0x7aed00ea,0x5887000d,0x60080058,0x00000000}},	//   szat, рыза, kıml,
  { {0x2019043d,0x2769007e,0xd874043e,0x00000000}},	//   nosi_, اشای_, زامب,
  { {0xef1f005b,0x60080058,0x79a70002,0x00000000}},	//   zgün_, dıml, _крве,
  { {0xe6180086,0x2019043f,0xbb3a0063,0x00000000}},	//   аді_, hosi_, _תעשי,
  { {0x20190440,0x656803a7,0x33f50054,0x00000000}},	//   kosi_, _dedh, йчис,
  { {0xd77403eb,0x31670290,0x6448006c,0x00000000}},	//   _واقع, _senz_, _dudi,
  { {0x6d450025,0x65680441,0xdb04017d,0x00000000}},	//   _ogha, _fedh, rdiç,
  { {0x6d450185,0x27fd001f,0xdb04017d,0x00000000}},	//   _ngha, liwn_, sdiç,
  { {0x2733001b,0xa87900b5,0x20190290,0x00000000}},	//   _ảnh_, װאָר, fosi_,
  { {0x6d450027,0xdb060442,0xfaff00ac,0x00000000}},	//   _agha, _inkö, _reën_,
  { {0xc2cb0021,0x1dc30042,0x64480023,0x00000000}},	//   _جبال_, शांत, _zudi,
  { {0x9f5900fe,0x64480150,0x27fd002b,0x00000000}},	//   ensä_, _yudi, hiwn_,
  { {0x76410443,0x68e10019,0xe0550021,0x00000000}},	//   _mily, _üldh, _اختب,
  { {0x66180240,0x2d8c0051,0x201901f4,0x00000000}},	//   zovk, żde_, cosi_,
  { {0x4a430444,0xdd110445,0x27fd00a3,0x00000000}},	// [420] знув, _výši, diwn_,
  { {0x9f590164,0x7bcb0026,0xe9d70446,0x00000000}},	//   visé_, ögur, бку_,
  { {0xb8650021,0x6008005b,0xa802005b,0x00000000}},	//   قانو, yıml, şıma,
  { {0x64480009,0x9f590003,0x263d0066,0x00000000}},	//   _rudi, tisé_, _dňom_,
  { {0x764100a4,0xd5b10013,0x64480447,0x00000000}},	//   _bily, _bá_, _sudi,
  { {0x644802dd,0x9f590164,0xd5b1008b,0x00000000}},	//   _pudi, risé_, _cá_,
  { {0xd4670138,0x65680146,0x76410185,0x00000000}},	//   бије_, _vedh, _dily,
  { {0x94730032,0x32540448,0xdb060240,0x00000000}},	//   أدوا, овир, _zaká,
  { {0x6008005b,0xdb0600a5,0xdce7017c,0x00000000}},	//   rıml, _enkö, vajč,
  { {0x9098000a,0x7641001f,0x31c60076,0x00000000}},	//   авот_, _gily, ссив,
  { {0x64480449,0x2019044a,0x3ea00150,0x00000000}},	//   _uudi, tosi_, _apit_,
  { {0x7c24007d,0x20190072,0x5f390054,0x00000000}},	//   jlir, uosi_, ипня_,
  { {0x2019044b,0x2d98044c,0x2257007e,0x00000000}},	//   rosi_, ffre_, _هلند_,
  { {0xddcd0045,0xa1580086,0x93250021,0x00000000}},	//   _stał, _таку_, _برمن,
  { {0x9cc8000d,0x2019044d,0xe4780063,0x00000000}},	//   быта_, posi_, יָּש,
  { {0x68e10004,0xdb0f006d,0xa4fb0041,0x00000000}},	//   _üldi, _hacé, אללט,
  { {0x7769044e,0xdd910021,0x69d50114,0x00000000}},	// [430] _reex, _قوة_, _poze,
  { {0xceb40047,0x9e150054,0x6280044f,0x00000000}},	//   _זיץ_, _єдні, irmo,
  { {0x7afb0024,0xdb0f0003,0x7c240450,0x00000000}},	//   _ľutu, _macé, blir,
  { {0xdb0f0003,0xdcfc0078,0xe76b005d,0x00000000}},	//   _lacé, ugrą, احان_,
  { {0xdb23006a,0xdb060451,0x69d500a8,0x00000000}},	//   _روسی, _taká, _toze,
  { {0x27fd0185,0x4efc0063,0x442400a5,0x00000000}},	//   siwn_, נהגו, elm_,
  { {0xdb1d0139,0x62800452,0xdb070014,0x00000000}},	//   _tosó, ermo, álæg,
  { {0xd7940062,0xdc6c009d,0x843600de,0x00000000}},	//   _нисъ, נ֣וֹ, يكور_,
  { {0x72c50054,0x00000000,0x00000000,0x00000000}},	//   ібоз,   ,   ,
  { {0xfaff00e8,0xbb3c00b5,0xef1f005b,0x00000000}},	//   _reël_, נעזי, rgül_,
  { {0xa0690138,0xe5c4026c,0x2379007e,0x00000000}},	//   јама_, _эсто, _نماد_,
  { {0x64420453,0xd9a60053,0xcdc90063,0x00000000}},	//   _gioi, _ऑस्ट, _בך_,
  { {0x8db60086,0x11d50454,0x51f5009e,0x00000000}},	//   осві, _мікр, _وستر,
  { {0x73040085,0x11440044,0xc0e50131,0x00000000}},	//   _эпіз, _فَهُ, _молк,
  { {0x7a300137,0x10d50085,0xfce601d5,0x00000000}},	//   näte, _філё, цово,
  { {0xdb0d0025,0x7c240455,0xec16007e,0x00000000}},	//   adaí, ulir, آورد,
  { {0x533600b5,0x3ea0017f,0xdde9005d,0x00000000}},	// [440] ַנען_, _upit_, _گريه_,
  { {0x998a0078,0xc9860021,0x3ead0058,0x00000000}},	//   _ribų_, تشري, çete_,
  { {0xa17a0047,0xb17a0047,0xe8fa0141,0x00000000}},	//   שטעט, שטער, јле_,
  { {0x7a3000fe,0xb09a0047,0x87260456,0x00000000}},	//   däte, ייער, омеж,
  { {0xdce7001c,0xc7a30002,0xdb040139,0x00000000}},	//   majā, ќичк, hdiú,
  { {0x78af024a,0xdce7001c,0xfa670457,0x00000000}},	//   äivä, lajā, _фарк_,
  { {0x37e60086,0x14ca0121,0x00000000,0x00000000}},	//   _довг, рыли_,   ,
  { {0x68e301f2,0xdce7001c,0x7dd00072,0x00000000}},	//   ønde, najā, _väsy,
  { {0xc1a600e1,0x64420072,0x320a01ce,0x00000000}},	//   ојни, _vioi, ихон_,
  { {0x68e90080,0x81bc008f,0x60160014,0x00000000}},	//   _ředi, alēn, mámy,
  { {0xc9530063,0xa0540086,0xdce7001c,0x00000000}},	//   ומת_, явні, kajā,
  { {0x6831018c,0x645a0458,0x429a0044,0x00000000}},	//   rådg, _itti, _ننصح_,
  { {0xf7730063,0x2ef4000d,0x68e1004b,0x00000000}},	//   וקר_, дзяр, _üldv,
  { {0x69d800ea,0x683100b9,0x7bc602d2,0x00000000}},	//   övel, måde, _anku,
  { {0xdb0d0027,0x9f590025,0x9b6b000a,0x00000000}},	//   rdaí, lisí_, ишаа_,
  { {0x3eb000fe,0xaa550062,0xda670021,0x00000000}},	//   ältä_, зваш, قائي,
  { {0x2aab0459,0x161a0053,0x20120066,0x00000000}},	// [450] штво_, धवार_, ézie_,
  { {0x645a02f6,0x7c3a0006,0x7bc6045a,0x00000000}},	//   _otti, įtra, _enku,
  { {0x6d550051,0x9f590025,0xd604045b,0x00000000}},	//   mcza, hisí_, _лiкв,
  { {0x99980006,0x27e900ea,0x68310137,0x00000000}},	//   _virš_, óan_, kåde,
  { {0x645a045c,0x6b8d00a4,0x68e300b9,0x00000000}},	//   _atti, mgag, øndb,
  { {0x7a3000bd,0x6b8d004b,0xbb3a0063,0x00000000}},	//   täte, lgag, _לערי,
  { {0x69c7045d,0x05760021,0x3552005d,0x00000000}},	//   _inje, سمية_, رنيز,
  { {0x7a30045e,0x6d550022,0x6b8d045f,0x00000000}},	//   räte, hcza, ngag,
  { {0x645a01f7,0xdb0f0460,0xf6470054,0x00000000}},	//   _etti, _incó, _єхан,
  { {0x200b0051,0x7a300461,0x22970066,0x00000000}},	//   enci_, päte, eľká_,
  { {0x6d550045,0x68310137,0xc6170053,0x00000000}},	//   dcza, pådd, दकीय_,
  { {0x2477003b,0xd00a0002,0xdd92007e,0x00000000}},	//   măm_, семе_, کوس_,
  { {0x63a90462,0x2477000c,0xdce7008f,0x00000000}},	//   meen, lăm_, vajā,
  { {0x63a90463,0x645a01f2,0x225f017e,0x00000000}},	//   leen, _ytti, mpuk_,
  { {0xdce7003d,0x2477000c,0xdb0f0058,0x00000000}},	//   tajā, năm_, _encü,
  { {0x60dc0464,0x78ba00ea,0x6b8d0465,0x00000000}},	//   ärme, _átvi, ggag,
  { {0x20020311,0x2477008b,0xdce7008f,0x00000000}},	// [460] miki_, hăm_, rajā,
  { {0x6b8d00a4,0x63a90466,0x4efb0063,0x00000000}},	//   agag, heen, _להפו,
  { {0x02a80235,0x4ddb014e,0x63a90467,0x00000000}},	//   _कन्न, _החיו, keen,
  { {0x63a9006f,0x20020468,0x2477003b,0x00000000}},	//   jeen, niki_, dăm_,
  { {0xdb0600c7,0xa3cf0053,0x869a0363,0x00000000}},	//   _bakå, शान_, стет_,
  { {0xf1d0008b,0xe5b3000d,0x69c7007d,0x00000000}},	//   _mạch_, ейшы, _gnje,
  { {0x24770469,0xd4670001,0x2451008b,0x00000000}},	//   găm_, пије_, _cám_,
  { {0x20020035,0x6d550051,0xdb0f00cd,0x00000000}},	//   jiki_, zcza, _incò,
  { {0x6d550051,0x3667046a,0xdce5001c,0x00000000}},	//   ycza, _нато_, _mehā,
  { {0x6831046b,0x2b460066,0x51f80054,0x00000000}},	//   råde, ľoch_, інню_,
  { {0x2002046c,0x2477000c,0x68e10019,0x00000000}},	//   fiki_, căm_, _üldt,
  { {0x6d550051,0xf1d0008b,0xa263008b,0x00000000}},	//   wcza, _bạch_, _khố,
  { {0x27e6046d,0xf19401d5,0x41e6046e,0x00000000}},	//   ikon_, _жиль, _ніка,
  { {0x7a2b005b,0x127b0047,0x7524004c,0x00000000}},	//   gütl, _פאוע, řizu,
  { {0x6d550051,0x24510013,0x819b009a,0x00000000}},	//   rcza, _xám_, _הסוצ,
  { {0x69c7007d,0x1bd4046f,0x321e0470,0x00000000}},	//   _snje, нося, loty_,
  { {0x2477000c,0xf1d0008b,0x59d9000d,0x00000000}},	// [470] zăm_, _gạch_, одаў_,
  { {0xdce7003b,0x96b30053,0x321e0471,0x00000000}},	//   gajă, _इनबॉ, noty_,
  { {0x67d50472,0x4ddc0063,0x2477003b,0x00000000}},	//   можу, _לחזו, xăm_,
  { {0xdb0f02dd,0x2477000c,0xeabf0013,0x00000000}},	//   _hací, văm_, _trù_,
  { {0xa263008b,0x9f4b006d,0x2451004a,0x00000000}},	//   _chố, licó_, _sám_,
  { {0x2477000c,0x20020473,0x63a90474,0x00000000}},	//   tăm_, ziki_, ween,
  { {0x58840475,0x9f4b006d,0x63a90476,0x00000000}},	//   _пыта, nicó_, teen,
  { {0x24770477,0xf8b20063,0x7a300478,0x00000000}},	//   răm_, _בשל_, mäta,
  { {0x2477000c,0x27ff0089,0x63a90479,0x00000000}},	//   săm_, _imun_, reen,
  { {0x13060055,0x81bc003d,0x68e10004,0x00000000}},	//   ьный_, blēm, _ülds,
  { {0x1faa000a,0xf1d0008b,0x2002047a,0x00000000}},	//   окни_, _sạch_, tiki_,
  { {0x9f4b02dd,0x320c047b,0x6603047c,0x00000000}},	//   dicó_, andy_, link,
  { {0x2002047d,0x69d800ea,0x62890283,0x00000000}},	//   riki_, övek, queo,
  { {0xc332014e,0x9f4b02dd,0xdca6047e,0x00000000}},	//   _סוג_, ficó_, маги,
  { {0x81bc003d,0x27ed047f,0x2d840058,0x00000000}},	//   klēj, _olen_, ğme_,
  { {0x2d84005b,0x7a2b004b,0x224700ca,0x00000000}},	//   şme_, sütl, _hink_,
  { {0x66030480,0xe9da0481,0x1ee8005d,0x00000000}},	// [480] kink, ока_, _رودی_,
  { {0xbf9b017d,0x66030482,0x6286007d,0x00000000}},	//   niên, jink, škog,
  { {0xdce7003b,0x66030483,0x27e60072,0x00000000}},	//   rajă, dink, tkon_,
  { {0xdb0f0080,0x9f4b0290,0xa263008b,0x00000000}},	//   _zací, licò_, _phố,
  { {0x27e600fe,0xdb1d00b9,0xfbdf008b,0x00000000}},	//   rkon_, _ansæ, _kiên_,
  { {0x66030484,0x27e60485,0x27ed0486,0x00000000}},	//   gink, skon_, _elen_,
  { {0x64a30001,0xbf9b0016,0x81bc001c,0x00000000}},	//   ваја, diên, blēj,
  { {0xfbdf00aa,0xa263001b,0x69dc0487,0x00000000}},	//   _liên_, _thố, _hore,
  { {0x23270001,0x7ae40488,0x66030489,0x00000000}},	//   моћи_, nyit, bink,
  { {0xfbdf008b,0x66030051,0xdce70051,0x00000000}},	//   _niên_, cink, lają,
  { {0x2247048a,0x69dc048b,0x9f4b0290,0x00000000}},	//   _dink_, _more, dicò_,
  { {0x69dc02e3,0xdce70051,0xe3630336,0x00000000}},	//   _lore, nają, _акци,
  { {0x69dc00e8,0xfbdf001b,0x9f4b0290,0x00000000}},	//   _oore, _biên_, ficò_,
  { {0xbf9b048c,0x69dc048d,0x9f4b006d,0x00000000}},	//   ciên, _nore, ticó_,
  { {0xdb0f048e,0xdce70051,0x26c2004c,0x00000000}},	//   _vací, kają, _škol_,
  { {0xdb0d0016,0x6603048f,0xdb21027d,0x00000000}},	//   ndaç, zink, štív,
  { {0xdce70045,0x63a20490,0x69dc0491,0x00000000}},	// [490] dają, _mbon, _bore,
  { {0x69dc0492,0x7e6d0035,0x58870085,0x00000000}},	//   _core, _iwap, дыда,
  { {0x69dc0493,0x27ed0494,0x66030495,0x00000000}},	//   _dore, _plen_, vink,
  { {0xdd0d0051,0xdce70051,0x66030496,0x00000000}},	//   półp, gają, wink,
  { {0x660300eb,0x7af60045,0xcff8014e,0x00000000}},	//   tink, czyt, וצאה_,
  { {0x04b5005a,0x69dc0497,0x66030072,0x00000000}},	//   есия, _gore, uink,
  { {0xdcfe01f7,0x66030498,0x24e90054,0x00000000}},	//   _yapı, rink, ямки_,
  { {0x4788000a,0xdb060024,0xdce70051,0x00000000}},	//   _осум_, _rakú, cają,
  { {0x52a6026c,0xc2450499,0x2247049a,0x00000000}},	//   евым_, нник, _pink_,
  { {0x7bdd0045,0xdb1d00c7,0x63a2049b,0x00000000}},	//   _losu, _insä, _ebon,
  { {0xbf9b0016,0x22470122,0x0596007e,0x00000000}},	//   riên, _vink_, _سالگ,
  { {0x6e2500e3,0x34bd0053,0x35c70053,0x00000000}},	//   _akhb, ्मीद, लाक़,
  { {0x62640086,0x63b9001f,0x63bb049c,0x00000000}},	//   _авіа, _iawn, mdun,
  { {0x63bb0199,0xdce70051,0xf1d0008b,0x00000000}},	//   ldun, zają, _hạnh_,
  { {0x32050037,0xfbdf001b,0x63bb005b,0x00000000}},	//   mily_, _viên_, odun,
  { {0xc4d200b5,0x63bb049d,0x69dc049e,0x00000000}},	//   נגן_, ndun, _sore,
  { {0xfbdf001b,0x63bb00bd,0x7bdd0080,0x00000000}},	// [4a0] _tiên_, idun, _dosu,
  { {0xdce70051,0x629b0006,0x645c0003,0x00000000}},	//   wają, ituo, _érig,
  { {0x69dc010a,0x629b0019,0xdb1d00bd,0x00000000}},	//   _vore, htuo, _ansä,
  { {0x629b0006,0xe73a049f,0x291704a0,0x00000000}},	//   ktuo, пее_, رقند_,
  { {0xdce70045,0x63bb04a1,0x69dc04a2,0x00000000}},	//   rają, ddun, _tore,
  { {0x3205004c,0x63bb004d,0x69dc0072,0x00000000}},	//   jily_, edun, _uore,
  { {0x68e10019,0x320504a3,0xf7720021,0x00000000}},	//   _üldp, dily_, _ماء_,
  { {0x764804a4,0xf1d0001b,0xd3700021,0x00000000}},	//   _widy, _cạnh_, جهة_,
  { {0xeb9f0031,0x75280051,0xdb0d04a5,0x00000000}},	//   _kjør_, _wydz, rdaç,
  { {0x75280051,0xfa970047,0x51f70121,0x00000000}},	//   _tydz, עדיש_, енью_,
  { {0x68150051,0xdb1d0137,0xdb0f0139,0x00000000}},	//   ląda, _inså, _macá,
  { {0x63a20035,0x20d50006,0x44200046,0x00000000}},	//   _ubon, džią_, _ði_,
  { {0xe04a006a,0x44260035,0x2d8504a6,0x00000000}},	//   _کشته_, _iko_, óleo_,
  { {0x92f2005b,0x320500e5,0x7c2604a7,0x00000000}},	//   ığım, cily_, _akkr,
  { {0x7bdd04a8,0x7c8404a9,0x63b90168,0x00000000}},	//   _posu, луте, _yawn,
  { {0x7e6d0035,0x7a2b004d,0x68380014,0x00000000}},	//   _twap, müti, nídd,
  { {0xe9870001,0xeb9f04aa,0xdb26005d,0x00000000}},	// [4b0] ећен, _sjøs_, پولی,
  { {0x99990006,0xafdb01e1,0xd6d1005d,0x00000000}},	//   _rusų_, smød, یقا_,
  { {0x44260117,0x78ba0024,0xef200051,0x00000000}},	//   _oko_, _štvr, ążek_,
  { {0xdb1d00c7,0x6b670003,0xfbdf0013,0x00000000}},	//   _anså, _dégâ, _kiêm_,
  { {0x7c2d04ab,0x212b00aa,0x68e50072,0x00000000}},	//   mlar, ́ch_, syhd,
  { {0xeb9f0031,0xdcee001c,0x85e80086,0x00000000}},	//   _gjør_, labā, ндів_,
  { {0x34bd0161,0x66e7001c,0x320504ac,0x00000000}},	//   ्मेद, _sīkā, vily_,
  { {0x7c2d04ab,0x629b04ad,0xd7c901f3,0x00000000}},	//   nlar, ttuo, _توره_,
  { {0x52a90086,0x62650062,0xfbdf0013,0x00000000}},	//   євом_, ъвпа, _niêm_,
  { {0x3d1a0053,0x2292007e,0x629b04ae,0x00000000}},	//   _मुझे_, گلیس, rtuo,
  { {0x32050037,0x7c2d04af,0x23e7019d,0x00000000}},	//   rily_, klar, _підв,
  { {0x3205033c,0x7c2d005b,0x629b04b0,0x00000000}},	//   sily_, jlar, ptuo,
  { {0x442d04b1,0x443f04b2,0x7c2d04b3,0x00000000}},	//   mle_, mmu_, dlar,
  { {0x644b00bb,0x7c2d04b4,0x62890025,0x00000000}},	//   _higi, elar, mreo,
  { {0x7b96019d,0x7c2d01f7,0x644b0035,0x00000000}},	//   краї, flar, _kigi,
  { {0x442d01f7,0x443f04b5,0x7c2d04b6,0x00000000}},	//   nle_, nmu_, glar,
  { {0x3b07005a,0xdb0f0025,0x442d04b7,0x00000000}},	// [4c0] вето_, _pacá, ile_,
  { {0x443f0360,0x644b04b8,0x69c00078,0x00000000}},	//   hmu_, _ligi, _ėmes,
  { {0x7db50088,0x443f0150,0x442d04b9,0x00000000}},	//   _ёсьц, kmu_, kle_,
  { {0x7aeb000f,0x7a300066,0x7c2d04ba,0x00000000}},	//   ölté, päto, clar,
  { {0x969604bb,0x7c2404bc,0x442d04bd,0x00000000}},	//   треш, moir, dle_,
  { {0x6d480006,0x7c240003,0x628904be,0x00000000}},	//   ždau, loir, dreo,
  { {0xeb9f0031,0x442d04bf,0x69ce04c0,0x00000000}},	//   _kjøp_, fle_, _inbe,
  { {0xe4e3019d,0x68e304c1,0x644b0139,0x00000000}},	//   рішн, ände, _cigi,
  { {0x644b04c2,0x26c4004b,0xf74304c3,0x00000000}},	//   _digi, _urmo_, _вето,
  { {0x644b007a,0x442d04c4,0x7c2d005b,0x00000000}},	//   _eigi, ale_, zlar,
  { {0x4426017f,0xf9930063,0x7c2d04c5,0x00000000}},	//   _tko_, ברת_, ylar,
  { {0xb4fb00b5,0x62890025,0x44260035,0x00000000}},	//   _קלאר, breo, _uko_,
  { {0x69ce04c6,0xfaff00e8,0x7c2d0058,0x00000000}},	//   _onbe, _leër_, vlar,
  { {0x827700b5,0x2458008b,0xfbdf0013,0x00000000}},	//   _יעדע_, _kém_, _viêm_,
  { {0x7c2d01f7,0x7c240025,0x2d580156,0x00000000}},	//   tlar, foir, тись_,
  { {0x69ce02ab,0x683104c7,0x24580080,0x00000000}},	//   _anbe, vådo, _mém_,
  { {0x7c2d01f7,0x6d5c010a,0x644000fe,0x00000000}},	// [4d0] rlar, bcra, immi,
  { {0x442d01f7,0x7c2d005b,0x442404c8,0x00000000}},	//   zle_, slar, hom_,
  { {0x7c2d01f7,0x394700c7,0xd1410051,0x00000000}},	//   plar, äns_, cząć_,
  { {0x3b64005a,0x442404c9,0xa9270078,0x00000000}},	//   _върв, jom_, _rožė,
  { {0x68e30137,0x644b04ca,0xc1780078,0x00000000}},	//   ändb, _rigi, nkės_,
  { {0x69d8000f,0xdb060080,0xf6240086,0x00000000}},	//   övet, _jaký, адіо,
  { {0x18b80076,0x644b04cb,0xe3b10021,0x00000000}},	//   _игры_, _pigi, مرة_,
  { {0x442404cc,0x628904cd,0x442d04ce,0x00000000}},	//   gom_, treo, ule_,
  { {0x32d4000d,0x644b04cf,0x11d90021,0x00000000}},	//   ацэс, _vigi, فوظة_,
  { {0x644000fe,0x628904d0,0x7e7d04d1,0x00000000}},	//   ammi, rreo, dssp,
  { {0x644b04d2,0x91050076,0xdb0f017d,0x00000000}},	//   _tigi, упне, _facç,
  { {0x442404c9,0x629c003b,0xd00f0044,0x00000000}},	//   com_, ăror, كلٍ_,
  { {0x7c240164,0x7e7d04d3,0x3f9e0022,0x00000000}},	//   voir, gssp, ętu_,
  { {0xdb04017d,0xa0c5007e,0x8e750054,0x00000000}},	//   leiç, _ميتو, шуюч,
  { {0x7c2403b2,0x6d5c0034,0x201904d4,0x00000000}},	//   toir, rcra, éric_,
  { {0xf0920063,0x6d5c04d5,0xabf504d6,0x00000000}},	//   _הנה_, scra, ачущ,
  { {0x7c2404d7,0xed5a01f6,0xbb750094,0x00000000}},	// [4e0] roir, _поп_, русъ,
  { {0x7bcf048e,0x7a2b0019,0x7e6400a4,0x00000000}},	//   _encu, kütu, _itip,
  { {0x2fd7007e,0xfce604d8,0x7c240003,0x00000000}},	//   _شوید_, _соно, poir,
  { {0x61e00235,0x27e0007a,0xdb040016,0x00000000}},	//   _पक्ष, ðin_, jeiç,
  { {0x4a750475,0x442404d9,0x69d800ea,0x00000000}},	//   _выст, vom_, öves,
  { {0x69ce04da,0x44240022,0xe8560044,0x00000000}},	//   _unbe, wom_, _منسد,
  { {0xdb04017d,0x54a60021,0x6ab6002b,0x00000000}},	//   feiç, احتف, lwyf,
  { {0xd90d006a,0x2676005d,0x7e640130,0x00000000}},	//   _تیم_, _مهرآ, _otip,
  { {0x81bc003d,0x6596007e,0x99630066,0x00000000}},	//   klēt, _مجار, líši_,
  { {0xdd1f0024,0x68380080,0x24580124,0x00000000}},	//   _líši, bídc, _tém_,
  { {0xf993014e,0x30a3005a,0xddcd000c,0x00000000}},	//   זרת_, бряв, _ataş,
  { {0xde590088,0x1e1d0053,0x7e7d04db,0x00000000}},	//   камі_, पक्ष_, tssp,
  { {0x7e7d004d,0x68150022,0x81d404dc,0x00000000}},	//   ussp, ządo, _волх,
  { {0xdb07000f,0x52830021,0xdb0600ea,0x00000000}},	//   ámít, _الوك, _lakó,
  { {0x7e7d004d,0x7c0901f3,0xa0c30044,0x00000000}},	//   sssp, نيسف_, _هيوو,
  { {0x7a2b00bd,0xf1d20053,0xdb060058,0x00000000}},	//   hütt, तावन, _fakü,
  { {0x200b04dd,0xdb060024,0x09750121,0x00000000}},	// [4f0] mici_, _taký, игаю,
  { {0xdd9104de,0xd91b0076,0x200b04df,0x00000000}},	//   _بود_, нье_, lici_,
  { {0x6d480006,0xd7e7013c,0x48ab000d,0x00000000}},	//   ždar, лідо, этам_,
  { {0xf3f1001b,0x200b04e0,0x69d804e1,0x00000000}},	//   _mục_, nici_, över,
  { {0xb5fd00eb,0x7c3a0164,0xf3f10013,0x00000000}},	//   _atša, ître, _lục_,
  { {0xdb1f0019,0x200b04e2,0xdb0e0014,0x00000000}},	//   övõi, hici_, _þjál,
  { {0xdb1d010a,0x200b005b,0x62860114,0x00000000}},	//   _ansø, kici_, ákon,
  { {0x200b0392,0x81bc008f,0x73e504e3,0x00000000}},	//   jici_, klēs, роиз,
  { {0x91d50086,0x200b04e4,0x7a2b0244,0x00000000}},	//   ацні, dici_, bütt,
  { {0x7a3000fe,0xdb060195,0x7d08004c,0x00000000}},	//   vätk, _zakó, údsk,
  { {0x200b04e5,0xf3f10013,0x7e6404e6,0x00000000}},	//   fici_, _cục_, _stip,
  { {0x200b04e7,0x76430150,0xf3f10013,0x00000000}},	//   gici_, lmny, _dục_,
  { {0x201904e8,0xddd60066,0x3f8c0058,0x00000000}},	//   éria_, _avyš, ğdu_,
  { {0x7e6404e9,0x752d004c,0xb7c400dd,0x00000000}},	//   _vtip, řazu, ăţir,
  { {0x200b04ea,0xf1d20082,0x00000000,0x00000000}},	//   bici_, तारन,   ,
  { {0x61e300ea,0x78450078,0x7a3004eb,0x00000000}},	//   _honl, _tėvy, mäti,
  { {0x39560079,0x7e64007d,0xb956005e,0x00000000}},	// [500] ањет, _utip, атећ,
  { {0x2fc004ec,0x8e7b0063,0xa96a04ed,0x00000000}},	//   _haig_, _שניה, тижа_,
  { {0xd8260062,0x2cba04ee,0x8ba604ef,0x00000000}},	//   аджи, _uspd_, _кинж,
  { {0x443d0185,0x68e301e3,0x46ea005a,0x00000000}},	//   _nhw_, ända, кден_,
  { {0x2fc00268,0xa6b6005a,0xddd60240,0x00000000}},	//   _maig_, рсещ, _zvyš,
  { {0x645e0016,0x2d9804f0,0xd6cf007e,0x00000000}},	//   ípio, ngre_, بقه_,
  { {0x7a3000fe,0x200b005b,0xa5f7005a,0x00000000}},	//   jäti, yici_, рещу_,
  { {0x25a00080,0xd7f20021,0xe8d70063,0x00000000}},	//   řil_, _بكر_, _דולר_,
  { {0xf8050121,0x78af007c,0x9f490058,0x00000000}},	//   _учён, čivš, _ilaç_,
  { {0xc05a0088,0x61e304f1,0x95c704f2,0x00000000}},	//   кім_, _conl, _клуб_,
  { {0x3a37014e,0x200b04f3,0x39570063,0x00000000}},	//   שרים_, tici_, ישים_,
  { {0x82a60145,0x00000000,0x00000000,0x00000000}},	//   _вадж,   ,   ,
  { {0xe1fa0001,0x61e3005b,0xbe8b0062,0x00000000}},	//   _игд_, _fonl, ъсне_,
  { {0xf3f1001b,0x200b04f4,0x62820104,0x00000000}},	//   _tục_, sici_, _ivoo,
  { {0x52b60161,0x2fc000cd,0x200b04f5,0x00000000}},	//   _अनुस, _faig_, pici_,
  { {0x2d980031,0x62820019,0xd0f70063,0x00000000}},	//   agre_, _kvoo, _כמות_,
  { {0xa3a80235,0xe8e0008b,0x61fa004b,0x00000000}},	// [510] ख्य_, ưới_, ohtl,
  { {0x683802f4,0xf99304f6,0x628004f7,0x00000000}},	//   vída, تبر_, ismo,
  { {0xb9c40021,0xf75500de,0xd77700de,0x00000000}},	//   تقلي, مناج, لاشع,
  { {0x62800203,0x3f9904f8,0xd7880021,0x00000000}},	//   ksmo, ngsu_, لنمو_,
  { {0x27e4003b,0x7d1b0058,0xc7b80121,0x00000000}},	//   _domn_, ğusu, рёх_,
  { {0x443d04f9,0x660804fa,0x628004fb,0x00000000}},	//   _shw_, _cmdk, dsmo,
  { {0xfc3f001b,0x20090290,0x628004fc,0x00000000}},	//   _khí_, _omai_, esmo,
  { {0xd794005a,0x61e3005b,0x248904fd,0x00000000}},	//   _мисъ, _sonl, čam_,
  { {0xfc3f0025,0x7aed04fe,0xdb1d0164,0x00000000}},	//   _mhí_, nyat, _basé,
  { {0x61fa04ff,0x7a300461,0x7aed0058,0x00000000}},	//   ghtl, täti, iyat,
  { {0xafdb0093,0xfbdf0013,0xb8750500,0x00000000}},	//   rmøn, _hiêu_, алiз,
  { {0x7aed003e,0xafdb01f2,0xfbdf0013,0x00000000}},	//   kyat, smøn, _kiêu_,
  { {0x7a30024a,0x2fc000cd,0x0cd00053,0x00000000}},	//   säti, _vaig_, हम्म,
  { {0xfc3f02dd,0x6da60001,0x61fa0501,0x00000000}},	//   _ahí_, љива, chtl,
  { {0x4095043b,0xfc3f0027,0x9c590001,0x00000000}},	//   _العر, _bhí_, ишту_,
  { {0xfc3f001b,0x3ce500c7,0x7a3000c7,0x00000000}},	//   _chí_, älva_, nätv,
  { {0x68e30502,0x89aa0002,0xbb430503,0x00000000}},	// [520] ändn, лкав_, зетк,
  { {0xc3320063,0x200e0051,0xdb040003,0x00000000}},	//   לון_, ślić_, nfié,
  { {0xe93a018e,0x9f4900cd,0x224b0066,0x00000000}},	//   учај_, _plaç_, ícky_,
  { {0x60dc0504,0x8b9602a1,0x7d1b0058,0x00000000}},	//   ärmi, _уроч, ğust,
  { {0x68380080,0x661a0150,0x673b0051,0x00000000}},	//   bídn, _pjtk, _czuj,
  { {0x99d603eb,0xd49a00fb,0xd6270505,0x00000000}},	//   _اتحا, гри_, боче_,
  { {0x75890086,0xdb0400be,0xdb1d006c,0x00000000}},	//   рсів_, rdiõ, _rasé,
  { {0x62860006,0x20dc0066,0x7bc40506,0x00000000}},	//   škom, nšiť_, ndiu,
  { {0x44f30013,0x6aa40507,0x7bc4004e,0x00000000}},	//   ạ_, ntif, idiu,
  { {0x2d8c01a8,0x61fa004b,0x645c006c,0x00000000}},	//   ódel_, uhtl, _ério,
  { {0x20190016,0x546a0002,0x320c0195,0x00000000}},	//   ério_, _саем_, ridy_,
  { {0x6282006f,0x6aa40508,0x7a300072,0x00000000}},	//   _tvoo, ktif, mätu,
  { {0x7336007e,0xde59000d,0x657a0509,0x00000000}},	//   _ارائ, рагі_, _keth,
  { {0x831b0047,0x645a050a,0x2327005e,0x00000000}},	//   _גודז, _kuti, _уочи_,
  { {0xf1a9006a,0xfc3f001b,0x657a050b,0x00000000}},	//   _خانه_, _phí_, _meth,
  { {0x317e050c,0x9994004c,0x657a050d,0x00000000}},	//   latz_, _češi_, _leth,
  { {0x1a5b0021,0x4a540062,0x7c3a0003,0x00000000}},	// [530] اشرة_, зкус, îtra,
  { {0x645a03b2,0x9f4b0080,0x657a050e,0x00000000}},	//   _outi, nkcí_, _neth,
  { {0xe8e000aa,0x7a30024a,0x31780045,0x00000000}},	//   ười_, jätu, órzy_,
  { {0x4735050f,0x317e0206,0xd7580021,0x00000000}},	//   онес, hatz_, مجها_,
  { {0x20190164,0x62860006,0x6aa40510,0x00000000}},	//   insi_, škoj, ctif,
  { {0x1958000d,0x25a9007d,0x645a0511,0x00000000}},	//   _гары_, đalo_, _buti,
  { {0x69d50512,0x657a001f,0x44f3008b,0x00000000}},	//   _inze, _deth, ụ_,
  { {0xfbdf001b,0x645a0513,0x69c50514,0x00000000}},	//   _tiêu_, _duti, ldhe,
  { {0x657a0515,0xdb1d0516,0x645a0517,0x00000000}},	//   _feth, _insó, _euti,
  { {0x69c50518,0xf0a90085,0x80a90519,0x00000000}},	//   ndhe, акол_, авов_,
  { {0xf9920132,0x7a3000fe,0x32f4001b,0x00000000}},	//   ורי_, mätt, ày_,
  { {0x26cd0150,0x7a30051a,0x81bc001c,0x00000000}},	//   _kreo_, lätt, slēp,
  { {0x3f890185,0xeef50088,0x69d5051b,0x00000000}},	//   _ddau_, пярэ, _onze,
  { {0x20190150,0x27fd002b,0x22590014,0x00000000}},	//   ansi_, hhwn_, ísku_,
  { {0x68e3051c,0xb147005d,0x69c5013d,0x00000000}},	//   ändl, _دیدم_, ddhe,
  { {0x69d5051d,0x6aa4051e,0x69c500ca,0x00000000}},	//   _anze, ttif, edhe,
  { {0x6aa40034,0x63a9051f,0x261a0053,0x00000000}},	// [540] utif, ifen, _बदली_,
  { {0x69c5016d,0x238c0006,0x20f50013,0x00000000}},	//   gdhe, mėjų_, ói_,
  { {0x20dc0024,0x7a3000fe,0x02b60053,0x00000000}},	//   pšiť_, dätt, _अन्न,
  { {0x6aa40003,0xc66a005e,0x645a0520,0x00000000}},	//   ptif, ашке_, _ruti,
  { {0x777b0164,0x26cd0521,0x645a0522,0x00000000}},	//   _deux, _creo_, _suti,
  { {0x62860006,0x7aeb004d,0x7641001f,0x00000000}},	//   škok, ägte, _chly,
  { {0x63a90523,0x7880004c,0xd6d90022,0x00000000}},	//   ffen, _dává, _mgły_,
  { {0x0443000a,0x63a9001f,0x657a0524,0x00000000}},	//   мејн, gfen, _weth,
  { {0x7a3003c8,0x442f00ea,0x32f4008b,0x00000000}},	//   bätt, _dkg_, ùy_,
  { {0x238c0078,0x51f80525,0x645a0526,0x00000000}},	//   dėjų_, сною_, _tuti,
  { {0x645a00fe,0x4254007e,0x69b70063,0x00000000}},	//   _uuti, _کنتر, חליף_,
  { {0x317e00bd,0x69c500ea,0x8007012c,0x00000000}},	//   satz_, zdhe, ічне,
  { {0x41e6000d,0x7a300137,0x238c0078,0x00000000}},	//   _міка, näts, gėjų_,
  { {0x81f80049,0x7c36013d,0x6d5a005f,0x00000000}},	//   _دفتر_, elyr, žtan,
  { {0x271c001b,0x1bd5005a,0x644204aa,0x00000000}},	//   ỉnh_, повя, _khoi,
  { {0xdfd10032,0x60240095,0x929d0022,0x00000000}},	//   _أية_, _одја, szłe,
  { {0x68380066,0x34b70042,0xc95b0085,0x00000000}},	// [550] rídl, _आन्द, аўе_,
  { {0x78a50026,0x69c500ca,0xadb9005d,0x00000000}},	//   tthv, udhe, _اهدا_,
  { {0x9f400026,0x7a300527,0x69c50528,0x00000000}},	//   _hlið_, vätt, rdhe,
  { {0x080b0044,0x00000000,0x00000000,0x00000000}},	//   جزئي_,   ,   ,
  { {0x7a3000bd,0x7bda0063,0xc6680002,0x00000000}},	//   tätt, _הקרו, ошје_,
  { {0x7c2d0529,0x26cd000c,0x29070139,0x00000000}},	//   loar, _vreo_, únas_,
  { {0x7a30052a,0xdb1d052b,0x63a90244,0x00000000}},	//   rätt, _masí, tfen,
  { {0xc2c50032,0x7a30052c,0x26cd052d,0x00000000}},	//   كيبي, sätt, _treo_,
  { {0xd5bb052e,0x69c10026,0x64420139,0x00000000}},	//   _все_, _óles, _dhoi,
  { {0x238c0006,0x13060121,0x63a904a7,0x00000000}},	//   vėjų_, яный_, sfen,
  { {0xf99200b5,0x64420027,0x3eb200ac,0x00000000}},	//   ערט_, _fhoi, _spyt_,
  { {0xa3bb006a,0xb4d70053,0x60160006,0x00000000}},	//   _خاطر_, ामी_, kšme,
  { {0x7c2d052f,0xdb1d0530,0x64490531,0x00000000}},	//   doar, _basí, mmei,
  { {0x7c2d000c,0x442d0532,0x238c0078,0x00000000}},	//   eoar, loe_, rėjų_,
  { {0xf1b2014e,0x7c3a0003,0x64490229,0x00000000}},	//   _נסה_, îtro, omei,
  { {0x7c2d000c,0x442d0533,0x1e86032d,0x00000000}},	//   goar, noe_, _елим,
  { {0x442d002b,0x2e360014,0x3f820534,0x00000000}},	// [560] ioe_, hæfi_, maku_,
  { {0x3f82014f,0x7d27013d,0x64490535,0x00000000}},	//   laku_, érsé, hmei,
  { {0x23bd0161,0x64490019,0x9f590331,0x00000000}},	//   ्याद, kmei, cisó_,
  { {0xdb1d0080,0x7a3000bd,0x3f82017f,0x00000000}},	//   _zasí, täts, naku_,
  { {0x64490019,0xf3f1008b,0x29070014,0x00000000}},	//   dmei, _cụm_, únar_,
  { {0x7bc60536,0x6e2e0290,0x3f8200fe,0x00000000}},	//   _haku, nobb, haku_,
  { {0x7bc60537,0x64420025,0xdb0d0014,0x00000000}},	//   _kaku, _phoi, ldað,
  { {0x7bc60538,0x29370047,0x3f820539,0x00000000}},	//   _jaku, _זאלן_, jaku_,
  { {0x7bc6053a,0x683101f2,0xdb0d0014,0x00000000}},	//   _maku, rådt, ndað,
  { {0x7bc6053b,0x7c2d053c,0x6e2e02af,0x00000000}},	//   _laku, zoar, jobb,
  { {0x64420027,0x65680150,0x6e2e053d,0x00000000}},	//   _thoi, _ifdh, dobb,
  { {0x04db014e,0x3f820509,0x7bc6053e,0x00000000}},	//   _לקבל, gaku_, _naku,
  { {0xdb0d017d,0x7c2d000c,0x63a2053f,0x00000000}},	//   meaç, voar, _icon,
  { {0x61140540,0x60dc0137,0x7bc600a4,0x00000000}},	//   _одлу, ärms, _aaku,
  { {0x7c2d0529,0xa0a30141,0x3f82017c,0x00000000}},	//   toar, _зајд, baku_,
  { {0x7bc60150,0x6c540541,0x80a30044,0x00000000}},	//   _caku, ексу, _أمين,
  { {0xba55005e,0x7c2d0542,0xdd0c0022,0x00000000}},	// [570] двај, roar, góła,
  { {0x5a340138,0x68380080,0x7c2d000c,0x00000000}},	//   енут, bídk, soar,
  { {0x7c2d0529,0x7bc60543,0x64490072,0x00000000}},	//   poar, _faku, ymei,
  { {0x2d9c01e3,0x27e9007a,0x33f1017d,0x00000000}},	//   _över_, ðan_, _táxi_,
  { {0x7e69000c,0x6fa50053,0xe69b0022,0x00000000}},	//   _împă, _कानू, _żołą,
  { {0x2d830544,0x63a20545,0xddc4003b,0x00000000}},	//   naje_, _acon, _itiţ,
  { {0x64490546,0x442d0547,0x7bc60548,0x00000000}},	//   tmei, toe_, _yaku,
  { {0x3cfc0047,0x644902d2,0x7e6d007d,0x00000000}},	//   מלונ, umei, _otap,
  { {0xdcfc00c2,0x64490549,0x442d054a,0x00000000}},	//   varč, rmei, roe_,
  { {0xa87900b5,0x78a10137,0x63a203e1,0x00000000}},	//   ֿאָר, _älvs, _econ,
  { {0x9327007e,0x7e6d054b,0x0519005d,0x00000000}},	//   _کران, _atap, _بياب_,
  { {0x63a20025,0xddc4003b,0x6838004c,0x00000000}},	//   _gcon, _otiţ, vídk,
  { {0x63bb054c,0xa2e40054,0x3f82054d,0x00000000}},	//   meun, _поїд, raku_,
  { {0x69c7054e,0x7bc6054f,0x63bb0550,0x00000000}},	//   _naje, _saku, leun,
  { {0x7bc60551,0x7e6d0552,0xa00a0021,0x00000000}},	//   _paku, _etap, _وقتل_,
  { {0x63bb0553,0x8c4304c3,0x69c70050,0x00000000}},	//   neun, весе, _aaje,
  { {0x69c700e3,0x62860554,0xf4120063,0x00000000}},	// [580] _baje, škov, דפן_,
  { {0x7bc60009,0xfe460086,0x68380555,0x00000000}},	//   _waku, _інно, mídi,
  { {0x7bc60556,0x1c4602d8,0x69c70557,0x00000000}},	//   _taku, _оном, _daje,
  { {0x63bb0558,0xd6d90022,0x3f80005f,0x00000000}},	//   jeun, _szła_, _jeiu_,
  { {0xa3e10235,0x63bb0559,0x6b84055a,0x00000000}},	//   दान_, deun, maig,
  { {0x6b840027,0x63a2055b,0x69c7055c,0x00000000}},	//   laig, _scon, _gaje,
  { {0xe9a3055d,0xf79a0044,0x9e49009a,0x00000000}},	//   _шарп, _ونسب_, הֲקִ,
  { {0x6b84018d,0x69c7055e,0x828a03d1,0x00000000}},	//   naig, _zaje, особ_,
  { {0x752d005b,0x27e6055f,0xdb1d0260,0x00000000}},	//   ğaza, mjon_, _kasá,
  { {0x6b840560,0x24f6047e,0x27e60561,0x00000000}},	//   haig, _очер, ljon_,
  { {0x20d3000d,0x2d830562,0x7e6d0479,0x00000000}},	//   віўс, vaje_, _stap,
  { {0x2d830035,0x68e30563,0x27e60564,0x00000000}},	//   waje_, ändi, njon_,
  { {0x6b840027,0xe46a0014,0x2d830565,0x00000000}},	//   daig, blöð_, taje_,
  { {0x2e360046,0x828b009a,0xdb1d0566,0x00000000}},	//   kæfu_, _וְהֶ, _nasá,
  { {0x6b840025,0xebc70001,0x2d830567,0x00000000}},	//   faig, мљан, raje_,
  { {0x2d830568,0xa0080021,0x25a9007d,0x00000000}},	//   saje_, _يقول_, đali_,
  { {0x7e6d0035,0x68380569,0x27e600ea,0x00000000}},	// [590] _utap, cídi, djon_,
  { {0x2fc9056a,0xdb1d056b,0x6815056c,0x00000000}},	//   _haag_, _casá, jądr,
  { {0x6b8400eb,0x61e700c7,0x321e0034,0x00000000}},	//   baig, öjli, inty_,
  { {0x69c70035,0xf7700021,0x6b84056d,0x00000000}},	//   _waje, لاه_, caig,
  { {0xdb1d056e,0x2fc9056f,0x69c70570,0x00000000}},	//   _ansö, _maag_, _taje,
  { {0x7a2b00bd,0x2fc90179,0xa594005a,0x00000000}},	//   hütz, _laag_, връщ,
  { {0x63bb03a8,0x2d810019,0xd4660330,0x00000000}},	//   teun, _mehe_, нище_,
  { {0xee3f0024,0x2d810019,0xdb1d0080,0x00000000}},	//   dtým_, _lehe_, _zasá,
  { {0xb06500fe,0xc6a40571,0x63bb0572,0x00000000}},	//   kyää, _архи, reun,
  { {0xdb040016,0xddc4017f,0x6b8400ea,0x00000000}},	//   nfiá, _otiš, zaig,
  { {0x83fc017f,0x27ed0573,0x86080044,0x00000000}},	//   _suđe, _koen_, _تقلق_,
  { {0x27ed0072,0xb5fd0574,0x321e0575,0x00000000}},	//   _joen_, _duše, anty_,
  { {0x79850089,0x92a7005e,0x6b840576,0x00000000}},	//   kahw, _цјел, vaig,
  { {0x27ff0185,0x62890025,0x68380577,0x00000000}},	//   _llun_, mseo, rídi,
  { {0x27ff01f7,0x62860578,0x6b840579,0x00000000}},	//   _olun_, škot, taig,
  { {0x27ed0031,0x6b840139,0x83fc0130,0x00000000}},	//   _noen_, uaig, _tuđe,
  { {0x6b84057a,0x64590035,0x6289057b,0x00000000}},	// [5a0] raig, _miwi, nseo,
  { {0x6b840027,0x2d81004d,0x6459057c,0x00000000}},	//   saig, _gehe_, _liwi,
  { {0x27ed002b,0xdb1d013d,0x6b84057d,0x00000000}},	//   _boen_, _vasá, paig,
  { {0xc6a60081,0xe108009a,0x08090044,0x00000000}},	//   ерки, וּנָ, وزني_,
  { {0x27ed0102,0x27e600ea,0xc0530047,0x00000000}},	//   _doen_, rjon_, אזא_,
  { {0x27e6057e,0x3e660013,0x7af60072,0x00000000}},	//   sjon_, _môt_, myyt,
  { {0x7af60072,0x62890360,0x64a3005e,0x00000000}},	//   lyyt, eseo, гаја,
  { {0x27ed0150,0x3447000d,0xa3d40062,0x00000000}},	//   _goen_, нчын_, тоич,
  { {0x6459001f,0x7af60072,0xe3af0044,0x00000000}},	//   _diwi, nyyt, صري_,
  { {0x2258007a,0x44ce0045,0x84e60076,0x00000000}},	//   örk_, _tę_, _позж,
  { {0x7a2b0199,0x5a170063,0x89970041,0x00000000}},	//   tütz, תקין_, עכטס_,
  { {0x6d5e002c,0x2d81004d,0xdcfc005f,0x00000000}},	//   _agpa, _sehe_, egrį,
  { {0x69dc057f,0x2fc900ca,0xb0650072,0x00000000}},	//   _onre, _vaag_, tyää,
  { {0xbf9b017d,0x2fc90104,0x30a60054,0x00000000}},	//   chên, _waag_, _зрив,
  { {0x11e90021,0x61f50580,0x2fc900be,0x00000000}},	//   _تعني_, özle, _taag_,
  { {0x69dc00bd,0xc1780078,0xdcfc0078,0x00000000}},	//   _anre, lbė_, agrį,
  { {0x5a350581,0x600c0063,0xd5b8008f,0x00000000}},	// [5b0] внат, _מִזְ, _ajām_,
  { {0x20fc0013,0x61fa0582,0xd6d90022,0x00000000}},	//   ỏi_, nktl, _szło_,
  { {0xdcfc001c,0x2e360583,0x61fa0137,0x00000000}},	//   parā, ræft_, iktl,
  { {0x69dc0584,0x6d450585,0xe7190021,0x00000000}},	//   _enre, _izha, ويات_,
  { {0x7bdd0586,0x02bc0042,0xb7f20042,0x00000000}},	//   _insu, ्टोन, _अकरम_,
  { {0x27e0003d,0x0c74007e,0xceb4009f,0x00000000}},	//   ķina_, _جدید, ריס_,
  { {0x27ed02b0,0xdb040026,0xf4b3007e,0x00000000}},	//   _toen_, leið, اشتگ,
  { {0x7bcd007a,0x6aad0035,0x62890019,0x00000000}},	//   ndau, otaf, tseo,
  { {0x2480017f,0x7c3a0164,0x6aad0587,0x00000000}},	//   ćima_, îtri, ntaf,
  { {0x929d0051,0x6aad0035,0x62890588,0x00000000}},	//   szło, itaf, rseo,
  { {0x62890589,0xa3e10053,0x7bdd058a,0x00000000}},	//   sseo, दाद_, _onsu,
  { {0x339b0032,0xdb040026,0x6289058b,0x00000000}},	//   _رخصة_, keið, pseo,
  { {0x7648024a,0x6d45058c,0x20fc008b,0x00000000}},	//   _yhdy, _azha, ải_,
  { {0x7bdd0089,0x7af600fe,0x8e59005e,0x00000000}},	//   _ansu, vyyt, ејсу_,
  { {0x201900cd,0x15f40053,0xbd83058d,0x00000000}},	//   èric_, _अवसर_, ргск,
  { {0x3e660164,0x20190003,0xdca3007b,0x00000000}},	//   _tôt_, érit_, јати,
  { {0x09fa0021,0x3205004c,0xab630094,0x00000000}},	// [5c0] وفرة_, ohly_, рвул,
  { {0xfe9b014e,0x7bdd04bc,0x7bcd001f,0x00000000}},	//   _קיימ, _ensu, adau,
  { {0x7af600fe,0x7e6400fe,0x18a6026c,0x00000000}},	//   syyt, _huip, таем,
  { {0x66010019,0xdb040026,0x765a058e,0x00000000}},	//   _allk, beið, _sity,
  { {0xc1780006,0xf62a0086,0xc7a3058f,0x00000000}},	//   ybė_, міки_, ричк,
  { {0x68380016,0x69dc0359,0x9633000d,0x00000000}},	//   vídu, _unre, аніц,
  { {0x7e640104,0xafdb01e1,0x48e30590,0x00000000}},	//   _luip, lløe, _корв,
  { {0xdcfe007d,0xccf3009a,0xa7da0044,0x00000000}},	//   _nepč, שכה_, _تورط_,
  { {0x2a660025,0xe7370121,0xd4030591,0x00000000}},	//   íobh_, _ает_, рящи,
  { {0x32050592,0xa9b8014b,0x88ca009d,0x00000000}},	//   ghly_, дзiр, ֵמָ֖,
  { {0xbb1b000c,0xa99b0047,0x6838017d,0x00000000}},	//   _neîn, וביר, sídu,
  { {0xc0580088,0xdfd10593,0x3205017c,0x00000000}},	//   кія_, حيح_, ahly_,
  { {0xa294000d,0x82fa005d,0x92940092,0x00000000}},	//   _салі, _تراز_, _салц,
  { {0x2731008b,0xdb040014,0x32050594,0x00000000}},	//   ỡng_, veið, chly_,
  { {0xab950193,0xde580086,0xdcfc003b,0x00000000}},	//   ливі, тарі_, vară,
  { {0x6aad0595,0x6d4500a8,0xb5fd0596,0x00000000}},	//   ttaf, _vzha, _muša,
  { {0xab840597,0x7bcd0598,0x6aad0035,0x00000000}},	// [5d0] руск, rdau, utaf,
  { {0xdb04007a,0x66180599,0xd91b0076,0x00000000}},	//   reið, jivk, мье_,
  { {0x67d5000a,0x4426059a,0x5887000d,0x00000000}},	//   ложу, _ojo_, тыза,
  { {0xc7940088,0x442600c3,0x7bdd059b,0x00000000}},	//   аршы, _njo_, _unsu,
  { {0xd639000d,0x7cfc0072,0x4b7a0132,0x00000000}},	//   някі_, pärö, _ראשו,
  { {0x68e300c7,0xa2b80161,0xd12603eb,0x00000000}},	//   änds, ्बन्, _هم_,
  { {0x64b50021,0x2019059c,0x60060046,0x00000000}},	//   احتر, kisi_, _hóme,
  { {0x2019005b,0xb5fd059d,0x42c90363,0x00000000}},	//   jisi_, _duša, егин_,
  { {0x2019059e,0x3205059f,0xdb0f004c,0x00000000}},	//   disi_, thly_, _obcí,
  { {0x2019004b,0x3f9e0078,0x60e905a0,0x00000000}},	//   eisi_, ėtum_, емом_,
  { {0xafdb00b9,0x7c2900b2,0xfbdf002b,0x00000000}},	//   dløb, čerj, _phêl_,
  { {0xbb1b000c,0xdee605a1,0x320500e5,0x00000000}},	//   _reîn, гоми, shly_,
  { {0x443f05a2,0x201900cd,0x2cba0150,0x00000000}},	//   mlu_, èria_, _sppd_,
  { {0x22920021,0x201905a3,0x91e20002,0x00000000}},	//   _الوس, érir_, _гоше,
  { {0x201905a4,0xafdb05a5,0x443f05a6,0x00000000}},	//   bisi_, rmør, olu_,
  { {0x3ec900fe,0x201905a7,0xeb9f000e,0x00000000}},	//   ättä_, cisi_, _smør_,
  { {0x8eb3007e,0x8c430189,0x62950051,0x00000000}},	// [5e0] _هميش, сете, ązow,
  { {0x7a30004d,0x443f05a8,0x99860044,0x00000000}},	//   lätz, hlu_, الاو,
  { {0x3ea205a9,0x3ce50137,0x443f05aa,0x00000000}},	//   lukt_, älvt_, klu_,
  { {0xdc9b0063,0x443f007d,0xad1b0047,0x00000000}},	//   _איטל, jlu_, _טויר,
  { {0x443f0185,0x68e300c7,0x600605ab,0x00000000}},	//   dlu_, ändr, _góme,
  { {0x7a3000bd,0x629b0006,0x7c24000c,0x00000000}},	//   hätz, druo, lnir,
  { {0x2955011c,0x2480007d,0xd49705ac,0x00000000}},	//   _вътр, ćimo_, гры_,
  { {0x68e305ad,0x69ce05ae,0x443f05af,0x00000000}},	//   ånde, _habe, glu_,
  { {0x2d8a05b0,0x201905b1,0x629b0078,0x00000000}},	//   kabe_, visi_, gruo,
  { {0x32b70021,0x443f05b2,0x201905b3,0x00000000}},	//   ادية_, alu_, wisi_,
  { {0x69ce05b4,0xaa370047,0x629b05b5,0x00000000}},	//   _mabe, רטיק_, aruo,
  { {0x7c24017f,0x69ce05b6,0x20190150,0x00000000}},	//   jnir, _labe, uisi_,
  { {0xa3e10053,0x743b0047,0xb5fd00a8,0x00000000}},	//   दार_, _װעגװ, _mušn,
  { {0x20190357,0x7c2405b7,0x2fcd007d,0x00000000}},	//   sisi_, enir, žeg_,
  { {0xafdb00b9,0x02170063,0x201905b8,0x00000000}},	//   rløb, _תחום_, pisi_,
  { {0xfbdf00aa,0x69ce05b9,0x38ae0014,0x00000000}},	//   _thêm_, _aabe, dýr_,
  { {0x7c280164,0x60dc00b9,0x44240025,0x00000000}},	// [5f0] édra, ærmf, inm_,
  { {0x69ce05ba,0xceb40047,0x443f05bb,0x00000000}},	//   _cabe, _היץ_, zlu_,
  { {0x69ce0199,0x7a300072,0x443f05bc,0x00000000}},	//   _dabe, näty, ylu_,
  { {0x8d74006a,0x7c24003b,0x629b0078,0x00000000}},	//   _پایا, cnir, yruo,
  { {0x68e30093,0x66e505bd,0x69ce05be,0x00000000}},	//   åndb, рола, _fabe,
  { {0x44a50021,0x69ce05bf,0x644005c0,0x00000000}},	//   لمتق, _gabe, elmi,
  { {0xfdf80063,0x443f05c1,0x7bcf0089,0x00000000}},	//   רצות_, tlu_, _kacu,
  { {0x7a300072,0x7bcf05c2,0x69ce05c3,0x00000000}},	//   däty, _jacu, _zabe,
  { {0x443f0397,0x020500e1,0xf3490062,0x00000000}},	//   rlu_, изин, ъпил_,
  { {0x443f05c4,0x6440003a,0x51550121,0x00000000}},	//   slu_, almi, итну,
  { {0xd00a05c5,0x443f05c6,0x629b0050,0x00000000}},	//   вене_, plu_, sruo,
  { {0x2d8a002c,0xdcfe001c,0x78ba0137,0x00000000}},	//   wabe_, _nepā, _ätve,
  { {0x629d00ea,0x79950051,0x91e505c7,0x00000000}},	//   ásod, _odzw, _воле,
  { {0x44d50418,0x7a300199,0x3ea205c8,0x00000000}},	//   _kā_, sätz, rukt_,
  { {0x2d8a05c9,0x6b66011c,0x44d5001c,0x00000000}},	//   rabe_, иква, _jā_,
  { {0x69ce05ca,0x8b260141,0x9e6601ce,0x00000000}},	//   _sabe, адбе, _квид,
  { {0x78bc0599,0x7c2405cb,0xcb000053,0x00000000}},	// [600] _sprv, rnir, लैंड_,
  { {0x7e7600a4,0x0b5902dc,0x7c2400dd,0x00000000}},	//   _ityp, урсы_, snir,
  { {0xa7660079,0x44c700ea,0x61ee004b,0x00000000}},	//   акед, _nő_, öbli,
  { {0x69ce05cc,0xb5fd007d,0xf0b60047,0x00000000}},	//   _wabe, _bušo, ילער_,
  { {0x7bc4003b,0x69ce05cd,0x16a705ce,0x00000000}},	//   meiu, _tabe, ивци_,
  { {0xa613019d,0x96f7000a,0x2888005d,0x00000000}},	//   оміч, решт_, _مصری_,
  { {0x291e0137,0x628200e5,0x68d50062,0x00000000}},	//   _äta_, _swoo, _лютф,
  { {0xf3f8008f,0x39470058,0x07a305cf,0x00000000}},	//   _kuģi_, ünse_, _масн,
  { {0x52140055,0x41e6000d,0x3f8b007d,0x00000000}},	//   йдит, аіна, vacu_,
  { {0x44c700ea,0x717805ac,0x7a300050,0x00000000}},	//   _fő_, ыбор_, täty,
  { {0xf993014e,0x6aa4006f,0xbb1b003b,0x00000000}},	//   חרת_, huif, _reîm,
  { {0xdb1d00ea,0xa2b80053,0x7a300072,0x00000000}},	//   _vasú, ्बद्, räty,
  { {0x7a300072,0x88570041,0x7bcf05d0,0x00000000}},	//   säty, ישטע_, _racu,
  { {0x2723008b,0x7bcf05d1,0x8233009b,0x00000000}},	//   ằng_, _sacu, _وروا,
  { {0x4094043b,0x4c940076,0x7bcf0052,0x00000000}},	//   _البر, жисс, _pacu,
  { {0x3ced007d,0x27230066,0x515b0063,0x00000000}},	//   ćev_, nčnú_, _בכוו,
  { {0x2012006f,0x996705d2,0x1a5b0021,0x00000000}},	// [610] ëzie_, ател, نشطة_,
  { {0x2b85008b,0xac9501ce,0x0357009a,0x00000000}},	//   ặc_, _лаош, שימש_,
  { {0x6d5a0078,0x27230066,0x7bcf05d3,0x00000000}},	//   žtar, kčnú_, _tacu,
  { {0xf7f4007e,0x7bc4003b,0x6e880043,0x00000000}},	//   يسند, ceiu, _حنیف_,
  { {0xa3ea0235,0xd6d90045,0x6b8d004b,0x00000000}},	//   मान_, _była_, maag,
  { {0x85780062,0x99910022,0x6b8d05d4,0x00000000}},	//   асът_, żały_, laag,
  { {0x69c50019,0x18a4000d,0xcd980063,0x00000000}},	//   mehe, _маём, בדות_,
  { {0x69c50004,0x68f80137,0xe45f004b,0x00000000}},	//   lehe, ävde, öö_,
  { {0x6032001c,0x600605d5,0xe299005e,0x00000000}},	//   lāmg, _nóma, ћао_,
  { {0x44d5003d,0x9f590139,0x69c505d6,0x00000000}},	//   _tā_, bhsú_, nehe,
  { {0x3f8905d7,0x629d027d,0xa3d70053,0x00000000}},	//   _beau_, ásob, ायद_,
  { {0x69c500bd,0x6b8d006f,0xdcfe003b,0x00000000}},	//   hehe, jaag, _lepă,
  { {0x69c505d8,0x63a905d9,0x6b8d0229,0x00000000}},	//   kehe, mgen, daag,
  { {0x3f9e005b,0x63a905da,0xdcfe003b,0x00000000}},	//   ştu_, lgen, _nepă,
  { {0x61e305db,0xddcd000c,0x61fc05dc,0x00000000}},	//   _innl, _staţ, örle,
  { {0x60dc05dd,0x63a905de,0xb09a0047,0x00000000}},	//   ærme, ngen, _עיפר,
  { {0xfe720032,0x63a905df,0x6da605e0,0x00000000}},	// [620] _عدة_, igen, _липа,
  { {0x200200fe,0x69c505e1,0x443d004d,0x00000000}},	//   lkki_, gehe, _lkw_,
  { {0xa3d70161,0x395c00c7,0xdcfe000c,0x00000000}},	//   ाया_, ävs_, _depă,
  { {0x2002024a,0xa6e9001b,0x63a9006f,0x00000000}},	//   nkki_, _trự, jgen,
  { {0xadec0394,0x69c505e2,0xddcd003b,0x00000000}},	//   ञापन_, behe, _utaţ,
  { {0x63a905e3,0x6032001c,0x47330086,0x00000000}},	//   egen, lāmd, чніс,
  { {0x7d7b0047,0x63a905e4,0x18a3000d,0x00000000}},	//   אנצו, fgen, _нарм,
  { {0x3a3a01e3,0x63a905e5,0x68150051,0x00000000}},	//   lopp_, ggen, ządz,
  { {0xfbd30063,0x443d00be,0x4254009b,0x00000000}},	//   לתה_, _dkw_, ينبر,
  { {0x63a905e6,0x60060090,0x3f89006c,0x00000000}},	//   agen, _róma, _seau_,
  { {0x3f890164,0x660805e7,0x60060046,0x00000000}},	//   _peau_, _ildk, _sóma,
  { {0x82a6047e,0x61e300d1,0x443d05e8,0x00000000}},	//   _гадж, _ennl, _gkw_,
  { {0x60dc0146,0x3f890003,0xddcd00a8,0x00000000}},	//   ærmb, _veau_, _ataš,
  { {0xddcd0051,0x6b8d05e9,0xcd740062,0x00000000}},	//   _uważ, waag, згръ,
  { {0xf0b7007e,0x321e05ea,0x1df80121,0x00000000}},	//   _هايش_, mity_, щеры_,
  { {0x321e05eb,0x600605ec,0x68150022,0x00000000}},	//   lity_, _tóma, sądz,
  { {0x6b8d016d,0x69c505ed,0xeab00021,0x00000000}},	// [630] raag, tehe, فعل_,
  { {0x996705ee,0xddab05ef,0x321e05f0,0x00000000}},	//   стал, _стил_, nity_,
  { {0x69c50400,0x321e0072,0x094b05f1,0x00000000}},	//   rehe, iity_, учаи_,
  { {0xb8f10235,0x69c50199,0xad1a0063,0x00000000}},	//   _वन_, sehe, _כותר,
  { {0xcf940047,0xe739005e,0xa0260072,0x00000000}},	//   פטס_, јел_, ltöä,
  { {0x2009001f,0x60160130,0x75d500de,0x00000000}},	//   _llai_, ršmi, زيعا,
  { {0x20020026,0x63a903ac,0xa0260072,0x00000000}},	//   ykki_, tgen, ntöä,
  { {0xdb0d006d,0x63a905f2,0x320c004c,0x00000000}},	//   leañ, ugen, ehdy_,
  { {0x63a905f3,0x4209005e,0x23290193,0x00000000}},	//   rgen, инио_, ропи_,
  { {0xb5fd017f,0x31250076,0x6232005e,0x00000000}},	//   _mušk, ждог, мењу,
  { {0x443d0150,0x63a9006f,0xd4980092,0x00000000}},	//   _tkw_, pgen, _грч_,
  { {0xa3ea0053,0x2056000d,0xb4d50053,0x00000000}},	//   माण_, ўтор, िटी_,
  { {0x2002024a,0xce4a05f4,0x321e05f5,0x00000000}},	//   rkki_, изме_, bity_,
  { {0x2738001b,0x321e05f6,0x27e0001c,0x00000000}},	//   ứng_, city_, ķini_,
  { {0xdbc7007a,0xed5a05f7,0x3e6f004b,0x00000000}},	//   töðu, ров_, _eüt_,
  { {0xcb670062,0x1c4601dd,0x2004008f,0x00000000}},	//   жате_, інам, ījis_,
  { {0xdbc70026,0x3a3a05f8,0x00000000,0x00000000}},	// [640] röðu, topp_,   ,
  { {0x497a0088,0x718c0047,0x68fe0244,0x00000000}},	//   рсаў_, ָװאַ, typd,
  { {0xd6d90045,0x3a3a00df,0x00000000,0x00000000}},	//   _było_, ropp_,   ,
  { {0x321e0195,0x6e3c0244,0x386d011b,0x00000000}},	//   zity_, lorb, _čert_,
  { {0x6e3c0179,0x62860080,0x2441017c,0x00000000}},	//   oorb, škoz, nómu_,
  { {0x2ba80053,0xd49a05f9,0x321e00e5,0x00000000}},	//   गलवा, ари_, xity_,
  { {0x25a001f7,0x1db20053,0x321e05fa,0x00000000}},	//   ğil_, _जानत, vity_,
  { {0x6e3c0025,0x18670002,0x25a0005b,0x00000000}},	//   horb, _фати_, şil_,
  { {0x6ab60045,0x2489007d,0x320c002b,0x00000000}},	//   ntyf, ćama_, thdy_,
  { {0x6acb009a,0x3abb009d,0xa57300de,0x00000000}},	//   בֶטַ, סמינ, _يُقت,
  { {0x104b0055,0xb3ca05fb,0x321e05fc,0x00000000}},	//   иями_, _влез_, rity_,
  { {0x321e0034,0xdb2101c8,0x8f3505fd,0x00000000}},	//   sity_, _štíh, земц,
  { {0x6e3c0205,0x1439007e,0xa3d70053,0x00000000}},	//   forb, _اينک_, ायर_,
  { {0x6e3c02f5,0x40940044,0x00000000,0x00000000}},	//   gorb, _فلتر,   ,
  { {0x317b0063,0x3174056c,0x59d50082,0x00000000}},	//   _דרומ, ądzą_, _डोगर,
  { {0x80c70053,0x7e7d05fe,0xb5fd05ff,0x00000000}},	//   ़बरे, ppsp, _pušk,
  { {0xf96b0363,0x6e3c0600,0x00000000,0x00000000}},	// [650] арей_, borb,   ,
  { {0x527b00b5,0xa2b20053,0x600d006c,0x00000000}},	//   ינמא, _आमन्, _dûme,
  { {0x81bc001c,0x602400ea,0x18a40086,0x00000000}},	//   tnēj, sőme, даєм,
  { {0x2d91017f,0x61f801f2,0x600d0003,0x00000000}},	//   laze_, _lovl, _fûme,
  { {0xeb760047,0x76c70049,0x501c009a,0x00000000}},	//   _מערץ_, تغال, סודו,
  { {0xe6180086,0x19a80601,0x2d910602,0x00000000}},	//   оді_, _мтсп_, naze_,
  { {0x7e6d0509,0xf5050603,0xd4d90085,0x00000000}},	//   _luap, язко, сьлі_,
  { {0x60060066,0x69d50604,0xb5fd0605,0x00000000}},	//   _rómo, _haze, _muši,
  { {0x69d50606,0x29ff0051,0x2d910607,0x00000000}},	//   _kaze, ałań_, kaze_,
  { {0x11d50032,0xddc4017f,0x69d50608,0x00000000}},	//   ستخد, _stiž, _jaze,
  { {0x38b50609,0x61fc0137,0xcea90149,0x00000000}},	//   når_, örla, _תי_,
  { {0x6e3c00bd,0x69d5060a,0xafdb01e1,0x00000000}},	//   worb, _laze, lløj,
  { {0x63bb060b,0xdb1d006d,0x932701fb,0x00000000}},	//   mfun, _masó, _بران,
  { {0x2d8c03d9,0xa2f60063,0x38b502c0,0x00000000}},	//   úde_, _ממנה_, kår_,
  { {0xe166007e,0x6142060c,0x1d07060d,0x00000000}},	//   _عضوی, _пеша, пери_,
  { {0xc4d200b5,0xbc63060e,0xd2ef005e,0x00000000}},	//   עגן_, евск, _пoдр,
  { {0x2fc000bb,0x63bb0035,0x02b60047,0x00000000}},	// [660] _ibig_, ifun, ּלעך_,
  { {0xa3e20053,0x4a43060f,0x6ab60051,0x00000000}},	//   _फोन_, енув, rtyf,
  { {0xa967005a,0x63bb0610,0x38b50611,0x00000000}},	//   чиха_, kfun, går_,
  { {0xde6d008b,0x46ea0612,0x83fc007d,0x00000000}},	//   _hươn, йден_, _tuđi,
  { {0x69d503d9,0x073a0032,0x6d40005b,0x00000000}},	//   _faze, حساب_, şmad,
  { {0x69d50613,0x6b84004d,0x63bb0614,0x00000000}},	//   _gaze, lbig, efun,
  { {0xdb0f03b2,0xdb1d00cd,0x2d8500ea,0x00000000}},	//   _accè, _absè, űleg_,
  { {0xde6d008b,0x02a60615,0x929d0022,0x00000000}},	//   _lươn, пром, zyłe,
  { {0x6b84002c,0x61f802e2,0x6aa40616,0x00000000}},	//   ibig, _povl, nrif,
  { {0x27e0003d,0x9098000a,0xdb0d017d,0x00000000}},	//   ķinu_, овот_, sfaç,
  { {0x2ee0003e,0x6aa40617,0x63bb0618,0x00000000}},	//   _arif_, hrif, bfun,
  { {0xe45a0619,0x2ee0001f,0x38a0003b,0x00000000}},	//   _уже_, _brif_, mără_,
  { {0xf206011c,0xeb9f00b9,0x2d910066,0x00000000}},	//   _няко, _fløj_, taze_,
  { {0x9c83061a,0x6aa4061b,0x32050034,0x00000000}},	//   účov, drif, ckly_,
  { {0xde6d008b,0xc1bb0063,0x2d91061c,0x00000000}},	//   _dươn, _המוש, raze_,
  { {0x6aa40185,0x6b8400bb,0xdfd10049,0x00000000}},	//   frif, gbig, _شيخ_,
  { {0x6aa4061d,0x8f9c0063,0x69d5001c,0x00000000}},	// [670] grif, _היחי, _paze,
  { {0x6b84061e,0xde6d008b,0x6f0f005b,0x00000000}},	//   abig, _gươn, ıncı,
  { {0x6032003d,0x799c001f,0xe3c70006,0x00000000}},	//   lāma, _ddrw, ščių_,
  { {0x38b5061f,0x290f0051,0x6aa40620,0x00000000}},	//   rår_, ąga_, brif,
  { {0x290702e2,0x16a90086,0xdb04017d,0x00000000}},	//   šna_, івки_, rgiã,
  { {0x45d20001,0x38b50137,0x68e100ea,0x00000000}},	//   вољс, pår_, _áldo,
  { {0x2489017f,0x63bb0621,0x7c2d0622,0x00000000}},	//   ćamo_, tfun, onar,
  { {0xdb0f0623,0x63bb0035,0x13090065,0x00000000}},	//   _accé, ufun, жний_,
  { {0x2d9e0026,0x35b5005e,0x63bb0624,0x00000000}},	//   ótek_, _обар, rfun,
  { {0x3eab0625,0xaa7b0066,0x63bb0246,0x00000000}},	//   duct_, _zrýc, sfun,
  { {0x7c2d0626,0x33b50121,0xc6090053,0x00000000}},	//   knar, _жёлт, वसीय_,
  { {0x2ee00185,0xde6d0013,0x001a0085,0x00000000}},	//   _prif_, _sươn, іўны_,
  { {0x64490627,0x7c2d00c3,0xa3ea0053,0x00000000}},	//   mlei, dnar, मार_,
  { {0x442d0628,0x7c2d0629,0x3f820051,0x00000000}},	//   lne_, enar, dłuż_,
  { {0x442d062a,0x3eb90122,0x9e63041d,0x00000000}},	//   one_, atst_, тврд,
  { {0x442d062b,0x443f062c,0x6449062d,0x00000000}},	//   nne_, nou_, nlei,
  { {0x442d062e,0xde6d001b,0x8c43036a,0x00000000}},	// [680] ine_, _tươn, тете,
  { {0x2b8c001b,0x6449062f,0x2eff004d,0x00000000}},	//   ếc_, hlei, äufe_,
  { {0x442d0630,0x6b8400a4,0xe947007e,0x00000000}},	//   kne_, pbig, ورمی,
  { {0x798e021f,0x442d0631,0x443f0632,0x00000000}},	//   _webw, jne_, jou_,
  { {0x7c240332,0x629d00ea,0xb865007e,0x00000000}},	//   miir, ásol, رامو,
  { {0x44ce0080,0x442d0633,0x64490634,0x00000000}},	//   _př_, ene_, elei,
  { {0x3e7400c7,0x55e30635,0x94aa0636,0x00000000}},	//   _lät_, тојб, ітка_,
  { {0x443f0016,0x442d0637,0x68e30146,0x00000000}},	//   gou_, gne_, ænde,
  { {0x61fc0137,0x3e740137,0x00000000,0x00000000}},	//   örlo, _nät_,   ,
  { {0x60dc00b9,0x442d0638,0xf12601d5,0x00000000}},	//   ærmo, ane_, дьмо,
  { {0x8506006a,0x64490639,0x443f063a,0x00000000}},	//   _توان, blei, bou_,
  { {0x443f063b,0x6032008f,0x628000a5,0x00000000}},	//   cou_, tāma, ppmo,
  { {0x64400006,0x4424063c,0xdefb000d,0x00000000}},	//   momi, mim_, цын_,
  { {0x6032001c,0x6440063d,0x4424063e,0x00000000}},	//   rāma, lomi, lim_,
  { {0x6440004b,0x7c2d063f,0x6032008f,0x00000000}},	//   oomi, tnar, sāma,
  { {0x44240640,0x64400641,0x7c2d0642,0x00000000}},	//   nim_, nomi, unar,
  { {0x7c2d0643,0xcd040080,0x8fa40001,0x00000000}},	// [690] rnar, vněž_, _рање,
  { {0x443f0644,0x44240645,0x442d0646,0x00000000}},	//   zou_, him_, zne_,
  { {0x39470146,0x5a44000d,0x64400647,0x00000000}},	//   æns_, тэта, komi,
  { {0x443f0016,0x64400006,0x27e9006d,0x00000000}},	//   xou_, jomi, ñan_,
  { {0x443f027d,0x7bcd0003,0x442d0648,0x00000000}},	//   vou_, meau, vne_,
  { {0x442d0045,0x9f5900c7,0x44240649,0x00000000}},	//   wne_, ckså_, eim_,
  { {0xe3b10032,0x60060025,0x443f064a,0x00000000}},	//   هرة_, _fómh, tou_,
  { {0x442d0529,0x645b0035,0x36d5064b,0x00000000}},	//   une_, umui, _побр,
  { {0x6449064c,0x442d064d,0x645b064e,0x00000000}},	//   rlei, rne_, rmui,
  { {0xe1f10032,0x442d064f,0x443f0650,0x00000000}},	//   اسة_, sne_, sou_,
  { {0x2c750137,0x65940651,0x44240652,0x00000000}},	//   _nåd_, _раху, bim_,
  { {0x44240631,0x64400653,0x61ea0654,0x00000000}},	//   cim_, comi, _enfl,
  { {0x2ac3001c,0x7bcd0655,0xdd020066,0x00000000}},	//   nībā_, deau, ľuču,
  { {0x2d9e0164,0xa3d70053,0xb5fd007d,0x00000000}},	//   ûte_, ायक_, _gušt,
  { {0xd00a0001,0x7c240656,0xa3b60042,0x00000000}},	//   _неке_, tiir, _जाम_,
  { {0x7bcd0657,0x3e7400a5,0x711a009a,0x00000000}},	//   geau, _tät_, _מוצפ,
  { {0xf4120047,0x60060658,0x1f660086,0x00000000}},	// [6a0] אפן_, _rómh, _яким,
  { {0x7c240659,0xed5a005e,0x4424065a,0x00000000}},	//   siir, _ноп_, zim_,
  { {0x4424005b,0x1bea065b,0x7c24065c,0x00000000}},	//   yim_, _едни_, piir,
  { {0x4424065d,0x7bcd006c,0x7d01065e,0x00000000}},	//   xim_, ceau, älse,
  { {0x4424065f,0x6006006d,0xdb060244,0x00000000}},	//   vim_, _cómi, _abkö,
  { {0x4424001f,0x999a0022,0x600605ec,0x00000000}},	//   wim_, żyły_, _dómi,
  { {0x7c2f0025,0x44240660,0x81bc001c,0x00000000}},	//   _áirí, tim_, inēt,
  { {0xd4670138,0x644000fe,0xb5fd007d,0x00000000}},	//   није_, uomi, _sušt,
  { {0x07b70032,0x44240661,0x2ac3001c,0x00000000}},	//   _سهلة_, rim_, cībā_,
  { {0x44240662,0x64400663,0x6613056c,0x00000000}},	//   sim_, somi, ądkó,
  { {0x44240664,0xe9f90013,0x64400665,0x00000000}},	//   pim_, huế_, pomi,
  { {0x929d0045,0x2c750666,0x28970063,0x00000000}},	//   syła, _råd_, עדכן_,
  { {0x7bcd0667,0xb5fd0078,0x93fb0063,0x00000000}},	//   veau, _tušt, _מלאי,
  { {0x91e3005e,0x81bc008f,0xaa7b0014,0x00000000}},	//   _боље, gnēt, _brýn,
  { {0x7bcd0668,0x2ac3008f,0x8c250044,0x00000000}},	//   teau, zībā_, نفسه,
  { {0x7c84000a,0x59c60042,0xdbf2004c,0x00000000}},	//   ѓусе, _रॉबर, třás,
  { {0x7bcd0669,0x49cb05ac,0x7b740021,0x00000000}},	// [6b0] reau, зуем_, اطفا,
  { {0x7bcd066a,0x6d41066b,0x1a65005d,0x00000000}},	//   seau, ülas, ئیسی_,
  { {0x48ab066c,0x5d550095,0x7bcd066d,0x00000000}},	//   ятам_, _шкот, peau,
  { {0xfbab0055,0x629d000f,0x200b0080,0x00000000}},	//   _этой_, ások, nkci_,
  { {0x79a700e1,0xc66b0121,0xe56e0141,0x00000000}},	//   _прве, чшее_, из_,
  { {0x2ac3001c,0xb5fd0078,0x60060331,0x00000000}},	//   rībā_, _aušr, _vómi,
  { {0x2ac3008f,0xda34066e,0x69c10042,0x00000000}},	//   sībā_, _серы, र्णी,
  { {0x73e5066f,0x00000000,0x00000000,0x00000000}},	//   тоиз,   ,   ,
  { {0x961d008f,0x27ed0670,0xe3b1005d,0x00000000}},	//   _atņe, _inen_, هرک_,
  { {0x96df0088,0x85b8018e,0xd5d40044,0x00000000}},	//   _нiву_, _плус_, _متمث,
  { {0x76430671,0x21690002,0x93b502d8,0x00000000}},	//   mony, ќини_, _абец,
  { {0x7d070051,0x27ed004d,0x76430672,0x00000000}},	//   dyjs, _jnen_, lony,
  { {0x93940021,0x441a00ff,0x6024013d,0x00000000}},	//   _إجما, _קונס, sőmo,
  { {0x76430673,0x6f060022,0xed5a01ce,0x00000000}},	//   nony, rykc, дог_,
  { {0xdcfc003d,0xdde400ea,0x629b0078,0x00000000}},	//   varē, ésőb, lsuo,
  { {0xd1640062,0x27ff00e5,0x76430674,0x00000000}},	//   _съчи, _noun_, hony,
  { {0xee3a0675,0xab270676,0xab66066c,0x00000000}},	// [6c0] _они_, вота_, твал,
  { {0x48e60001,0x7d01004d,0x27ed04aa,0x00000000}},	//   козв, älsc, _anen_,
  { {0x2d980677,0x7d070022,0x76430678,0x00000000}},	//   mare_, cyjs, dony,
  { {0x661d0006,0x2d980679,0x8b26000d,0x00000000}},	//   _įska, lare_, _адме,
  { {0x2d98003b,0x7643002b,0x4b550094,0x00000000}},	//   oare_, fony, _бърт,
  { {0x2d98067a,0x8f1b0063,0xceb50041,0x00000000}},	//   nare_, וונת, ריװ_,
  { {0xd5e9008b,0x6d480058,0x4c9b009d,0x00000000}},	//   _qué, üdah, ֵ֑הו,
  { {0x6459067b,0x98360088,0x2000000c,0x00000000}},	//   _chwi, _рэгі, _noii_,
  { {0x69dc067c,0x20d30529,0x2d9801e3,0x00000000}},	//   _kare, _aţi_, kare_,
  { {0x69dc02b0,0x76430051,0x69de067d,0x00000000}},	//   _jare, cony, ndpe,
  { {0x2d98067e,0x50f3000d,0x69dc067f,0x00000000}},	//   dare_, азэт, _mare,
  { {0x69dc0680,0x03a302b6,0x2d930681,0x00000000}},	//   _lare, _вицо, _sexe_,
  { {0x63a20682,0xdcf5003d,0x4ea7005a,0x00000000}},	//   _idon, pazī, ърна,
  { {0x2d98067e,0x69dc01a6,0xc0aa00b3,0x00000000}},	//   gare_, _nare, _قابل_,
  { {0x6d400683,0x7ae60684,0x2000003b,0x00000000}},	//   şman, _arkt, _foii_,
  { {0xec340685,0x7d070051,0x76430686,0x00000000}},	//   ансь, ryjs, zony,
  { {0x7d070051,0x69de006f,0x2d980687,0x00000000}},	// [6d0] syjs, fdpe, bare_,
  { {0x2d980688,0x69dc0689,0x3f99068a,0x00000000}},	//   care_, _care, lasu_,
  { {0x63a2068b,0x7ae6068c,0x7c300014,0x00000000}},	//   _odon, _erkt, ðirð,
  { {0xac190086,0xc7c40121,0xafdb05e7,0x00000000}},	//   _чому_, исчи, mløs,
  { {0x07a40088,0x7c3a000f,0xf77003eb,0x00000000}},	//   раін, étre, زان_,
  { {0x62720051,0x76430035,0x63a2068d,0x00000000}},	//   _młod, uony, _adon,
  { {0x62820250,0x7bdd068e,0x5e580047,0x00000000}},	//   _atoo, _kasu, דיגע_,
  { {0x2d980529,0x27ed068f,0x3f99007d,0x00000000}},	//   zare_, _unen_, jasu_,
  { {0x3f99001f,0x7bdd035d,0x36d40690,0x00000000}},	//   dasu_, _masu, _котр,
  { {0x2d98000c,0x8185000d,0x386d0691,0x00000000}},	//   xare_, ыгож, _hier_,
  { {0x2d980692,0x63ae0025,0x9848003b,0x00000000}},	//   vare_, áiné, _uşă_,
  { {0x7bdd0693,0xafdb05b9,0x2d980694,0x00000000}},	//   _nasu, dløs, ware_,
  { {0x7e600122,0x765a00fe,0x69de00ac,0x00000000}},	//   ïmpo, _yhty, ydpe,
  { {0xb7c2001c,0x386d0695,0x60060331,0x00000000}},	//   ēģin, _lier_, _rómu,
  { {0x2d9803f2,0x7bdd0696,0x69dc0697,0x00000000}},	//   rare_, _basu, _rare,
  { {0x69dc0698,0x44e301f7,0x59c60053,0x00000000}},	//   _sare, _mı_, र्नर,
  { {0x2d9803f2,0x44e30058,0xdee60699,0x00000000}},	// [6e0] pare_, _lı_, _сопи,
  { {0xeef7069a,0x3d07013d,0x38bc0046,0x00000000}},	//   _עמיר_, ívvá_, tír_,
  { {0x3ea000d1,0x44e3005b,0x61fc069b,0x00000000}},	//   _hvit_, _nı_, örli,
  { {0xe73a0055,0x3ea0069c,0xb8dc0053,0x00000000}},	//   нее_, _kvit_, _आम_,
  { {0xc7a3005a,0x386d0179,0x69dc069d,0x00000000}},	//   сичк, _dier_, _tare,
  { {0x386d069e,0x799505e4,0xc4da005e,0x00000000}},	//   _eier_, _gezw, еђи_,
  { {0x6282015e,0x68e3069f,0x7ae406a0,0x00000000}},	//   _stoo, åndt, lvit,
  { {0x28030080,0x79950051,0x7ae406a1,0x00000000}},	//   ěrná_, _zezw, ovit,
  { {0x7ae406a2,0x7bc40290,0x660106a3,0x00000000}},	//   nvit, ifiu, _folk,
  { {0x660100f3,0xddcd0080,0x7e60006f,0x00000000}},	//   _golk, _staž, ïmpl,
  { {0xddcd000c,0x463b00b5,0x5ff505fb,0x00000000}},	//   _luaţ, _טעמע, азну,
  { {0x63a20035,0x66010089,0xb84a000d,0x00000000}},	//   _udon, _zolk, млiв,
  { {0x7bdd0397,0x6d4001f7,0xcf270021,0x00000000}},	//   _rasu, şmal, ارجي,
  { {0xd2b7014e,0x2731001b,0x44e3005b,0x00000000}},	//   _עלות_, ạng_, _yı_,
  { {0xdb0d0025,0x7bdd06a4,0x62720022,0x00000000}},	//   rgaí, _pasu, _włod,
  { {0x60060014,0xafdb05e7,0x60c5004b,0x00000000}},	//   _dóms, rløs, _ähma,
  { {0x7ac7000d,0xafdb06a5,0xdcfc0078,0x00000000}},	// [6f0] ысве, sløs, karė,
  { {0x386d0031,0xafdb02ab,0xdb160026,0x00000000}},	//   _sier_, pløs, reyð,
  { {0x7bdd0004,0x442606a6,0xdcfc0006,0x00000000}},	//   _tasu, _omo_, darė,
  { {0x2ee90089,0x79950051,0xe84b0593,0x00000000}},	//   _kraf_, _wezw, رجان_,
  { {0x6b8d06a7,0x2d940024,0xf7450001,0x00000000}},	//   mbag, ždeň_, јело,
  { {0x6b8d06a8,0x68e306a9,0x386d06aa,0x00000000}},	//   lbag, ånds, _wier_,
  { {0x386d06ab,0x224506ac,0x660106ad,0x00000000}},	//   _tier_, volk_, _volk,
  { {0x660106ae,0xf2d90043,0x92f500de,0x00000000}},	//   _wolk, نبخش_, لأخض,
  { {0x21f5019d,0x660106af,0xe299005e,0x00000000}},	//   аїнс, _tolk, њао_,
  { {0x03220088,0x20c50086,0x442606b0,0x00000000}},	//   ідэн, айом, _emo_,
  { {0x2ee9001f,0x7ae406b1,0x6032008f,0x00000000}},	//   _araf_, zvit, lāmi,
  { {0xa4fa00b7,0x2ee9001f,0x7ae400fe,0x00000000}},	//   _בלעט, _braf_, yvit,
  { {0x636b01f7,0x7d0100c7,0x6032001c,0x00000000}},	//   _dönü, älsn, nāmi,
  { {0x91fc0418,0x628906b2,0x6b8d003e,0x00000000}},	//   rmāc, mpeo, ebag,
  { {0x3b9606b3,0x8b9606b4,0x2ee900ca,0x00000000}},	//   ијат, ирач, _eraf_,
  { {0x6b8d002c,0xe8e0001b,0xafdb01f2,0x00000000}},	//   gbag, _hiệp_, slør,
  { {0x6aad06b5,0x6da606b6,0x6032008f,0x00000000}},	// [700] graf, _кипа, jāmi,
  { {0x6b8d00a4,0xac76007e,0x7ae406b7,0x00000000}},	//   abag, _پادش, rvit,
  { {0xa3b60161,0x636b005b,0x6b8d06b8,0x00000000}},	//   _जाल_, _yönü, bbag,
  { {0xdb2000ea,0x3ead06b9,0x929d0051,0x00000000}},	//   ítóg, šete_, szły,
  { {0x6aad06ba,0xdcfc0078,0x2c7c013d,0x00000000}},	//   craf, tarė, _híd_,
  { {0x7aeb0146,0x442606bb,0xe4a6006e,0x00000000}},	//   ægte, _smo_, арио,
  { {0xd49706bc,0x44260019,0xdcfe008f,0x00000000}},	//   ары_, _pmo_, _iepē,
  { {0x7c36001f,0xa68606bd,0x9f910046,0x00000000}},	//   nnyr, _влад, _núðu_,
  { {0xd467005e,0xa3e701ce,0xf74a02da,0x00000000}},	//   шиће_, рдња_, _شجره_,
  { {0xafdb00d1,0xdb0d0026,0x69c80058,0x00000000}},	//   eløp, ngaá, _öded,
  { {0x9f910026,0xe3ba06be,0xe8e00013,0x00000000}},	//   _búðu_, _абе_, _diệp_,
  { {0x1073000d,0x2ee9003b,0x6f1d06bf,0x00000000}},	//   ўляю, _praf_, tzsc,
  { {0x2475008f,0x2bba0042,0xd622014b,0x00000000}},	//   _rāmi_, इलना, _лiда,
  { {0x6f1d06c0,0xf0b7005d,0xd24f0054,0x00000000}},	//   rzsc, دایش_, _єц_,
  { {0xac19018b,0x61fc0137,0xdde1013d,0x00000000}},	//   гову_, örlu, ítői,
  { {0xb068000d,0x2ee906c1,0xa3b60042,0x00000000}},	//   _крыж_, _traf_, जलि_,
  { {0x6b8d06c2,0xda7806c3,0xf9930021,0x00000000}},	// [710] rbag, аях_, قبض_,
  { {0xd9990032,0x6b8d06c4,0x6aad06c5,0x00000000}},	//   انات_, sbag, rraf,
  { {0x6aad005b,0x2907000c,0xf0930047,0x00000000}},	//   sraf, âna_, ַנס_,
  { {0x6aad06c6,0x6032008f,0x7d0800a5,0x00000000}},	//   praf, tāmi, ädse,
  { {0x7c2d06c7,0x929d0022,0xa6c9030b,0x00000000}},	//   miar, ryłk, улла_,
  { {0x929d0051,0x7c2d06c8,0x5a440085,0x00000000}},	//   syłk, liar, _дэса,
  { {0x6032008f,0x361a005d,0x588406c9,0x00000000}},	//   sāmi, درنگ_, _мыта,
  { {0xa9540086,0xf77f01f7,0xad38009f,0x00000000}},	//   _єкті, _üç_, ינוס_,
  { {0xa7150001,0xa3d60053,0x26cd0035,0x00000000}},	//   _удаљ, ाज़_, _upeo_,
  { {0xe61300b3,0x7c2d06ca,0xe1f905ef,0x00000000}},	//   _بشر_, hiar, уго_,
  { {0xafdb00d1,0xd24e007e,0x62720022,0x00000000}},	//   tløp, رچه_, _płoc,
  { {0x9f060032,0x6d40005b,0x6006006d,0x00000000}},	//   موجو, şmak, _cómp,
  { {0x201e00eb,0x91e506cb,0x52850032,0x00000000}},	//   ėti_, _голе, _التك,
  { {0xe29f007a,0x62720051,0x64490229,0x00000000}},	//   áðu_, _włoc, loei,
  { {0x7c2d06cc,0x0c790076,0x442d06cd,0x00000000}},	//   fiar, исты_, oie_,
  { {0x442d06ce,0x7c2d06cf,0x2c7c004c,0x00000000}},	//   nie_, giar, _víd_,
  { {0x63a606d0,0xc27a0047,0x442d06d1,0x00000000}},	// [720] ókni, ָרעי, iie_,
  { {0x442d06d2,0x7c360046,0x7c2d004e,0x00000000}},	//   hie_, snyr, aiar,
  { {0xf8aa0001,0x2d9a00ac,0x442d06d3,0x00000000}},	//   увек_, _iepe_, kie_,
  { {0x442d06d4,0x7c2d06d5,0xdcfc008f,0x00000000}},	//   jie_, ciar, harī,
  { {0xdcfc003d,0xf62a0086,0xf7460076,0x00000000}},	//   karī, ліки_, щедо,
  { {0x442d0019,0x9e7b0047,0x27e006d6,0x00000000}},	//   eie_, אנספ, žin_,
  { {0xdcfc003d,0x485a000d,0x442d06d7,0x00000000}},	//   darī, _браў_, fie_,
  { {0x2d9a06d8,0x442d06d9,0x3ea20046,0x00000000}},	//   _lepe_, gie_, kskt_,
  { {0x386600c7,0xe73a06da,0x6032008f,0x00000000}},	//   mmor_, _сеа_, nāmu,
  { {0x7c2d051e,0x442d06db,0x7ae90066,0x00000000}},	//   ziar, aie_, _šetk,
  { {0x38660150,0xa15806dc,0x7c2d0089,0x00000000}},	//   omor_, рану_, yiar,
  { {0x3957014e,0x442d06dd,0xa93b0047,0x00000000}},	//   משים_, cie_, רײטי,
  { {0x7c2d06de,0xdcf5056c,0x00000000,0x00000000}},	//   viar, iczą,   ,
  { {0xdb0d017d,0x633b0047,0x60dc00b9,0x00000000}},	//   lgaç, _געדױ, ærms,
  { {0x3ea200d1,0x6a690078,0x0ba7000d,0x00000000}},	//   askt_, _užfi, йшам,
  { {0x388100eb,0x00000000,0x00000000,0x00000000}},	//   _nėra_,   ,   ,
  { {0xdb0d017d,0x7c2d06df,0x999906e0,0x00000000}},	// [730] igaç, riar, икат_,
  { {0x6fb5006a,0x7c2d06e1,0x127b0047,0x00000000}},	//   _امکا, siar, טאמע,
  { {0x7c2d06e2,0x58d90094,0x75e9013d,0x00000000}},	//   piar, рдея_, nöző,
  { {0x2a790089,0xc1c40053,0x69d80066,0x00000000}},	//   _tusb_, वभुग, ôver,
  { {0xb6c70121,0x442d06e3,0x6449017d,0x00000000}},	//   ссей, vie_, voei,
  { {0x442d06e4,0x2d830051,0x853c0006,0x00000000}},	//   wie_, ncje_, _idėj,
  { {0x442d06e5,0xf650007e,0xdcfc008f,0x00000000}},	//   tie_, رئه_, varī,
  { {0x24090076,0xd2a90121,0x52a906e6,0x00000000}},	//   рнии_, акие_, авим_,
  { {0x764a0035,0x2d830051,0x13060076,0x00000000}},	//   bofy, kcje_, жный_,
  { {0x442d06e7,0xaadc0047,0x69d706e8,0x00000000}},	//   sie_, רחזר, nexe,
  { {0x7bd60035,0xdbc6004b,0x644906e9,0x00000000}},	//   yeyu, mööd, poei,
  { {0xa3b60161,0x62860066,0xe29f0014,0x00000000}},	//   _जाए_, íkoc, áðs_,
  { {0x2d9a0009,0xb7da0063,0x6d58004c,0x00000000}},	//   _pepe_, בקרי, _úvaz,
  { {0xf267005e,0xdcf50022,0x3ea206ea,0x00000000}},	//   _уђем, zczą, rskt_,
  { {0xd24e0032,0xc5f20063,0x69d706eb,0x00000000}},	//   _جنو_, ודם_, dexe,
  { {0x6ab60026,0x63bb06ec,0x3ea20014,0x00000000}},	//   tuyf, ngun, pskt_,
  { {0x61e306ed,0x63bb06ee,0x8d7601fb,0x00000000}},	// [740] _kanl, igun, _وادا,
  { {0x63bb003e,0x3866002b,0x200202f7,0x00000000}},	//   hgun, wmor_, ljki_,
  { {0x3935000d,0x69d90053,0x61e306ef,0x00000000}},	//   пэцс, नज़ी, _manl,
  { {0xb8f20161,0x46ea06f0,0x6d5e019f,0x00000000}},	//   _वह_, иден_, _izpa,
  { {0x4e0e0053,0x87030121,0x764a06f1,0x00000000}},	//   _हवाई_, дяще, tofy,
  { {0x61e300a4,0x63bb06f2,0xa3cc0042,0x00000000}},	//   _nanl, egun, श्न_,
  { {0x9f450080,0x38810078,0x62720022,0x00000000}},	//   ělé_, _tėra_, _błon,
  { {0x61e30250,0x63bb053b,0x799c06f3,0x00000000}},	//   _aanl, ggun, _herw,
  { {0x6aa406f4,0x62720022,0x61e306f5,0x00000000}},	//   nsif, _dłon, _banl,
  { {0x27e402eb,0x32180045,0x61e306f6,0x00000000}},	//   _hamn_, óry_, _canl,
  { {0xb97b0063,0x799c06f7,0x27e606f8,0x00000000}},	//   יניי, _merw, odon_,
  { {0x68e30146,0x27e606f9,0x69ca0053,0x00000000}},	//   ændi, ndon_, स्ती,
  { {0xee3f0080,0x69ce06fa,0x91780013,0x00000000}},	//   krýt_, _obbe, hởi_,
  { {0x61e30185,0xd344006a,0x2e4b02e4,0x00000000}},	//   _ganl, _ویژه_, рямо_,
  { {0x2cb806fb,0x660801e1,0x63a000dd,0x00000000}},	//   gurd_, _modk, oamn,
  { {0x27e402eb,0x6aa40035,0x63a006fc,0x00000000}},	//   _namn_, fsif, namn,
  { {0x9b6b005a,0x61e3005b,0xa3cc0053,0x00000000}},	// [750] ршва_, _yanl, श्य_,
  { {0x3eb90019,0x63a006fd,0xdb0406fe,0x00000000}},	//   must_, hamn, egió,
  { {0x3eb90004,0xb86b000a,0x63bb0058,0x00000000}},	//   lust_, ајде_, ygun,
  { {0x69ce06ff,0x63a0007d,0xaa7b0014,0x00000000}},	//   _ebbe, jamn, _brýt,
  { {0xf7700032,0x3eb90019,0xdbc60019,0x00000000}},	//   ناه_, nust_, tööd,
  { {0x62720051,0x6b9d002b,0x799c0700,0x00000000}},	//   _słon, _hesg, _gerw,
  { {0x1c0f0161,0x7985001f,0x3eb9004b,0x00000000}},	//   _सवाल_, mchw, hust_,
  { {0x32070701,0xd7c9006a,0x3eb90702,0x00000000}},	//   _sony_, _دوره_, kust_,
  { {0x61e3002c,0x63bb0703,0x3eb90704,0x00000000}},	//   _panl, rgun, just_,
  { {0x3eb90705,0x321e0706,0x660806a3,0x00000000}},	//   dust_, ghty_, _godk,
  { {0x61e30707,0x7985004d,0x00850062,0x00000000}},	//   _vanl, ichw, ялно,
  { {0xd3b80086,0x5437007e,0x3dd8002b,0x00000000}},	//   _душі_, _برطر, werw_,
  { {0xdbd9007a,0x3eb90708,0x6d410003,0x00000000}},	//   væðu, gust_, ûlan,
  { {0x32130013,0x2738008d,0xb5fd0078,0x00000000}},	//   _ôxy_, ẩng_, _pušy,
  { {0xdbd90026,0x7aef0709,0xed5a070a,0x00000000}},	//   tæðu, _arct, сов_,
  { {0x799c070b,0x6c360021,0x3eb9070c,0x00000000}},	//   _serw, أفرا, bust_,
  { {0x799c014f,0xdbd90026,0x6b9d070d,0x00000000}},	// [760] _perw, ræðu, _desg,
  { {0xa3ab0161,0x6aa4070e,0x19b9000d,0x00000000}},	//   कृत_, rsif, жуць_,
  { {0x799c070f,0x48b60062,0x88ca0002,0x00000000}},	//   _verw, ящат, слев_,
  { {0x799c00e8,0xdcf50051,0x79850710,0x00000000}},	//   _werw, jczę, achw,
  { {0x799c0711,0x27e60712,0x17790054,0x00000000}},	//   _terw, rdon_, ісць_,
  { {0x26c600fe,0x69ce006f,0xd49a0713,0x00000000}},	//   rtoo_, _ubbe, бри_,
  { {0x628b001f,0xa507005e,0x63a00714,0x00000000}},	//   _atgo, зеја_, tamn,
  { {0xb603003d,0xb4ac0042,0x493b009a,0x00000000}},	//   īšan, _कटी_, _הגלו,
  { {0x27f70114,0x63a00715,0x68e301e1,0x00000000}},	//   šení_, ramn, ændv,
  { {0x3eb90004,0x63a00716,0xe8e00013,0x00000000}},	//   vust_, samn, _nhịp_,
  { {0x3eb90717,0x63a0013d,0xbfd9012c,0x00000000}},	//   wust_, pamn, однє_,
  { {0x3eb90004,0x8fa400e1,0x9f350086,0x00000000}},	//   tust_, наџе, демі,
  { {0x6b9d0718,0x7985001f,0xb4ac0042,0x00000000}},	//   _resg, ychw, _कटु_,
  { {0x6b9d0331,0x3eb90719,0x7e280085,0x00000000}},	//   _sesg, rust_, піса_,
  { {0x3eb90019,0x61f80173,0x463b0041,0x00000000}},	//   sust_, _invl, צעלע,
  { {0x5c74071a,0xb1570063,0xafdb00b9,0x00000000}},	//   елст, _מסוג_, dnøg,
  { {0x7cf60014,0xdce70058,0x7985071b,0x00000000}},	// [770] týrð, rajı, tchw,
  { {0xdce7005b,0xdcf50051,0xf1cf0042,0x00000000}},	//   sajı, zczę, त्पन,
  { {0xdb0d0026,0x7985071c,0x20190078,0x00000000}},	//   ngaú, rchw, ūriu_,
  { {0x79850199,0x69c8005b,0x7658004c,0x00000000}},	//   schw, _öden, elvy,
  { {0x7985002b,0xf7730044,0xe68800de,0x00000000}},	//   pchw, راص_, كننى_,
  { {0x8afa0063,0x7aed00ca,0x00000000,0x00000000}},	//   _והשי, mvat,   ,
  { {0x7bcd0035,0xa5060062,0x7aed071d,0x00000000}},	//   ofau, деща_, lvat,
  { {0xfcaa00b7,0x3ea9024a,0x657a00ac,0x00000000}},	//   קיפּ, _ovat_, _egth,
  { {0x7aed071e,0x69ca0053,0x6612013d,0x00000000}},	//   nvat, स्वी, ükkö,
  { {0x7aed00ea,0x80a90121,0xa229071f,0x00000000}},	//   ivat, овов_, іжна_,
  { {0x7aed0720,0x3494005a,0xafdb00d1,0x00000000}},	//   hvat, _захр, lløy,
  { {0x7aed0721,0xa295012c,0x00000000,0x00000000}},	//   kvat, _жаді,   ,
  { {0x6d49000c,0x628b002b,0x442f0722,0x00000000}},	//   şeal, _utgo, _img_,
  { {0x7a20000f,0x7bcd0723,0x7aed065e,0x00000000}},	//   _köte, efau, dvat,
  { {0x7aed0724,0x3ea90229,0xc0a8007e,0x00000000}},	//   evat, _evat_, _فايل_,
  { {0x7a2000c7,0x8fa6007e,0xa09a0063,0x00000000}},	//   _möte, _کمکه, _ויקט,
  { {0x2eff00bd,0x6d450725,0xdd990066,0x00000000}},	// [780] äuft_, _exha, ŕňa_,
  { {0xe9d70726,0x9f9d0014,0x4a430727,0x00000000}},	//   мку_, læði_, внув,
  { {0x49990086,0xd7e60086,0x18a30062,0x00000000}},	//   яття_, діло, вахм,
  { {0x6d4001f7,0x9f400728,0x2ef200ac,0x00000000}},	//   şmas, _unió_, _kryf_,
  { {0xc7a3041d,0xafdb00b9,0x7aed0729,0x00000000}},	//   тичк, snøg, cvat,
  { {0x3eaf00b9,0x442f072a,0xe8df0013,0x00000000}},	//   _ægte_, _amg_, _luộc_,
  { {0x68e305b9,0x442f072b,0xa5c40042,0x00000000}},	//   ændt, _bmg_, _राठौ,
  { {0xd4670001,0x6b96072c,0x690b0063,0x00000000}},	//   мије_, nbyg, _וּמְ,
  { {0x9402007e,0xc274005e,0xd403072d,0x00000000}},	//   فوژه, нлиј, тящи,
  { {0xf8d20161,0xdb15072e,0x8afb0047,0x00000000}},	//   _सहाय, ébéc, קהיי,
  { {0xd1300032,0x9f450080,0xe8df008b,0x00000000}},	//   امج_, ělí_, _buộc_,
  { {0xe8df001b,0xeb9f00d1,0x7aed004a,0x00000000}},	//   _cuộc_, _fløy_, yvat,
  { {0xd6d90045,0x6b96072f,0x2ef2001f,0x00000000}},	//   _były_, dbyg, _cryf_,
  { {0x6ab600e8,0x2ef200ac,0xe7310063,0x00000000}},	//   dryf, _dryf_, אֵל_,
  { {0x1bd5005a,0xfe240076,0x645c001c,0x00000000}},	//   новя, тьян, _īrij,
  { {0xec680086,0x6b960730,0x2019008f,0x00000000}},	//   друк_, gbyg, īris_,
  { {0xcb340062,0x2ef20731,0xafdb05b9,0x00000000}},	// [790] ветъ, _gryf_, rnød,
  { {0xe9d30021,0xc95b000d,0xdcfc003b,0x00000000}},	//   ضغط_, оўе_, ucră,
  { {0x7aed065c,0x5c7506c3,0x20190072,0x00000000}},	//   svat, _плот, oksi_,
  { {0x201900f3,0x7aed006f,0xad26005d,0x00000000}},	//   nksi_, pvat, _سرپو,
  { {0x201900fe,0x16a90054,0x59c70042,0x00000000}},	//   iksi_, ївки_, _लापर,
  { {0x644200fe,0x0608000d,0x68e300b9,0x00000000}},	//   _ajoi, мнік_, ænds,
  { {0x57b700de,0xbd9c009d,0x00000000,0x00000000}},	//   _يحرز, חסות,   ,
  { {0xe739001f,0xe795007e,0x13090086,0x00000000}},	//   _ddŵr_, _سارک, зний_,
  { {0x9f9d007a,0x7c3a0732,0xeb920063,0x00000000}},	//   væði_, étri, נָה_,
  { {0x201900fe,0x7a2000bd,0x41050733,0x00000000}},	//   eksi_, _töte, езов,
  { {0x20890062,0x6e350734,0xd5a6005d,0x00000000}},	//   яйни_, dizb, _سلنی,
  { {0xcdc9014e,0x59cf0042,0x80a00042,0x00000000}},	//   _לך_, स्तर, _खबरे,
  { {0xef170055,0x9f9d007a,0x443f0735,0x00000000}},	//   емя_, ræði_, mnu_,
  { {0x20190736,0x443f0737,0xc6920149,0x00000000}},	//   aksi_, lnu_, ראם_,
  { {0xa3cc0053,0x5274007e,0x621a00ff,0x00000000}},	//   श्व_, _شاهز, _מוסק,
  { {0x443f0738,0x98ac008f,0xc87f0075,0x00000000}},	//   nnu_, ūlīt_, ışla_,
  { {0xdd2f0080,0x645b0072,0x6b960739,0x00000000}},	// [7a0] _měře, ilui, rbyg,
  { {0x2b9e008b,0x6b96073a,0x8e970063,0x00000000}},	//   ắc_, sbyg, _רדיו_,
  { {0x69c801f7,0x2d98073b,0x7d010137,0x00000000}},	//   _ödem, mbre_, älst,
  { {0xad370063,0x443f073c,0x96ea01dd,0x00000000}},	//   _טניס_, jnu_, зька_,
  { {0x68e30146,0x2d98073d,0x443f073e,0x00000000}},	//   ændr, obre_, dnu_,
  { {0xd49a073f,0x645b00ca,0x7c240740,0x00000000}},	//   при_, elui, lhir,
  { {0x24e7000a,0x645b0741,0x443f0742,0x00000000}},	//   емји_, flui, fnu_,
  { {0x6b7b0047,0x443f0743,0x66e60744,0x00000000}},	//   ּרינ, gnu_, _поба,
  { {0xe7d501f7,0x7c240745,0xf7460002,0x00000000}},	//   lığı, ihir, _џезо,
  { {0xe8df0013,0xd5e90021,0x443f0746,0x00000000}},	//   _nuớc_, _يعلن_, anu_,
  { {0x3a37014e,0x7c24003e,0x9f400026,0x00000000}},	//   תרים_, khir, _snið_,
  { {0x645b0747,0x69de0748,0x2d98032a,0x00000000}},	//   clui, hepe, ebre_,
  { {0x7c240035,0x4ea7000d,0x6e35004d,0x00000000}},	//   dhir, эрна, tizb,
  { {0x127b0047,0x7bc600a5,0x7c240433,0x00000000}},	//   _זאגע, _acku, ehir,
  { {0xc0e300d7,0x69de0749,0x7c240046,0x00000000}},	//   _бојк, depe, fhir,
  { {0xe7d501f7,0x515b0063,0x91780013,0x00000000}},	//   dığı, _מכוו, mời_,
  { {0xc87f005b,0x61ea0026,0xb603017c,0x00000000}},	// [7b0] ışma_, _kafl, úško,
  { {0xa93d000d,0x69de074a,0x63a202e3,0x00000000}},	//   одзi, gepe, _leon,
  { {0x443f074b,0xe578008f,0x4c9502d8,0x00000000}},	//   ynu_, _kaķu_, _шинс,
  { {0x63a2074c,0x7c24074d,0xf773005d,0x00000000}},	//   _neon, chir, هاش_,
  { {0x44240027,0x69de006f,0x443f074e,0x00000000}},	//   dhm_, bepe, vnu_,
  { {0x3eb90034,0x69de000c,0x27e9074f,0x00000000}},	//   irst_, cepe, žan_,
  { {0x443f0750,0xdb0d0026,0x9f4c004c,0x00000000}},	//   tnu_, ngaþ, ědé_,
  { {0x443f0751,0xb6f5005e,0x645b0050,0x00000000}},	//   unu_, _избј, ului,
  { {0x645b0752,0x320e0035,0x04560021,0x00000000}},	//   rlui, _bofy_, خلية_,
  { {0x645b04c6,0x443f0753,0xd24e0754,0x00000000}},	//   slui, snu_, يني_,
  { {0x443f0755,0x3eb90756,0x61ea002b,0x00000000}},	//   pnu_, erst_, _dafl,
  { {0x63a20757,0x69de0758,0x7a200137,0x00000000}},	//   _geon, zepe, _möta,
  { {0x69c7017f,0xdb06027d,0x7bdf0759,0x00000000}},	//   _ocje, _odká, dequ,
  { {0xdd9201fb,0xc58e0013,0xc33203c3,0x00000000}},	//   شور_, hồng_, _דוד_,
  { {0x6da30138,0x7c24075a,0x2731008b,0x00000000}},	//   риса, thir, ạnh_,
  { {0x8c43000a,0x69d5004d,0xc1780078,0x00000000}},	//   аесе, _abze, adės_,
  { {0xf9920593,0x69de075b,0x7c24075c,0x00000000}},	// [7c0] لبا_, tepe, rhir,
  { {0xceb90080,0xba23000d,0xe7d5005b,0x00000000}},	//   áře_, адук, tığı,
  { {0x7bdf0016,0x291c027d,0x69de075d,0x00000000}},	//   bequ, áva_, repe,
  { {0x69de075e,0xe73a075f,0xca29009a,0x00000000}},	//   sepe, мее_, חם_,
  { {0x62720051,0xa6fa0021,0x91780013,0x00000000}},	//   _głow, بعاء_, iới_,
  { {0x4a750076,0x63a20019,0xceb30063,0x00000000}},	//   _быст, _seon, שיג_,
  { {0x04c70021,0x7a200137,0x7ae40760,0x00000000}},	//   نووي_, _göta, lwit,
  { {0x61ea0185,0x94230001,0x7bc40761,0x00000000}},	//   _safl, имје, ngiu,
  { {0x7c230529,0x325406da,0x59cf0053,0x00000000}},	//   _înre, лвир, स्वर,
  { {0x3f80017d,0x7aeb01e1,0x66250022,0x00000000}},	//   _agiu_, ægti, ątkó,
  { {0x859b0132,0x9f4e0240,0x3ea000a4,0x00000000}},	//   _חשבו, čným_, _awit_,
  { {0xc953014e,0x94a90021,0x7d0301a8,0x00000000}},	//   ימת_, _أطلق_, _ànsi,
  { {0x3eb90474,0x61ea0762,0xf38f0013,0x00000000}},	//   urst_, _tafl, oảng_,
  { {0x6e940076,0x7bc40763,0xf7730132,0x00000000}},	//   риру, egiu, יקר_,
  { {0x62720045,0xfb870088,0x7bdf0764,0x00000000}},	//   _słow, вызн, tequ,
  { {0x7bc402f6,0xd10f0161,0x5fa70161,0x00000000}},	//   ggiu, ाहरण_, _ख़िल,
  { {0x7bdf0765,0xc3340063,0x49cb0766,0x00000000}},	// [7d0] requ, אוּ_, дуем_,
  { {0xf7f4007e,0x4d99013c,0x2ee90767,0x00000000}},	//   یسند, _якою_, _isaf_,
  { {0x6d410066,0x7bdf0331,0x5fa70042,0x00000000}},	//   úlad, pequ, _ख़ाल,
  { {0x787a0080,0xd78901fb,0xc8640768,0x00000000}},	//   _důvo, رنتو_, атчи,
  { {0x17540054,0xc58e008d,0xdb0d004b,0x00000000}},	//   авця, rồng_, ngaü,
  { {0x26360051,0xc9870769,0x1994076a,0x00000000}},	//   słon_, _шуми, _варя,
  { {0x6aad076b,0xc9580085,0x7a20013d,0x00000000}},	//   lsaf, _аўт_, _kötn,
  { {0x32cb076c,0xd46602e4,0x6b8d076d,0x00000000}},	//   tøy_, лище_, ncag,
  { {0x6aad076e,0x27ff0072,0x6595076f,0x00000000}},	//   nsaf, _inun_, _базу,
  { {0x2d81001b,0x95d80121,0x32cb069f,0x00000000}},	//   _nghe_, _идут_, røy_,
  { {0xe4cb006a,0x69c50770,0x32cb04aa,0x00000000}},	//   _زبان_, ighe, søy_,
  { {0x25a50771,0xf3f00021,0x91fc008f,0x00000000}},	//   _hell_, _وأن_, elād,
  { {0x27ed0185,0x25a50772,0x2fdf0019,0x00000000}},	//   _maen_, _kell_, õuga_,
  { {0x7643017e,0x63a90773,0x27ed0774,0x00000000}},	//   nnny, laen, _laen_,
  { {0x91fc003d,0xdcee005b,0x27ff005b,0x00000000}},	//   rmāt, tabı, _onun_,
  { {0x61e1024a,0x63a90775,0x69c501f4,0x00000000}},	//   lell, naen, eghe,
  { {0xab660776,0x4a460777,0xab27015b,0x00000000}},	// [7e0] увал, гнав, гота_,
  { {0x25a502f6,0xdcee01f7,0x787a0080,0x00000000}},	//   _nell_, sabı, _půvo,
  { {0x63a90778,0x60c10779,0x32360047,0x00000000}},	//   kaen, nulm, נטען_,
  { {0x63a90035,0x6b8d077a,0x7e7e0136,0x00000000}},	//   jaen, ccag, _hipp,
  { {0x61e1077b,0x25a50127,0x6d5e077c,0x00000000}},	//   kell, _bell_, _hypa,
  { {0xf38f001b,0x25a5077d,0x60c1077e,0x00000000}},	//   uảng_, _cell_, kulm,
  { {0x61e1077f,0x25a5055b,0x83fd00ea,0x00000000}},	//   dell, _dell_, klőd,
  { {0x4422000f,0x7643003e,0x61e100fe,0x00000000}},	//   ók_, anny, eell,
  { {0x25a50780,0x57460781,0xe3af0021,0x00000000}},	//   _fell_, _снаб, سري_,
  { {0xf1c60080,0x2000000c,0x2fc90025,0x00000000}},	//   _část_, _anii_, _scag_,
  { {0xdb0600b9,0x63a9033b,0x3178004d,0x00000000}},	//   _udkæ, baen, ärz_,
  { {0x0eeb0076,0xd259008f,0x82a60782,0x00000000}},	//   ньги_, ruņa_, _бадж,
  { {0xe296000a,0x69c501e1,0x62720022,0x00000000}},	//   _среќ, yghe, _błot,
  { {0x6d5e0783,0x61e10784,0x7a2000a5,0x00000000}},	//   _bypa, cell, _sötn,
  { {0x7e7e00e5,0x91fc008f,0xec6b0785,0x00000000}},	//   _dipp, rlād, ерак_,
  { {0xdb060137,0x60df013d,0x9b9501a4,0x00000000}},	//   _odkä, őzmé, риац,
  { {0x91fc001c,0xdfd80062,0x5a350786,0x00000000}},	// [7f0] plād, _същ_, анат,
  { {0x6b8d0787,0x321e0051,0xc7b9013d,0x00000000}},	//   scag, nkty_, _elől_,
  { {0x69c50788,0x2967005e,0x99670789,0x00000000}},	//   rghe, уњав, утал,
  { {0x25a50034,0x765a078a,0x6272078b,0x00000000}},	//   _sell_, _akty, _złot,
  { {0x65640080,0x61e1066d,0x63a9078c,0x00000000}},	//   řihl, yell, vaen,
  { {0x76430150,0x60c1005b,0xf77004f6,0x00000000}},	//   unny, yulm, سان_,
  { {0x25a5078d,0x63a9078e,0x61e1078f,0x00000000}},	//   _vell_, taen, vell,
  { {0x25a504bf,0x321e0022,0x61e10790,0x00000000}},	//   _well_, ekty_, well,
  { {0x25a50034,0x74120032,0xcb1200b5,0x00000000}},	//   _tell_, تويا, ַלט_,
  { {0xdb0d006d,0x61e10791,0x60c10792,0x00000000}},	//   ngañ, uell, tulm,
  { {0xc5fa0047,0xb5fa0047,0x3547000d,0x00000000}},	//   _שפעט, _שלעכ, _схав,
  { {0x60c101f7,0x43750793,0x7339005e,0x00000000}},	//   rulm, _култ, _изер_,
  { {0x2055000d,0x83fd00ea,0x61e10238,0x00000000}},	//   стэр, rlőd, pell,
  { {0x5332000a,0x387f0089,0x6da30794,0x00000000}},	//   _фељт, _liur_, жира,
  { {0xed5a0795,0x62860240,0x92680092,0x00000000}},	//   тов_, íkov, _срца_,
  { {0x6d5e0114,0x20000796,0x83fd013d,0x00000000}},	//   _vypa, _unii_, llőb,

  { {0x62720051,0x6d5e0051,0xdcfc001c,0x00000000}},	// [800] _głos, _wypa, obrī,
  { {0x6d5e0797,0x1daa0161,0x3c3f00fe,0x00000000}},	//   _typa, _क़ित, tävä_,
  { {0x77860798,0xdcfc0023,0x387f056c,0x00000000}},	//   алез, ibrī, _biur_,
  { {0x386d0799,0x7d1c0072,0xd90d005d,0x00000000}},	//   _cher_, myrs, ریق_,
  { {0xc6a30065,0x66f4079a,0xa6c701ce,0x00000000}},	//   орщи, сплу, илца_,
  { {0x386d00bd,0xc8960092,0x68fa013d,0x00000000}},	//   _eher_, _врањ, _átdo,
  { {0x29070137,0x75890086,0xd943079b,0x00000000}},	//   änat_, усів_, _дери,
  { {0x6a6b00bd,0x6e3c079c,0x68e20022,0x00000000}},	//   rüfe, hirb, łods,
  { {0xf5ea026b,0x9294005e,0x33730062,0x00000000}},	//   _имал_, љаоц, огър,
  { {0xd4d60088,0xb0660072,0x51f70121,0x00000000}},	//   _відэ, yvää, анью_,
  { {0xdcb1008b,0x6e3c079d,0x7a20004d,0x00000000}},	//   ởi_, dirb, _rötl,
  { {0x6e3c0025,0x7d1c01e1,0x853b009a,0x00000000}},	//   eirb, dyrs, _בגבי,
  { {0x32940032,0x2294079e,0xfe73009e,0x00000000}},	//   _التأ, _التس, قدس_,
  { {0x76580066,0x91e30121,0xf1a30062,0x00000000}},	//   novy, _моче, _дрън,
  { {0x2ba7041d,0x62720051,0x44260736,0x00000000}},	//   ијав, _włos, _klo_,
  { {0x5bb80076,0x717b014e,0xd0080001,0x00000000}},	//   ился_, _בנוס, _веће_,
  { {0xe9870001,0xb0660019,0xaed50001,0x00000000}},	// [810] аћен, svää, _уопш,
  { {0x387f0150,0x7d1c06a5,0x7ac4079f,0x00000000}},	//   _siur_, byrs, юссе,
  { {0xda7803d6,0x442607a0,0xa3d60042,0x00000000}},	//   рят_, _olo_, िभा_,
  { {0xe8df00aa,0x7aeb00b9,0x6d49003b,0x00000000}},	//   _quốc_, ægts, şeas,
  { {0xd6390085,0x8b030022,0x6a6b0244,0x00000000}},	//   лякі_, łębs, rüfb,
  { {0x2d910022,0xe5a207a1,0x442607a2,0x00000000}},	//   ncze_, пиши, _alo_,
  { {0x29070137,0x386d00e5,0xe8df008d,0x00000000}},	//   ånad_, _ther_, _tuốc_,
  { {0xd4e40086,0x436907a3,0x442607a4,0x00000000}},	//   юючи, лайн_, _clo_,
  { {0x32d0008b,0xdcfc008f,0xd8380085,0x00000000}},	//   gày_, tbrī, _тэр_,
  { {0x76580066,0x69c807a5,0x32d40085,0x00000000}},	//   covy, _ödet, іцыс,
  { {0x6d40005b,0x442607a6,0x786a0061,0x00000000}},	//   şmaz, _flo_, lýva,
  { {0x442607a7,0x6e3c004d,0x9f42004c,0x00000000}},	//   _glo_, wirb, leké_,
  { {0x2bcb0053,0x9dba0085,0x7bc3005f,0x00000000}},	//   िलना, лыву_, ėnul,
  { {0x23740024,0x51950021,0xe29c0041,0x00000000}},	//   ňajú_, _الغذ, _ישׂר,
  { {0x1d19019d,0x82340242,0x6e3c0014,0x00000000}},	//   ають_, _برنا, rirb,
  { {0x711a0063,0x20d1013d,0x6096005d,0x00000000}},	//   _תוקפ, mái_, _انيس_,
  { {0x629b00fe,0x3b070189,0xc0530063,0x00000000}},	// [820] npuo, бето_, _מזה_,
  { {0x7dea0076,0xdb0d0014,0xf9c40043,0x00000000}},	//   _смог_, rgað, تحری,
  { {0xd23a0047,0x8c26005d,0x7cd60044,0x00000000}},	//   נגעל, _هفده, _اتخذ,
  { {0xa967005a,0xdb0600ea,0x20f7003b,0x00000000}},	//   щиха_, _leké, _măi_,
  { {0x29070137,0x20d1008b,0x628f07a8,0x00000000}},	//   änar_, hái_, ícol,
  { {0x442600d1,0xa5f80416,0x20d1013d,0x00000000}},	//   _slo_, реку_, kái_,
  { {0xd497000d,0x6f1d0051,0x442607a9,0x00000000}},	//   бры_, zysc, _plo_,
  { {0x94180076,0x786a01c2,0x2d910051,0x00000000}},	//   ржит_, býva, zcze_,
  { {0x59cf0053,0x6a700137,0x7a200137,0x00000000}},	//   स्कर, räff, _nötk,
  { {0x6d4001f7,0xf238000a,0x69da0058,0x00000000}},	//   şmay, рпош_, _öted,
  { {0x20f7003b,0x69dc0025,0x4426007d,0x00000000}},	//   _căi_, _mbre, _tlo_,
  { {0x4420008b,0x43860021,0x44260332,0x00000000}},	//   _ôi_, _الإق, _ulo_,
  { {0x69dc07aa,0x316b0022,0x3c27004e,0x00000000}},	//   _obre, ęcza_, _nõva_,
  { {0x44f80013,0x2ceb0085,0x27e607ab,0x00000000}},	//   _kĩ_, льбо_, heon_,
  { {0x786a027d,0xb4250051,0x2d910022,0x00000000}},	//   zýva, łżeń, rcze_,
  { {0x44f80013,0x69dc06d5,0xd0110044,0x00000000}},	//   _mĩ_, _abre, _آلة_,
  { {0x7b6707ac,0x27e607ad,0x7a2007ae,0x00000000}},	// [830] стве, deon_, _köth,
  { {0x3da7030b,0x00000000,0x00000000,0x00000000}},	//   _уриб,   ,   ,
  { {0x44f80013,0xdd92007e,0x7c23003b,0x00000000}},	//   _nĩ_, _توپ_, _înro,
  { {0x7aee00fe,0x69dc07af,0x7c670242,0x00000000}},	//   äntä, _ebre, _داخل,
  { {0x958507b0,0x7c2d07b1,0xdcf50058,0x00000000}},	//   олле, mhar, mazı,
  { {0x7c2d07b2,0x7a20004d,0xc1b70042,0x00000000}},	//   lhar, _nöth, _आयेग,
  { {0x44f8001b,0xafdb00b9,0x240907b3,0x00000000}},	//   _cĩ_, rnøj, инки_,
  { {0x7afd07b4,0x7c2d07b5,0x44f8008b,0x00000000}},	//   _krst, nhar, _dĩ_,
  { {0x20f7000c,0xc7b900ea,0x7c2d07b6,0x00000000}},	//   _săi_, _idő_, ihar,
  { {0xdcf5005b,0x7c2d07b7,0x20f700dd,0x00000000}},	//   hazı, hhar, _păi_,
  { {0x7c2d07b8,0x7bcf07b9,0x629b07ba,0x00000000}},	//   khar, _occu, spuo,
  { {0x629b0072,0x20f7003b,0x20d107bb,0x00000000}},	//   ppuo, _văi_, rái_,
  { {0x442d0027,0x7c2d07bc,0xdcb1008b,0x00000000}},	//   mhe_, dhar, ẩn_,
  { {0x442d0016,0x7c2d014f,0x7bcf07bd,0x00000000}},	//   lhe_, ehar, _accu,
  { {0x7afd0019,0x442d07be,0xa06a07bf,0x00000000}},	//   _arst, ohe_, _кака_,
  { {0x442d07c0,0x628b0035,0x645b07c1,0x00000000}},	//   nhe_, _kugo, noui,
  { {0x63ab07c2,0x628b07c3,0x628307c4,0x00000000}},	// [840] _megn, _jugo, _kino,
  { {0x62830080,0x63ab07c5,0x644907c6,0x00000000}},	//   _jino, _legn, hnei,
  { {0x7afd07c7,0x7c2d0027,0x443f0006,0x00000000}},	//   _erst, bhar, kiu_,
  { {0x62990051,0x645b0003,0x7c2d031d,0x00000000}},	//   _otwo, joui, char,
  { {0x629900e8,0x44f8001b,0x98ab001c,0x00000000}},	//   _ntwo, _sĩ_, āmās_,
  { {0x7c240004,0xafdb00d1,0x63ab004b,0x00000000}},	//   lkir, tnøk, _aegn,
  { {0x7a2000bd,0x443f0024,0x291c0019,0x00000000}},	//   _nöti, fiu_, ävad_,
  { {0x6283024a,0x64490146,0x443f07c8,0x00000000}},	//   _aino, gnei, giu_,
  { {0x63ab0290,0xafdb00d1,0x7c2407c9,0x00000000}},	//   _degn, snøk, ikir,
  { {0x386607ca,0x442d07cb,0x628b07cc,0x00000000}},	//   llor_, ahe_, _dugo,
  { {0x72330032,0xf99301f9,0x442d0025,0x00000000}},	//   بريط, ורת_, bhe_,
  { {0x442d07cd,0x443f07ce,0x63ab07cf,0x00000000}},	//   che_, ciu_, _gegn,
  { {0xe1ef006a,0xd5b1001b,0x3866000c,0x00000000}},	//   رسی_, _hóa_, ilor_,
  { {0x628307d0,0x7c2407d1,0x644007d2,0x00000000}},	//   _gino, ekir, limi,
  { {0x56370047,0x7c2d07d3,0x644007d4,0x00000000}},	//   קאלע_, thar, oimi,
  { {0x7c2d07d5,0x628307d6,0x59dd0053,0x00000000}},	//   uhar, _zino, न्नर,
  { {0xdceb01f7,0x7c2d07d7,0x8d8707d8,0x00000000}},	// [850] ınız, rhar, _мунд,
  { {0x7c2d0009,0x7afd01a6,0x7c2400fe,0x00000000}},	//   shar, _vrst, akir,
  { {0x7c380026,0x644900fe,0xab950086,0x00000000}},	//   ðará, ynei, _нині,
  { {0x443f0268,0xdce5001b,0x7be5027d,0x00000000}},	//   xiu_, _nghĩ, íruč,
  { {0x443f07d9,0x660507da,0x63ab07db,0x00000000}},	//   viu_, зпла, _regn,
  { {0x63ab02f6,0x61e80117,0x65650019,0x00000000}},	//   _segn, jedl, ühho,
  { {0x442d018d,0x443f07dc,0x628307dd,0x00000000}},	//   the_, tiu_, _rino,
  { {0x628307de,0x644007df,0x7bcd07e0,0x00000000}},	//   _sino, gimi, ngau,
  { {0x442d07e1,0x63ab07e2,0xe2990001,0x00000000}},	//   rhe_, _vegn, љао_,
  { {0x442d07e3,0xd6280001,0x7c240089,0x00000000}},	//   she_, _дође_, zkir,
  { {0x63ab07e4,0x442d07e5,0x91fc001c,0x00000000}},	//   _tegn, phe_, plān,
  { {0x6440048e,0x628b002c,0x63ab07e6,0x00000000}},	//   cimi, _tugo, _uegn,
  { {0x62990045,0x7c2400d1,0xeef50085,0x00000000}},	//   _utwo, vkir, мярэ,
  { {0x863500b5,0x60c80137,0x7aed059f,0x00000000}},	//   לאָג_, budm, dwat,
  { {0xd5b1001b,0x32070051,0xdd8f0021,0x00000000}},	//   _xóa_, _inny_, اوف_,
  { {0x7aed0035,0xdddc0240,0x8c460062,0x00000000}},	//   fwat, zorň, чебе,
  { {0x443d00e8,0x7c2407c9,0x38660137,0x00000000}},	// [860] _mmw_, rkir, vlor_,
  { {0x4efb0047,0x7c2407e7,0x644007e8,0x00000000}},	//   _פליג, skir, zimi,
  { {0x7aed0089,0x6440005b,0xae1b07e9,0x00000000}},	//   awat, yimi, _הויכ,
  { {0x644007ea,0x7a2000a5,0x00000000,0x00000000}},	//   ximi, _nötv,   ,
  { {0x386607eb,0x644007ec,0xabfb0063,0x00000000}},	//   rlor_, vimi, _ההכר,
  { {0x6440002b,0xe4a607ed,0x00000000,0x00000000}},	//   wimi, прио,   ,
  { {0x25ac0080,0x443d03a2,0x80c00053,0x00000000}},	//   _vedl_, _bmw_, _विधे,
  { {0x3298000a,0x60c80137,0x61e8001f,0x00000000}},	//   овиќ_, vudm, wedl,
  { {0x61e807ee,0x644007ef,0x62340062,0x00000000}},	//   tedl, rimi, депу,
  { {0x80c00161,0x248c0089,0x4b3700ff,0x00000000}},	//   _विदे, _tudm_, פריל_,
  { {0x66080146,0x64a307f0,0x61e807f1,0x00000000}},	//   _indk, _заха, redl,
  { {0x7aed0045,0xdcb1008b,0xa3e30053,0x00000000}},	//   ywat, ẩm_, _पॉप_,
  { {0xd5b10013,0x82fa007e,0x661a07f2,0x00000000}},	//   _món_, _دراز_, _kotk,
  { {0x661a024a,0xb4b60082,0x00000000,0x00000000}},	//   _jotk, _जिफ़_,   ,
  { {0x61db0063,0xcd740062,0x0d840121,0x00000000}},	//   _הקוד, егръ, елён,
  { {0x7e60003b,0x7aed07f3,0x7bcd0078,0x00000000}},	//   împr, twat, ugau,
  { {0x20090089,0x7bcd07f4,0xa3de0053,0x00000000}},	// [870] _inai_, rgau, द्य_,
  { {0x91fc0418,0x661a007a,0x2bcb0161,0x00000000}},	//   klām, _notk, िलहा,
  { {0x7aed07f5,0x9f52006c,0x7bcd005f,0x00000000}},	//   swat, _rayé_, pgau,
  { {0x6608004b,0xa2bd0042,0x6fbf0042,0x00000000}},	//   _andk, _शिल्, ्लिं,
  { {0xd6db07f6,0x9f520003,0xa6c90054,0x00000000}},	//   сте_, _payé_, ілка_,
  { {0x7a200137,0x9aa4005d,0x6499005e,0x00000000}},	//   _sötv, _سمفو, отир_,
  { {0xcd980063,0xf8ae005d,0x661a07f7,0x00000000}},	//   הדות_, _نکن_, _dotk,
  { {0x3e64013d,0x442b07f8,0x6608004d,0x00000000}},	//   lött_, óc_, _endk,
  { {0x661a01c2,0x15f50042,0x26360022,0x00000000}},	//   _fotk, _इसपर_, głos_,
  { {0x80d90086,0x20090089,0x45d406da,0x00000000}},	//   оєму_, _anai_, _поус,
  { {0xb7bd000c,0x764307f9,0x7a200014,0x00000000}},	//   _alţi, miny, _götu,
  { {0x59dd0161,0xa3ae0053,0x764307fa,0x00000000}},	//   न्तर, करण_, liny,
  { {0x9f5f0026,0xdb06006d,0x7a2007fb,0x00000000}},	//   ðuð_, _pekí, _kött,
  { {0x1e830088,0xfce60086,0x3e6400ea,0x00000000}},	//   клям, мого, jött_,
  { {0x91fc001c,0x3e6400ea,0x7a200137,0x00000000}},	//   klāj, dött_, _mött,
  { {0x69c3006d,0x6ab607fc,0x764307fd,0x00000000}},	//   ónen, tsyf, hiny,
  { {0xcb6707fe,0x09ba0021,0x764307ff,0x00000000}},	// [880] дате_, قطاع_, kiny,
  { {0x67220035,0x76430800,0x3e64013d,0x00000000}},	//   vyoj, jiny, gött_,
  { {0x76430801,0x6ab60137,0x661a0802,0x00000000}},	//   diny, ssyf, _rotk,
  { {0xfbb20161,0x2d980803,0x661a0072,0x00000000}},	//   _ज़िम, lcre_, _sotk,
  { {0x76430150,0x661a0804,0x9e65005d,0x00000000}},	//   finy, _potk, _زاین,
  { {0x2486001f,0xceb90080,0x2d980805,0x00000000}},	//   _siom_, áři_, ncre_,
  { {0xf9830806,0x7a200137,0xa5070092,0x00000000}},	//   _агро, _dött, деја_,
  { {0xa803005a,0x7d010807,0xa957009a,0x00000000}},	//   _изсл, ålsi, _חילק_,
  { {0xa01b007a,0x7a200137,0x76430808,0x00000000}},	//   lmög, _fött, biny,
  { {0x7a200809,0x76430150,0x660800a5,0x00000000}},	//   _gött, ciny, _undk,
  { {0x644b0026,0xa01b004d,0xd46a005e,0x00000000}},	//   ðmið, nmög, _диже_,
  { {0x3e64000f,0x5346080a,0xc326080b,0x00000000}},	//   zött_, _охла, _омек,
  { {0x80c00053,0xe1fa014b,0xa2d30044,0x00000000}},	//   _विवे, _мгд_, _لينت,
  { {0x2009002b,0xfc3f004c,0xe24600f2,0x00000000}},	//   _wnai_, _smí_, _تخصي,
  { {0x463b0047,0x7a200244,0x0cd40505,0x00000000}},	//   קעלע, _löts, корю,
  { {0x69de006f,0x764300ac,0x2009002b,0x00000000}},	//   efpe, ziny, _unai_,
  { {0x3e6400ea,0x76430150,0x61f80150,0x00000000}},	// [890] tött_, yiny, _kavl,
  { {0x61f8074f,0x61fa080c,0x9987004c,0x00000000}},	//   _javl, ndtl, ónů_,
  { {0x7a200137,0x91fc001c,0x18a40054,0x00000000}},	//   _rött, elāk, ваєм,
  { {0x2c27019d,0x38c40026,0x7643080d,0x00000000}},	//   _цьог, _sérð_, winy,
  { {0x7643014f,0x78710137,0x91fc008f,0x00000000}},	//   tiny, gåva, glāk,
  { {0xf770006a,0x61f8080e,0x3eb9080f,0x00000000}},	//   جام_, _navl, isst_,
  { {0x9f4e0080,0x76430810,0xa01b0244,0x00000000}},	//   čném_, riny, omöd,
  { {0x764306a7,0x91fc008f,0x2903004b,0x00000000}},	//   siny, blāk, _irja_,
  { {0xa3de0235,0x786a0066,0xd5b10013,0x00000000}},	//   द्ध_, zývk, _hóm_,
  { {0x80c00235,0xaac70082,0x7ac70082,0x00000000}},	//   _विशे, _लिनक, _लिनअ,
  { {0x64450003,0xa87907e9,0xe0460811,0x00000000}},	//   éhis, ּאָר, енни,
  { {0x44f10812,0xdb060024,0xb4fa0063,0x00000000}},	//   _iš_, _leká, _מפעי,
  { {0xd24e006a,0x69d50051,0xd12e007e,0x00000000}},	//   _گنو_, _ocze, لمی_,
  { {0x69c3006d,0x2d980813,0x2d8c06a5,0x00000000}},	//   ónel, ucre_, øde_,
  { {0xdb040814,0x68e20022,0x1d070815,0x00000000}},	//   mbié, łodz, нери_,
  { {0x224500a4,0x3c2e0066,0xd259008f,0x00000000}},	//   lilk_, _býva_, ruņu_,
  { {0x5aca0085,0x2f550085,0xa9a60816,0x00000000}},	// [8a0] ялам_, _атэс, еизд,
  { {0x4a430817,0x224500a4,0xa01b004d,0x00000000}},	//   гнув, nilk_, tmög,
  { {0x4c860818,0x442f06aa,0xd8260330,0x00000000}},	//   _плов, _olg_, нджи,
  { {0x7641001f,0xdc9b0047,0xa01b0649,0x00000000}},	//   _amly, _מיטל, rmög,
  { {0x44f100eb,0x224500a4,0x45d406b4,0x00000000}},	//   _aš_, kilk_, волс,
  { {0xdcfc04ab,0xceb30819,0xd4910013,0x00000000}},	//   ları, ניו_, _bù_,
  { {0xb5a50054,0x64c300de,0x85b700de,0x00000000}},	//   трій, هيول, راوس_,
  { {0x6f040529,0xd4910013,0x7641002b,0x00000000}},	//   _oric, _dù_, _emly,
  { {0x3254005e,0x61f8081a,0x9961008f,0x00000000}},	//   квир, _pavl, _cīņa_,
  { {0x2d8c0024,0x442f069f,0xdb04006c,0x00000000}},	//   ždej_, _elg_, rbiè,
  { {0xdcfc01f7,0x6d49000c,0x3a370063,0x00000000}},	//   karı, şeaz, גרים_,
  { {0x6f04081b,0xf9460085,0x00000000,0x00000000}},	//   _bric, ьнiк_,   ,
  { {0x6d48006d,0xdcfc005b,0x7641002b,0x00000000}},	//   údan, darı, _ymly,
  { {0xbe880076,0x6f04081c,0x68e20022,0x00000000}},	//   ессе_, _dric, łody,
  { {0xf1b30063,0x2d85081d,0x6f04081e,0x00000000}},	//   _עסק_, äle_, _eric,
  { {0x6565004b,0xac18081f,0xb0620072,0x00000000}},	//   ühhi, носу_, ääte,
  { {0xf9c70820,0x628a013d,0x6f0400f1,0x00000000}},	// [8b0] ещен, _kifo, _gric,
  { {0x60c80821,0x78710137,0x201900a8,0x00000000}},	//   ordm, gåvn, ljsi_,
  { {0xa928000d,0xbc790086,0xdcfc0058,0x00000000}},	//   ніце_, _обох_, barı,
  { {0x69d50051,0x628a002b,0x612b013d,0x00000000}},	//   _wcze, _lifo, lölö,
  { {0xe8df001b,0x799c001f,0x80380047,0x00000000}},	//   _thỏa_, _ffrw, ענדע_,
  { {0x69d50051,0xdb0600b9,0xd5b1008b,0x00000000}},	//   _ucze, _bekæ, _tóm_,
  { {0x224500c3,0x442f0822,0xe8df0013,0x00000000}},	//   vilk_, _plg_, _muịc_,
  { {0xd1380051,0x13090156,0xb8e70053,0x00000000}},	//   dzą_, дний_, ों_,
  { {0x5695005a,0x95d9000a,0x628a0823,0x00000000}},	//   _разт, _одат_, _bifo,
  { {0xdcfc005b,0x76410014,0x02020085,0x00000000}},	//   zarı, _umly, азьн,
  { {0x628a0824,0xdcfc005b,0xa2bd0053,0x00000000}},	//   _difo, yarı, _शिक्,
  { {0x7d1a0137,0x5046005e,0x6f040825,0x00000000}},	//   ätsm, темб, _pric,
  { {0x63a90826,0xdcfc005b,0x60c800ca,0x00000000}},	//   mben, varı, ardm,
  { {0x78780827,0x6fa20053,0x63a90828,0x00000000}},	//   míve, _क्रू, lben,
  { {0xdcfc005b,0x63a900c3,0xd1380051,0x00000000}},	//   tarı, oben, czą_,
  { {0x218800b5,0xec16007e,0x31560047,0x00000000}},	//   _אָפּ, خورد, _שיקן_,
  { {0x787803d9,0x27fd0185,0xea8a018e,0x00000000}},	// [8c0] níve, ddwn_, дбал_,
  { {0xdcfc005b,0x26cf007d,0x5ee90063,0x00000000}},	//   sarı, dugo_, _נַפְ,
  { {0xdcfc005b,0x7d010829,0x63a900a5,0x00000000}},	//   parı, ålst, kben,
  { {0xc7c30076,0x63a9007d,0xb6a606da,0x00000000}},	//   асши, jben, видл,
  { {0x63a9082a,0xfaa60092,0x56f30044,0x00000000}},	//   dben, _јаго, لأوز,
  { {0x78780080,0x9f420072,0xd5e30054,0x00000000}},	//   díve, mekä_, ижчи,
  { {0x628a051e,0xdb0f017d,0xd946082b,0x00000000}},	//   _rifo, _recé, _реви,
  { {0xa5070138,0x7c360185,0x63a9082c,0x00000000}},	//   ђења_, nhyr, gben,
  { {0x26dd0051,0x7878017d,0x9f4b0331,0x00000000}},	//   ctwo_, gíve, pecé_,
  { {0x62060086,0x0676082d,0x50f401ce,0x00000000}},	//   тчиз, _рубя, гзот,
  { {0x63a9082e,0x64570331,0x628a00dd,0x00000000}},	//   bben, éxic, _vifo,
  { {0x7878017d,0xd1380051,0x03a602b6,0x00000000}},	//   bíve, rzą_, _ридо,
  { {0xd1380045,0x628a082f,0x787800be,0x00000000}},	//   szą_, _tifo, cíve,
  { {0xa3de0161,0xdd1c004c,0xf425004e,0x00000000}},	//   द्र_, láře, _ääre_,
  { {0x69c8005b,0x7d240131,0x26dd056c,0x00000000}},	//   _ödey, афте, ztwo_,
  { {0xdfd10021,0xe8e00013,0xdb0f003b,0x00000000}},	//   _اية_, ýời_, _decî,
  { {0xba5501ce,0x4a550085,0xe451009a,0x00000000}},	// [8d0] гвај, гкас, צֶל_,
  { {0x63a90830,0xbdf502f8,0x5b340044,0x00000000}},	//   zben, _спој, جعفر,
  { {0x27ef0831,0x9848005b,0x09e40054,0x00000000}},	//   tegn_, _ağı_, роєн,
  { {0xdcb1001b,0xdb060832,0x3e760014,0x00000000}},	//   ẩu_, _bekä, mæta_,
  { {0x7878017d,0x27ef0119,0x27fd00a3,0x00000000}},	//   xíve, regn_, rdwn_,
  { {0x7c2d0833,0xd7740021,0x26cf02f7,0x00000000}},	//   lkar, جامع, rugo_,
  { {0x245a001c,0x26dd0051,0xd4690184,0x00000000}},	//   zīme_, stwo_, нике_,
  { {0x63a90834,0x7c2d0835,0x78780836,0x00000000}},	//   uben, nkar, tíve,
  { {0x63a90837,0x1755000d,0xdb06004d,0x00000000}},	//   rben, _свая, _gekä,
  { {0x7d080838,0x63a90839,0x7878017d,0x00000000}},	//   ådsk, sben, ríve,
  { {0x78780016,0x9f4e0080,0xd5b1008b,0x00000000}},	//   síve, čním_, _nói_,
  { {0xddd50080,0xdb0a0240,0x7c2d083a,0x00000000}},	//   mozř, šnéh, jkar,
  { {0x91e5083b,0x442d083c,0x7c2d083d,0x00000000}},	//   _боле, mke_, dkar,
  { {0xf77600b5,0xdd920067,0x7c2d083e,0x00000000}},	//   טערי_, صور_, ekar,
  { {0x8c7a005a,0x7c2d083f,0x5184005e,0x00000000}},	//   ещат_, fkar, _кућа,
  { {0x7c2d00bb,0x442d0840,0x6449003b,0x00000000}},	//   gkar, nke_, niei,
  { {0x9b930032,0x442d0841,0x69da0058,0x00000000}},	// [8e0] إلكت, ike_, _ötek,
  { {0xe9d70842,0x3e760026,0x7c2d0843,0x00000000}},	//   лку_, bæta_, akar,
  { {0x442d0844,0xd5b10013,0x08c60727,0x00000000}},	//   kke_, _gói_, убен,
  { {0x442d0845,0xdbd700bd,0x3c350137,0x00000000}},	//   jke_, mäßi, _påve_,
  { {0x442d0846,0xd7070121,0xdd1c004c,0x00000000}},	//   dke_, лнце_, váře,
  { {0x442d0847,0x7af6002b,0x38c8005d,0x00000000}},	//   eke_, mwyt, _لاری_,
  { {0x64490185,0x7af6001f,0x54e60021,0x00000000}},	//   fiei, lwyt, استق,
  { {0xd4670001,0x25f00053,0x442d0848,0x00000000}},	//   лије_, _इसकी_, gke_,
  { {0x7af6001f,0xa6ca007e,0x91fc001c,0x00000000}},	//   nwyt, _سوال_, klāt,
  { {0xe29f007a,0xd6cf01a7,0x38660849,0x00000000}},	//   íða_, _رقم_, loor_,
  { {0xf5930032,0xddce0078,0x20d3000d,0x00000000}},	//   _المج, albū, біўс,
  { {0x38660186,0x557700b5,0xe29a026b,0x00000000}},	//   noor_, _געבן_, _зад_,
  { {0x80c00053,0x6d5a006c,0x6e95084a,0x00000000}},	//   _विके, ûtan, ригу,
  { {0x38660438,0x764a002b,0x6e940121,0x00000000}},	//   hoor_, nify, сиру,
  { {0x7c2d003d,0x16d10161,0x28c90042,0x00000000}},	//   tkar, _सम्ब, ांछि,
  { {0x3866006f,0x7c2d084b,0xd175000d,0x00000000}},	//   joor_, ukar, _тычы,
  { {0x7c2d084c,0x38660625,0xc3340063,0x00000000}},	// [8f0] rkar, door_, בוּ_,
  { {0x7f3c00b7,0x442d084d,0x386600ca,0x00000000}},	//   _רעזו, zke_, eoor_,
  { {0x442d084e,0x2907084f,0x6449002b,0x00000000}},	//   yke_, ína_, yiei,
  { {0x38660850,0x80d70047,0x00000000,0x00000000}},	//   goor_, רואװ_,   ,
  { {0x76ab0138,0x6f1b00bd,0x442d0851,0x00000000}},	//   хтев_, äuch, vke_,
  { {0x19940086,0xa3e70053,0xa5940062,0x00000000}},	//   _гаря, म्न_, бръщ,
  { {0x3d080053,0x84590852,0x442d0648,0x00000000}},	//   हिये_, крит_, tke_,
  { {0xdd1d0024,0x6a6b00bd,0x91fc001c,0x00000000}},	//   ráňt, rüfu, klās,
  { {0x442d0853,0x42550854,0x7cec013d,0x00000000}},	//   rke_, итот, _körö,
  { {0x27ff00fe,0x442d0855,0x3eb2002b,0x00000000}},	//   _haun_, ske_, _rwyt_,
  { {0x787807a8,0x442d0008,0x30760002,0x00000000}},	//   líva, pke_, иумс,
  { {0xdb0f017d,0x649a07e9,0x6495005f,0x00000000}},	//   _mecâ, _סינה, _ašig,
  { {0x92b70021,0x02a70856,0xdb16006c,0x00000000}},	//   _إحصا, _срем, payé,
  { {0xed5a0138,0x3cfa0857,0xdb0f0858,0x00000000}},	//   вог_, _pspv_, _cecí,
  { {0xdb0f02dd,0x32f60022,0x629b00ca,0x00000000}},	//   _decí, _zły_, lquo,
  { {0xbb76005a,0x63bb0859,0x7c3a008f,0x00000000}},	//   аузъ, naun, ītro,
  { {0x38660122,0x4a4601e8,0x199602d8,0x00000000}},	// [900] voor_, анав, ајер,
  { {0x78780080,0x7af6001f,0xdebb0063,0x00000000}},	//   díva, rwyt, _שמיל,
  { {0x386600ac,0xf1dd0053,0x91fc001c,0x00000000}},	//   toor_, _मानन, olār,
  { {0x63bb003d,0xdb0f0529,0xa9670330,0x00000000}},	//   jaun, _decâ, шиха_,
  { {0x386600e8,0x27ff003e,0x8f9b0063,0x00000000}},	//   roor_, _daun_, דיני,
  { {0x7cec00ea,0xddc7085a,0x3866085b,0x00000000}},	//   _görö, oljš, soor_,
  { {0xa3e70053,0x764a085c,0x38660524,0x00000000}},	//   म्भ_, rify, poor_,
  { {0x63bb085d,0x27ff0360,0x8ba9009a,0x00000000}},	//   gaun, _gaun_, ְׁתִ,
  { {0xd3770121,0x46a3085e,0xd6cf0044,0x00000000}},	//   ичь_, _матв, _يقف_,
  { {0x27ff004d,0x2258004b,0xa01b0046,0x00000000}},	//   _zaun_, õrk_, gmön,
  { {0xd1300021,0xdb0f07a8,0x73c6005d,0x00000000}},	//   سمح_, _recí, _نيام,
  { {0x27e60185,0x9202001c,0x2000003b,0x00000000}},	//   nfon_, _šāda, _caii_,
  { {0x20050080,0xa8570063,0x629b006c,0x00000000}},	//   ěli_, שיכה_, cquo,
  { {0x20050045,0x7a320146,0x290a085f,0x00000000}},	//   śli_, _sætn, _orba_,
  { {0x2ca500ac,0xcd040121,0x41270002,0x00000000}},	//   ëld_, очти, _војо_,
  { {0x7055006a,0x69dc0860,0xec340086,0x00000000}},	//   _دنبا, _acre, онсь,
  { {0x290a0812,0x207c0047,0x5a35065b,0x00000000}},	// [910] _arba_, _באהא, бнат,
  { {0xe9190054,0x27ff004b,0x7a380861,0x00000000}},	//   лозі_, _saun_, апур_,
  { {0x7cec00ea,0x27e60862,0xa3e70042,0x00000000}},	//   _vörö, ffon_, म्ड_,
  { {0x78780863,0xb7bd00dd,0xb8ef0042,0x00000000}},	//   tíva, _boţa, _शि_,
  { {0x7cec000f,0x290a0290,0x3c350137,0x00000000}},	//   _törö, _erba_, _gåva_,
  { {0x248f0150,0x69dc0139,0x63a20864,0x00000000}},	//   _sigm_, _gcre, _afon,
  { {0x44f8008b,0xe8020053,0x290a0734,0x00000000}},	//   _cũ_, _रोका_, _grba_,
  { {0xed580063,0xd64d000d,0x6d480025,0x00000000}},	//   יבור_, _лiпе, údai,
  { {0xdb060865,0x63bb0866,0x86980867,0x00000000}},	//   _sekú, raun, _вкус_,
  { {0xe4e7019d,0x629b0164,0xb06300fe,0x00000000}},	//   _відн, rquo, äänt,
  { {0x63a2001f,0x63bb00a4,0x9f5e0080,0x00000000}},	//   _ffon, paun, ětí_,
  { {0x44e103ad,0xaac70053,0x66010868,0x00000000}},	//   mó_, _लिंक, _halk,
  { {0x69c70869,0x44e1086a,0x6601086b,0x00000000}},	//   _odje, ló_, _kalk,
  { {0x660100fe,0xf6790047,0x6da3086c,0x00000000}},	//   _jalk, טאָמ, зира,
  { {0x44e1086d,0x6601086e,0x2d8c086f,0x00000000}},	//   nó_, _malk, äde_,
  { {0x69dc0870,0xdb0a0080,0x44e10871,0x00000000}},	//   _scre, šníh, ió_,
  { {0x63b90185,0x290a017f,0x62990150,0x00000000}},	// [920] _mewn, _srba_, _juwo,
  { {0xbf9b03d9,0x386d0872,0x49960330,0x00000000}},	//   ndên, _aker_, сшат,
  { {0x31ba00b5,0x44e10873,0x497a000d,0x00000000}},	//   רזענ, jó_, усаў_,
  { {0xe73a0055,0x387f0027,0xf3f9003b,0x00000000}},	//   лее_, _chur_, boţi_,
  { {0x27e6001f,0xa01b004b,0x66010874,0x00000000}},	//   rfon_, dmöl, _balk,
  { {0x63a2051e,0x7ae40875,0xceb3009f,0x00000000}},	//   _sfon, mtit, ליד_,
  { {0x44e10876,0x96c40053,0x26cf0877,0x00000000}},	//   gó_, _रिकॉ, argo_,
  { {0x44f8001b,0xd5b10013,0x39570063,0x00000000}},	//   _vũ_, _sót_, _השלם_,
  { {0x32660878,0x8c1b0063,0x8506007e,0x00000000}},	//   йтов, רופי, _گوان,
  { {0x11d80032,0x3e7f0164,0x44e10879,0x00000000}},	//   جودة_, oîte_, bó_,
  { {0x04960032,0x44e102dd,0x71740032,0x00000000}},	//   _الصح, có_, تهدا,
  { {0x7c26087a,0x6e25005b,0xbfab0121,0x00000000}},	//   _nokr, _sohb, ытое_,
  { {0x447b00b7,0x7878013d,0x1fa40085,0x00000000}},	//   _ענדע, hívo, ярэг,
  { {0xbc95000a,0x63b90045,0x39dd0053,0x00000000}},	//   жавј, _zewn, न्फ़ि,
  { {0x90a60242,0x7c26087b,0x7ae4087c,0x00000000}},	//   _احتم, _bokr, etit,
  { {0x98c5001c,0x7d03013d,0x7a20087d,0x00000000}},	//   ūtīt_, eírá, _götz,
  { {0x44e1000f,0x78780024,0x2fc901b9,0x00000000}},	// [930] zó_, tívn, _idag_,
  { {0x44e102dd,0x98b8005b,0x386d087e,0x00000000}},	//   yó_, _ayrı_, _sker_,
  { {0xda780257,0x291e01a8,0x442604f9,0x00000000}},	//   сят_, _àtal_, _ooo_,
  { {0x44e102dd,0x6f0d087f,0x78780195,0x00000000}},	//   vó_, _krac, sívn,
  { {0xfaff001c,0x7d030880,0x66010881,0x00000000}},	//   šību_, bírá, _palk,
  { {0x44e10882,0xd12601a7,0x69c70883,0x00000000}},	//   tó_, _قم_, _udje,
  { {0x63b90045,0xe3b10032,0x66010884,0x00000000}},	//   _pewn, ورة_, _valk,
  { {0x386d0031,0x44e10885,0x66010886,0x00000000}},	//   _uker_, ró_, _walk,
  { {0x44e10885,0x66010887,0xe299005e,0x00000000}},	//   só_, _talk, јао_,
  { {0x63b90051,0x44e1006d,0x60e90888,0x00000000}},	//   _wewn, pó_, амом_,
  { {0x6f0d01f7,0xfbdf0016,0x3ea9003b,0x00000000}},	//   _arac, _ocê_, _atat_,
  { {0x7ae40889,0xa01b0137,0x44c5001c,0x00000000}},	//   ytit, lmöj, mē_,
  { {0x44c5001c,0x6da60121,0x6f0d088a,0x00000000}},	//   lē_, жига, _crac,
  { {0x44260625,0x7c26088b,0x6f0d088c,0x00000000}},	//   _zoo_, _sokr, _drac,
  { {0x27ed00bd,0x44c5001c,0xafdb01f2,0x00000000}},	//   _oben_, nē_, giøs,
  { {0x6a7000bd,0xeb970076,0x7ae4088d,0x00000000}},	//   häft, жит_, ttit,
  { {0x3b07026b,0xdb04017d,0x3a26088e,0x00000000}},	// [940] оето_, ibiç, омаг,
  { {0x32050034,0x7878088f,0x7ae40890,0x00000000}},	//   ndly_, tívo, rtit,
  { {0xd23a0047,0xdb1d00b9,0x7c260891,0x00000000}},	//   סגעל, _ndsæ, _tokr,
  { {0x44c5001c,0x7d03013d,0x7ae40892,0x00000000}},	//   dē_, sírá, ptit,
  { {0xc7a30893,0x7d03004c,0xfaa60894,0x00000000}},	//   фичк, pírá, _фаго,
  { {0xe4a6000a,0x3af900b5,0x27ed00bd,0x00000000}},	//   орио, _פּרע, _eben_,
  { {0xc7a60062,0xd4970895,0xc8b50085,0x00000000}},	//   _мивк, оры_, _нсты,
  { {0xe4660058,0x320500e5,0xf2c60896,0x00000000}},	//   _önüş, edly_, осон,
  { {0x83fd00ea,0x69da005b,0x442600be,0x00000000}},	//   rlőp, _ötes, _voo_,
  { {0x26c00078,0x44260897,0xc5160044,0x00000000}},	//   šios_, _woo_, _وبات,
  { {0x4a7b00b5,0x64950080,0x44260898,0x00000000}},	//   שריב, _všic, _too_,
  { {0x320500e5,0x40340121,0x6f0d07f7,0x00000000}},	//   adly_, деюс, _prac,
  { {0xe67b008b,0x3d950899,0x9ed8089a,0x00000000}},	//   _hưở, зигр, омят_,
  { {0xdef80088,0x6f0d089b,0x68e500a3,0x00000000}},	//   цыю_, _vrac, ythd,
  { {0x6ce4019d,0xbc4b000d,0x6288004b,0x00000000}},	//   міте, ачае_, mmdo,
  { {0x6f0d089c,0xafdb0093,0x26110053,0x00000000}},	//   _trac, riøs, _धोनी_,
  { {0x44c5001c,0x97ea005b,0x5a3502b6,0x00000000}},	// [950] zē_, ışlı, пнат,
  { {0x78a300ea,0xf8b1007e,0xda78089d,0x00000000}},	//   ínvo, فکر_, оях_,
  { {0x57f50062,0x6e210244,0x00000000,0x00000000}},	//   зпет, ölbu,   ,
  { {0x68e504bf,0x44c5008f,0x9cd60063,0x00000000}},	//   rthd, vē_, _צורה_,
  { {0xafdb00b9,0x8c1a089e,0x8bc40085,0x00000000}},	//   chøe, _הורי, _ўсюд,
  { {0xafdb0031,0x1efc0047,0x44c5008f,0x00000000}},	//   rnøy, ילדע, tē_,
  { {0x6a70089f,0xafdb00d1,0x7af90058,0x00000000}},	//   räft, snøy, şatı,
  { {0x57f4018e,0xa01b0137,0x44c5001c,0x00000000}},	//   _опст, smöj, rē_,
  { {0xf7490032,0xe3b1007e,0x44c5001c,0x00000000}},	//   _الذي_, ورک_, sē_,
  { {0x3637006a,0x44c5001c,0xd5b10013,0x00000000}},	//   _بررس, pē_, _góp_,
  { {0x216908a0,0x32050034,0xdb1d00b9,0x00000000}},	//   сини_, rdly_, _udsæ,
  { {0x29360047,0x644b051c,0x3ea401c8,0x00000000}},	//   פארן_, _umgi, ímto_,
  { {0x20040024,0xf3f900dd,0x3e760014,0x00000000}},	//   ľmi_, meţ_, læti_,
  { {0xf3f9003b,0x200408a1,0x645b004e,0x00000000}},	//   leţ_, žmi_, lnui,
  { {0xc692014e,0xafdb0093,0x91ba0063,0x00000000}},	//   תאם_, riør, _המצי,
  { {0xc0a80021,0x01340049,0x7aa60121,0x00000000}},	//   _باول_, _تعهد, зиаз,
  { {0x9983004c,0x9205008f,0xf093009a,0x00000000}},	// [960] _bojů_, apāņ, _אנה_,
  { {0xb4bb0053,0x97ea0058,0x499a066e,0x00000000}},	//   _अबू_, ışmı, стая_,
  { {0x7d0100b9,0xd7ef08a2,0x9e650044,0x00000000}},	//   ælst, ну_, _تاين,
  { {0xdb040122,0xfc320032,0x7a320014,0x00000000}},	//   ncië, _أحد_, _mæti,
  { {0xfbd3014e,0x7c360137,0xf3f9003b,0x00000000}},	//   _אתר_, mkyr, deţ_,
  { {0xe8df001b,0xdb0f017d,0xd6a9007e,0x00000000}},	//   _giữa_, _secç, زدهم_,
  { {0x4dfb0041,0x9f42017c,0x9abe0085,0x00000000}},	//   מפסא, veký_, вiча_,
  { {0xe73a06da,0x7c2408a3,0x7c3601e9,0x00000000}},	//   _леб_, njir, nkyr,
  { {0xdb0600ea,0xf7430896,0x75960044,0x00000000}},	//   _nekü, _зето, _فجاء,
  { {0x7a320026,0x443f08a4,0x645b006f,0x00000000}},	//   _bæti, ahu_, anui,
  { {0x26190053,0x443f08a5,0xf1dd0053,0x00000000}},	//   पारी_, bhu_, _मारन,
  { {0xc48608a6,0xdb0600ea,0x73e6000d,0x00000000}},	//   _элек, _bekü, _ходз,
  { {0x7a3200b9,0xee870121,0xbf340330,0x00000000}},	//   _tæth, зыво, енящ,
  { {0x13170063,0xf0b7007e,0x6ca708a7,0x00000000}},	//   _מחדל_, _کاوش_, зраж,
  { {0x7a32007a,0xc27b0063,0xe9ff008b,0x00000000}},	//   _gæti, _הרגי, _ngạc_,
  { {0x415b014e,0x31c60080,0x2d580086,0x00000000}},	//   _לדוג, bízí_, чись_,
  { {0xdb040164,0xdb06004d,0xdb0d0003,0x00000000}},	// [970] nciè, _gekü, rbaï,
  { {0x61fa0436,0xe29f0014,0x79a408a8,0x00000000}},	//   netl, íði_, ерце,
  { {0x24890024,0x60da005b,0x6ca402fa,0x00000000}},	//   ňami_, nutm, _пряж,
  { {0xf770006a,0x61fa08a9,0xf775071f,0x00000000}},	//   گام_, hetl, мулю,
  { {0x61fa01f7,0x64400025,0x7c3a0003,0x00000000}},	//   ketl, dhmi, être,
  { {0x61fa017f,0xf3f9003b,0xf77008aa,0x00000000}},	//   jetl, inţe_, دام_,
  { {0x443f08ab,0x91b3008d,0xf3f900dd,0x00000000}},	//   thu_, _đèn_, teţ_,
  { {0xc9520063,0x52a908ac,0xd2a905f4,0x00000000}},	//   _סמן_, овим_, окие_,
  { {0x13060076,0xf3f9003b,0xa3df0053,0x00000000}},	//   дный_, reţ_, तलब_,
  { {0x68e100c7,0x6440005b,0x645b08ad,0x00000000}},	//   _älds, ahmi, snui,
  { {0x95c4007e,0xf3f9003b,0xdb0401a8,0x00000000}},	//   _سينه, enţe_, aciè,
  { {0xcdc9014e,0x78a900c2,0x644008ae,0x00000000}},	//   _כך_, _čevl, chmi,
  { {0xdb040122,0x4374018e,0x61fa08af,0x00000000}},	//   rcië, _пушт, betl,
  { {0x291101f4,0xa2940054,0x0caa0044,0x00000000}},	//   _orza_, _зачі, قطري_,
  { {0xf3f9003b,0x1d0708b0,0xebe60054,0x00000000}},	//   anţe_, мери_, мовп,
  { {0x6e210014,0x00000000,0x00000000,0x00000000}},	//   ölbr,   ,   ,
  { {0x29030019,0x7c240089,0xfaff001c,0x00000000}},	// [980] _asja_, rjir, šīnu_,
  { {0x6f0400ac,0x7c3608b1,0x2911007d,0x00000000}},	//   _isic, skyr, _brza_,
  { {0x32070037,0xac860086,0x3ea00164,0x00000000}},	//   _many_, _огол, _huit_,
  { {0x68e300cd,0x999a0078,0x648500be,0x00000000}},	//   ànda, tipų_, nóid,
  { {0x61fa0779,0x46a3000d,0x87030200,0x00000000}},	//   yetl, вачв, вяще,
  { {0x443d001f,0x26c6004b,0x28db0042,0x00000000}},	//   _alw_, rsoo_, मूहि,
  { {0x5e5700b5,0xe0c7007e,0x3ea008b2,0x00000000}},	//   ויסע_, _جز_, _luit_,
  { {0x61fa08b3,0x47d30021,0xdb040331,0x00000000}},	//   wetl, _ليفر, ecié,
  { {0x3ea00164,0x68e100c7,0x61fa00ea,0x00000000}},	//   _nuit_, _äldr, tetl,
  { {0x443d001f,0xdb040003,0xa6830141,0x00000000}},	//   _elw_, rciè, _алуд,
  { {0x60da0019,0x61fa08b4,0x320708b5,0x00000000}},	//   uutm, retl, _dany_,
  { {0x68e100c7,0x3ea008b6,0xf9930063,0x00000000}},	//   _ålde, _buit_, כרת_,
  { {0x3ead00f5,0xc7b30063,0x69ce08b7,0x00000000}},	//   ëet_, כבר_, _odbe,
  { {0x3ea008b8,0x799c002b,0x52130085,0x00000000}},	//   _duit_, _ngrw, _адшт,
  { {0xd308001b,0x6e9408b9,0x64850139,0x00000000}},	//   _hệ_, тиру, bóid,
  { {0x3ea00003,0xd3080013,0x1bbb0021,0x00000000}},	//   _fuit_, _kệ_, تاسع_,
  { {0x661a0250,0x629800ea,0x7a320026,0x00000000}},	// [990] _ontk, _kivo, _lætu,
  { {0x20090229,0xdcfc0075,0x660808ba,0x00000000}},	//   _haai_, abrı, _nadk,
  { {0xd308001b,0xb86b0002,0x7a320014,0x00000000}},	//   _lệ_, ојде_, _nætu,
  { {0xa2cf0161,0xec350047,0x31570047,0x00000000}},	//   _दिल्, _נאָר_, ויבן_,
  { {0xd7580044,0x386f0023,0xe7240044,0x00000000}},	//   وجها_, rogr_, َّمَ,
  { {0x2009021f,0xdb1d0024,0x629801b3,0x00000000}},	//   _laai_, _odsú, _nivo,
  { {0x67d50001,0x69c508bb,0x32070022,0x00000000}},	//   _пову, mahe, _rany_,
  { {0x69c50019,0x2ca10089,0xdcb1008b,0x00000000}},	//   lahe, _muhd_, ẩy_,
  { {0xb7bd003b,0x2fc001a8,0x629808bc,0x00000000}},	//   _noţi, _reig_, _bivo,
  { {0x64950006,0x7a320014,0x69c508bd,0x00000000}},	//   _išim, _fætu, nahe,
  { {0x3ea004bc,0x7a320026,0x2009006f,0x00000000}},	//   _suit_, _gætu, _baai_,
  { {0x7a32007a,0x78780240,0xd00a0002,0x00000000}},	//   _hætt, tívi, чеме_,
  { {0x648508be,0x2fc000cd,0x200900ac,0x00000000}},	//   róid, _veig_, _daai_,
  { {0xe29f007a,0x3ea000cd,0x64850025,0x00000000}},	//   íðu_, _vuit_, sóid,
  { {0x75f3005b,0x7a3208bf,0x69c508c0,0x00000000}},	//   mızı, _mætt, dahe,
  { {0x98a70080,0x6f040025,0x629808c1,0x00000000}},	//   šně_, _tsic, _zivo,
  { {0xfc3f0025,0x6f040035,0xada608c2,0x00000000}},	// [9a0] _dlí_, _usic, _папл,
  { {0x75f301f7,0x19b90088,0x69c508c3,0x00000000}},	//   nızı, дуць_, gahe,
  { {0xa3df016a,0xba3b00cd,0x27fd001f,0x00000000}},	//   तला_, _suïc, fewn_,
  { {0xe7860086,0xc18c0047,0x248d08c4,0x00000000}},	//   нуло, קטאָ, jmem_,
  { {0x7a3208c5,0x660800ac,0x63a908c6,0x00000000}},	//   _bætt, _padk, dcen,
  { {0x69ce0146,0x63a908c7,0x672d0072,0x00000000}},	//   _udbe, ecen, äaja,
  { {0x6298051e,0xa5070131,0x00000000,0x00000000}},	//   _rivo, ееја_,   ,
  { {0x63a900b9,0x55030121,0xdb0401a8,0x00000000}},	//   gcen, учша, nciï,
  { {0xa01b007a,0x200900ac,0xdb080003,0x00000000}},	//   llög, _raai_, élèv,
  { {0x24860037,0x63a908c8,0xd308001b,0x00000000}},	//   _whom_, acen, _vệ_,
  { {0xb7bd000c,0x629808c9,0xa01b0014,0x00000000}},	//   _soţi, _vivo, nlög,
  { {0x44cc0080,0xd308008b,0x63a908ca,0x00000000}},	//   mě_, _tệ_, ccen,
  { {0x629808cb,0x84570041,0x00000000,0x00000000}},	//   _tivo, _אבאס_,   ,
  { {0x61460164,0xfc3f0025,0x200900ac,0x00000000}},	//   _célé, _slí_, _waai_,
  { {0x44cc0080,0x69c50004,0x61460164,0x00000000}},	//   ně_, vahe, _délé,
  { {0x9f52006d,0x8aa70076,0x69c500a4,0x00000000}},	//   _cayó_, ержд, wahe,
  { {0x657a001f,0x69c508cc,0x3e760046,0x00000000}},	// [9b0] _lyth, tahe, tætt_,
  { {0xbbeb007e,0xf3f9003b,0x248d0051,0x00000000}},	//   _کردم_, inţa_, zmem_,
  { {0xe61f001b,0xa01b0137,0x7878013d,0x00000000}},	//   _đô_, rlöf, hívu,
  { {0x44cc0080,0x7a320146,0xd759002a,0x00000000}},	//   dě_, _sætt, ولات_,
  { {0x657a0137,0x245a008f,0xd763005d,0x00000000}},	//   _ayth, nīmu_, دنشی,
  { {0x64950114,0x657a001f,0xc8f50094,0x00000000}},	//   _všim, _byth, _изгъ,
  { {0xf3f9000c,0x63a908cd,0x7aed08ce,0x00000000}},	//   enţa_, tcen, ltat,
  { {0x657e0058,0x612a0058,0x6d5808cf,0x00000000}},	//   üpha, zölç, _žvak,
  { {0x4864005a,0x7a3205b9,0x1422000d,0x00000000}},	//   _сърб, _tætt, рдым,
  { {0x25ac08d0,0x44cc0080,0xdb080003,0x00000000}},	//   _gfdl_, bě_, élév,
  { {0x63a908d1,0x387d001f,0xf3f9003b,0x00000000}},	//   pcen, olwr_, anţa_,
  { {0x321c08d2,0x6146006c,0x7aed08d3,0x00000000}},	//   _envy_, _sélé, ktat,
  { {0xe28e08d4,0x387d002b,0x7aed013d,0x00000000}},	//   _ва_, ilwr_, jtat,
  { {0x7aed08d5,0x2d9e00d1,0xc0a8007e,0x00000000}},	//   dtat, øte_, بایل_,
  { {0x7aed06c6,0xa01b0137,0x442f007d,0x00000000}},	//   etat, flöd, _kog_,
  { {0x442f08d6,0xb06300fe,0xe8df0013,0x00000000}},	//   _jog_, äätt, _nhựa_,
  { {0x614603b2,0x7aed00bb,0x442f017f,0x00000000}},	// [9c0] _télé, gtat, _mog_,
  { {0x4a4308d7,0x442f08d8,0x7878013d,0x00000000}},	//   анув, _log_, hívt,
  { {0x4dd900b5,0x442f016d,0x2dd90047,0x00000000}},	//   _אַרױ, _oog_, _אַרב,
  { {0x44cc0080,0x657a0003,0xa01b0014,0x00000000}},	//   vě_, _ryth, rlög,
  { {0x7aed08d9,0x657a002b,0xb6060062,0x00000000}},	//   ctat, _syth, вяйк,
  { {0x44cc0080,0x98a7000c,0xdb0600ea,0x00000000}},	//   tě_, ână_, _bekö,
  { {0xe976007e,0x0466005e,0x442f08da,0x00000000}},	//   _شهرد, ктим, _bog_,
  { {0x2465001c,0xd467005e,0x764108db,0x00000000}},	//   tēma_, кије_, _elly,
  { {0x657a0185,0xa01b0026,0x442f08dc,0x00000000}},	//   _wyth, kmör, _dog_,
  { {0x44cc004c,0x442f002b,0x00000000,0x00000000}},	//   pě_, _eog_,   ,
  { {0x7aed03e8,0x320a0024,0x442f000f,0x00000000}},	//   ztat, ľby_, _fog_,
  { {0x76580009,0xe5370047,0x320a0114,0x00000000}},	//   livy, _שטאט_, žby_,
  { {0x76410072,0x6d5a0066,0x2d8c004c,0x00000000}},	//   _ylly, útan, ýden_,
  { {0x442f00bd,0x7c2f08dd,0x6f1608de,0x00000000}},	//   _zog_, _socr, _dryc,
  { {0xbca50032,0xe29b0063,0x9f5901a8,0x00000000}},	//   امري, _קשור, mesí_,
  { {0x7aed08df,0x76580035,0xbf670021,0x00000000}},	//   ttat, hivy, _لدخو,
  { {0x4c9407b0,0x7aed08e0,0x5b150085,0x00000000}},	// [9d0] ритс, utat, ымат,
  { {0x7aed08e1,0x201e001c,0x27140013,0x00000000}},	//   rtat, ētie_, _ình_,
  { {0x7aed08e2,0x39a40817,0xda7803d6,0x00000000}},	//   stat, ршув, тят_,
  { {0x7aed08e3,0xdd3a0063,0x87d40085,0x00000000}},	//   ptat, _נערכ, аўшч,
  { {0x1635005a,0x442f000c,0xd7ee0021,0x00000000}},	//   ледя, _rog_, سكو_,
  { {0x6442024a,0x6d580006,0x442f00bd,0x00000000}},	//   _aloi, _žvai, _sog_,
  { {0x7878034d,0x56920001,0xb7bd003b,0x00000000}},	//   tívt, љајт, _soţu,
  { {0x13090619,0x84580076,0x644208e4,0x00000000}},	//   ений_, крыт_, _cloi,
  { {0x628a0027,0x97ea01f7,0x26cd007d,0x00000000}},	//   _bhfo, ıştı, _uveo_,
  { {0x64420050,0x442f0244,0x422508e5,0x00000000}},	//   _eloi, _wog_, удов,
  { {0xe4e40086,0xf3f5007e,0x442f08e6,0x00000000}},	//   _вічн, _متشک, _tog_,
  { {0x64420164,0x61380025,0xab5b00ca,0x00000000}},	//   _gloi, _súlú, _reün,
  { {0x63bb08e7,0xa3e80053,0x60da0170,0x00000000}},	//   mbun, _बात_, artm,
  { {0xb0630019,0xa2d80053,0x63bb08e8,0x00000000}},	//   äärt, _मित्, lbun,
  { {0xdb1d0080,0xa01b08e9,0x63bb0130,0x00000000}},	//   _desí, rmör, obun,
  { {0x6e3c08ea,0x6f1608eb,0x4095000d,0x00000000}},	//   skrb, _tryc, _крыт,
  { {0x63bb00bd,0x6f160080,0xc0530063,0x00000000}},	// [9e0] ibun, _uryc, _לזה_,
  { {0x200208ec,0x996c008f,0xde060131,0x00000000}},	//   leki_, _vēža_, _спои,
  { {0xafdb00b9,0x291e08ed,0x9c66005d,0x00000000}},	//   dhøj, _štab_, _مهدو,
  { {0x46a6000d,0xdb1d004c,0x200208ee,0x00000000}},	//   гадв, _zesí, neki_,
  { {0x601b0072,0x6d69003b,0x29070014,0x00000000}},	//   _hämä, ăpaţ, ænar_,
  { {0x63bb00bd,0x64420025,0xa5f808ef,0x00000000}},	//   ebun, _sloi, теку_,
  { {0xa3e80161,0x7bc608f0,0xbf9b00ac,0x00000000}},	//   _बाद_, _keku, ndêr,
  { {0x20020150,0x765808f1,0x63bb08f2,0x00000000}},	//   jeki_, sivy, gbun,
  { {0x3855011c,0xc1ea0088,0x200201f7,0x00000000}},	//   _търс, ньне_, deki_,
  { {0x64a60086,0x27e60137,0x7bc60150,0x00000000}},	//   _бажа, lgon_, _leku,
  { {0xdb1d017d,0x601b0072,0x27e608f3,0x00000000}},	//   _resí, _nämä, ogon_,
  { {0xa3bb016a,0x27e608f4,0x648508f5,0x00000000}},	//   _अभय_, ngon_, lóin,
  { {0xa857014e,0x27e6002b,0x73360044,0x00000000}},	//   ריכה_, igon_, _حرائ,
  { {0xdb1d017d,0x539b009f,0xa19401fc,0x00000000}},	//   _lesã, _ניגו, _калч,
  { {0xdd950088,0xe7a40161,0x523b0047,0x00000000}},	//   равы, _ओलंप, _אײגנ,
  { {0x200201f7,0x7bc60150,0x5b2708f6,0x00000000}},	//   ceki_, _ceku, льза,
  { {0xba550095,0x63a205b3,0xadd5005e,0x00000000}},	// [9f0] авај, _mgon, _копљ,
  { {0x27e6006f,0x63bb003b,0xa01b004d,0x00000000}},	//   egon_, zbun, blöc,
  { {0x3eb9001c,0x64850405,0x63bb0051,0x00000000}},	//   lpst_, dóin, ybun,
  { {0x64b1003d,0x63a202ae,0x27e9004b,0x00000000}},	//   _jāie, _ngon, üan_,
  { {0x291800e3,0x67d4000a,0x7c2b0019,0x00000000}},	//   _erra_, сочу, ögru,
  { {0x200208f7,0xbada0063,0x64850025,0x00000000}},	//   zeki_, _בקשת, góin,
  { {0xce38014e,0xafdb00b9,0x91f5008b,0x00000000}},	//   ראות_, rhøj, híc,
  { {0x7c2d08f8,0x63a20139,0xd3f9000d,0x00000000}},	//   njar, _cgon, тэкі_,
  { {0x63bb08f9,0x200200ac,0x69c70052,0x00000000}},	//   rbun, veki_, _keje,
  { {0x63bb08fa,0xdb0408fb,0x994a0058,0x00000000}},	//   sbun, nciá, nışa_,
  { {0xd567000a,0xafdb0146,0x10210053,0x00000000}},	//   _стап, dkøb, यांश_,
  { {0xdd2f0080,0x7afd08fc,0x84640062,0x00000000}},	//   _běže, _opst, _лъче,
  { {0x387e03b2,0x644908fd,0x343a0047,0x00000000}},	//   _être_, mhei, _שײנע,
  { {0x442d08fe,0x644908ff,0x7bc60900,0x00000000}},	//   lje_, lhei, _seku,
  { {0x7afd003d,0x31790047,0x27e6001f,0x00000000}},	//   _apst, _באַד, ygon_,
  { {0xef1a06be,0x442d0901,0x443f0902,0x00000000}},	//   _ами_, nje_, nku_,
  { {0x69c7000f,0x442d017f,0x207b0047,0x00000000}},	// [a00] _beje, ije_, _באקא,
  { {0x601b024a,0x628100cd,0x6f09005b,0x00000000}},	//   _tämä, nllo, çece,
  { {0x443f0004,0x6449021f,0x442d0903,0x00000000}},	//   kku_, khei, kje_,
  { {0x1ae60055,0x64490122,0x27e600a4,0x00000000}},	//   _комм, jhei, ugon_,
  { {0x69c700ea,0x442d0904,0x648500ea,0x00000000}},	//   _feje, dje_, tóin,
  { {0x442d0051,0xaa460905,0x443f0368,0x00000000}},	//   eje_, _тегл, eku_,
  { {0x44f1001b,0x7ae40906,0x442d0907,0x00000000}},	//   _cơ_, luit, fje_,
  { {0x64490102,0x62810908,0x443f0909,0x00000000}},	//   ghei, ello, gku_,
  { {0x23380055,0xdc370047,0x7794007e,0x00000000}},	//   уппы_, שאפט_, _ایشا,
  { {0x442d090a,0x443f090b,0x11d80021,0x00000000}},	//   aje_, aku_, دودة_,
  { {0x8506006a,0x442d00c3,0x7ae40025,0x00000000}},	//   _خوان, bje_, huit,
  { {0x442d0045,0x68e300cd,0x63a2090c,0x00000000}},	//   cje_, àndi, _ugon,
  { {0xfe7f090d,0x11f8007e,0x6d4e00dd,0x00000000}},	//   juïc_, _موشک_, ezba,
  { {0x7ae4090e,0x30a6090f,0x66fa008f,0x00000000}},	//   duit, _крив, mākā,
  { {0x69c70910,0x7c2d0911,0xc0e30141,0x00000000}},	//   _reje, tjar, _дојк,
  { {0xe5170161,0x69c70912,0x64400760,0x00000000}},	//   थिति_, _seje, nkmi,
  { {0x7ae40913,0x228b0031,0xdb0f0857,0x00000000}},	// [a10] guit, søke_, _recó,
  { {0x443f0114,0x6f0d01f4,0x7c2d0914,0x00000000}},	//   zku_, _isac, sjar,
  { {0x442d0915,0x69c70916,0x64490917,0x00000000}},	//   yje_, _veje, yhei,
  { {0x7ae40918,0x3ea9053b,0x38660314,0x00000000}},	//   buit, _kuat_, gnor_,
  { {0x3b64005a,0x442d00c3,0x44f1001b,0x00000000}},	//   _дърв, vje_, _sơ_,
  { {0x3ea90089,0x2fc90139,0x85e80054,0x00000000}},	//   _muat_, _leag_, идів_,
  { {0x442d0919,0x6449091a,0x3ea9000c,0x00000000}},	//   tje_, thei, _luat_,
  { {0x442d091b,0x44f10013,0x443f091c,0x00000000}},	//   uje_, _vơ_, uku_,
  { {0xa3e80053,0x442d091d,0x66fa008f,0x00000000}},	//   _बार_, rje_, gākā,
  { {0x62810014,0x44f10013,0x442d091e,0x00000000}},	//   ullo, _tơ_, sje_,
  { {0x8467011c,0x2fc90025,0x628100cd,0x00000000}},	//   _къде, _beag_, rllo,
  { {0x3ea90397,0x66fa008f,0x6440091f,0x00000000}},	//   _buat_, bākā, ckmi,
  { {0x14740021,0x6f63026c,0x91fc001c,0x00000000}},	//   _بالج, звяз, onāl,
  { {0x6d4e00bd,0x3ea90089,0x28d80053,0x00000000}},	//   tzba, _duat_, _डिलि,
  { {0x6f0d00f3,0x32050034,0x6efd00c7,0x00000000}},	//   _esac, mely_, _påbö,
  { {0xa01b00fe,0x2fc900ac,0x320507ee,0x00000000}},	//   llön, _geag_, lely_,
  { {0xfb8a000d,0x6d4e013d,0xddce00a8,0x00000000}},	// [a20] убак_, szba, aobš,
  { {0x239b0006,0x32050920,0x7ae40921,0x00000000}},	//   mąjį_, nely_, ruit,
  { {0x6459006f,0x7ae40922,0x3979000d,0x00000000}},	//   _omwi, suit, асцю_,
  { {0x7ae40923,0xb17a0047,0x2bba0044,0x00000000}},	//   puit, אטער, _حادة_,
  { {0x32050034,0x38660924,0x46f603d1,0x00000000}},	//   kely_, rnor_, счет,
  { {0xdb1d00b9,0x2bd00053,0x91fc001c,0x00000000}},	//   _besæ, तःका, gnāl,
  { {0x32050920,0x186a0925,0x2a6f00ea,0x00000000}},	//   dely_, _бави_, égbe_,
  { {0xfbdf001f,0x91fc001c,0xe8e0008b,0x00000000}},	//   _llên_, anāl, _chụp_,
  { {0x64400026,0x661100fe,0x239b0006,0x00000000}},	//   rkmi, ökkä, jąjį_,
  { {0x64400019,0xd6cf0021,0x66fa001c,0x00000000}},	//   skmi, _أقل_, rākā,
  { {0x5316006a,0x2012003e,0x66fa008f,0x00000000}},	//   _گذار, _bayi_, sākā,
  { {0xfe7f00cd,0xa2e6000d,0xf3f9003b,0x00000000}},	//   duïa_, _годд, tiţe_,
  { {0xa01b0046,0x3205011b,0xddce011b,0x00000000}},	//   blön, bely_, libř,
  { {0xf3f900dd,0x32050926,0x6d140042,0x00000000}},	//   riţe_, cely_, डिंग_,
  { {0x7bcd0026,0x463b0047,0x725b0063,0x00000000}},	//   taau, נעלע, _תכופ,
  { {0xe165007e,0xafdb01e1,0x91fc008f,0x00000000}},	//   _بدهي, ehøv, inām,
  { {0x6a350138,0x765a0137,0x213e002b,0x00000000}},	// [a30] онађ, _omty, lyth_,
  { {0x91f5008b,0xa381004b,0x27ed0927,0x00000000}},	//   hín, öõig, _scen_,
  { {0xc0b2008d,0xa3e80042,0xdb040046,0x00000000}},	//   _rưởi_, बला_, sbið,
  { {0xac190928,0xb9010053,0xc0b20013,0x00000000}},	//   _тому_, _दि_, _sưởi_,
  { {0xb06600fe,0x68e50072,0x76460078,0x00000000}},	//   ltää, suhd, _įkyr,
  { {0xf7700929,0x1a94000d,0x79c9005d,0x00000000}},	//   ران_, _наяў, _خوسف_,
  { {0x32050037,0xb066024a,0x91fc001c,0x00000000}},	//   vely_, ntää, rnāl,
  { {0x68e300cd,0xb0660072,0x3205002b,0x00000000}},	//   àndu, itää, wely_,
  { {0x32050037,0xb0660072,0xdb1d00be,0x00000000}},	//   tely_, htää, _desç,
  { {0xe4e70086,0x239b0078,0xc59501ce,0x00000000}},	//   _гідн, vąjį_, _дизј,
  { {0x386d0198,0x32050034,0x69d8017d,0x00000000}},	//   _kjer_, rely_, óvei,
  { {0x76430831,0x44f30016,0xdb1d00fe,0x00000000}},	//   lkny, mã_, _kesä,
  { {0x2d85092a,0x31790022,0x3205092b,0x00000000}},	//   ülen_, łsz_, pely_,
  { {0xdca6006e,0x239b0078,0xa01b0072,0x00000000}},	//   жави, rąjį_, llöl,
  { {0xf3f90529,0x2d8c092c,0x76430052,0x00000000}},	//   enţi_, åde_, ikny,
  { {0xac86071f,0x4c860085,0x6fb600de,0x00000000}},	//   ігал, ілав, _بمظا,
  { {0x49ca0001,0xe7ff0053,0xdcef008f,0x00000000}},	// [a40] илан_, ोजना_, ījāt,
  { {0x5e570021,0x387f0089,0xceb9004c,0x00000000}},	//   _وليس_, _akur_, íře_,
  { {0xf3f9003b,0xad590062,0x291c092d,0x00000000}},	//   anţi_, _грях_, íva_,
  { {0x225e00c3,0xfe7f00cd,0xdb1d092e,0x00000000}},	//   zitk_, nuïn_, _besä,
  { {0x7c26092f,0x98a30930,0x6009009a,0x00000000}},	//   _inkr, фице, מִסְ,
  { {0x386d0146,0x96330088,0xc4da0001,0x00000000}},	//   _ejer_, мніц, ађи_,
  { {0x8675000d,0x44f3017d,0xdb070014,0x00000000}},	//   чыцц, gã_, élög,
  { {0x9cd70063,0x7e7c0931,0x66e60932,0x00000000}},	//   קופה_, horp, _моба,
  { {0x1666005a,0x213e001f,0xf20607da,0x00000000}},	//   _двам, wyth_, ояно,
  { {0x7af600eb,0xb06600fe,0x3a3800a8,0x00000000}},	//   ityt, ytää, _jorp_,
  { {0xf21f0053,0x7c260933,0x7e7c0934,0x00000000}},	//   बाज़_, _onkr, dorp,
  { {0x91fc008f,0xc05b012c,0x00000000,0x00000000}},	//   onāk, ріо_,   ,
  { {0x64b1008f,0x289b0041,0xdefb0085,0x00000000}},	//   _jāin, ייטא, шын_,
  { {0x3f85003d,0xb06600fe,0x7c260935,0x00000000}},	//   ālu_, ttää, _ankr,
  { {0x91bb0063,0xf3f9003b,0xdfdb0062,0x00000000}},	//   _דמוי, liţa_, _къп_,
  { {0x1bbb0021,0xb0660072,0x2bbb0044,0x00000000}},	//   شارع_, rtää, شارة_,
  { {0x44260035,0xb06600fe,0xe8df008b,0x00000000}},	// [a50] _mno_, stää, _thừa_,
  { {0x7c2600c3,0x539b0063,0x3a380936,0x00000000}},	//   _enkr, שימו, _corp_,
  { {0x3a380179,0x7af60006,0xf3f9003b,0x00000000}},	//   _dorp_, atyt, hiţa_,
  { {0xa6c90021,0x3835000d,0xdb1d0072,0x00000000}},	//   موصل_, янер, _pesä,
  { {0xab840699,0x290e0014,0x2b520022,0x00000000}},	//   _журк, æfar_, czyc_,
  { {0x44260937,0xd1260021,0xc1780078,0x00000000}},	//   _ano_, _كم_, ngės_,
  { {0x91fc008f,0x044502fe,0x6a140062,0x00000000}},	//   anāk, зейн, _юмру,
  { {0x44f3017d,0x387f017e,0x9479005e,0x00000000}},	//   rã_, _ukur_, љску_,
  { {0x44f300be,0x44260938,0x782400de,0x00000000}},	//   sã_, _dno_, _تعّل,
  { {0x44260198,0xe680003b,0x64aa004c,0x00000000}},	//   _eno_, ălţă, _břid,
  { {0xfe7f01a8,0x7e7c0939,0x051900de,0x00000000}},	//   tuïn_, vorp, _دياب_,
  { {0x44d70529,0xe8df001b,0x7e7c006f,0x00000000}},	//   mă_, _chứa_, worp,
  { {0x44d70529,0x7d1e093a,0x644b093b,0x00000000}},	//   lă_, _srps, _ilgi,
  { {0x629d0080,0x539a009a,0xb2ba009a,0x00000000}},	//   ůsob, _פיסו, _המסר,
  { {0x44d70529,0x44260185,0xa8bc0058,0x00000000}},	//   nă_, _yno_, örüş_,
  { {0xdb0d0025,0x7e7c093c,0x7c95071f,0x00000000}},	//   acaí, sorp, друц,
  { {0x78bb017f,0xaa46000a,0x290300ea,0x00000000}},	// [a60] _čuva, пеал, _apja_,
  { {0x7af6015e,0x3af40137,0x6996093d,0x00000000}},	//   rtyt, räp_, прех,
  { {0x44d7000c,0x18a6093e,0xe8fa093f,0x00000000}},	//   jă_, чаем, сле_,
  { {0xafdb02ab,0x44d7000c,0x3a38006f,0x00000000}},	//   lhør, dă_, _worp_,
  { {0xf7430940,0x91fc008f,0x7bc40046,0x00000000}},	//   нецо, unāk, mbiu,
  { {0x7bc40006,0x76a90086,0xf3f9003b,0x00000000}},	//   lbiu, ітів_, viţa_,
  { {0x44d7000c,0x69dc0941,0xdb07013d,0x00000000}},	//   gă_, _idre, ömör,
  { {0xb6030418,0x68e30942,0x64a3000a,0x00000000}},	//   ēšan, ánde, наја,
  { {0x69ce06a7,0xf363000d,0x7ae40943,0x00000000}},	//   _kebe, етэн, nrit,
  { {0x64aa0080,0x44d7000c,0xf3f9003b,0x00000000}},	//   _přid, bă_, riţa_,
  { {0x44d70529,0x7ae400bd,0x64b30080,0x00000000}},	//   că_, hrit, _přiř,
  { {0x69ce0199,0x44260944,0x6f040025,0x00000000}},	//   _lebe, _uno_, _bpic,
  { {0x69dc055e,0xa8570063,0x9f600014,0x00000000}},	//   _odre, ליטה_, órðu_,
  { {0x539b0063,0x8cb10053,0x6266007e,0x00000000}},	//   _הידו, _आंदो, _عاشق,
  { {0x01fb0063,0x7ae40945,0x51fb0063,0x00000000}},	//   _הפול, erit, _ההוצ,
  { {0x7ae40946,0x69dc0947,0x3cf60042,0x00000000}},	//   frit, _adre, ँढ़ें_,
  { {0x44d70469,0x69ce014f,0x62880948,0x00000000}},	// [a70] ză_, _bebe, oldo,
  { {0x19ab000a,0x69ce0949,0xab840002,0x00000000}},	//   стап_, _cebe, хуск,
  { {0x3d240088,0xdb1d094a,0x69ce094b,0x00000000}},	//   _зьяв, _jesú, _debe,
  { {0xf9900032,0x44d7000c,0x1ab50062,0x00000000}},	//   ابك_, vă_, _обмя,
  { {0x7ae4094c,0x200b0051,0x69ce094d,0x00000000}},	//   crit, ieci_, _febe,
  { {0x44d70469,0x69ce094e,0xcb120063,0x00000000}},	//   tă_, _gebe, _שלם_,
  { {0xdb1d0024,0x7bcf003e,0x78a2004a,0x00000000}},	//   _nesú, _kecu, ňova,
  { {0x44d70529,0x200b017f,0xa01b00c7,0x00000000}},	//   ră_, jeci_, slöj,
  { {0xd5b100aa,0x44d70529,0x7d1c082a,0x00000000}},	//   _các_, să_, zvrs,
  { {0x44d7000c,0xd5d5005d,0x61450782,0x00000000}},	//   pă_, _آقاخ, деоа,
  { {0x7ae40024,0x69c50139,0xd00a0062,0x00000000}},	//   zrit, ibhe, оене_,
  { {0x7bcf000c,0x7ae400fe,0x6aa7006f,0x00000000}},	//   _necu, yrit, _lijf,
  { {0x99830078,0xe1ee0363,0x73c40044,0x00000000}},	//   _kojų_, _иг_, _أيهم,
  { {0xf2d20063,0x91fc001c,0x01650259,0x00000000}},	//   _יעד_, riāc, _окло,
  { {0x7ae4094f,0x7bcf0950,0x69ce0951,0x00000000}},	//   writ, _becu, _rebe,
  { {0x69ce0952,0x7bcf000c,0x7ae40953,0x00000000}},	//   _sebe, _cecu, trit,
  { {0xd5b1001b,0x6d550290,0x7bcf0954,0x00000000}},	// [a80] _xác_, azza, _decu,
  { {0xff5f03b2,0x6aa70122,0xe8df008b,0x00000000}},	//   raît_, _cijf, _chữa_,
  { {0xa90a0021,0x27fd001f,0x7bcf0955,0x00000000}},	//   تيال_, ffwn_, _fecu,
  { {0x313600b5,0xab2a0956,0x7ae40957,0x00000000}},	//   ונעם_, _дома_, prit,
  { {0x3946001c,0xa09b0149,0x69ce0958,0x00000000}},	//   ņos_, קינט, _tebe,
  { {0x69dc0959,0xd5b1008b,0x69ce004d,0x00000000}},	//   _udre, _rác_, _uebe,
  { {0x6935004c,0xdb0601e1,0xaaa70042,0x00000000}},	//   _přeš, _afkø, _कूटक,
  { {0x64aa0080,0xe314000a,0xd7060001,0x00000000}},	//   _přib, емињ, _озби,
  { {0xb66a0002,0x41e60304,0x200b095a,0x00000000}},	//   _диаз_, міна, veci_,
  { {0xd25003eb,0xd62601a7,0x51f80086,0x00000000}},	//   اند_, _تعري, чною_,
  { {0xa01b00fe,0x92570021,0x63b9002b,0x00000000}},	//   llöi, بشير_, _ffwn,
  { {0xc32a0032,0xd5b1001b,0xb84a014b,0x00000000}},	//   _وكان_, _tác_, йлiв,
  { {0x200b005b,0x20190019,0x7bcf095b,0x00000000}},	//   reci_, rdsi_, _recu,
  { {0x200b074f,0x7bcf095c,0x44cc0022,0x00000000}},	//   seci_, _secu, oś_,
  { {0x320c0706,0x1df805ac,0x7bcf095d,0x00000000}},	//   medy_, ьеры_, _pecu,
  { {0x28d80042,0x320c004c,0x5f950217,0x00000000}},	//   _डिजि, ledy_, _пийт,
  { {0x7b6700e1,0x7bcf008f,0xa3b30042,0x00000000}},	// [a90] фтве, _vecu, जुट_,
  { {0x6485095e,0x9967060d,0x16000042,0x00000000}},	//   lóit, мтел, ल्मर_,
  { {0xa3c30235,0x6aa70122,0xba3b00cd,0x00000000}},	//   ्रम_, _vijf, _suïs,
  { {0x6aa7006f,0x99830078,0x7ae2008f,0x00000000}},	//   _wijf, _sojų_, šota,
  { {0x320c0024,0xe70b005d,0x44cc0022,0x00000000}},	//   kedy_, تتان_, eś_,
  { {0x7aed0397,0x24510114,0x88c70044,0x00000000}},	//   muat, _máme_, _يتأل,
  { {0x7aed095f,0x7c3d0960,0xf8b40085,0x00000000}},	//   luat, _kosr, _абсэ,
  { {0xdb1d02ab,0x00000000,0x00000000,0x00000000}},	//   _besø,   ,   ,
  { {0x64aa0080,0x25a9007e,0x13060121,0x00000000}},	//   _přic, _فضای_, еный_,
  { {0x291e0006,0x320c00e5,0xcb120063,0x00000000}},	//   _štai_, gedy_, נלי_,
  { {0x50b5000d,0x1a160047,0x7aed0961,0x00000000}},	//   эспу, ײַיש_, huat,
  { {0x7aed003e,0xa9240066,0xdee60962,0x00000000}},	//   kuat, _ôžet, номи,
  { {0x644900bd,0x64aa0080,0x201e0080,0x00000000}},	//   mkei, _třic, ěti_,
  { {0x443d0034,0x24510240,0x64490963,0x00000000}},	//   _how_, _dáme_, lkei,
  { {0x644900fe,0x7c3d00ca,0x27e0013d,0x00000000}},	//   okei, _bosr, óink_,
  { {0x7aed0009,0x78a90964,0x7c3d032a,0x00000000}},	//   fuat, _niev, _cosr,
  { {0x3b07011c,0x7aed0965,0x644900fe,0x00000000}},	// [aa0] нето_, guat, ikei,
  { {0x443d0034,0x9b930032,0x2fe80022,0x00000000}},	//   _low_, الكت, ługą_,
  { {0x6449024a,0xef18001c,0x62810966,0x00000000}},	//   kkei, āļu_, iolo,
  { {0x443d0034,0x7aed014f,0x68e3006d,0x00000000}},	//   _now_, buat, ánda,
  { {0x0c23005a,0x62810967,0x6843000d,0x00000000}},	//   _смян, kolo, ынца,
  { {0x25fb0161,0x7bd60968,0x246c004c,0x00000000}},	//   ल्ली_, layu, měmi_,
  { {0x443d0969,0x6281096a,0x91fc008f,0x00000000}},	//   _bow_, dolo, ināt,
  { {0x64490199,0x6281096b,0x443d096c,0x00000000}},	//   gkei, eolo, _cow_,
  { {0xa3b70021,0x78a3006f,0x68e10137,0x00000000}},	//   راير_, ïnve, _åldr,
  { {0x644900eb,0x7bd60089,0x24510066,0x00000000}},	//   akei, hayu, _ráme_,
  { {0xa01b00a5,0xd4c50085,0x320c096d,0x00000000}},	//   ilöv, _асіп, redy_,
  { {0xa3c30053,0xd250007e,0x3866096e,0x00000000}},	//   ्रण_, انگ_, nior_,
  { {0xc43b0063,0xe29a005a,0x64850025,0x00000000}},	//   _מתאי, _еад_, róit,
  { {0x661a024a,0x6281096f,0x44fa00ac,0x00000000}},	//   _jatk, colo, oë_,
  { {0xdcb1001b,0x7c3d0970,0x661a0971,0x00000000}},	//   ể_, _posr, _matk,
  { {0x60da02e0,0x661a0972,0x7aed081b,0x00000000}},	//   mstm, _latk, tuat,
  { {0x78a90973,0xde790062,0xeab3009e,0x00000000}},	// [ab0] _riev, _обич_, اعر_,
  { {0x83fd00ea,0xf09f00cd,0x7bd600a4,0x00000000}},	//   lnőt, lmà_, aayu,
  { {0xdd9104de,0x78a9003d,0x7aed0974,0x00000000}},	//   _خود_, _piev, suat,
  { {0x64850025,0x38660290,0x8c440141,0x00000000}},	//   hóir, gior_, _беџе,
  { {0x44fa00e8,0xab5b0122,0xdb0700fe,0x00000000}},	//   eë_, _geüp, ämäs,
  { {0x443d00e3,0xa5090079,0x3866017d,0x00000000}},	//   _sow_, дека_, aior_,
  { {0x64850025,0x62810975,0x443d0976,0x00000000}},	//   dóir, volo, _pow_,
  { {0x3866003b,0xd5b10013,0x62810022,0x00000000}},	//   cior_, _gán_, wolo,
  { {0x64490977,0xf7730021,0x443d00e5,0x00000000}},	//   rkei, _صار_, _vow_,
  { {0x64850025,0x64490978,0xf09f00cd,0x00000000}},	//   góir, skei, emà_,
  { {0x443d0979,0x2127005d,0x6281097a,0x00000000}},	//   _tow_, ريحی_, rolo,
  { {0xa3d20161,0x20040512,0x64850025,0x00000000}},	//   वरण_, ými_, róis,
  { {0x60c400c3,0x6281097b,0x249f0014,0x00000000}},	//   _čime, polo, mmum_,
  { {0x63bb097c,0x248d097d,0x3f8c001c,0x00000000}},	//   lcun, llem_, ādu_,
  { {0x7bd6002c,0x8d63006e,0x957c0022,0x00000000}},	//   tayu, авре, _idąc,
  { {0x3ce500ea,0x63bb097e,0xa3c30042,0x00000000}},	//   álva_, ncun, ्रि_,
  { {0x38660034,0x248d097f,0xcb670980,0x00000000}},	// [ac0] vior_, ilem_, вате_,
  { {0x7bd60981,0x6fa70042,0x3cea0042,0x00000000}},	//   sayu, _गणतं, _छिपे_,
  { {0xa3c30235,0x7bd600a4,0x661a0982,0x00000000}},	//   ्रा_, payu, _ratk,
  { {0xd5b1001b,0x60dc00ea,0x83fd00ea,0x00000000}},	//   _báo_, ármi, inős,
  { {0xd5b100aa,0x69ca007a,0x2ca00019,0x00000000}},	//   _cáo_, ðfes, mmid_,
  { {0xe7370001,0x629d0983,0x2ca0004b,0x00000000}},	//   тељ_, ïsol, lmid_,
  { {0x386600c7,0xbf9b00ac,0xd5b1008d,0x00000000}},	//   pior_, neêr, _tán_,
  { {0x291802e8,0x74670121,0x248d0575,0x00000000}},	//   _isra_, крыв_, glem_,
  { {0x6d470045,0xdb0d0016,0x2ca00025,0x00000000}},	//   zyja, rcaç, imid_,
  { {0x91fc003d,0x60c40734,0xe61a0054,0x00000000}},	//   ciāl, _čimb, _іде_,
  { {0x67220984,0x248d0985,0xb6a3030b,0x00000000}},	//   lvoj, blem_, _тифл,
  { {0xdb04048e,0x64850139,0xf09f01a8,0x00000000}},	//   nció, sóir, umà_,
  { {0xf09f0268,0xdb04006d,0x67220986,0x00000000}},	//   rmà_, ició, nvoj,
  { {0x2ca00019,0xc6940047,0x67220987,0x00000000}},	//   emid_, טאָ_, ivoj,
  { {0xdb0400ea,0x7e67006f,0x4fc70988,0x00000000}},	//   kció, rijp, _испа,
  { {0x30a4000d,0x55770041,0x67220078,0x00000000}},	//   _крыв, דעלן_, kvoj,
  { {0x6e450021,0xddc700c2,0xe29a008d,0x00000000}},	// [ad0] _منظم, anjš, _khư_,
  { {0x68e303ad,0x672202e2,0x2ca00019,0x00000000}},	//   ándo, dvoj, amid_,
  { {0x249f0014,0xb8b40021,0xab62004b,0x00000000}},	//   ymum_, لإنت, üürn,
  { {0x69ca0026,0xa01b0989,0x7ce8009a,0x00000000}},	//   ðfer, mlös, _בַשֶ,
  { {0x64aa0080,0xa01b00fe,0x7c2f0725,0x00000000}},	//   _přin, llös, _incr,
  { {0xe29a00aa,0xdb04048e,0xf3f90529,0x00000000}},	//   _như_, ació, miţi_,
  { {0x91fc003d,0xf3f9000c,0x58d4098a,0x00000000}},	//   riāl, liţi_, _вост,
  { {0xdb04048e,0x63bb0003,0xc984005e,0x00000000}},	//   cció, ucun, _ђури,
  { {0x69d5000f,0xf3f9000c,0x63bb098b,0x00000000}},	//   _keze, niţi_, rcun,
  { {0xa3c30235,0x63bb098c,0x248d098d,0x00000000}},	//   ्रह_, scun, slem_,
  { {0x10a6098e,0xfe7f00cd,0x69d5098f,0x00000000}},	//   лион, nuïu_, _meze,
  { {0x69d50122,0xcea900b5,0x24840990,0x00000000}},	//   _leze, _זי_, comm_,
  { {0xe28e0991,0xa2e50071,0xa01b004d,0x00000000}},	//   _га_, _солд, elös,
  { {0xa01b00bd,0xf3f9003b,0x7c2f0992,0x00000000}},	//   flös, diţi_, _ancr,
  { {0x2d8c0146,0xdc9a0002,0x67220993,0x00000000}},	//   æde_, еташ_, zvoj,
  { {0xfe7f0994,0x2ca0004b,0x61f1003b,0x00000000}},	//   duïu_, umid_, şelă,
  { {0x69d50995,0x2ca00019,0xf3f9003b,0x00000000}},	// [ae0] _beze, rmid_, giţi_,
  { {0xa01b0137,0x442f0996,0x2ca00997,0x00000000}},	//   slöt, _lng_, smid_,
  { {0x69d50998,0x2d8500ea,0x442f0999,0x00000000}},	//   _deze, ület_, _ong_,
  { {0xf3f9003b,0x3e6d0195,0x20d10130,0x00000000}},	//   biţi_, ržte_, iši_,
  { {0xdb0402dd,0xf3f9003b,0x69d5099a,0x00000000}},	//   rció, ciţi_, _feze,
  { {0x442f099b,0xdd25001c,0x69d5099c,0x00000000}},	//   _ang_, līša, _geze,
  { {0x20d10198,0xdb04099d,0x764100a4,0x00000000}},	//   jši_, pció, _doly,
  { {0xdd25001c,0x6d5c008f,0x20d1099e,0x00000000}},	//   nīša, izra, dši_,
  { {0x78a2099f,0x91a90013,0x7641013d,0x00000000}},	//   mmov, _đá_, _foly,
  { {0x76410185,0xfe7f00cd,0x78a209a0,0x00000000}},	//   _goly, nuït_, lmov,
  { {0x2d8c0051,0xd48f07da,0x7413007e,0x00000000}},	//   żdej_, _гр_, _گونا,
  { {0x78a2006d,0x4254005d,0xe3b702d8,0x00000000}},	//   nmov, انگر, _ббц_,
  { {0xe29a001b,0xdd25003d,0x20d109a1,0x00000000}},	//   _thư_, dīša, aši_,
  { {0x98bc0080,0xf3f9003b,0x20d100c2,0x00000000}},	//   ávě_, viţi_, bši_,
  { {0x442f0185,0xfe7f0994,0x3d0f0161,0x00000000}},	//   _yng_, duït_, ाबें_,
  { {0xf3f90529,0x78a2017f,0x859b0063,0x00000000}},	//   tiţi_, jmov, תשלו,
  { {0x909800b3,0x6442006f,0x4c9407b0,0x00000000}},	// [af0] _حضور_, _mooi, ситс,
  { {0xf3f90529,0xa01b0137,0x78a209a2,0x00000000}},	//   riţi_, plös, emov,
  { {0xf3f90529,0x98510045,0x64aa0080,0x00000000}},	//   siţi_, nąć_, _přil,
  { {0x64420162,0xdddc000c,0xf3f9000c,0x00000000}},	//   _nooi, porţ, piţi_,
  { {0xfe7f00cd,0x752809a3,0x2d9c0066,0x00000000}},	//   buït_, _ardz, _úver_,
  { {0xb5c20086,0x7aed09a4,0x7bcd0206,0x00000000}},	//   ойшл, mrat, lbau,
  { {0x442f09a5,0xe3b10032,0x7a410080,0x00000000}},	//   _png_, يرة_, _vítě,
  { {0x1309019d,0x20d1074f,0x29010025,0x00000000}},	//   вний_, vši_, mtha_,
  { {0x644200e8,0x76410006,0x4423004c,0x00000000}},	//   _dooi, _toly, ěj_,
  { {0x24800117,0x20090089,0x7aed09a6,0x00000000}},	//   čima_, _abai_, irat,
  { {0x27e00026,0xdddc007d,0x6f0d09a7,0x00000000}},	//   ðing_, jorš, _apac,
  { {0x6442006f,0xa06a0001,0x442f09a8,0x00000000}},	//   _gooi, тама_, _ung_,
  { {0x083a0047,0x8db60054,0x7aed013d,0x00000000}},	//   דערל, исві, jrat,
  { {0x7aed09a9,0x20d100b2,0x7bcd004d,0x00000000}},	//   drat, pši_, ebau,
  { {0xdd25003d,0xabd60001,0x7bcd00bd,0x00000000}},	//   tīša, ицај, fbau,
  { {0x672909aa,0x417a0063,0x7aed09ab,0x00000000}},	//   _orej, _שנקב, frat,
  { {0xfe7f0268,0x290109ac,0x2d8509ad,0x00000000}},	// [b00] tuït_, etha_, üler_,
  { {0xdd25001c,0x99580066,0x32050168,0x00000000}},	//   sīša, ráža_, nfly_,
  { {0xaa7b0080,0x29010027,0x7aed09ae,0x00000000}},	//   _svýc, gtha_, arat,
  { {0xafdb0146,0x64aa0080,0x672909af,0x00000000}},	//   lkør, _přim, _brej,
  { {0x2bd30053,0x644200f5,0x29010025,0x00000000}},	//   तररा, _rooi, atha_,
  { {0x672909b0,0x78a209b1,0x3916005d,0x00000000}},	//   _drej, smov, _پورز,
  { {0xafdb02ab,0x29010025,0x98a60086,0x00000000}},	//   ljøe, ctha_, _виве,
  { {0x32050034,0x9168008b,0x94180121,0x00000000}},	//   efly_, _lực_, ужит_,
  { {0xa2b30121,0x672909b2,0xd1ca09b3,0x00000000}},	//   обыч, _grej, кунд_,
  { {0x26c0003b,0x166309b4,0xb254005e,0x00000000}},	//   ţios_, _двум, скољ,
  { {0x91a900aa,0x67290024,0x6f0d09b5,0x00000000}},	//   _đã_, _zrej, _spac,
  { {0x506701f6,0x7aed09b6,0x90e70044,0x00000000}},	//   ртоа, yrat, جَّل_,
  { {0xfe7f00cd,0xd2520044,0x00000000,0x00000000}},	//   duïr_, _ونص_,   ,
  { {0x69d8007a,0x9f4000bd,0x7ea000bd,0x00000000}},	//   ðvel, _weiß_, höpf,
  { {0xdd95000d,0x7ea0004d,0x7bcd004d,0x00000000}},	//   савы, köpf, tbau,
  { {0x228b0031,0x7aed09b7,0x31330062,0x00000000}},	//   søkt_, trat, _феър,
  { {0x7bcd003d,0x64aa0080,0x6f0d014f,0x00000000}},	// [b10] rbau, _přij, _upac,
  { {0xab840459,0xe9ab006a,0x7aed09b8,0x00000000}},	//   цуск, ندان_, rrat,
  { {0x3947003b,0x3d240121,0x7aed09b9,0x00000000}},	//   âns_, _дьяв, srat,
  { {0x672909ba,0x2901057a,0x7aed09bb,0x00000000}},	//   _prej, rtha_, prat,
  { {0xdd28003d,0xdc36069a,0x628809bc,0x00000000}},	//   mēša, _הארט_, kodo,
  { {0xdd28003d,0x29010025,0xb6070928,0x00000000}},	//   lēša, ptha_, рядк,
  { {0xd46908ef,0xafdb00d1,0xddd50078,0x00000000}},	//   лике_, shøy, enzū,
  { {0xdd28001c,0xd5b10013,0x9cd80063,0x00000000}},	//   nēša, _mái_, בוהה_,
  { {0x67290198,0x62880185,0x9f44005b,0x00000000}},	//   _urej, fodo, ümü_,
  { {0x628809bd,0x8b580063,0xe7300044,0x00000000}},	//   godo, ייחס_, _تصف_,
  { {0xf5950593,0xd6980085,0xdd28008f,0x00000000}},	//   _الاج, _лiто, kēša,
  { {0x320504aa,0xb7bd00dd,0x7ae20130,0x00000000}},	//   sfly_, _faţe, šoti,
  { {0x443f001c,0xdd28001c,0x316b0051,0x00000000}},	//   mju_, dēša, ńcz_,
  { {0xddc30259,0x443f09be,0x628809bf,0x00000000}},	//   збри, lju_, codo,
  { {0x9168008b,0xafdb06a5,0x443f09c0,0x00000000}},	//   _vực_, rkør, oju_,
  { {0x443f09c1,0x645b0122,0x78a30179,0x00000000}},	//   nju_, nhui, ïnvl,
  { {0x8c4306be,0x4e7a0021,0xcff7009d,0x00000000}},	// [b20] чете, _محدد_, _הצפה_,
  { {0x443f0019,0x64aa0080,0x4a4309c2,0x00000000}},	//   hju_, _přik, пнув,
  { {0xafdb00d1,0x645b006f,0x090609c3,0x00000000}},	//   sjøe, khui, спен,
  { {0xdd28001c,0x628809c4,0xb7d70044,0x00000000}},	//   cēša, zodo, موما_,
  { {0x62880035,0xeb75000d,0x645b006f,0x00000000}},	//   yodo, _дырэ, dhui,
  { {0x7c2409c5,0x89f50088,0x645b006f,0x00000000}},	//   ldir, _мясц, ehui,
  { {0x628809a0,0x89db0063,0x6d4e09c6,0x00000000}},	//   vodo, _תחלי, nyba,
  { {0x62880051,0x7c240508,0x2480082a,0x00000000}},	//   wodo, ndir, čimo_,
  { {0x7c240035,0x628809c7,0x55e609c8,0x00000000}},	//   idir, todo, _гозб,
  { {0xdd28001c,0x628800fe,0x69de09c9,0x00000000}},	//   zēša, uodo, nape,
  { {0x443f00c3,0x212a0025,0x628809ca,0x00000000}},	//   bju_, íbh_, rodo,
  { {0x628809cb,0x645b09cc,0x32020080,0x00000000}},	//   sodo, chui, řky_,
  { {0x69de09cd,0x7c24001f,0x628809ce,0x00000000}},	//   kape, ddir, podo,
  { {0xdce50024,0x69de09cf,0xd0d40062,0x00000000}},	//   _vzhľ, jape, _докъ,
  { {0x64aa02f4,0x200400cd,0xdd28001c,0x00000000}},	//   _přih, òmic_, tēša,
  { {0x60c709d0,0x3cec013d,0xa177009a,0x00000000}},	//   íjme, ádva_, _לעוד_,
  { {0xdd28003d,0xeabf0013,0xe9d90002,0x00000000}},	// [b30] rēša, _trùm_, имач_,
  { {0x443f00c3,0x61fa00a4,0x7b740021,0x00000000}},	//   zju_, ngtl, أطفا,
  { {0xd5b10013,0xdd28008f,0x7c2409d1,0x00000000}},	//   _tái_, pēša, bdir,
  { {0x19a809d2,0x69de0656,0x64460072,0x00000000}},	//   ступ_, aape, ökil,
  { {0x443f09d3,0x7bdf01fa,0xac240085,0x00000000}},	//   vju_, maqu, _эфэк,
  { {0xdb1d01e3,0xd62907a1,0x7bdf09d4,0x00000000}},	//   _besö, роке_, laqu,
  { {0xf5320079,0x443f09d5,0x645b09d6,0x00000000}},	//   дејќ, tju_, thui,
  { {0x94790001,0x443f005f,0x645e005f,0x00000000}},	//   јску_, uju_, ūpin,
  { {0xa5f90001,0x645b0173,0x443f09d7,0x00000000}},	//   _везу_, rhui, rju_,
  { {0x645b09d8,0x7bdf0153,0xdd1c01c8,0x00000000}},	//   shui, haqu, váže,
  { {0x9327007e,0x443f09d9,0xf4870601,0x00000000}},	//   _گران, pju_, _лудн,
  { {0x6d4e0066,0x78fa009f,0x1faa09da,0x00000000}},	//   vyba, ספרו, икни_,
  { {0x7bdf01a8,0x7c2409db,0x92b7009e,0x00000000}},	//   daqu, vdir, _احصا,
  { {0xdd1c01da,0x7ea00137,0xda0b0042,0x00000000}},	//   ráže, köpe, स्मत_,
  { {0xa3bd016a,0x7bdf00be,0x69de09dc,0x00000000}},	//   _आला_, faqu, vape,
  { {0xdb1d09dd,0x69de0983,0x6d4e09de,0x00000000}},	//   _lesõ, wape, ryba,
  { {0xf4120132,0x7c2409df,0x69de09e0,0x00000000}},	// [b40] ופן_, rdir, tape,
  { {0x224700ac,0x4996007b,0x290f00dd,0x00000000}},	//   _jonk_, ошет, ăgan_,
  { {0x8c4609e1,0xdd0f01f7,0x2f040026,0x00000000}},	//   _дене, mışt, lög_,
  { {0x394700c7,0xdd0f01f7,0x9f480013,0x00000000}},	//   änsa_, lışt, _điêu_,
  { {0x69de09e2,0x64aa004c,0x66e302d8,0x00000000}},	//   pape, _křiv, доча,
  { {0xf4ea0076,0x645909e3,0x7ae409e4,0x00000000}},	//   афий_, _alwi, msit,
  { {0xd90d006a,0x7ae409e4,0x69dc09e5,0x00000000}},	//   _میل_, lsit, _iere,
  { {0xfc570047,0x7bc409e6,0xdb1d004b,0x00000000}},	//   ַביש_, nciu, _eesõ,
  { {0x69dc09e7,0xdd0f005b,0x2f040014,0x00000000}},	//   _kere, kışt, jög_,
  { {0x7bdf0016,0x24510025,0x3cf8069f,0x00000000}},	//   zaqu, _lámh_, kurv_,
  { {0x69dc09e8,0xd2570088,0x224709e9,0x00000000}},	//   _mere, іць_, _donk_,
  { {0xe0cf007e,0x661809ea,0x69dc056a,0x00000000}},	//   کزی_, levk, _lere,
  { {0x20050051,0x7bdf09eb,0xf487005d,0x00000000}},	//   ęli_, vaqu, _بالی,
  { {0x24890024,0x7bc400dd,0x69dc09ec,0x00000000}},	//   čame_, eciu, _nere,
  { {0x76480051,0x7bdf09ed,0x7d1c002b,0x00000000}},	//   _mody, taqu, gwrs,
  { {0x69dc051e,0x3ced082a,0xa0680095,0x00000000}},	//   _aere, čev_, _маја_,
  { {0xb6060024,0x764500fe,0xc3340063,0x00000000}},	// [b50] _kráľ, öhyk, הוּ_,
  { {0x69dc09ee,0x7648001f,0x7bdf09ef,0x00000000}},	//   _cere, _nody, saqu,
  { {0x69dc09f0,0x481509f1,0x7ae409f2,0x00000000}},	//   _dere, змес, asit,
  { {0x9d1a014e,0x765a09f3,0xb17b00b5,0x00000000}},	//   _פורט, _alty, סטאר,
  { {0x27e0007a,0x69dc09f4,0xd5b10013,0x00000000}},	//   ðina_, _fere, _lát_,
  { {0x201909f5,0x2ca90019,0x69dc09f6,0x00000000}},	//   hesi_, lmad_, _gere,
  { {0x7bdd0397,0x67d5014c,0x201909f7,0x00000000}},	//   _kesu, _нову, kesi_,
  { {0x69c509f8,0x68e3006d,0x4d7c0063,0x00000000}},	//   lche, ándu, ירוע,
  { {0x69dc01f7,0x7bdd09f9,0x2ca9004b,0x00000000}},	//   _yere, _mesu, imad_,
  { {0x7bdd09fa,0x2ca90231,0xd5b10013,0x00000000}},	//   _lesu, hmad_, _sáu_,
  { {0x69c50199,0x201909fb,0xddce0078,0x00000000}},	//   iche, fesi_, sibū,
  { {0x7bdd09fc,0x69c509fd,0x2d84005b,0x00000000}},	//   _nesu, hche, şmek_,
  { {0x64aa0080,0x24510080,0xdd0f0058,0x00000000}},	//   _přiv, _námi_, tışt,
  { {0x20190290,0x248d09fe,0x2ca9004b,0x00000000}},	//   aesi_, loem_, emad_,
  { {0x61e109ff,0x7bdd0199,0x2d9e0031,0x00000000}},	//   mall, _besu, åte_,
  { {0x248d00e8,0x0d990088,0x2ca9017f,0x00000000}},	//   noem_, ітры_, gmad_,
  { {0x7bdd0a00,0xdd0f005b,0x2d9e0240,0x00000000}},	// [b60] _desu, pışt, ťte_,
  { {0x7bc4051e,0xada60095,0x61e10a01,0x00000000}},	//   sciu, _напл, nall,
  { {0x764800eb,0x61e10a02,0x7bdd001f,0x00000000}},	//   _rody, iall, _fesu,
  { {0x69dc0a03,0x69c50a04,0x7bdd0a05,0x00000000}},	//   _were, ache, _gesu,
  { {0x61e10a06,0x387f00c7,0xafdb00d1,0x00000000}},	//   kall, _djur_, kjøn,
  { {0x6594000a,0x69c50a07,0x61e10a08,0x00000000}},	//   малу, cche, jall,
  { {0x7bdd00f3,0x20c1001b,0x7c2600c3,0x00000000}},	//   _yesu, _nói_, _kakr,
  { {0x6d410072,0x661800a8,0x04630505,0x00000000}},	//   älai, sevk, етьм,
  { {0x66180024,0x6720017f,0xd5b1008b,0x00000000}},	//   pevk, _usmj, _sát_,
  { {0x201900f3,0x3f85005b,0x20c10013,0x00000000}},	//   wesi_, şluk_, _bói_,
  { {0x69c300c3,0x20190a09,0x60cd007d,0x00000000}},	//   žneg, tesi_, _čamc,
  { {0x34aa005e,0x60c70066,0x2bb80042,0x00000000}},	//   _увео_, íjma, _अलगा,
  { {0xaa7b0080,0x61e10a0a,0x8fe4000d,0x00000000}},	//   _svým, ball, эцэд,
  { {0x61e10a0b,0x7bdd08f0,0x20190a0c,0x00000000}},	//   call, _sesu, sesi_,
  { {0x44260a0d,0x7c260a0e,0x7bdd0a0f,0x00000000}},	//   _kao_, _bakr, _pesu,
  { {0x7c2600f3,0xfad90062,0x6abd0a10,0x00000000}},	//   _cakr, ждащ_, _pusf,
  { {0x76430051,0x2d8c00bd,0x69c50a11,0x00000000}},	// [b70] yjny, üder_, tche,
  { {0x24510080,0x27e0007a,0x68e3000c,0x00000000}},	//   _vámi_, ðinn_, ândo,
  { {0x291903eb,0xa01b0026,0x69c5031d,0x00000000}},	//   تقاد_, rnöf, rche,
  { {0x69c50a12,0x44260a13,0xd75900f2,0x00000000}},	//   sche, _nao_, يلات_,
  { {0x69c50025,0x7ea00137,0x79950051,0x00000000}},	//   pche, löpa, _wyzw,
  { {0xf1ba0013,0x7c260a14,0x61e101a8,0x00000000}},	//   _ngơ_, _zakr, xall,
  { {0x4426001b,0x7c3a0025,0x61e10a15,0x00000000}},	//   _bao_, _úcrá, vall,
  { {0x4426001b,0x45180086,0x24580003,0x00000000}},	//   _cao_, яція_, _démo_,
  { {0xe73f0016,0x61e107db,0xddc700c2,0x00000000}},	//   _çõ_, tall, zijš,
  { {0x25a00080,0x81bc008f,0x60e90a16,0x00000000}},	//   řila_, ldēj, омом_,
  { {0x44260a17,0x64aa0080,0x26cd007d,0x00000000}},	//   _fao_, _přit, _hteo_,
  { {0xd36e006a,0x61e10a18,0x81bc008f,0x00000000}},	//   اهی_, sall, ndēj,
  { {0x81bc001c,0x61e10a19,0xb0660072,0x00000000}},	//   idēj, pall, erää,
  { {0x44260a1a,0x644b001f,0x7c260a1b,0x00000000}},	//   _zao_, _hogi, _sakr,
  { {0x44260035,0x7c260a1c,0xb60601c2,0x00000000}},	//   _yao_, _pakr, _uráž,
  { {0x27ed0a1d,0x44260013,0xddc70a1e,0x00000000}},	//   _nden_, _xao_, rijš,
  { {0x7c2600d1,0xeb970a1f,0x644b0a20,0x00000000}},	// [b80] _vakr, дит_, _mogi,
  { {0x248000c3,0x7c260035,0x63bc004c,0x00000000}},	//   čimi_, _wakr, ěrni,
  { {0xa8060088,0x7c260a21,0xafdb04aa,0x00000000}},	//   дзел, _takr, kjøl,
  { {0x649e006f,0xdb0d0195,0xd7ef0044,0x00000000}},	//   eëin, škán, لكم_,
  { {0xdb1d00b9,0x47360021,0x44260a22,0x00000000}},	//   _afsæ, براز, _rao_,
  { {0x4426001b,0xdd1d0114,0x27ed0a23,0x00000000}},	//   _sao_, lášt, _eden_,
  { {0x7af601e1,0x44260a24,0x34940a25,0x00000000}},	//   lryt, _pao_, накр,
  { {0xfc3f0013,0x7af60051,0xd4970085,0x00000000}},	//   _khía_, oryt, мры_,
  { {0xd703005a,0xb286000d,0x84ea0042,0x00000000}},	//   _изти, дынк, _टिकट_,
  { {0x64aa0080,0x65790025,0x44260035,0x00000000}},	//   _přis, ábhá, _wao_,
  { {0x442600bb,0x09f7014e,0x6d480a26,0x00000000}},	//   _tao_, ומים_, ädal,
  { {0xdbd6021e,0x644b0a27,0x7af60a28,0x00000000}},	//   _jääd, _gogi, kryt,
  { {0xd5b10013,0x93430a29,0xfe730049,0x00000000}},	//   _háp_, _инце, ندس_,
  { {0x7ea000fe,0x7af60022,0x539b009a,0x00000000}},	//   töpa, dryt, _וידו,
  { {0xdd940088,0x387d001f,0x7af60022,0x00000000}},	//   вары, ynwr_, eryt,
  { {0xaa7b004c,0x629a0a2a,0x00000000,0x00000000}},	//   _zvýh, llto,   ,
  { {0x5a35005a,0xda670032,0x629a0a2b,0x00000000}},	// [b90] ннат, وائي, olto,
  { {0x7ea00137,0xa01b00ca,0x26000042,0x00000000}},	//   löpn, coör, _राषी_,
  { {0x7af60078,0x29070a2c,0x629a0a2d,0x00000000}},	//   aryt, îna_, ilto,
  { {0x7af60a2e,0xc19b0063,0x81bc008f,0x00000000}},	//   bryt, חשבי, udēj,
  { {0x387d001f,0x6d5500ea,0x3e6d0078,0x00000000}},	//   rnwr_, lyza, ežti_,
  { {0x629a01af,0xe5a50a2f,0xf5050a30,0x00000000}},	//   jlto, нили, езко,
  { {0x63a2000f,0x98c3001c,0xd5b10013,0x00000000}},	//   _azon, ēvēt_, _cáp_,
  { {0x27ed010a,0x64a2005a,0x332d0a31,0x00000000}},	//   _uden_, лаща, tvex_,
  { {0xe610007e,0x64aa0080,0x662800fe,0x00000000}},	//   _چشم_, _přir, öskä,
  { {0x64b1003d,0x60c701d9,0xdcff004c,0x00000000}},	//   _jāiz, íjmo, ívěj,
  { {0xafdb00d1,0x6f160022,0x00000000,0x00000000}},	//   lkøy, _spyc,   ,
  { {0x7e75008f,0x2004004e,0x629a0a32,0x00000000}},	//   eizp, ümi_, alto,
  { {0x83640044,0xa856009a,0x00000000,0x00000000}},	//   _لدول, גירה_,   ,
  { {0x60c400c2,0x42550044,0x024500de,0x00000000}},	//   _čimv, _سنعر, _سَبَ,
  { {0xdd92013a,0x409601f6,0x5096005e,0x00000000}},	//   اوز_, _прит, _приђ,
  { {0xfc3f001b,0x7e750023,0x6aa80042,0x00000000}},	//   _phía_, aizp, कग्र,
  { {0xa089009a,0x539a009d,0x7c9300de,0x00000000}},	// [ba0] _קְצִ, ִיעו, القص,
  { {0xdbd600fe,0x9f420114,0x7af60072,0x00000000}},	//   _sääd, jaké_, rryt,
  { {0xdbd601cf,0x8d7604a0,0xd7ef071f,0x00000000}},	//   _pääd, _سادا, лу_,
  { {0x27e00a33,0x2002017e,0x66e60a34,0x00000000}},	//   úin_, ngki_, еода,
  { {0x2d9a0a35,0x5ac7012c,0x00000000,0x00000000}},	//   _hype_, _плям_,   ,
  { {0xf52605ce,0x96b7005e,0x8b0b009a,0x00000000}},	//   ефин, нују_, _מִלֵ,
  { {0x63a2013d,0x24510014,0x88c50044,0x00000000}},	//   _szon, _náms_, _لتقل,
  { {0x7ea0024a,0x25a00080,0x68fe0244,0x00000000}},	//   köpo, řilo_, mupd,
  { {0x08770047,0xa686000d,0xf2060a36,0x00000000}},	//   _נעמט_, _злад, няно,
  { {0x629a0a37,0xaa16000d,0xe60e005e,0x00000000}},	//   ulto, дзiц, вдe_,
  { {0x629a0a38,0xf5060054,0x64a60a39,0x00000000}},	//   rlto, _їздо, _зажа,
  { {0x20b4000d,0x25a1004d,0x8386030b,0x00000000}},	//   лёўс, ühle_, _пыле,
  { {0x8cd90042,0x67220022,0xbfa80a3a,0x00000000}},	//   _फौजो, nwoj, етре_,
  { {0xfc3f008b,0x27e600a4,0x6114000d,0x00000000}},	//   _chín_, haon_, _адку,
  { {0xdd95000d,0x321e0a3b,0xeca7005e,0x00000000}},	//   тавы, mety_, ејан,
  { {0x6d550051,0x2d9a00d1,0xc19b0063,0x00000000}},	//   ryza, _dype_, _משוי,
  { {0x7bf80085,0x27e6013d,0x30840044,0x00000000}},	// [bb0] энтр_, daon_, _حليف,
  { {0x67220022,0x6d410050,0x321e0a3c,0x00000000}},	//   dwoj, älas, nety_,
  { {0xfe7f00cd,0xa3c20053,0x4de60082,0x00000000}},	//   duïx_, ्डा_, _क़तई_,
  { {0xab5b017d,0x69d80014,0x80a70042,0x00000000}},	//   _agüe, ðver, _टीमे,
  { {0x38a70019,0xe7580086,0x58b80021,0x00000000}},	//   võrd_, ниці_, رامج_,
  { {0x7c2d007a,0xf6d4007e,0xe7360062,0x00000000}},	//   ldar, ازند, теш_,
  { {0x64aa0080,0xc9840a3d,0x7c2d0a3e,0x00000000}},	//   _přip, _бути, odar,
  { {0x248905c9,0x93590002,0x7c2d0a3f,0x00000000}},	//   čamo_, дроу_, ndar,
  { {0x13060076,0x321e06b8,0x7c2d0a40,0x00000000}},	//   вный_, fety_, idar,
  { {0x68e10146,0x321e0066,0x7c2d002b,0x00000000}},	//   _ælds, gety_, hdar,
  { {0x320b0051,0x3eba00a4,0xb1420085,0x00000000}},	//   ęcy_, _ript_, анэл,
  { {0x7c2d003d,0x6455005e,0x64460050,0x00000000}},	//   jdar, _швеђ, ökit,
  { {0x442d0a41,0xf8b200b5,0x7c2d0a42,0x00000000}},	//   mde_, ישט_, ddar,
  { {0x645b00fe,0x442d0a43,0x78bb0a44,0x00000000}},	//   lkui, lde_, _liuv,
  { {0x7c2d006f,0x442d0a45,0x67220051,0x00000000}},	//   fdar, ode_, zwoj,
  { {0x64490a46,0x7c2d0a47,0x442d02e0,0x00000000}},	//   njei, gdar, nde_,
  { {0xc0530063,0x645b0072,0x442d0a48,0x00000000}},	// [bc0] _כזה_, ikui, ide_,
  { {0x442d024a,0x64490659,0x60c30a49,0x00000000}},	//   hde_, hjei, _kunm,
  { {0x27e600bb,0xbf9b017d,0x61e30a4a,0x00000000}},	//   taon_, ngên, _menl,
  { {0x38600027,0x78a904bc,0x442d0a4b,0x00000000}},	//   óir_, _chev, jde_,
  { {0xe1e7006a,0xf11e0053,0x68fe006f,0x00000000}},	//   _پس_, _बन्द_, supd,
  { {0x442d0a4c,0xd627005e,0x644900be,0x00000000}},	//   ede_, воље_, ejei,
  { {0x442d0173,0x60c3004d,0xd5d50085,0x00000000}},	//   fde_, _nunm, уючы,
  { {0x442d0a4d,0xd6d20021,0x78a900ca,0x00000000}},	//   gde_, _نقر_, _ghev,
  { {0x68e10146,0x799c001f,0xdc9b0047,0x00000000}},	//   _ældr, _hyrw, ויקל,
  { {0x443d0185,0x386603d9,0x442d0a4e,0x00000000}},	//   _enw_, lhor_, ade_,
  { {0x26c40a4f,0x38660089,0xd1660062,0x00000000}},	//   _humo_, ohor_, тъпи,
  { {0x38660016,0xf99301f9,0x68e30a50,0x00000000}},	//   nhor_, ירת_, ândi,
  { {0x2d9e0378,0x69ce0014,0x2458013d,0x00000000}},	//   üten_, _ofbe, _némi_,
  { {0xdce5061a,0x425600e1,0xd3570063,0x00000000}},	//   _vyhľ, _штет, _בידי_,
  { {0xac190a51,0x61e8033b,0x7c2d0a52,0x00000000}},	//   нову_, madl, tdar,
  { {0xfbd3006a,0x69ce0a53,0xdd25001c,0x00000000}},	//   شتر_, _afbe, gūša,
  { {0x7c2d0a54,0xfaf30021,0xeeab0a55,0x00000000}},	// [bd0] rdar, ؤثر_, _оток_,
  { {0xf09f0268,0x442d0a56,0xa2c30053,0x00000000}},	//   llà_, zde_, रदत्,
  { {0x442d0a57,0xdbd1004b,0x9f4e013d,0x00000000}},	//   yde_, _küüd, önöm_,
  { {0x61e80a58,0x2486007d,0x7c3d004d,0x00000000}},	//   hadl, _njom_, _unsr,
  { {0x442d0a59,0xdbd10019,0xe72e03d6,0x00000000}},	//   vde_, _müüd, ще_,
  { {0x442d0122,0x6a600026,0x7aed0a5a,0x00000000}},	//   wde_, _höfn, msat,
  { {0x9f4000cd,0x799c001f,0x7aed0a5b,0x00000000}},	//   _veié_, _gyrw, lsat,
  { {0x2901002c,0xdbd10019,0x26c40a5c,0x00000000}},	//   muha_, _nüüd, _fumo_,
  { {0x442d0a5d,0x3e660164,0x7aed0a5e,0x00000000}},	//   rde_, _hôte_, nsat,
  { {0xb7bd0529,0x645b0a5f,0x442d0a60,0x00000000}},	//   _naţi, skui, sde_,
  { {0x61e3010a,0x290100a4,0x628105b9,0x00000000}},	//   _venl, nuha_, rnlo,
  { {0x44e10812,0xbf9b0016,0x8335007e,0x00000000}},	//   mų_, rgên, _مرتض,
  { {0xa3c20235,0x44e10006,0x6b9d0093,0x00000000}},	//   ्डर_, lų_, _nysg,
  { {0x290100bb,0x3f9e003d,0x249f0a61,0x00000000}},	//   kuha_, ātu_, llum_,
  { {0x44e100eb,0x10f5000d,0x7aed0a62,0x00000000}},	//   nų_, _сяля, esat,
  { {0x44e10006,0x7aed004d,0x6b9d002b,0x00000000}},	//   ių_, fsat, _bysg,
  { {0xfc3f0a63,0x6b9d001f,0x7aed0a64,0x00000000}},	// [be0] _dní_, _cysg, gsat,
  { {0x32050037,0x6b9d0185,0x44e100eb,0x00000000}},	//   ngly_, _dysg, kų_,
  { {0x44e100eb,0x3e660a65,0x38660a66,0x00000000}},	//   jų_, _côte_, thor_,
  { {0x44e10006,0x6abc071c,0x7aed0a67,0x00000000}},	//   dų_, _wirf, bsat,
  { {0xdd1d0024,0xd7f90086,0x81bc001c,0x00000000}},	//   ráťt, тує_, ldēt,
  { {0xfe360047,0x249f0052,0xfc3f004c,0x00000000}},	//   ראַך_, elum_, _zní_,
  { {0x44e10006,0x81bc001c,0xb9b50062,0x00000000}},	//   gų_, ndēt, _встъ,
  { {0x249f0026,0x545406be,0x2876093e,0x00000000}},	//   glum_, рвит, _сыгр,
  { {0x18670001,0x41e60500,0x2ca0004b,0x00000000}},	//   _сати_, ліна, ilid_,
  { {0xdbd10019,0x471b0047,0x44e10006,0x00000000}},	//   _süüd, _אומג, bų_,
  { {0xdbd10019,0x2ca004b4,0xb7bd003b,0x00000000}},	//   _püüd, klid_, _raţi,
  { {0xfc3f008b,0xc0ab0049,0x61e80244,0x00000000}},	//   _phím_, عادل_, sadl,
  { {0x543b00b5,0x08770047,0xf09f01a8,0x00000000}},	//   _רעדא, רעכט_, rlà_,
  { {0x6a600026,0x929d0022,0xfc3f011b,0x00000000}},	//   _söfn, tułe, _sní_,
  { {0xf09f00cd,0xf518009a,0x00000000,0x00000000}},	//   plà_, כֵּל,   ,
  { {0x2ca00019,0x7aed0a68,0x6b9d001f,0x00000000}},	//   glid_, tsat, _pysg,
  { {0x0ca80076,0x44e10078,0xba750062,0x00000000}},	// [bf0] утри_, zų_, агащ,
  { {0x2bb80021,0x7aed0a69,0x7bcd0a6a,0x00000000}},	//   طاقة_, rsat, scau,
  { {0x7aed0a6b,0x49750002,0x47d501fb,0x00000000}},	//   ssat, јлес, ليار,
  { {0x2c27019d,0x44e10006,0xab950086,0x00000000}},	//   _сьог, vų_, _вимі,
  { {0x66b5000a,0xd6db00a0,0xd5e50086,0x00000000}},	//   абду, хте_, ажли,
  { {0x44e100eb,0x2458004c,0x56940054,0x00000000}},	//   tų_, _mému_, бачт,
  { {0x249f0026,0x36660062,0xdb1d01e1,0x00000000}},	//   tlum_, ращо_, _afsø,
  { {0x99840032,0x60c400c3,0x44e10006,0x00000000}},	//   _الفو, _čimp, rų_,
  { {0x44e10006,0x32c90013,0xc8640a6c,0x00000000}},	//   sų_, _qúy_, _утри,
  { {0x249f0026,0xaa7b0240,0xe4e70086,0x00000000}},	//   slum_, _zvýr, _бідн,
  { {0x764100ac,0x9a760063,0x249f0779,0x00000000}},	//   _inly, שתתף_, plum_,
  { {0xb4c10161,0x32c9008b,0xcea90063,0x00000000}},	//   ंदी_, _túy_, _חי_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x3ebe000f,0x442f0a6d,0x3f850075,0x00000000}},	//   ött_, _hag_, ğlup_,
  { {0x81bc001c,0xbda50021,0xee3702f8,0x00000000}},	//   udēt, محفو, јнс_,
  { {0x442f01e3,0xbc630a6e,0xa01b00fe,0x00000000}},	//   _jag_, овск, nnöl,

  { {0x91fc003d,0x442f0a6f,0x6b850021,0x00000000}},	// [c00] bkād, _mag_, مشكل,
  { {0xda660032,0x442f0a70,0x25a00080,0x00000000}},	//   جاري, _lag_, řili_,
  { {0x2cba0021,0xa9260a71,0xdca60a72,0x00000000}},	//   _لاحظ_, рдел, _вани,
  { {0x442f0a73,0x7c96007e,0x97c50021,0x00000000}},	//   _nag_, _خشخا, متهم,
  { {0x7c2403d9,0x2813009e,0x45d40a74,0x00000000}},	//   meir, تونس, болс,
  { {0xb4c10235,0x7c240a75,0x7c2f007d,0x00000000}},	//   ंदू_, leir, _zacr,
  { {0x394700c7,0x442f0a76,0x6d5c0a77,0x00000000}},	//   änst_, _bag_, nyra,
  { {0x7c2403d9,0x2c67004b,0x73d70062,0x00000000}},	//   neir, _tõde_, адър_,
  { {0x442f0a78,0xd5b1001b,0x27e00026,0x00000000}},	//   _dag_, _máy_, ðinu_,
  { {0x80ca0235,0x7d1e0031,0x7c240a79,0x00000000}},	//   _संदे, _opps, heir,
  { {0xba370063,0xd5750086,0x3a370a7a,0x00000000}},	//   בטיח_, _луць, ברים_,
  { {0xd409006a,0x320a0051,0x7c24039f,0x00000000}},	//   _متهم_, żby_, jeir,
  { {0x7c240a7b,0x236d0051,0x44240a7c,0x00000000}},	//   deir, czej_, mem_,
  { {0xa2c30161,0x442f0122,0xbe880a7d,0x00000000}},	//   रदर्, _zag_, ассе_,
  { {0x7c240185,0xd0870076,0x44240474,0x00000000}},	//   feir, _выпи, oem_,
  { {0x24580024,0x7c240a7e,0x2d580376,0x00000000}},	//   _tému_, geir, шись_,
  { {0x6a600026,0xdee4005e,0xf9c701f8,0x00000000}},	// [c10] _töfl, _доњи, ащен,
  { {0x78a20a7f,0x24890a80,0x44240a81,0x00000000}},	//   elov, čami_, hem_,
  { {0x7c240a82,0x39150a83,0x4c950002,0x00000000}},	//   beir, смер, _гинс,
  { {0x78a20198,0x7c24017d,0x87d4000d,0x00000000}},	//   glov, ceir, оўшч,
  { {0xafdb00d1,0x8c1a0063,0x44240a84,0x00000000}},	//   ljøs, _גורי, dem_,
  { {0x64420027,0x44240250,0x442f0a85,0x00000000}},	//   _anoi, eem_, _sag_,
  { {0x442f0273,0xb4c1016a,0x9608000d,0x00000000}},	//   _pag_, ंदे_, рэча_,
  { {0x44240a86,0x64420025,0xe894000d,0x00000000}},	//   gem_, _cnoi, _дась,
  { {0x442f00dd,0x753a0a87,0x83fd013d,0x00000000}},	//   _vag_, _ertz, lhők,
  { {0x442f0a88,0x7c240a89,0x9f4201c2,0x00000000}},	//   _wag_, zeir, jaká_,
  { {0x442f0a8a,0x236d0045,0x25570080,0x00000000}},	//   _tag_, szej_, _dělá_,
  { {0x7c240016,0x387d002b,0x291301a8,0x00000000}},	//   xeir, niwr_, itxa_,
  { {0x7c240a8b,0x6d410a8c,0x6d5c0a8d,0x00000000}},	//   veir, ålan, wyra,
  { {0x387d001f,0x93c2003b,0xea000013,0x00000000}},	//   hiwr_, ţăto, _đắn_,
  { {0x7c240a8e,0x98a7004c,0x6da60a8f,0x00000000}},	//   teir, íně_, сива,
  { {0x3fe60a90,0xeb9a0a91,0x7c2400be,0x00000000}},	//   _ужив, гиб_, ueir,
  { {0x64aa02f4,0x387d0185,0x7c240a92,0x00000000}},	// [c20] _přiz, diwr_, reir,
  { {0x7c240a93,0x0f370063,0x78a20a94,0x00000000}},	//   seir, _פריט_, wlov,
  { {0x7d1e0a95,0x97c60021,0x1e570063,0x00000000}},	//   _upps, مقاو, _השיר_,
  { {0x673b04d0,0x18a6047e,0x387d002b,0x00000000}},	//   _bruj, щаем, giwr_,
  { {0x673b0331,0x78a2073c,0x44240a96,0x00000000}},	//   _cruj, rlov, vem_,
  { {0x44240045,0x78a20a97,0x64420a98,0x00000000}},	//   wem_, slov, _snoi,
  { {0x78a20a99,0x26090053,0x27e00014,0x00000000}},	//   plov, _सारी_, ðins_,
  { {0x44240a9a,0xb8de0053,0x387d002b,0x00000000}},	//   uem_, ुआ_, ciwr_,
  { {0xe7370055,0xafdb0031,0xc1ea0086,0x00000000}},	//   _лет_, kjør, льне_,
  { {0x3d190053,0x6f060a9b,0x44240a9c,0x00000000}},	//   _पहले_, dukc, sem_,
  { {0x3a370063,0x1a9b0047,0x44240a9d,0x00000000}},	//   זרים_, רייע, pem_,
  { {0x9f4b0164,0x20050078,0xc9530063,0x00000000}},	//   lacé_, ėlio_, למת_,
  { {0xa01b00ea,0x80ca0053,0x321a005d,0x00000000}},	//   lnök, _संवे, _ميشد_,
  { {0x63a20273,0xafdb0031,0x9f4b0003,0x00000000}},	//   _iyon, gjør, nacé_,
  { {0xdd3a000c,0x127b0047,0x629a0a9e,0x00000000}},	//   văţa, _גאגע, moto,
  { {0x69d800ea,0x63a20a9f,0x629a0aa0,0x00000000}},	//   űvel, _kyon, loto,
  { {0x62880441,0x6d480137,0x5ea50021,0x00000000}},	// [c30] ondo, ädar, _ومعل,
  { {0xe9ab014d,0x629a0aa1,0x1ed80044,0x00000000}},	//   هدان_, noto, _ابيب_,
  { {0xdd3a003b,0x63a20aa2,0x62880aa3,0x00000000}},	//   răţa, _lyon, indo,
  { {0x27e9006d,0xbd88007e,0xf770007e,0x00000000}},	//   úan_, _چنین_, کام_,
  { {0x387d001f,0x63a20aa4,0x629a0aa5,0x00000000}},	//   riwr_, _nyon, koto,
  { {0xddc50080,0x34b30053,0xa565005d,0x00000000}},	//   _pohř, ुद्द, يگان,
  { {0x69c70031,0x63a20003,0x629a0aa6,0x00000000}},	//   _igje, _ayon, doto,
  { {0x673b0aa7,0xe459032d,0x62880aa8,0x00000000}},	//   _truj, ржи_, endo,
  { {0x60ca00bd,0x27ef0014,0x61ea004d,0x00000000}},	//   _aufm, magn_, _befl,
  { {0x629a0aa9,0x6e21004b,0x99580066,0x00000000}},	//   goto, õlbl, láša_,
  { {0xdddc0006,0x63a20aaa,0x60260aab,0x00000000}},	//   sirū, _eyon, одна,
  { {0x50460138,0xe45f0019,0x62880aac,0x00000000}},	//   цемб, ööd_, ando,
  { {0xe1ee0aad,0x629a0aae,0x8e5a005e,0x00000000}},	//   _ог_, boto, ајву_,
  { {0x61ea087d,0x629a0aaf,0x6f060ab0,0x00000000}},	//   _gefl, coto, rukc,
  { {0x8c7a005a,0x2c67004b,0xdb1d0014,0x00000000}},	//   ащат_, _sõda_, _ofsó,
  { {0x69d5006f,0x8c430ab1,0x6097005d,0x00000000}},	//   _afze, месе, _ونوس_,
  { {0x20e7013d,0x6a60004d,0x4bd90085,0x00000000}},	// [c40] lői_, _höfi, сься_,
  { {0x89f5000d,0x7d150046,0x6dfa01ce,0x00000000}},	//   зяцц, éfsá, _тхис_,
  { {0xc92a005a,0x38cb007e,0x6a600046,0x00000000}},	//   роеж_, لانی_, _jöfi,
  { {0x186a000a,0x629a0ab2,0x69da0053,0x00000000}},	//   јади_, zoto, _प्री,
  { {0x629a0035,0x41c90053,0x3ced007d,0x00000000}},	//   yoto, रशास, ćeve_,
  { {0x4733019d,0xd1380006,0x6d4f003b,0x00000000}},	//   ьніс, yvą_, ţiaţ,
  { {0x27ef00a4,0xafdb00d1,0x629a0ab3,0x00000000}},	//   bagn_, kjøp, voto,
  { {0x60c4004b,0x63a20ab4,0xa01b013d,0x00000000}},	//   _niim, _pyon, rnök,
  { {0x629a0ab5,0x2451011b,0xf3f50043,0x00000000}},	//   toto, _jámy_, ستيک,
  { {0x629a0ab6,0x628800ed,0xfb1b0063,0x00000000}},	//   uoto, undo, סוימ,
  { {0x61ea0026,0x6e21004b,0xfc3f008d,0x00000000}},	//   _vefl, õlbm, _khít_,
  { {0x7ea00137,0x6d4100a5,0x629a0ab7,0x00000000}},	//   köps, ålam, soto,
  { {0x60c4053b,0xdfa70021,0x628f0003,0x00000000}},	//   _diim, تحدي, écoc,
  { {0xb2370044,0x6dc700de,0x00000000,0x00000000}},	//   _وكنا_, تزحل,   ,
  { {0xa6e90013,0xeda40054,0x271e0023,0x00000000}},	//   _giươ, дшто, lānā_,
  { {0x3e540058,0x4bdb005d,0xb4fb069a,0x00000000}},	//   _aştı_, شبرد_, יפלי,
  { {0x27ef0137,0x00000000,0x00000000,0x00000000}},	// [c50] vagn_,   ,   ,
  { {0x0b880086,0x3cfe01b3,0x19950062,0x00000000}},	//   істи_, štva_, пазя,
  { {0x0a680092,0x320c0022,0xd6220085,0x00000000}},	//   црти_, igdy_, _мiка,
  { {0x88c80086,0x48780054,0x00000000,0x00000000}},	//   ілів_, осія_,   ,
  { {0x87270021,0x69c704aa,0xe73904e3,0x00000000}},	//   تعام, _tgje, сел_,
  { {0x27ef06a5,0x69c700d1,0xd6290a8f,0x00000000}},	//   sagn_, _ugje, соке_,
  { {0xb0660072,0x673e008f,0xc984005e,0x00000000}},	//   nsää, āpja, _жути,
  { {0xb06600fe,0x17f80021,0x20e7013d,0x00000000}},	//   isää, _ورقة_, vői_,
  { {0x66f40001,0xc6a70092,0xa3b50042,0x00000000}},	//   _опту, _држи, छें_,
  { {0x27ed016d,0x20e700ea,0xe6640076,0x00000000}},	//   _heen_, tői_, _отхо,
  { {0x60c40019,0x27ed00e5,0x61450ab8,0x00000000}},	//   _piim, _keen_, чена,
  { {0xc4d20063,0x26c50ab9,0x4375007b,0x00000000}},	//   _נגד_, _hilo_, _нулт,
  { {0x60c40aba,0x27ed00f5,0x92a40051,0x00000000}},	//   _viim, _meen_, ółcz,
  { {0xed5a0abb,0x25a5004b,0x27ed0abc,0x00000000}},	//   бог_, _kyll_, _leen_,
  { {0x60c4024a,0x26c50abd,0x62810abe,0x00000000}},	//   _tiim, _milo_, milo,
  { {0x62810abf,0x27ed006f,0xec7706da,0x00000000}},	//   lilo, _neen_, ппс_,
  { {0x2d850003,0xb066004b,0x628100dd,0x00000000}},	// [c60] ûler_, asää, oilo,
  { {0x62810529,0x26c50ac0,0x7c360ac1,0x00000000}},	//   nilo, _nilo_, sdyr,
  { {0x27ed03e9,0x2f160146,0x62810ac2,0x00000000}},	//   _been_, læg_, iilo,
  { {0xa8000080,0x64590ac3,0x62810ac4,0x00000000}},	//   příč_, _nowi, hilo,
  { {0x6281007a,0x26c5065f,0x16340ac5,0x00000000}},	//   kilo, _bilo_, деля,
  { {0x6b890ac6,0x98ac005b,0xdef7009a,0x00000000}},	//   _þega, ılır_, למנט_,
  { {0x628100c3,0x34940088,0x64590ac7,0x00000000}},	//   dilo, макр, _bowi,
  { {0x27ed0ac8,0xc955000d,0x64590ac9,0x00000000}},	//   _geen_, _ўтры, _cowi,
  { {0x64590051,0x87f9000d,0x26c50aca,0x00000000}},	//   _dowi, _фэст_, _filo_,
  { {0x25a50a2e,0x62810acb,0x271e001c,0x00000000}},	//   _fyll_, gilo, rānā_,
  { {0x76480051,0xecbe0042,0xc5690044,0x00000000}},	//   _indy, ्दाफ, _وحمل_,
  { {0xa3e60161,0x7af6024a,0xdfd80062,0x00000000}},	//   _बजट_, ksyt, зър_,
  { {0x6a60007a,0x53340189,0x62810acc,0x00000000}},	//   _höfu, _целт, bilo,
  { {0x6447003d,0x6281000c,0x7af60acd,0x00000000}},	//   ējie, cilo, dsyt,
  { {0x386600ea,0x6e940ace,0x7ea00072,0x00000000}},	//   kkor_, хиру, töpr,
  { {0x9f4b0080,0xea00008b,0x765a0acf,0x00000000}},	//   lací_, _đạn_, _loty,
  { {0xb06600fe,0x7af600d1,0xddca003b,0x00000000}},	// [c70] ssää, gsyt, _înşi,
  { {0x27ed0034,0x9f4b0080,0xa01b00ea,0x00000000}},	//   _seen_, nací_, gnöv,
  { {0x80a4007e,0x32d2008b,0xacb5005e,0x00000000}},	//   _زمین, _lây_, _обољ,
  { {0x2c09007e,0x62810ad0,0x26c50ad1,0x00000000}},	//   _بعدی_, zilo, _silo_,
  { {0x9f4b0080,0x765a001f,0xcc560063,0x00000000}},	//   kací_, _boty, _חברי_,
  { {0x64590ad2,0xdd1c0080,0x627901c2,0x00000000}},	//   _sowi, láše, lňov,
  { {0x64590045,0x765a0ad3,0x27ed015e,0x00000000}},	//   _powi, _doty, _teen_,
  { {0x386600c7,0x32d2001b,0x2ca9002c,0x00000000}},	//   ckor_, _bây_, nlad_,
  { {0x2ca9001f,0x32d2008b,0x62810ad4,0x00000000}},	//   ilad_, _cây_, tilo,
  { {0x32d2008b,0x2ca90ad5,0x2f1601e1,0x00000000}},	//   _dây_, hlad_, væg_,
  { {0x62810529,0x386d04aa,0x2ca90ad6,0x00000000}},	//   rilo, _kler_, klad_,
  { {0x627901d9,0x62810ad7,0x7af60072,0x00000000}},	//   jňov, silo, ysyt,
  { {0x32d2001b,0x2ca90ad8,0x6281055b,0x00000000}},	//   _gây_, dlad_, pilo,
  { {0x7cd500eb,0x248d00c3,0x2f1601e1,0x00000000}},	//   _sąra, lnem_, ræg_,
  { {0x6da30ad9,0x2d950ada,0x248d0adb,0x00000000}},	//   вира, ертс, onem_,
  { {0x248d0adc,0x3cfe0add,0x6a600137,0x00000000}},	//   nnem_, štvo_, _löft,
  { {0x248d00bd,0x32d2001b,0x3ced007d,0x00000000}},	// [c80] inem_, _xây_, ćeva_,
  { {0x7af60051,0x2bde0053,0x77f80053,0x00000000}},	//   rsyt, _फ्रा, ुल्क_,
  { {0x2ca90ade,0x386d007d,0x9f420066,0x00000000}},	//   blad_, _bler_, jakú_,
  { {0x9f4b0080,0xe7aa03d1,0x20d3008b,0x00000000}},	//   zací_, овел_, _mãi_,
  { {0xfc3f0025,0x20d3008b,0x248d0adf,0x00000000}},	//   _thír_, _lãi_, dnem_,
  { {0xa3c10053,0x38660ae0,0xa01b00a5,0x00000000}},	//   ंधन_, skor_, lnöt,
  { {0x386d01e3,0x9f4b016b,0xceb300b5,0x00000000}},	//   _fler_, vací_, דיג_,
  { {0x628f0003,0x29180089,0x83340330,0x00000000}},	//   écon, _iqra_, ених,
  { {0x41c90053,0xd6260021,0x9f4b0260,0x00000000}},	//   रशंस, _يعطي, tací_,
  { {0x20d3008b,0x41540376,0x32d2008b,0x00000000}},	//   _bãi_, евос, _vây_,
  { {0x9f4b0080,0x248d0ae1,0x20d3008b,0x00000000}},	//   rací_, bnem_, _cãi_,
  { {0x32d2001b,0xc1780078,0x246c0051,0x00000000}},	//   _tây_, lbėk_, yśmy_,
  { {0x80ca0053,0x6d480137,0x6d5a0ae2,0x00000000}},	//   _संके, ådan, ätan,
  { {0x8d6b000a,0x2ca9001f,0x2005005b,0x00000000}},	//   ојба_, wlad_, şli_,
  { {0x44fa001c,0x27e600ca,0x62790061,0x00000000}},	//   nī_, kbon_, tňov,
  { {0x2ca900a4,0xbae50021,0x4fc70121,0x00000000}},	//   ulad_, فكري, _оспа,
  { {0x7b180076,0x2ca90ae3,0x2d9e004d,0x00000000}},	// [c90] мотр_, rlad_, üter_,
  { {0x248d0ae4,0xce6b0a29,0x387f006c,0x00000000}},	//   znem_, _фрид_, _smur_,
  { {0x2ca900a5,0x321e00e5,0xdb06004c,0x00000000}},	//   plad_, ifty_, _vzká,
  { {0x3a380345,0xf8b1005d,0x59df0042,0x00000000}},	//   _earp_, اکس_, _प्रर,
  { {0x290c0146,0x248d00c3,0xcc760063,0x00000000}},	//   _ådan_, vnem_, _נעשה_,
  { {0x8cb90161,0xb0cf0053,0x45350062,0x00000000}},	//   ्दको, _संलग, ехит,
  { {0x248d00c3,0xe5a20086,0xa01b0072,0x00000000}},	//   tnem_, лиши, nnös,
  { {0x387f053b,0x20d3008b,0x7c2d0ae5,0x00000000}},	//   _umur_, _rãi_, near,
  { {0x248d0ae6,0x20d30013,0xa01b0050,0x00000000}},	//   rnem_, _sãi_, tiön,
  { {0x248d00c3,0x26df0035,0x7c2d0ae7,0x00000000}},	//   snem_, _ituo_, hear,
  { {0x00860ae8,0x248d0ae9,0x3219056c,0x00000000}},	//   елно, pnem_, ęsy_,
  { {0x7c2d0aea,0xcea90aeb,0x72d50094,0x00000000}},	//   jear, _הי_, _зодф,
  { {0x644b0aec,0x2ca000e5,0xf8b20047,0x00000000}},	//   _ingi, void_, טשט_,
  { {0x442d0aed,0x8235005d,0x27e60075,0x00000000}},	//   lee_, _سرتا, zbon_,
  { {0xfcb60076,0x7c2d0025,0x6fa00042,0x00000000}},	//   ещаю, fear, _गुरू,
  { {0x7c2d0aee,0x442d0aef,0xdca60af0,0x00000000}},	//   gear, nee_, хаби,
  { {0xac070088,0x2ca00af1,0xab270af2,0x00000000}},	// [ca0] энта_, roid_, нота_,
  { {0x27ff00e3,0x7c2d002b,0x442d0af3,0x00000000}},	//   _adun_, aear, hee_,
  { {0x442d0af4,0xa8060002,0x27e00331,0x00000000}},	//   kee_, езел, ñino_,
  { {0x7c2d0af5,0x7d0e00a4,0x6e2e00ea,0x00000000}},	//   cear, mubs, lebb,
  { {0x3a3800eb,0x27e60af6,0xf7430699,0x00000000}},	//   _tarp_, rbon_, лецо,
  { {0xe45f00fe,0x644b02ea,0x20000150,0x00000000}},	//   öön_, _angi, _ldii_,
  { {0x7ae40af7,0x442d0af8,0x2b400af9,0x00000000}},	//   lpit, fee_, lvic_,
  { {0x7ae40009,0x442d0afa,0x44fa001c,0x00000000}},	//   opit, gee_, rī_,
  { {0x7ae400fe,0x44fa008f,0xb05b0072,0x00000000}},	//   npit, sī_, nmäe,
  { {0x75d60021,0x644b0afb,0xda100053,0x00000000}},	//   _أيضا, _engi, ालित_,
  { {0xd48f0afc,0x018a015a,0x7c2d04aa,0x00000000}},	//   _бр_, ящий_, year,
  { {0x7f440003,0x442d0afd,0xf9930063,0x00000000}},	//   _briq, cee_, טרת_,
  { {0x69dc048e,0x387b0047,0x69ce0afe,0x00000000}},	//   _ofre, לטטױ, _ogbe,
  { {0x6e2e00ea,0x9f4b00cd,0x78a2004e,0x00000000}},	//   gebb, racà_, hoov,
  { {0x3ced007d,0xceeb007e,0xa01b0072,0x00000000}},	//   ćevo_, _کربن_, liöm,
  { {0xa01b0354,0x69dc0aff,0x7f850044,0x00000000}},	//   rnös, _afre, _للعن,
  { {0xddc50024,0x9f530051,0x7c2d0b00,0x00000000}},	// [cb0] _dlhš, ędów_, rear,
  { {0x442d0b01,0x6f0f01f4,0x7c2d0b02,0x00000000}},	//   zee_, mucc, sear,
  { {0x7c2d0037,0x6f0f0b03,0x6f1d004d,0x00000000}},	//   pear, lucc, ltsc,
  { {0xdddc0006,0x6f1d06aa,0x7658004c,0x00000000}},	//   mirš, otsc, ejvy,
  { {0x442d0b04,0x6f0f0314,0x69dc002b,0x00000000}},	//   vee_, nucc, _ffre,
  { {0x6d4a0027,0x442d0b05,0x6f1d0b06,0x00000000}},	//   _áfac, wee_, itsc,
  { {0xdd03001c,0x9181008b,0x628f0003,0x00000000}},	//   ērķa, iệc_, écom,
  { {0x6e2e013d,0x20ee004c,0x04450142,0x00000000}},	//   zebb, dři_, теин,
  { {0x36d5019d,0x442d0034,0x2ba70053,0x00000000}},	//   _розр, ree_, _कुमा,
  { {0x6f0f0b07,0xb1450086,0x69dc0b08,0x00000000}},	//   ducc, внол, _xfre,
  { {0x442d0b09,0xd00a0b0a,0x8ccd0053,0x00000000}},	//   pee_, мене_, _दंगो,
  { {0x6f1d0b0b,0x6e2e0b0c,0x59c30042,0x00000000}},	//   ftsc, webb, वेयर,
  { {0x3e740137,0x547a0063,0x6d450b0d,0x00000000}},	//   _läte_, _קטנו, _arha,
  { {0xdee30b0e,0x33760063,0xe72e01ce,0x00000000}},	//   рори, _בתנך_, сеy_,
  { {0x6e2e02f6,0xada60b0f,0x6f1d0122,0x00000000}},	//   rebb, тавл, atsc,
  { {0x2c7502fb,0x69dc0b10,0x6e2e00ea,0x00000000}},	//   _nådd_, _sfre, sebb,
  { {0x6d450199,0x7d1c00c3,0x6b6301e8,0x00000000}},	// [cc0] _erha, strs, акта,
  { {0x5db60021,0xbb430121,0x09e60505,0x00000000}},	//   _لإجر, шеук, тожн,
  { {0x1bea0121,0x7ae40b11,0xb05b078c,0x00000000}},	//   _одни_, spit, smäe,
  { {0xe45f004b,0xe7860320,0x7ae40b12,0x00000000}},	//   ööl_, куло, ppit,
  { {0x62830066,0x78a2004b,0xb05b004d,0x00000000}},	//   _omno, roov, lmäc,
  { {0x20ee0080,0x78a2004b,0xa9060021,0x00000000}},	//   yři_, soov, _لبرن,
  { {0x91fc001c,0x6e23005b,0xafdb00b9,0x00000000}},	//   skāk, _önbe, ldøe,
  { {0x39470146,0x63ab0831,0x04630121,0x00000000}},	//   ænse_, _bygn, итым,
  { {0x7eb200d1,0xe61a0690,0xd4330021,0x00000000}},	//   væpn, _ода_, شعيب,
  { {0x63ab0b13,0x20ee004c,0x8556005d,0x00000000}},	//   _dygn, tři_, _لیتر_,
  { {0x60f80088,0xb505007e,0x7c2600c2,0x00000000}},	//   эння_, _مظنو, _obkr,
  { {0x30a4005a,0xdddc0006,0x64a3000d,0x00000000}},	//   иряв, virš, _каха,
  { {0x6f1d0375,0xd36f00f2,0xa01b0072,0x00000000}},	//   utsc, _وهم_, liök,
  { {0x2c75010a,0x6f1d051d,0x6f0f0b14,0x00000000}},	//   _måde_, rtsc, rucc,
  { {0xeca7000a,0x6f0f0b15,0x62880b16,0x00000000}},	//   вјан, succ, mido,
  { {0x62880b17,0x20050078,0x26cc0b18,0x00000000}},	//   lido, ėlis_, _lido_,
  { {0x09bd0053,0x2c750b19,0xfe6e007e,0x00000000}},	// [cd0] ्ख्य, _nåde_, زگی_,
  { {0xadbd0088,0x62880b1a,0x99670002,0x00000000}},	//   _напi, nido, ктел,
  { {0x49a400e1,0x67290b1b,0x60cd0b1c,0x00000000}},	//   ајца, _spej, _kiam,
  { {0x24580024,0x2c7506a3,0xd5e8008b,0x00000000}},	//   _témy_, _både_, _đón,
  { {0xef1f005b,0x62880b1d,0xf77000f2,0x00000000}},	//   ntü_, kido, ياه_,
  { {0x7c3d0228,0xa3ac016a,0x98b3005b,0x00000000}},	//   _hasr, _गरज_, ıdır_,
  { {0x62880b1e,0x85780062,0x63ab0051,0x00000000}},	//   dido, ксът_, _sygn,
  { {0x6288001c,0xef1f0058,0x60cd0960,0x00000000}},	//   eido, ktü_, _niam,
  { {0x7c3d005b,0x26cc0b1f,0x99830078,0x00000000}},	//   _masr, _fido_, _tajų_,
  { {0x62880b20,0x3cfe00c2,0x7c3d0139,0x00000000}},	//   gido, štvi_, _lasr,
  { {0x65940002,0x64150021,0x6d40008f,0x00000000}},	//   _кафу, _مواط, āmak,
  { {0x7c3d0b21,0x60cd0b22,0x82d90062,0x00000000}},	//   _nasr, _ciam, _зддс_,
  { {0x69aa016a,0x62880b23,0x443f0026,0x00000000}},	//   _जुनी, bido, mdu_,
  { {0x62880b24,0x443f0b25,0x62830b26,0x00000000}},	//   cido, ldu_, _umno,
  { {0x60cd0290,0x443d00a4,0xe8140053,0x00000000}},	//   _fiam, _kaw_, _डाला_,
  { {0x60cd0b27,0x645b0b28,0xb05b004d,0x00000000}},	//   _giam, njui, rmäc,
  { {0x4bd90b29,0x8c43005a,0x3b0705fb,0x00000000}},	// [ce0] ться_, щете, лето_,
  { {0x443d04bf,0x443f0072,0x2c750b2a,0x00000000}},	//   _law_, hdu_, _råde_,
  { {0x2bc50053,0xb05b0072,0x63ae0022,0x00000000}},	//   लेबा, lmäa, ębni,
  { {0x3860007a,0x26cc0b2b,0x78bb0016,0x00000000}},	//   ðir_, _sido_, _chuv,
  { {0x443f0742,0x26cc006d,0x4bfb0063,0x00000000}},	//   ddu_, _pido_, _אלכס,
  { {0x0f37014e,0x443f0b2c,0x5694007b,0x00000000}},	//   טרנט_, edu_, јакт,
  { {0x62880b2d,0x443d057c,0xb05b0072,0x00000000}},	//   vido, _baw_, hmäa,
  { {0xdd0400eb,0x38b50137,0x44b40002,0x00000000}},	//   ūrėt, påra_, јбис,
  { {0x60cd0025,0xb27400d7,0x26cc017d,0x00000000}},	//   _riam, илиш, _tido_,
  { {0x60cd0b2e,0x645b00fe,0x443f0b2f,0x00000000}},	//   _siam, ajui, adu_,
  { {0xa0550086,0x62880b30,0x443d00f1,0x00000000}},	//   авні, rido, _faw_,
  { {0xf5370063,0x62880b31,0xdfd10021,0x00000000}},	//   _תנאי_, sido, تيح_,
  { {0x62880b32,0x00000000,0x00000000,0x00000000}},	//   pido,   ,   ,
  { {0x64400026,0x6b890046,0xef1f0075,0x00000000}},	//   ldmi, _þegi, rtü_,
  { {0xdcbb005a,0x64400b33,0xef1f005b,0x00000000}},	//   еща_, odmi, stü_,
  { {0xaed5000a,0x64400b34,0x61fa0b35,0x00000000}},	//   _коиш, ndmi, latl,
  { {0x3b550001,0x6d4a007a,0x6e950086,0x00000000}},	// [cf0] шкар, _áfan, _випу,
  { {0xdb2400ea,0x61fa0b36,0x443f0b37,0x00000000}},	//   ásán, natl, zdu_,
  { {0xd7d50001,0x39470026,0x628f072e,0x00000000}},	//   ажењ, íns_, écoi,
  { {0xfe7f002b,0xc1780078,0x61fa0b38,0x00000000}},	//   opïo_, lbės_, hatl,
  { {0x07a502a9,0xe7390b39,0x443f073c,0x00000000}},	//   јалн, тел_, vdu_,
  { {0x443d0b3a,0x64400b3b,0x6a720014,0x00000000}},	//   _saw_, edmi, _hæfn,
  { {0x3e74004b,0x443f01e1,0x443d0b3c,0x00000000}},	//   _jäta_, tdu_, _paw_,
  { {0x443f0b3d,0x3e740b3e,0xb05b0072,0x00000000}},	//   udu_, _mäta_, ymäa,
  { {0x43750b3f,0x645b068f,0xfc3f0026,0x00000000}},	//   руйт, rjui, _maí_,
  { {0xc6a7041d,0x2ef2001f,0x64400b40,0x00000000}},	//   _срби, _rwyf_, admi,
  { {0x6e3e00f3,0x7c24007a,0x443d001f,0x00000000}},	//   _rapb, yfir, _taw_,
  { {0x44f3003b,0x3f6a0b41,0x61fa0b42,0x00000000}},	//   mţ_, вимо_, aatl,
  { {0x61fa0058,0x8234005d,0x00000000,0x00000000}},	//   batl, _گرنا,   ,
  { {0x91e50001,0x61450766,0x200c0058,0x00000000}},	//   _токе, _века, şdi_,
  { {0x44f3000c,0x7c240b43,0xa3dc0053,0x00000000}},	//   nţ_, tfir, तुक_,
  { {0xb05b0b44,0x3e7b0080,0x9ce5000d,0x00000000}},	//   lmän, eště_, сцёл,
  { {0xfc3f0016,0xb05b0137,0x7c240b45,0x00000000}},	// [d00] _daí_, omän, rfir,
  { {0x7c240b46,0xab270b47,0x7bdf0b48,0x00000000}},	//   sfir, рофа_, acqu,
  { {0xd00f006a,0x19b90088,0x673b0b49,0x00000000}},	//   _علی_, гуць_, _asuj,
  { {0xc18c0047,0x8c460b4a,0xa01b0072,0x00000000}},	//   עטאָ, _теме, tiöi,
  { {0x27e902dd,0xbb430086,0x9168008b,0x00000000}},	//   ñana_, _деяк, _mức_,
  { {0xbb43000a,0x3cfe027c,0xa01b00fe,0x00000000}},	//   _ќерк, štvu_, riöi,
  { {0x44240089,0x61fa0b4b,0xa5070002,0x00000000}},	//   tfm_, vatl, аеја_,
  { {0x98a30b4c,0x64400b4d,0x656a00a3,0x00000000}},	//   _дисе, udmi, ryfh,
  { {0xc1780006,0x61fa00ea,0xd2500021,0x00000000}},	//   ybės_, tatl, كنة_,
  { {0x67220078,0x27e1004c,0xdd1c0066,0x00000000}},	//   mtoj, ěhne_, _záťa,
  { {0x2c750137,0x67220b4e,0x91680013,0x00000000}},	//   _låda_, ltoj, _bức_,
  { {0x67220b4f,0x61fa0b50,0x44320013,0x00000000}},	//   otoj, satl, _úy_,
  { {0x90980062,0x67220b51,0x61fa0b52,0x00000000}},	//   рвят_, ntoj, patl,
  { {0xea0000aa,0x672200eb,0x645d00fe,0x00000000}},	//   _đến_, itoj, ösiv,
  { {0x672200fe,0x1df80076,0x6e940121,0x00000000}},	//   htoj, ресы_, циру,
  { {0x2c7500c7,0x5c740ae8,0x115b0063,0x00000000}},	//   _båda_, олст, _ידוע,
  { {0xa9e70021,0xdb230058,0x9bc7030b,0x00000000}},	// [d10] لثان, _örüm, рёвк,
  { {0xd1380051,0x3e740137,0x2019004e,0x00000000}},	//   ową_, _täta_, lgsi_,
  { {0x67220b53,0xdd910049,0xb7d5009e,0x00000000}},	//   etoj, _روح_, مقاب,
  { {0x20190397,0x315700b5,0x286b0062,0x00000000}},	//   ngsi_, ייבן_, ързо_,
  { {0x6d5a0072,0x27200013,0xb05b0072,0x00000000}},	//   ätav, gòn_, ymän,
  { {0x78a20512,0xbb3a00b5,0x5a47000d,0x00000000}},	//   čova, _געשי, _тэма,
  { {0x19940062,0x28f80499,0x6e350022,0x00000000}},	//   _даря, _весь_, iezb,
  { {0xd7c9007e,0x0d980063,0xfbdf00be,0x00000000}},	//   _موزه_, יכום_, _inês_,
  { {0xb05b01bb,0xd2a90121,0xf7850044,0x00000000}},	//   tmän, лкие_, _الذَ,
  { {0x27fd001f,0x9168008b,0x2ca9002b,0x00000000}},	//   lawn_, _sức_, hoad_,
  { {0x61f801f7,0x29010b54,0xb05b0b55,0x00000000}},	//   _devl, nsha_, rmän,
  { {0x45b60063,0x307a0021,0xf9920063,0x00000000}},	//   _הפעל_, احدة_, לרי_,
  { {0x248d003d,0xb05b0072,0x889a0149,0x00000000}},	//   miem_, mmäl, רברי,
  { {0xd5b1001b,0x248d001c,0x27fd001f,0x00000000}},	//   _ký_, liem_, hawn_,
  { {0x9168008b,0x628f0003,0x2d9e0058,0x00000000}},	//   _tức_, écou, çte_,
  { {0x672200eb,0x248d0b56,0xb05b0137,0x00000000}},	//   ytoj, niem_, nmäl,
  { {0xd5b1001b,0xf1bf0080,0x6e350b57,0x00000000}},	// [d20] _lý_, řád_, bezb,
  { {0xb05b0b58,0x6f040b59,0x764106f1,0x00000000}},	//   hmäl, _ivic, _naly,
  { {0xfe37014e,0x248d0b5a,0x69260002,0x00000000}},	//   _פרטי_, kiem_, смеа,
  { {0x248d003d,0x91fc003d,0x17fa0021,0x00000000}},	//   jiem_, nkār, اراة_,
  { {0x248d003d,0xd1380051,0x366a0002,0x00000000}},	//   diem_, zwą_, ладо_,
  { {0x27200013,0x67220b51,0x47330085,0x00000000}},	//   ròn_, rtoj, яніс,
  { {0x764100eb,0x9f590003,0x91fc008f,0x00000000}},	//   _daly, rasé_, kkār,
  { {0xb176008b,0x248d0b5b,0x76430022,0x00000000}},	//   _ngượ, giem_, adny,
  { {0xa3a80042,0xa01b00a5,0x988b009a,0x00000000}},	//   _खुश_, lhög, _עָלֵ,
  { {0xda7b0047,0xd1380022,0x7c360b5c,0x00000000}},	//   ָנטר, twą_, heyr,
  { {0x909906b4,0x7c360072,0xd011002a,0x00000000}},	//   ивот_, keyr, ولد_,
  { {0xbec3008f,0xd1380022,0x248d0b5d,0x00000000}},	//   ķīmi, rwą_, ciem_,
  { {0x5f94005a,0x3e970021,0x94bb009a,0x00000000}},	//   зият, مؤسس, _עמדת,
  { {0x64420025,0x539b0063,0x7d15008f,0x00000000}},	//   _haoi, _גידו, tuzs,
  { {0xb05b00fe,0x52750002,0xa1930085,0x00000000}},	//   lmäm, _ќучу, _нашч,
  { {0x7d15013d,0x9c390131,0x7643056c,0x00000000}},	//   ruzs, јпат_, zdny,
  { {0x2ca90b5e,0x64420b5f,0xd9f902d8,0x00000000}},	// [d30] road_, _maoi, инац_,
  { {0x7f4d0b60,0xf9c7047e,0xacf80051,0x00000000}},	//   _iraq, бщен, _żółt,
  { {0xb05b00fe,0x78a20195,0x2901007d,0x00000000}},	//   ymäl, čovn, usha_,
  { {0x6d40003d,0xdb0f0164,0x644200a4,0x00000000}},	//   āmat, _lycé, _naoi,
  { {0x76410006,0x248d0b61,0xbc1a0063,0x00000000}},	//   _paly, viem_, _דורש,
  { {0xf1c80161,0x248d0051,0x91fc001c,0x00000000}},	//   रधान, wiem_, zkār,
  { {0x248d003d,0x9f40007a,0x2b490150,0x00000000}},	//   tiem_, _leið_, lvac_,
  { {0x7b08007a,0x13090b62,0x7aed0b63,0x00000000}},	//   _ástæ, аний_, opat,
  { {0xb7bd0529,0x64420027,0x248d0b61,0x00000000}},	//   _obţi, _daoi, riem_,
  { {0x248d003d,0x2f100026,0xbb3c0047,0x00000000}},	//   siem_, _lögð_, רעזי,
  { {0x64420027,0x645d0b64,0x91fc001c,0x00000000}},	//   _faoi, ösis, tkār,
  { {0x9fca026b,0x7aed0104,0xb1840066,0x00000000}},	//   игна_, kpat, íťaz,
  { {0x98c50006,0xe28e07f0,0x083a0047,0x00000000}},	//   štės_, _жа_, בערל,
  { {0xc5f90047,0x91fc008f,0x539a069a,0x00000000}},	//   יפֿט, skār, _דינו,
  { {0xa01b0b65,0xa3c10053,0x7aed0b66,0x00000000}},	//   giös, ंधक_, epat,
  { {0x6f00000f,0x7f4d017d,0xa01b00a5,0x00000000}},	//   ámcs, _fraq, vhög,
  { {0x7aed00bb,0x2ab4004b,0xa01b0072,0x00000000}},	// [d40] gpat, läbi_, riöt,
  { {0x63b600d1,0x6d5a0072,0xf2210042,0x00000000}},	//   _øyne, ätas, _माफ़_,
  { {0x7aed0b67,0x6ee5007e,0x6497001c,0x00000000}},	//   apat, _وسیل, rģij,
  { {0x628600ea,0xa01b0b68,0xd7ef0021,0x00000000}},	//   ékoz, rhög, نكم_,
  { {0x6d430014,0xa01b0137,0x2c7c0046,0x00000000}},	//   _ánar, shög, _vídd_,
  { {0x64420025,0x6b63000d,0x6497003b,0x00000000}},	//   _saoi, _ўкра, nţif,
  { {0x2aaf004d,0x69230b69,0x9e5b069a,0x00000000}},	//   rübt_, _омра, יכסט,
  { {0xe8140053,0x9998008f,0xa3e50053,0x00000000}},	//   _डाटा_, _garš_, बुल_,
  { {0xa01b0244,0xd5a4005d,0x66e50044,0x00000000}},	//   ziös, _کلای, _فألق,
  { {0x026a0086,0x3f820b6a,0x9f400014,0x00000000}},	//   рший_, dzku_, _reið_,
  { {0x3a37014e,0x2ee90b6b,0x7aed0051,0x00000000}},	//   חרים_, _staf_, zpat,
  { {0xb05b00fe,0x232a0336,0x628f0b6c,0x00000000}},	//   mmäk, _води_, écor,
  { {0xe29a0138,0xb05b0072,0xd2520044,0x00000000}},	//   _кад_, lmäk, _ينص_,
  { {0x2907000f,0x628a004d,0x2f100014,0x00000000}},	//   ának_, _umfo, _sögð_,
  { {0xdb060072,0x12a90021,0xdc8b0239,0x00000000}},	//   _lykä, _ادنى_, асал_,
  { {0xe57100b5,0x69d80006,0x7f4d0b6d,0x00000000}},	//   ײַל_, žvel, _traq,
  { {0x7aed0035,0xb05b0072,0x6d5a0b6e,0x00000000}},	// [d50] upat, hmäk, ätar,
  { {0x7aed0b6f,0x8e84005e,0x7d010046,0x00000000}},	//   rpat, _огње, álss,
  { {0xdc2f001c,0x629a0b70,0x7aed089c,0x00000000}},	//   ažād, into, spat,
  { {0x7aed0b71,0xf8070054,0x7c590044,0x00000000}},	//   ppat, ічен, _الحر_,
  { {0x78ab00b9,0x8cba0053,0xfc5a0063,0x00000000}},	//   rogv, ्षरो, _הכרמ,
  { {0x1af6009a,0x7f3c009d,0x00000000,0x00000000}},	//   _ממשל_, יעדו,   ,
  { {0xa5060062,0x2d830022,0x929d0022,0x00000000}},	//   пеща_, nzje_, jsła,
  { {0x629a0b72,0xc952009d,0xbd9c009d,0x00000000}},	//   ento, _אמל_, יסות,
  { {0xafdb01f2,0x383401dd,0xf773014d,0x00000000}},	//   gdøm, _інфр, _غار_,
  { {0xb05b0b73,0x7d08004c,0xaabd0042,0x00000000}},	//   lmäh, ádsk, ्गिक,
  { {0x02020088,0xe45f0019,0x91fc001c,0x00000000}},	//   эзэн, öös_, rkāp,
  { {0x629a0b74,0x55ba0063,0x92a40022,0x00000000}},	//   anto, _המעו, ółrz,
  { {0xc4840085,0x929d056c,0xaabd0082,0x00000000}},	//   _ўлік, asła, ्गाक,
  { {0xb05b0b75,0x92b70044,0x02450044,0x00000000}},	//   hmäh, _بحصا, _رَبَ,
  { {0x7c2f000c,0xa01b0137,0x9993004c,0x00000000}},	//   _bbcr, riör, dexů_,
  { {0x8fa60054,0xaf0601f6,0xa7fd013d,0x00000000}},	//   _найе, _епил, _elűz,
  { {0x207b0047,0x8e560086,0x20020b76,0x00000000}},	// [d60] _לאקא, _етні, maki_,
  { {0x7c2f0146,0x20020b77,0xdb060051,0x00000000}},	//   _ebcr, laki_, _szkó,
  { {0xceb300b7,0x4ddb0063,0xe853007e,0x00000000}},	//   _איז_, _לחיו, کنند,
  { {0x38cb006a,0x18a30062,0x6f0600b9,0x00000000}},	//   مانی_, нахм, oskc,
  { {0x29130268,0x629a00f1,0x99f60085,0x00000000}},	//   arxa_, ynto, _няві,
  { {0xd6d90086,0x929d0051,0x20020075,0x00000000}},	//   іті_, ysła, haki_,
  { {0x20020b78,0x442f0b79,0xa6e9008d,0x00000000}},	//   kaki_, _bbg_, _nhươ,
  { {0x629a0b7a,0x20020211,0x399b0063,0x00000000}},	//   wnto, jaki_, _הילד,
  { {0x200201f7,0x6b8400bd,0x291a0b7b,0x00000000}},	//   daki_, nzig, lupa_,
  { {0xb05b024a,0xafdb01f2,0x877b0063,0x00000000}},	//   mmäi, rdøm, _האמי,
  { {0x2497006a,0xa6e9001b,0xdb2300ea,0x00000000}},	//   _کنند_, _chươ, _öröm,
  { {0x60c407b9,0x27e60b7c,0x35e20042,0x00000000}},	//   _chim, ncon_, _पलड़,
  { {0x6b840b7d,0x60c40035,0x3a3a00a5,0x00000000}},	//   jzig, _dhim, kepp_,
  { {0x291a0b7e,0xd3570063,0x539b0063,0x00000000}},	//   kupa_, _מידי_, _פיגו,
  { {0x20020009,0xeda40086,0xdddc005f,0x00000000}},	//   baki_, ешто, birž,
  { {0x30a40088,0x5cb9000d,0x60c4003b,0x00000000}},	//   _прыв, ілаў_, _ghim,
  { {0x3f9e01f7,0xcb340062,0x290e0046,0x00000000}},	// [d70] ştur_, нетъ, áfan_,
  { {0x99d70021,0x6d410046,0x2a6a0b7f,0x00000000}},	//   ستطا, ælas, _cobb_,
  { {0x290701da,0x291a00a4,0x6d410058,0x00000000}},	//   éna_, gupa_, çlad,
  { {0x3869007a,0x6a73005b,0x6b84004d,0x00000000}},	//   ðar_, _sıfı, bzig,
  { {0x6497000c,0xf72b000d,0x7c2d0b80,0x00000000}},	//   nţie, сцей_, mfar,
  { {0x442f0150,0x20020b81,0x7c2d0b82,0x00000000}},	//   _sbg_, zaki_, lfar,
  { {0x6f090080,0xa9340651,0x291a0b83,0x00000000}},	//   šech, _перш, cupa_,
  { {0x200200ac,0x7c2d0b84,0xb4b70042,0x00000000}},	//   xaki_, nfar, छते_,
  { {0x7c2d0b85,0x20020b86,0xd408005d,0x00000000}},	//   ifar, vaki_, ستيم_,
  { {0xa6e9001b,0x7c2d0616,0x60c40b87,0x00000000}},	//   _phươ, hfar, _shim,
  { {0x20020b88,0xb97a0047,0x213e001f,0x00000000}},	//   taki_, ַנשי, gwth_,
  { {0x66030b89,0xf4b6005d,0x00000000,0x00000000}},	//   lank, _قشنگ,   ,
  { {0x64490185,0x20020b8a,0x64590b8b,0x00000000}},	//   mdei, raki_, _inwi,
  { {0xa6e9001b,0x442d0b8c,0x200207b8,0x00000000}},	//   _thươ, lfe_, saki_,
  { {0x20020b8d,0x7c2d0036,0x6497003b,0x00000000}},	//   paki_, ffar, aţie,
  { {0xf1a7007e,0x27ff00bd,0x6b84004d,0x00000000}},	//   _واژه_, _neun_, tzig,
  { {0x6497000c,0x442d0359,0x3e740019,0x00000000}},	// [d80] cţie, ife_, _läti_,
  { {0x6b84004d,0x1996005e,0x66030b8e,0x00000000}},	//   rzig, мјер, jank,
  { {0x66030b8f,0xb80a0021,0x6459006f,0x00000000}},	//   dank, قيام_, _onwi,
  { {0x224700e8,0x2ee000ac,0x291a0b90,0x00000000}},	//   _lank_, _kuif_, rupa_,
  { {0x6449001f,0x2ee00003,0x7d1c0b91,0x00000000}},	//   ddei, _juif_, lurs,
  { {0x442d0b92,0x66030b93,0x6e3c05b2,0x00000000}},	//   efe_, gank, nerb,
  { {0x69dc0016,0x442d069e,0x6e3c0b94,0x00000000}},	//   _igre, ffe_, ierb,
  { {0x3ae400c7,0x660300fe,0xb05b00fe,0x00000000}},	//   _köp_, aank, lmäv,
  { {0x7ae20025,0x22470b95,0x66030b96,0x00000000}},	//   íoth, _bank_, bank,
  { {0x38660137,0x64490b97,0x442d0b98,0x00000000}},	//   ljor_, adei, afe_,
  { {0x018a0076,0x7c2d001f,0x6e3c0b99,0x00000000}},	//   ющий_, yfar, derb,
  { {0x7d1c007a,0x73c60021,0x1c1d0042,0x00000000}},	//   durs, _قيام, _फाइल_,
  { {0x7d1c00e8,0xdfd8005a,0x69dc0b9a,0x00000000}},	//   eurs, дър_, _ogre,
  { {0x53330086,0x69dc0b9b,0x764a00b9,0x00000000}},	//   _решт, _ngre, ndfy,
  { {0x76480089,0xc348008b,0xec6b0abb,0x00000000}},	//   _mady, _hổ_, орак_,
  { {0x6497003b,0x69dc03e1,0x660301f0,0x00000000}},	//   pţie, _agre, zank,
  { {0x7c2d0b9c,0x765a0b9d,0x6e3c0b9e,0x00000000}},	// [d90] rfar, _onty, berb,
  { {0x27ff00e8,0x68fc001f,0x7c2d0b9f,0x00000000}},	//   _seun_, _bwrd, sfar,
  { {0x5e5600b5,0x7d1c0ba0,0x6449001f,0x00000000}},	//   _װירע_, curs, ydei,
  { {0x6d450ba1,0x929d0022,0x765a0ba2,0x00000000}},	//   _isha, ysło, _anty,
  { {0x61ea0ba3,0x764800bb,0xc348008b,0x00000000}},	//   _offl, _bady, _nổ_,
  { {0x6f1d0290,0x68fc001f,0x8afa0063,0x00000000}},	//   iusc, _fwrd, _מהשי,
  { {0x66030ba4,0x68fc002b,0x629d0003,0x00000000}},	//   rank, _gwrd, ésom,
  { {0x765a0609,0xc348001b,0x6d450035,0x00000000}},	//   _enty, _bổ_, _msha,
  { {0xc348008b,0x628104bf,0x22470ba5,0x00000000}},	//   _cổ_, thlo, _pank_,
  { {0x272902dd,0xe1f10021,0xda0f0053,0x00000000}},	//   mún_, دسة_, ाणित_,
  { {0x442d00bd,0x9f5e005b,0x386d004b,0x00000000}},	//   pfe_, ştü_, _koer_,
  { {0x6e3c0ba6,0xf09f00cd,0x6f1d0b27,0x00000000}},	//   werb, gnà_, fusc,
  { {0x24180086,0x6d450ba7,0x22470ba8,0x00000000}},	//   _цією_, _asha, _tank_,
  { {0x387f00cd,0x386d00ac,0x7bdd00a4,0x00000000}},	//   _llur_, _loer_, _agsu,
  { {0x387f005b,0x7afd001f,0x66010ba9,0x00000000}},	//   _olur_, _awst, _melk,
  { {0x249f0026,0x660100ea,0x7d1c0baa,0x00000000}},	//   nnum_, _lelk, rurs,
  { {0x249f0026,0x6e3c0bab,0x1fb601dd,0x00000000}},	// [da0] inum_, perb, _яскр,
  { {0x387f017e,0x672b04aa,0x3205004c,0x00000000}},	//   _alur_, dtgj, naly_,
  { {0x76480bac,0x249f0bad,0x386600cd,0x00000000}},	//   _rady, knum_, tjor_,
  { {0x7648002c,0x3f7a0149,0x3205004c,0x00000000}},	//   _sady, ּאַס, haly_,
  { {0x2729048e,0x6136000f,0x386d0bae,0x00000000}},	//   gún_, _külö, _doer_,
  { {0x6601016b,0xc3480013,0xe769004c,0x00000000}},	//   _celk, _rổ_, nářů,
  { {0x249f007a,0x76480006,0xc348008b,0x00000000}},	//   fnum_, _vady, _sổ_,
  { {0x249f007a,0x66010019,0x54540795,0x00000000}},	//   gnum_, _eelk, твит,
  { {0xb05b00c7,0xcc3b00b5,0x6497001c,0x00000000}},	//   lläg, לעקט, eģis,
  { {0x2c7c006d,0x2ca00025,0x389800c2,0x00000000}},	//   _oído_, hnid_, ačrt_,
  { {0x2b910024,0xb05b00c7,0xd6cf0593,0x00000000}},	//   môcť_, nläg, _اقل_,
  { {0xc348001b,0x33f60021,0x69c30051,0x00000000}},	//   _tổ_, _أساس, żneg,
  { {0xb05b00bd,0xf09f00cd,0x9326007e,0x00000000}},	//   hläg, rnà_, _سرشن,
  { {0x6f1d0027,0xa01b087d,0xddde011b,0x00000000}},	//   rusc, chön, _kopř,
  { {0xac950071,0x6f1d0baf,0x4c950054,0x00000000}},	//   вавш, susc, вивс,
  { {0xdcb8011c,0xb05b0137,0x91bb009a,0x00000000}},	//   ещу_, dläg, _ממוי,
  { {0x64970529,0x613600ea,0x386d0bb0,0x00000000}},	// [db0] nţia, _fülö, _roer_,
  { {0xb05b0bb1,0x2ca0004b,0x6e25004d,0x00000000}},	//   amät, anid_, _uchb,
  { {0x6d450035,0x249f0014,0xb05b00a5,0x00000000}},	//   _usha, ynum_, gläg,
  { {0x660100fe,0xb05b00fe,0xb06600fe,0x00000000}},	//   _selk, mmäs, mpää,
  { {0xf7450bb2,0xd6db0bb3,0x386d04c6,0x00000000}},	//   тело, чте_, _voer_,
  { {0x29070139,0x64970078,0xe9d3007e,0x00000000}},	//   ánas_, dţia, _مغز_,
  { {0x32050080,0x386d00e8,0x27290025,0x00000000}},	//   valy_, _toer_, sún_,
  { {0x660103a8,0x249f0026,0xddde004c,0x00000000}},	//   _welk, unum_, _dopř,
  { {0xb05b00fe,0x249f0bb4,0x66010bb5,0x00000000}},	//   hmäs, rnum_, _telk,
  { {0x42550002,0x249f0014,0x44260bb6,0x00000000}},	//   ттит, snum_, _eco_,
  { {0x249f0026,0xb05b0bb7,0xa01b0014,0x00000000}},	//   pnum_, ymät, rhön,
  { {0x3e7400c7,0xdee60bb8,0xa01b0014,0x00000000}},	//   _lätt_, коми, shön,
  { {0x443f0bb9,0xab5b00ea,0x10a30a36,0x00000000}},	//   meu_, _szün, риян,
  { {0x63a400eb,0x644b0bba,0x6f0d0080,0x00000000}},	//   _žing, _hagi, _dvac,
  { {0x644b0bbb,0x2907003b,0x27ed004d,0x00000000}},	//   _kagi, ânal_, _ofen_,
  { {0x443f0bbc,0xb05b0137,0x7f860021,0x00000000}},	//   neu_, vläg, _للبن,
  { {0x443f0bbd,0x644b0bbe,0x7c2b00cd,0x00000000}},	// [dc0] ieu_, _magi, ògra,
  { {0xaa7b0026,0x644b0bbf,0x6a830002,0x00000000}},	//   _stýr, _lagi, алуа,
  { {0xb05b0bc0,0xa926047e,0x984a0062,0x00000000}},	//   mmär, тдел, дяла_,
  { {0x644b0bc1,0xb05b0bc2,0x63a40014,0x00000000}},	//   _nagi, rläg, _þing,
  { {0x443f0bc3,0xb05b00c7,0x27e00bc4,0x00000000}},	//   deu_, släg, žino_,
  { {0x7bc600c3,0xb05b0bc5,0xddde0080,0x00000000}},	//   _izku, pläg, _popř,
  { {0x644b06a7,0x443f0268,0x8546000d,0x00000000}},	//   _bagi, feu_, тэле,
  { {0x38c8006a,0x443f0bc6,0x644b0290,0x00000000}},	//   _سازی_, geu_, _cagi,
  { {0xb05b00c7,0xf2c60bc7,0x03c30200,0x00000000}},	//   kmär, ксон, исьм,
  { {0x6497000c,0xb05b00fe,0x7af60078,0x00000000}},	//   rţia, ymäs, ipyt,
  { {0x443f0bc8,0x78a201b3,0x644b0bc9,0x00000000}},	//   beu_, onov, _fagi,
  { {0x04460138,0x443f0bca,0x61f5005b,0x00000000}},	//   _једн, ceu_, ızla,
  { {0x6440005b,0x9f590137,0x44240bcb,0x00000000}},	//   memi, kaså_, mgm_,
  { {0x64970529,0x64400bcc,0x644b0022,0x00000000}},	//   nţin, lemi, _zagi,
  { {0x3e7400c7,0xac27000a,0xf708008b,0x00000000}},	//   _rätt_, кфак, hủ_,
  { {0x3e7401e3,0x7c240290,0x64400bcd,0x00000000}},	//   _sätt_, ggir, nemi,
  { {0x5a350431,0xb05b01bb,0xb0660072,0x00000000}},	// [dd0] лнат, smäs, spää,
  { {0x443f0bce,0xdce70051,0x753a003b,0x00000000}},	//   zeu_, zyję, _optz,
  { {0x64400bcf,0x83fd00ea,0x7af60051,0x00000000}},	//   kemi, rkőz, apyt,
  { {0x443f0268,0x6497003b,0xc19b0063,0x00000000}},	//   xeu_, eţin, ושבי,
  { {0x443f0bd0,0x3b640062,0x3e740137,0x00000000}},	//   veu_, _кърв, _tätt_,
  { {0x76240054,0x64400526,0xd626005e,0x00000000}},	//   иміз, eemi, гоше_,
  { {0x443f0bd1,0x644b0bd2,0x27ee004c,0x00000000}},	//   teu_, _pagi, émní_,
  { {0x64400004,0x69c7082a,0x03250002,0x00000000}},	//   gemi, _izje, гдин,
  { {0x443f0bd3,0x6497003b,0xd299071f,0x00000000}},	//   reu_, bţin, етні_,
  { {0x443f0bd1,0x644b0bd4,0x36d50bd5,0x00000000}},	//   seu_, _wagi, _созр,
  { {0xe4e7019d,0x44f5005a,0x443f0bc8,0x00000000}},	//   _різн, _спес, peu_,
  { {0xa3550049,0xa3ea0042,0x64400bd6,0x00000000}},	//   _مختص, _मलय_, cemi,
  { {0x6d41005b,0x99750051,0xb05b0bd7,0x00000000}},	//   çlan, nęła_, tmär,
  { {0x78a20008,0x539a009f,0xdee30bd8,0x00000000}},	//   znov, _אינו, сори,
  { {0x6497000c,0x81bc008f,0xc6920bd9,0x00000000}},	//   nţio, sfēr, זאם_,
  { {0xb05b0004,0xdd8f0021,0x3e740bda,0x00000000}},	//   smär, سوق_, _päts_,
  { {0xb05b00c7,0x7c240bdb,0x99750051,0x00000000}},	// [de0] pmär, rgir, jęła_,
  { {0x2d9e0003,0x7af60078,0xb05b0072,0x00000000}},	//   ûtes_, rpyt, lmäp,
  { {0xdce8001c,0x82960047,0xaf36007e,0x00000000}},	//   ēlēt, נדעס_, _شرکت,
  { {0xe3a7006a,0x6440017d,0x6d40003b,0x00000000}},	//   _هر_, xemi, ămad,
  { {0x4733007e,0x2bba0044,0x78a20bdc,0x00000000}},	//   مروز, _ساحة_, rnov,
  { {0x78a201b3,0x96b7005e,0x6497003b,0x00000000}},	//   snov, лују_, uţin,
  { {0xafdb02ab,0x6497000c,0x64400bdd,0x00000000}},	//   ndør, rţin, temi,
  { {0x6497000c,0xe3140002,0x78a201d1,0x00000000}},	//   sţin, амињ, čovs,
  { {0x6497003b,0xeb970047,0x64400bde,0x00000000}},	//   aţio, ָדיר_, remi,
  { {0x67220006,0x6497003b,0x64400708,0x00000000}},	//   muoj, lţil, semi,
  { {0xd657014e,0x6497000c,0x3cf80024,0x00000000}},	//   _תיבת_, cţio, jprv_,
  { {0x6497000c,0x26de0bdf,0x9f590025,0x00000000}},	//   nţil, _hito_, masú_,
  { {0x26de0006,0x67220006,0x7ae60035,0x00000000}},	//   _kito_, nuoj, _nukt,
  { {0xb05b0199,0xc7b3014e,0x0cbf0053,0x00000000}},	//   fläc, מבר_, ्ष्म,
  { {0x6d580026,0x765e00fe,0x26de0be0,0x00000000}},	//   _ával, öpyy, _mito_,
  { {0x7ae6053b,0x67220006,0x1f750ac5,0x00000000}},	//   _bukt, kuoj, _влия,
  { {0x26de0016,0xafdb07e6,0x67220006,0x00000000}},	// [df0] _oito_, rdøs, juoj,
  { {0x44ea03b2,0x26de00bb,0x200b0be1,0x00000000}},	//   _où_, _nito_, laci_,
  { {0x60cd0be2,0x629a0be3,0x62880072,0x00000000}},	//   _kham, iito, ihdo,
  { {0x89340032,0x7ae600df,0xa565007e,0x00000000}},	//   إعلا, _fukt, یگان,
  { {0x67220006,0xe7580086,0xd6d50121,0x00000000}},	//   guoj, лиці_, ажды,
  { {0x8704015a,0x629a0be4,0x44ea008b,0x00000000}},	//   сяце, jito, _bù_,
  { {0x200b02f4,0x26de0be5,0x6f1d00bd,0x00000000}},	//   kaci_, _dito_, hrsc,
  { {0x628800fe,0x44ea001b,0x200b04c9,0x00000000}},	//   ehdo, _dù_, jaci_,
  { {0xd6270032,0xc482019d,0x200b0743,0x00000000}},	//   _معاي, ільк, daci_,
  { {0xa7740be6,0x6497000c,0x26de0150,0x00000000}},	//   _улуч, pţio, _gito_,
  { {0x6497000c,0x4254000d,0x78a900d1,0x00000000}},	//   lţim, стыт, _kjev,
  { {0x628800fe,0xa01b004d,0x200b0be7,0x00000000}},	//   ahdo, nhöh, gaci_,
  { {0x60cd0035,0x2329047e,0xdee60be8,0x00000000}},	//   _dham, _роли_, роги,
  { {0x62880be9,0x78a9007d,0x629a0bea,0x00000000}},	//   chdo, _ljev, cito,
  { {0x6f1d0194,0x67220006,0x200b017f,0x00000000}},	//   arsc, zuoj, baci_,
  { {0x200b0beb,0x3ceb0061,0x60cd0168,0x00000000}},	//   caci_, _živí_, _gham,
  { {0x4e1a0076,0x3ae8007e,0xb05b0137,0x00000000}},	// [e00] _июня_, ابری_, släc,
  { {0xda790086,0xef1f00ea,0x67220078,0x00000000}},	//   ляє_, zzük_, vuoj,
  { {0x26de0bec,0xfe370047,0x2bb80053,0x00000000}},	//   _rito_, _דריי_, _आडवा,
  { {0x26de02f6,0x31360047,0x09c60053,0x00000000}},	//   _sito_, ינעם_, _वरीय,
  { {0x6497000c,0x87030bed,0x3eb80250,0x00000000}},	//   rţil, ояще, oort_,
  { {0x200b02f4,0x75230009,0x67220006,0x00000000}},	//   zaci_, funz, ruoj,
  { {0x32180045,0x629a0bee,0x67220341,0x00000000}},	//   órym_, vito, suoj,
  { {0x660a0146,0x3eb80bef,0x67220078,0x00000000}},	//   safk, hort_, puoj,
  { {0x200b0bf0,0x69e3003b,0x764301a8,0x00000000}},	//   vaci_, şteş, beny,
  { {0xab5b000f,0x44ea008b,0x629a017d,0x00000000}},	//   _szük, _tù_, uito,
  { {0x32070034,0x60cd00ac,0xa446042c,0x00000000}},	//   _deny_, _pham, _внед,
  { {0x6d41005b,0x757b0047,0x859b0063,0x00000000}},	//   çlam, _שטאפ, _בשבו,
  { {0x6f1d0717,0x629a0bf1,0x200b0bf2,0x00000000}},	//   ursc, pito, raci_,
  { {0x6f1d0199,0x660800a8,0x32070bf3,0x00000000}},	//   rrsc, _jedk, _geny_,
  { {0x6d47006f,0x200b0bf4,0xbc070bf5,0x00000000}},	//   uwja, paci_, ичай,
  { {0x60cd0035,0x320c0bf6,0x7d1a0014,0x00000000}},	//   _uham, lady_, átsa,
  { {0x6a150121,0x3eb80bf7,0x929d0022,0x00000000}},	// [e10] ймау, bort_, asłu,
  { {0x78a9017f,0x929d0051,0x660805a5,0x00000000}},	//   _sjev, bsłu, _nedk,
  { {0x78a9017f,0x7ed40021,0x29670001,0x00000000}},	//   _pjev, _بزيا, шњав,
  { {0x76430009,0x254700ea,0x320c004a,0x00000000}},	//   weny, _ről_, hady_,
  { {0xa01b00bd,0x98480062,0x629800ca,0x00000000}},	//   rhöh, ряха_, _omvo,
  { {0x75230035,0x7bda0063,0xa01b004d,0x00000000}},	//   tunz, _תקשו, shöh,
  { {0xbe3c0063,0x660800a8,0x24860bf8,0x00000000}},	//   דעות, _dedk, _blom_,
  { {0x76430bf9,0x63a40078,0x320c00e5,0x00000000}},	//   seny, _žina, eady_,
  { {0x75230290,0x76430bfa,0x43750299,0x00000000}},	//   sunz, peny, суйт,
  { {0x254700ea,0xf6740021,0x16380021,0x00000000}},	//   _től_, _والخ, _نسمة_,
  { {0x3eb80026,0x248604aa,0x7c36002b,0x00000000}},	//   vort_, _flom_, yfyr,
  { {0xb7bd0529,0x3eb800bd,0x200900dd,0x00000000}},	//   _acţi, wort_, _ceai_,
  { {0xd12e006a,0x42d50086,0x998c0022,0x00000000}},	//   ومی_, _ліку, _łoże_,
  { {0x201e0bfb,0xddde00dd,0x63a40046,0x00000000}},	//   şti_, _copş, _þina,
  { {0x3eb80bfc,0x70f50021,0x62810bfd,0x00000000}},	//   rort_, _استئ, mklo,
  { {0x6f040034,0x27e0082a,0xb05b03be,0x00000000}},	//   _twic, žini_, llän,
  { {0x7c360bfe,0x3eb80bff,0xcb670074,0x00000000}},	// [e20] rfyr, port_, бате_,
  { {0xb05b0832,0xa96a05bd,0x62810c00,0x00000000}},	//   nlän, лиза_, nklo,
  { {0x660800c3,0x628100c2,0xb05b092e,0x00000000}},	//   _redk, iklo, ilän,
  { {0x510a0047,0xb05b0244,0x80ce0082,0x00000000}},	//   רהײַ, hlän, _धीमे,
  { {0x68fb02f7,0x4cbb0063,0x62810c01,0x00000000}},	//   _čude, _תזכו, kklo,
  { {0xfd65001b,0x2486007d,0x07070044,0x00000000}},	//   _nguồ, _slom_, حيوي_,
  { {0x99860032,0x5d7a00b5,0x27e9027c,0x00000000}},	//   _الأو, טאַק, žana_,
  { {0x320c0c02,0xb05b0244,0xa2f40c03,0x00000000}},	//   wady_, elän, опич,
  { {0x77860001,0xc445007e,0xf3ef0021,0x00000000}},	//   _улаз, زیون_, رأي_,
  { {0x2732000c,0xb1140002,0x9f52006d,0x00000000}},	//   mân_, омош, _leyó_,
  { {0x3abb00b5,0xd257000d,0xaabb0047,0x00000000}},	//   רמינ, сцы_, רזיכ,
  { {0x629d0003,0x320c0c04,0x62810c05,0x00000000}},	//   ésor, sady_, aklo,
  { {0xff040062,0xdb0f00be,0x7d1a0014,0x00000000}},	//   зясн, _excê, átsn,
  { {0xacf90541,0xa2d30044,0x62810c06,0x00000000}},	//   ингу_, _فينت, cklo,
  { {0x40350c07,0x27320c08,0xf5180063,0x00000000}},	//   _дейс, hân_, יֵּל,
  { {0xa0a40c09,0xa01b00c7,0xce33007e,0x00000000}},	//   _најд, ehöv, _کودک,
  { {0xf09f00cd,0xba750121,0x3a7508a8,0x00000000}},	// [e30] mià_, огащ, олар,
  { {0xf09f0268,0x9e0705f1,0x51f8009a,0x00000000}},	//   lià_, _учил, שִּׂ,
  { {0x28150c0a,0xe291009d,0x00000000,0x00000000}},	//   قواس, וְא_,   ,
  { {0xf09f00cd,0x17fb0021,0x62810384,0x00000000}},	//   nià_, ارضة_, zklo,
  { {0xf1050161,0x2732008b,0xd5e50c0b,0x00000000}},	//   _शब्द_, gân_, ожли,
  { {0x45190432,0xb05b0137,0x2ca900a5,0x00000000}},	//   ация_, xlän, lnad_,
  { {0x2ca90c0c,0x22450023,0x1a68005d,0x00000000}},	//   onad_, velk_, _دیلی_,
  { {0x2ca90004,0x8339000a,0xf1c30080,0x00000000}},	//   nnad_, ачот_, _liší_,
  { {0xf09f00cd,0x6497000c,0xb05b01bb,0x00000000}},	//   dià_, nţii, tlän,
  { {0xe2990001,0x2ca9001f,0x92e80044,0x00000000}},	//   рао_, hnad_, حريق_,
  { {0xc6680079,0x63a40ac6,0x13f50088,0x00000000}},	//   _уште_, _þinn, _дзея,
  { {0x61fc005b,0xb05b089f,0x62810c0d,0x00000000}},	//   ırla, slän, sklo,
  { {0x249f0c0e,0xb05b092e,0x2ca90c0f,0x00000000}},	//   mium_, plän, dnad_,
  { {0x3f8c0051,0x248d0c10,0xb7da0063,0x00000000}},	//   ądu_, lhem_, יקרי,
  { {0x3f840024,0x1d0a01ef,0x6e210014,0x00000000}},	//   šmu_, реби_, ólba,
  { {0xf09f0268,0x90c30c07,0x2ca900c7,0x00000000}},	//   cià_, _обще, gnad_,
  { {0xdca30699,0x2002004b,0x2d910c11,0x00000000}},	// [e40] фати, mbki_, azze_,
  { {0x4a430002,0x768f00d1,0xa01b004d,0x00000000}},	//   мнув, _høyf, nkön,
  { {0xdb060137,0x6497003b,0x02b60047,0x00000000}},	//   _nykö, aţii, קלעך_,
  { {0xd7f00021,0xa01b01e9,0xaf35005d,0x00000000}},	//   ركت_, shöv, _بویژ,
  { {0x6497000c,0x2732008b,0xa01b0072,0x00000000}},	//   cţii, uân_, kkön,
  { {0x63a400eb,0x6d5e01f0,0x0576013a,0x00000000}},	//   _žino, _krpa, قاعد,
  { {0x442f0c12,0x2907003b,0x98a700dd,0x00000000}},	//   _bcg_, ânat_, înă_,
  { {0x69ce05c9,0x248d0c13,0x7d7b069a,0x00000000}},	//   _izbe, ghem_, ינצו,
  { {0x68430088,0xd7ef0021,0xf09f00cd,0x00000000}},	//   _інфа, _شكل_, vià_,
  { {0xa5f70001,0xc2170086,0x68fe0829,0x00000000}},	//   _међу_, оєю_, oppd,
  { {0xf09f00cd,0xdb0f00f4,0xe3af007e,0x00000000}},	//   tià_, _excè, فری_,
  { {0x6e3e00e3,0x249f0c14,0x27e00c15,0x00000000}},	//   _abpb, cium_, žinu_,
  { {0xf09f0268,0x98b3017f,0x5f94005a,0x00000000}},	//   rià_, žeća_, дият,
  { {0xf09f00cd,0x6722008f,0xc6940041,0x00000000}},	//   sià_, iroj, לאָ_,
  { {0x66cd0024,0xb05b0c16,0x2ca90137,0x00000000}},	//   núka, lläm, tnad_,
  { {0xbca50032,0x67220c17,0x9f61003b,0x00000000}},	//   أمري, kroj, ăpân_,
  { {0xcb34005a,0x2ca90c18,0x2d850c19,0x00000000}},	// [e50] метъ, rnad_, šle_,
  { {0x249f0c1a,0x6497003b,0x67220c1b,0x00000000}},	//   zium_, rţii, droj,
  { {0x2ca90137,0xb05b0072,0xdcef008f,0x00000000}},	//   pnad_, yläl, ēdēt,
  { {0x63ad0026,0x6497003b,0x20d2013d,0x00000000}},	//   _þang, pţii, ráig_,
  { {0xae1f0053,0x17980121,0x27e908ed,0x00000000}},	//   _बयान_, овцы_, žano_,
  { {0x7bda0063,0x5b7a0063,0x442f0c1c,0x00000000}},	//   _לקרו, _הרשא, _scg_,
  { {0x20020051,0xe9180054,0x67220072,0x00000000}},	//   ybki_, _морі_, aroj,
  { {0xddc70024,0x7c2d0c1d,0x628a04cf,0x00000000}},	//   rejň, ngar, _alfo,
  { {0xec79008b,0xe5e5005d,0x7c2d0c1e,0x00000000}},	//   _độc_, _فزای, igar,
  { {0x7c2d001f,0xc879005b,0x249f0c1f,0x00000000}},	//   hgar, _hoş_, sium_,
  { {0xb05b0072,0x6b890022,0xa01b00a6,0x00000000}},	//   lmäy, _żegl, rkön,
  { {0x628a000f,0xdb0f0c20,0x44f10013,0x00000000}},	//   _elfo, _excé, _iá_,
  { {0x44f10c21,0xb4b7016a,0x26c70c22,0x00000000}},	//   _há_, चकी_, olno_,
  { {0x442d0c23,0x7c2d0c24,0x12fa0063,0x00000000}},	//   lge_, egar, _ההסב,
  { {0x44f10c25,0x442d0c26,0x7c2d0c27,0x00000000}},	//   _já_, oge_, fgar,
  { {0x768f0031,0x7c2d0c28,0x64490c29,0x00000000}},	//   _høyd, ggar, neei,
  { {0x20d20025,0x44f10c2a,0x442d0c2b,0x00000000}},	// [e60] ráid_, _lá_, ige_,
  { {0x20d20025,0x78ab0078,0x7c2d0c2c,0x00000000}},	//   sáid_, engv, agar,
  { {0xc879005b,0x44f10c2d,0xc4cb0053,0x00000000}},	//   _boş_, _ná_, ाताओ,
  { {0xc879000c,0x9f59006d,0xa01b01bb,0x00000000}},	//   _coş_, casó_, lhör,
  { {0x6d5c00e8,0x27e0024a,0x442d0c2e,0x00000000}},	//   lvra, äin_, dge_,
  { {0x67220c2f,0x442d0c30,0xa96a0794,0x00000000}},	//   rroj, ege_, _лига_,
  { {0x6d5c0179,0x44f10c31,0x9c8300b2,0x00000000}},	//   nvra, _cá_, ščev,
  { {0x442d0c32,0x26c702e2,0x44f10c33,0x00000000}},	//   gge_, alno_, _dá_,
  { {0x78a20c34,0x684302fa,0x00000000,0x00000000}},	//   miov, _янта,   ,
  { {0x44f10c35,0x442d0c36,0xb05b0137,0x00000000}},	//   _fá_, age_, rläm,
  { {0x44f10027,0x7c2d0c37,0x6449004d,0x00000000}},	//   _gá_, ygar, beei,
  { {0x66cd0024,0xa01b0c38,0x78a20445,0x00000000}},	//   núkn, ehör, niov,
  { {0x4abe0161,0xaabe0053,0x768f00d1,0x00000000}},	//   ्ताव, ्ताक, _føyd,
  { {0x2ee500bd,0x68fc0c39,0x64b300dd,0x00000000}},	//   ölf_, _otrd, răie,
  { {0xdb1d0080,0x44f1008b,0x6497003b,0x00000000}},	//   _vysí, _xá_, aţiu,
  { {0x5d54000d,0x7c2d0c3a,0xd1380c3b,0x00000000}},	//   экст, ugar, mtą_,
  { {0x768f0031,0x6497000c,0x6d5c0c3c,0x00000000}},	// [e70] _høye, cţiu, avra,
  { {0x6ce70086,0xd1380078,0x7bc60078,0x00000000}},	//   _німе, otą_, _dyku,
  { {0xd13800eb,0x7bc60026,0x442d0c3d,0x00000000}},	//   ntą_, _eyku, yge_,
  { {0xd13800eb,0x6497003b,0xc864005e,0x00000000}},	//   itą_, nţit, етљи,
  { {0x2d8300eb,0xb8f40053,0x44f10c3e,0x00000000}},	//   lyje_, _सी_, _sá_,
  { {0xd1380006,0xb05b0072,0xf62b0054,0x00000000}},	//   ktą_, rmäy, сіди_,
  { {0x442d0c3f,0x2d830006,0xb05b0072,0x00000000}},	//   tge_, nyje_, smäy,
  { {0x44f10c40,0x78a20240,0x442d0c41,0x00000000}},	//   _vá_, ciov, uge_,
  { {0xafdb0093,0x644900e5,0x26c70061,0x00000000}},	//   nfød, reei, plno_,
  { {0x44f1018d,0x6d450c42,0x768f00d1,0x00000000}},	//   _tá_, _opha, _bøye,
  { {0x442d00c7,0x672b0026,0xd1380078,0x00000000}},	//   pge_, lugj, gtą_,
  { {0xa06a0001,0x7afd0019,0x2d830078,0x00000000}},	//   цама_, _otst, dyje_,
  { {0xd1380c3b,0x66cd017c,0x6d450c43,0x00000000}},	//   atą_, núko, _apha,
  { {0xafdb000e,0x6497003b,0xdd92007e,0x00000000}},	//   dfød, rţiu, پور_,
  { {0x6d4e0122,0x32050c44,0x929200d7,0x00000000}},	//   uwba, mbly_, _јајц,
  { {0x6d5c00c7,0x69da0016,0x6497000c,0x00000000}},	//   rvra, _útei, pţiu,
  { {0xa01b00c7,0x7ae7006f,0x6d5c0983,0x00000000}},	// [e80] phör, _bijt, svra,
  { {0xdddc00c2,0x6d5c0104,0xed630066,0x00000000}},	//   akrš, pvra, ôžé_,
  { {0xceb300b5,0x7bc60022,0x6abe004d,0x00000000}},	//   _ביז_, _wyku, ropf,
  { {0x6abe004d,0x5ca60505,0xcb6a0a29,0x00000000}},	//   sopf, _цимб, _даме_,
  { {0x9b030062,0x7bc60058,0x98a3005e,0x00000000}},	//   _изяд, _uyku, њиче,
  { {0xd138091b,0xa9260141,0x3e740066,0x00000000}},	//   ytą_, _одгл, _päty_,
  { {0x68fc00c2,0x764a002b,0x98a60c45,0x00000000}},	//   _utrd, refy, _живе,
  { {0x764a001f,0x7ae700ca,0xb05b00a5,0x00000000}},	//   sefy, _zijt, rläk,
  { {0xb05b0137,0xa226007e,0xed590023,0x00000000}},	//   släk, ورده, āži_,
  { {0x60c40006,0xa01b004d,0x325401dd,0x00000000}},	//   _akim, rköm, хвор,
  { {0x60f8013c,0xd1380078,0x40350c46,0x00000000}},	//   яння_, utą_, ненс,
  { {0xd1380c47,0x60d6001f,0x2d830006,0x00000000}},	//   rtą_, _chym, vyje_,
  { {0xd1380c48,0x6497003b,0x6d450c49,0x00000000}},	//   stą_, rţit, _spha,
  { {0x2d830006,0x6d4500d1,0xd1380078,0x00000000}},	//   tyje_, _ppha, ptą_,
  { {0x7ae7006f,0x7afd0850,0x6497003b,0x00000000}},	//   _rijt, _stst, mţir,
  { {0x2d830006,0xbf350086,0x6497003b,0x00000000}},	//   ryje_, _знищ, lţir,
  { {0x3ea3006f,0x9f630137,0xa01b0072,0x00000000}},	// [e90] pijt_, åväl_, hkök,
  { {0x2d8300eb,0x6497003b,0x0ab8005d,0x00000000}},	//   pyje_, nţir, وطلب_,
  { {0xb05b0072,0xf7700043,0x00000000,0x00000000}},	//   eläi, یاه_,   ,
  { {0x386902dd,0xc87901f7,0x3cfe00ea,0x00000000}},	//   ñar_, _kişi_, ítve_,
  { {0xfc3f000f,0x7afd0c4a,0x69c70051,0x00000000}},	//   _amíg_, _utst, _wyje,
  { {0xaa4500fe,0x6288006f,0x7ae7006f,0x00000000}},	//   ävää_, jkdo, _uijt,
  { {0xafdb00d1,0xaabe0082,0x00000000,0x00000000}},	//   rdøy, ्तरक,   ,
  { {0x6288006f,0x6aa50150,0x7d1a0014,0x00000000}},	//   ekdo, lihf, átsi,
  { {0x27ed0c4b,0x60d60c4c,0xa2e50c4d,0x00000000}},	//   _igen_, _rhym, ноид,
  { {0xe3b6000d,0x69c301a8,0x60c40c4e,0x00000000}},	//   эбы_, ünew, _skim,
  { {0x68e90045,0x32050c4f,0x60d6002b,0x00000000}},	//   _kied, rbly_, _phym,
  { {0x037b007e,0x62880c50,0x4395014b,0x00000000}},	//   _وحشت_, akdo, _паес,
  { {0x68e90c51,0x6497003b,0xb3870021,0x00000000}},	//   _mied, bţir, _تجاه,
  { {0x523900b5,0x64590a9f,0x645b0c52,0x00000000}},	//   _זײַנ, _hawi, ldui,
  { {0x27ed0122,0x7bcb00bd,0x64590c53,0x00000000}},	//   _ogen_, ügun, _kawi,
  { {0x63a40006,0x68e90c54,0x60c40035,0x00000000}},	//   _žini, _nied, _ukim,
  { {0x6d4101f7,0x64590c55,0x443f05b3,0x00000000}},	// [ea0] çlar, _mawi, ifu_,
  { {0x27ed0c56,0x6b960022,0x64590c57,0x00000000}},	//   _agen_, rzyg, _lawi,
  { {0x68e90c58,0x9c83085a,0x6da60c59,0x00000000}},	//   _bied, ščav, _чина,
  { {0x64590045,0x7e7e0c5a,0x645b08ad,0x00000000}},	//   _nawi, _hopp, jdui,
  { {0x17540076,0x7e7e0c5b,0x68e90c5c,0x00000000}},	//   твля, _kopp, _died,
  { {0x27ed06a3,0x645b0c5d,0xcfb70041,0x00000000}},	//   _egen_, edui, עלסי_,
  { {0x443f001f,0x64590c5e,0x7e7e0c5f,0x00000000}},	//   ffu_, _bawi, _mopp,
  { {0x7e7e024a,0xd4970076,0x645b0104,0x00000000}},	//   _lopp, ерь_, gdui,
  { {0x68e30173,0x82a6026c,0x7e7e0072,0x00000000}},	//   ïnde, ешне, _oopp,
  { {0xdbc70019,0x68e9001c,0x87170063,0x00000000}},	//   _tööi, _zied, _נקבע_,
  { {0x6497003b,0xc5690021,0x61ee0078,0x00000000}},	//   rţir, _يحمل_, žblo,
  { {0x645900bb,0xa98b009a,0x00000000,0x00000000}},	//   _gawi, לָכִ,   ,
  { {0xdfd80062,0x768f04aa,0x6d58007d,0x00000000}},	//   еър_, _høya, _švap,
  { {0xa6e700aa,0x64590045,0x7e7e055b,0x00000000}},	//   _nhữ, _zawi, _copp,
  { {0x765a00eb,0x20d20025,0xa01b00fe,0x00000000}},	//   _maty, máin_, hköi,
  { {0x765a0c60,0x6ca4026c,0x27e90c61,0x00000000}},	//   _laty, груж, žani_,
  { {0x5a3505fb,0x68e90c62,0x6a35005e,0x00000000}},	// [eb0] кнат, _ried, кнађ,
  { {0x20d20025,0x645b000c,0x765a0051,0x00000000}},	//   náin_, zdui, _naty,
  { {0x768f0031,0x3947090d,0x48150ac5,0x00000000}},	//   _nøya, ïns_, вмес,
  { {0x20d20027,0x7e7e01f4,0x26c50195,0x00000000}},	//   háin_, _zopp, _sklo_,
  { {0x20d90025,0xed59001c,0x64590c63,0x00000000}},	//   méid_, āžu_, _rawi,
  { {0x64590c64,0x68e90c65,0x945d0045,0x00000000}},	//   _sawi, _wied, końc,
  { {0x68e909ff,0x64590c5e,0xe1f1007e,0x00000000}},	//   _tied, _pawi, یسد_,
  { {0x27ed00b9,0x929d0051,0x20d20139,0x00000000}},	//   _ugen_, dpła, eáin_,
  { {0x645b0c66,0x660c00ea,0xb05b004d,0x00000000}},	//   rdui, élkü, nläu,
  { {0x387f0592,0x23620026,0x20d90025,0x00000000}},	//   _hour_, ækja_, héid_,
  { {0x645900a4,0xb05b004d,0x273b002b,0x00000000}},	//   _tawi, hläu, lên_,
  { {0x387f03b2,0x7e7e0c67,0x7e0a0042,0x00000000}},	//   _jour_, _sopp, वर्ग_,
  { {0xa4d4019d,0x386d000e,0x08760047,0x00000000}},	//   _соці, _mner_, דערט_,
  { {0x9f9e0016,0x273b001b,0xe0df0290,0x00000000}},	//   _ação_, iên_, amò_,
  { {0x71640021,0x2d8c0066,0xdca60092,0x00000000}},	//   _مايك, áde_, вави,
  { {0xeaed0053,0xed570002,0xa0c6009b,0x00000000}},	//   जदूत_, њот_, _جيبو,
  { {0xf41200b5,0x7e7e0c68,0x69d501f4,0x00000000}},	// [ec0] יפן_, _topp, _azze,
  { {0x7e7e00d1,0x64950139,0xdee6049f,0x00000000}},	//   _uopp, _fáig, _шопи,
  { {0xceb9004c,0x765a0022,0x649501c8,0x00000000}},	//   éře_, _raty, _káid,
  { {0x387f0164,0x20d90139,0xb05b004d,0x00000000}},	//   _cour_, céid_, bläu,
  { {0x69d5000f,0x765a0006,0x929d0051,0x00000000}},	//   _ezze, _paty, zpła,
  { {0x64950025,0x6f02005b,0xa6340086,0x00000000}},	//   _láid, _çocu, ункі,
  { {0x387f0034,0x64b3000c,0x69c300ea,0x00000000}},	//   _four_, răin, ünet,
  { {0xa01b013d,0xc7b9013d,0x765a0022,0x00000000}},	//   lköv, _időn_, _waty,
  { {0x20d20025,0xd2500021,0x6ac70014,0x00000000}},	//   táin_, منة_, _örfá,
  { {0xa01b00c7,0xe3af0021,0x7c29008f,0x00000000}},	//   nköv, ترى_, _ķerm,
  { {0x387f0c69,0x63ad0026,0xb05b0137,0x00000000}},	//   _your_, _þann, klät,
  { {0x63a400eb,0x20d20027,0x443200d1,0x00000000}},	//   _žinu, sáin_, _øy_,
  { {0xe0df0290,0x20d20c6a,0xa0a4000d,0x00000000}},	//   rmò_, máil_, раўд,
  { {0x6fe9001c,0x661800c2,0x2fcd0051,0x00000000}},	//   _rīcī, navk, żego_,
  { {0xfcc7005e,0x9c830124,0x929d0022,0x00000000}},	//   вљам, áčov, jsły,
  { {0x273b00aa,0x7059000a,0x3cfe00ea,0x00000000}},	//   yên_, _чаир_, ítva_,
  { {0x20190c6b,0x44f80c6c,0x66180c6d,0x00000000}},	// [ed0] masi_, _lé_, kavk,
  { {0x20d20027,0x7e55019d,0xb05b00bd,0x00000000}},	//   háil_, _своє, rläu,
  { {0x387f0c6e,0x20d90027,0x69c802ab,0x00000000}},	//   _pour_, péid_, _ødel,
  { {0xdb1d00fe,0x5c040062,0x20190c6f,0x00000000}},	//   _pysä, _вяра, nasi_,
  { {0x20d20025,0xb05b00fe,0xfeb8007e,0x00000000}},	//   dáil_, lläs, _سایت_,
  { {0x2ca90c70,0x44f80c71,0x273b001b,0x00000000}},	//   liad_, _bé_, rên_,
  { {0x44f80027,0x20190801,0x8883007e,0x00000000}},	//   _cé_, kasi_, _پیشن,
  { {0x23660117,0x2ca90185,0x20d20027,0x00000000}},	//   _broj_, niad_, gáil_,
  { {0x20190551,0x69da0c72,0xb05b004d,0x00000000}},	//   dasi_, _úter, hläs,
  { {0x2ca9001f,0x44f80c73,0x6f1d0c74,0x00000000}},	//   hiad_, _fé_, dssc,
  { {0x20190c75,0xb05b0072,0xe4d6005d,0x00000000}},	//   fasi_, ylät, ضویت_,
  { {0x20d20027,0x20190c76,0x6f1d004d,0x00000000}},	//   cáil_, gasi_, fssc,
  { {0x2ca90185,0x3245032d,0x44f80c77,0x00000000}},	//   diad_, _белг, _zé_,
  { {0xed5a0138,0x248d0080,0xf2070071,0x00000000}},	//   ног_, lkem_, _рядо,
  { {0x2ca90185,0x64950025,0x44f80013,0x00000000}},	//   fiad_, _táid, _xé_,
  { {0x2ca90c78,0x6abe0053,0x1bea0ab1,0x00000000}},	//   giad_, ्त्र, едби_,
  { {0xb05b0137,0xb2f60047,0x7c2b0c79,0x00000000}},	// [ee0] rlät, ָצעס_, ógra,
  { {0x248d0004,0xb05b0354,0xdde400ea,0x00000000}},	//   hkem_, slät, űrűs,
  { {0x2ca9001f,0xb05b00e0,0x60c60c7a,0x00000000}},	//   biad_, plät, ookm,
  { {0x7643001f,0x98c5000d,0x2ca9001f,0x00000000}},	//   efny, асіл, ciad_,
  { {0x44f80c7b,0x248d0080,0x66180c7c,0x00000000}},	//   _sé_, dkem_, tavk,
  { {0xbb430001,0x44f80c7d,0x39580078,0x00000000}},	//   _ћерк, _pé_, _tsrs_,
  { {0x20d20027,0x2019005b,0x66180c7e,0x00000000}},	//   táil_, yasi_, ravk,
  { {0x66180c7f,0x2b400af9,0x44f80c80,0x00000000}},	//   savk, otic_, _vé_,
  { {0xb05b0199,0x20d20025,0x20190c6f,0x00000000}},	//   klär, ráil_, vasi_,
  { {0x44f80c81,0x20d20025,0x68e2060b,0x00000000}},	//   _té_, sáil_, lmod,
  { {0x3263000d,0x68e20c82,0x201907fa,0x00000000}},	//   стыв, omod, tasi_,
  { {0x68e20c83,0x6f1d0c84,0x201901f4,0x00000000}},	//   nmod, tssc, uasi_,
  { {0x20190c85,0x6f1d00bd,0x03a30a91,0x00000000}},	//   rasi_, ussc, _лицо,
  { {0x20190c86,0x256301f7,0x3eaa00bd,0x00000000}},	//   sasi_, _yıl_, gibt_,
  { {0x2ca90185,0x69ce0c87,0x6f040c88,0x00000000}},	//   tiad_, _nybe, _etic,
  { {0xb05b00bd,0xd1380051,0xa01b013d,0x00000000}},	//   rläs, rząd_, gköt,
  { {0x2ca90185,0xda15005e,0x768f00d1,0x00000000}},	// [ef0] riad_, идањ, _bøyl,
  { {0x69ce0c89,0x2ca9001f,0x8f9c0047,0x00000000}},	//   _bybe, siad_, _ריזי,
  { {0xb9b50021,0x2d8a0c8a,0x2b400c8b,0x00000000}},	//   جماع, cybe_, atic_,
  { {0x69ce000e,0x5d7a0041,0x76480022,0x00000000}},	//   _dybe, _סארק, _abdy,
  { {0xdc3600b5,0x65680035,0x248d004c,0x00000000}},	//   _דארט_, _ardh, vkem_,
  { {0x83fd00ea,0x68e2040d,0xab66001c,0x00000000}},	//   zdőd, amod, _daļē,
  { {0x291c0080,0x248d0c8c,0xd61800f2,0x00000000}},	//   ávat_, tkem_, اتها_,
  { {0x03250c8d,0x06b1004c,0x443900ca,0x00000000}},	//   адин, _řídí_, üs_,
  { {0x67d40086,0xd2990054,0x6568004d,0x00000000}},	//   _готу, втні_, _erdh,
  { {0x78ab0c8e,0x6f040c8f,0x248d0c90,0x00000000}},	//   ligv, _rtic, skem_,
  { {0xe0da0c91,0x39410034,0x26c70c92,0x00000000}},	//   кво_, nths_, mono_,
  { {0x78ab006f,0x6f04074f,0x2d8a0078,0x00000000}},	//   nigv, _ptic, vybe_,
  { {0x7d050025,0xa8560063,0x60c60066,0x00000000}},	//   _aths, בירה_, rokm,
  { {0x539a0165,0x68e20c93,0x1167005d,0x00000000}},	//   _בינו, zmod, _ملتی_,
  { {0x26c70290,0x62830c94,0x68e2002b,0x00000000}},	//   iono_, _iono, ymod,
  { {0x768f00d1,0x62830c95,0x26c7002b,0x00000000}},	//   _søyl, _hono, hono_,
  { {0x6f04017f,0x26c70035,0x62830c96,0x00000000}},	// [f00] _utic, kono_, _kono,
  { {0xb05b00fe,0x26c70c97,0x62830c98,0x00000000}},	//   lläp, jono_, _jono,
  { {0x26c70c99,0x20d90016,0x2b400c9a,0x00000000}},	//   dono_, léia_, stic_,
  { {0x69ce0512,0x2a610025,0x2b400c9b,0x00000000}},	//   _vybe, adhb_, ptic_,
  { {0x47330086,0xe737019c,0x20d900be,0x00000000}},	//   жніс, иец_, néia_,
  { {0x628302f6,0x26c70c9c,0xafdb06a5,0x00000000}},	//   _nono, gono_, dføl,
  { {0xa01b01bb,0x997c0023,0xdaa70896,0x00000000}},	//   ljöe, lāža_, _тврд_,
  { {0xd70603d6,0xd5b1008b,0x69d8008f,0x00000000}},	//   _взаи, _séc_, ļved,
  { {0xa2c20161,0xf749006a,0x62830c9d,0x00000000}},	//   रकल्, _مجله_, _bono,
  { {0x62830c9e,0x26c70c9f,0x20d9017d,0x00000000}},	//   _cono, cono_, déia_,
  { {0x09f7014e,0xd1380051,0x99f70063,0x00000000}},	//   ימים_, dząc_, יזיה_,
  { {0x75d3006a,0xdcee0006,0xdb1d0066,0x00000000}},	//   _بيما, mybė, _vysú,
  { {0x44260ca0,0xdcee0078,0xbfa80a71,0x00000000}},	//   _ido_, lybė, атре_,
  { {0x7dc70021,0x62830ca1,0x8027005d,0x00000000}},	//   لتأك, _gono, درگم,
  { {0x442608c4,0xdcee0078,0x6ca70603,0x00000000}},	//   _kdo_, nybė, араж,
  { {0x1bf5000d,0x30150002,0x26c70ca2,0x00000000}},	//   спаў, _удир, zono_,
  { {0x26c700f3,0x7de000ea,0x60cd0058,0x00000000}},	// [f10] yono_, tásé, _ikam,
  { {0xdcee0006,0x996707ac,0xd4910013,0x00000000}},	//   kybė, ител, _mùa_,
  { {0xd36604de,0x26c7051e,0x161a0053,0x00000000}},	//   _که_, vono_, _नज़र_,
  { {0x26c70150,0x39410ca3,0x83fd013d,0x00000000}},	//   wono_, rths_, zdőb,
  { {0xcc760063,0x39a70066,0x7c48013d,0x00000000}},	//   _הערה_, dísť_, éprő,
  { {0x26c707a0,0x1af60ca4,0x394100e5,0x00000000}},	//   uono_, _למשל_, pths_,
  { {0x45180088,0x26c702f6,0xb9950021,0x00000000}},	//   ацыя_, rono_, _الأب,
  { {0x629a024a,0xe570007e,0xa8a40726,0x00000000}},	//   ehto, بطه_, _друк,
  { {0x26c70ca5,0x13060121,0x6b8d0ca6,0x00000000}},	//   pono_, бный_, nyag,
  { {0xafdb0205,0x60cd0ca7,0x44260ca8,0x00000000}},	//   rføl, _akam, _edo_,
  { {0xb5a70878,0x60ea0074,0x1c170042,0x00000000}},	//   _трай, лмом_, तराल_,
  { {0x656e0027,0x628300f3,0xafdb0ca9,0x00000000}},	//   _ábha, _wono, pføl,
  { {0xafdb010a,0xdee60086,0x443d0150,0x00000000}},	//   lføj, йоми, _icw_,
  { {0x20d90016,0xde0307da,0x78bb0415,0x00000000}},	//   réia_, зпри, _ljuv,
  { {0x753c00bd,0x69a70053,0xd1380051,0x00000000}},	//   _ärzt, _टेली, rząc_,
  { {0x20d90016,0xa9240066,0xd1380051,0x00000000}},	//   péia_, _úžit, sząc_,
  { {0xc9f60032,0xa01b013d,0x60970043,0x00000000}},	// [f20] مساع, pkör, _دنيس_,
  { {0x78100053,0xe8100053,0x4b230054,0x00000000}},	//   ार्क_, ार्थ_, ямув,
  { {0x6b8d00a4,0xe9da005e,0x186a0caa,0x00000000}},	//   ayag, ћке_, лажи_,
  { {0xdcee0006,0xa01b0cab,0x38cb007e,0x00000000}},	//   vybė, nköp, هانی_,
  { {0xb8650cac,0x07ba00de,0x00000000,0x00000000}},	//   تالو, دهشة_,   ,
  { {0xa01b024a,0xdcee0006,0xd627005e,0x00000000}},	//   hköp, tybė, боље_,
  { {0xd6390054,0xa01b00a5,0xdcfc005f,0x00000000}},	//   рячі_, kköp, tyrę,
  { {0xa4d80002,0x69dc0cad,0xdcee0078,0x00000000}},	//   јдиу_, _izre, rybė,
  { {0x649c0025,0xc3270021,0xb8de0053,0x00000000}},	//   _léig, مكين_, ीक_,
  { {0x32180024,0xddc50024,0x20d90139,0x00000000}},	//   úry_, _zahŕ, géin_,
  { {0xa0550086,0x6722008f,0x64a60141,0x00000000}},	//   овні, lsoj, _лажа,
  { {0x557700b5,0x661a037e,0x672200c2,0x00000000}},	//   _לעבן_, _hetk, osoj,
  { {0x7e2b000d,0xbf9b00ac,0xbfab019b,0x00000000}},	//   ліва_, ebêr, утне_,
  { {0x768f00d1,0xd3570063,0x0dcb0ab1,0x00000000}},	//   _røyk, _לידי_, губи_,
  { {0x629801f4,0xc2ed004c,0x321e0cae,0x00000000}},	//   _ilvo, řící, maty_,
  { {0x7b150062,0x6b8d0caf,0x67220cb0,0x00000000}},	//   ждах, tyag, ksoj,
  { {0x6f16001f,0x6d5e0283,0xd5b10013,0x00000000}},	// [f30] _gwyc, _espa, _nén_,
  { {0x661a0cb1,0x2486016c,0x321e0022,0x00000000}},	//   _netk, _loom_, naty_,
  { {0x6f160051,0x3a840085,0x79590cb2,0x00000000}},	//   _zwyc, чытв, риер_,
  { {0xd7d50001,0xe3c70078,0x2907008f,0x00000000}},	//   ожењ, ūčių_, īna_,
  { {0x69cb00bd,0x69dc00ea,0x321e0022,0x00000000}},	//   ßgeb, _ezre, katy_,
  { {0xda7b000d,0x64950139,0x321e004c,0x00000000}},	//   _сям_, _cáin, jaty_,
  { {0x7d020024,0x20020022,0x78bb00a5,0x00000000}},	//   _čosk, ycki_, _tjuv,
  { {0x62980cb3,0xcd980063,0x6d410058,0x00000000}},	//   _alvo, מדות_, çlay,
  { {0x24860cb4,0xdc8c009a,0x00000000,0x00000000}},	//   _doom_, רְוָ,   ,
  { {0x52a90cb5,0x321e0cb6,0x31250cb7,0x00000000}},	//   рвом_, gaty_, одог,
  { {0x6f160051,0xdb060014,0xd5bb0131,0x00000000}},	//   _swyc, _ómög, _сса_,
  { {0x649c0025,0x493a0149,0x62980cb8,0x00000000}},	//   _réig, סגרו, _elvo,
  { {0x661a01f7,0x644900d1,0xd5b1008b,0x00000000}},	//   _yetk, mfei, _kéo_,
  { {0xfc3f00cd,0xddde003b,0x21690cb9,0x00000000}},	//   _ací_, _nopţ, _вики_,
  { {0x649c018d,0xed5a0cba,0xcc8a0cbb,0x00000000}},	//   _féid, шов_, абве_,
  { {0x1c46000d,0x64490cbc,0x6f160022,0x00000000}},	//   ўнам, nfei, _twyc,
  { {0x6d5e0051,0x8b260121,0xf2000042,0x00000000}},	// [f40] _wspa, юдае, लुक़_,
  { {0x649c0027,0x1ae30cbd,0x00000000,0x00000000}},	//   _téig, доум,   ,
  { {0xa9670062,0x6281003b,0x661a0cbe,0x00000000}},	//   жиха_, ijlo, _retk,
  { {0x50ca0161,0x661a03a4,0x67220072,0x00000000}},	//   रविष, _setk, tsoj,
  { {0x24860034,0x67220006,0xe8e00013,0x00000000}},	//   _room_, usoj, hiệt_,
  { {0x6b8b0cbf,0x9991013d,0x64490cc0,0x00000000}},	//   ägge, _edző_, efei,
  { {0x69dc001c,0x64490cc1,0xa5070002,0x00000000}},	//   _uzre, ffei, оеја_,
  { {0x672d001c,0xe9d70086,0xb198008b,0x00000000}},	//   šaja, _єкт_, _ngưỡ,
  { {0x649c0025,0xc445007e,0x76b20051,0x00000000}},	//   _réid, سیون_, głyc,
  { {0x38660cc2,0x68fc0cc3,0xfbd3009a,0x00000000}},	//   ldor_, _kurd, ותח_,
  { {0xe45a019d,0xdd1c0024,0x321e0471,0x00000000}},	//   _вже_, yšše, raty_,
  { {0x68fc010e,0x765800fe,0x6d5c0cc4,0x00000000}},	//   _murd, levy, dwra,
  { {0x6101003d,0x38660cc5,0xff040062,0x00000000}},	//   _vēla, idor_, дясн,
  { {0x68fc006c,0x62980050,0x6d5c00a3,0x00000000}},	//   _ourd, _ulvo, fwra,
  { {0x68fc0cc6,0xbd680a91,0x6d5c002b,0x00000000}},	//   _nurd, орте_, gwra,
  { {0x90c400e1,0x90e7005d,0xbb4b012c,0x00000000}},	//   _обје, _بستن, иїзд_,
  { {0x1eab0021,0x68fc00d1,0x38660cc7,0x00000000}},	// [f50] _نادي_, _aurd, ddor_,
  { {0x768f00d1,0x68fc0cc8,0xc96b005e,0x00000000}},	//   _høyv, _burd, ијед_,
  { {0xad27006a,0x64490185,0xe9f80086,0x00000000}},	//   _برخو, yfei, інці_,
  { {0x68fc01f7,0xe8f80304,0x64950025,0x00000000}},	//   _durd, ілі_, _cáil,
  { {0xcb44082b,0x64950139,0x2d9100e5,0x00000000}},	//   _охри, _dáil, lyze_,
  { {0x8afa0063,0x386600c5,0x6d47004b,0x00000000}},	//   _להשי, ador_, otja,
  { {0xceb400b5,0x64950025,0x7afd0cc9,0x00000000}},	//   ויס_, _fáil, _hust,
  { {0x6d470268,0x7afd0cca,0xe4c80044,0x00000000}},	//   itja, _kust, يبين_,
  { {0xe3b10032,0x7afd0ccb,0x13060121,0x00000000}},	//   عرب_, _just, пный_,
  { {0xe2990138,0x64490ccc,0x68fc0058,0x00000000}},	//   сао_, sfei, _yurd,
  { {0x76b20051,0xd5b10013,0x20d200ea,0x00000000}},	//   słyc, _kém_, káit_,
  { {0x7afd0ccd,0x7b09017c,0x76b20022,0x00000000}},	//   _oust, _kľud, płyc,
  { {0x7afd00eb,0xbf9b017d,0xb4c90042,0x00000000}},	//   _nust, scên, ोती_,
  { {0x649c0139,0x998c0066,0x6d5c00a3,0x00000000}},	//   _géib, _čože_, twra,
  { {0x7c960304,0x64950025,0xe7eb0053,0x00000000}},	//   прац, _láim, जेता_,
  { {0x249f03d9,0x6d5c002b,0x7af5008f,0x00000000}},	//   nhum_, rwra, _aizt,
  { {0x7af5000f,0x7afd0cce,0x68fc0ccf,0x00000000}},	// [f60] _bizt, _cust, _surd,
  { {0x64950139,0x7afd0cd0,0x68fc0cd1,0x00000000}},	//   _sáil, _dust, _purd,
  { {0xb9060054,0x2bac0042,0x7afd0cd2,0x00000000}},	//   їздк, _घेरा, _eust,
  { {0x68fc02ab,0x7afd0cd3,0xf7460002,0x00000000}},	//   _vurd, _fust, зедо,
  { {0x68fc0cd4,0x7afd0cd5,0x78a300ac,0x00000000}},	//   _wurd, _gust, ënva,
  { {0xba55005a,0x35d40076,0x2d8701a8,0x00000000}},	//   _отсъ, молё, _ànec_,
  { {0x64950025,0x7afd05e4,0xd5b00021,0x00000000}},	//   _táil, _zust, ضفة_,
  { {0x7de7000f,0x957c0051,0x2ca000a4,0x00000000}},	//   lésé, _rząd, nhid_,
  { {0x07a30131,0xa7860044,0xe77a009d,0x00000000}},	//   _затн, _عشرو, _לָ֑ך,
  { {0x7de700ea,0xcb130063,0x6d470014,0x00000000}},	//   nésé, עלת_, ytja,
  { {0xdc3f0066,0x30350121,0x40350cd6,0x00000000}},	//   víľk, менё, менс,
  { {0x7bc3000c,0x64a3000d,0x20d20331,0x00000000}},	//   şnui, _паха, dáis_,
  { {0x68e300f5,0x7ee70062,0x91fc008f,0x00000000}},	//   ïndi, зцве, ldām,
  { {0xc7b900ea,0x6d47087b,0x7afd0cd7,0x00000000}},	//   _időt_, ttja, _rust,
  { {0x20d20cd8,0x7de700ea,0x7afd0cd9,0x00000000}},	//   táit_, désé, _sust,
  { {0x768f00d1,0x6d4700ea,0x113b0063,0x00000000}},	//   _høyt, rtja, _התהל,
  { {0x69d8005b,0x83fd00ea,0x6108004c,0x00000000}},	// [f70] üven, zdőo, _děle,
  { {0x6f0d0cda,0x7de7013d,0x20d200a3,0x00000000}},	//   _itac, gésé, sáit_,
  { {0x7afd0244,0xbbeb005d,0x7af5011b,0x00000000}},	//   _wust, _گردم_, _vizt,
  { {0x69d50024,0xddde017f,0xddc70051,0x00000000}},	//   _vyze, _uopš, zejś,
  { {0x7afd004b,0x69d50022,0xf7450cdb,0x00000000}},	//   _uust, _wyze, фело,
  { {0x768f00d1,0x20d20025,0x672d008f,0x00000000}},	//   _nøyt, náir_, šajo,
  { {0x24e902a1,0x249f0550,0xa5f601ce,0x00000000}},	//   омки_, thum_, мељу_,
  { {0x64950025,0x9f650024,0x200901f4,0x00000000}},	//   _táim, _štýl_, _nfai_,
  { {0x249f0cdc,0x7d1a00ea,0x823504a0,0x00000000}},	//   rhum_, átsz, وردا,
  { {0x628a0cdd,0x20d20014,0xe3b60766,0x00000000}},	//   _cofo, jáir_, ьбы_,
  { {0x6101001c,0x6f0d0cde,0x67290014,0x00000000}},	//   _vēlo, _atac, _hvej,
  { {0x7de7000f,0x64420025,0xf485007e,0x00000000}},	//   zésé, _gcoi, _تائی,
  { {0xe3ae0088,0x10a30cdf,0x628a00be,0x00000000}},	//   _рб_, тиян, _fofo,
  { {0x83fd000f,0x6f0d0025,0x628a002b,0x00000000}},	//   zdől, _dtac, _gofo,
  { {0x768f00d1,0x2ca00139,0x6f0d0331,0x00000000}},	//   _høys, thid_, _etac,
  { {0x6729006d,0x443f0ce0,0x236d0066,0x00000000}},	//   _ovej, ngu_, ovej_,
  { {0x7de7000f,0x9f44024a,0x236d0261,0x00000000}},	// [f80] tésé, ämä_, nvej_,
  { {0x2ca00ce1,0x6b8b0137,0x8d76007e,0x00000000}},	//   shid_, ägga, _قاجا,
  { {0x7de700ea,0x4866005a,0x61080080,0x00000000}},	//   résé, дълб, _těle,
  { {0x7de700ea,0x00000000,0x00000000,0x00000000}},	//   sésé,   ,   ,
  { {0x7c240ce2,0x7de7013d,0xa6ca01ce,0x00000000}},	//   mair, pésé, олда_,
  { {0x9f400122,0x64420025,0x443f0ce3,0x00000000}},	//   _azië_, _scoi, egu_,
  { {0xa01b0026,0xd82600e1,0x645b0ce4,0x00000000}},	//   fjöl, _одви, feui,
  { {0x7c240ce5,0x628a0b92,0xa01b0026,0x00000000}},	//   nair, _sofo, gjöl,
  { {0x68e300dd,0x63ad0ce6,0x00000000,0x00000000}},	//   înde, _žanr,   ,
  { {0x7c240ce7,0x443f0ce8,0x4b7b009a,0x00000000}},	//   hair, agu_, קאיו,
  { {0x3a370a7a,0x60cf003b,0x6f0d0ce9,0x00000000}},	//   ורים_, tocm, _stac,
  { {0x10740086,0x78a20cea,0xe7f50053,0x00000000}},	//   влюю, nhov, ुँचा_,
  { {0x7c24066d,0x44240ceb,0x23e20053,0x00000000}},	//   dair, mam_, _परिद,
  { {0x768f076c,0x44240cec,0x00000000,0x00000000}},	//   _høyr, lam_,   ,
  { {0x20d20026,0x7c2404bc,0x20c70afc,0x00000000}},	//   ráir_, fair, _осиг,
  { {0x7c240027,0x63a40078,0x44240ced,0x00000000}},	//   gair, _žiny, nam_,
  { {0xfbd00032,0x7b090066,0xba2b0021,0x00000000}},	// [f90] لتك_, _sľub, قسام_,
  { {0x44240cee,0xdb040003,0xb05b004e,0x00000000}},	//   ham_, iziè, snäd,
  { {0x44240cef,0x443f0185,0x7c240025,0x00000000}},	//   kam_, ygu_, bair,
  { {0xd0f90047,0xdbd90026,0x7c240cf0,0x00000000}},	//   פּער, _fæði, cair,
  { {0xdbd90014,0xf3f900dd,0x44240cf1,0x00000000}},	//   _gæði, neţe_, dam_,
  { {0x45190905,0xa01b00ea,0x7f3c0047,0x00000000}},	//   пция_, gköz, קעוו,
  { {0xddde0051,0x645b0cf2,0xe5760062,0x00000000}},	//   _zapł, teui, езщ_,
  { {0xfdf8014e,0x78a20114,0x44240cf3,0x00000000}},	//   וצות_, chov, gam_,
  { {0x6101001c,0x645b0cf4,0x443f0cf5,0x00000000}},	//   _vēlm, reui, rgu_,
  { {0x57780032,0x443f0185,0x44240162,0x00000000}},	//   _تصفح_, sgu_, aam_,
  { {0x44240cf6,0xa06a0cf7,0xe2a80044,0x00000000}},	//   bam_, пана_, باين_,
  { {0x44240cf8,0x649c0139,0x20050051,0x00000000}},	//   cam_, _héin, ślin_,
  { {0xb7bd003b,0x9f4c005b,0xa2950054,0x00000000}},	//   _feţe, _ölüm_, _паді,
  { {0x78a20114,0xdbd90046,0xed6001c8,0x00000000}},	//   zhov, _ræði, ážou_,
  { {0x7c240cf9,0x6b8b00c7,0xc692009f,0x00000000}},	//   tair, äggn, נאל_,
  { {0xa01b000f,0x7c240025,0x649c0025,0x00000000}},	//   zköz, uair, _léin,
  { {0x7c240cfa,0x69cb0058,0x945d0022,0x00000000}},	// [fa0] rair, şgel, lońs,
  { {0x4a4305fb,0x44240cfb,0x636a013d,0x00000000}},	//   лнув, zam_, löná,
  { {0x7c240cfc,0xf2960047,0x44240bbf,0x00000000}},	//   pair, עכער_, yam_,
  { {0xafdb0205,0x442403cc,0xb05b004d,0x00000000}},	//   mfør, xam_, mnäc,
  { {0xafdb02ab,0xa01b00ea,0x78a20cfd,0x00000000}},	//   lfør, tköz, rhov,
  { {0x44240cfe,0x78a20cff,0x945d056c,0x00000000}},	//   wam_, shov, końs,
  { {0xb7bd0529,0x78a200c7,0xafdb02ab,0x00000000}},	//   _reţe, phov, nfør,
  { {0x60c401b3,0x6440007d,0x945d0022,0x00000000}},	//   _njim, ugmi, dońs,
  { {0x64400004,0x73d7005a,0x44240d00,0x00000000}},	//   rgmi, ндър_, ram_,
  { {0x44240d01,0x39580150,0xafdb00d1,0x00000000}},	//   sam_, _kprs_, kfør,
  { {0xb145007e,0x5a9b0047,0xf3f9003b,0x00000000}},	//   نیوم_, פשטא, veţe_,
  { {0xafdb02ab,0x859b009a,0x00000000,0x00000000}},	//   dfør, _משבו,   ,
  { {0x61080080,0xf3f9003b,0x94a90021,0x00000000}},	//   _děla, teţe_, _تطلق_,
  { {0xd36f007e,0x71260021,0x2a6a00a5,0x00000000}},	//   _دهه_, _كربل, _nabb_,
  { {0xafdb0d02,0xf3f9003b,0xbdd502fa,0x00000000}},	//   gfør, reţe_, товщ,
  { {0xf3f9003b,0x768f04aa,0x11db0063,0x00000000}},	//   seţe_, _løyp, _מחוב,
  { {0x6fb90086,0x629a0d03,0xcb340062,0x00000000}},	// [fb0] _ігор_, okto, летъ,
  { {0x213e0034,0x629a0d04,0x60dd00cf,0x00000000}},	//   outh_, nkto, llsm,
  { {0x649c0164,0x629a0d05,0x76b20022,0x00000000}},	//   _réin, ikto, głym,
  { {0x89340032,0x90d6008d,0x99640085,0x00000000}},	//   اعلا, hùn, ытул,
  { {0x649c0025,0x213e004d,0x48040054,0x00000000}},	//   _péin, huth_, упів,
  { {0xd1380006,0x386908ed,0x368b089a,0x00000000}},	//   krą_, žar_, ясен_,
  { {0x6abf0161,0x569200e1,0xf5320002,0x00000000}},	//   ्वीर, рајт, аејќ,
  { {0x629a0d06,0x25ba0139,0xd1380d07,0x00000000}},	//   ekto, úpla_, drą_,
  { {0x2005004c,0x03220085,0xd138005f,0x00000000}},	//   ělil_, адын, erą_,
  { {0x68fb0290,0x649c0025,0x290305b3,0x00000000}},	//   _hiud, _héil, _kuja_,
  { {0x10a60d08,0x2bd80042,0x68fb004e,0x00000000}},	//   винн, _भुना, _kiud,
  { {0x629a0d09,0x40960d0a,0xf8b30042,0x00000000}},	//   akto, трот, ूचिय,
  { {0x6f630088,0xd1380022,0x68e900a3,0x00000000}},	//   авяз, arą_, _mhed,
  { {0x764308f0,0xafdb00d1,0x945d0051,0x00000000}},	//   ngny, tfør, pońs,
  { {0xb05b004d,0x63a9004d,0x62870072,0x00000000}},	//   unäc, lzen, öjou,
  { {0xafdb02ab,0x649c0025,0x6fb60021,0x00000000}},	//   rfør, _néil, _لمعا,
  { {0x63a90d0b,0x4a460002,0xab270a72,0x00000000}},	// [fc0] nzen, кнав, кота_,
  { {0xafdb076c,0x63a90d0c,0x6108011b,0x00000000}},	//   pfør, izen, _měln,
  { {0x68fb00eb,0x29030016,0x39460121,0x00000000}},	//   _biud, _cuja_, тнег,
  { {0x68fb0d0d,0x6f040035,0x649c0139,0x00000000}},	//   _ciud, _kuic, _céil,
  { {0x63a90d0e,0x6f040d0f,0xf7430002,0x00000000}},	//   jzen, _juic, иецо,
  { {0x63a90d10,0xf793000d,0xd1380078,0x00000000}},	//   dzen, рашэ, yrą_,
  { {0x649c0025,0x6d4e0d11,0x2bd80042,0x00000000}},	//   _féil, ntba, _भँडा,
  { {0x68fb051e,0x649c0025,0x3eb80d12,0x00000000}},	//   _giud, _géil, hirt_,
  { {0x69dc072f,0x6d4e0d13,0x44f70021,0x00000000}},	//   _hyre, htba, خروج_,
  { {0xd138091b,0x6d4e0d14,0x6108004c,0x00000000}},	//   trą_, ktba, _děln,
  { {0x7afc0498,0x68e900b9,0x63a90d15,0x00000000}},	//   _mirt, _yhed, azen,
  { {0x40350088,0x69dc0d16,0x213e0d17,0x00000000}},	//   ыемс, _myre, ruth_,
  { {0x63a90045,0x69dc0d18,0xdfd80062,0x00000000}},	//   czen, _lyre, вър_,
  { {0x7afc0150,0xf7730063,0xa2930086,0x00000000}},	//   _nirt, בקש_, _ваші,
  { {0x6d4e0d19,0x69dc0d1a,0x5c070895,0x00000000}},	//   gtba, _nyre, вяза,
  { {0x672d003d,0xec340086,0x3eb80139,0x00000000}},	//   šaji, инсь, airt_,
  { {0x68e9001f,0x7afc0b9c,0x2903017d,0x00000000}},	// [fd0] _rhed, _birt, _suja_,
  { {0xe0df0290,0x64950025,0xdee40259,0x00000000}},	//   llò_, _háit, _коњи,
  { {0x2d8c000e,0x3f99001f,0x68e9002b,0x00000000}},	//   ødet_, lysu_, _phed,
  { {0x08d40086,0x9981004c,0x69dc0d1b,0x00000000}},	//   ація, sahů_, _dyre,
  { {0x649c0025,0x68fb0871,0x6101001c,0x00000000}},	//   _céim, _viud, _vēli,
  { {0x64950027,0x4aa70161,0xf77003eb,0x00000000}},	//   _láit, _गतिव, غان_,
  { {0x20d904cd,0x54d50131,0x955501f3,0x00000000}},	//   néis_, лциу, اختا,
  { {0x20050045,0xe89401e8,0x63a90d1c,0x00000000}},	//   ślij_, _кась, tzen,
  { {0x61080080,0xe8940121,0x63a90d1d,0x00000000}},	//   _bělo, _тать, uzen,
  { {0x454504f6,0xed6001d9,0x386d0d1e,0x00000000}},	//   _منطق, ážku_, _haer_,
  { {0x386d0089,0x63a90d1f,0x6108004c,0x00000000}},	//   _kaer_, szen, _dělo,
  { {0x71a2000d,0x20d90331,0x3eb8004d,0x00000000}},	//   саюз, déis_, wirt_,
  { {0xd12e007e,0x6f040d20,0x386d0335,0x00000000}},	//   يمی_, _quic, _maer_,
  { {0x386d00e8,0x61450699,0x2d9803d4,0x00000000}},	//   _laer_, _бека, tyre_,
  { {0x2d9e027d,0xb05b0137,0x387f0058,0x00000000}},	//   áte_, mnän, _onur_,
  { {0x6d4e0d21,0x7afc0d22,0x3f99002b,0x00000000}},	//   rtba, _sirt, bysu_,
  { {0x30db0047,0x2d9e04d9,0x0aea0062,0x00000000}},	// [fe0] _אַזע, šte_, едай_,
  { {0x9a6a0032,0x20d9006d,0x649c0d23,0x00000000}},	//   عمال_, béis_, _réim,
  { {0xd5b1001b,0x2d850137,0x7afc0d24,0x00000000}},	//   _xét_, älet_, _virt,
  { {0x7afc0d25,0x20d90025,0x386d0d26,0x00000000}},	//   _wirt, léir_, _caer_,
  { {0x386d0d27,0x7afc0d28,0x7bdd002b,0x00000000}},	//   _daer_, _tirt, _gysu,
  { {0x7afc0025,0x20d90025,0x96e70054,0x00000000}},	//   _uirt, néir_, льща_,
  { {0x2aa4000f,0x64950025,0x7c260150,0x00000000}},	//   _több_, _náis, _kekr,
  { {0x938a0002,0x386d002b,0xb4be0053,0x00000000}},	//   есоа_, _gaer_, ँचे_,
  { {0x64950025,0x5c370047,0xb356005d,0x00000000}},	//   _ráit, ארפן_, ایتا_,
  { {0x59b80053,0xa5da0021,0xa01b00a5,0x00000000}},	//   _आधार, _كبار_, njöv,
  { {0x7c260250,0x6e25005b,0xdd120058,0x00000000}},	//   _oekr, _rehb, _rüşv,
  { {0x7d050058,0x69c30022,0x7c260d29,0x00000000}},	//   _ruhs, źneg, _nekr,
  { {0xe0df0290,0xe29a0d2a,0x6108004c,0x00000000}},	//   rlò_, _пад_, _tělo,
  { {0x7bdd0051,0x44260013,0x64950d2b,0x00000000}},	//   _rysu, _heo_, _fáis,
  { {0x7c260d2c,0x4426055f,0xc2c3014d,0x00000000}},	//   _bekr, _keo_, _ديوي,
  { {0x64950025,0x20d90d2d,0x2fc600a8,0x00000000}},	//   _háir, réis_, _žoge_,
  { {0x2d8c05b9,0x20d9006d,0x44260d2e,0x00000000}},	// [ff0] øder_, séis_, _meo_,
  { {0x20d90d2f,0x44260d30,0x386d002b,0x00000000}},	//   péis_, _leo_, _saer_,
  { {0xedf3007e,0x64950025,0x7bdd0051,0x00000000}},	//   _ديدگ, _máir, _wysu,
  { {0xddde0080,0x7c2603ac,0x44260d31,0x00000000}},	//   _např, _gekr, _neo_,
  { {0xd366041b,0x2ca90027,0x44290066,0x00000000}},	//   _به_, mhad_, _ľa_,
  { {0xca49007e,0x64950139,0x3a87000d,0x00000000}},	//   _جلسه_, _náir, _сымв,
  { {0x44260025,0x95c801ce,0xaa58012c,0x00000000}},	//   _beo_, лућа_, _щиру_,
  { {0x44260d32,0x2ca900a3,0xf7950085,0x00000000}},	//   _ceo_, nhad_, _кабэ,
  { {0x64950025,0x44260d33,0x73050d34,0x00000000}},	//   _báir, _deo_, јпоз,
  { {0xe2990001,0x64950139,0x72950062,0x00000000}},	//   тао_, _páis, рших,
  { {0x20c60086,0x067a0047,0x00860ad9,0x00000000}},	//   ийом, _שנעל, ално,
  { {0x44260d35,0x2c150053,0x672d007d,0x00000000}},	//   _geo_, _फ्लू_, šaju,
  { {0x20d90025,0x7c260d36,0x53390041,0x00000000}},	//   téir_, _rekr, _סײַד,
  { {0x64950025,0x2ca900f5,0x248d0d37,0x00000000}},	//   _táis, ehad_, ljem_,
  { {0x20d90025,0xb606027d,0x7c2600c2,0x00000000}},	//   réir_, _uváž, _pekr,
  { {0x248d065f,0x2ca90025,0xb05b0072,0x00000000}},	//   njem_, ghad_, nnäl,

  { {0x3b07071a,0x249f0d38,0xdca30121,0x00000000}},	// [1000] ието_, ikum_, цати,
  { {0x248d0d39,0x249f0058,0x3ce00807,0x00000000}},	//   hjem_, hkum_, sliv_,
  { {0x7c2601f7,0x249f0026,0xb4f70053,0x00000000}},	//   _tekr, kkum_, ुदाय_,
  { {0x31560047,0xb17a0047,0x2ca9080f,0x00000000}},	//   ייען_, כטער, chad_,
  { {0x248d00c3,0x91fc001c,0x44260d3a,0x00000000}},	//   djem_, ndār, _reo_,
  { {0x4426018d,0xdcfc0078,0xe6930049,0x00000000}},	//   _seo_, tyrė, يلند,
  { {0xfc3f0066,0x4426004b,0xda5b009a,0x00000000}},	//   _ulíc_, _peo_, _שכלל,
  { {0xd4970121,0x94170062,0xd37a0d3b,0x00000000}},	//   иры_, ажът_, вчо_,
  { {0xb8dc016a,0x64950027,0x44260d3c,0x00000000}},	//   ेच_, _páir, _veo_,
  { {0xd2570086,0x68e20cc7,0x291a0d3d,0x00000000}},	//   ацю_, llod, oppa_,
  { {0x672d0add,0x64a60d3e,0x248d0a80,0x00000000}},	//   šajt, _кажа, bjem_,
  { {0xd83f0114,0xdfa70002,0xe0440002,0x00000000}},	//   _účtu_, ајго, онџи,
  { {0x64950025,0x6d5e07b9,0x58f70047,0x00000000}},	//   _táir, _appa, ימטע_,
  { {0xd5b10013,0x3ea5013d,0x539b009a,0x00000000}},	//   _kép_, ólt_, _בידו,
  { {0xa2d30053,0x6143018e,0x6113003b,0x00000000}},	//   डवर्, _деја, _căld,
  { {0x76b20051,0xbd440021,0x51fb0063,0x00000000}},	//   pływ, تنفي, _בהוצ,
  { {0x2ca90d3f,0x5a35005a,0x68e2001f,0x00000000}},	// [1010] rhad_, йнат, dlod,
  { {0xda780055,0x657a057a,0x213e00f6,0x00000000}},	//   иях_, _orth, orth_,
  { {0xceb200b5,0xe987005e,0x83fd013d,0x00000000}},	//   _זיי_, шћан, ndőr,
  { {0x213e00e5,0x68e20d40,0x89340044,0x00000000}},	//   irth_, glod, زعما,
  { {0x96b90001,0x248d00c2,0x291a0d41,0x00000000}},	//   луку_, vjem_, appa_,
  { {0x68e2001c,0x7c2d017a,0x23ca0053,0x00000000}},	//   alod, laar, ापनद,
  { {0x248d00c3,0xce380063,0x25a1004c,0x00000000}},	//   tjem_, באות_, áhl_,
  { {0x7c2d0d42,0x64950025,0x249f0052,0x00000000}},	//   naar, _cáip, ukum_,
  { {0x248d00c3,0xf773006a,0x657a0185,0x00000000}},	//   rjem_, _باز_, _erth,
  { {0x249f0d43,0xe610005d,0x7c2d0d44,0x00000000}},	//   skum_, _قشم_, haar,
  { {0x6f160d45,0x7c2d0d46,0x63ad0022,0x00000000}},	//   _styc, kaar, _żand,
  { {0x84640062,0x7c2d0d47,0xd3080013,0x00000000}},	//   _мъче, jaar, _iện_,
  { {0x999100ea,0x442d0d48,0x26c70d49,0x00000000}},	//   _mező_, mae_, onno_,
  { {0x442d0d4a,0x64490d4b,0xc7d60aeb,0x00000000}},	//   lae_, lgei, מורי_,
  { {0x6da30d4c,0x62830d4d,0xada30d4e,0x00000000}},	//   пира, _inno, парл,
  { {0x64490d4f,0x442d0d50,0x7c2d0d51,0x00000000}},	//   ngei, nae_, gaar,
  { {0x2ca00d52,0x4ed60d53,0x7e9a043e,0x00000000}},	// [1020] rkid_, _гюнт, _منظر_,
  { {0x7c2d00bb,0x2ca00d54,0x442d0d55,0x00000000}},	//   aaar, skid_, hae_,
  { {0x9e7b00b5,0x68e2001c,0x38cb007e,0x00000000}},	//   _ענטפ, tlod, گالی_,
  { {0x6c860032,0xb05b0072,0x777b0d56,0x00000000}},	//   _الحم, enäj, _brux,
  { {0xddd50080,0x62830229,0x30db0047,0x00000000}},	//   dezř, _onno, אַגע,
  { {0xa01b0137,0x7e7a0047,0xcd29007e,0x00000000}},	//   njör, ראַז, _حسین_,
  { {0xb9960032,0x64950139,0x68e20d57,0x00000000}},	//   _الزب, _páip, plod,
  { {0x26c70290,0xe3140001,0x442d00f6,0x00000000}},	//   anno_, омињ, gae_,
  { {0x213e0185,0x657a0185,0xdc9b0047,0x00000000}},	//   wrth_, _wrth, טיקל,
  { {0x2d7808ea,0x78a2027d,0x2b400139,0x00000000}},	//   _oče_, lkov, iric_,
  { {0x290a0004,0x442d002c,0xd4d6000d,0x00000000}},	//   _juba_, bae_, _лідэ,
  { {0x290a0150,0x78a20d58,0x442d0d59,0x00000000}},	//   _muba_, nkov, cae_,
  { {0x290a0019,0x4394018e,0x623400e1,0x00000000}},	//   _luba_, _фалс, _делу,
  { {0x2918048e,0x7c2d0173,0x9e140086,0x00000000}},	//   _otra_, waar, здрі,
  { {0x6102003d,0x7095000a,0xb05b00fe,0x00000000}},	//   _vēlr, _макф, nnäk,
  { {0x2b4004aa,0x78a2059d,0x929d056c,0x00000000}},	//   fric_, jkov, dpły,
  { {0x40540032,0x38660d5a,0xfe6e007e,0x00000000}},	// [1030] _رئيس, deor_, رگی_,
  { {0x5a350086,0x539b0063,0x7c2d0d5b,0x00000000}},	//   інет, אימו, saar,
  { {0x290a0d5c,0x6d410d5d,0x7c2d0d5e,0x00000000}},	//   _cuba_, álad, paar,
  { {0x6d5500bd,0xec6b03d6,0x2b4000e5,0x00000000}},	//   mtza, _срок_, bric_,
  { {0x442d0d5f,0x2b4001a8,0x6108004c,0x00000000}},	//   vae_, cric_, _děli,
  { {0xb7c6003d,0x290700f8,0x6f1d006f,0x00000000}},	//   diģē, ínas_, ipsc,
  { {0x6d4700c3,0x64490d60,0x442d0d61,0x00000000}},	//   nuja, tgei, tae_,
  { {0x94790d62,0x6e2e00ea,0xf359005e,0x00000000}},	//   рску_, zabb, ашој_,
  { {0x442d0d63,0x290a007d,0x52a908ac,0x00000000}},	//   rae_, _zuba_, ивим_,
  { {0x6d55006f,0x6e2e004d,0x29180014,0x00000000}},	//   ktza, xabb, _ytra_,
  { {0x71b50076,0x208a0d64,0x6113003b,0x00000000}},	//   ющих, айни_, _sălb,
  { {0x25d600b5,0xafdb00d1,0x6d470d65,0x00000000}},	//   _ווען_, lføy, duja,
  { {0xa8560063,0x60cd0d66,0xa01b0014,0x00000000}},	//   חירה_, _djam, tjör,
  { {0x78a90d67,0x78a2027d,0x6113003b,0x00000000}},	//   _llev, zkov, _călc,
  { {0xde03019d,0x78a90d68,0x6d470d69,0x00000000}},	//   дпри, _olev, guja,
  { {0x8b260ac5,0x2b400d6a,0x6e2e0d21,0x00000000}},	//   ждае, tric_, sabb,
  { {0x765c0026,0x6d470006,0x20050080,0x00000000}},	// [1040] _öryg, auja, ělit_,
  { {0xe8220053,0x6d470d6b,0x61e30014,0x00000000}},	//   मर्थ_, buja, _kynl,
  { {0x78a9010a,0x6abe0186,0x89160021,0x00000000}},	//   _blev, ripf, زبائ,
  { {0x78a90d6c,0x814c0047,0x80370047,0x00000000}},	//   _clev, רעאַ, ַנצע_,
  { {0x2907007a,0x78a20d6d,0x69cb0244,0x00000000}},	//   ínar_, rkov, ßger,
  { {0x649c0025,0xeb9f0093,0x7b09007d,0x00000000}},	//   _léit, _tfør_, _džud,
  { {0x27ed000f,0xd6390086,0x78a90717,0x00000000}},	//   _ezen_, сячі_, _flev,
  { {0xd91b0063,0xf9b7009a,0x09b7009d,0x00000000}},	//   _כולל, _והלך_, _ופלט_,
  { {0xb05b0072,0xf3660054,0xccf3089e,0x00000000}},	//   snäk, ітин, וכה_,
  { {0xb7c6001c,0x60cd0d6e,0x78a9004c,0x00000000}},	//   riģē, _sjam, _zlev,
  { {0x61e30185,0x26dc0d6f,0x27e40d70,0x00000000}},	//   _cynl, movo_, _hymn_,
  { {0x6d4700fe,0x26dc0d71,0x29040d72,0x00000000}},	//   vuja, lovo_, _jima_,
  { {0x248601e3,0xb05b0072,0x649c0d73,0x00000000}},	//   _inom_, nnäi, _déit,
  { {0x26dc055e,0x6d470d74,0x29040d75,0x00000000}},	//   novo_, tuja, _lima_,
  { {0xdcbb011c,0x61e3001f,0x361b0047,0x00000000}},	//   аща_, _gynl, שולד,
  { {0x290400c3,0x62980a63,0x26dc0d76,0x00000000}},	//   _nima_, _hovo, hovo_,
  { {0x63a0027d,0x2486007d,0x26dc0d77,0x00000000}},	// [1050] nymn, _mnom_, kovo_,
  { {0x6d470d78,0x60dd0d79,0x78a90d7a,0x00000000}},	//   puja, losm, _slev,
  { {0xdfd1006a,0x89d90021,0x2d8c01e9,0x00000000}},	//   _زيگ_, حوار_, ädet_,
  { {0xf7710067,0x6f0d0035,0x6b8b0137,0x00000000}},	//   فات_, _kuac, äggs,
  { {0x7c22006d,0x0a6b0001,0x78a90080,0x00000000}},	//   ñore, _крви_, _vlev,
  { {0xd6db02a9,0x26dc02e2,0x62980d7b,0x00000000}},	//   ште_, govo_, _novo,
  { {0x6f0d0025,0xa9540086,0xf5920021,0x00000000}},	//   _luac, _окрі, فلوج,
  { {0x442b008b,0x20090d7c,0xf3f900dd,0x00000000}},	//   úc_, _ngai_, leţi_,
  { {0x6f0d0027,0x649c0025,0x61e30d7d,0x00000000}},	//   _nuac, _réit, _synl,
  { {0xf3f90529,0xd2a90055,0x649c006d,0x00000000}},	//   neţi_, ское_, _béis,
  { {0x1a9c0047,0x6113003b,0x21690cdf,0x00000000}},	//   ייזע, _băla, щини_,
  { {0x6f0d0139,0x6113003b,0x95c4005d,0x00000000}},	//   _buac, _căla, _تيمه,
  { {0x7ea20164,0x61fe0240,0xb7bd003b,0x00000000}},	//   _hôpi, _úpln, _beţi,
  { {0x62980add,0x52390047,0xe3b001fb,0x00000000}},	//   _govo, _הײַנ, _جرم_,
  { {0xf3f90529,0xb7bd000c,0x91e20932,0x00000000}},	//   deţi_, _deţi, _поше,
  { {0x649c0025,0x236d0051,0xac0a0002,0x00000000}},	//   _héir, owej_, снаа_,
  { {0x6f0d0d7e,0x29040d7f,0x6b630d80,0x00000000}},	// [1060] _guac, _rima_, нкта,
  { {0xf3f90529,0x645b0027,0x6d410025,0x00000000}},	//   geţi_, hfui, álac,
  { {0x7e9b0063,0xa9670062,0x0e9b0063,0x00000000}},	//   _הסיו, зиха_, _השיל,
  { {0x649c0027,0x6f57005d,0xa2bb0082,0x00000000}},	//   _léir, _بلیز_, षोत्,
  { {0x7c240d81,0x26dc0869,0x66e60d82,0x00000000}},	//   mbir, tovo_, пода,
  { {0xf3f90529,0x26dc051e,0x649c0139,0x00000000}},	//   ceţi_, uovo_, _néir,
  { {0x29040d83,0xb05b004b,0x26dc0d84,0x00000000}},	//   _tima_, snäi, rovo_,
  { {0x7b070025,0x493b0063,0x39570063,0x00000000}},	//   _órtá, _לגלו, _משלם_,
  { {0x7d060659,0xf743006e,0x62980114,0x00000000}},	//   _miks, _пето, _povo,
  { {0x7d060d85,0x649c0139,0x2cfa0053,0x00000000}},	//   _liks, _péis, ्दुल_,
  { {0xb7bd000c,0xf1a301d5,0x81c60121,0x00000000}},	//   _reţi, ерян, ящие,
  { {0x6298004d,0x7d060d86,0x00000000,0x00000000}},	//   _wovo, _niks,   ,
  { {0x7c240d87,0xdfdb005a,0x629800c2,0x00000000}},	//   dbir, сън_, _tovo,
  { {0xd24f0032,0xb2d30021,0x69c10014,0x00000000}},	//   _منه_, _كينغ, _ýleg,
  { {0xf3f9000c,0x7d060150,0xa2d90053,0x00000000}},	//   veţi_, _biks, नकर्,
  { {0x6f0d0139,0x2a7f0075,0x6108011b,0x00000000}},	//   _tuac, _şub_, _dělt,
  { {0xf3f90469,0x2d8c0d88,0x7d060d89,0x00000000}},	// [1070] teţi_, äder_, _diks,
  { {0x7c240d8a,0x7d06005f,0x0dcb0d8b,0x00000000}},	//   abir, _eiks, _гуми_,
  { {0xf3f9000c,0xa9070593,0x7d060d8c,0x00000000}},	//   reţi_, سبان, _fiks,
  { {0x6ef200b9,0xe9f80086,0x2d9e004e,0x00000000}},	//   ræbe, їнці_, ätee_,
  { {0x3b64011c,0xf3f9000c,0xe738000d,0x00000000}},	//   _първ, peţi_, зеі_,
  { {0x644700eb,0x45190062,0xcd340043,0x00000000}},	//   ėjim, оция_, _تریب,
  { {0x6724001c,0xdb08013d,0x45180085,0x00000000}},	//   ģija, ölöt, пцыя_,
  { {0x0319007e,0x649c0139,0xc9520063,0x00000000}},	//   يتخت_, _séir, _שמן_,
  { {0x2d570058,0x649c0139,0x33650054,0x00000000}},	//   hçe_, _péir, євог,
  { {0x7c2400c3,0x2d57005b,0x957c0051,0x00000000}},	//   zbir, kçe_, _cząs,
  { {0x9046006a,0x94190094,0xf4870083,0x00000000}},	//   ونده, _джет_, _нудн,
  { {0xcea900b7,0xb6030066,0x7c2f0d8d,0x00000000}},	//   _די_, _vtáč, _necr,
  { {0x7d0601d0,0xe2a80043,0x9836009d,0x00000000}},	//   _riks, زاین_, וטרו_,
  { {0xa1c50086,0x442f00ac,0x7d060d8e,0x00000000}},	//   _облд, _heg_, _siks,
  { {0x2d9e003b,0x7d060d8f,0x7c240605,0x00000000}},	//   âte_, _piks, tbir,
  { {0x442f02ab,0xb05b0d90,0x5f460021,0x00000000}},	//   _jeg_, liän, _قنبل,
  { {0x442f0d91,0x200f0066,0xa08b0063,0x00000000}},	// [1080] _meg_, ámiť_, _וְיִ,
  { {0x4a43000a,0xda660021,0x7c240d92,0x00000000}},	//   кнув, باري, sbir,
  { {0x7d060d93,0x442f0438,0xd910007e,0x00000000}},	//   _tiks, _oeg_, ایر_,
  { {0x3ce901c2,0x291c001c,0x7c2f05df,0x00000000}},	//   clav_, īva_, _gecr,
  { {0xafdb00b9,0x69d5004d,0xd7f706da,0x00000000}},	//   lgør, _exze, муш_,
  { {0x442f0004,0xb05b0137,0xd7f90086,0x00000000}},	//   _aeg_, lnät, чує_,
  { {0xafdb05b9,0x442f0d94,0xa9260085,0x00000000}},	//   ngør, _beg_, _ідал,
  { {0x2a780d95,0x54540062,0x9855000d,0x00000000}},	//   _harb_, хвит, _птуш,
  { {0x442f0d96,0xbc1b0063,0xfc3f0026,0x00000000}},	//   _deg_, חופש, _slík_,
  { {0xb92b0013,0x442f0d97,0xa79b009a,0x00000000}},	//   _nguỵ_, _eeg_, _ושמח,
  { {0x6722003d,0xb05b0137,0xe1340085,0x00000000}},	//   lpoj, knät, энны,
  { {0x3cfa0161,0x14170021,0xafdb01e1,0x00000000}},	//   ्दों_, _قيمة_, dgør,
  { {0x5f94005a,0x7c2f04bc,0x26ce0290,0x00000000}},	//   вият, _recr, onfo_,
  { {0x2d5701f7,0x442f006f,0xafdb00b9,0x00000000}},	//   tçe_, _zeg_, fgør,
  { {0xafdb0146,0x443d001f,0x26ce0d98,0x00000000}},	//   ggør, _ydw_, info_,
  { {0x9f550086,0x2cb2001f,0x55770047,0x00000000}},	//   _звич, ghyd_, ועלן_,
  { {0x7c22006d,0xd1380078,0x7e770d99,0x00000000}},	// [1090] ñora, lsą_, _taxp,
  { {0x2a780d2e,0xe9ab00f2,0x3ce90d9a,0x00000000}},	//   _carb_, يدان_, slav_,
  { {0x2a780025,0x7eab0019,0x7c2f005b,0x00000000}},	//   _darb_, _hüpo, _tecr,
  { {0x2cb20185,0xd1380006,0x6e35007d,0x00000000}},	//   chyd_, isą_, lazb,
  { {0x442f0d9b,0xddd500ea,0xbc1a0063,0x00000000}},	//   _reg_, mező, _מורש,
  { {0x442f0031,0xd1380006,0xddd500ea,0x00000000}},	//   _seg_, ksą_, lező,
  { {0x26c9007d,0xb05b0d9c,0xd9140085,0x00000000}},	//   đao_, nnäs, _адсы,
  { {0x628a0d9d,0x6d470d9e,0x2ca90137,0x00000000}},	//   _anfo, irja, nkad_,
  { {0x442f0d9f,0xe3b10021,0xd1380078,0x00000000}},	//   _veg_, طرة_, esą_,
  { {0x442f0da0,0x673b0072,0xeb92089e,0x00000000}},	//   _weg_, _ivuj, רָה_,
  { {0x2f140137,0xddd500ea,0x68eb006f,0x00000000}},	//   _säg_, kező, olgd,
  { {0xddd500ea,0x628a0da1,0x3f6a0da2,0x00000000}},	//   jező, _enfo, пимо_,
  { {0x6d470da3,0x6d410da4,0x2ca90da5,0x00000000}},	//   erja, álan, dkad_,
  { {0x2f1400c7,0xafdb00b9,0xd2510021,0x00000000}},	//   _väg_, tgør, _صنع_,
  { {0x98a70080,0xacf600d7,0x9f63004c,0x00000000}},	//   éně_, ечај, ěvák_,
  { {0xafdb0146,0x91ba009a,0x00000000,0x00000000}},	//   rgør, _ממצי,   ,
  { {0xcb670da6,0x6d470da7,0xab660085,0x00000000}},	// [10a0] нате_, arja, эвал,
  { {0xb05b00c7,0xafdb00b9,0x8c430058,0x00000000}},	//   snät, pgør, ışab,
  { {0xc879005b,0x29110da8,0xc8660da9,0x00000000}},	//   _baş_, _cuza_, етли,
  { {0xd491001b,0x60c6003e,0x2ca900c7,0x00000000}},	//   _tùy_, nikm, ckad_,
  { {0x60c60019,0x7c360332,0xb05b0daa,0x00000000}},	//   iikm, mayr, onär,
  { {0x26ce0297,0x2f3b0047,0x6d5c0dab,0x00000000}},	//   unfo_, לגנד, otra,
  { {0x6d4e0dac,0x6d5c03e1,0x23660dad,0x00000000}},	//   nuba, ntra, _spoj_,
  { {0x67220072,0x6d5c0dae,0x6745013d,0x00000000}},	//   ppoj, itra, ütjü,
  { {0x7afe0bbd,0x68e20019,0x6d4e00a4,0x00000000}},	//   ompt, mood, huba,
  { {0x6d4e0009,0x6d470014,0x9bbb0063,0x00000000}},	//   kuba, yrja, פציפ,
  { {0xd46a0daf,0xd1380006,0x51f80086,0x00000000}},	//   _ниже_, usą_, ьною_,
  { {0xe61f008b,0x68e2056f,0xd1380078,0x00000000}},	//   _đôi_, nood, rsą_,
  { {0xdefb0121,0x6d5c0db0,0xddd5009c,0x00000000}},	//   зыв_, etra, vező,
  { {0x628a0034,0x6d5c00bd,0x60c60078,0x00000000}},	//   _unfo, ftra, aikm,
  { {0x68e20d9e,0x6d5c0db1,0x6d4e0db2,0x00000000}},	//   kood, gtra, guba,
  { {0x61430001,0x60c6005b,0xb05b0137,0x00000000}},	//   _сећа, cikm, rnäs,
  { {0x6d4e004b,0xfbd00021,0x2ca90db3,0x00000000}},	// [10b0] auba, متك_, rkad_,
  { {0x2ca90db4,0x6d4e0db5,0x6d5c0db6,0x00000000}},	//   skad_, buba, btra,
  { {0xc9840d34,0xb8350062,0xe8590085,0x00000000}},	//   луци, веещ, даеш_,
  { {0x7afe00ac,0xd3080013,0xcd960063,0x00000000}},	//   ampt, _iệu_, _סדרת_,
  { {0xb05b0072,0x4c9a089e,0xe6950121,0x00000000}},	//   jiäm, _חברו, киды,
  { {0xc6680001,0x6446013d,0x7eb0004e,0x00000000}},	//   ешће_, ókin, _käpa,
  { {0x68e200e8,0x20e10053,0xc8790058,0x00000000}},	//   bood, नवाध, _taş_,
  { {0xe8d5009d,0x00000000,0x00000000,0x00000000}},	//   _סוּר_,   ,   ,
  { {0x6d5c0db7,0x60c60014,0x6d4e004d,0x00000000}},	//   ztra, vikm, zuba,
  { {0x63a600d1,0x6d4e0150,0x6d5c0db8,0x00000000}},	//   økna, yuba, ytra,
  { {0x61ea0185,0x60c60006,0x4a5c0047,0x00000000}},	//   _cyfl, tikm, לדזו,
  { {0x26c70db9,0x6d5c0dba,0x387d002b,0x00000000}},	//   lino_, vtra, ndwr_,
  { {0xb05b0137,0x3f8401c2,0x6d5c002b,0x00000000}},	//   tnär, ímu_, wtra,
  { {0x6d4e0dbb,0x6d5c0dbc,0x60c60dbd,0x00000000}},	//   tuba, ttra, sikm,
  { {0x61ea0185,0xed5705a1,0x6d5c0dbe,0x00000000}},	//   _gyfl, кор_, utra,
  { {0x8c43000a,0x6d4e0dbf,0x26c70dc0,0x00000000}},	//   иесе, ruba, hino_,
  { {0x6d4e00bb,0x387d001f,0x6d5c03db,0x00000000}},	// [10c0] suba, ddwr_, stra,
  { {0x26c70dc1,0x6d5c0dc2,0x0f370041,0x00000000}},	//   jino_, ptra, _שריט_,
  { {0x68e20019,0xda650021,0x26c70dc3,0x00000000}},	//   tood, طالي, dino_,
  { {0xdb0d00ea,0xd3080013,0xa01b0014,0x00000000}},	//   szaá, _hệt_, rdög,
  { {0x26c70dc4,0x68e20dc5,0xcee9005d,0x00000000}},	//   fino_, rood, _زرین_,
  { {0x68e20019,0x26c70dc6,0xb05b0072,0x00000000}},	//   sood, gino_, viäm,
  { {0xceb30063,0xd3080013,0x95530021,0x00000000}},	//   שיו_, _mệt_, لخيا,
  { {0xe6f20013,0xd308008d,0x18a30085,0x00000000}},	//   _dườ, _lệt_, _касм,
  { {0x26c70198,0xd4670001,0x6ef200b9,0x00000000}},	//   bino_, тиње_, væbn,
  { {0x26c70dc7,0x60c400a4,0xc1740121,0x00000000}},	//   cino_, _amim, глощ,
  { {0xaa370047,0xe6f20013,0x40350dc8,0x00000000}},	//   כטיק_, _gườ, ленс,
  { {0x7ccc005b,0x94260002,0x7eb0004b,0x00000000}},	//   oğru, _рмде, _räpa,
  { {0x2d9e0dc9,0x2d8c0dca,0xddce005f,0x00000000}},	//   äten_, åden_, bebū,
  { {0x41dd0053,0x62340dcb,0x6d4109b6,0x00000000}},	//   _नुकस, _секу, šlam,
  { {0x2d850dcc,0xd308008b,0x9e340121,0x00000000}},	//   íle_, _dệt_, ресч,
  { {0x2b4901a8,0xf0470085,0x26c70dcd,0x00000000}},	//   trac_, _рэко, zino_,
  { {0x9be70086,0x09bd0053,0x80a4007e,0x00000000}},	// [10d0] тівк, ्प्य, _خمين,
  { {0xdd03005b,0x7a35007e,0x387d002b,0x00000000}},	//   ırıc, افاص, wdwr_,
  { {0x26c70dce,0x77690137,0x6cd5002a,0x00000000}},	//   vino_, _spex, _مقدا,
  { {0x64420dcf,0xe6f2008d,0x26c700a3,0x00000000}},	//   _ndoi, _rườ, wino_,
  { {0x3ea10019,0x26c70dd0,0x7b090078,0x00000000}},	//   _koht_, tino_, _užuo,
  { {0xe7eb0042,0x66f4046e,0xc7320044,0x00000000}},	//   ड़ेगा_, апчу, حفوظ,
  { {0x26c70dd1,0x95c8005e,0xf999009a,0x00000000}},	//   rino_, кућа_, _אֱ֭ל,
  { {0x94750021,0x26c70dd2,0x3f8600c2,0x00000000}},	//   ادثا, sino_, _šoum_,
  { {0x26c70dd3,0xdce5001c,0x13090065,0x00000000}},	//   pino_, _arhī, нний_,
  { {0x6b67001c,0xe6f20013,0x7dd2013d,0x00000000}},	//   mīgā, _tườ, nűsé,
  { {0x27fa0051,0xd3080013,0x2455002a,0x00000000}},	//   ępne_, _rệt_, _مناس,
  { {0x629a0dd4,0xd308008d,0x351a0063,0x00000000}},	//   ajto, _sệt_, _טוענ,
  { {0x7ae5037e,0x6b67008f,0x239b0021,0x00000000}},	//   koht, nīgā, _تخضع_,
  { {0x7ae500fe,0x91fc008f,0xe39a0063,0x00000000}},	//   joht, teāt, _רֹאש,
  { {0x92560dd5,0x290d006d,0x63bb004d,0x00000000}},	//   _сајт_, _oiea_, lzun,
  { {0x63a90003,0x27ed0331,0x4f960dd6,0x00000000}},	//   oyen, _oyen_, _броу,
  { {0x8b260088,0x63bb00bd,0xf4120047,0x00000000}},	// [10e0] удзе, nzun, מפן_,
  { {0xfeba006a,0x290d0ccf,0x7e56005e,0x00000000}},	//   _ساخت_, _aiea_, _стиц,
  { {0x09f6047e,0x91fc0023,0x6da60dcb,0x00000000}},	//   учая, leār, _сина,
  { {0x27ed04b1,0x7e7e01a0,0xd7fa0076,0x00000000}},	//   _byen_, _happ, нул_,
  { {0x7c95000d,0xddc70124,0x7e7e0dd7,0x00000000}},	//   _трэц, mejš, _kapp,
  { {0x66e302dc,0xddc70dd8,0xaf770041,0x00000000}},	//   боча, lejš, טענס_,
  { {0x7b09017f,0x6b84056f,0x7e7e0dd9,0x00000000}},	//   _ožuj, lvig, _mapp,
  { {0xddc70dda,0x63bb004d,0x3a3a0ddb,0x00000000}},	//   nejš, fzun, lapp_,
  { {0x6b67001c,0xa5070001,0x63a900ea,0x00000000}},	//   cīgā, ћења_, gyen,
  { {0x3a3a0ddc,0x6b84004b,0xf12609b3,0x00000000}},	//   napp_, ivig, льмо,
  { {0x6b840019,0x63bb0035,0xa52602d8,0x00000000}},	//   hvig, azun, _смед,
  { {0x7a48001c,0x629a0104,0x7e7e0ddd,0x00000000}},	//   lītē, sjto, _aapp,
  { {0x7e7e0dde,0x4fc70ddf,0xdfd80062,0x00000000}},	//   _bapp, усна, гър_,
  { {0x7e7e0de0,0x6b840de1,0x7a480023,0x00000000}},	//   _capp, dvig, nītē,
  { {0xccfb0138,0x7e7e0de2,0x7eb0004b,0x00000000}},	//   ећа_, _dapp, _täpn,
  { {0x61f50058,0x61f80de3,0x00000000,0x00000000}},	//   üzle, _izvl,   ,
  { {0x5a350581,0x6bd40021,0x68fb002b,0x00000000}},	// [10f0] инат, متكر, _rhud,
  { {0x68e90de4,0x68fb00e5,0x20040066,0x00000000}},	//   _sked, _shud, ýmie_,
  { {0xb815000a,0x7dd200ea,0x2d9e04aa,0x00000000}},	//   адеј, rűsé, øtet_,
  { {0x7e7e0de5,0xf77108aa,0xddc70a80,0x00000000}},	//   _zapp, قات_, cejš,
  { {0x7c2d076b,0x4e190042,0xcc5603c3,0x00000000}},	//   mbar, _दलाई_, _דברי_,
  { {0x6b67001c,0x63a90b88,0x7c2d0de6,0x00000000}},	//   rīgā, vyen, lbar,
  { {0x5e580047,0x68fb001f,0x7d0f00ea,0x00000000}},	//   טיגע_, _thud, _kics,
  { {0x63bb0199,0x58d50086,0x68e900d1,0x00000000}},	//   tzun, _тобт, _uked,
  { {0x7c2d00ac,0x63bb004d,0x657a0de7,0x00000000}},	//   ibar, uzun, _esth,
  { {0x63bb00bd,0x79820051,0xd2a90121,0x00000000}},	//   rzun, łowe, ткое_,
  { {0x3f890089,0x7c2d0de8,0x63a906ed,0x00000000}},	//   _arau_, kbar, syen,
  { {0x7c2d0051,0x7e7e0de9,0xd59a0063,0x00000000}},	//   jbar, _sapp, _בבעל,
  { {0x442d0dea,0xddc703f5,0x7e7e0deb,0x00000000}},	//   mbe_, vejš, _papp,
  { {0x7c2d0089,0x7d0f0025,0x6b840290,0x00000000}},	//   ebar, _aics, vvig,
  { {0x3f89000c,0x3c4200ea,0xddc70dec,0x00000000}},	//   _erau_, _lévő_, tejš,
  { {0xed570079,0x3f890ded,0x7c2d0dee,0x00000000}},	//   јот_, _frau_, gbar,
  { {0xddc70def,0x3f890df0,0x442d004d,0x00000000}},	// [1100] rejš, _grau_, ibe_,
  { {0x62810886,0x7c2d0df1,0x6b840df2,0x00000000}},	//   ndlo, abar, rvig,
  { {0x3af50076,0x2d8502ea,0x442d00ea,0x00000000}},	//   сятс, ålet_, kbe_,
  { {0x387f003d,0x442d0df3,0x6e3c0df4,0x00000000}},	//   _caur_, jbe_, larb,
  { {0x442d01a6,0xdddc00ea,0xf7170021,0x00000000}},	//   dbe_, merő, لينغ_,
  { {0x6b8b0146,0xdb04000f,0x442d0df5,0x00000000}},	//   ægge, rzió, ebe_,
  { {0x3856005a,0x6281002b,0x7d040df6,0x00000000}},	//   _възс, ddlo, omis,
  { {0x6d410025,0x48e3013c,0x442d013d,0x00000000}},	//   álai, _досв, gbe_,
  { {0x9ae90086,0x6d4e004d,0x2b4000e5,0x00000000}},	//   нiше_, hrba, nsic_,
  { {0x7d040df7,0x29180df8,0x6d410df9,0x00000000}},	//   hmis, _kura_, šlai,
  { {0x442d02f6,0xf42600fe,0x6e3c0dfa,0x00000000}},	//   bbe_, ääsi_, darb,
  { {0x38660dfb,0x649c0268,0x29180dfc,0x00000000}},	//   nfor_, _néix, _mura_,
  { {0x7d040dfd,0xdfdb005a,0x6e3c0dfe,0x00000000}},	//   dmis, тън_, farb,
  { {0x6e3c0dff,0x7d040e00,0x752a0244,0x00000000}},	//   garb, emis, opfz,
  { {0x7d0f0123,0x42fb0063,0x51930021,0x00000000}},	//   _pics, _שהוס, _ولهذ,
  { {0xdddc000f,0x6e3c0179,0xc035018e,0x00000000}},	//   gerő, aarb, _униј,
  { {0x5c07005a,0x2fcf00c7,0x29180e01,0x00000000}},	// [1110] рява, _ägg_, _aura_,
  { {0x9be4000d,0xe9870001,0x29180e02,0x00000000}},	//   ціск, ићен, _bura_,
  { {0x442d0e03,0x29180741,0x7c2d0e04,0x00000000}},	//   ybe_, _cura_, pbar,
  { {0x7c950021,0x29180e05,0x6d550e06,0x00000000}},	//   _الحص, _dura_, muza,
  { {0x7bd801f7,0x6281002b,0x442d0e07,0x00000000}},	//   şvur, ydlo, vbe_,
  { {0x36c40054,0xdbdd013d,0x7a40004c,0x00000000}},	//   обіг, jáér, rátí,
  { {0x20d20024,0x27fa0051,0x442d0e08,0x00000000}},	//   lšie_, ępna_, tbe_,
  { {0x442d0e09,0x9dd80063,0xadd80063,0x00000000}},	//   ube_, יווק_, יווח_,
  { {0x7c22006d,0x442d0e0a,0x20d20066,0x00000000}},	//   ñori, rbe_, nšie_,
  { {0x7d0402e2,0x3f840014,0x6d550e0b,0x00000000}},	//   zmis, æmum_, kuza,
  { {0x20d20024,0xd298000d,0x7d040e0c,0x00000000}},	//   hšie_, ртыі_, ymis,
  { {0x6d5500be,0xdcfc003b,0xcea903c3,0x00000000}},	//   duza, ivră, _אי_,
  { {0x20d2034d,0xd308008b,0xb606008f,0x00000000}},	//   jšie_, _tệp_, rkšņ,
  { {0x6d55000c,0x249f007a,0xed5a0e0d,0x00000000}},	//   fuza, ljum_, лог_,
  { {0x7d040004,0x6e3c0e0e,0xb4f90047,0x00000000}},	//   tmis, rarb, ָפּי,
  { {0x3a3800cd,0xa01b0058,0x7d04078c,0x00000000}},	//   _serp_, ldön, umis,
  { {0x29180035,0x22470089,0x6a160021,0x00000000}},	// [1120] _sura_, _kdnk_, مبار,
  { {0x3f8f0016,0x29180e0f,0x249f004b,0x00000000}},	//   _água_, _pura_, hjum_,
  { {0x249f0026,0x5d860021,0x2b400e10,0x00000000}},	//   kjum_, _الجل, ssic_,
  { {0x20d20066,0xe73d011b,0x98c5045b,0x00000000}},	//   bšie_, aříž, осіл,
  { {0x386602ab,0xdd8f007e,0x69d9004d,0x00000000}},	//   rfor_, _قوی_, ßwer,
  { {0x66e30086,0xb05b004d,0x38660e11,0x00000000}},	//   поча, chäf, sfor_,
  { {0xceb30063,0x249f0014,0xa56a00de,0x00000000}},	//   היג_, fjum_, اصتك_,
  { {0x249f0026,0x65b20046,0xd5370044,0x00000000}},	//   gjum_, eðhö, حثوا_,
  { {0xdbdd013d,0x5c5b0041,0x3636005d,0x00000000}},	//   táér, װדיק, _هراس,
  { {0x2561000f,0xafdb01e1,0xa01b013d,0x00000000}},	//   ból_, naøe, gdön,
  { {0xf09f0268,0x76480185,0x6a9b0047,0x00000000}},	//   tjà_, _iddy, אשינ,
  { {0xdbdd00ea,0x26ce002b,0x44200075,0x00000000}},	//   sáér, lifo_, _üi_,
  { {0x2ca00150,0x33f603eb,0x2e4b0062,0x00000000}},	//   djid_, _اساس, ляво_,
  { {0x20d20024,0xd1300021,0x3d950e12,0x00000000}},	//   všie_, _قمت_, оигр,
  { {0x7e7500c2,0x82630044,0x212600de,0x00000000}},	//   rezp, _رهين, _اعتُ,
  { {0x853b00b5,0x8cf50726,0x20d20066,0x00000000}},	//   טגלי, ізац, tšie_,
  { {0xab870062,0xab940054,0x5b1401a4,0x00000000}},	// [1130] щувк, питі, змут,
  { {0x20d20024,0x7055007e,0x249f0022,0x00000000}},	//   ršie_, _انکا, zjum_,
  { {0x249f0014,0xb05b00a5,0xceb2089e,0x00000000}},	//   yjum_, rhäf, _חיי_,
  { {0x20d20024,0x76480185,0xb05b0072,0x00000000}},	//   pšie_, _addy, miäs,
  { {0xb05b00fe,0x46a5005a,0x7528008f,0x00000000}},	//   liäs, жалв, _atdz,
  { {0x79820051,0x256107c2,0x7f3c0047,0x00000000}},	//   łowa, tól_, נעוו,
  { {0x249f0026,0x04590021,0x6592005e,0x00000000}},	//   tjum_, للغة_, дају,
  { {0x2561000f,0xc32503d6,0x44390025,0x00000000}},	//   ról_, омик, ús_,
  { {0x249f0026,0xd2990086,0x00000000,0x00000000}},	//   rjum_, атні_,   ,
  { {0x02c5019d,0x63a60137,0x68eb0e13,0x00000000}},	//   ійно, äkna, logd,
  { {0xd4e7019d,0x21690e14,0x2bd00053,0x00000000}},	//   _люди, шини_, _सेना,
  { {0xd00a0062,0x629c00a5,0x439501f6,0x00000000}},	//   иене_, öror, _маес,
  { {0x443f0185,0xb4e50053,0x10a30062,0x00000000}},	//   mau_, पकी_, фиян,
  { {0xdcb1001b,0x67290035,0x443f0e15,0x00000000}},	//   ển_, _mtej, lau_,
  { {0xa1560001,0x2d8c0066,0x386d0e16,0x00000000}},	//   _дају_, íde_, _ober_,
  { {0x443f0e17,0x645b0e18,0x62830e19,0x00000000}},	//   nau_, ngui, _hano,
  { {0x645b0e1a,0x62830e1b,0x7eb000fe,0x00000000}},	// [1140] igui, _kano, _läpi,
  { {0x386d0199,0x2ca00974,0x443f0e1c,0x00000000}},	//   _aber_, sjid_, hau_,
  { {0x6d41000f,0xb05b0137,0x443f07ff,0x00000000}},	//   álat, miär, kau_,
  { {0xb05b0e1d,0x186a0e1e,0x872a000d,0x00000000}},	//   chäd, ради_, аўка_,
  { {0x443f0c70,0x27e001f7,0x47330086,0x00000000}},	//   dau_, çin_, дніс,
  { {0x9f61000f,0x645b0e1f,0xe6660054,0x00000000}},	//   ését_, egui, ітло,
  { {0x443f001f,0x26ce001f,0x7c2400b2,0x00000000}},	//   fau_, rifo_, ocir,
  { {0x443f0185,0x62830dac,0x7c240e20,0x00000000}},	//   gau_, _aano, ncir,
  { {0x62830e21,0x6d4801c8,0xdc8b009a,0x00000000}},	//   _bano, ádaj, בְיָ,
  { {0x62830e22,0x764800b9,0x78a20e23,0x00000000}},	//   _cano, _uddy, ljov,
  { {0xe29a001b,0x81c60076,0xa1940002,0x00000000}},	//   _chưa_, ющие, чанч,
  { {0x443f0e24,0xb05b0072,0xb97b009a,0x00000000}},	//   cau_, viäs, בנטי,
  { {0x3f8d00cd,0x64400e25,0x62830e26,0x00000000}},	//   íeu_, mami, _fano,
  { {0x7c260146,0x62830e27,0xb05b0072,0x00000000}},	//   _afkr, _gano, tiäs,
  { {0x9c830e28,0xeca70dd5,0x31c30062,0x00000000}},	//   íčov, ојан, _осъв,
  { {0x4c940076,0x6aaa00bd,0xac940200,0x00000000}},	//   мисс, öffn, масш,
  { {0xa01b0137,0xd108007e,0xdfd10049,0x00000000}},	// [1150] ndöm, _بقيه_, _سيد_,
  { {0x6d41000f,0xba980086,0x64400e29,0x00000000}},	//   álas, овує_, hami,
  { {0xceb200b7,0xe2a6007a,0x67290080,0x00000000}},	//   _ניט_, _áður_, _stej,
  { {0x5d7a0e2a,0xdcef0078,0xdbdd013d,0x00000000}},	//   _פארק, _įdėj, láír,
  { {0x386d004d,0x64400e2b,0x20d20066,0x00000000}},	//   _vber_, dami, nšia_,
  { {0x443f001f,0xcf580063,0xb7d20021,0x00000000}},	//   wau_, קבות_, عقوب,
  { {0x7c3d0150,0x644f017d,0x60cd0e2c,0x00000000}},	//   _kesr, ócio, _omam,
  { {0x64400e2d,0x6283024a,0xb4e50161,0x00000000}},	//   gami, _sano, पके_,
  { {0x443f0185,0x7c3d0228,0x20d20024,0x00000000}},	//   rau_, _mesr, jšia_,
  { {0x44260185,0x78a90173,0x60cd0e2e,0x00000000}},	//   _efo_, _hoev, _amam,
  { {0x64400019,0x443f0e2f,0x62830e30,0x00000000}},	//   bami, pau_, _vano,
  { {0x64400e31,0x628300ca,0x7c3d0e32,0x00000000}},	//   cami, _wano, _nesr,
  { {0x628300bb,0xa2950086,0xdd0c0051,0x00000000}},	//   _tano, _наді, różn,
  { {0x78bb02dd,0xe29a008b,0x78a90e33,0x00000000}},	//   _lluv, _thưa_, _loev,
  { {0x6da60e34,0xb05b0504,0x61ee01d1,0x00000000}},	//   чива, riär, čilé,
  { {0x61fc01f7,0x8b260076,0x443d00e5,0x00000000}},	//   ürle, здае, _jew_,
  { {0x305b0063,0x905b0063,0x7c3d0e35,0x00000000}},	// [1160] _הדפד, _הכפת, _desr,
  { {0x7c240e36,0x09e60c45,0x64400e37,0x00000000}},	//   scir, позн, zami,
  { {0xe9da0001,0xfbc90063,0x3c450078,0x00000000}},	//   љке_, נת_, _būvį_,
  { {0x443d0e38,0x7eab0019,0xb4e50053,0x00000000}},	//   _new_, _hüpp, पको_,
  { {0x64400e39,0x945d0022,0x28bd0042,0x00000000}},	//   vami, hińs, ्फ़ि,
  { {0xab27011c,0xd94600d7,0x78bb0019,0x00000000}},	//   _хора_, _неги, _eluv,
  { {0x6440010e,0x78bb0e3a,0x3ea5013d,0x00000000}},	//   tami, _fluv, ölti_,
  { {0x89db0063,0x64400150,0xd4c3014b,0x00000000}},	//   _החלי, uami, есьп,
  { {0x64400e3b,0xe737070a,0x8cc10053,0x00000000}},	//   rami, _нет_, रोटो,
  { {0x64400e3c,0xa01b0137,0x20d20066,0x00000000}},	//   sami, rdöm, všia_,
  { {0x443d0037,0xdbdd00ea,0x395a0e3d,0x00000000}},	//   _few_, váír, nups_,
  { {0x69c10019,0xdfd5000d,0x98ba0078,0x00000000}},	//   _ülee, домы, rupė_,
  { {0xdcb1001b,0x2d8c00b9,0xb465005d,0x00000000}},	//   ểm_, æden_, _آدمه,
  { {0x20d20066,0x945d0022,0x7bc4056c,0x00000000}},	//   ršia_, bińs, dziu,
  { {0x7eb00019,0x945d0051,0x6e3e0150,0x00000000}},	//   _näpu, cińs, _depb,
  { {0x20d20024,0x60cd005f,0x41db009a,0x00000000}},	//   pšia_, _umam, _לחוס,
  { {0x9f54000d,0x2bc70053,0xfbd301fb,0x00000000}},	// [1170] _звыч, _रेखा, رتر_,
  { {0x7b090117,0x62880e3e,0x78a90d1e,0x00000000}},	//   _ažur, nddo, _soev,
  { {0x2d8c0e3f,0x2d9e0137,0x60dd0e40,0x00000000}},	//   ådet_, ätet_, onsm,
  { {0x18690086,0x60dd0e41,0x315707e9,0x00000000}},	//   іали_, nnsm, ליבן_,
  { {0x62980179,0x9be40086,0x3ebe0078,0x00000000}},	//   _onvo, _зірк, šytų_,
  { {0x6d550e42,0x6d47056c,0x00000000,0x00000000}},	//   orza, osja,   ,
  { {0x78a90a53,0x58d50086,0xb925007e,0x00000000}},	//   _toev, _жовт, _آفري,
  { {0x6288001f,0x6d480025,0xcd9803c3,0x00000000}},	//   eddo, ádai, לדות_,
  { {0x27ff005b,0x62880d27,0x6d55004d,0x00000000}},	//   _uzun_, fddo, hrza,
  { {0x6d470019,0x25e80053,0x6288002b,0x00000000}},	//   ksja, _चुकी_, gddo,
  { {0x6d550051,0x76430e43,0x35f5000d,0x00000000}},	//   jrza, many, _ўпер,
  { {0x644b010a,0x6d55017f,0x62980e44,0x00000000}},	//   _udgi, drza, _envo,
  { {0x6d47006f,0x7d1e007d,0x945d0022,0x00000000}},	//   esja, _sups, sińs,
  { {0x76430e45,0x945d0022,0xad3a0054,0x00000000}},	//   nany, pińs, жчає_,
  { {0x6d470e46,0xf2e6005d,0x6d41013d,0x00000000}},	//   gsja, _تکيه_, álap,
  { {0x7643014f,0xc1060c0a,0x00000000,0x00000000}},	//   hany, _توبي,   ,
  { {0x6d470019,0x76430e47,0xcb670e48,0x00000000}},	// [1180] asja, kany, мате_,
  { {0x0f570063,0x76430e49,0x6d550022,0x00000000}},	//   _קיים_, jany, brza,
  { {0xa967005a,0x76430e4a,0x7e7c0e4b,0x00000000}},	//   диха_, dany, merp,
  { {0x395a0e4c,0x6d5c0e4d,0x0c26000d,0x00000000}},	//   rups_, mura, _імгн,
  { {0x76430009,0x62880185,0xb9060161,0x00000000}},	//   fany, yddo, _पद_,
  { {0x07a30856,0x7e7c0e4e,0x76430e4f,0x00000000}},	//   таљн, nerp, gany,
  { {0x6d5c0e50,0xf9830e51,0x7e7c0e52,0x00000000}},	//   nura, _игро, ierp,
  { {0x2ebb0235,0x764300a4,0x7e7c06aa,0x00000000}},	//   _उत्त, aany, herp,
  { {0x76430e53,0x7e7c03fb,0x6d5c0e54,0x00000000}},	//   bany, kerp, hura,
  { {0xd250006a,0xeb9100b5,0xcb9b0047,0x00000000}},	//   دند_, אָט_, קסיט,
  { {0x62880185,0x6d5c053b,0xf1aa007e,0x00000000}},	//   rddo, jura, زاده_,
  { {0x04930021,0x6d5c0e55,0xe5e7005d,0x00000000}},	//   _للمح, dura, _غزلی,
  { {0x6d5c024a,0x7c3600b9,0xef640062,0x00000000}},	//   eura, dbyr, къро,
  { {0x7e7c0e56,0xdcfe0080,0x629800bd,0x00000000}},	//   gerp, _trpě, _unvo,
  { {0x6d5c0e57,0x9f9900ca,0xd0d50094,0x00000000}},	//   gura, _dáár_, _покъ,
  { {0x20c20139,0x76430e58,0x6d470e59,0x00000000}},	//   _cóid_, zany, rsja,
  { {0x2d8c0e5a,0x2d9e0199,0x3f85003d,0x00000000}},	// [1190] åder_, äter_, ālus_,
  { {0x6d5c0e5b,0x7e7c00e5,0x69c50206,0x00000000}},	//   bura, cerp, tzhe,
  { {0x644f000f,0xe0df01f4,0x6d5c0e5c,0x00000000}},	//   ócik, onò_, cura,
  { {0x2bd00161,0x76430e5d,0x2bcb0001,0x00000000}},	//   _सेवा, wany, _дуго_,
  { {0x76430397,0xf388008b,0x36d50e5e,0x00000000}},	//   tany, _nợ_, нодр,
  { {0x764300cd,0xddde007d,0x7d0d0e5f,0x00000000}},	//   uany, _hapš, lmas,
  { {0x76430e60,0x6d480078,0xc6a40062,0x00000000}},	//   rany, šdav, ърци,
  { {0x7d0d01f7,0x7643076b,0x9fa000ac,0x00000000}},	//   nmas, sany, _wéér_,
  { {0x76430e61,0x6d5c0e62,0x7d0d0e63,0x00000000}},	//   pany, zura, imas,
  { {0x13060055,0x6d5c0859,0x7d0d0e64,0x00000000}},	//   нный_, yura, hmas,
  { {0xe1f9000d,0xd12e007e,0x7d0d04b3,0x00000000}},	//   яго_, یمی_, kmas,
  { {0xe0df051e,0xf9920e2a,0x3cfb0053,0x00000000}},	//   gnò_, ארט_, ्षों_,
  { {0x76410078,0x7e7c0897,0x7d0d0e65,0x00000000}},	//   _kely, terp, dmas,
  { {0x3ebe0026,0x7d0d027a,0x83fd00ea,0x00000000}},	//   ótt_, emas, ggőe,
  { {0xc5f200b5,0x224500c2,0x76410e66,0x00000000}},	//   ָדן_, malk_, _mely,
  { {0x6d5c0e67,0x7eb0004d,0x7d0d0e68,0x00000000}},	//   rura, _päps, gmas,
  { {0x245a005b,0x7e7c0e69,0x207b0041,0x00000000}},	// [11a0] lümü_, perp, _זאפא,
  { {0xb05b0c38,0x6d5c0e6a,0xea870e6b,0x00000000}},	//   nhän, pura, нбул_,
  { {0xcee9006a,0x6d5c0150,0x245a005b,0x00000000}},	//   _ترين_, qura, nümü_,
  { {0x7eb00004,0x645c013d,0xe8f6005d,0x00000000}},	//   _täps, őriz, رساخ,
  { {0x20d200c2,0x76410e6c,0x22450e6d,0x00000000}},	//   jšim_, _bely, kalk_,
  { {0x7641002b,0xf388008d,0x46a30085,0x00000000}},	//   _cely, _rợ_, лачв,
  { {0xceb30063,0xf388008b,0x7641001f,0x00000000}},	//   ריו_, _sợ_, _dely,
  { {0x69c10019,0x7521006d,0xdce80078,0x00000000}},	//   _ülea, _dulz, ėlėt,
  { {0x7641002b,0xb05b004d,0x8c1b0063,0x00000000}},	//   _fely, fhän, הופי,
  { {0x76410e6e,0xf388008b,0x7d0d0e6f,0x00000000}},	//   _gely, _vợ_, zmas,
  { {0x83fd00ea,0x25a1004d,0x7d0d0e70,0x00000000}},	//   ggőb, ählt_, ymas,
  { {0x254c0080,0x20d200a8,0x61f8004c,0x00000000}},	//   měl_, bšim_, _vyvl,
  { {0x224504c6,0xb05b00bd,0xe0df051e,0x00000000}},	//   balk_, bhän, rnò_,
  { {0x245a0058,0x7f5d0003,0x539b009f,0x00000000}},	//   bümü_, rusq, _מידו,
  { {0x3f840014,0x7d0d0e71,0x254c004c,0x00000000}},	//   æmur_, tmas, něl_,
  { {0xccf80001,0x7d0d0e72,0x628a002b,0x00000000}},	//   ећу_, umas, _hafo,
  { {0x7d0d0e73,0x3ea5013d,0x7e2b0e74,0x00000000}},	// [11b0] rmas, ölts_, _ніна_,
  { {0x7d0d0a68,0x7e65004d,0x2b490003,0x00000000}},	//   smas, _uchp, rsac_,
  { {0x7d0d005b,0x764100e5,0x2b490e75,0x00000000}},	//   pmas, _rely, ssac_,
  { {0x254c0080,0x628a0558,0x7641056b,0x00000000}},	//   děl_, _lafo, _sely,
  { {0x81bc001c,0x245a0058,0x76410e76,0x00000000}},	//   ucēj, zümü_, _pely,
  { {0x81bc008f,0x20d2007d,0x2ca9065e,0x00000000}},	//   rcēj, všim_, ljad_,
  { {0xb5c20086,0x2f0400a5,0x81bc008f,0x00000000}},	//   ийшл, nöga_, scēj,
  { {0x69cc0024,0x64420025,0x3af40137,0x00000000}},	//   ôlež, _ceoi, läpp_,
  { {0x9998000c,0xe3b10021,0x13090156,0x00000000}},	//   _terţ_, شرة_, мний_,
  { {0x628a0185,0x7eb00659,0x20d200c2,0x00000000}},	//   _cafo, _näpp, ršim_,
  { {0xd702000d,0x628a002b,0xb05b0e77,0x00000000}},	//   _лiта, _dafo, rhän,
  { {0x245a005b,0x290f00a4,0xe3b0007e,0x00000000}},	//   rümü_, nmga_, _گرم_,
  { {0xb05b01bb,0x22450e78,0x22950021,0x00000000}},	//   mhäl, palk_, _للإس,
  { {0x628a0185,0x79820045,0xe3b0007e,0x00000000}},	//   _gafo, łowi, _درم_,
  { {0xbea3018e,0xb05b00bd,0x248d0e79,0x00000000}},	//   шарк, chäo, odem_,
  { {0x248d0e7a,0xb05b0e7b,0x1d070094,0x00000000}},	//   ndem_, nhäl, веси_,
  { {0x8fa606da,0x248d004c,0x00000000,0x00000000}},	// [11c0] _рапе, idem_,   ,
  { {0x248d004d,0x63a60137,0x3ced08ed,0x00000000}},	//   hdem_, äkni, čeva_,
  { {0x19b9000d,0xae570063,0x7d0a005e,0x00000000}},	//   нуць_, _בסיס_, _оног_,
  { {0x248d03f5,0x79950051,0x290f00a4,0x00000000}},	//   jdem_, _drzw, gmga_,
  { {0x248d001f,0x7995004d,0x60dd0e7c,0x00000000}},	//   ddem_, _erzw, érmi,
  { {0x254c0080,0x64420025,0x645c0078,0x00000000}},	//   těl_, _seoi, ėrim,
  { {0xa01b00ea,0xd9430121,0xb05b004d,0x00000000}},	//   ldöt, _веси, fhäl,
  { {0x628a0185,0xb86601fb,0xd467005e,0x00000000}},	//   _safo, _جاسو, виће_,
  { {0x2c6d000f,0xaa820026,0xd3a3000d,0x00000000}},	//   lódó_, _þýsk, арэп,
  { {0x254c004c,0x68e20e7d,0xe737012c,0x00000000}},	//   pěl_, lnod, _реф_,
  { {0x64420e7e,0xe3af005d,0x9f4f0046,0x00000000}},	//   _teoi, مری_, _ágú_,
  { {0xd5d90047,0xe3ba0175,0x68e20e7f,0x00000000}},	//   _אַנש, _обе_, nnod,
  { {0xe703001b,0x68e20e80,0x628a002b,0x00000000}},	//   _hướ, inod, _tafo,
  { {0x7a48001c,0x11d60021,0x9f340054,0x00000000}},	//   nūtē, _لتعد, рері,
  { {0x2ca90019,0xb05b0137,0x20d20130,0x00000000}},	//   tjad_, lhäm, kših_,
  { {0x20d200c3,0xa263008d,0x68e200a8,0x00000000}},	//   jših_, _luồ, jnod,
  { {0x3a750076,0x68e20512,0x2ca903b0,0x00000000}},	// [11d0] ллар, dnod, rjad_,
  { {0x2ca9004b,0x6a34005e,0x5a340e81,0x00000000}},	//   sjad_, инуђ, инут,
  { {0x68e20185,0x68e302dd,0xe703008b,0x00000000}},	//   fnod, éndo, _nướ,
  { {0xc864005e,0x236d0022,0x0cd40e82,0x00000000}},	//   атљи, ytej_, _воюю,
  { {0xdcb1001b,0x20c2017d,0xe9ff0013,0x00000000}},	//   ểu_, _jóia_, _trắc_,
  { {0xe703001b,0x20d202e2,0xda34000d,0x00000000}},	//   _bướ, aših_, _веры,
  { {0xb05b00bd,0x4519042c,0x248d00bd,0x00000000}},	//   thäl, нция_, tdem_,
  { {0xe703001b,0x05760021,0x7c2d0e83,0x00000000}},	//   _dướ, امية_, ncar,
  { {0xb05b00bd,0x7d1d0e84,0x248d0e85,0x00000000}},	//   rhäl, _miss, rdem_,
  { {0x7c2d00e5,0x27e00139,0xa01b0072,0x00000000}},	//   hcar, úine_, hdös,
  { {0x291e03b2,0x01650076,0x9259007e,0x00000000}},	//   _état_, ыкно, وشگر_,
  { {0x7d1d0e86,0x2f040026,0x6b8400ac,0x00000000}},	//   _niss, gögn_, ywig,
  { {0xe28e0e87,0xddc7013d,0x442d0e88,0x00000000}},	//   _ла_, dejű, mce_,
  { {0x7c2d003e,0x64490025,0x442d0e89,0x00000000}},	//   ecar, laei, lce_,
  { {0x62810529,0x5de6005a,0x68e2001f,0x00000000}},	//   melo, ужва, ynod,
  { {0x62810e8a,0x442d0e8b,0x27e90022,0x00000000}},	//   lelo, nce_, żany_,
  { {0x69030019,0x7d1d0e8c,0x442d0e8d,0x00000000}},	// [11e0] tõen, _diss, ice_,
  { {0x26c700c3,0xee3a000d,0xdd04005b,0x00000000}},	//   jhno_, _яно_, ırır,
  { {0x68e204c6,0x442d0080,0x2d9602a9,0x00000000}},	//   tnod, kce_, _српс,
  { {0x7c2d0e8e,0xdca60e8f,0xccfa0086,0x00000000}},	//   ccar, _сами, _їхні_,
  { {0x62810e90,0x60c40035,0x442d0e91,0x00000000}},	//   kelo, _mlim, dce_,
  { {0xaf770047,0x62810e92,0x60c400cd,0x00000000}},	//   רעסס_, jelo, _llim,
  { {0x62810e93,0x60c40e94,0x6d4e0246,0x00000000}},	//   delo, _olim, nsba,
  { {0x6f1e0051,0x290700cd,0x44980121,0x00000000}},	//   _lipc, ïnat_, твию_,
  { {0xb4e40235,0x6d5c004d,0x6906008f,0x00000000}},	//   _नदी_, hrra, ārdē,
  { {0x3866001f,0x62810e95,0x0377007e,0x00000000}},	//   lgor_, gelo, احيت_,
  { {0x764a0014,0x442d0e96,0x7c2d0e97,0x00000000}},	//   mafy, bce_, ycar,
  { {0x442d051e,0x38660e98,0x6d4e02c0,0x00000000}},	//   cce_, ngor_, dsba,
  { {0x2d9e02f0,0x62810e99,0x6d5c0e9a,0x00000000}},	//   åten_, belo, erra,
  { {0x7d1d0004,0x3866001f,0x60c40e9b,0x00000000}},	//   _siss, hgor_, _elim,
  { {0x7c2d02b0,0xd130007e,0x7d1d0e9c,0x00000000}},	//   tcar, _بمب_, _piss,
  { {0xd1380006,0xed580066,0xf0470121,0x00000000}},	//   mpą_, áľa_, _сэко,
  { {0x7c2d0e9d,0xafdb00b9,0x6d5c0e9e,0x00000000}},	// [11f0] rcar, dbøg, arra,
  { {0x6e670001,0x442d0e9f,0x7d1d0ea0,0x00000000}},	//   _стиж, zce_, _wiss,
  { {0x60c400fe,0xaae80086,0x7d1d0ea1,0x00000000}},	//   _ylim, уєте_, _tiss,
  { {0x69c10019,0x7f5d0164,0x38660137,0x00000000}},	//   _ülem, orsq, ggor_,
  { {0x64490ea2,0x07a50793,0x442d0ea3,0x00000000}},	//   vaei, ралн, vce_,
  { {0x0555005a,0x442d0051,0x62810ea4,0x00000000}},	//   атия, wce_, xelo,
  { {0x442d03a4,0x6281008a,0x64a50121,0x00000000}},	//   tce_, velo, иака,
  { {0x9479005e,0xed64004a,0x47350cdf,0x00000000}},	//   тску_, leží_, _внас,
  { {0x62810ea5,0x442d0ea6,0x56670049,0x00000000}},	//   telo, rce_, _مداف,
  { {0x6d5c0ea7,0x442d0ea8,0x60c40ea9,0x00000000}},	//   yrra, sce_, _slim,
  { {0x68e900d1,0x62810eaa,0x42060062,0x00000000}},	//   _kjed, relo, иньо_,
  { {0x65630016,0x272b00b9,0x62810eab,0x00000000}},	//   munh, _køn_, selo,
  { {0x20c20139,0x62810eac,0x65630ead,0x00000000}},	//   _fóin_, pelo, lunh,
  { {0x6d4e021f,0xed5a0138,0x272b00b9,0x00000000}},	//   tsba, ког_, _møn_,
  { {0x272b00b9,0x68fb005b,0x66c60014,0x00000000}},	//   _løn_, _okud, _uðke,
  { {0xdcfc017f,0x60c40035,0x224709fe,0x00000000}},	//   tvrđ, _ulim, _henk_,
  { {0x69c10019,0x1eca0001,0x3f8c001c,0x00000000}},	// [1200] _ülej, _алпи_, ādus_,
  { {0x63a90268,0x68e9006d,0x19960001,0x00000000}},	//   ixen, _ajed, ијер,
  { {0x7bcd008f,0xae5b009a,0x0e5b009a,0x00000000}},	//   azau, _בכיר, _בדיב,
  { {0x26c5051e,0x272b01e1,0xe73a0eae,0x00000000}},	//   _allo_, _bøn_, вед_,
  { {0x1634005a,0xf1ba0013,0x290d04aa,0x00000000}},	//   беля, _ngơn_, _dhea_,
  { {0xafdb0146,0x68e900b9,0x290701a8,0x00000000}},	//   sbøg, _ejed, ïnar_,
  { {0x20d20024,0x09fa0021,0x3866002b,0x00000000}},	//   lšiu_, _شفرة_, pgor_,
  { {0x44220031,0x26c502dd,0xd4970076,0x00000000}},	//   øk_, _ello_, арь_,
  { {0x20d20066,0x82a60eaf,0xdc89009a,0x00000000}},	//   nšiu_, ашне, רְצָ,
  { {0x291f0529,0x9f4f0003,0xb273014c,0x00000000}},	//   _ziua_, _âgé_, ольш,
  { {0x63bb002c,0x21630086,0x6563017d,0x00000000}},	//   ayun, отяг, cunh,
  { {0xddc50080,0xd1380078,0x26dc0eb0,0x00000000}},	//   _schů, rpą_, livo_,
  { {0x7648034d,0xa2940088,0x20d20024,0x00000000}},	//   _kedy, _галі, jšiu_,
  { {0x76480045,0x7b1000bd,0x26dc0066,0x00000000}},	//   _jedy, läuf, nivo_,
  { {0xdddc0eb1,0xc5340063,0xec6b0002,0x00000000}},	//   adrž, מָּה_, крак_,
  { {0xc05b019d,0x26dc02dd,0x76480eb2,0x00000000}},	//   _рік_, hivo_, _ledy,
  { {0x75280045,0x2bba0051,0x60dd0eb3,0x00000000}},	// [1210] _ludz, jącą_, mism,
  { {0x69c10019,0x68e90755,0x26dc02e2,0x00000000}},	//   _ülek, _sjed, jivo_,
  { {0xc8ab005a,0x272b05dd,0x2d8c00b9,0x00000000}},	//   къде_, _søn_, ædet_,
  { {0xf7710032,0x60dd0eb4,0x2cad004b,0x00000000}},	//   كات_, nism, _õed_,
  { {0x2bde0053,0x7648002b,0x7528008f,0x00000000}},	//   _नेपा, _bedy, _audz,
  { {0x656304aa,0x75280eb5,0x60dd0eb6,0x00000000}},	//   tunh, _budz, hism,
  { {0x68e9017f,0xcb120063,0x2247005b,0x00000000}},	//   _tjed, _מלך_, _renk_,
  { {0x68e90eb7,0x60dd0331,0x20d2004c,0x00000000}},	//   _ujed, jism, nšit_,
  { {0x60dd0eb8,0x27ff0058,0x764800f1,0x00000000}},	//   dism, _uyun_, _fedy,
  { {0x6563017d,0xfbd20063,0x26dc0d6f,0x00000000}},	//   punh, פתי_, civo_,
  { {0x63bb002c,0x20c20025,0x60dd0eb9,0x00000000}},	//   syun, _fóil_, fism,
  { {0x224700e8,0x397a014e,0x297a0e2a,0x00000000}},	//   _wenk_, נטרנ, נטרא,
  { {0x660100fe,0x443f0eba,0x22470ebb,0x00000000}},	//   _hylk, mbu_, _tenk_,
  { {0x20d20066,0x7d18013d,0x24180054,0x00000000}},	//   všiu_, _évsz, _тією_,
  { {0x7196006a,0xdca60ebc,0x2d95090f,0x00000000}},	//   _هنوز_, бави, ортс,
  { {0x386d0089,0x60dd0ebd,0x9c260002,0x00000000}},	//   _ncer_, cism, сдад,
  { {0x443f0ebe,0x1d070794,0x2d84004c,0x00000000}},	// [1220] ibu_, сети_, ňme_,
  { {0x386d0ebf,0x20d20066,0x8e860021,0x00000000}},	//   _acer_, ršiu_, _الده,
  { {0x91fc008f,0x499a0766,0x7648056c,0x00000000}},	//   egāj, ытая_, _redy,
  { {0x20d20024,0x61fc004d,0x443f007c,0x00000000}},	//   pšiu_, ürli, jbu_,
  { {0x26dc0ec0,0x4b55005a,0x67210ec1,0x00000000}},	//   tivo_, _мърт, _bilj,
  { {0x672106bb,0x386d00e3,0x7d040ec2,0x00000000}},	//   _cilj, _ecer_, llis,
  { {0x26dc0ec3,0xb05b0ec4,0x7d040ec5,0x00000000}},	//   rivo_, mhäv, olis,
  { {0x7648001f,0x39570063,0x2d980ec6,0x00000000}},	//   _wedy, _לשלם_, ivre_,
  { {0x47c6000a,0x7d040ec7,0x60dd0ec8,0x00000000}},	//   _убав, ilis, vism,
  { {0x66010ec9,0x52d80086,0x7d040eca,0x00000000}},	//   _fylk, рмою_, hlis,
  { {0x8afb0149,0x7d040ecb,0x60dd0ecc,0x00000000}},	//   רהיי, klis, tism,
  { {0xef260058,0x60dd006c,0xe0190054,0x00000000}},	//   ğüne_, uism, ижні_,
  { {0x6d5a0024,0x833a0076,0x44260c12,0x00000000}},	//   átan, _счет_, _igo_,
  { {0x60dd0ecd,0x7d160024,0x7d040ece,0x00000000}},	//   sism, emys, elis,
  { {0x6d5a0ecf,0xb6bb0063,0x60dd0ed0,0x00000000}},	//   štan, נצלי, pism,
  { {0xd904006a,0x7d040ed1,0x69c1004b,0x00000000}},	//   _سی_, glis, _ülei,
  { {0x2d8c0146,0x88bd0051,0x5c070ed2,0x00000000}},	// [1230] æder_, _liśc, сява,
  { {0x2d980ed3,0x61ff013d,0x443f073e,0x00000000}},	//   bvre_, _ízlé, zbu_,
  { {0x20d20080,0x7d040ed4,0x3ebe0ed5,0x00000000}},	//   pšit_, blis, ötte_,
  { {0x44260ed6,0x67210ed7,0xdddc00dd,0x00000000}},	//   _ngo_, _silj, serţ,
  { {0x6729006d,0xdddc003b,0x68f900e5,0x00000000}},	//   _quej, perţ, rowd,
  { {0xe80f0053,0x98aa001c,0xe0df01f4,0x00000000}},	//   ़ेगा_, ājām_, hiò_,
  { {0x443f0512,0x0319007e,0x67210ed8,0x00000000}},	//   tbu_, یتخت_, _vilj,
  { {0xe5760085,0x00000000,0x00000000,0x00000000}},	//   ізы_,   ,   ,
  { {0x7b1000bd,0xe0df0290,0xb05b004d,0x00000000}},	//   bäud, diò_, nhäu,
  { {0x66010045,0x799c002b,0x798e002b,0x00000000}},	//   _tylk, _yrrw, _ysbw,
  { {0xdddc0ed9,0x7d040eda,0x7b10004d,0x00000000}},	//   kerš, ylis, säug,
  { {0xe0df0290,0xb05b0072,0xcea900ff,0x00000000}},	//   giò_, tkäa, _בי_,
  { {0x7d040058,0x644b005f,0xc2c50044,0x00000000}},	//   vlis, _iegi, _ويصي,
  { {0x61450edb,0x31650124,0x7f750085,0x00000000}},	//   _дека, pulz_, чуюц,
  { {0x7e23000a,0x644b014f,0x2d980edc,0x00000000}},	//   ддрж, _kegi, uvre_,
  { {0xe0df0290,0x691100b9,0xb05b01e9,0x00000000}},	//   ciò_, nåed, lkän,
  { {0x7d04018d,0x8b26019d,0xeb970edd,0x00000000}},	// [1240] rlis, ідже, оит_,
  { {0xda660021,0xb05b0ede,0x7d16004c,0x00000000}},	//   تاري, nkän, smys,
  { {0x64590045,0x7d040edf,0xe9da0001,0x00000000}},	//   _odwi, plis, јке_,
  { {0xa8a30095,0xb17a0047,0xa17a0047,0x00000000}},	//   дршк, יטער, יטעט,
  { {0xb05b01bb,0x16340ee0,0x4733005d,0x00000000}},	//   phäv, пеля, وروز,
  { {0xe0df051e,0xd7f90086,0x8f9b0ee1,0x00000000}},	//   ziò_, щує_, ייני,
  { {0xb05b01e3,0x2bde0053,0xe5a30001,0x00000000}},	//   dkän, _नेता, дији,
  { {0x644b0ee2,0x64400ee3,0x5454066f,0x00000000}},	//   _cegi, ubmi, чвит,
  { {0xe0df0290,0x644b0ee4,0xa6e60ee5,0x00000000}},	//   viò_, _degi, _джал,
  { {0x3ce00019,0x442600ac,0xa2a70053,0x00000000}},	//   hiiv_, _wgo_, फ़ॉल्,
  { {0x2730008b,0x644b00cd,0xe1340766,0x00000000}},	//   _hàn_, _fegi, янны,
  { {0x44260ee6,0xa346000d,0x6ab70053,0x00000000}},	//   _ugo_, _дэкл, _आक्र,
  { {0x69c10019,0x6d5a0ee7,0x3947013d,0x00000000}},	//   _ülev, štal, ánsz_,
  { {0x2005003d,0x2730008b,0xdefb026c,0x00000000}},	//   āli_, _màn_, рым_,
  { {0x2730008b,0x62880dd1,0x853c0078,0x00000000}},	//   _làn_, medo, _drėg,
  { {0x5ce70086,0x27300013,0x62880ee8,0x00000000}},	//   іюва, _oàn_, ledo,
  { {0x27300013,0x60c00ee9,0x10170044,0x00000000}},	// [1250] _nàn_, ömme, _ببغد,
  { {0x501c0063,0x7f84007e,0xb05b004d,0x00000000}},	//   _דוחו, _کلین, rhäu,
  { {0xdc3f0a63,0x62880eea,0xb05b004d,0x00000000}},	//   líčk, iedo, shäu,
  { {0x2730008b,0xb05b00bd,0xb17b0047,0x00000000}},	//   _bàn_, chät, שטאר,
  { {0x6d55000f,0x644b0eeb,0x27300013,0x00000000}},	//   lsza, _regi, _càn_,
  { {0x62880743,0x853c0006,0x644b0bad,0x00000000}},	//   jedo, _orėd, _segi,
  { {0x62880eec,0x645d0006,0x6e350051,0x00000000}},	//   dedo, ųsim, iczb,
  { {0x28f80086,0x628800ca,0x6d550740,0x00000000}},	//   _десь_, eedo, isza,
  { {0xf41f00fe,0x6b8d0b06,0x644b0eed,0x00000000}},	//   ää_, nwag, _vegi,
  { {0x62880eee,0xeb920063,0xb5950456,0x00000000}},	//   gedo, תָה_, _низш,
  { {0x644b0eef,0xb05b01e9,0x6b8d0206,0x00000000}},	//   _tegi, rkän, hwag,
  { {0xb05b0137,0x69c1004b,0xef260058,0x00000000}},	//   skän, _üleu, şüme_,
  { {0x2004007a,0xb05b0137,0x21b8007e,0x00000000}},	//   æmi_, mkäl, مپیک_,
  { {0x6d5a0ef0,0x539a07e9,0x141a0041,0x00000000}},	//   štam, _לינו, _פוסב,
  { {0x2d9e016b,0x6d5500ea,0x76430089,0x00000000}},	//   íte_, gsza, ibny,
  { {0x6b8d0917,0x91ba0063,0xb05b0ef1,0x00000000}},	//   fwag, _למצי, nkäl,
  { {0x6b8d0ef2,0xb05b0072,0xab6602e1,0x00000000}},	// [1260] gwag, ikäl, явал,
  { {0x0e660055,0x3f92002c,0xff24007e,0x00000000}},	//   _экон, _isyu_, _تبعی,
  { {0xdebb0063,0x3ebb0063,0x27300013,0x00000000}},	//   _המיל, _הציב, _sàn_,
  { {0xeb9f000e,0x186a0ef3,0x6b8d0244,0x00000000}},	//   _frø_, сади_, bwag,
  { {0x47330086,0xfc3f006d,0x6563004d,0x00000000}},	//   еніс, _unía_, ernh,
  { {0x99640080,0x29060019,0x628801a8,0x00000000}},	//   může_, sloa_, xedo,
  { {0x673b0072,0xf1c2008d,0x62880ef4,0x00000000}},	//   _etuj, _chở_, vedo,
  { {0x62880185,0x77620cfc,0x2730008b,0x00000000}},	//   wedo, prox, _tàn_,
  { {0x2f040014,0x62880ef5,0x6d550022,0x00000000}},	//   lögu_, tedo, zsza,
  { {0x7afe0ef6,0x68e2001f,0x86ea0021,0x00000000}},	//   nopt, liod, _اعرف_,
  { {0x6d5a0117,0x69c10019,0x6a9b0047,0x00000000}},	//   štaj, _ület, זשינ,
  { {0x62880ef7,0xeafa0053,0x68e20a8d,0x00000000}},	//   sedo, ्तुत_, niod,
  { {0x04430b3f,0xa4b70063,0x98a7007d,0x00000000}},	//   _чечн, _מלאה_, šići_,
  { {0x68e2001f,0x0eeb0200,0x6d550ef8,0x00000000}},	//   hiod, сьми_, tsza,
  { {0x7afe0ef9,0x68eb002b,0xdcfe004c,0x00000000}},	//   dopt, yngd, _uspě,
  { {0x6d550efa,0x6b8d0d13,0x27f20051,0x00000000}},	//   rsza, twag, żyny_,
  { {0x6d5503e8,0x68e20efb,0x9a87007b,0x00000000}},	// [1270] ssza, diod, зуел,
  { {0x6b8d0007,0xb05b004d,0x88bd0022,0x00000000}},	//   rwag, chär, _ciśn,
  { {0xc1780006,0xceb20047,0x6b8d0efc,0x00000000}},	//   ntė_, _סיט_, swag,
  { {0x2ee3006f,0xa3cc0053,0x26cc0efd,0x00000000}},	//   lijf_, रना_, _aldo_,
  { {0x69d80026,0x2058009f,0x7afe0efe,0x00000000}},	//   úver, ליאל_, bopt,
  { {0x60cd0eff,0x2557003b,0x7b10004d,0x00000000}},	//   _llam, tăl_, räuc,
  { {0x60cd005b,0xf6500049,0xb05b0f00,0x00000000}},	//   _olam, ائه_, tkäl,
  { {0x2ee30122,0xe8940088,0x68e2000c,0x00000000}},	//   hijf_, _пась, ciod,
  { {0xc1780006,0xd702000d,0xd3be0121,0x00000000}},	//   etė_, _кiра, а́ть,
  { {0x66cf076c,0x69c10004,0x78bb0f01,0x00000000}},	//   _bøke, _üles, _houv,
  { {0x60cd0034,0x208a005a,0xf78b0058,0x00000000}},	//   _blam, ойни_, şçı_,
  { {0xafe6019d,0xd00a000a,0x5558000d,0x00000000}},	//   домл, жеме_, _хаця_,
  { {0x78bb0164,0x92b50021,0x3438005d,0x00000000}},	//   _mouv, _يحتا, _رسند_,
  { {0x60cd0019,0x78bb0f02,0xa01b00a5,0x00000000}},	//   _elam, _louv, dföd,
  { {0x78a9006f,0x60cd0136,0xb05b0ae2,0x00000000}},	//   _onev, _flam, rhär,
  { {0x78bb03b2,0x60cd0f03,0x7c85005e,0x00000000}},	//   _nouv, _glam, нуђе,
  { {0xa2d40053,0x3207002b,0x7afe0f04,0x00000000}},	// [1280] योक्, _hyny_, topt,
  { {0x273b000c,0x68e20051,0x78a900dd,0x00000000}},	//   _mână_, wiod, _anev,
  { {0xdce9005b,0x2d9c00ea,0x2241004b,0x00000000}},	//   _çoğu, _éve_, _õhku_,
  { {0x78bb0164,0x7afe0f05,0x5883066e,0x00000000}},	//   _couv, sopt, выша,
  { {0x78a906bb,0xba56005a,0x69030019,0x00000000}},	//   _dnev, _отвъ, võet,
  { {0x46a30062,0x68e20f06,0x78a90f07,0x00000000}},	//   качв, siod, _enev,
  { {0x68e20674,0x78660044,0xf600014b,0x00000000}},	//   piod, _يدرك, ымкi_,
  { {0x78bb0f08,0x6abc0014,0x78a90130,0x00000000}},	//   _gouv, _horf, _gnev,
  { {0x66cf0d96,0x69c10019,0x128a0062,0x00000000}},	//   _søke, _üler, ощни_,
  { {0x60cd0f09,0xc17a0086,0xf7430f0a,0x00000000}},	//   _slam, оїм_, _рефо,
  { {0x6abc0f0b,0xa2d40042,0x60cd0f0c,0x00000000}},	//   _morf, योग्, _plam,
  { {0xc1780006,0xe4a50086,0xd4c60021,0x00000000}},	//   rtė_, _пріо, _تغطي,
  { {0xc1780006,0x60cd006f,0x60c00137,0x00000000}},	//   stė_, _vlam, ömma,
  { {0x32070185,0xd3b70086,0x63a20f0d,0x00000000}},	//   _fyny_, _юлії_, _iron,
  { {0x2ee3006f,0x27fa0051,0x12fb0063,0x00000000}},	//   rijf_, ępny_, _והגב,
  { {0x629a0438,0x6ee9017f,0x62980d11,0x00000000}},	//   ldto, džbe, _havo,
  { {0x660801f2,0x629a01e1,0x62980078,0x00000000}},	// [1290] _lydk, odto, _kavo,
  { {0x2904002c,0x6abc001f,0x78bb0f0e,0x00000000}},	//   _akma_, _corf, _souv,
  { {0x78bb03b2,0x25de024c,0x2d9e00c7,0x00000000}},	//   _pouv, _केली_, åtet_,
  { {0x629802f6,0x20090150,0xa01b0137,0x00000000}},	//   _lavo, _kyai_, pföd,
  { {0x6abc0f0f,0x21290089,0x57480085,0x00000000}},	//   _forf, _miah_, дзім_,
  { {0x6abc0185,0x66cf0031,0x62980f10,0x00000000}},	//   _gorf, _søkb, _navo,
  { {0xd5b1002a,0x63a20f11,0x66360044,0x00000000}},	//   افع_, _aron, ركيس_,
  { {0x273b0529,0xb9250021,0x78a900e5,0x00000000}},	//   _până_, _أفري, _unev,
  { {0x63a20f12,0x13e90086,0x20090150,0x00000000}},	//   _cron, ямий_, _nyai_,
  { {0x7dee00ea,0x63a20109,0x99980078,0x00000000}},	//   nősé, _dron, _gerų_,
  { {0x629800bd,0x63a20f13,0xafdb05a5,0x00000000}},	//   _davo, _eron, sbøl,
  { {0x0ef80053,0xe0d2007e,0xea000013,0x00000000}},	//   ंक्स_, ازد_, hiếu_,
  { {0xafdb00b9,0x63a20f14,0x62980f15,0x00000000}},	//   lbøj, _gron, _favo,
  { {0x62980006,0x248d0f16,0xe3b0007e,0x00000000}},	//   _gavo, leem_, _خرم_,
  { {0xddc10086,0x3f4d0f17,0x1d160131,0x00000000}},	//   аттi_, ažu_, еќар,
  { {0x248d00e8,0x91fc001c,0x62980f18,0x00000000}},	//   neem_, rgāt, _zavo,
  { {0xc4d20047,0x6abc0f19,0x4c350085,0x00000000}},	// [12a0] אגן_, _porf, тэст,
  { {0x19f6018e,0x89f6000d,0x88bd0022,0x00000000}},	//   нџер, няец, _wiśl,
  { {0xa84a0021,0x91fc008f,0x6abc0f1a,0x00000000}},	//   كلام_, lgār, _vorf,
  { {0xa2a1024c,0x7ae500fe,0x00000000,0x00000000}},	//   _कोस्, aiht,   ,
  { {0x66080f1b,0x66e60f1c,0x91fc008f,0x00000000}},	//   _sydk, нода, ngār,
  { {0x69c500ac,0xb05b0072,0xda650044,0x00000000}},	//   byhe, tkäk, _لافي,
  { {0x67280117,0x69c1004b,0xf52607ed,0x00000000}},	//   _vidj, _ülep, нфин,
  { {0x62980f1d,0x63a20f1e,0x67280150,0x00000000}},	//   _savo, _pron, _widj,
  { {0x62980f1f,0xe3b20593,0x53e60085,0x00000000}},	//   _pavo, ارع_, эцка,
  { {0x629a00b9,0x63a20f20,0xeb91009a,0x00000000}},	//   udto, _vron, בָט_,
  { {0x63a20f21,0x64a6000d,0x21670002,0x00000000}},	//   _wron, _пажа, ниќи_,
  { {0x63a200aa,0x7dee013d,0x34560044,0x00000000}},	//   _tron, zősé, _أنشأ,
  { {0x09dd0235,0x62980f22,0xbfa80cb5,0x00000000}},	//   _मध्य, _tavo, нтре_,
  { {0xb3e90021,0x79820051,0x61eb00ea,0x00000000}},	//   _تعمل_, łowy, állá,
  { {0x7ae500c2,0xe29b0149,0xa1940330,0x00000000}},	//   viht, _זשור, _райч,
  { {0xb05b00fe,0x2f1600b9,0x88bd0022,0x00000000}},	//   kkäi, væge_, _piśm,
  { {0x7dee000f,0xea670138,0x2d9e0a2e,0x00000000}},	// [12b0] tősé, ењен, åter_,
  { {0x63bd05dd,0x69110666,0x3a740121,0x00000000}},	//   øsni, gåen, ллур,
  { {0x1df90076,0x7ae5005b,0xafdb04aa,0x00000000}},	//   _цены_, riht, kbøk,
  { {0xf77108aa,0x7dee013d,0x7ae50bda,0x00000000}},	//   لات_, sősé, siht,
  { {0x257a00ac,0xafdb00d1,0x7d0d0f23,0x00000000}},	//   eël_, dbøk, mlas,
  { {0x7d0d0f24,0x67d202f8,0x9f38009a,0x00000000}},	//   llas, рољу, תנגד_,
  { {0x6d5a017f,0x8aa4005a,0xa2a10053,0x00000000}},	//   štav, _сряд, _कोष्,
  { {0x4518000d,0x7d0d0f25,0x5925005d,0x00000000}},	//   нцыя_, nlas, _شکاف,
  { {0x83fd013d,0x7d0d0f26,0x07350f27,0x00000000}},	//   egőr, ilas, _резю,
  { {0x7d0d016b,0x3f85003b,0xc3c80021,0x00000000}},	//   hlas, ălul_, عظيم_,
  { {0x7d0d0f28,0x8602007e,0x63ad0f29,0x00000000}},	//   klas, _پژوه, _šand,
  { {0x3495018e,0xa2a10053,0xf9920063,0x00000000}},	//   _јадр, _कोर्, ברט_,
  { {0xf3670076,0x7d0d0f2a,0xe28e058f,0x00000000}},	//   _чтен, dlas, _ка_,
  { {0x601e0024,0x200c001c,0x7d0d0f2b,0x00000000}},	//   _rámč, ādi_, elas,
  { {0xfc3f0024,0x691100d1,0x7d0d05b2,0x00000000}},	//   _kníh_, våen, flas,
  { {0x7d0d0f2c,0x98b8001c,0x753c013d,0x00000000}},	//   glas, _otrā_, _érze,
  { {0x69110f2d,0x1d070f2e,0x64490f2f,0x00000000}},	// [12c0] tåen, тети_, ibei,
  { {0x4a430f30,0x7d0d021e,0x692c00dd,0x00000000}},	//   инув, alas, _aşea,
  { {0x442f0f31,0x7d0d0f32,0x27e90046,0x00000000}},	//   _ogg_, blas, úann_,
  { {0x7d0d0f33,0x6d5c0e77,0xf7460f34,0x00000000}},	//   clas, msra, ведо,
  { {0xe73706f0,0x09290021,0x7d040f35,0x00000000}},	//   веч_, رسمي_, mois,
  { {0x6d5a0066,0xa714000d,0x7d040f36,0x00000000}},	//   štau, ымлі, lois,
  { {0xafdb00d1,0xb05b004b,0x6d5c0f37,0x00000000}},	//   tbøk, skäi, nsra,
  { {0x69c300fe,0x7d040f38,0x60c0004d,0x00000000}},	//   änee, nois, ömml,
  { {0xb8d6016a,0x64a30635,0x62810f39,0x00000000}},	//   जा_, рања, fflo,
  { {0x02a6019d,0x442f03b1,0x7d0d0f3a,0x00000000}},	//   трим, _egg_, zlas,
  { {0x7d04024a,0xd48f037c,0xf484007e,0x00000000}},	//   kois, _кр_, _ماشی,
  { {0x7d0400fe,0x6d5c02e0,0x7c2b0078,0x00000000}},	//   jois, dsra, žgri,
  { {0xfbdf00e8,0x7d040f3b,0xc0e4000d,0x00000000}},	//   _leêr_, dois, роўк,
  { {0x76580009,0x645d0078,0x7f9402d8,0x00000000}},	//   navy, ųsit, јарх,
  { {0x2fcd0117,0x6d5c0f3c,0x7d0d0f3d,0x00000000}},	//   šeg_, gsra, tlas,
  { {0x8c3b00bd,0x656a0025,0x69110093,0x00000000}},	//   _maßg, irfh, gåel,
  { {0x5c07005a,0x7d0d0f3e,0x76580f3f,0x00000000}},	// [12d0] тява, rlas, kavy,
  { {0x7d0d0f40,0xf09f00cd,0x7b10004d,0x00000000}},	//   slas, ldà_, bäum,
  { {0x7d0d0f41,0x6f020139,0x7d040f42,0x00000000}},	//   plas, _íoca, bois,
  { {0x01350047,0xf09f00cd,0x71d7009d,0x00000000}},	//   אָסט_, ndà_, כובד_,
  { {0x9735006a,0x6d5a0f43,0x62810ac9,0x00000000}},	//   اکرا, štat, yflo,
  { {0x76580078,0xfc3f004c,0x2ed10042,0x00000000}},	//   gavy, _sníh_, _हतोत,
  { {0xceb400ff,0x05540085,0xa5090f44,0x00000000}},	//   ייס_, атыя, нека_,
  { {0x26190053,0x38a40699,0x8a18030b,0x00000000}},	//   येगी_, _кјуб, _росс_,
  { {0x64490f45,0xf7940088,0x27e00025,0x00000000}},	//   rbei, _катэ, úint_,
  { {0xf09f01a8,0x64490f46,0x6d5c0072,0x00000000}},	//   edà_, sbei, ysra,
  { {0xfad6014e,0x290f0ad5,0x27390013,0x00000000}},	//   רותך_, olga_, _hèn_,
  { {0x20c20025,0x27390013,0x3f6a0f47,0x00000000}},	//   _cóip_, _kèn_, нимо_,
  { {0xe3650086,0x7d040f48,0x249f0f49,0x00000000}},	//   _скли, vois, mdum_,
  { {0x249f007a,0x6d5c0f4a,0xe29609da,0x00000000}},	//   ldum_, tsra, _баш_,
  { {0x7d04024a,0x69110f4b,0x6d5c0527,0x00000000}},	//   tois, tåel, usra,
  { {0x6d5c003d,0x7b1000bd,0x249f0f4c,0x00000000}},	//   rsra, räum, ndum_,
  { {0xcb670184,0x6d5c0f4d,0x2d850058,0x00000000}},	// [12e0] лате_, ssra, çler_,
  { {0x66cf0031,0x7d0400fe,0x6d5c0f4e,0x00000000}},	//   _søkn, sois, psra,
  { {0x38cb005d,0x7d040f4f,0x98a60f50,0x00000000}},	//   کالی_, pois, лиже,
  { {0x237f0051,0x27390013,0x28df0042,0x00000000}},	//   ktuj_, _bèn_, पोलि,
  { {0x4b55005a,0x76580f51,0x249f0014,0x00000000}},	//   _въст, tavy, ddum_,
  { {0x3b0a0076,0x4e7a00b5,0xb8cb0053,0x00000000}},	//   _чего_, גאַצ, _को_,
  { {0x45d40ac5,0x2ca0004b,0xf5200085,0x00000000}},	//   ройс, odid_, онкi_,
  { {0x2ca00f52,0x76580006,0x28090066,0x00000000}},	//   ndid_, savy, ätný_,
  { {0x765800eb,0xe6460f53,0x18670062,0x00000000}},	//   pavy, _безп, _щати_,
  { {0x63ad004a,0x4b7b0047,0xa01b0014,0x00000000}},	//   _šanc, עטיג, ffön,
  { {0x7f440089,0x5ab70047,0xe57a0054,0x00000000}},	//   _atiq, אליע_, _їзд_,
  { {0x2ca00089,0x1074071f,0x853b009a,0x00000000}},	//   jdid_, блюю, _נגדי,
  { {0xf09f0268,0x2ca0002b,0x9f350054,0x00000000}},	//   rdà_, ddid_, регі,
  { {0x539b0063,0x66cf00d1,0x8c3b004d,0x00000000}},	//   _ניוו, _nøkl, _maße,
  { {0x7f440f54,0x56370047,0xbdd401d5,0x00000000}},	//   _etiq, ראלע_, борщ,
  { {0x2bd9005d,0x361b009d,0x00000000,0x00000000}},	//   پارک_, תולד,   ,
  { {0xba550095,0x6d470026,0x4a550f55,0x00000000}},	// [12f0] ивај, spja, икас,
  { {0xb05b00bd,0x2ca0004b,0x27390013,0x00000000}},	//   rkäu, adid_, _rèn_,
  { {0x6d5a0024,0x38350071,0xe8590085,0x00000000}},	//   štar, анер, ваеш_,
  { {0x237f0045,0x5c070062,0x7a32013d,0x00000000}},	//   ytuj_, _бяга, tűtí,
  { {0x0a6b0459,0xb05b00fe,0xe72e0376,0x00000000}},	//   _први_, lkäs, же_,
  { {0x0f58009f,0xe7360f56,0xff580041,0x00000000}},	//   ניום_, шеш_, נבוך_,
  { {0xa5640032,0xb05b0b58,0x3ebe0f57,0x00000000}},	//   مدين, nkäs, ötti_,
  { {0x91f5008b,0x38600139,0x33650160,0x00000000}},	//   hác, óirt_, авиг,
  { {0x249f0f58,0xc603008f,0xd7fb0f59,0x00000000}},	//   rdum_, dzēš_, _чув_,
  { {0x68eb0122,0x6d450025,0xa01b0026,0x00000000}},	//   ligd, _otha, tfön,
  { {0x25b901fb,0x237f0022,0x0477005d,0x00000000}},	//   _جهاد_, stuj_, _ملاک_,
  { {0x68eb0173,0xa01b0137,0x61ee0025,0x00000000}},	//   nigd, rfön, úbla,
  { {0x443f0f5a,0xa01b0626,0x6d450f5b,0x00000000}},	//   mcu_, sfön, _atha,
  { {0x443f0f5c,0x71a50085,0x50d6005d,0x00000000}},	//   lcu_, _вакз, ازگر,
  { {0x1c3a0088,0x91e20612,0xa01b00ea,0x00000000}},	//   вязь_, _моше, lföl,
  { {0x645b004d,0x443f0f5d,0x236d00c2,0x00000000}},	//   naui, ncu_, orej_,
  { {0x2ca00019,0xdcb7008b,0x68eb0f5e,0x00000000}},	// [1300] rdid_, ởng_, digd,
  { {0xc3320063,0xb05b004b,0xe5e5004c,0x00000000}},	//   קוב_, skät, íměř,
  { {0x2d9a02f7,0x8c3b004d,0x89f50085,0x00000000}},	//   _uspe_, _saße, бяцц,
  { {0x270e0161,0x76410f5f,0x6d3b0149,0x00000000}},	//   ित्र_, _afly, _שײכו,
  { {0x443f0f60,0xa01b013d,0x60c40022,0x00000000}},	//   dcu_, jföl, _moim,
  { {0xa01b0137,0x316b0051,0x60c40072,0x00000000}},	//   dföl, ńczy_, _loim,
  { {0x3f85003b,0xd6da007e,0x60d60f61,0x00000000}},	//   ălui_, _یورش_, _olym,
  { {0x399b00b5,0x3864032c,0x499b0063,0x00000000}},	//   _בילד, _udmr_, _בשלב,
  { {0x96960054,0x78a200a8,0x8696005e,0x00000000}},	//   _вреш, mdov, _вјеч,
  { {0x78a20f62,0xdce70051,0xf2c60f63,0x00000000}},	//   ldov, mują, рсин,
  { {0xaa370047,0x2178000d,0x3a370132,0x00000000}},	//   יטיק_, ыйны_, ירים_,
  { {0xd4f5000d,0xd4670f64,0x60c40f65,0x00000000}},	//   _лячы, _вице_, _coim,
  { {0xdce70051,0x68e300cd,0x60c40f66,0x00000000}},	//   nują, èndi, _doim,
  { {0x0eeb0065,0xb05b0072,0xa6f8009d,0x00000000}},	//   тьми_, tkäs, אִֽי,
  { {0xdef80088,0xeda40193,0x3f820f67,0x00000000}},	//   рыя_, ошто, atku_,
  { {0xdce70045,0x60d6001f,0x78a208c1,0x00000000}},	//   kują, _glym, jdov,
  { {0x78a20290,0x68eb0e04,0xb05b0f68,0x00000000}},	// [1310] ddov, vigd, skäs,
  { {0x6e950032,0x443f00c3,0xdce70051,0x00000000}},	//   _الدا, zcu_, dują,
  { {0x68eb016d,0xdb040003,0xa01b013d,0x00000000}},	//   tigd, iviè, zföl,
  { {0xdce7056c,0xa3c70082,0xcd340043,0x00000000}},	//   fują, _उथल_, _گریب,
  { {0x2d830f69,0xdce70051,0x443f0f6a,0x00000000}},	//   ltje_, gują, vcu_,
  { {0x68eb00ac,0x98bc008f,0x6723007d,0x00000000}},	//   sigd, īvā_, umnj,
  { {0x3ea10019,0x2d830f6b,0x443f0f6c,0x00000000}},	//   _maht_, ntje_, tcu_,
  { {0xfdf80f6d,0x66cf00b9,0x7bcd0003,0x00000000}},	//   ימוש_, _køkk, oyau,
  { {0x60c40027,0x290d0f6e,0xe3e9007e,0x00000000}},	//   _roim, _ikea_, دکان_,
  { {0x443f0f6f,0xa01b0f70,0xe299005e,0x00000000}},	//   scu_, rföl, ћан_,
  { {0x60c40f71,0xe3a5007e,0x66cf0093,0x00000000}},	//   _poim, _گشای, _løkk,
  { {0x236d0198,0xa01b0f72,0xfd1f008b,0x00000000}},	//   prej_, pföl, _nhì_,
  { {0x66cf0031,0x60c4024a,0x78fa0047,0x00000000}},	//   _nøkk, _voim, רפרו,
  { {0x68fb0f73,0x3f820f74,0xc3320063,0x00000000}},	//   _ljud, rtku_, _זוג_,
  { {0x68e900c7,0x60c40f75,0xdce70051,0x00000000}},	//   _omed, _toim, zują,
  { {0x64590034,0xb05b03c8,0xfd1f0013,0x00000000}},	//   _jewi, skär, _chì_,
  { {0x3f9e003d,0x2d83006f,0xdb04006d,0x00000000}},	// [1320] ātus_, atje_, lvié,
  { {0x68fb0f76,0x7e560001,0x68e90f77,0x00000000}},	//   _ajud, _утиц, _amed,
  { {0x68fb00c7,0x2722008b,0xdb040e1a,0x00000000}},	//   _bjud, _hưng_, nvié,
  { {0x64590185,0x291f0f78,0xdce70051,0x00000000}},	//   _newi, _chua_, tują,
  { {0x26c50024,0x96ea013c,0x78a20f79,0x00000000}},	//   _bolo_, лька_, rdov,
  { {0x96f8000a,0xdce70051,0xd7f90086,0x00000000}},	//   јект_, rują, шує_,
  { {0xdce70051,0x6b840f7a,0x27220013,0x00000000}},	//   sują, ltig, _lưng_,
  { {0x6b8400cd,0xdce70051,0xd4970121,0x00000000}},	//   otig, pują, брь_,
  { {0x64590185,0xd2500021,0xa5070001,0x00000000}},	//   _dewi, ونة_, љења_,
  { {0x6b840f7b,0xdb9b0047,0x68e900c2,0x00000000}},	//   itig, נסיר, _zmed,
  { {0x6b8405e4,0xf2020053,0xe4a60002,0x00000000}},	//   htig, _रुख़_, _грло,
  { {0x6b8402f0,0x64590f7c,0x27220013,0x00000000}},	//   ktig, _gewi, _bưng_,
  { {0xdfd8005a,0x2d8300ca,0x2722008d,0x00000000}},	//   бър_, wtje_, _cưng_,
  { {0x27220013,0x2d83013d,0xd9fa0042,0x00000000}},	//   _dưng_, ttje_, ्थात_,
  { {0x691802dd,0x6b840f7d,0xfd1f0013,0x00000000}},	//   víen, etig, _phì_,
  { {0x2d830f7e,0x5c070121,0x6b840f7f,0x00000000}},	//   rtje_, бяза, ftig,
  { {0x6b840f80,0x2d830907,0x692c0058,0x00000000}},	// [1330] gtig, stje_, _eşek,
  { {0x433b0047,0x63bd0137,0xfaa7005e,0x00000000}},	//   טעמב, äsni, љшан,
  { {0x753a0199,0xfd1f001b,0x7bcd00f3,0x00000000}},	//   _nutz, _thì_, syau,
  { {0x26c50f81,0xa8150001,0xdced0078,0x00000000}},	//   _solo_, одеш, _įkėl,
  { {0x660401f7,0x6c7a0047,0x765a06a3,0x00000000}},	//   şikl, _דארפ, _bety,
  { {0x2f5c009f,0x35c90f82,0x64590f83,0x00000000}},	//   נדונ, игло_, _sewi,
  { {0x26c5051e,0x64590051,0xddd50051,0x00000000}},	//   _volo_, _pewi, lazł,
  { {0x753a004d,0x6d5a0003,0x68e90f84,0x00000000}},	//   _dutz, âtai, _umed,
  { {0xdcfc001c,0x26c5017d,0x03a50f85,0x00000000}},	//   ntrā, _tolo_, ципо,
  { {0x765a006f,0xdddc00ea,0x1287007e,0x00000000}},	//   _gety, zerű, حمدی_,
  { {0x27220013,0xb05b0072,0x63a40f86,0x00000000}},	//   _sưng_, tkäp, _šint,
  { {0x7985001f,0x7b1000bd,0xa8790047,0x00000000}},	//   ithw, läut, סאָר,
  { {0xa3bb006a,0x940501fb,0xc50c0041,0x00000000}},	//   _حاضر_, _بوشه, _גלאָ,
  { {0x73040054,0x613e0023,0x63a90f87,0x00000000}},	//   _епіз, _gīlo, mven,
  { {0x63a90f88,0x6da305ef,0x69c30656,0x00000000}},	//   lven, мира, änel,
  { {0x63a90f89,0x60dd087d,0x6b840739,0x00000000}},	//   oven, chsm, ttig,
  { {0xab660086,0x6b8400bd,0x7985001f,0x00000000}},	// [1340] ювал, utig, ethw,
  { {0x6b840f8a,0x6023000d,0xaa160141,0x00000000}},	//   rtig, _ідэа, офеј,
  { {0x18a60612,0x6b840f8b,0x88e60121,0x00000000}},	//   жаем, stig, ожже,
  { {0x765a00a4,0x63a90f8c,0xe7aa0f8d,0x00000000}},	//   _sety, kven, ивел_,
  { {0x63a90122,0xd90d005d,0x765a056c,0x00000000}},	//   jven, ایق_, _pety,
  { {0x7d1600fe,0x2d8500cd,0x501b0063,0x00000000}},	//   llys, àleg_, בונו,
  { {0xd5470079,0x8c3b00bd,0xa9670e34,0x00000000}},	//   опје_, _maßn, _мира_,
  { {0x63a900b9,0x387f0139,0x7d160d1a,0x00000000}},	//   fven, _gcur_, nlys,
  { {0x63a9006f,0x7d160f8e,0x00000000,0x00000000}},	//   gven, ilys,   ,
  { {0x6f020025,0x7d16001f,0xc17401d5,0x00000000}},	//   _íoch, hlys, площ,
  { {0x63a90f8f,0x7b10004d,0x7d160f90,0x00000000}},	//   aven, läus, klys,
  { {0x63a90f91,0x4035082d,0x859b009a,0x00000000}},	//   bven, яемс, _כשבו,
  { {0x63a90529,0x6918006d,0x66cf04aa,0x00000000}},	//   cven, víel, _søki,
  { {0xe2970f92,0x7985001f,0xb0340085,0x00000000}},	//   _мач_, ythw, ьняш,
  { {0x7b1000bd,0x3ceb0002,0x99800066,0x00000000}},	//   häus, аќам_, eďže_,
  { {0x69c30546,0xdcee001c,0xdcb80505,0x00000000}},	//   änem, tubā, ощу_,
  { {0x28ab0053,0x7b100072,0xc104005d,0x00000000}},	// [1350] _घोषि, jäus, _تويي,
  { {0x42370047,0x7d160f93,0x69370130,0x00000000}},	//   ַנדל_, alys, _oćet,
  { {0xdcfc003d,0x3958001f,0xf3f9003b,0x00000000}},	//   strā, _cwrs_, iaţa_,
  { {0x23660117,0x63a90f94,0x6ee9007d,0x00000000}},	//   _ovoj_, yven, džbi,
  { {0xba770032,0x7d0d000c,0xf680004c,0x00000000}},	//   _واست, moas, ěžně_,
  { {0x63a90290,0x7d0d0f95,0x98aa004c,0x00000000}},	//   vven, loas, _kubě_,
  { {0x3958001f,0x7b100244,0x00000000,0x00000000}},	//   _gwrs_, räut,   ,
  { {0x63a906bb,0x7d0d0be3,0x75220f96,0x00000000}},	//   tven, noas, _choz,
  { {0x63a90164,0xf3f9003b,0x69370130,0x00000000}},	//   uven, faţa_, _ećet,
  { {0x396400fe,0x23660066,0x63a90f97,0x00000000}},	//   _ässä_, _dvoj_, rven,
  { {0x7d0d00fe,0x63a90f98,0xdcfc00dd,0x00000000}},	//   koas, sven, ntră,
  { {0x21060161,0x63a900e8,0x7d0d003b,0x00000000}},	//   रवेश_, pven, joas,
  { {0xe4560047,0x08760047,0x2055000d,0x00000000}},	//   _זינט_, הערט_, ьтэр,
  { {0x75290f99,0xb14502f8,0xb3080044,0x00000000}},	//   lmez, _енкл, _وغول_,
  { {0x412a0854,0xe1f60131,0x471a009d,0x00000000}},	//   _локо_, _нгш_, מושג,
  { {0x01360063,0xb05b00fe,0x75290058,0x00000000}},	//   _צרפת_, ljän, nmez,
  { {0xfc030f9a,0x98a4005f,0x7d160f9b,0x00000000}},	// [1360] епто, _gimę_, rlys,
  { {0x7d1600e8,0xb05b0137,0x7529004d,0x00000000}},	//   slys, njän, hmez,
  { {0x7d160f9c,0xbe3b0063,0x2d9c0003,0x00000000}},	//   plys, _לעית, _ève_,
  { {0x80bf0053,0x7b10004d,0x7d0d0f9d,0x00000000}},	//   षाये, täus, coas,
  { {0xdc3700b5,0xa01b0026,0x20ef004c,0x00000000}},	//   _מאכט_, rgög, dřil_,
  { {0x6594000d,0x7b10004d,0x66e301dd,0x00000000}},	//   даку, räus, ноча,
  { {0xceb30063,0x7aee00a4,0x23660648,0x00000000}},	//   תיו_, _imbt, _svoj_,
  { {0x68130051,0x98a30b3f,0xd37a06da,0x00000000}},	//   _będą, _писе, бчо_,
  { {0xd3b80054,0x363604a0,0x366a0129,0x00000000}},	//   ілої_, _فراس, _газо_,
  { {0x246c0013,0x51f80054,0x20050058,0x00000000}},	//   ớm_, жною_, şlik_,
  { {0x7aee0150,0xd2570085,0x21630094,0x00000000}},	//   _mmbt, чцы_, нтяг,
  { {0x6937017f,0xe53b0063,0x55bb0063,0x00000000}},	//   _kćer, _התאר, _למבו,
  { {0x7d0d0529,0xdfd80062,0xa3cd0053,0x00000000}},	//   voas, пър_, रहण_,
  { {0x63a20f9e,0x3d950f9f,0x57fb009a,0x00000000}},	//   _ison, мигр, מלכו,
  { {0x629a0fa0,0x7d0d0fa1,0x7e28014b,0x00000000}},	//   meto, toas, зіта_,
  { {0x7aee006f,0xfc3f017d,0x51fb0063,0x00000000}},	//   _ambt, _baía_, _להוצ,
  { {0x7d0d0fa2,0xfc3f0460,0xab94005e,0x00000000}},	// [1370] roas, _caía_, натљ,
  { {0x7529004c,0x7f4d00be,0x629a0fa3,0x00000000}},	//   zmez, _itaq, neto,
  { {0x629a0fa4,0x69da004b,0x3eb7005f,0x00000000}},	//   ieto, _ütel, četė_,
  { {0x3ce00080,0x63a20fa5,0x629a0fa6,0x00000000}},	//   chiv_, _oson, heto,
  { {0xdcfc000c,0xf09f008b,0x629a0fa7,0x00000000}},	//   stră, goài_, keto,
  { {0x7b10004d,0x2ca90fa8,0x629a0fa9,0x00000000}},	//   säur, ldad_, jeto,
  { {0x65920001,0x20ef004c,0x629a0faa,0x00000000}},	//   вају, třil_, deto,
  { {0x33d50086,0x2ca90fa8,0x443905e7,0x00000000}},	//   діот, ndad_, øs_,
  { {0xe7390185,0xb05b00c7,0x63a200ea,0x00000000}},	//   _grŵp_, tjän, _cson,
  { {0x290f0fab,0xe299005e,0x2ca9055f,0x00000000}},	//   loga_, цао_, hdad_,
  { {0x7f4d0fac,0x63a20fad,0xdb2400ea,0x00000000}},	//   _ataq, _eson, ésén,
  { {0x290f0fae,0x3cf90053,0xa988009a,0x00000000}},	//   noga_, ्कों_, הָשִ,
  { {0x2ca90137,0x629a0faf,0xdddc0023,0x00000000}},	//   ddad_, beto, pgrū,
  { {0x2ca9006d,0xb05b0072,0x853c0078,0x00000000}},	//   edad_, ljäl, _grės,
  { {0x386d0cd4,0x290f017f,0xfc3f017d,0x00000000}},	//   _oder_, koga_, _saía_,
  { {0x2ca90fb0,0xb05b0072,0x386d0fb1,0x00000000}},	//   gdad_, njäl, _nder_,
  { {0x394d00c2,0xcaca0085,0x3ce00605,0x00000000}},	// [1380] _česa_, огае_, rhiv_,
  { {0x89f60fb2,0x7d0900c2,0xb05b0137,0x00000000}},	//   وثائ, česa, hjäl,
  { {0x290f0140,0xbfa30013,0xdebb0063,0x00000000}},	//   foga_, hiể, _ומיל,
  { {0x69da00ea,0x38cb007e,0x61ee0e57,0x00000000}},	//   _ütem, يانی_, úbli,
  { {0x872a000d,0x98a4004c,0xab2a0854,0x00000000}},	//   оўка_, _zimě_, _мома_,
  { {0x47330086,0x386d0fb3,0x569302f8,0x00000000}},	//   вніс, _eder_, вашт,
  { {0x69d800b9,0xa96a06da,0xb05b0137,0x00000000}},	//   øved, _фиба_, fjäl,
  { {0x66cf0031,0x98a600c2,0x636a0fb4,0x00000000}},	//   _søkt, omoč_, орог_,
  { {0xd90d04de,0x629a0fb5,0x22490058,0x00000000}},	//   _این_, teto, _şaka_,
  { {0x6629013d,0xa823005d,0x68e20fb6,0x00000000}},	//   áskö, _شکنن, lhod,
  { {0x02a30088,0x386d01b0,0xe3af007e,0x00000000}},	//   трым, _yder_, هری_,
  { {0x754900ea,0x63a20fb7,0x62830fb8,0x00000000}},	//   őszö, _tson, _ecno,
  { {0x26cc0fb9,0x629a0fba,0x04430152,0x00000000}},	//   _kodo_, peto, _речн,
  { {0xe1ef006a,0x7ce30004,0x37d900b5,0x00000000}},	//   اسی_, _kõrg, פֿרע,
  { {0x9f34019d,0xdc3a01f7,0xc3270032,0x00000000}},	//   тері, _açık, _تكون_,
  { {0xe7ab0024,0x26cc0516,0x00000000,0x00000000}},	//   _ďaľš, _lodo_,   ,
  { {0x2ca90fbb,0x290f017f,0x386d00ac,0x00000000}},	// [1390] rdad_, voga_, _rder_,
  { {0x26cc0fbc,0xcf270049,0x7a540044,0x00000000}},	//   _nodo_, _تربي, نضما,
  { {0x7ce30019,0x63a0002b,0x290f0fbd,0x00000000}},	//   _nõrg, hwmn, toga_,
  { {0x26de0fbe,0xf8b10043,0x00000000,0x00000000}},	//   _alto_, دکس_,   ,
  { {0x26cc0fbf,0x290f0fc0,0xf7480044,0x00000000}},	//   _bodo_, roga_, وجوه_,
  { {0xdb0600b9,0x26cc006d,0x6f020139,0x00000000}},	//   _arkæ, _codo_, _íoct,
  { {0x66cf00d1,0x66f20022,0x04450af2,0x00000000}},	//   _søks, ałko, нейн,
  { {0x2f160fc1,0x27e60058,0x68e20fc2,0x00000000}},	//   lægt_, bzon_, chod,
  { {0xe3b10593,0xf7730593,0x58840085,0x00000000}},	//   ارب_, _جاز_, _шыра,
  { {0x16db0032,0xbfa30013,0xd5b1008d,0x00000000}},	//   _بذرة_, riể, _tŕ_,
  { {0x78a90019,0xb05b0527,0xcb120063,0x00000000}},	//   _kaev, lkäy, רלי_,
  { {0x98b8003d,0xe4540088,0x26c701b3,0x00000000}},	//   _kurā_, _акцы, ljno_,
  { {0x9522006a,0xb05b00fe,0x60cd000c,0x00000000}},	//   _حکوم, nkäy, _doam,
  { {0x78a90019,0x68e2016b,0x6da60fc3,0x00000000}},	//   _laev, zhod, нига,
  { {0x27e6000f,0x7bcb004d,0x60cd0fc4,0x00000000}},	//   zzon_, ägun, _foam,
  { {0xc06f0080,0x7693005b,0x64490fc5,0x00000000}},	//   íští, lıyı, ncei,
  { {0x628100c2,0x68e20240,0x6836005b,0x00000000}},	// [13a0] oglo, vhod, _müdü,
  { {0x62810fc6,0x76930058,0x09e60fc7,0x00000000}},	//   nglo, nıyı, нозн,
  { {0x26cc0006,0xae5b0063,0x984a0062,0x00000000}},	//   _rodo_, _מכיר, пяла_,
  { {0xa01b01e3,0x38600027,0x68e20080,0x00000000}},	//   mför, úir_, uhod,
  { {0x68e20fc8,0x26cc00a4,0xa01b0fc9,0x00000000}},	//   rhod, _podo_, lför,
  { {0x644b01b0,0x7ce3004b,0xb5a60456,0x00000000}},	//   _afgi, _põrg, ерий,
  { {0x68e2017f,0xa01b0502,0x26cc00c2,0x00000000}},	//   phod, nför, _vodo_,
  { {0x7ce30019,0xd37a000a,0xb05b0137,0x00000000}},	//   _võrg, пчо_, tjäm,
  { {0x26cc0fca,0x29040fcb,0xd467005e,0x00000000}},	//   _todo_, _ijma_, хиње_,
  { {0xa01b0137,0x026a0076,0xd2570054,0x00000000}},	//   kför, чший_, нцю_,
  { {0x7ce3004b,0x6d48011b,0x6611005d,0x00000000}},	//   _hõre, ídal, _پژوا,
  { {0xa01b00c7,0x644900cd,0x68360058,0x00000000}},	//   dför, ccei, _güdü,
  { {0xf8b30063,0xaf37007e,0x4e160042,0x00000000}},	//   אשר_, فرست, _दुबई_,
  { {0x661a00fe,0xdddc056c,0x00000000,0x00000000}},	//   _kytk, darł,   ,
  { {0x673a0994,0x6d5e001f,0x2f1600b9,0x00000000}},	//   _mitj, _cwpa, vægt_,
  { {0x51830fcc,0xa1830085,0x3e3400de,0x00000000}},	//   _суша, _сышл, افِر,
  { {0x2f1600b9,0xb05b00fe,0x78a9004b,0x00000000}},	// [13b0] tægt_, hjäk, _raev,
  { {0x3f640062,0x7c14012c,0x3e690043,0x00000000}},	//   _стъб, удує, _کجکی_,
  { {0x6d5e002b,0x78a9004e,0x00000000,0x00000000}},	//   _gwpa, _paev,   ,
  { {0x6ee20024,0x6d5500ca,0xf9900044,0x00000000}},	//   _vôbe, mpza, إبل_,
  { {0x7ce30004,0x98140088,0x317e00bd,0x00000000}},	//   _võrd, льшч, hutz_,
  { {0x26c700c2,0x6b8d0137,0xcf940149,0x00000000}},	//   ujno_, mtag, רטס_,
  { {0xceb4014e,0x6b8d0fcd,0x2729008b,0x00000000}},	//   טיס_, ltag, húng_,
  { {0xdb060d88,0x673a006f,0x94790fce,0x00000000}},	//   _erkä, _eitj, фску_,
  { {0x64490860,0xf5060062,0x14250062,0x00000000}},	//   rcei, ънъл_, ъдим,
  { {0x57f407b0,0xb05b004d,0x6b8d0fcf,0x00000000}},	//   _спут, ljäh, itag,
  { {0x0574006a,0x04950021,0x95570021,0x00000000}},	//   _ماند, _للاح, _أخطا,
  { {0x3f6a0fd0,0xb05b004d,0xa01b0137,0x00000000}},	//   мимо_, njäh, vför,
  { {0xefc70121,0xb05b004d,0xa8560063,0x00000000}},	//   влял_, ijäh, כירה_,
  { {0x6b8d010a,0xa01b01e3,0xe1f1006a,0x00000000}},	//   dtag, tför, _پست_,
  { {0x8d6302a9,0x92580021,0x213b0fd1,0x00000000}},	//   ивре, _أشهر_, _fiqh_,
  { {0xa01b0fd2,0xdddc0022,0xc339004c,0x00000000}},	//   rför, tarł, řídá,
  { {0xa01b0d88,0x6b8d0fd3,0xcb670713,0x00000000}},	// [13c0] sför, gtag, кате_,
  { {0xa01b00c7,0x7bc401a8,0xed460121,0x00000000}},	//   pför, rxiu, _иноп,
  { {0xa01b0026,0xef1f00ea,0xa9670062,0x00000000}},	//   ngön, ztük_, виха_,
  { {0xb05b004d,0xe874007e,0x6b8d0fd4,0x00000000}},	//   gjäh, انشگ, btag,
  { {0x2ca00019,0x27290024,0x673a0fd5,0x00000000}},	//   meid_, kúnd_, _pitj,
  { {0x2ca00fd6,0xc1780006,0x46f60062,0x00000000}},	//   leid_, yrė_, ъчет,
  { {0x442000eb,0x673a0fd7,0x8884007e,0x00000000}},	//   _ši_, _vitj, _میان,
  { {0xef1f00ea,0x2ca00019,0x44200013,0x00000000}},	//   ttük_, neid_, _ơi_,
  { {0xccf301d8,0x2b460025,0x656a0025,0x00000000}},	//   יכה_, íoch_, ssfh,
  { {0x2ca00102,0x21290fd8,0x2d9a01f2,0x00000000}},	//   heid_, _shah_, _oppe_,
  { {0x60f90fd9,0xf1a3005a,0x98b8003b,0x00000000}},	//   ення_, арян, _gură_,
  { {0x64a60141,0xdb040072,0x85f7009a,0x00000000}},	//   _јада, lviä, _בצבע_,
  { {0x99620080,0x2ca00019,0xf09f00cd,0x00000000}},	//   _níže_, deid_, reà_,
  { {0x2d47099a,0x2cab0fda,0x6b8d0a8c,0x00000000}},	//   _põe_, _sacd_, vtag,
  { {0x224e00a5,0xe297007b,0xc0cb01ce,0x00000000}},	//   _iffk_, _рај_, _жупе_,
  { {0x6b8d0fdb,0x5c7402b6,0xd5b8008f,0x00000000}},	//   ttag, илст, _azāk_,
  { {0xfc640062,0x6e460014,0xbab90fdc,0x00000000}},	// [13d0] ръсн, íubú, нгах_,
  { {0x7a400a63,0x6b8d0fdd,0xab940086,0x00000000}},	//   vští, rtag, рифі,
  { {0x6b8d0fde,0x2ca00fdf,0x99850021,0x00000000}},	//   stag, beid_, الصو,
  { {0x98ad0045,0xf7710fe0,0x25b90080,0x00000000}},	//   _mieć_, مات_, _čsl_,
  { {0xb05b004d,0x60dd0fe1,0x7a40004c,0x00000000}},	//   rjäh, iksm, uští,
  { {0xd6db0b0f,0x6f15006d,0x06840086,0x00000000}},	//   ьте_, nozc, игін,
  { {0x6d450004,0xf3f90529,0x29880fe2,0x00000000}},	//   _juha, maţi_, _исто_,
  { {0xf3f90529,0x60dd006f,0x6d450fe3,0x00000000}},	//   laţi_, jksm, _muha,
  { {0x42d5000d,0xe796007e,0xf495007e,0x00000000}},	//   гіну, _مالک, نشکد,
  { {0xdb0403d9,0xf3f90529,0x2fd90185,0x00000000}},	//   rviç, naţi_, dysg_,
  { {0xf3f9003b,0x442600ac,0x333c0fe4,0x00000000}},	//   iaţi_, _ezo_, _divx_,
  { {0xf1c30080,0x61fc0025,0xf4870d34,0x00000000}},	//   _alší_, úrla, _јужн,
  { {0xe2a8007e,0x2ca0004b,0x645b00ca,0x00000000}},	//   راین_, veid_, mbui,
  { {0x201e003d,0x6d450fe5,0xf3f9000c,0x00000000}},	//   āti_, _buha, jaţi_,
  { {0xe296005a,0xf3f9000c,0x2ca00fe6,0x00000000}},	//   _сащ_, daţi_, teid_,
  { {0x645b006f,0x61d60063,0x98b80078,0x00000000}},	//   nbui, _תוקף_, _kurą_,
  { {0xf3f9000c,0x2ca00fe7,0xeb2a0f8d,0x00000000}},	// [13e0] faţi_, reid_, ежал_,
  { {0x2ca00004,0xf3f90529,0x7641002b,0x00000000}},	//   seid_, gaţi_, _ngly,
  { {0x3f820fe8,0x2d9a0137,0x499a0085,0x00000000}},	//   luku_, _uppe_, этая_,
  { {0xa3e30053,0xb78a005e,0x7d7b00ff,0x00000000}},	//   नना_, ељке_, _אנטו,
  { {0xf3f9000c,0x7c26001c,0x3f820fe9,0x00000000}},	//   baţi_, _uzkr, nuku_,
  { {0xf3f90529,0x7d0400bd,0x645b0c8b,0x00000000}},	//   caţi_, lnis, ebui,
  { {0x7d040fea,0xdcfc00a8,0x44260feb,0x00000000}},	//   onis, hurč, _szo_,
  { {0x645b0dac,0x33740fec,0x7d040fed,0x00000000}},	//   gbui, агир, nnis,
  { {0xd70a026b,0x98ad0051,0x48060a25,0x00000000}},	//   _знае_, _sieć_, _спав,
  { {0x3f820035,0x7d040fee,0x92b600f2,0x00000000}},	//   duku_, hnis, احظا,
  { {0x7d040fef,0xe3b2007e,0x6f15004c,0x00000000}},	//   knis, _گرا_, vozc,
  { {0xf3f90529,0x2ba50053,0x0446032d,0x00000000}},	//   zaţi_, _ऑनला, _седн,
  { {0x6d450ff0,0x44260035,0x60dd0ff1,0x00000000}},	//   _suha, _uzo_, rksm,
  { {0xf3f9000c,0x6d450ff2,0x02a30062,0x00000000}},	//   xaţi_, _puha, _гръм,
  { {0xf3f90529,0x7d040ff3,0x78a20ff4,0x00000000}},	//   vaţi_, fnis, keov,
  { {0x4fd50086,0xd904007e,0x7d040ff5,0x00000000}},	//   _вжит, _ری_, gnis,
  { {0xf3f90529,0xdbc600bd,0x69d801f2,0x00000000}},	// [13f0] taţi_, röße, øven,
  { {0x6d450ff6,0xf3f9003b,0x7d040ff7,0x00000000}},	//   _tuha, uaţi_, anis,
  { {0x7d040199,0xf3f90529,0xad27005d,0x00000000}},	//   bnis, raţi_, _مرحو,
  { {0xf3f90529,0x78a20146,0x48390021,0x00000000}},	//   saţi_, geov, نكاح_,
  { {0xf3f9000c,0x0b8b0062,0x2d830ff8,0x00000000}},	//   paţi_, _ясни_, luje_,
  { {0x4b7a0047,0x645b00ca,0xe7330044,0x00000000}},	//   _באשו, wbui, حصص_,
  { {0x2d910ff9,0x645b0c5f,0x2d830ffa,0x00000000}},	//   ntze_, tbui, nuje_,
  { {0x09e10161,0xe7250013,0x8c3b004d,0x00000000}},	//   पनीय, _dưỡ, _faßt,
  { {0xe78700d7,0x443900c7,0x2d83016b,0x00000000}},	//   _љубо, äs_, huje_,
  { {0x3ae400c7,0x7d040ffb,0x645b0104,0x00000000}},	//   _köpa_, znis, sbui,
  { {0x2d830ffc,0x645b059f,0xd5bb0054,0x00000000}},	//   juje_, pbui, _яса_,
  { {0xf5300032,0x96340699,0x3f820078,0x00000000}},	//   _فإن_, _унхц, tuku_,
  { {0x8c3b004d,0x3ae400a5,0xe3a5005d,0x00000000}},	//   _maßs, _löpa_, _خشای,
  { {0x3f820117,0xc8e20053,0x0efa0085,0x00000000}},	//   ruku_, _खत्म_, тэмы_,
  { {0x3f820ffd,0x20ef0080,0xacf60d34,0x00000000}},	//   suku_, třit_, ачај,
  { {0x3f820ffe,0x7ce3004b,0xdb0f00cd,0x00000000}},	//   puku_, _põra, _arcà,

  { {0x0b1a0021,0xac050021,0x78a20261,0x00000000}},	// [1400] نقرة_, مذكو, veov,
  { {0x2d830fff,0xba26000d,0x7d041000,0x00000000}},	//   buje_, адзк, snis,
  { {0xc8661001,0x7e7b0063,0x2d830aa3,0x00000000}},	//   атли, _באיז, cuje_,
  { {0x3ae40137,0xd7fa1002,0x7c961003,0x00000000}},	//   _döpa_, кул_, _троц,
  { {0x27e0018d,0x78a21004,0x4b550062,0x00000000}},	//   áin_, reov, _гъст,
  { {0xb05b0072,0x78a21005,0xb882004c,0x00000000}},	//   ljät, seov, _řídk,
  { {0xafdb0146,0x27e00392,0x5f090042,0x00000000}},	//   ncør, šin_, _सदस्_,
  { {0x63b900a3,0xd9431006,0xd49a012c,0x00000000}},	//   _brwn, _фети, трк_,
  { {0x6676006a,0x63b9001f,0xa507005e,0x00000000}},	//   _ندار, _crwn, јења_,
  { {0xd5b8008f,0xeb97009a,0xb1e600de,0x00000000}},	//   _trā_, סדיר_, لأجه,
  { {0x2d8301d9,0x3ce0004b,0xb5ca00de,0x00000000}},	//   xuje_, kkiv_, _جوام_,
  { {0xd5fb0063,0x2d8301f5,0xb92a0054,0x00000000}},	//   _בפבר, vuje_, нкiв,
  { {0x89370047,0x2d830051,0x29370047,0x00000000}},	//   ירטע_, wuje_, יאטן_,
  { {0xdefb06bc,0x539b0063,0x2ee50014,0x00000000}},	//   тым_, _סיוו, ólf_,
  { {0x27290025,0xcf8e007e,0x69d805e7,0x00000000}},	//   núna_, وژی_, øvel,
  { {0x9fe7006a,0x2c780086,0xd6d90022,0x00000000}},	//   _نسخه, ийсь_, _pułk_,
  { {0x6f950021,0x2d831007,0xdb0f1008,0x00000000}},	// [1410] _الخض, suje_, _arcá,
  { {0x62881009,0x2d83100a,0x5c040085,0x00000000}},	//   ngdo, puje_, іята,
  { {0xaf34006a,0x3ce900d1,0xf9f90021,0x00000000}},	//   _بريت, phav_, دفاع_,
  { {0xb4d50053,0x20040022,0x99280054,0x00000000}},	//   _सके_, źmie_, аюча_,
  { {0xe72e000d,0x97a70121,0xb05b0072,0x00000000}},	//   зе_, ррел, ljäs,
  { {0x9a840d34,0x2d73007d,0xbae50044,0x00000000}},	//   _мусл, oće_, _اكسي,
  { {0xb9e4012c,0x2729009c,0x5e78009a,0x00000000}},	//   _діти, gúna_, בתון_,
  { {0xe9190086,0x2d73007d,0xccf2009a,0x00000000}},	//   _собі_, iće_, ּ֛ה_,
  { {0x36d50001,0x368b100b,0xa825007e,0x00000000}},	//   _лоар, _асен_, _اکان,
  { {0x628800d1,0xa2e50002,0x24770013,0x00000000}},	//   ggdo, соод, ểm_,
  { {0xd9f70053,0xf1bf017c,0xa06a0d4e,0x00000000}},	//   ंछित_, čšom_, лана_,
  { {0xaac90053,0xf494012c,0xa535014b,0x00000000}},	//   राडक, _мрію, _унеч,
  { {0x2d73017f,0xc4840085,0x10160085,0x00000000}},	//   eće_, _флік, сьня,
  { {0x63a90035,0xfe7a0085,0xd9f90042,0x00000000}},	//   mwen, ыёмы_, ्पात_,
  { {0x8db50086,0xdef9000d,0x63a9100c,0x00000000}},	//   ості, рыў_, lwen,
  { {0x6b84100d,0x6c59005e,0xa5da0041,0x00000000}},	//   tuig, ијус_, אַמי,
  { {0x60c4100e,0xdcfc001c,0x3ce00e6c,0x00000000}},	// [1420] _inim, gurā, rkiv_,
  { {0x98a6007d,0x4bd90121,0xb05b0ef1,0x00000000}},	//   omoć_, шься_, sjät,
  { {0x60d6005b,0xbed70047,0x63a90a67,0x00000000}},	//   _koym, _הויז_, hwen,
  { {0xe894019d,0x6d5c100f,0x63a91010,0x00000000}},	//   іаль, mpra, kwen,
  { {0xb7960001,0x6d5c1011,0x628801e1,0x00000000}},	//   срећ, lpra, ygdo,
  { {0x63a90186,0x6ffc001c,0xef1f005b,0x00000000}},	//   dwen, mācī, ltür_,
  { {0x60c4017f,0x6d5c1012,0x7f3b0047,0x00000000}},	//   _onim, npra, נעצו,
  { {0xdbdd034d,0x63a9004d,0xb05b0137,0x00000000}},	//   zšír, fwen, hjär,
  { {0xb7f20053,0x96960ad9,0x6ffc008f,0x00000000}},	//   _आइटम_, _греш, nācī,
  { {0x6eeb1013,0xf2c60a91,0x60c41014,0x00000000}},	//   _kübe, ссин, _anim,
  { {0x5a9b0047,0xef1f0058,0xba9b07e9,0x00000000}},	//   נשטא, ktür_, נסטי,
  { {0x692c000c,0x7afe005b,0x6d5c1015,0x00000000}},	//   _aşez, hipt, dpra,
  { {0x7afe0ac6,0x6d5c1016,0xb05b0137,0x00000000}},	//   kipt, epra, fjär,
  { {0x60c40213,0xff07000d,0x39581017,0x00000000}},	//   _enim, сямн, _otrs_,
  { {0x68e21018,0xab5b087d,0x2d730130,0x00000000}},	//   kkod, _krüg, uće_,
  { {0x99860045,0x657c02ea,0x69de00d1,0x00000000}},	//   łoś_, _århu, dype,
  { {0x8b580021,0x68e20b2a,0x6d5c1019,0x00000000}},	// [1430] مجلس_, dkod, apra,
  { {0xe509008b,0x2d73007d,0xa9c70086,0x00000000}},	//   oặc_, pće_, йсек,
  { {0x7f3c00b5,0x394a00e5,0x96f9005d,0x00000000}},	//   _געזו, _cubs_, یعتر_,
  { {0xad27006a,0x0cab026b,0x38690026,0x00000000}},	//   _درخو, _стои_, úar_,
  { {0x78a4004b,0xab840002,0x17c90a91,0x00000000}},	//   õiva, _нурк, ргли_,
  { {0xab5b00bd,0x7afe053b,0xe739101a,0x00000000}},	//   _prüf, cipt, шел_,
  { {0x68e201e1,0xd5750054,0x6104013d,0x00000000}},	//   bkod, цуль, lőle,
  { {0x63a900bd,0xe894000d,0x68e20137,0x00000000}},	//   twen, _нась, ckod,
  { {0x63a90194,0x42e90001,0x59e10053,0x00000000}},	//   uwen, имио_, पनकर,
  { {0x63a90199,0x68e90080,0x60c4017f,0x00000000}},	//   rwen, _hled, _snim,
  { {0x68e9101b,0x5455026b,0x63a9004d,0x00000000}},	//   _kled, _двет, swen,
  { {0x6d5c00c2,0x6112008f,0x00000000,0x00000000}},	//   vpra, kāle,   ,
  { {0xb05b0137,0x2b59101c,0x7fd6045b,0x00000000}},	//   tjär, _ntsc_, ціні,
  { {0x68e9001f,0x539a0063,0x68e2101d,0x00000000}},	//   _lled, _כינו, zkod,
  { {0x3d28007e,0x98a40078,0xdcfc003b,0x00000000}},	//   متری_, _gimė_, jură,
  { {0xb05b003a,0x6eeb004d,0x68e90137,0x00000000}},	//   sjär, _rübe, _nled,
  { {0x2a780150,0x6d5c101e,0x68e205a5,0x00000000}},	// [1440] _pdrb_, spra, vkod,
  { {0x68e9006d,0x69de0246,0x6d5c101f,0x00000000}},	//   _aled, type, ppra,
  { {0xdcfc000c,0x68e21020,0x6f1c1021,0x00000000}},	//   gură, tkod, morc,
  { {0xab5b00bd,0x718c0047,0x6f1c1022,0x00000000}},	//   _brüd, רװאַ, lorc,
  { {0x7d0905c9,0x68e21023,0x4c36007f,0x00000000}},	//   čest, rkod, _фэнт,
  { {0x68e21024,0x290d0035,0x6f1c1025,0x00000000}},	//   skod, _ejea_, norc,
  { {0xab5b0019,0xc448007e,0xdcfc003b,0x00000000}},	//   _prüg, میان_, cură,
  { {0x68e901a6,0x15170032,0xd250007e,0x00000000}},	//   _gled, يزية_, کند_,
  { {0xdcfc001c,0x442200b9,0x3e57004c,0x00000000}},	//   ltrē, æk_, nětí_,
  { {0x3f9e00dd,0x35a60085,0xe5a60816,0x00000000}},	//   ătul_, _мазг, _мизи,
  { {0x610400ea,0xdcfc001c,0x7ce3004b,0x00000000}},	//   zőle, ntrē, _sõrm,
  { {0x6b9600c7,0x23660022,0xdcf50022,0x00000000}},	//   ktyg, _twoj_, orzą,
  { {0xf044000d,0x6f1c0b02,0xc49b0063,0x00000000}},	//   дэро, forc, _כשאת,
  { {0x6f1c007d,0xe29701ce,0x8e8400de,0x00000000}},	//   gorc, _даљ_, ولُه,
  { {0x52130001,0xccfb0001,0x2732000c,0x00000000}},	//   _одшт, аћа_, mând_,
  { {0x9f6b0001,0x8b670021,0x610400ea,0x00000000}},	//   _кроз_, قائم, tőle,
  { {0x2d68003b,0x6f1c1026,0xe81a0082,0x00000000}},	// [1450] aşe_, borc, _फुला_,
  { {0xf43b014e,0x2732000c,0x6f1c1027,0x00000000}},	//   שתמש, nând_, corc,
  { {0xfc3f1028,0x68e91029,0xdcf50051,0x00000000}},	//   _país_, _pled, erzą,
  { {0xaac90053,0x394400cd,0x63a2102a,0x00000000}},	//   राहक, _cims_, _opon,
  { {0x99540080,0xdcfc000c,0x69ca087d,0x00000000}},	//   _výše_, sură, äfer,
  { {0x7bda0063,0x68e9001f,0xb345017d,0x00000000}},	//   _הקשו, _wled, _liçã,
  { {0x63a20016,0x2732003b,0x7ce3004b,0x00000000}},	//   _apon, dând_, _nõrk,
  { {0xe9180086,0x2ca90139,0x68fb0058,0x00000000}},	//   _досі_, nead_, _umud,
  { {0x291d0051,0x3995102b,0x2732003b,0x00000000}},	//   mowa_, lås_, fând_,
  { {0x386d102c,0x2732000c,0x291d0051,0x00000000}},	//   _heer_, gând_, lowa_,
  { {0x386d0102,0x42250086,0x3995102d,0x00000000}},	//   _keer_, ядов, nås_,
  { {0x7cf103d4,0x291d102e,0xd59a0063,0x00000000}},	//   _hårf, nowa_, _לבעל,
  { {0x386d102f,0x7ce30019,0x273200dd,0x00000000}},	//   _meer_, _tõrj, bând_,
  { {0x2732000c,0x386d1030,0x442f00a8,0x00000000}},	//   când_, _leer_, _izg_,
  { {0x2ca90025,0x291d0051,0xa9280240,0x00000000}},	//   fead_, kowa_, ližš,
  { {0x2732000c,0xf0660076,0x386d1031,0x00000000}},	//   mâne_, _экип, _neer_,
  { {0x2d8300c7,0x6f1c1032,0x291d0051,0x00000000}},	// [1460] arje_, porc, dowa_,
  { {0x4b23000a,0x8b230076,0x6b9600c7,0x00000000}},	//   емув, едуе, rtyg,
  { {0x6edb014e,0x386d1033,0x39951034,0x00000000}},	//   _החיפ, _beer_, gås_,
  { {0x2732000c,0x3eaa004d,0xdcf50051,0x00000000}},	//   zând_, lebt_, trzą,
  { {0xdcfc003d,0x386d0034,0x4cbb0063,0x00000000}},	//   strē, _deer_, _הזכו,
  { {0x2d980164,0x6d460b67,0xddc71035,0x00000000}},	//   otre_, _hika, lajš,
  { {0x6b841036,0x6d461037,0x2732003b,0x00000000}},	//   lrig, _kika, vând_,
  { {0x2d980164,0x6b841038,0x61e11039,0x00000000}},	//   itre_, orig, dyll,
  { {0x2732000c,0x6b8400b9,0x6d46103a,0x00000000}},	//   tând_, nrig, _mika,
  { {0x386d0122,0xdb0d03d9,0x248d0016,0x00000000}},	//   _zeer_, rvaç, agem_,
  { {0x2732000c,0x6b84103b,0x6d4600fe,0x00000000}},	//   rând_, hrig, _oika,
  { {0x2fc00185,0x2d9800d1,0x6d46103c,0x00000000}},	//   _brig_, dtre_, _nika,
  { {0x2732000c,0x38690026,0x613f001c,0x00000000}},	//   pând_, ðari_, _jūli,
  { {0x6d46024a,0x442600bb,0x61360026,0x00000000}},	//   _aika, _iyo_, jálf,
  { {0x06fd0080,0x6b84103d,0xe29b009a,0x00000000}},	//   _říká_, erig, _השור,
  { {0x6d46103e,0xe5090013,0x6b840f15,0x00000000}},	//   _cika, hặn_, frig,
  { {0x2d9c01e3,0x6d460e53,0x0f270086,0x00000000}},	// [1470] _även_, _dika, _ньом,
  { {0x7cea0a63,0x6112001c,0x0ab40002,0x00000000}},	//   _výra, māla, нбуџ,
  { {0xab5b00bd,0x291d0051,0x752200ea,0x00000000}},	//   _brüc, towa_, _okoz,
  { {0xddde0080,0xf77101a7,0x3995103f,0x00000000}},	//   _nepř, نات_, rås_,
  { {0x3f8b005b,0xab5b00bd,0x44261040,0x00000000}},	//   nucu_, _drüc, _nyo_,
  { {0x386d0102,0xd2460032,0x291d1041,0x00000000}},	//   _weer_, _لن_, sowa_,
  { {0x67210198,0x248d00cd,0x9f440080,0x00000000}},	//   _vklj, tgem_, ámé_,
  { {0x7d0d1042,0x6112008f,0x61e10072,0x00000000}},	//   nnas, kāla, vyll,
  { {0x61e1001f,0x248d1043,0x7d0d1044,0x00000000}},	//   wyll, rgem_, inas,
  { {0x67210117,0x7d0d0185,0x610400ea,0x00000000}},	//   _uklj, hnas, dőla,
  { {0x2d980003,0x7d0d1045,0x63bb1046,0x00000000}},	//   xtre_, knas, svun,
  { {0x63a4000c,0x6b841047,0x63c8013d,0x00000000}},	//   _ţine, yrig, érnö,
  { {0x61e10185,0xdb0f0871,0x644b00ac,0x00000000}},	//   syll, _escé, _iggi,
  { {0x6d46014f,0x2d981048,0x75291049,0x00000000}},	//   _sika, ttre_, llez,
  { {0x2d980164,0xddc700c3,0x3eaa004d,0x00000000}},	//   utre_, tajš, rebt_,
  { {0x7d0d0bad,0xa01b0137,0x2d98104a,0x00000000}},	//   gnas, tgöt, rtre_,
  { {0x2d98104b,0x83b500b5,0xddc7104c,0x00000000}},	// [1480] stre_, ופּע_, rajš,
  { {0x6d460bc1,0xa01b0cbf,0x2d98104d,0x00000000}},	//   _wika, rgöt, ptre_,
  { {0x6d46003d,0x7c260051,0x644b104e,0x00000000}},	//   _tika, _wykr, _oggi,
  { {0x18670138,0x395c001c,0xfd45000d,0x00000000}},	//   даци_, īvs_, _пэўн,
  { {0x7d040072,0xa01b0b68,0x7529007d,0x00000000}},	//   miis, lgör, dlez,
  { {0x644b104f,0x64590122,0x752200c3,0x00000000}},	//   _aggi, _afwi, _skoz,
  { {0xdcf50051,0x7ae31050,0xa01b1051,0x00000000}},	//   erzę, önte, ngör,
  { {0x290201e3,0x75291052,0x7cf10666,0x00000000}},	//   _öka_, glez, _gård,
  { {0x38661053,0xddde004c,0x2286012c,0x00000000}},	//   mbor_, _vepř, мунг,
  { {0x6d5e017f,0x65c60905,0x75290080,0x00000000}},	//   _otpa, _обза, alez,
  { {0x752902dd,0xdcf50051,0xe8df0013,0x00000000}},	//   blez, arzę, _hiền_,
  { {0xf503005a,0x6ef00137,0x752901f4,0x00000000}},	//   _изхо, _näbb, clez,
  { {0x7ce30004,0xc0e4000d,0x64a3005e,0x00000000}},	//   _kõrv, тоўк, _јача,
  { {0xe8df001b,0x3f8b005b,0x6112008f,0x00000000}},	//   _miền_, rucu_, rāla,
  { {0xdd940088,0xc348001b,0xe8df008b,0x00000000}},	//   кары, _nổi_, _liền_,
  { {0x201e000c,0x30a702a9,0x61e700b9,0x00000000}},	//   ştia_, _цркв, øjle,
  { {0xfd440088,0x7d0d1054,0x6ef0004d,0x00000000}},	// [1490] тэрн, rnas, _säbe,
  { {0x0dcb011c,0x4ac90053,0x19eb0593,0x00000000}},	//   _думи_, राइव, يراً_,
  { {0xceb20047,0x212b0616,0x7d0d0014,0x00000000}},	//   _גיי_, olch_, pnas,
  { {0x7cf105e7,0xe8df008d,0xc348008d,0x00000000}},	//   _båre, _biền_, _dổi_,
  { {0x7cf10137,0x78ab00ac,0x27e90014,0x00000000}},	//   _vård, regv, áan_,
  { {0x6d580003,0x38661055,0xc1780078,0x00000000}},	//   _évac, abor_, ksė_,
  { {0x38660137,0x27e90869,0x69d804aa,0x00000000}},	//   bbor_, šan_, øvet,
  { {0xdb040014,0x7cf10b2a,0xdcf50022,0x00000000}},	//   lvið, _fåre, trzę,
  { {0x68e40072,0x613601c2,0x24090121,0x00000000}},	//   öide, nále, янии_,
  { {0xe299005e,0x7529004c,0xe161014b,0x00000000}},	//   чао_, slez, лямi_,
  { {0x753b00ca,0x290f1056,0xf647005e,0x00000000}},	//   pmuz, onga_, _цхан,
  { {0x2732003b,0xa01b0137,0x68f90058,0x00000000}},	//   mâna_, vgör, _çadı,
  { {0x7d04021e,0x290f1057,0xdb040014,0x00000000}},	//   viis, inga_, kvið,
  { {0x61360080,0xa01b0137,0x38661058,0x00000000}},	//   dále, tgör, zbor_,
  { {0x7d04021e,0x6da30713,0xa0a609b3,0x00000000}},	//   tiis, лира, _зайд,
  { {0x7cea004a,0xe058007e,0x6112008f,0x00000000}},	//   _výro, _زیست_, mālo,
  { {0x7d04003a,0xdb040014,0x249f0014,0x00000000}},	// [14a0] riis, fvið, ifum_,
  { {0x290f1059,0x7d040ff2,0xda650021,0x00000000}},	//   enga_, siis, نامي,
  { {0xf9690086,0x7cf1105a,0xdc3c00c2,0x00000000}},	//   дрій_, _såre, _iščo,
  { {0xdd2f0080,0x7cf100b9,0xcb09016e,0x00000000}},	//   pěšn, _påre, זל_,
  { {0x3866105b,0x569402fe,0x387f002b,0x00000000}},	//   rbor_, валт, _ddur_,
  { {0x290f105c,0x7cf100df,0xa824007e,0x00000000}},	//   anga_, _våre, _یکشن,
  { {0x212b001f,0x6b490078,0x9597005e,0x00000000}},	//   ylch_, _užga, етњу_,
  { {0xe8df001b,0x7cf105a5,0x2907006c,0x00000000}},	//   _tiền_, _tåre, énat_,
  { {0x7ce3004b,0x6d3b009a,0x00000000,0x00000000}},	//   _tõrv, התקנ,   ,
  { {0x13f30076,0xdb970047,0x877b0063,0x00000000}},	//   узья, עדיט_, _מאמי,
  { {0xe6d90026,0x27e6105d,0xc1780078,0x00000000}},	//   _þráð, lyon_, usė_,
  { {0xef1f0244,0x28c60082,0x25d7009d,0x00000000}},	//   grün_, _रोमि, _רואן_,
  { {0xe8df001b,0x27e60465,0x201e003b,0x00000000}},	//   _hiển_, nyon_, ştin_,
  { {0x9f350086,0x26de0035,0xf09f00cd,0x00000000}},	//   тегі, _joto_, sfà_,
  { {0x26de105e,0x7e7500c2,0xd72d0054,0x00000000}},	//   _moto_, razp, _лiце,
  { {0x6b8d0a5c,0x7cf1011d,0x26de105f,0x00000000}},	//   tuag, _sårb, _loto_,
  { {0x3eba000c,0x60cd1060,0xfa87005e,0x00000000}},	// [14b0] _fapt_, _inam, ећем,
  { {0x26de051e,0x27e60a9f,0x3ce900c2,0x00000000}},	//   _noto_, dyon_, skav_,
  { {0xab5b0199,0x7b0b001c,0x249f0026,0x00000000}},	//   _grün, kļuv, yfum_,
  { {0xa954019d,0x6c790047,0xdb040026,0x00000000}},	//   укці, _קאָפ, svið,
  { {0x60cd0035,0x26de1061,0x69d80093,0x00000000}},	//   _mnam, _boto_, øver,
  { {0x8698005a,0xe8df008b,0xd6db07da,0x00000000}},	//   етът_, _biển_, яте_,
  { {0x27e60414,0x5b1402a9,0x60cd08ee,0x00000000}},	//   ayon_, _смрт, _onam,
  { {0x27e61062,0xe8df008d,0x00000000,0x00000000}},	//   byon_, _diển_,   ,
  { {0xf6990138,0x249f1063,0x26de1064,0x00000000}},	//   _овај_, rfum_, _foto_,
  { {0x929d0047,0x6112008f,0x60cd1065,0x00000000}},	//   _פֿון_, tālo, _anam,
  { {0xe4e70086,0x9f44004c,0x67230130,0x00000000}},	//   _підн, ámí_, monj,
  { {0x23b50032,0xd00a000a,0x67231066,0x00000000}},	//   _لمؤس, деме_, lonj,
  { {0x78bb0164,0xe299036a,0x3ae40137,0x00000000}},	//   _mauv, _жал_, _köpt_,
  { {0x78bb1067,0x67230397,0x60cd1068,0x00000000}},	//   _lauv, nonj, _enam,
  { {0x7c96005a,0x27e6005b,0x8c96000d,0x00000000}},	//   крац, zyon_, краі,
  { {0xfbe700aa,0xe6d90026,0x7c85005e,0x00000000}},	//   _thể_, _þræð, луђе,
  { {0x3eba0031,0x67231069,0x1c46106a,0x00000000}},	// [14c0] _tapt_, konj, тнам,
  { {0x60cd106b,0x00000000,0x00000000,0x00000000}},	//   _znam,   ,   ,
  { {0x7c2900b9,0x26de106c,0xd946106d,0x00000000}},	//   _øern, _roto_, вежи,
  { {0xe7860088,0x26de106e,0x09060062,0x00000000}},	//   вуко, _soto_, ъпен,
  { {0x38cb007e,0x67230ee9,0x6455004c,0x00000000}},	//   ظامی_, fonj, ězil,
  { {0xdb0f0016,0x67230a1a,0xc9860021,0x00000000}},	//   _escâ, gonj, _لشري,
  { {0x27e6106f,0x66e300d7,0x26de1070,0x00000000}},	//   syon_, роја, _voto_,
  { {0x399c00cd,0x44b4018e,0xef1f00ea,0x00000000}},	//   mís_, убис, erül_,
  { {0x26de0512,0x96960086,0x399c1071,0x00000000}},	//   _toto_, _ареш, lís_,
  { {0x78bb0253,0x26cc1072,0x6723032c,0x00000000}},	//   _zauv, _undo_, conj,
  { {0x399c0857,0x68e00014,0x6abc1073,0x00000000}},	//   nís_, _komd, _marf,
  { {0xb97b0063,0x7bc61074,0x7cf8013d,0x00000000}},	//   ונטי, _orku, _hírf,
  { {0x399c0025,0x68e3017d,0x53b60042,0x00000000}},	//   hís_, êndi, _अनिश,
  { {0x6ee200be,0x3d9501fe,0x00000000,0x00000000}},	//   _sôbr, лигр,   ,
  { {0x5e58019d,0xdef80088,0x7bc60051,0x00000000}},	//   тися_, тыя_, _arku,
  { {0x60cd1075,0x68e00331,0x853c0078,0x00000000}},	//   _unam, _nomd, _spėj,
  { {0x6d580164,0x7b0b008f,0x6abc1076,0x00000000}},	// [14d0] _évan, kļut, _barf,
  { {0x8c440138,0x78bb0164,0x61360026,0x00000000}},	//   ређе, _sauv, mála,
  { {0x6136000f,0x78bb0164,0x69d80d02,0x00000000}},	//   lála, _pauv, øvep,
  { {0xfc64011c,0xfc3f006d,0x39150085,0x00000000}},	//   _върн, _maíz_, ымер,
  { {0x6136000f,0xd366006a,0x9cd60063,0x00000000}},	//   nála, _ده_, _עושה_,
  { {0x2d910080,0xa5b90001,0x273b008b,0x00000000}},	//   ouze_, ећих_, iêng_,
  { {0x61360027,0xdb1d017d,0x399c032a,0x00000000}},	//   hála, _ersã, cís_,
  { {0x38c200ea,0x69c70150,0x91fc001c,0x00000000}},	//   térő_, _irje, abāk,
  { {0xdb040072,0x67230516,0xd2990054,0x00000000}},	//   rviö, ponj, нтні_,
  { {0x61e80185,0xe8df001b,0x61361077,0x00000000}},	//   fydl, _diễn_, dála,
  { {0x394d04c6,0xb14606f0,0x04950593,0x00000000}},	//   _kies_, лнол, _ملاح,
  { {0xa6e2007a,0x6d5a1078,0x201e0058,0x00000000}},	//   _öðru, ítam, ştim_,
  { {0x2d91006f,0x61361079,0x2d85004c,0x00000000}},	//   euze_, gála, álen_,
  { {0x394d0780,0xe299107a,0x6d410003,0x00000000}},	//   _lies_, _чак_, ïlan,
  { {0x523900b5,0xd3360063,0x7cf10137,0x00000000}},	//   _אײַנ, _גרסה_, _såra,
  { {0x399c0268,0xacf5005e,0x6abc107b,0x00000000}},	//   vís_, ачуј, _sarf,
  { {0x6abc107c,0xdc75000d,0x69c300b9,0x00000000}},	// [14e0] _parf, рысь, ænen,
  { {0x89f60088,0x80a00161,0x7cf10137,0x00000000}},	//   ляец, ग्रे, _våra,
  { {0x6abc00c7,0x7ce30004,0xcd360021,0x00000000}},	//   _varf, _võrr, _مرحب,
  { {0xdb0f00cd,0x399c107d,0x6abc107e,0x00000000}},	//   _escà, rís_, _warf,
  { {0x6283107f,0x394d1080,0x399c01a8,0x00000000}},	//   _odno, _dies_, sís_,
  { {0x394d0c29,0x3f72001c,0xd5b00021,0x00000000}},	//   _eies_, iņu_, قفت_,
  { {0xdb23013d,0x69c7007d,0xc7b9013d,0x00000000}},	//   _óráj, _grje, _eső_,
  { {0x29040009,0xfc3f02dd,0xc448007e,0x00000000}},	//   _umma_, _raíz_, نیان_,
  { {0xd2500032,0x9cd70063,0xe78a007e,0x00000000}},	//   ينة_, רופה_, _سپاه_,
  { {0x6136000f,0x61e81081,0x61fa00bd,0x00000000}},	//   vála, tydl, tztl,
  { {0x62340259,0xe6160002,0xf1a301d5,0x00000000}},	//   рену, _сфаќ, брян,
  { {0x61360025,0xe8df0013,0x62831082,0x00000000}},	//   tála, _tiễn_, _edno,
  { {0x8cbf0053,0xe47b0047,0x29370047,0x00000000}},	//   _लोगो, _טראכ, טאטן_,
  { {0x43830032,0xb3bb0063,0xff040062,0x00000000}},	//   _الوق, _נמוכ, бясн,
  { {0x61361083,0xeca7000a,0x6d580164,0x00000000}},	//   sála, лјан, _éval,
  { {0x55770047,0x61361084,0x6ef000a5,0x00000000}},	//   טעלן_, láln, _fäbo,
  { {0xe8df00aa,0x1bd400a0,0xab5b004d,0x00000000}},	// [14f0] _hiện_, ботя, _trüm,
  { {0xe8df001b,0x63bd00b9,0x394d0c29,0x00000000}},	//   _kiện_, æsni, _sies_,
  { {0x394d1085,0x127b0041,0xc333089e,0x00000000}},	//   _pies_, גאבע, צוע_,
  { {0x2fc900e8,0xd7f10021,0x69c70130,0x00000000}},	//   _krag_, يكا_, _vrje,
  { {0xdb0f05d5,0x61360114,0x394d1086,0x00000000}},	//   _escá, káln, _vies_,
  { {0x6b8d000e,0x394d004d,0x7bc8069a,0x00000000}},	//   mrag, _wies_, _עֶרֶ,
  { {0x8aa4019d,0x45191087,0x6d4f0035,0x00000000}},	//   _уряд, кция_, _kica,
  { {0x7cf81088,0x394d01a8,0xf4290519,0x00000000}},	//   _vírg, _uies_, койл_,
  { {0x28f80b3f,0x54a40021,0x61360260,0x00000000}},	//   _сеть_, صحيف, fáln,
  { {0x42550fe2,0xe8df008b,0x03a800f2,0x00000000}},	//   штит, _biện_, اديو_,
  { {0x6b8d028d,0x7cf800ea,0xab5b0058,0x00000000}},	//   hrag, _híre, _brük,
  { {0xe8df001b,0x3f72001c,0x6b8d0850,0x00000000}},	//   _diện_, tņu_, krag,
  { {0x6112001c,0x613d00ea,0x61361089,0x00000000}},	//   nāli, zélg, báln,
  { {0xdcee0080,0x7cf80025,0x6b8d108a,0x00000000}},	//   ědče, _míre, drag,
  { {0x6d4f0974,0x2d9e03b2,0x6b8d028d,0x00000000}},	//   _bica, îte_, erag,
  { {0x3fe60086,0x6b8d108b,0xb05b051c,0x00000000}},	//   _вжив, frag, rdäc,
  { {0x6136000f,0xca560002,0x6d4f0cf8,0x00000000}},	// [1500] lálo, атењ, _dica,
  { {0xff7b0047,0x7bc4108c,0x7cf10d1a,0x00000000}},	//   _שטימ, rviu, _hårl,
  { {0x6d4f03d9,0x6b8d108d,0x6136108e,0x00000000}},	//   _fica, arag, nálo,
  { {0x3ead017f,0xdbdc108f,0x2c5c0051,0x00000000}},	//   đete_, lšíc, _bądź_,
  { {0x69c500d1,0x26350013,0x6b8d1090,0x00000000}},	//   avhe, _áo_, crag,
  { {0x7cf80027,0x6d44001f,0x613d00ea,0x00000000}},	//   _díre, lmia, méle,
  { {0x7e7c0089,0x613600ea,0xd5b00021,0x00000000}},	//   iarp, váln, سفة_,
  { {0x54b8005a,0x6136004c,0x442f01e1,0x00000000}},	//   угия_, dálo, _byg_,
  { {0x2bc90053,0x7e7c1091,0x61361092,0x00000000}},	//   रिया, karp, táln,
  { {0xdbdc0240,0x41c6000d,0x6eeb1093,0x00000000}},	//   jšíc, аёма, _tübi,
  { {0x613d1094,0xdcf6004c,0x20d50021,0x00000000}},	//   héle, ýběr, مقدس,
  { {0xab5b0199,0x7e6e00c7,0xe8df001b,0x00000000}},	//   _früh, ebbp, _viện_,
  { {0x7cf102ab,0x6d4f1095,0x395801a8,0x00000000}},	//   _dårl, _rica, _lurs_,
  { {0x7e7c00c7,0x6b8d1096,0x6d57017d,0x00000000}},	//   garp, vrag, _puxa,
  { {0x13b60161,0xab5b042e,0x5186005e,0x00000000}},	//   _अनुभ, _trük, _ђука,
  { {0x6b8d1097,0x613600ea,0xccf8005e,0x00000000}},	//   trag, náll, аћу_,
  { {0x113c0063,0xdd2f004c,0x6b8d1098,0x00000000}},	// [1510] _בתהל, _těžb, urag,
  { {0xf9c71099,0x7e7c109a,0x7d16002b,0x00000000}},	//   ищен, carp, anys,
  { {0x6d4f005b,0x3958109b,0x6b8d004d,0x00000000}},	//   _tica, _curs_, srag,
  { {0x6112001c,0x3958109c,0x58870085,0x00000000}},	//   tāli, _durs_, рыжа,
  { {0x7d0d109d,0xa7a9005e,0x9cd6009a,0x00000000}},	//   mias, укла_, _הורה_,
  { {0x6136000f,0x7cf80025,0xb8820026,0x00000000}},	//   eáll, _víre, _þíni,
  { {0x395800c2,0xa509006e,0x0568005e,0x00000000}},	//   _gurs_, лека_, ајњи_,
  { {0x201e000c,0x6136109e,0x78a9000e,0x00000000}},	//   ştii_, gáll, _ubev,
  { {0x57f5000a,0xe5040021,0x387d002b,0x00000000}},	//   _упат, تبوي, mawr_,
  { {0x6d440051,0x7d0d0e67,0x387d002b,0x00000000}},	//   zmia, hias, lawr_,
  { {0x7e7c0026,0x6d440a8d,0x613d00ea,0x00000000}},	//   varp, ymia, zéle,
  { {0x3f6a0138,0x387d001f,0x7d0d0035,0x00000000}},	//   лимо_, nawr_, jias,
  { {0x7e7c109f,0x320b0051,0x7d0d10a0,0x00000000}},	//   tarp, ńcy_, dias,
  { {0x083a0047,0x613d10a1,0x752900ca,0x00000000}},	//   טערל, véle, loez,
  { {0x51950021,0x7e7c0354,0x527a0041,0x00000000}},	//   _العذ, rarp, _ענקא,
  { {0x4bda0076,0x1d07000a,0x7d0d10a2,0x00000000}},	//   льзя_, беси_, gias,
  { {0x4aaa10a3,0x61360024,0x395810a4,0x00000000}},	// [1520] лкан_, nálm, _surs_,
  { {0x613600ea,0xca56005e,0x6d4410a5,0x00000000}},	//   záll, стањ, smia,
  { {0xc879005b,0x7cf80297,0x387d001f,0x00000000}},	//   _beş_, _círc, fawr_,
  { {0x2732000c,0x7d0d10a6,0x3f820051,0x00000000}},	//   mâni_, cias, osku_,
  { {0xa03a0047,0x2bc90053,0x613610a7,0x00000000}},	//   װײַז, रिणा, váll,
  { {0xb8ef0161,0x3b0a0121,0x6112008f,0x00000000}},	//   _वो_, _сего_, mālu,
  { {0xceb30063,0x6136013d,0xa4d80505,0x00000000}},	//   פיה_, táll, идку_,
  { {0xdb1d00c7,0x8a170063,0x18a3050f,0x00000000}},	//   _ersä, _החלו_, _насм,
  { {0xe73a0079,0x6112001c,0x3f8210a8,0x00000000}},	//   _беа_, nālu, jsku_,
  { {0x27f90019,0x2bc90053,0x3f8210a9,0x00000000}},	//   _üsna_, रिता, dsku_,
  { {0x7d0d0089,0x394610aa,0xd2500049,0x00000000}},	//   yias, omos_, بند_,
  { {0xca370063,0x613600ea,0x463b0047,0x00000000}},	//   מניה_, lálj, _געבע,
  { {0xdcee001c,0x394605d5,0xdb0d0014,0x00000000}},	//   arbī, imos_, kvað,
  { {0x6136000f,0xdb1d017d,0x28cf0053,0x00000000}},	//   nálj, _essê, _सोनि,
  { {0xc27b00b5,0x427b0063,0x645d0078,0x00000000}},	//   _גרוי, _גאוג, žsie,
  { {0xe2170063,0xdcf5008f,0xdb06013d,0x00000000}},	//   _לקוח_, muzī, _eskü,
  { {0x212b0024,0x99620066,0x672a10ab,0x00000000}},	// [1530] moch_, _ríše_, kofj,
  { {0x394610ac,0xda670021,0x6e950021,0x00000000}},	//   emos_, صائي, _بلدا,
  { {0xdcfc001c,0x99620114,0x4879000d,0x00000000}},	//   gurē, _píše_, асля_,
  { {0x212b10ad,0x9cb50021,0x383510ae,0x00000000}},	//   noch_, _بمحت, онер,
  { {0x7d1d10af,0x69d80072,0xe72e10b0,0x00000000}},	//   _ijss, äver, де_,
  { {0x613600ea,0x212b10b1,0x7c3d00c2,0x00000000}},	//   gálj, hoch_, _izsr,
  { {0x212b0024,0x2d8310b2,0x05790021,0x00000000}},	//   koch_, nsje_, جمعة_,
  { {0x212b0024,0xe9190086,0x2d83006f,0x00000000}},	//   joch_, _тобі_, isje_,
  { {0x613600ea,0x212b10b3,0x290f10b4,0x00000000}},	//   bálj, doch_, miga_,
  { {0x290f10b5,0xf6f5006a,0x13090076,0x00000000}},	//   liga_, _بزرگ, рной_,
  { {0x61460601,0x799710b6,0x7cf8013d,0x00000000}},	//   жена, nuxw, _líra,
  { {0xa2a90235,0xa4f7007e,0x3f820743,0x00000000}},	//   _जॉर्, _دکتر_, tsku_,
  { {0x613600ea,0x3f840114,0x290f004b,0x00000000}},	//   lálk, ému_, iiga_,
  { {0x7cea0026,0x3f8210b7,0x236d007d,0x00000000}},	//   _nýrr, rsku_, mpej_,
  { {0x6ab710b8,0x2ca90137,0xdd920049,0x00000000}},	//   dexf, ffad_, ظور_,
  { {0x290f01b3,0x6112001c,0x613600ea,0x00000000}},	//   jiga_, tālu, zálj,
  { {0x6ef00004,0x290f10b9,0xdd2f004c,0x00000000}},	// [1540] _läbi, diga_, běžn,
  { {0xdcfc003d,0x2d910051,0x60c40e7e,0x00000000}},	//   turē, brze_, _haim,
  { {0x613600ea,0x60c40576,0xed5a005e,0x00000000}},	//   válj, _kaim, _њом_,
  { {0x290f0019,0x613610ba,0x60c40877,0x00000000}},	//   giga_, dálk, _jaim,
  { {0x394610bb,0xdb040122,0x87ba0076,0x00000000}},	//   rmos_, ntië, рует_,
  { {0x6b840027,0x3eb810bc,0xc58a0076,0x00000000}},	//   msig, nert_, ащие_,
  { {0x613600ea,0x290f004b,0x3eb810bd,0x00000000}},	//   rálj, biga_, iert_,
  { {0x443d0199,0x3eb800bd,0x2d9801a8,0x00000000}},	//   _bzw_, hert_, iure_,
  { {0x6b8410be,0x212b0066,0x69ce1035,0x00000000}},	//   nsig, voch_, _hrbe,
  { {0x613610bf,0xd25a0001,0x20020051,0x00000000}},	//   lálh, шци_, dzki_,
  { {0xd62a0076,0x3eb810c0,0x212b10c1,0x00000000}},	//   _тоже_, dert_, toch_,
  { {0x6136000f,0xdb1d00cd,0x613d0026,0x00000000}},	//   nálh, _essè, féla,
  { {0x60c410c2,0x2d980bbd,0x212b10c3,0x00000000}},	//   _daim, eure_, roch_,
  { {0x6b8410c4,0x212b10c1,0x2d910051,0x00000000}},	//   dsig, soch_, trze_,
  { {0xfe54000d,0x60c4003b,0x212b0066,0x00000000}},	//   дкрэ, _faim, poch_,
  { {0x2d830051,0x01fb0063,0x2d8d00a8,0x00000000}},	//   rsje_, _כפול, čee_,
  { {0x6b84002c,0x20020051,0x3eb810c5,0x00000000}},	// [1550] gsig, czki_, bert_,
  { {0xdb040164,0xad670021,0x3eb810c6,0x00000000}},	//   ntiè, _واجه, cert_,
  { {0x63bb00bd,0x6b840455,0x2ca9004d,0x00000000}},	//   zwun, asig, pfad_,
  { {0x63670024,0x61e700b9,0x6b84006d,0x00000000}},	//   nčný, øjli, bsig,
  { {0x3f99005b,0x290f10c7,0xd7f8005e,0x00000000}},	//   nusu_, riga_, жуј_,
  { {0x290f10c8,0xb5790121,0x613610c9,0x00000000}},	//   siga_, бщих_, tálk,
  { {0x3f9910ca,0x63670024,0x290f09c9,0x00000000}},	//   husu_, kčný, piga_,
  { {0xd5ae0021,0x9f4400ea,0xf7bb007e,0x00000000}},	//   افي_, ámú_, _پدرش_,
  { {0x13090086,0x48fa0047,0xb8ff0053,0x00000000}},	//   йний_, _פּלא, ता_,
  { {0xa2050086,0x63bb00bd,0xe2990856,0x00000000}},	//   зпод, rwun, љан_,
  { {0x3eb810cb,0x6136017d,0xe8df0013,0x00000000}},	//   vert_, láli, _nhịn_,
  { {0x3eb800bd,0x443d0051,0x79850035,0x00000000}},	//   wert_, _tzw_, ishw,
  { {0x3eb810cc,0x26c500f3,0x60c4021e,0x00000000}},	//   tert_, _kalo_, _vaim,
  { {0x3eb800bd,0x2d980399,0x7d0100ac,0x00000000}},	//   uert_, ture_, ëlsn,
  { {0x3eb8076c,0x2732000c,0x57b80053,0x00000000}},	//   rert_, mânt_, _इन्ह,
  { {0x3eb810cd,0x26c5002c,0x3ea110ce,0x00000000}},	//   sert_, _lalo_, _echt_,
  { {0x3f99005b,0x613600ea,0x2d980399,0x00000000}},	// [1560] cusu_, válh, sure_,
  { {0x2d9802f6,0x6b840f80,0x628110cf,0x00000000}},	//   pure_, rsig, nalo,
  { {0x68e910d0,0x3a990085,0xc4bd0042,0x00000000}},	//   _boed, ўтую_, ्याओ,
  { {0xc7c60076,0xb05b00fe,0x26c710d1,0x00000000}},	//   зски, ydäm, edno_,
  { {0x68e9001f,0x6d5e0035,0x613600ea,0x00000000}},	//   _doed, _hupa, gáli,
  { {0x6d5e10d2,0x26c510d3,0x628110d4,0x00000000}},	//   _kupa, _calo_, jalo,
  { {0x628110d5,0x613d0080,0x7e7e00ca,0x00000000}},	//   dalo, déln, _mepp,
  { {0x68e910d6,0x68fb001f,0x7cf80080,0x00000000}},	//   _goed, _glud, _míro,
  { {0xd4670001,0x26c5017d,0x61360516,0x00000000}},	//   чиње_, _falo_, cáli,
  { {0x98b800eb,0xe3af01a7,0x7e7e10d7,0x00000000}},	//   _kurį_, اري_, _nepp,
  { {0xdb040003,0x6d5e008f,0xdceb007d,0x00000000}},	//   rtiè, _nupa, _žiča,
  { {0x63a4000c,0xdb040003,0x6281004b,0x00000000}},	//   _ţinu, stiè, aalo,
  { {0x6d5e10d8,0xe505007e,0xdb040003,0x00000000}},	//   _aupa, _تبلي, ptiè,
  { {0x6d5e00f3,0x628a0146,0x7e7e0290,0x00000000}},	//   _bupa, _udfo, _cepp,
  { {0xdd910021,0x271b0041,0x7cf8017c,0x00000000}},	//   ضوء_, צולײ, _vírn,
  { {0x291c0b6d,0x65c7004c,0x26c700a8,0x00000000}},	//   éval_, léhá, zdno_,
  { {0x68e90c70,0x201e01f7,0xd0080138,0x00000000}},	// [1570] _roed, ştir_, _неће_,
  { {0x613610d9,0x3ea10025,0x798510da,0x00000000}},	//   váli, _ucht_, tshw,
  { {0xed580079,0x68fb10db,0x68e9006f,0x00000000}},	//   _ноќ_, _plud, _poed,
  { {0xf9900242,0xd8390085,0x613610dc,0x00000000}},	//   ابل_, опец_, táli,
  { {0x2b93006a,0x68e90179,0x6d5e00c2,0x00000000}},	//   _سیاس, _voed, _zupa,
  { {0x68e9006f,0x8f9c00ff,0x657a002b,0x00000000}},	//   _woed, מידי, _bwth,
  { {0x27320529,0x26c702e2,0x7cf8006d,0x00000000}},	//   vânt_, rdno_, _oírl,
  { {0x62810022,0x613601c8,0x657a00a3,0x00000000}},	//   walo, páli, _dwth,
  { {0xf794000d,0xa2a10053,0xd7940062,0x00000000}},	//   _патэ, _खाद्, _питъ,
  { {0x613600ea,0x628101f4,0x7bcd0003,0x00000000}},	//   nálv, ualo, ivau,
  { {0x63a40529,0x387f00e8,0x657a002b,0x00000000}},	//   _ţint, _keur_, _gwth,
  { {0xdb04006d,0x7e7e10dd,0x6d5e10de,0x00000000}},	//   rtié, _sepp, _rupa,
  { {0x6d5e10df,0x628110e0,0x73e40086,0x00000000}},	//   _supa, palo, _поїз,
  { {0x387f03b2,0x249f10e1,0x63a910e2,0x00000000}},	//   _leur_, lgum_, mten,
  { {0x63a910e3,0x613d013d,0x6da30af0,0x00000000}},	//   lten, célo, кира,
  { {0x249f0ac6,0x205610e4,0x63a910e5,0x00000000}},	//   ngum_, _отпр, oten,
  { {0xe8df001b,0x38c60078,0x7e7e10e6,0x00000000}},	// [1580] _chọn_, _jūrų_, _tepp,
  { {0x63a910e7,0x6d5e10e8,0x6a16005d,0x00000000}},	//   iten, _tupa, وبار,
  { {0x8ca60053,0x89f5000d,0x7cf8013d,0x00000000}},	//   _छापो, няцц, _hírm,
  { {0x63a90323,0xef1f0075,0xa934005d,0x00000000}},	//   kten, nsün_, رباچ,
  { {0x387f10e9,0x69da08c1,0x2d85004c,0x00000000}},	//   _deur_, _šted, šlet_,
  { {0x61360026,0xdcfc0006,0x386601a8,0x00000000}},	//   málu, turė, scor_,
  { {0xceb30063,0x613600ea,0x63a910ea,0x00000000}},	//   דיו_, lálu, eten,
  { {0x2ca00019,0x249f0026,0x63a910eb,0x00000000}},	//   ngid_, ggum_, ften,
  { {0x2ca00019,0x63a910ec,0x69e3003b,0x00000000}},	//   igid_, gten, ăteş,
  { {0x2732003b,0x7cf110ed,0x57430854,0x00000000}},	//   râns_, _hårt, _ануб,
  { {0x6128005b,0x63a910ee,0x61150a71,0x00000000}},	//   kıld, aten, едну,
  { {0x7bcd0006,0x63a910ef,0x6136013d,0x00000000}},	//   yvau, bten, zálv,
  { {0xf09f00cd,0x24f7000d,0xfebb007e,0x00000000}},	//   rgà_, _іншы_, ياست_,
  { {0x2ca0004b,0x6b960022,0x24840244,0x00000000}},	//   egid_, dryg, lamm_,
  { {0xfcc70001,0x7c87005e,0x613600ea,0x00000000}},	//   мљам, дузе, válv,
  { {0x6c550002,0xa2d60082,0x00000000,0x00000000}},	//   екбу, बाक्,   ,
  { {0x7bcd0072,0x8aa70794,0x6136013d,0x00000000}},	// [1590] uvau, дред, gálu,
  { {0xab940086,0x2d85029c,0x7bcd10f0,0x00000000}},	//   тифі, áles_, rvau,
  { {0x387f0164,0x6136013d,0xe3c8008d,0x00000000}},	//   _peur_, rálv, _lự_,
  { {0x6f15005b,0xa2150047,0xdcf5008f,0x00000000}},	//   lizc, ײַעס_, irzī,
  { {0x63a910f1,0x320510f2,0x6d4d10f3,0x00000000}},	//   xten, zzly_, mmaa,
  { {0xd24610f4,0x613600ea,0xc879003b,0x00000000}},	//   _من_, lált, _roşu_,
  { {0x386010f5,0x6d4d06f8,0xa8a710f6,0x00000000}},	//   žira_, omaa, _орак,
  { {0x6d4d10f7,0x613600ea,0xc9840259,0x00000000}},	//   nmaa, nált, _јури,
  { {0x249f007a,0x6d4d00fe,0xe3c80013,0x00000000}},	//   rgum_, imaa, _cự_,
  { {0xe3c8001b,0x63a910d0,0x6d4d10f8,0x00000000}},	//   _dự_, rten, hmaa,
  { {0x6d4d10f9,0x613d00ea,0x63a910fa,0x00000000}},	//   kmaa, mélj, sten,
  { {0xcea9014e,0x63a910fb,0xd576009a,0x00000000}},	//   _לי_, pten, _נתנה_,
  { {0x6d4d0250,0xdb1d0858,0x251a0047,0x00000000}},	//   dmaa, _assí, _צונא,
  { {0x201e000c,0x6d4d0f5e,0x69ca01e1,0x00000000}},	//   ăti_, emaa, æfek,
  { {0x65610016,0x6128005b,0xe8160053,0x00000000}},	//   _julh, tıld, _देना_,
  { {0x656103d9,0x6d4d10fc,0x613610fd,0x00000000}},	//   _mulh, gmaa, gált,
  { {0xac0a000a,0xf1c9008b,0x6128005b,0x00000000}},	// [15a0] чнаа_, _hạ_, rıld,
  { {0x6d4d10fe,0x61280058,0xef1f0075,0x00000000}},	//   amaa, sıld, nsül_,
  { {0x6128005b,0x613600ea,0x91fc008f,0x00000000}},	//   pıld, bált, ecāj,
  { {0x6d4600fe,0xe973007e,0xc7ca0121,0x00000000}},	//   _uhka, اهند, зыке_,
  { {0x69c300b9,0xf1c9008b,0xe73a0448,0x00000000}},	//   æner, _lạ_, пед_,
  { {0x8f9b00b5,0x7bc610ff,0xe5c60980,0x00000000}},	//   פיצי, _isku, есио,
  { {0xe3c800aa,0xd5b70121,0xf1c90013,0x00000000}},	//   _sự_, есы_, _nạ_,
  { {0x273b008b,0x2d981100,0x35c50053,0x00000000}},	//   hênh_, irre_, विज़,
  { {0xd90d006a,0xe8b501f7,0x7d0400fe,0x00000000}},	//   _بین_, lışı, ihis,
  { {0x55e60086,0x51f80086,0x78a2085a,0x00000000}},	//   _позб, дною_, lgov,
  { {0x7cf80080,0x7d041101,0x78a208ea,0x00000000}},	//   _círk, khis, ogov,
  { {0xe3c8001b,0x753b000c,0x7bc60ba5,0x00000000}},	//   _tự_, cluz, _osku,
  { {0x6136000f,0x04570032,0x65610089,0x00000000}},	//   vált, _كلمة_, _zulh,
  { {0x3ea5000f,0x1ee7006a,0x7d041102,0x00000000}},	//   ült_, روزی_, ehis,
  { {0x6d4d1103,0x7bc60ef1,0x613d013d,0x00000000}},	//   tmaa, _asku, nélk,
  { {0x563700b5,0xd904006a,0x23b70053,0x00000000}},	//   גאלע_, _طی_, _अहमद,
  { {0x78a201b3,0x628e0051,0x6d4d1104,0x00000000}},	// [15b0] dgov, óbow, rmaa,
  { {0xadf50088,0xab180086,0x6d4d1105,0x00000000}},	//   _апош, нієї_, smaa,
  { {0x6d4d0250,0xf1c9008b,0x7d0400d1,0x00000000}},	//   pmaa, _xạ_, bhis,
  { {0x57f50002,0xf0940047,0x6d580003,0x00000000}},	//   кпет, ָנס_, _évap,
  { {0xdddc1106,0x46a502b3,0xdbcd00ca,0x00000000}},	//   parţ, валв, _vóór,
  { {0x78a200b2,0x613d013d,0x00000000,0x00000000}},	//   agov, félk,   ,
  { {0x2bc90053,0xd626005e,0x3ce900a8,0x00000000}},	//   रिका, коше_, ojav_,
  { {0x69c7007d,0x3ce900a8,0x9ddc0063,0x00000000}},	//   _isje, njav_, לקוח,
  { {0x3f8b0051,0x443900b9,0xf7080013,0x00000000}},	//   jscu_, æs_, hủy_,
  { {0x69d50051,0xdcfc001c,0xdddc00a2,0x00000000}},	//   _krze, turī, harš,
  { {0x3f8b000c,0x3f990046,0xc2420505,0x00000000}},	//   escu_, ersu_, иньк,
  { {0xdddc007d,0xf1c90013,0x7d041107,0x00000000}},	//   jarš, _vạ_, xhis,
  { {0xc95200b5,0xc2c50044,0xa78c009a,0x00000000}},	//   ימט_, _ليشي, ּאלֹ,
  { {0x78a20117,0x69c7017f,0xe8b5005b,0x00000000}},	//   zgov, _osje, yışı,
  { {0x7d160058,0x3f9900a8,0x386d1108,0x00000000}},	//   tiys, arsu_, _ofer_,
  { {0x7aee00cd,0xad390086,0x61360066,0x00000000}},	//   _sobt, ечує_, ráls,
  { {0xc0c9005e,0x69d51109,0x7d16107b,0x00000000}},	// [15c0] _чује_, _arze, riys,
  { {0x69d50051,0x6283110a,0xe8b5005b,0x00000000}},	//   _brze, _jeno, tışı,
  { {0x3ce900c2,0x62830fa9,0x7bc60051,0x00000000}},	//   bjav_, _meno, _wsku,
  { {0x69d50051,0x2900017d,0xe8b5005b,0x00000000}},	//   _drze, óia_, rışı,
  { {0x69d500bd,0xdb080139,0x7bc6110b,0x00000000}},	//   _erze, ólót, _usku,
  { {0x47330454,0x7cf10b19,0x6283110c,0x00000000}},	//   аніс, _hårp, _neno,
  { {0x27e00529,0x69d80146,0xdb0f017d,0x00000000}},	//   ţin_, æved, _escó,
  { {0x23ab0146,0x2cb2002b,0xb8650044,0x00000000}},	//   føj_, nfyd_, _ماكو,
  { {0x7d03000c,0x6283110d,0x69d50022,0x00000000}},	//   _înse, _beno, _zrze,
  { {0x6e29005b,0x7cf80025,0x613d110e,0x00000000}},	//   şebi, _díri, méli,
  { {0x26de0034,0x31c3005a,0xe8160053,0x00000000}},	//   _into_, асяв, _देता_,
  { {0x7cf80139,0x51f70183,0xf946014b,0x00000000}},	//   _fíri, тнюю_, ннiк_,
  { {0x62830aa8,0x7cf800be,0x69d801e1,0x00000000}},	//   _feno, _gíri, åvej,
  { {0x2cb2001f,0x6283110f,0x63a0004b,0x00000000}},	//   efyd_, _geno, mumn,
  { {0x6288094c,0xd788001b,0x8233007e,0x00000000}},	//   mado, hể_, _پروا,
  { {0x26cc04a6,0x7e62003b,0x3ead004c,0x00000000}},	//   _lado_, _şopt, řet_,
  { {0xac180001,0x26de1110,0x7c841111,0x00000000}},	// [15d0] воту_, _onto_, русе,
  { {0x69d51112,0x613d1113,0x62881114,0x00000000}},	//   _prze, déli, nado,
  { {0xf9c7005a,0x6128005b,0x60cd1115,0x00000000}},	//   ъщан, lıla, _kaam,
  { {0xf1b30047,0x63a01116,0x60cd0bda,0x00000000}},	//   יסע_, kumn, _jaam,
  { {0x26cc0009,0x612801f7,0x6d5d002c,0x00000000}},	//   _bado_, nıla, _iisa,
  { {0x69d50045,0xdb0f00cd,0x62881117,0x00000000}},	//   _trze, _escò, jado,
  { {0x26cc06b2,0x7cf80367,0x62881118,0x00000000}},	//   _dado_, _síri, dado,
  { {0x23ab0146,0x61360026,0x6b4b00ea,0x00000000}},	//   tøj_, jálp, függ,
  { {0x6b8d03d9,0xed11001b,0x6d5d1119,0x00000000}},	//   nsag, _đối_, _misa,
  { {0xa3d5016a,0x6d5d0436,0x26cc017d,0x00000000}},	//   हिब_, _lisa, _gado_,
  { {0x3495000a,0xa189000d,0x6283111a,0x00000000}},	//   _баер, эбна_, _veno,
  { {0xd5fa0047,0xd00a111b,0x6d5d111c,0x00000000}},	//   _אפער, ееме_, _nisa,
  { {0x6128005b,0x6288111d,0x60cd004e,0x00000000}},	//   gıla, bado, _daam,
  { {0x33920032,0x6b8d10c4,0x62881114,0x00000000}},	//   _الوز, dsag, cado,
  { {0xb1760013,0x6d5d111e,0xdef9000d,0x00000000}},	//   _trượ, _bisa, тыў_,
  { {0x6128005b,0x6d5d111f,0x6b8d0014,0x00000000}},	//   bıla, _cisa, fsag,
  { {0x612801f7,0x6b8d1120,0x6d5d1121,0x00000000}},	// [15e0] cıla, gsag, _disa,
  { {0x78a90331,0x09e61122,0x613d1123,0x00000000}},	//   _acev, лозн, véli,
  { {0x6b8d00a4,0x26cc1124,0x6d5d1125,0x00000000}},	//   asag, _rado_, _fisa,
  { {0x62881126,0x613d1127,0xa9260121,0x00000000}},	//   zado, téli, ыдел,
  { {0x62881128,0xbcfb0003,0x01370047,0x00000000}},	//   yado, _siég, אָגט_,
  { {0x62880367,0x613d1129,0xbcfb0003,0x00000000}},	//   xado, réli, _piég,
  { {0xe1e7006a,0x7d030529,0x6128005b,0x00000000}},	//   _اس_, _însc, zıla,
  { {0x612801f7,0x443d0185,0x63a0112a,0x00000000}},	//   yıla, _byw_, tumn,
  { {0x60cd0004,0x6288112b,0x2904112c,0x00000000}},	//   _raam, tado, _ilma_,
  { {0x26de0034,0x443d001f,0x63a00dde,0x00000000}},	//   _unto_, _dyw_, rumn,
  { {0x22580019,0xba9b0047,0x63a0007d,0x00000000}},	//   ärk_, עסטי, sumn,
  { {0x612801f7,0x443d001f,0x6b8d0164,0x00000000}},	//   tıla, _fyw_, ysag,
  { {0x6b4b004d,0x6d5d112d,0xe3af007e,0x00000000}},	//   lüge, _risa, _فرو_,
  { {0x6d5d0551,0x612801f7,0x69c50034,0x00000000}},	//   _sisa, rıla, ywhe,
  { {0xbcfb03b2,0xb816016a,0x6b4b00bd,0x00000000}},	//   _liée, _देसम_, nüge,
  { {0x612801f7,0xab5b004b,0x563b0047,0x00000000}},	//   pıla, _tsük, געלײ,
  { {0x6d5d112e,0xaae00053,0x30780021,0x00000000}},	// [15f0] _visa, नांक, _صحية_,
  { {0x6d5d00f3,0xa3d50053,0x2904112f,0x00000000}},	//   _wisa, हित_, _alma_,
  { {0x6b8d1130,0x6d5d1131,0xbcfb006c,0x00000000}},	//   ssag, _tisa, _piéd,
  { {0xd7d5000a,0x69c50034,0x317b0047,0x00000000}},	//   ижењ, rwhe, גראמ,
  { {0xdb041132,0x17550054,0xdb07013d,0x00000000}},	//   stiá, авдя, álód,
  { {0x6b4b00bd,0x443d001f,0x61fa0061,0x00000000}},	//   füge, _ryw_, kytl,
  { {0x5a440088,0x00000000,0x00000000,0x00000000}},	//   _гэта,   ,   ,
  { {0xd6180021,0x2d9e007d,0x2129004b,0x00000000}},	//   دتها_, šteg_, _njah_,
  { {0xab5b0019,0x76a70021,0x320c0066,0x00000000}},	//   _psüh, _محاك, ezdy_,
  { {0x57f40001,0x6620004c,0xdb160050,0x00000000}},	//   _упут, ázká, svyö,
  { {0x21290150,0xf8c90042,0x324505a0,0x00000000}},	//   _bjah_, _रसाय, ренг,
  { {0x33d50454,0xa3d50042,0x3a36009a,0x00000000}},	//   _вікт, हिद_, ירתם_,
  { {0x955401fb,0x320c0022,0xa9360063,0x00000000}},	//   _اخلا, azdy_, שטרה_,
  { {0x394d0016,0xa8560063,0xd1390022,0x00000000}},	//   _lhes_, יירה_, stąp_,
  { {0xad3a0054,0x764e01c8,0xff050085,0x00000000}},	//   вчає_, _úbyt, сяўн,
  { {0x25ed0053,0xc5f20063,0x6f660141,0x00000000}},	//   _अपनी_, חדל_, _квиз,
  { {0xed571133,0x6b4b004d,0xca86072d,0x00000000}},	// [1600] рот_, züge, игай,
  { {0x0d861134,0x1e961135,0xbf130044,0x00000000}},	//   _клон, _трир, _وويب,
  { {0x395f0150,0x6b4b004d,0x7e9b0063,0x00000000}},	//   _bius_, fügb, _בסיו,
  { {0x4069009a,0x00000000,0x00000000,0x00000000}},	//   ְיוּ_,   ,   ,
  { {0x67d400e1,0x6f1c0139,0x613d013d,0x00000000}},	//   солу, oirc, mélt,
  { {0x7cf81136,0xd7370054,0xc178005f,0x00000000}},	//   _víru, апії_, ypė_,
  { {0x4420000c,0x95ca1137,0x2abb009a,0x00000000}},	//   _ţi_, тула_, _שמלא,
  { {0x5e570047,0x95d70062,0x6b4b004d,0x00000000}},	//   סיקע_, рдът_, rüge,
  { {0x6f1c00bd,0xdcef007d,0x76480022,0x00000000}},	//   kirc, žeće, _wzdy,
  { {0x21290e46,0x32660896,0xf7461138,0x00000000}},	//   _sjah_, штив, _тезо,
  { {0x6f1c0290,0x98af001c,0xd62701d5,0x00000000}},	//   dirc, logā_, _кофе_,
  { {0xd5fb0047,0x23660078,0x799e002b,0x00000000}},	//   _שפאר, _tuoj_, irpw,
  { {0x69da00c2,0x9f590003,0x4432008d,0x00000000}},	//   _štel, lysé_, _ây_,
  { {0x65680035,0xa2d30021,0xada80066,0x00000000}},	//   _kudh, _وينت, zdĺž,
  { {0xe2970001,0x63390041,0x613d013d,0x00000000}},	//   _тај_, _געװױ, félt,
  { {0x65681139,0x6f1c0139,0xa3ca0082,0x00000000}},	//   _mudh, airc, _लना_,
  { {0xea670001,0x395f00cd,0x2d580376,0x00000000}},	// [1610] ањен, _rius_, рить_,
  { {0x6738007d,0x65680983,0x6f1c113a,0x00000000}},	//   jovj, _oudh, circ,
  { {0xdb06013d,0xdb1d0014,0x63b500dd,0x00000000}},	//   émáb, _orsö, ăzni,
  { {0x1869005e,0x7bcb0014,0xc7950044,0x00000000}},	//   ћали_, ægus, مشتب,
  { {0x69ca00b9,0x395f00cd,0x2d910051,0x00000000}},	//   æfer, _vius_, lsze_,
  { {0x16a906be,0x2ca90019,0x6568113b,0x00000000}},	//   увки_, lgad_, _budh,
  { {0x394d113c,0xe8df0013,0x2ca9013d,0x00000000}},	//   _thes_, _nhện_, ogad_,
  { {0x7af500ea,0x2ca9113d,0xb92500f2,0x00000000}},	//   _hozt, ngad_, _افري,
  { {0x291d0009,0x673800a8,0x6f1c0058,0x00000000}},	//   miwa_, bovj, yirc,
  { {0x291d113e,0x13060076,0xddde0240,0x00000000}},	//   liwa_, йный_, _lepš,
  { {0xdb040016,0x2d910051,0x63b60072,0x00000000}},	//   stiç, jsze_, _äynn,
  { {0x291d0035,0x14ca007e,0x91fc008f,0x00000000}},	//   niwa_, _مهمی_, ecās,
  { {0xc50c00b5,0x2ca9113f,0xb05b0050,0x00000000}},	//   _בלאָ, dgad_, seän,
  { {0x65681140,0x644b085a,0x613d00ea,0x00000000}},	//   _yudh, _izgi, féls,
  { {0x291d0009,0x6b5000c7,0xf2d20047,0x00000000}},	//   kiwa_, lägg, _מעג_,
  { {0x3c660088,0x2ca900c7,0x291d0035,0x00000000}},	//   скаг, ggad_, jiwa_,
  { {0x291d0035,0x6128005b,0x2d910022,0x00000000}},	// [1620] diwa_, nılm, asze_,
  { {0x2ca91141,0x1eca0121,0x2d910022,0x00000000}},	//   agad_, _слои_, bsze_,
  { {0x8db60086,0x60c60229,0x67380130,0x00000000}},	//   _успі, oekm, vovj,
  { {0x718a00b5,0x6128005b,0xc9850021,0x00000000}},	//   רװײַ, kılm, تشكي,
  { {0x31b100ea,0xc7a30a90,0x6738007d,0x00000000}},	//   ház_, зичк, tovj,
  { {0x6d4404bf,0x09e60062,0x98af008f,0x00000000}},	//   llia, _логн, rogā_,
  { {0x6d441142,0x291d0035,0xfb1b0063,0x00000000}},	//   olia, biwa_, _עולמ,
  { {0x539800a0,0xdb040072,0x337405ce,0x00000000}},	//   авия_, stiä, огир,
  { {0x2d851143,0x6d441144,0x6738017f,0x00000000}},	//   ález_, ilia, povj,
  { {0x6d441145,0x91b80002,0x656800ea,0x00000000}},	//   hlia, агот_, _tudh,
  { {0xe3af006a,0x69da00c3,0xf5390080,0x00000000}},	//   وری_, _štej, boť_,
  { {0xd3e4006a,0x4a5b0063,0xd46a005e,0x00000000}},	//   _وقای, טדיו, _сиде_,
  { {0x2d910045,0x6d441146,0xa01b0137,0x00000000}},	//   wsze_, dlia, dböc,
  { {0x291d1147,0x6d441148,0x644200a4,0x00000000}},	//   ziwa_, elia, _iyoi,
  { {0x2d850164,0xde590086,0xb05b0072,0x00000000}},	//   èle_, раві_, meäm,
  { {0x6d4402f6,0x91e3005e,0x2d911149,0x00000000}},	//   glia, _хоће, rsze_,
  { {0x2d9100ea,0x69d800b9,0x2ca910c8,0x00000000}},	// [1630] ssze_, æven, rgad_,
  { {0xdb510021,0x2d910051,0xbb840021,0x00000000}},	//   ذَا_, psze_, سلمي,
  { {0x291d0009,0x7d03000c,0x6128005b,0x00000000}},	//   tiwa_, _înso, zılm,
  { {0x6128005b,0xe8940086,0x628a00ea,0x00000000}},	//   yılm, заць, _lefo,
  { {0x291d113e,0x69dc114a,0x6298114b,0x00000000}},	//   riwa_, _erre, _odvo,
  { {0x7d0d03e8,0x291d114c,0x6b5000c7,0x00000000}},	//   lhas, siwa_, vägg,
  { {0xdb0d0025,0x291d0035,0x24e9114d,0x00000000}},	//   ntaí, piwa_, имки_,
  { {0x612801f7,0xa835005e,0x6298114e,0x00000000}},	//   tılm, _дебљ, _advo,
  { {0x628a114f,0x13090d82,0x248d00be,0x00000000}},	//   _befo, иний_, raem_,
  { {0x6128005b,0xe29900e1,0x69ce1150,0x00000000}},	//   rılm, јан_, _ysbe,
  { {0x60c6001c,0x6d44001f,0x90c6015a,0x00000000}},	//   tekm, ylia, обне,
  { {0x612801f7,0x7bcf1151,0x320b0051,0x00000000}},	//   pılm, _oscu, ący_,
  { {0x7529000c,0x60c6005b,0x6b500502,0x00000000}},	//   mnez, rekm, läge,
  { {0x26c710ca,0x6d44001f,0x628a1152,0x00000000}},	//   neno_, wlia, _gefo,
  { {0x7bcf000c,0x7529003b,0x62811153,0x00000000}},	//   _ascu, onez, mblo,
  { {0x26c71154,0x62811155,0x7d0d1156,0x00000000}},	//   heno_, lblo, ghas,
  { {0x6d441157,0x62811158,0x8c431159,0x00000000}},	// [1640] rlia, oblo, дете,
  { {0x98ad0024,0x26c7115a,0x0ae70062,0x00000000}},	//   _cieľ_, jeno_, одуй_,
  { {0x7bcf094c,0x26c7115b,0x6d44115c,0x00000000}},	//   _escu, deno_, plia,
  { {0x31ba0047,0xdb040025,0x7d0d115d,0x00000000}},	//   יזענ, ntiú, chas,
  { {0x6281115e,0xdb040139,0xa6ca0074,0x00000000}},	//   kblo, itiú, илда_,
  { {0x7d04024a,0x26c7115f,0x75291160,0x00000000}},	//   lkis, geno_, enez,
  { {0x62811161,0xb0aa0053,0x69ce1162,0x00000000}},	//   dblo, _कांग, _usbe,
  { {0x888607b0,0x62811163,0x7d041164,0x00000000}},	//   _флаж, eblo, nkis,
  { {0x26c70def,0x39461165,0xd94302d8,0x00000000}},	//   beno_, mlos_, _цети,
  { {0x39461166,0x7d0d00ea,0x20d70013,0x00000000}},	//   llos_, zhas, _ủi_,
  { {0xfd4d008b,0xdb040331,0xa1740085,0x00000000}},	//   ghiệ, guié, ягні,
  { {0x3946004d,0x10740054,0x38600130,0x00000000}},	//   nlos_, млюю, žiru_,
  { {0x39461167,0x645d0078,0x68e40072,0x00000000}},	//   ilos_, žsir, öidy,
  { {0xf1a61168,0xdb040003,0x7d040072,0x00000000}},	//   _дрин, quiè, ekis,
  { {0x61fc00c7,0x98af0006,0xc27b0047,0x00000000}},	//   ärld, logą_, _דרוי,
  { {0xdb040027,0x459b0047,0x26c70be1,0x00000000}},	//   ctiú, יסלע, zeno_,
  { {0x7d0d1169,0xdb0d0025,0x3946004d,0x00000000}},	// [1650] rhas, staí, dlos_,
  { {0x39460b23,0x657a00ea,0x7d04116a,0x00000000}},	//   elos_, _otth, akis,
  { {0x7d0d116b,0x3946004d,0xceb203c3,0x00000000}},	//   phas, flos_, _איי_,
  { {0x3946116c,0xcdda00b5,0xed58000a,0x00000000}},	//   glos_, _פֿיר, _моќ_,
  { {0x60dc00b5,0x69d80137,0x66e50062,0x00000000}},	//   יקאנ, åver, зола,
  { {0x3946116d,0x26c70331,0xff7c07e9,0x00000000}},	//   alos_, ueno_, סטומ,
  { {0x3946116e,0x26c7116f,0xa5f6005e,0x00000000}},	//   blos_, reno_, зеју_,
  { {0x6b5000bd,0x613600ea,0xcdaa0047,0x00000000}},	//   räge, bály, ציפֿ,
  { {0x6b500137,0x62810109,0x657a04aa,0x00000000}},	//   säge, tblo, _etth,
  { {0x753b0080,0x1309014c,0x7d04009c,0x00000000}},	//   souz, сной_, zkis,
  { {0x753b007c,0xcb120063,0x7d040246,0x00000000}},	//   pouz, גלי_, ykis,
  { {0x62811170,0xbcfb0331,0x3d050042,0x00000000}},	//   sblo, _sién, रसों_,
  { {0xb4d70053,0x62811171,0x7fd50054,0x00000000}},	//   ायी_, pblo, мірі,
  { {0x3f9e016b,0x3ebe0026,0x61280058,0x00000000}},	//   čtu_, ýtt_, zılh,
  { {0x63a91172,0xdb040164,0xbcfb006d,0x00000000}},	//   luen, quié, _vién,
  { {0xa01b0026,0x25710026,0x61fc01bb,0x00000000}},	//   mbön, _mál_, ärle,
  { {0x7d040bcf,0xfbdf017d,0x63a90399,0x00000000}},	// [1660] rkis, _crê_, nuen,
  { {0xe8160161,0xa3dc0042,0x7d041173,0x00000000}},	//   _देगा_, डित_, skis,
  { {0x257100ea,0x3946004d,0x7d040058,0x00000000}},	//   _nál_, tlos_, pkis,
  { {0x63a9028d,0x39460d90,0x57ea0456,0x00000000}},	//   kuen, ulos_, йдем_,
  { {0x2efa00bd,0x39461174,0xdcf7000c,0x00000000}},	//   _kopf_, rlos_, şcăr,
  { {0xc58a0121,0x39461175,0x60d600e5,0x00000000}},	//   бщие_, slos_, _laym,
  { {0x3946039f,0x5554005d,0x7d15013d,0x00000000}},	//   plos_, وپتر, _ügsé,
  { {0xd3a60086,0x25710080,0x63a90331,0x00000000}},	//   проп, _dál_, fuen,
  { {0x63a902f6,0x07a3000a,0x94730021,0x00000000}},	//   guen, _патн, رديا,
  { {0xa3ab0053,0x957c0022,0xa3180054,0x00000000}},	//   गढ़_, _prąd, іжну_,
  { {0xbcfb0003,0x645d0078,0x29060050,0x00000000}},	//   _biél, žsip, okoa_,
  { {0x63a91176,0x29060072,0x60d61177,0x00000000}},	//   buen, nkoa_, _caym,
  { {0x63a9048e,0x5f94011c,0xdbf1004c,0x00000000}},	//   cuen, ният, tříc,
  { {0x6b960618,0x2efa009c,0x41730043,0x00000000}},	//   dsyg, _copf_, بایس,
  { {0x290600fe,0x2d9e027c,0xb2bb0063,0x00000000}},	//   kkoa_, šten_, _המור,
  { {0x6144000a,0x645d0014,0x5cb90085,0x00000000}},	//   _пеја, ýsig, ўлаў_,
  { {0xa3d50053,0xdb990054,0xec3402fa,0x00000000}},	// [1670] हिए_, ювач_, енть,
  { {0x7bcd002b,0x2bb80044,0x00000000,0x00000000}},	//   rwau, ثافة_,   ,
  { {0x60d60058,0x5d55080b,0x66f00082,0x00000000}},	//   _yaym, _окот, चानक_,
  { {0x5fb10042,0x25e00042,0x6d88009a,0x00000000}},	//   _जमाल, किनी_, _מָשְ,
  { {0xd7f8005e,0x98f40021,0x78a4013d,0x00000000}},	//   зуј_, عثما, óiva,
  { {0x85790076,0x257100ea,0xd00c0063,0x00000000}},	//   осит_, _pál_, מּוֹ,
  { {0x69da0198,0x20020051,0x28a70085,0x00000000}},	//   _štev, zyki_, _ншаг,
  { {0x6b4b00bd,0xb4d70053,0x2907008f,0x00000000}},	//   zügl, ाये_, īnas_,
  { {0x2f0f00bd,0x68e91178,0x2be00053,0x00000000}},	//   _züge_, _ined, निया,
  { {0x68fb02b0,0xdddc0006,0x68e90066,0x00000000}},	//   _houd, varž, _hned,
  { {0x67231179,0x60d6117a,0x68fb117b,0x00000000}},	//   minj, _paym, _koud,
  { {0x6723117c,0x20020051,0x68fb0072,0x00000000}},	//   linj, tyki_, _joud,
  { {0x212200e3,0x68fb117d,0x63a9117e,0x00000000}},	//   rikh_, _moud, quen,
  { {0x6723117f,0x7f19000d,0x20020051,0x00000000}},	//   ninj, пісу_, ryki_,
  { {0x68e90024,0x6e430d34,0xdd1c004a,0x00000000}},	//   _oned, верз, _vážn,
  { {0xdb0d00bd,0x7bc3000c,0x6723082a,0x00000000}},	//   traß, ănun, hinj,
  { {0x6723082a,0xe3b900ea,0x2f560121,0x00000000}},	// [1680] kinj, ntű_, _отос,
  { {0x68e91180,0x290d003b,0x6b9601e1,0x00000000}},	//   _aned, _alea_, rsyg,
  { {0x67231181,0x3ebe0019,0x29060072,0x00000000}},	//   dinj, õttu_, tkoa_,
  { {0x66030051,0x58ba0021,0x07a6000d,0x00000000}},	//   dynk, تائج_, дадн,
  { {0x4c360088,0x67231182,0x29060072,0x00000000}},	//   _цэнт, finj, rkoa_,
  { {0x8f890063,0xdddc0051,0x68e9057c,0x00000000}},	//   פְנֵ, karż, _ened,
  { {0xd5af005a,0x68fb1183,0x66e3007b,0x00000000}},	//   ъс_, _foud, тоја,
  { {0x68fb1184,0x25a00fff,0x88c60021,0x00000000}},	//   _goud, čil_, _تتسل,
  { {0x7afc1185,0x644e0051,0x67231186,0x00000000}},	//   _kort, ębio, binj,
  { {0x68fb0122,0x6723007d,0x3944004e,0x00000000}},	//   _zoud, cinj, _hkms_,
  { {0x2d9e0080,0x36060242,0x7afc0e5c,0x00000000}},	//   átel_, _تواف, _mort,
  { {0xbcfb0003,0x957c0022,0xe5060044,0x00000000}},	//   _piém, _trąb, _تبطي,
  { {0x7afc00e8,0xd467005e,0x2d9e0077,0x00000000}},	//   _oort, _жице_, štel_,
  { {0x7afc095b,0x15f20082,0xa6f8009a,0x00000000}},	//   _nort, _अपार_, הִֽי,
  { {0xccfb0001,0x64550051,0xdb0d017d,0x00000000}},	//   оћа_, ęzie, ltaç,
  { {0x6b5000c7,0xdb04006f,0xa115007e,0x00000000}},	//   väga, brië, _سوخت,
  { {0xdb0d03d9,0x7afc1187,0x66030022,0x00000000}},	// [1690] ntaç, _bort, zynk,
  { {0x68fb1188,0xdb0d017d,0x7afc1189,0x00000000}},	//   _soud, itaç, _cort,
  { {0x68fb118a,0x6723074f,0x7afc118b,0x00000000}},	//   _poud, vinj, _dort,
  { {0x2d83006f,0x08d40054,0xe7f30042,0x00000000}},	//   mpje_, кція, _आपदा_,
  { {0x68fb0164,0x26170053,0x6723118c,0x00000000}},	//   _voud, _भेजी_, tinj,
  { {0x68fb006f,0x6b500137,0x7afc118d,0x00000000}},	//   _woud, lägn, _gort,
  { {0xe81f0053,0x6723118e,0x7648001f,0x00000000}},	//   _मेरा_, rinj, _cydy,
  { {0x68e9035a,0x7648001f,0x6128005b,0x00000000}},	//   _uned, _dydy, nılt,
  { {0x3735000d,0x386d118f,0x67231190,0x00000000}},	//   _знаё, _iger_, pinj,
  { {0xcb1200b5,0xf7720063,0xfbd20063,0x00000000}},	//   ָלט_, _עקב_, נתי_,
  { {0x03220088,0x3f990026,0x7d0f013d,0x00000000}},	//   удэн, essu_, _olcs,
  { {0xdb04006f,0xe8df0013,0x2d9e004c,0x00000000}},	//   trië, _khốn_, átem_,
  { {0x13f4005a,0x6d5a00cd,0x2d83006f,0x00000000}},	//   _изця, ïtam, epje_,
  { {0x2d9e007d,0xdb04006f,0x61ee0139,0x00000000}},	//   štem_, rrië, óilí,
  { {0x2f1401e3,0x63bb1191,0x2d8c0164,0x00000000}},	//   _lägg_, ltun, ède_,
  { {0xc5f200b5,0x386d0137,0x7afc1192,0x00000000}},	//   נדן_, _nger_, _sort,
  { {0x63bb1193,0x7afc1194,0xe81f0042,0x00000000}},	// [16a0] ntun, _port, _मेला_,
  { {0x63bb1195,0x7fd70063,0x7d0f013d,0x00000000}},	//   itun, _טופס_, _elcs,
  { {0x7afc07c7,0xfd4a0062,0xfbdf0013,0x00000000}},	//   _vort, _нзок_, _uyên_,
  { {0x76480185,0x7afc0359,0xb17a0047,0x00000000}},	//   _rydy, _wort, לטער,
  { {0x7afc057a,0x3913007e,0x6d461196,0x00000000}},	//   _tort, دونز, _ikka,
  { {0x98c5001c,0x6b841197,0xcf930063,0x00000000}},	//   ītās_, mpig, נטו_,
  { {0xceb30149,0xdb040003,0x60c4007d,0x00000000}},	//   טיג_, vriè, _obim,
  { {0x63bb00bd,0x1543007b,0x95c3005d,0x00000000}},	//   ftun, лејм, اييه,
  { {0xd4e30055,0xdb040164,0x63bb1198,0x00000000}},	//   ующи, triè, gtun,
  { {0xdb0d0016,0x0bb70063,0x6b840c55,0x00000000}},	//   rtaç, עלים_, ipig,
  { {0x6d46007a,0xdb040164,0xdb0d0016,0x00000000}},	//   _okka, rriè, staç,
  { {0xdb0d017d,0x76440075,0xf946014b,0x00000000}},	//   ptaç, ğiyd, мнiк_,
  { {0xa01b013d,0x76440075,0x389b009a,0x00000000}},	//   mbök, şiyd, היכנ,
  { {0x5453019d,0x32050080,0xc2c40049,0x00000000}},	//   _світ, byly_, _شيعي,
  { {0x7c870001,0xac950f63,0x0dc81199,0x00000000}},	//   еузе, кавш, нути_,
  { {0x2d83006f,0x38690734,0x22620022,0x00000000}},	//   rpje_, žari_, ęskę_,
  { {0x6b8400a4,0x8aa70928,0xfaa70f34,0x00000000}},	// [16b0] gpig, еред, ешен,
  { {0x2fc900a4,0x60dd119a,0x69d5119b,0x00000000}},	//   _ipag_, ldsm, _psze,
  { {0x6b84119c,0xf9930242,0x798e002b,0x00000000}},	//   apig, ابط_, _cwbw,
  { {0x2fc900a4,0x7d0f00ea,0xd23b0063,0x00000000}},	//   _kpag_, _ulcs, הגבל,
  { {0xb8c90161,0x69d50045,0x9e67007e,0x00000000}},	//   _गए_, _wsze, _تاکن,
  { {0x6d4d0d9e,0x2f140137,0x66b20002,0x00000000}},	//   llaa, _vägg_, абљу,
  { {0x798e001f,0x6d460026,0x05a90054,0x00000000}},	//   _gwbw, _ykka, євий_,
  { {0x386d0146,0x60dd00b9,0x6d4d119d,0x00000000}},	//   _uger_, jdsm, nlaa,
  { {0x7d03000c,0x63bb051a,0xdcfc001c,0x00000000}},	//   _însu, utun, nprā,
  { {0x75220290,0x613d10fd,0x6b4b004d,0x00000000}},	//   _emoz, mély, fügi,
  { {0x6d4d0004,0x2fc9002c,0x63bb119e,0x00000000}},	//   klaa, _apag_, stun,
  { {0xbcfb017d,0x6d5a0006,0x63bb119f,0x00000000}},	//   _fiéi, įtak, ptun,
  { {0x2f140cbf,0x6b8401db,0x889a0063,0x00000000}},	//   _läge_, xpig, וברי,
  { {0xdb0403b2,0x656b11a0,0x6d4d11a1,0x00000000}},	//   prié, _high, elaa,
  { {0x7e230001,0x6d4d0072,0x644b11a2,0x00000000}},	//   адрж, flaa, _hygi,
  { {0x657c00ea,0x63a911a3,0x6d4d11a4,0x00000000}},	//   _érhe, oren, glaa,
  { {0x656b0037,0x63a911a5,0x765c0061,0x00000000}},	// [16c0] _migh, nren, _úryv,
  { {0x656b0034,0x613d00ea,0x63a911a6,0x00000000}},	//   _ligh, dély, iren,
  { {0xdb1d0146,0x63a909f8,0x644b00eb,0x00000000}},	//   _opsæ, hren, _lygi,
  { {0x656b0034,0x6b8411a7,0xdcfc001c,0x00000000}},	//   _nigh, ppig, bprā,
  { {0xab660051,0x63a911a8,0x6843066e,0x00000000}},	//   _pożą, jren, анца,
  { {0xfaa60121,0x501b0063,0x6d44003b,0x00000000}},	//   _шаго, וונו, loia,
  { {0xdb0402dd,0x63a911a9,0xe8df008d,0x00000000}},	//   stió, eren, _chồn_,
  { {0x6d4401f4,0x7d03003b,0x7d16002b,0x00000000}},	//   noia, _înst, nhys,
  { {0x63a911aa,0x656b01f4,0xd8770044,0x00000000}},	//   gren, _digh, _شملت_,
  { {0x656b0034,0x86ea0021,0x51f80086,0x00000000}},	//   _eigh, _تعرف_, еною_,
  { {0x656b0034,0x63a911ab,0xe80e0042,0x00000000}},	//   _figh, aren, ़ैरा_,
  { {0x94260055,0x452a0062,0x63a911ac,0x00000000}},	//   _имее, _южен_, bren,
  { {0x6d4411ad,0x60dd11ae,0x63a911af,0x00000000}},	//   doia, rdsm, cren,
  { {0x9f600026,0x7d160072,0xdb25013d,0x00000000}},	//   ærðu_, ehys, épül,
  { {0x6d4d11b0,0xce940062,0x6b500e77,0x00000000}},	//   tlaa, расъ, rägl,
  { {0x1bd50062,0x7d16002b,0x2d580505,0x00000000}},	//   лобя, ghys, вись_,
  { {0xdc5501aa,0x6d4d0250,0xfbd00021,0x00000000}},	// [16d0] увањ, rlaa, يتك_,
  { {0x6d4d0a53,0xf1b60053,0xab28005e,0x00000000}},	//   slaa, _अमान, вођа_,
  { {0x6d4d11b1,0x2578013d,0x38bd013d,0x00000000}},	//   plaa, _nél_, járó_,
  { {0xe0df051e,0x6d4401a8,0x63a911b2,0x00000000}},	//   ndò_, coia, yren,
  { {0x656b11b3,0xfd5611b4,0x7d0d11b5,0x00000000}},	//   _righ, _תשרי_, mkas,
  { {0x656b11b6,0xe8df0013,0x63a911b7,0x00000000}},	//   _sigh, _phồn_, vren,
  { {0x257800ea,0x1994000d,0x7d0d11b8,0x00000000}},	//   _cél_, _вася, okas,
  { {0x63a911b9,0x257811ba,0x693c007d,0x00000000}},	//   tren, _dél_, včeg,
  { {0x63a911bb,0xbcfb006c,0x7d0d11bc,0x00000000}},	//   uren, _fiév, ikas,
  { {0xe1f90055,0x257800ea,0x63a909b7,0x00000000}},	//   его_, _fél_, rren,
  { {0x7d0d11bd,0x656b11be,0x9afa0063,0x00000000}},	//   kkas, _tigh, תפתח,
  { {0x7fb6000d,0x63a90399,0x656b11bf,0x00000000}},	//   лёгі, pren, _uigh,
  { {0x7d0d11c0,0x6d4400dd,0x03a50133,0x00000000}},	//   dkas, voia, _сило,
  { {0x7d0d11c1,0xfd65008d,0x752911c2,0x00000000}},	//   ekas, _truồ, liez,
  { {0x7d0d11c3,0xdb04017d,0xdd1d004c,0x00000000}},	//   fkas, luiç, lářs,
  { {0x9f4000cd,0x7d0d11c4,0x7e7c007d,0x00000000}},	//   _triï_, gkas, scrp,
  { {0x38bd00ea,0xdb04017d,0xdd1d004c,0x00000000}},	// [16e0] záró_, nuiç, nářs,
  { {0x7d0d11c5,0x8a3a0076,0x945d0051,0x00000000}},	//   akas, няет_, leńs,
  { {0x8886005a,0xb05b004d,0x5d6a0002,0x00000000}},	//   глеж, nfän, _пиом_,
  { {0x7aeb001c,0xb866005d,0x7d0d11c6,0x00000000}},	//   ēgta, هاشو, ckas,
  { {0xa3d20053,0xdd1d0080,0x7529003b,0x00000000}},	//   _हैं_, jářs, diez,
  { {0xdd1d0080,0x05b40021,0x6b4b087d,0x00000000}},	//   dářs, لمتح, fügu,
  { {0x645d0ac6,0xceb3014e,0xe5c611c7,0x00000000}},	//   ýsin, ציה_, усло,
  { {0x25780014,0x61fc00a5,0x7c29017c,0x00000000}},	//   _vél_, ärlm, _žeri,
  { {0xdb04017d,0x2578006f,0x28dd0053,0x00000000}},	//   guiç, _wél_, _नोटि,
  { {0x9bbb00b5,0x394611c8,0x20e1008d,0x00000000}},	//   עציפ, loos_, _ỗi_,
  { {0xaac60161,0xd250006a,0x7bc3003b,0x00000000}},	//   र्यक, تند_, ănui,
  { {0xdb040016,0xd257000d,0x752911c9,0x00000000}},	//   buiç, ыцы_, ciez,
  { {0xa3b30161,0xe0df0290,0x7d0d11ca,0x00000000}},	//   जूद_, rdò_, vkas,
  { {0x26de11cb,0x3dda004d,0x1ee7005d,0x00000000}},	//   _jato_, _bspw_, دوسی_,
  { {0xc27b00b5,0x7d0d11cc,0xb352008d,0x00000000}},	//   _ארוי, tkas, củab,
  { {0x26de11cd,0xf1a90161,0x629a0d11,0x00000000}},	//   _lato_, _कितन, lato,
  { {0x7d0d11ce,0x394611cf,0x2aab005e,0x00000000}},	// [16f0] rkas, doos_, етео_,
  { {0x212b0199,0x6eb20053,0x7d0d11d0,0x00000000}},	//   lich_, _जाएँ, skas,
  { {0x6907000d,0x7d0d11d1,0x212b0022,0x00000000}},	//   лядз, pkas, oich_,
  { {0x629a11d2,0x212b11d3,0xdb040046,0x00000000}},	//   hato, nich_, stið,
  { {0x6b4b004d,0x6d5d11d4,0xab5b01a8,0x00000000}},	//   fügt, _ihsa, _aqüe,
  { {0x212b0037,0x7ceb00c7,0x945d0051,0x00000000}},	//   hich_, _förä, zeńs,
  { {0x212b0045,0x629a11d5,0x9f440080,0x00000000}},	//   kich_, dato, ímé_,
  { {0xdb040016,0x212b016b,0xa5f6005e,0x00000000}},	//   tuiç, jich_, рећу_,
  { {0x26de0016,0x7529001c,0xab5b01a8,0x00000000}},	//   _fato_, riez, _eqüe,
  { {0xa1c50088,0x13090076,0xdb040016,0x00000000}},	//   абод, тной_, ruiç,
  { {0x752911d6,0xcb140063,0x2745004c,0x00000000}},	//   piez, מלץ_, ríně_,
  { {0x9567011c,0x26de11d7,0x212b0051,0x00000000}},	//   _създ, _zato_, gich_,
  { {0x248d017d,0x6446004b,0x629a11d8,0x00000000}},	//   mbem_, ükit, bato,
  { {0x6d5d0035,0xb05b11d9,0x629a071d,0x00000000}},	//   _ahsa, pfän, cato,
  { {0xb05b089f,0x7c9611da,0xde0311db,0x00000000}},	//   lfäl, ирац, опри,
  { {0x212b034d,0xdb0400fe,0x3f8d003b,0x00000000}},	//   cich_, ntiö, ţeua_,
  { {0xb05b00bd,0x998d007d,0x6b50004d,0x00000000}},	// [1700] nfäl, _ćeš_, lägi,
  { {0x305b0063,0x9f9b0063,0xdb040072,0x00000000}},	//   _בדפד, _שסיפ, htiö,
  { {0xbcfb0003,0x26de11dc,0x693c00a8,0x00000000}},	//   _piét, _rato_, jčec,
  { {0xb05b00c7,0xe7860086,0x629a11dd,0x00000000}},	//   kfäl, ауко, zato,
  { {0x26de11de,0x87ba0121,0xa81a0049,0x00000000}},	//   _pato_, тует_, ختار_,
  { {0x248d00cd,0xc986007e,0xb5a600a0,0x00000000}},	//   ebem_, _نشري, арий,
  { {0xb05b0244,0x629a11df,0x96f70044,0x00000000}},	//   efäl, vato, شعور_,
  { {0xbcfb0003,0xd94305c5,0xdb04017d,0x00000000}},	//   _hiér, _деси, briã,
  { {0x5397000d,0xbcfb00ea,0x26de11e0,0x00000000}},	//   авыя_, _kiér, _tato_,
  { {0x68e011e1,0xe5a60054,0x68e2004b,0x00000000}},	//   _hamd, _вижи, ldod,
  { {0xd25a005a,0x290411e2,0x212b11e3,0x00000000}},	//   ъци_, _koma_, tich_,
  { {0x64460019,0x2d570058,0xddd40022,0x00000000}},	//   ükis, eçen_, łaśn,
  { {0x2f1400c7,0x212b11e4,0xa3dc0053,0x00000000}},	//   _säga_, rich_, डिओ_,
  { {0x69dc00c3,0x69ce11e5,0x23270002,0x00000000}},	//   _osre, _opbe, _кочи_,
  { {0x4d27000a,0x2d8503a8,0x70950062,0x00000000}},	//   аќаа, ële_, _лайф,
  { {0x2f140004,0x5c7511e6,0x68e000d1,0x00000000}},	//   _väga_, слат, _namd,
  { {0x68e20185,0xa3dc0161,0xfc670062,0x00000000}},	// [1710] ddod, डिट_, ръвн,
  { {0xf1da0053,0xbcfb0331,0x4ea70cd6,0x00000000}},	//   _बनान, _ciér, _триа,
  { {0x3f8b00c3,0xf8750021,0xceb20041,0x00000000}},	//   lpcu_, مهاج, _ציט_,
  { {0x32370047,0xc879005b,0x68e011e7,0x00000000}},	//   סטאן_, _başa_, _camd,
  { {0x27e902dd,0x68e0002c,0x6298006f,0x00000000}},	//   ían_, _damd, _oevo,
  { {0x62980f6f,0xc7240086,0x7bdd11e8,0x00000000}},	//   _nevo, одій, _issu,
  { {0xe7f30053,0x63a211e9,0x27e6004d,0x00000000}},	//   _आपका_, _avon, avon_,
  { {0xce380063,0x68e0001f,0x290407a8,0x00000000}},	//   יאות_, _gamd, _goma_,
  { {0xa3d20053,0xb815005e,0xd7e40054,0x00000000}},	//   हौल_, _удај, _міфо,
  { {0xf7700032,0xb05b0832,0x63a200a8,0x00000000}},	//   _قال_, rfäl, _dvon,
  { {0x7c3b007a,0xb05b0502,0x321101d9,0x00000000}},	//   _þurf, sfäl, ázy_,
  { {0x80fa0002,0x628e0014,0x68f9009a,0x00000000}},	//   ухот_, ðbor, אלֹה,
  { {0x43850032,0x63850001,0x61ea00f5,0x00000000}},	//   _التق, _угла, _erfl,
  { {0x62980102,0x68e20c39,0x8e8311ea,0x00000000}},	//   _gevo, zdod, згре,
  { {0x321e0051,0x9f40017d,0x7bdd11eb,0x00000000}},	//   czty_, _criá_, _assu,
  { {0x31a301f7,0x614311ec,0x628111ed,0x00000000}},	//   mız_, _неща, lclo,
  { {0xed570079,0x290411ee,0x3f5601e1,0x00000000}},	// [1720] сот_, _roma_, læum_,
  { {0x29040009,0x68e011ef,0x7ed50086,0x00000000}},	//   _soma_, _samd, _діюч,
  { {0x31a304ab,0xe0df0268,0xea5a0002,0x00000000}},	//   nız_, clòs_, урај_,
  { {0xa9670062,0xc87911f0,0x61fc092e,0x00000000}},	//   биха_, _paşa_, ärli,
  { {0xe1e7007e,0x68e211f1,0x765a0022,0x00000000}},	//   _کس_, rdod, _szty,
  { {0x27e611f2,0x47330054,0xa0570041,0x00000000}},	//   rvon_, пніс, זױנס_,
  { {0x290411f3,0x69dc017f,0x76a90086,0x00000000}},	//   _toma_, _usre, ртів_,
  { {0x25610026,0x7644005b,0x31a30058,0x00000000}},	//   hólf_, şiyo, dız_,
  { {0x7d060006,0x2613008b,0x97bd0500,0x00000000}},	//   _moks, ạo_, _архi,
  { {0x31a30058,0x7d0611f4,0x8c1b009a,0x00000000}},	//   fız_, _loks, טופי,
  { {0x14ca0055,0x60f90fd9,0x2d9e11f5,0x00000000}},	//   _были_, ання_, âtel_,
  { {0x7d0611f6,0x056611f7,0x320c0022,0x00000000}},	//   _noks, _увен, rydy_,
  { {0x657a0035,0x321e0051,0x62980229,0x00000000}},	//   _huth, szty_, _tevo,
  { {0x657a0474,0x543b0047,0x98bd0051,0x00000000}},	//   _kuth, _געדא, mową_,
  { {0x7d0611f8,0x98bd0051,0x91860242,0x00000000}},	//   _boks, lową_, _اجتم,
  { {0xf2370063,0xdb160072,0x5d5501dd,0x00000000}},	//   _לרוץ_, htyä, ікат,
  { {0xba990086,0x657a11f9,0x2d9e11fa,0x00000000}},	// [1730] иває_, _luth, áter_,
  { {0x9f530051,0x6d5a00ca,0xdb04013d,0x00000000}},	//   ądów_, ïtar, triá,
  { {0xc27b00b5,0x7bc400cd,0xdb0d0014,0x00000000}},	//   ארבי, atiu, ptaþ,
  { {0x7644005b,0x98bd0051,0x35c20042,0x00000000}},	//   ğiyl, kową_, _शहज़,
  { {0x7bc411fb,0x2b93007e,0x657a081b,0x00000000}},	//   ctiu, _ریاس, _auth,
  { {0x8f9c0047,0xdb16008b,0x31a3005b,0x00000000}},	//   ריגי, huyê, yız_,
  { {0x395f0037,0x7d06005b,0x6b8d0f89,0x00000000}},	//   _thus_, _yoks, lpag,
  { {0x2a7b0006,0x69c511fc,0xb38511fd,0x00000000}},	//   šybą_, mthe, олил,
  { {0x6b8d0122,0x693c00c2,0x657a11fe,0x00000000}},	//   npag, očen, _euth,
  { {0xf1c30080,0x6b8d11ff,0xe2990001,0x00000000}},	//   _naší_, ipag, шао_,
  { {0x3f89014f,0x657a1200,0x69c51201,0x00000000}},	//   _atau_, _guth, nthe,
  { {0xe56e019d,0x6b8d0122,0x69c51202,0x00000000}},	//   _із_, kpag, ithe,
  { {0x31a3005b,0xb05b004d,0x69c5030c,0x00000000}},	//   sız_, nfäh, hthe,
  { {0x6b8d006f,0x60cd0019,0x69c51203,0x00000000}},	//   dpag, _ebam, kthe,
  { {0xec9a00d7,0x693c0240,0x6b8d1204,0x00000000}},	//   итај_, dčen, epag,
  { {0xa01b01bb,0x69c51205,0x7bc41206,0x00000000}},	//   rbör, dthe, ttiu,
  { {0x7d0602ab,0x6b8d1207,0x69c51208,0x00000000}},	// [1740] _voks, gpag, ethe,
  { {0x78a91209,0xdb04017d,0xab5b004d,0x00000000}},	//   _adev, iriç, _spür,
  { {0x69c5120a,0x6b8d002c,0x7bc4120b,0x00000000}},	//   gthe, apag, stiu,
  { {0x6b8d120c,0x7bc4120d,0x693c00c2,0x00000000}},	//   bpag, ptiu, ačen,
  { {0x2ca00eef,0xdb1600fe,0x69c5120e,0x00000000}},	//   maid_, ttyä, athe,
  { {0x291d00f3,0x69c5004d,0x2ca0120f,0x00000000}},	//   ahwa_, bthe, laid_,
  { {0x27ed1210,0xd5b00021,0x69c500ca,0x00000000}},	//   _eren_, رفة_, cthe,
  { {0x291d0009,0xa5070001,0x98bd0051,0x00000000}},	//   chwa_, жећа_, tową_,
  { {0xdddc007d,0x27ed0a3f,0xb05b00a5,0x00000000}},	//   jbrž, _gren_, rfäk,
  { {0xbcfb0025,0x2ca00123,0x657a1211,0x00000000}},	//   _mhéa, haid_, _tuth,
  { {0x6603000a,0xdcfc0006,0x2ca00019,0x00000000}},	//   _опфа, sprę, kaid_,
  { {0x2ca01212,0x612b1213,0x98bd0022,0x00000000}},	//   jaid_, рцог_, pową_,
  { {0xdb040016,0xada20024,0x5f94005a,0x00000000}},	//   criç, _šúpl, мият,
  { {0xa3d70053,0xadbd0085,0x69c51214,0x00000000}},	//   ाबर_, лагi, ythe,
  { {0xf1c302f4,0x2ca0001f,0xdb0d0003,0x00000000}},	//   _vaší_, faid_, fraî,
  { {0xbcfb0025,0x6b8d006f,0xccf80001,0x00000000}},	//   _bhéa, tpag, оћу_,
  { {0xbcfb0027,0x0ca8005a,0x693c0080,0x00000000}},	// [1750] _chéa, ютри_, tčen,
  { {0xbcfb0027,0x6b8d1215,0x693c0be1,0x00000000}},	//   _dhéa, rpag, učen,
  { {0x6b8d0122,0x291d00ac,0x69c80137,0x00000000}},	//   spag, thwa_, _ädel,
  { {0xbcfb0025,0x27ed1216,0x69c51217,0x00000000}},	//   _fhéa, _pren_, rthe,
  { {0x6cfa014e,0x6d4d0923,0x69c51218,0x00000000}},	//   _הפרס, moaa, sthe,
  { {0x291d10ca,0xb05b004d,0x5a47000d,0x00000000}},	//   shwa_, rfäh, _дэба,
  { {0xb05b00bd,0x693c007d,0x27ed1219,0x00000000}},	//   sfäh, očel, _wren_,
  { {0xd4d9019d,0xdb04017d,0x27ed121a,0x00000000}},	//   ські_, triç, _tren_,
  { {0x249f121b,0x27ed0122,0xe3b10021,0x00000000}},	//   raum_, _uren_, ررة_,
  { {0x6b500137,0xb2250f8d,0x20e8008d,0x00000000}},	//   lägr, змол, _ởi_,
  { {0xdb0d02dd,0x06760047,0x25710130,0x00000000}},	//   ntañ, _זײער_, _ušlo_,
  { {0xdb0d0250,0x6908009a,0x00000000,0x00000000}},	//   kraï, ַּרְ,   ,
  { {0x2ca00004,0x645d0019,0x2458000d,0x00000000}},	//   vaid_, üsid, _даць_,
  { {0x656900bd,0xdb1c121c,0x693c08b7,0x00000000}},	//   lmeh, özün, ečel,
  { {0xdb0d0164,0xbcfb0025,0x2ca0121d,0x00000000}},	//   traî, _shéa, taid_,
  { {0x6d4d00a4,0x6569004d,0x3b8608a7,0x00000000}},	//   goaa, nmeh, злаг,
  { {0x65690035,0x1d07121e,0x2ca0121f,0x00000000}},	// [1760] imeh, чети_, raid_,
  { {0x6b5000c7,0x693c02f7,0x98bd0022,0x00000000}},	//   vägs, ačel, mowę_,
  { {0x1e970063,0x2ca01220,0xdb0d003b,0x00000000}},	//   _מכיל_, paid_, praî,
  { {0xbcfb0027,0xa9670062,0xdb0d10a1,0x00000000}},	//   _théa, пиха_, braï,
  { {0xdb0400e8,0x48790054,0x61e6008f,0x00000000}},	//   nsië, ісця_, ākli,
  { {0x7d040031,0xdbc70019,0x96ba02fe,0x00000000}},	//   ljis, tööt, суду_,
  { {0xdb0400c7,0x9f4000ac,0xd5af000d,0x00000000}},	//   rriä, _asië_, эс_,
  { {0xdce4017f,0x7d160006,0x27f7004c,0x00000000}},	//   kmič, nkys, ádný_,
  { {0xdb0d0026,0xd9430336,0x7c241221,0x00000000}},	//   otað, _чети, nzir,
  { {0x65690024,0xdb0d0026,0x98bd0051,0x00000000}},	//   ameh, ntað, dowę_,
  { {0x656200f3,0x86750088,0xdb0d0014,0x00000000}},	//   _thoh, _жыцц, itað,
  { {0x2d57005b,0x7aeb008f,0xaa370149,0x00000000}},	//   rçek_, ēgti, לטיק_,
  { {0x50640138,0xdb0400ac,0xdb0d0014,0x00000000}},	//   етра, rsiê, ktað,
  { {0x7c2402e2,0x941e0058,0xbcfb1222,0x00000000}},	//   dzir, ığıy, _chén,
  { {0x9f44004c,0x7d040014,0x7e440074,0x00000000}},	//   ímá_, fjis, ехте,
  { {0x693c017f,0x91bb0063,0xd23b009a,0x00000000}},	//   učel, _המהי, _לגול,
  { {0xdb0d017d,0x7f840021,0x6f01013d,0x00000000}},	// [1770] nuaç, _كلين, ölcs,
  { {0xdb0d00cd,0x501c0063,0x7d041223,0x00000000}},	//   rraï, _לוחו, ajis,
  { {0xceb200b5,0xdb040164,0x89d9007e,0x00000000}},	//   _ביי_, isiè, توار_,
  { {0xdb0d0025,0x7c24007d,0x79241224,0x00000000}},	//   mraí, bzir, ньчж,
  { {0xdb0d02dd,0xe72e1225,0xe7a80086,0x00000000}},	//   stañ, ве_, звіл_,
  { {0x8ae4019d,0x3ce90019,0xdb0d017d,0x00000000}},	//   _післ, ldav_, duaç,
  { {0xdb0d0025,0x2d781035,0x45d20092,0x00000000}},	//   nraí, _hčer_, војс,
  { {0x3ce90019,0x7ae700ea,0xfdf80063,0x00000000}},	//   ndav_, _hajt, לצות_,
  { {0xdb0d1226,0x65690b64,0x7ae700c2,0x00000000}},	//   hraí, rmeh, _kajt,
  { {0x3f840014,0x394f1227,0x23290054,0x00000000}},	//   ímum_, logs_, іони_,
  { {0xb209005a,0x98af0078,0xc1780078,0x00000000}},	//   ценз_, angą_, dvės_,
  { {0xcea9014e,0xdce40734,0x8fa6019c,0x00000000}},	//   _כי_, tmič, маме,
  { {0xbcfb0164,0xdb0d017d,0x25a0007d,0x00000000}},	//   _phén, cuaç, ćile_,
  { {0xdb0400e8,0x69d5006f,0x7ae71228,0x00000000}},	//   rsië, _opze, _najt,
  { {0xdb0d0027,0xdb04006f,0x7d160093,0x00000000}},	//   graí, ssië, tkys,
  { {0x2f14004b,0x1d5501ce,0xad65009b,0x00000000}},	//   _mägi_, еђус, فاقه,
  { {0x3ce6034d,0x5f2a0121,0xbcfb00f4,0x00000000}},	// [1780] ľov_, _моим_, _thén,
  { {0x3ce60024,0x7d161229,0xd910007e,0x00000000}},	//   žov_, skys, گیر_,
  { {0x78a20d19,0xdb0d0139,0x2f14004b,0x00000000}},	//   taov, craí, _nägi_,
  { {0xdb0d007a,0x693c0024,0x44240022,0x00000000}},	//   stað, mček, yzm_,
  { {0x98a30c07,0x31da0053,0xdb040025,0x00000000}},	//   тиче, _बन्ध, iriú,
  { {0x66e30001,0x758a0156,0xc58a0062,0x00000000}},	//   воља, осив_, ощие_,
  { {0xf1dd0042,0xd5ba046e,0x0f37009d,0x00000000}},	//   _फैलन, іск_, ורסט_,
  { {0xdb0d0016,0x7ae7122a,0xb906014b,0x00000000}},	//   tuaç, _zajt, _ўзак,
  { {0x63bb0035,0xa7a70002,0x693c004c,0x00000000}},	//   guun, _окта_, yčej,
  { {0x60c40016,0x2545001c,0x1bfb0047,0x00000000}},	//   _acim, vēle_, קליב,
  { {0xe135122b,0xdb04122c,0x63bb00a4,0x00000000}},	//   енны, friú, auun,
  { {0xdb040164,0x2d85004c,0x26dc122d,0x00000000}},	//   ssiè, ílem_, levo_,
  { {0xb5a00001,0x78a00150,0xc1780078,0x00000000}},	//   _енcи, _memv, tvės_,
  { {0xdb0d122e,0xd80b009d,0x00000000,0x00000000}},	//   traí, חִלָ,   ,
  { {0xdb040025,0x7ae70758,0xb2bb009a,0x00000000}},	//   briú, _rajt, _ומור,
  { {0x6f1e006f,0x7ae7122f,0xdb0d1230,0x00000000}},	//   _elpc, _sajt, rraí,
  { {0x3f670055,0x60dd0474,0xbbb90086,0x00000000}},	// [1790] _отоб, mesm, ягає_,
  { {0xbcfb0164,0x60dd1231,0xc879000c,0x00000000}},	//   _théo, lesm, _iaşi_,
  { {0x7ac4005a,0x394f0137,0x26dc1232,0x00000000}},	//   ъсте, togs_, devo_,
  { {0x25f40053,0x60dd1233,0x25610014,0x00000000}},	//   ्मनी_, nesm, kóla_,
  { {0x22590022,0x394f1234,0x7aca0082,0x00000000}},	//   ęski_, rogs_, _सॉकॅ,
  { {0x5fbc0047,0x25711235,0x63bb0072,0x00000000}},	//   קצונ, _išli_, vuun,
  { {0x6d480164,0x96940086,0xc879003b,0x00000000}},	//   édag, тріш, _laşi_,
  { {0x3ea10019,0x628a04ca,0x60dd1236,0x00000000}},	//   _leht_, _affo, jesm,
  { {0x60dd1237,0x25610046,0x36d51238,0x00000000}},	//   desm, góla_, _поар,
  { {0x60c41239,0x26dc123a,0x68e9001f,0x00000000}},	//   _scim, cevo_, _haed,
  { {0x68e900e3,0x68fb05b9,0x9f400025,0x00000000}},	//   _kaed, _knud, _triú_,
  { {0x628a04bc,0x4acf0053,0xaacf0053,0x00000000}},	//   _effo, स्तव, स्तक,
  { {0x653a0047,0xbcfb0066,0x68e90f20,0x00000000}},	//   _צענד, _chém, _maed,
  { {0x63a9123b,0x6d41123c,0xf76704a0,0x00000000}},	//   msen, élan, طا_,
  { {0x523900b5,0x63a9123d,0x68fb085a,0x00000000}},	//   _מײַנ, lsen, _onud,
  { {0x693c0066,0x21670363,0xfce3123e,0x00000000}},	//   rček, _пищи_, лосо,
  { {0x63a9123f,0xab661240,0x657c0046,0x00000000}},	// [17a0] nsen, евал, _érhv,
  { {0x3ea100bd,0x63a91241,0xba260085,0x00000000}},	//   _geht_, isen, ндзк,
  { {0x63a9004d,0x6459002b,0x68e91242,0x00000000}},	//   hsen, _lywi, _baed,
  { {0xc7c60245,0x63a91243,0xb05b0137,0x00000000}},	//   ески, ksen, mfär,
  { {0x64590035,0x63a91244,0x26dc1232,0x00000000}},	//   _nywi, jsen, tevo_,
  { {0x26dc02dd,0x63a91245,0x7bcb0063,0x00000000}},	//   uevo_, dsen, _מֶלֶ,
  { {0x68e900e3,0xd910006a,0x78a000c3,0x00000000}},	//   _faed, _پیش_, _temv,
  { {0x63a900b9,0x44f40095,0x6459002b,0x00000000}},	//   fsen, тпис, _bywi,
  { {0x64591246,0x96960054,0xd467005e,0x00000000}},	//   _cywi, _зреш, ниће_,
  { {0x2120003e,0x64590051,0x2f14004b,0x00000000}},	//   _alih_, _dywi, _kägu_,
  { {0x2258010a,0x5ab70047,0x7d0b0137,0x00000000}},	//   ærk_, עלטע_, ögsk,
  { {0x010b007e,0x2d81004d,0x859b0047,0x00000000}},	//   ستجو_, _ruhe_, _זשאו,
  { {0xc879000c,0x6459001f,0x60dd1247,0x00000000}},	//   _paşi_, _gywi, resm,
  { {0xb05b01bb,0x2d810072,0x93fb009d,0x00000000}},	//   ffär, _puhe_, _מלדי,
  { {0xa01b000f,0x2f14004b,0xdcef003b,0x00000000}},	//   nböz, _nägu_, _nică,
  { {0xbcfb0164,0x5d780076,0xdde3013d,0x00000000}},	//   _thém, ейся_, érőe,
  { {0x5c75005a,0x7ff70021,0x68e91248,0x00000000}},	// [17b0] тлат, _أسعا, _raed,
  { {0x68fb00d1,0x291f0139,0xb05b0137,0x00000000}},	//   _snud, _slua_, sfäs,
  { {0xc3330063,0x63a91249,0x68e9124a,0x00000000}},	//   נוע_, zsen, _paed,
  { {0x63a9124b,0x68e9124c,0x5dc8009a,0x00000000}},	//   ysen, _qaed, _אֶשְ,
  { {0x2571007d,0x34dd0053,0xfc640062,0x00000000}},	//   _ušli_, _मसौद, _бърн,
  { {0x45d51001,0x61260014,0x64590ee2,0x00000000}},	//   вцит, _gólf, _rywi,
  { {0xd7580021,0x66180066,0x7d0f013d,0x00000000}},	//   رجها_, _čaká, _kocs,
  { {0xa5f60001,0x3169006d,0x63a9124d,0x00000000}},	//   ђењу_, _nhaz_, tsen,
  { {0x777a0994,0x25a0007d,0x4944000d,0x00000000}},	//   _fitx, ćila_, _сэрб,
  { {0x63a9124e,0x7bcd124f,0x82f50094,0x00000000}},	//   rsen, itau, тчиц,
  { {0x7bcd00fe,0x64590051,0x63a91250,0x00000000}},	//   htau, _wywi, ssen,
  { {0x0596007e,0x7bcd0e77,0x63a91251,0x00000000}},	//   _شامگ, ktau, psen,
  { {0x61e10185,0xa023004b,0x81bc008f,0x00000000}},	//   swll, ööpr, nzēj,
  { {0x81bc003d,0xb05b00c7,0xb4640086,0x00000000}},	//   izēj, tfär, _скіл,
  { {0x2d9e0164,0x6da3005a,0xed5a1252,0x00000000}},	//   ète_, иира, дов_,
  { {0x693c1253,0x7bcd004d,0xb05b0354,0x00000000}},	//   lčev, ftau, rfär,
  { {0xed5709e1,0xb05b0d88,0xa05a0021,0x00000000}},	// [17c0] тот_, sfär, _تؤثر_,
  { {0x81bc001c,0x693c027c,0x27f800a8,0x00000000}},	//   dzēj, nčev, _črn_,
  { {0x18a61254,0x99f5013c,0xb05b004d,0x00000000}},	//   ваем, ляці, ngän,
  { {0x67211255,0xe995007e,0xdcfe1035,0x00000000}},	//   _allj, اهنگ, _kupč,
  { {0x2ba90053,0xb05b004d,0x765a1256,0x00000000}},	//   _चौपा, hgän, _syty,
  { {0xdcef003b,0xa0270014,0x61260046,0x00000000}},	//   _tică, _hröð, _fólg,
  { {0x19b90076,0xe9a3005e,0xceb30063,0x00000000}},	//   _путь_, _васп, ביו_,
  { {0x2545001c,0x291c001c,0xaa431257,0x00000000}},	//   tēla_, īvas_, _тесл,
  { {0x9836000d,0x765a0051,0x288b007e,0x00000000}},	//   _рэві, _wyty, _آصفی_,
  { {0x6d580026,0x764d00ea,0xd764007e,0x00000000}},	//   _ívaf, ényé, _صنای,
  { {0x691304ab,0x71e3000d,0x3abb0063,0x00000000}},	//   _içer, ацяж, ומינ,
  { {0x7bcd0078,0x56370041,0x25450023,0x00000000}},	//   ytau, _באבע_, pēla_,
  { {0xc0580086,0xe0df0290,0xa9230066,0x00000000}},	//   вір_, reò_, úžia,
  { {0xdb2301f7,0x21f40021,0x8233005d,0x00000000}},	//   örün, _مكتس, اریا,
  { {0xde740044,0x912b0044,0xde58012c,0x00000000}},	//   لدفع, _يسبق_, варі_,
  { {0x7bcd1258,0xdb21005b,0x61260139,0x00000000}},	//   ttau, ştür, _rólg,
  { {0x2d580bb3,0x8aa71259,0x2139125a,0x00000000}},	// [17d0] тить_, вред, mish_,
  { {0xdd11003d,0xbcfb0025,0x2139125b,0x00000000}},	//   _kļūd, _mhéi, lish_,
  { {0x6d480164,0x9f49005b,0x7bcd125c,0x00000000}},	//   édac, _araç_, stau,
  { {0x9f4900cd,0x2139125d,0x7bcd125e,0x00000000}},	//   _braç_, nish_, ptau,
  { {0x8c67000d,0x2ca9004b,0x37ab066f,0x00000000}},	//   _штод, maad_, фтен_,
  { {0x366905bd,0xdb0d00be,0x81bc008f,0x00000000}},	//   нало_, draç, rzēj,
  { {0x62860080,0x44290066,0x693c00b2,0x00000000}},	//   ěkol, _ťa_, včev,
  { {0xa3e9005a,0xdb0d017d,0x04c90021,0x00000000}},	//   едиа_, fraç, روخي_,
  { {0xbcfb0027,0xdb0d0016,0x2139077d,0x00000000}},	//   _chéi, graç, dish_,
  { {0x693c00c2,0x8c44005b,0x20190124,0x00000000}},	//   učev, _öğey, dysi_,
  { {0xbbd00161,0x693c02f7,0x21390345,0x00000000}},	//   _सङ्क, rčev, fish_,
  { {0xbcfb0027,0xb05b00bd,0xdb0d017d,0x00000000}},	//   _fhéi, rgän, braç,
  { {0x2ca900f5,0xf5390066,0xbcfb0139,0x00000000}},	//   daad_, miť_, _ghéi,
  { {0xf539034d,0x248d0473,0x2d8c125f,0x00000000}},	//   liť_, lcem_, ídeo_,
  { {0x63bb001c,0x693c074f,0x2f140137,0x00000000}},	//   lrun, očet, _sägs_,
  { {0xf5390024,0x693c1260,0x63bb1261,0x00000000}},	//   niť_, nčet, orun,
  { {0x3ce01262,0xaaba007e,0x612600f8,0x00000000}},	// [17e0] reiv_, فدار_, _cóle,
  { {0x291d0035,0x63bb1263,0x7dea0085,0x00000000}},	//   ekwa_, irun, _змог_,
  { {0x63bb0199,0xeb750088,0x25610046,0x00000000}},	//   hrun, рытэ, tóll_,
  { {0xb95a0032,0xf5390024,0x2d981264,0x00000000}},	//   رجاء_, jiť_, mpre_,
  { {0xf539034d,0x645d0019,0xb8dc0053,0x00000000}},	//   diť_, üsil, _आय_,
  { {0x96b70001,0x6d441265,0x6d561266,0x00000000}},	//   гућу_, lnia, loya,
  { {0x63bb1267,0x25a0007d,0x6d441268,0x00000000}},	//   erun, ćilo_, onia,
  { {0xdb0d0016,0x3eaa00bd,0x9f4900cd,0x00000000}},	//   traç, habt_, _traç_,
  { {0xdb0d017d,0x7792007e,0x3eaa01e1,0x00000000}},	//   uraç, _ایتا, kabt_,
  { {0x6d4400e3,0x21390034,0x693c00c3,0x00000000}},	//   hnia, wish_, ačet,
  { {0xf5390024,0xe3af006a,0x21391269,0x00000000}},	//   biť_, يری_, tish_,
  { {0x63bb00c7,0x7522007d,0xfc3f006d,0x00000000}},	//   brun, _uloz, _leía_,
  { {0x613600c3,0x21390c69,0x6d440051,0x00000000}},	//   ošlj, rish_, dnia,
  { {0x69dc126a,0xa294126b,0x6d44126c,0x00000000}},	//   _opre, _такі, enia,
  { {0x65600025,0xde590086,0x6d44001f,0x00000000}},	//   olmh, таві_, fnia,
  { {0x5c07005a,0x6d560150,0x693c00a8,0x00000000}},	//   ляза, goya, ičes,
  { {0x69dc126d,0x2ca9126e,0x68e2126f,0x00000000}},	// [17f0] _apre, raad_, deod,
  { {0xf539034d,0x2ca9002c,0x63a20035,0x00000000}},	//   ziť_, saad_, _mwon,
  { {0xdced00c2,0x63bb008f,0xdb041270,0x00000000}},	//   lmač, zrun, erió,
  { {0xdced00c2,0x6d440022,0xf1b30063,0x00000000}},	//   omač, cnia, מסע_,
  { {0xf539061a,0xe6c50021,0x69dc0003,0x00000000}},	//   viť_, لتغي, _epre,
  { {0x645d0019,0x7d0d1271,0xf7960021,0x00000000}},	//   üsim, ljas, جنوب_,
  { {0xf5390024,0x7c2d1272,0x7d0d1273,0x00000000}},	//   tiť_, lzar, ojas,
  { {0x7d0d024a,0xb60500ea,0xdb040331,0x00000000}},	//   njas, _aláí, brió,
  { {0xf5390024,0xf5760021,0xed130013,0x00000000}},	//   riť_, جميع_, _đội_,
  { {0xc6a40079,0xf5390024,0xadf70053,0x00000000}},	//   _грци, siť_, ुमान_,
  { {0x6d440185,0x7d0d007a,0xf5390024,0x00000000}},	//   ynia, kjas, piť_,
  { {0x7bdd00b9,0x63bb1274,0x5455000d,0x00000000}},	//   _opsu, prun, _квет,
  { {0x7d0d1275,0x6d561276,0x6d440066,0x00000000}},	//   djas, voya, vnia,
  { {0xdb040019,0x8235007e,0x08760047,0x00000000}},	//   uriü, _پرتا, יערט_,
  { {0x7d0d0026,0x6d560805,0x6d440051,0x00000000}},	//   fjas, toya, tnia,
  { {0x7aee003e,0x2d980003,0x7d0d0014,0x00000000}},	//   _sabt, rpre_, gjas,

  { {0x2d980529,0x69dc1277,0x6d441278,0x00000000}},	// [1800] spre_, _spre, rnia,
  { {0x69dc0031,0x6d440498,0x442d1279,0x00000000}},	//   _ppre, snia, ize_,
  { {0xfc3f006d,0x2d850080,0x68e211ad,0x00000000}},	//   _veía_, ílet_, teod,
  { {0x7d0b00c7,0x26c70290,0x9c83027d,0x00000000}},	//   ögst, egno_, účtu,
  { {0x442d0122,0x7aee00b9,0xec470076,0x00000000}},	//   jze_, _tabt, _взял_,
  { {0x69960086,0x442d127a,0x501b0063,0x00000000}},	//   _врах, dze_, כונו,
  { {0x69dc0024,0x98a60086,0x442d127b,0x00000000}},	//   _upre, _вибе, eze_,
  { {0x752906c6,0x98af003b,0x6283127c,0x00000000}},	//   ghez, rigă_, _agno,
  { {0x43060086,0x3946127d,0x6d41006c,0x00000000}},	//   аїна, mnos_, élai,
  { {0xf36600d7,0x3946127e,0x7d0d0f0c,0x00000000}},	//   јтин, lnos_, zjas,
  { {0x7c2d055b,0x79800035,0x442d127f,0x00000000}},	//   zzar, _kimw, aze_,
  { {0x75290009,0x39460b58,0x442d0058,0x00000000}},	//   chez, nnos_, bze_,
  { {0x442d0045,0xc0e40088,0x33940021,0x00000000}},	//   cze_, цоўк, _التز,
  { {0x3946001f,0xdced0240,0x6d480003,0x00000000}},	//   hnos_, rmač, édan,
  { {0x7d0d1280,0xeca70fe2,0x28d70042,0x00000000}},	//   tjas, ијан, ण्डि,
  { {0x7c2d1281,0x394600ea,0x427b0063,0x00000000}},	//   tzar, jnos_, _באוג,
  { {0x29e80529,0xfa870001,0x67da001c,0x00000000}},	// [1810] _aşa_, аћем, nājā,
  { {0x7c2d1282,0x2bc80002,0x39461283,0x00000000}},	//   rzar, јуто_, enos_,
  { {0x7c2d0051,0x3946001f,0x442d1284,0x00000000}},	//   szar, fnos_, zze_,
  { {0x645d0019,0x39461285,0xbcfb0003,0x00000000}},	//   üsik, gnos_, _chét,
  { {0x6aa7013d,0xa91d007d,0x78ab1286,0x00000000}},	//   _tejf, _niže, ragv,
  { {0x8698005a,0x394604a6,0x3f81004c,0x00000000}},	//   атът_, anos_, _jihu_,
  { {0x98af0006,0x3f81003b,0x691a0003,0x00000000}},	//   eigą_, _mihu_, _aïeu,
  { {0x442d1287,0x7ae5003a,0x00000000,0x00000000}},	//   tze_, leht,   ,
  { {0xf7940088,0xc95201f9,0x442d071e,0x00000000}},	//   _матэ, _זמן_, uze_,
  { {0x442d1288,0x60cd1289,0x27ed128a,0x00000000}},	//   rze_, _acam, _isen_,
  { {0x442d128b,0x568c0047,0xdce40051,0x00000000}},	//   sze_, _סטאַ, amię,
  { {0x2d6800bd,0x61360066,0x78a9128c,0x00000000}},	//   eßen_, ošli, _jeev,
  { {0x95540021,0xdb040014,0x69c5004d,0x00000000}},	//   _بخلا, krið, huhe,
  { {0x612606b2,0x254c0080,0x249f128d,0x00000000}},	//   _dóla, měla_, lbum_,
  { {0xe164007e,0x69c50019,0x853c0078,0x00000000}},	//   _وضعی, juhe, _kvėp,
  { {0x6136109f,0x63a4005b,0x91ba0047,0x00000000}},	//   kšli, _çinc, _עמפי,
  { {0xdb040016,0xbcfb0003,0xf3880013,0x00000000}},	// [1820] nsiç, _rhét, _lợn_,
  { {0xdb04017d,0x09e60054,0x6d5d128e,0x00000000}},	//   isiç, йозн, _eksa,
  { {0x1efb00b5,0xd9460363,0x80cf0042,0x00000000}},	//   _עלטע, бежи, _थामे,
  { {0x256100ea,0x1d0a128f,0x7ae50050,0x00000000}},	//   bóli_, _семи_, aeht,
  { {0x39461290,0xaab8007e,0x2ca0004b,0x00000000}},	//   rnos_, _نگار_, mbid_,
  { {0xe9aa007e,0x254c004c,0x25a5002b,0x00000000}},	//   _مدرن_, děla_, _bwll_,
  { {0x2d820035,0x29e8003b,0x81bc008f,0x00000000}},	//   _kike_, _uşa_, nzēt,
  { {0x2ca000ac,0x77861291,0x25a5002b,0x00000000}},	//   nbid_, _глаз, _dwll_,
  { {0x442200ea,0x2d821292,0xccf3089e,0x00000000}},	//   ák_, _mike_, לכה_,
  { {0x2d821293,0x78a91294,0xaaa80053,0x00000000}},	//   _like_, _zeev, गरिक,
  { {0xd5b9019d,0x3f8900cd,0x61260026,0x00000000}},	//   _всі_, _suau_, _sóla,
  { {0x81bc003d,0x59c90053,0xc5f30063,0x00000000}},	//   dzēt, ांतर, _מדע_,
  { {0xd8d700b5,0xa2d30053,0x69c50244,0x00000000}},	//   זוכט_, _बॉक्, zuhe,
  { {0x4374006a,0x6e940076,0x2d6800bd,0x00000000}},	//   _بهتر, зиру, ußen_,
  { {0xe189008b,0x2d821295,0xddc5004c,0x00000000}},	//   _hẳn_, _bike_, _vzhů,
  { {0x61260026,0x628e00c2,0x61360066,0x00000000}},	//   _tóla, žbod, yšli,
  { {0xdb041296,0xdcfe003b,0x7ae51297,0x00000000}},	// [1830] trið, _supă, teht,
  { {0x69c50026,0xbcfb0003,0x78a91298,0x00000000}},	//   tuhe, _chér, _seev,
  { {0x7ae51299,0xd91b129a,0x78a90168,0x00000000}},	//   reht, льд_, _peev,
  { {0x69c5129b,0x7ae5129c,0x5c07129d,0x00000000}},	//   ruhe, seht, _ляга,
  { {0xf771043b,0x78a9004b,0x69c5004b,0x00000000}},	//   وات_, _veev, suhe,
  { {0x69c500fe,0x25a5001f,0xbcfb006c,0x00000000}},	//   puhe, _pwll_, _thés,
  { {0xf5920032,0x2129003e,0x1efa00b5,0x00000000}},	//   ولوج, _olah_, ילװע,
  { {0x254c004c,0x321e0022,0xfd8a0041,0x00000000}},	//   těla_, dyty_, סטפּ,
  { {0x9817006a,0x27ed0857,0xa8a401ce,0x00000000}},	//   _ابزا, _usen_, _хрск,
  { {0xdb16024a,0x15ab0062,0x247f008f,0x00000000}},	//   styö, _бъди_, _rāmī_,
  { {0x81bc003d,0x21290025,0x9f49004d,0x00000000}},	//   dzēs, _blah_, _spaß_,
  { {0x254c004c,0x9136012c,0x3ce30082,0x00000000}},	//   pěla_, іхні, ख़ों_,
  { {0xd24e007e,0x2d82129e,0x28d10042,0x00000000}},	//   فنی_, _rike_, _हानि,
  { {0x321e0185,0x040e0013,0xd5dd0042,0x00000000}},	//   byty_, _lýợn, _महाज,
  { {0xad3a0086,0x395f00a8,0x2d82129f,0x00000000}},	//   ачає_, _okus_, _pike_,
  { {0xc5f20063,0x8d66000d,0x81bc008f,0x00000000}},	//   ודל_, івае, rzēt,
  { {0x25a0017f,0xcb050042,0x2ca012a0,0x00000000}},	// [1840] ćili_, रांड_, rbid_,
  { {0x4a9a0085,0x5de6089d,0x3a9a014b,0x00000000}},	//   ртаў_, _джоа, ртаю_,
  { {0xa3a90053,0x386d12a1,0x7f5c0003,0x00000000}},	//   गीत_, _azer_, morq,
  { {0x61fc06a5,0x6d410003,0xdd0f005b,0x00000000}},	//   årli, élat, mışs,
  { {0xbcfb12a2,0x7d0612a3,0x321e0022,0x00000000}},	//   _thér, _inks, zyty_,
  { {0xab2a0138,0x27e900cd,0x394d12a4,0x00000000}},	//   _тога_, çana_, _ejes_,
  { {0x76a90086,0x386d00ea,0x333e00cd,0x00000000}},	//   стів_, _ezer_, vitx_,
  { {0xb6030066,0xdb0d0014,0x1de20042,0x00000000}},	//   úšal, luað, _पहनत,
  { {0x25a9007d,0xd90d007e,0x96960062,0x00000000}},	//   ćala_, _حین_, _дреш,
  { {0x63bd00ea,0xd370013a,0x395f004c,0x00000000}},	//   ásna, عهد_, _zkus_,
  { {0xd2570054,0x28d10042,0x925812a5,0x00000000}},	//   жця_, _हामि, сант_,
  { {0x69c300c3,0x94d40021,0x254c004c,0x00000000}},	//   šneg, _ريتش, mělo_,
  { {0xb0340076,0xf8b30063,0xdfdb0062,0x00000000}},	//   дняш, ושר_, шън_,
  { {0x7d0600eb,0x2545001c,0x543b0041,0x00000000}},	//   _anks, vēli_, _דעדא,
  { {0xdef80088,0x645d004b,0x98af0078,0x00000000}},	//   цыя_, üsiv, aigę_,
  { {0x2545001c,0x21290150,0x6126013d,0x00000000}},	//   tēli_, _ulah_, _jóll,
  { {0xa91d00c2,0xac77005d,0xbe870044,0x00000000}},	// [1850] _niža, زارش, _وجدو,
  { {0x78a2004a,0x539b0165,0xea67005e,0x00000000}},	//   ebov, יימו, оњен,
  { {0x6136005f,0x7875013d,0x386d12a6,0x00000000}},	//   ašlu, küvé, _szer_,
  { {0xdb0d0025,0x254c004c,0xec150044,0x00000000}},	//   msaí, dělo_, _فوجد,
  { {0x07a5065b,0x18690856,0xe8380054,0x00000000}},	//   чалн, љали_, опці_,
  { {0x37070055,0x8c1a009a,0xb9c700de,0x00000000}},	//   ючев, _הושי, _وتأه,
  { {0xf6250156,0x78a2011b,0x9782005d,0x00000000}},	//   ядко, bbov, ریمه,
  { {0xf50912a7,0x395f12a8,0x00000000,0x00000000}},	//   снил_, _ukus_,   ,
  { {0x7f5c0331,0x29d500a5,0x612601d1,0x00000000}},	//   yorq, låa_, _sólo,
  { {0x395d0034,0x69d700cd,0xdb04017d,0x00000000}},	//   lows_, otxe, briõ,
  { {0xeccb0161,0x644d0006,0x4add0042,0x00000000}},	//   िलाफ, _žaid, न्यव,
  { {0x69d700cd,0x395d12a9,0xa4d50054,0x00000000}},	//   itxe, nows_, _ході,
  { {0xa3f40086,0x4f96000d,0x7f5c12aa,0x00000000}},	//   _опці, ярну, torq,
  { {0x539a0063,0x2d9612ab,0x07350041,0x00000000}},	//   _היסו, зрас, לאָם_,
  { {0x78bb007d,0x78a2004a,0x61260014,0x00000000}},	//   _oduv, ybov, _hólm,
  { {0xc5f20149,0x621a0041,0x91ba0063,0x00000000}},	//   עדן_, _לוצק, _המקי,
  { {0x5046005e,0xe8df0013,0xdb0d0014,0x00000000}},	// [1860] _хепб, _ngựa_, tuað,
  { {0x6d4112ac,0xdb59012c,0x3057009d,0x00000000}},	//   élar, оює_, _משפך_,
  { {0x273000aa,0xe9da12ad,0xdb0d0025,0x00000000}},	//   _hàng_, ске_, csaí,
  { {0xd910007e,0xb05b0137,0x27ff12ae,0x00000000}},	//   خیر_, rgäv, _brun_,
  { {0x78a212af,0xdb040139,0xd8230062,0x00000000}},	//   rbov, isiú, ндци,
  { {0x78a2006f,0x7bc400cd,0x27300013,0x00000000}},	//   sbov, mriu, _màng_,
  { {0x2730008b,0xa5d70021,0xb9b50062,0x00000000}},	//   _làng_, كبير_, _остъ,
  { {0x5398042c,0xa507005e,0xd4c3014b,0x00000000}},	//   овия_, зећа_, нсьп,
  { {0x27300013,0xb8e20042,0x27ff0046,0x00000000}},	//   _nàng_, ूल_, _grun_,
  { {0x59d00394,0x798e0009,0xa91d0080,0x00000000}},	//   _हमार, _kubw, _jižn,
  { {0x2000003b,0x41e60054,0xc48612b0,0x00000000}},	//   _arii_, чіпа, _елек,
  { {0xa91d00c2,0x27300013,0x63660014,0x00000000}},	//   _ližn, _bàng_, iðni,
  { {0x2730001b,0x645d0019,0x63ae004c,0x00000000}},	//   _càng_, üsit, áhně,
  { {0x2730008b,0x3f850026,0x7bc412b1,0x00000000}},	//   _dàng_, ölu_, driu,
  { {0x7bc40004,0x7af500c3,0xd24f0085,0x00000000}},	//   eriu, _razt, _чц_,
  { {0xf549008b,0xdb0d0139,0xfaf3005d,0x00000000}},	//   hấn_, rsaí, کثر_,
  { {0x7055006a,0x6c5406dc,0x2bb80021,0x00000000}},	// [1870] _زندا, екту, كالة_,
  { {0x60dd087d,0x539b009a,0xbbb8012c,0x00000000}},	//   lfsm, ציבו, ягує_,
  { {0x79a40076,0x7bc40271,0x6562008d,0x00000000}},	//   ерче, ariu, _okoh,
  { {0x637400cd,0x7bc400e5,0xcdb6009d,0x00000000}},	//   lànd, briu, _קפרה_,
  { {0x7bc40268,0x6d4d12b2,0x395d12b3,0x00000000}},	//   criu, mnaa, rows_,
  { {0x6d4d006f,0x27ff00dd,0xf773043e,0x00000000}},	//   lnaa, _vrun_, راش_,
  { {0x6d4d12b4,0x80bf0053,0x25a9007d,0x00000000}},	//   onaa, ्लाइ, ćalo_,
  { {0x6d4d12b5,0x26d80137,0x62980229,0x00000000}},	//   nnaa, _öron_, _afvo,
  { {0x23d40088,0x6d480003,0x27ff0150,0x00000000}},	//   нцэр, édai, _urun_,
  { {0x2730008b,0x68eb0983,0x69c5004d,0x00000000}},	//   _ràng_, legd, orhe,
  { {0x2730008b,0x69c5001f,0x6d4d12b6,0x00000000}},	//   _sàng_, nrhe, knaa,
  { {0xd7d10161,0x2545003d,0x6d4d0122,0x00000000}},	//   _समाच, tēlu_, jnaa,
  { {0x69c500bd,0x6d4d006f,0x316c008f,0x00000000}},	//   hrhe, dnaa, ēdz_,
  { {0x2730008b,0x68eb00ac,0x656912b7,0x00000000}},	//   _vàng_, hegd, lleh,
  { {0xa91d007d,0x69c501e1,0xa3a90042,0x00000000}},	//   _nižo, jrhe, गीर_,
  { {0x2730008b,0x656912b8,0x1d0712b9,0x00000000}},	//   _tàng_, nleh, меси_,
  { {0x6b8702b0,0x7bc40006,0x5fd20053,0x00000000}},	// [1880] _bijg, uriu, _तमिल,
  { {0xdcfd003d,0x6d4d12ba,0x637400cd,0x00000000}},	//   _visā, anaa, cànd,
  { {0x2005001c,0x2d950062,0xfe720021,0x00000000}},	//   ālie_, _пряс, _جدة_,
  { {0x7bc4000c,0xeb9f000e,0x6aae12bb,0x00000000}},	//   priu, _brød_, _webf,
  { {0x69c512bc,0xeb9a0a74,0x6569004c,0x00000000}},	//   arhe, _фиг_, dleh,
  { {0xf5490013,0x65620b2a,0x69c3004c,0x00000000}},	//   uấn_, _skoh, ánec,
  { {0xf5490013,0xb05b051c,0x799c0022,0x00000000}},	//   rấn_, ngär, _utrw,
  { {0x6ba501e3,0xdce408ea,0xb9030a74,0x00000000}},	//   _åtgä, klič, _изск,
  { {0xd8d700b5,0xbcfb0080,0x7c2412bd,0x00000000}},	//   _קומט_, _okén, nyir,
  { {0x61260026,0x52140ac5,0x657b00a4,0x00000000}},	//   _fólk, едот, amuh,
  { {0x6d4d12be,0xdce412bf,0x656912c0,0x00000000}},	//   ynaa, elič, bleh,
  { {0xf388001b,0x403512c1,0x03a612c2,0x00000000}},	//   _lợi_, еемс, _жидо,
  { {0x63740268,0xb05b00c7,0xdce40240,0x00000000}},	//   tànd, egär, glič,
  { {0x44240051,0x656000ea,0x636f01f2,0x00000000}},	//   mym_, lomh, lønn,
  { {0x200d000c,0x6d4d12c3,0xf1c50053,0x00000000}},	//   ţei_, tnaa, _वियन,
  { {0xdce412c4,0x69c5004c,0x5cc4007b,0x00000000}},	//   blič, vrhe, ксуз,
  { {0x6d4d12c5,0x442412c6,0x2d8c12c7,0x00000000}},	// [1890] rnaa, nym_, íder_,
  { {0x6d4d0179,0x65600025,0xb05b01bb,0x00000000}},	//   snaa, homh, sgäs,
  { {0x6d4d006f,0x272b00d1,0x637401a8,0x00000000}},	//   pnaa, _bønn_, càne,
  { {0x44240024,0x636f00d1,0x69c512c8,0x00000000}},	//   kym_, jønn, rrhe,
  { {0x6b87006f,0x25ac002b,0x7c840893,0x00000000}},	//   _tijg, _awdl_, _ауре,
  { {0x7d1d000f,0x44240106,0x28d10082,0x00000000}},	//   _hoss, dym_, _हावि,
  { {0xdce401a6,0xf388008b,0x3cf90019,0x00000000}},	//   zlič, _gợi_, _kasv_,
  { {0x7d1d024a,0x657b00a4,0xa565007e,0x00000000}},	//   _joss, umuh, رگان,
  { {0x13e60076,0x7d1d12c9,0x657b12ca,0x00000000}},	//   емый_, _moss, rmuh,
  { {0x2545001c,0x7d1d12cb,0x69c104aa,0x00000000}},	//   tēls_, _loss, _åles,
  { {0x7d1d00ac,0x636f05a5,0xf41f004b,0x00000000}},	//   _ooss, bønn, ääb_,
  { {0x7d1d03d9,0xdce41035,0x442412cc,0x00000000}},	//   _noss, tlič, bym_,
  { {0x44240051,0x442701fb,0x7529013d,0x00000000}},	//   cym_, _تراف, mkez,
  { {0x7529000f,0xb05b00c7,0x798900ac,0x00000000}},	//   lkez, tgär, _liew,
  { {0x8db50086,0xc69212cd,0x2d9e0003,0x00000000}},	//   ксті, ראל_, ëte_,
  { {0x79890045,0x2d9e001c,0x7d1d12ce,0x00000000}},	//   _niew, īte_, _coss,
  { {0x7d1d12cf,0x7ff60021,0x7d1600b9,0x00000000}},	// [18a0] _doss, _أسبا, rjys,
  { {0x272b0031,0x7c360022,0xe8030082,0x00000000}},	//   _sønn_, rzyr, लिना_,
  { {0x44240051,0x3f920035,0xda660021,0x00000000}},	//   zym_, _huyu_, راطي,
  { {0x69c302dd,0xdcfd00dd,0x612605ec,0x00000000}},	//   ánea, _visă, _bóli,
  { {0xa7fd000f,0x9d1b0047,0x637400cd,0x00000000}},	//   _szűr, _זוכט, nànc,
  { {0x57f30001,0x254c0080,0x44240066,0x00000000}},	//   упшт, měli_, vym_,
  { {0x44240045,0x61260516,0x38c8005d,0x00000000}},	//   wym_, _eóli, _ياری_,
  { {0x752900ea,0xc448007e,0x89db0063,0x00000000}},	//   gkez, ویان_, _מחלי,
  { {0x84970032,0x394610ac,0x636f0093,0x00000000}},	//   رئيس_, mios_, rønn,
  { {0x65600307,0xa91d00c3,0x394612d0,0x00000000}},	//   somh, _nižj, lios_,
  { {0xa1590690,0x75d60044,0xb5a50054,0x00000000}},	//   дану_, _سيشا, _арій,
  { {0x637400cd,0x394612d1,0xd257000d,0x00000000}},	//   fànc, nios_, эцы_,
  { {0xc9530063,0x7d1d12d2,0x637400cd,0x00000000}},	//   רמר_, _ross, gànc,
  { {0x254c0080,0xdefb000d,0x7d1d12d3,0x00000000}},	//   děli_, чым_, _soss,
  { {0x39460006,0x7d1d12d4,0x80a20053,0x00000000}},	//   kios_, _poss, _क्वे,
  { {0x63660026,0x9d1812d5,0x00000000,0x00000000}},	//   rðnu, ност_,   ,
  { {0xdb0d12d6,0x7d1d12d7,0x394612d8,0x00000000}},	// [18b0] nsaç, _voss, dios_,
  { {0xdb0d12d9,0x394600be,0x79890022,0x00000000}},	//   trañ, eios_, _siew,
  { {0xa2d80235,0x3946039f,0x612612da,0x00000000}},	//   _मान्, fios_, _sóli,
  { {0x394612d1,0x6d480153,0x61e5004d,0x00000000}},	//   gios_, édat, _ähle,
  { {0x79890034,0x7c6701fb,0x2ca912db,0x00000000}},	//   _view, _ساحل, mbad_,
  { {0x2d8b006d,0x798912dc,0xd618005d,0x00000000}},	//   _hice_, _wiew, کتها_,
  { {0x752903e8,0x56920001,0x394612dd,0x00000000}},	//   tkez, шајт, bios_,
  { {0x39460747,0x61260014,0x2ca912de,0x00000000}},	//   cios_, _tóli, nbad_,
  { {0x80a20161,0x442b12df,0xa6f50001,0x00000000}},	//   _क्षे, ác_, _изаш,
  { {0x3eb30034,0x69ca0016,0x63740268,0x00000000}},	//   _next_, áfeg, vànc,
  { {0x68fb047f,0x3f92005b,0x7529013d,0x00000000}},	//   _kaud, _suyu_, pkez,
  { {0x2eaa0161,0x63740268,0x291f0003,0x00000000}},	//   कर्त, tànc, _joua_,
  { {0x68fb12e0,0x200412e1,0x644f12e2,0x00000000}},	//   _maud, ími_, úcid,
  { {0x63bb12e3,0x80a20161,0x2d8b0025,0x00000000}},	//   msun, _क्रे, _aice_,
  { {0x6d5b00a8,0x2d8b12e4,0x63bb12e5,0x00000000}},	//   čuan, _bice_, lsun,
  { {0x68fb12e6,0x291f000c,0x254c0080,0x00000000}},	//   _naud, _noua_, těli_,
  { {0x69c30024,0x63bb12e7,0x2d8b12e8,0x00000000}},	// [18c0] ánen, nsun, _dice_,
  { {0x5fb70063,0x63bb12e9,0xffb7009a,0x00000000}},	//   _שהיא_, isun, _שליש_,
  { {0x3946048e,0x3ebe0026,0x3eb812ea,0x00000000}},	//   tios_, óttu_, mart_,
  { {0x1e570063,0x68fb0877,0x3eb812eb,0x00000000}},	//   _ישיר_, _caud, lart_,
  { {0x68fb003d,0x291f000c,0x394612ec,0x00000000}},	//   _daud, _doua_, rios_,
  { {0x394600eb,0x2d8b000c,0x290d12ed,0x00000000}},	//   sios_, _zice_, _enea_,
  { {0x39460297,0x68fb12ee,0x7afc12ef,0x00000000}},	//   pios_, _faud, _iart,
  { {0x29dc048e,0x68fb12f0,0x44f4005e,0x00000000}},	//   mía_, _gaud, упис,
  { {0x3eb812f1,0x63bb12f2,0x29dc12f3,0x00000000}},	//   kart_, gsun, lía_,
  { {0xdb0d017d,0x68fb001c,0xa6c70899,0x00000000}},	//   rsaç, _zaud, _алфа_,
  { {0x29dc12f4,0x63bb061e,0xdb04006d,0x00000000}},	//   nía_, asun, lsió,
  { {0x68e2001f,0x2d800051,0x216402a1,0x00000000}},	//   nfod, jmie_, итяг,
  { {0xdb0402dd,0x4fc7005a,0x3eb812f5,0x00000000}},	//   nsió, ъсна, fart_,
  { {0x63a200bb,0x69de12f6,0x2d8b0080,0x00000000}},	//   _iton, ktpe, _sice_,
  { {0x29dc006d,0xdb0412f7,0x2d8b12f8,0x00000000}},	//   jía_, mpiè, _pice_,
  { {0x29dc02dd,0x3eb8056f,0x7afc12f9,0x00000000}},	//   día_, aart_, _aart,
  { {0x68fb12fa,0x25a9017f,0x3eb812fb,0x00000000}},	// [18d0] _raud, ćali_, bart_,
  { {0x29dc048e,0x1fa4005a,0x79a7000a,0x00000000}},	//   fía_, _тръг, врде,
  { {0x29dc048e,0x68e2001f,0xdbd1004d,0x00000000}},	//   gía_, ffod, _füße,
  { {0x63a212fc,0x23c2016a,0x08d40054,0x00000000}},	//   _oton, _शिंद, иція,
  { {0xb8db0161,0x63a212fd,0x68fb12fe,0x00000000}},	//   _आज_, _nton, _vaud,
  { {0x29dc048e,0x68e2001f,0x7afc0d9d,0x00000000}},	//   bía_, afod, _gart,
  { {0x29dc048e,0x69de0122,0x3a84000d,0x00000000}},	//   cía_, ctpe, _вытв,
  { {0x7afc004d,0x63bb12ff,0x254c0022,0x00000000}},	//   _zart, tsun, yśle_,
  { {0xbcfb034d,0xe3b10032,0x63bb1300,0x00000000}},	//   _akék, حرب_, usun,
  { {0x63bb1301,0x2d800022,0x7880004c,0x00000000}},	//   rsun, zmie_, _dívč,
  { {0x63bb1302,0xe8df008b,0x3eb81303,0x00000000}},	//   ssun, _ngừa_, vart_,
  { {0x34950138,0x7fd60454,0x3eb81304,0x00000000}},	//   _садр, лігі, wart_,
  { {0x67211305,0xf487005e,0x3eb81306,0x00000000}},	//   _kolj, _ружн, tart_,
  { {0x08760047,0xdbd1004d,0x6126013d,0x00000000}},	//   טערט_, _süße, _rólu,
  { {0x68e2001f,0xa2d80053,0xf3880013,0x00000000}},	//   yfod, _मात्, _vợt_,
  { {0x5c160055,0x29dc02dd,0xfc3f006d,0x00000000}},	//   льзу, vía_, _reír_,
  { {0x3eb81307,0x2d801308,0x69c30078,0x00000000}},	// [18e0] part_, rmie_, šnel,
  { {0x2d800024,0x0eaa0088,0x29dc1309,0x00000000}},	//   smie_, _якой_, tía_,
  { {0x7afc130a,0x8e76000a,0x18a6047e,0x00000000}},	//   _vart, _љупч, гаем,
  { {0x29dc048e,0x386d0205,0x61fc01f2,0x00000000}},	//   ría_, _byer_, ærli,
  { {0x29dc130b,0x68e2001f,0x672101b3,0x00000000}},	//   sía_, rfod, _bolj,
  { {0xdb04048e,0xbcfb0024,0x29dc130c,0x00000000}},	//   rsió, _akéh, pía_,
  { {0xf41f024a,0xe9a30088,0x6721017f,0x00000000}},	//   ään_, _гасп, _dolj,
  { {0x186a02b6,0xaa43130d,0x95d70062,0x00000000}},	//   _заби_, _уесл, удът_,
  { {0x68e40019,0x83340062,0x14d50042,0x00000000}},	//   õidu, иних, _धारण,
  { {0x672100c2,0x79820051,0x236500a8,0x00000000}},	//   _golj, lmow, golj_,
  { {0xe6930032,0x0656000d,0x22580121,0x00000000}},	//   _المد, _стаў, тины_,
  { {0x644f017c,0x6ed70082,0xd59b009a,0x00000000}},	//   úcic, _बाहु, _נבדל,
  { {0x236500c2,0x60c400a3,0xe4760085,0x00000000}},	//   bolj_, _ddim, _сужэ,
  { {0x88bd0045,0x343b0047,0x2fc000c2,0x00000000}},	//   _kośc, _אײדע, _dvig_,
  { {0x2fc0130e,0xd2b70149,0x98bd0022,0x00000000}},	//   _evig_, _גלות_, liwą_,
  { {0x79820051,0x316900b2,0x88bd0022,0x00000000}},	//   jmow, _ukaz_, _mośc,
  { {0x79820022,0xfaa70054,0x8aa7130f,0x00000000}},	// [18f0] dmow, гшен, гред,
  { {0x69c300c2,0x20090003,0x66081310,0x00000000}},	//   šnem, _irai_, _ordk,
  { {0xdb580076,0xeb9f0146,0x7bcb0026,0x00000000}},	//   уют_, _grøn_, águb,
  { {0x20091311,0xf09f00cd,0x7bdf004d,0x00000000}},	//   _krai_, ncà_, ptqu,
  { {0x672106bb,0x27c70076,0xdcef0022,0x00000000}},	//   _polj, ущег, _chcą,
  { {0x386d0137,0xd705030b,0x7982056c,0x00000000}},	//   _vyer_, рзки, amow,
  { {0x67211312,0x236500c3,0x7bcd007a,0x00000000}},	//   _volj, volj_, lrau,
  { {0x7bcd004d,0x20090078,0x64a51313,0x00000000}},	//   orau, _orai_, јапа,
  { {0xa3b0016a,0x7bcd045e,0x36d51314,0x00000000}},	//   टील_, nrau, _возр,
  { {0x82350021,0x7bcd1315,0x2b0e0042,0x00000000}},	//   لرجا, irau, साएँ_,
  { {0x7bcd00bd,0xf7840021,0x88bd0051,0x00000000}},	//   hrau, _اللَ, _gośc,
  { {0x291d0035,0x2b170053,0x7bcd1316,0x00000000}},	//   njwa_, नाडु_, krau,
  { {0x2365007d,0x20091317,0xa3a7005e,0x00000000}},	//   polj_, _crai_, _сјек,
  { {0x82a50055,0x79820051,0x63a91318,0x00000000}},	//   _такж, zmow, mpen,
  { {0x69c303f5,0x7e230141,0x63a91319,0x00000000}},	//   šnej, одрж, lpen,
  { {0x7600000f,0xf388001b,0x63a9131a,0x00000000}},	//   lázá, _hợp_, open,
  { {0x4d630086,0x6a960054,0x0b460785,0x00000000}},	// [1900] ікув, ареє, анан,
  { {0xbd46007e,0x63a90ebe,0x3c19000d,0x00000000}},	//   _چندي, ipen, ыўся_,
  { {0xe9da131b,0x27ed006f,0x7bcd131c,0x00000000}},	//   тке_, _apen_, arau,
  { {0x88e60055,0x7bcd131d,0xa3e60053,0x00000000}},	//   ржде, brau, _पहल_,
  { {0x79820051,0x76000080,0x63a9006f,0x00000000}},	//   rmow, kázá, jpen,
  { {0xf549008d,0x88bd0022,0x68e90058,0x00000000}},	//   iấu_, _pośc, _ebed,
  { {0x63a9131e,0xd5b7066e,0xf549008d,0x00000000}},	//   epen, асы_, hấu_,
  { {0x55060002,0x2ca00c8b,0x5ca9009a,0x00000000}},	//   рчка, ncid_, ְׁתַ,
  { {0xa5070259,0x27e902a5,0x07a30002,0x00000000}},	//   рења_, çant_, _матн,
  { {0x3d0d0042,0x00000000,0x00000000,0x00000000}},	//   _ढोने_,   ,   ,
  { {0xd2570086,0x2d9e0080,0x63a9131f,0x00000000}},	//   ицю_, ítel_, apen,
  { {0xc05b000d,0xf539004c,0x73e60085,0x00000000}},	//   віг_, chť_, _водз,
  { {0xe53b0063,0xc05b0086,0xf09f00cd,0x00000000}},	//   _בתאר, тін_, rcà_,
  { {0x20090164,0x6d561320,0xf09f00cd,0x00000000}},	//   _vrai_, enya, scà_,
  { {0xd337009a,0x637b009a,0x7052005d,0x00000000}},	//   _דרגה_, _שנוד, قچیا,
  { {0xc0cb1321,0x7bcd1322,0x20091323,0x00000000}},	//   _руке_, trau, _trai_,
  { {0x20090488,0x2d9c013d,0x2bb80044,0x00000000}},	// [1910] _urai_, _éven_, لالة_,
  { {0x6d561324,0x7bcd1325,0xfb38005e,0x00000000}},	//   anya, rrau, азуј_,
  { {0x7bcd00e0,0x0b881326,0xc987013f,0x00000000}},	//   srau, рсти_, ауди,
  { {0x637d02a7,0x27390003,0x63a91327,0x00000000}},	//   mène, _mène_, ypen,
  { {0x98e40021,0x63a900e5,0x6d4d1328,0x00000000}},	//   تكنو, xpen, miaa,
  { {0xf549008b,0xc7c8000d,0x57a4000d,0x00000000}},	//   hất_, рыце_, ішча,
  { {0x0f380047,0x76001329,0x7c2d132a,0x00000000}},	//   שרוט_, vázá, lyar,
  { {0x1e58014e,0x63a9132b,0x68e9007d,0x00000000}},	//   ישור_, tpen, _ubed,
  { {0xe6c7007e,0x63a9132c,0x637d0003,0x00000000}},	//   _نتاي, upen, hène,
  { {0xf5e7019d,0x6d4d004b,0x7c2d132d,0x00000000}},	//   _відм, hiaa, iyar,
  { {0xa2d80161,0x7c2d132e,0x61e100cd,0x00000000}},	//   _मार्, hyar, utll,
  { {0x04950021,0x645e0051,0x63a9132f,0x00000000}},	//   _الإح, _śpie, ppen,
  { {0x6d4d0d36,0x84670094,0xd496009a,0x00000000}},	//   diaa, _тъже, _הכנת_,
  { {0xe4500021,0x7c2d1330,0xf412009a,0x00000000}},	//   _تضم_, dyar, _מפד_,
  { {0x9f4b00ea,0x442d1331,0x637d109c,0x00000000}},	//   óját_, lye_, rènd,
  { {0xe0da0138,0x6d4d0b45,0xad390054,0x00000000}},	//   _сви_, giaa, ачує_,
  { {0x442d10ca,0x6d5606c2,0x4f5a007e,0x00000000}},	// [1920] nye_, rnya, _مجدد_,
  { {0x8a3a0055,0x442d0058,0x6c550054,0x00000000}},	//   ляет_, iye_, іттє,
  { {0xd910007e,0x7c2d1332,0x628e1333,0x00000000}},	//   ویس_, ayar, žbov,
  { {0x6d4d0122,0x442d0474,0xf9690054,0x00000000}},	//   ciaa, kye_, арій_,
  { {0x3eba0034,0x307a00b5,0x2912005b,0x00000000}},	//   _kept_, װאַנ, ıya_,
  { {0x443f0418,0x7bd600a4,0x29001334,0x00000000}},	//   dzu_, muyu, žia_,
  { {0x443f007d,0x98a61335,0x7abb0063,0x00000000}},	//   ezu_, _гибе, _תצלו,
  { {0x7d041336,0x442d0035,0x3e830003,0x00000000}},	//   ndis, fye_, lété_,
  { {0xfc4a004c,0x7d041337,0x78a21338,0x00000000}},	//   blíž_, idis, mcov,
  { {0x7d04024a,0xdced027c,0xd6d2014d,0x00000000}},	//   hdis, vlač, _رقص_,
  { {0x443f1339,0x7d040838,0x36060044,0x00000000}},	//   azu_, kdis, _دواف,
  { {0xd257126b,0xdced0240,0xf549008b,0x00000000}},	//   сць_, tlač, uất_,
  { {0x7d04133a,0x443f0051,0x6d4d0914,0x00000000}},	//   ddis, czu_, viaa,
  { {0xa8570063,0x7d04133b,0x6d5a0003,0x00000000}},	//   מיכה_, edis, étan,
  { {0x81a60021,0xdced007d,0x6d4d133c,0x00000000}},	//   _احتل, slač, tiaa,
  { {0xbd6b0076,0xdced08ea,0x7d04133d,0x00000000}},	//   урге_, plač, gdis,
  { {0x7bd600f3,0x6440004d,0xbab901d5,0x00000000}},	// [1930] guyu, nzmi, игах_,
  { {0x6440001c,0x637d01a8,0x7d04133e,0x00000000}},	//   izmi, mènc, adis,
  { {0x7c2d08f0,0x637d0268,0x636f00b9,0x00000000}},	//   syar, lènc, mønt,
  { {0x2730001b,0x26de0942,0x7c2d133f,0x00000000}},	//   _hành_, _acto_, pyar,
  { {0x637d00cd,0x186900e1,0x98c50058,0x00000000}},	//   nènc, јали_, çtır_,
  { {0x637d00cd,0x442d0058,0xe7361340,0x00000000}},	//   iènc, vye_, жеш_,
  { {0x442d00e8,0xf77003eb,0x656900fe,0x00000000}},	//   wye_, راه_, toeh,
  { {0x442d1341,0xb3c903d6,0x2730008b,0x00000000}},	//   tye_, ализ_, _lành_,
  { {0x753b00ea,0x03a8007e,0xf359005e,0x00000000}},	//   rhuz, یدیو_, ишој_,
  { {0x637d0268,0x442d048a,0x2d9e0080,0x00000000}},	//   dènc, rye_, ítek_,
  { {0x442d00ac,0x443f0051,0x64401342,0x00000000}},	//   sye_, szu_, azmi,
  { {0xd00a000a,0x208a005a,0x394f00bd,0x00000000}},	//   аеме_, ийни_, nigs_,
  { {0x637d0268,0x41c50053,0x27300013,0x00000000}},	//   gènc, _विकस, _bành_,
  { {0x78bb1343,0xdfcf0021,0x27300013,0x00000000}},	//   _leuv, ضيف_, _cành_,
  { {0x2730008b,0x78bb1344,0x88bd0022,0x00000000}},	//   _dành_, _oeuv, _rośn,
  { {0x2fcd0198,0x853c0078,0x7d041345,0x00000000}},	//   šega_, _atėj, udis,
  { {0x637d0268,0x78a2027d,0x8b260154,0x00000000}},	// [1940] cènc, vcov, одае,
  { {0x636f0205,0x63a40025,0x7bd60058,0x00000000}},	//   møns, _éine, ruyu,
  { {0x3e830003,0x09e30a91,0x78bb1346,0x00000000}},	//   rété_, дохн, _beuv,
  { {0xcb090063,0x69c312a1,0x64400022,0x00000000}},	//   כל_, ânea, yzmi,
  { {0x98a303d1,0x3e830003,0x38600058,0x00000000}},	//   фиче, pété_, çir_,
  { {0x2cb200b9,0x78a21347,0xb5a61348,0x00000000}},	//   lbyd_, scov, орий,
  { {0x78a20124,0x7bc41349,0xa3dc0042,0x00000000}},	//   pcov, lsiu, तंभ_,
  { {0x6abc0ac6,0x63740268,0x7bc40078,0x00000000}},	//   _herf, màni, osiu,
  { {0x6abc007a,0x7bc4134a,0x53970088,0x00000000}},	//   _kerf, nsiu, овыя_,
  { {0x637d00cd,0x128a0062,0x27e6134b,0x00000000}},	//   vènc, ищни_, mton_,
  { {0x290410ca,0xba9b0063,0x2ef800f5,0x00000000}},	//   _kama_, יסיי, derf_,
  { {0x637d0268,0x29060009,0x799c0035,0x00000000}},	//   tènc, ndoa_, _murw,
  { {0x2904134c,0x2cbf0066,0x27e6134d,0x00000000}},	//   _mama_, _ľud_, nton_,
  { {0x637d0994,0x29040e53,0xfe790080,0x00000000}},	//   rènc, _lama_, řům_,
  { {0x637d0268,0xce94005a,0x3135134e,0x00000000}},	//   sènc, даръ, _некр,
  { {0x5c990475,0x2904134f,0x628e00c2,0x00000000}},	//   ская_, _nama_, žbos,
  { {0xdfdb005a,0x3fc9007e,0x7af71350,0x00000000}},	// [1950] _тъй_, _ادبی_, text,
  { {0x7ff4007e,0xf549008b,0x6b400026,0x00000000}},	//   _آسيا, hấp_, _lögf,
  { {0x78bb03b2,0x7bc40019,0x6abc1351,0x00000000}},	//   _peuv, asiu, _derf,
  { {0x7af71352,0x60dd06f1,0x29041353,0x00000000}},	//   sext, ngsm, _cama_,
  { {0x78bb0003,0x29040955,0x46a50062,0x00000000}},	//   _veuv, _dama_, палв,
  { {0x46a5005a,0x637400cd,0x394f01a8,0x00000000}},	//   чакв, bàni, sigs_,
  { {0x6728017f,0x637400cd,0x6b9d1354,0x00000000}},	//   _dodj, càni, _husg,
  { {0x6b9d00ac,0x5887000d,0x6abc00bd,0x00000000}},	//   _kusg, _дыза, _zerf,
  { {0x27ff0019,0x69c51355,0xc7c7005e,0x00000000}},	//   _usun_, lshe, _фсби,
  { {0xeb9f0146,0x6b9d1356,0x934201d5,0x00000000}},	//   _esøg_, _musg, енье,
  { {0xe8030161,0x6aa5004d,0x29041357,0x00000000}},	//   लिका_, ichf, _yama_,
  { {0x69c50034,0x2ef80438,0x672302e2,0x00000000}},	//   ishe, werf_, ljnj,
  { {0x88bd0051,0x69c50025,0x200f1358,0x00000000}},	//   _rośl, hshe, _ágil_,
  { {0x2d9c000f,0x395f00c7,0x69c7017f,0x00000000}},	//   _évek_, _ljus_, _ovje,
  { {0x6b9d0199,0x69c5006f,0x636f00d1,0x00000000}},	//   _ausg, jshe, søns,
  { {0x69c51359,0xdb0d0058,0x7bc4135a,0x00000000}},	//   dshe, asaü, tsiu,
  { {0x27e6135b,0x7bc40006,0x2cb2135c,0x00000000}},	// [1960] xton_, usiu, rbyd_,
  { {0x7bc40529,0x799c00f3,0x63740268,0x00000000}},	//   rsiu, _purw, tàni,
  { {0x387f135d,0x6abc135e,0x672800b2,0x00000000}},	//   _azur_, _verf, _rodj,
  { {0x6abc135f,0x637400cd,0x27e61360,0x00000000}},	//   _werf, ràni, tton_,
  { {0x2904017f,0x67281361,0x2906035e,0x00000000}},	//   _vama_, _podj, rdoa_,
  { {0x47330086,0x394d01a8,0x7d060058,0x00000000}},	//   нніс, _emes_, _haks,
  { {0x7d0601a5,0x29041362,0x27e60bcf,0x00000000}},	//   _kaks, _tama_, ston_,
  { {0x7d061363,0xda5b0063,0x6b9d1364,0x00000000}},	//   _jaks, _הכלל, _yusg,
  { {0x69c7017f,0xad1b0063,0x7d061365,0x00000000}},	//   _zvje, מוקר, _maks,
  { {0x883b014e,0x7d061366,0xb7d70021,0x00000000}},	//   _התמו, _laks, _روما_,
  { {0x76430045,0x26cc0185,0x65870026,0x00000000}},	//   czny, _iddo_, árhæ,
  { {0x867b0047,0xf487005d,0x84e61367,0x00000000}},	//   _פראו, _کامی, _ходж,
  { {0x60dd1368,0xcfa70121,0xdb0d004b,0x00000000}},	//   rgsm, яшни, tsaü,
  { {0x69c500fe,0x3da71369,0x81f60044,0x00000000}},	//   yshe, зраб, _فأعط,
  { {0xdef8000d,0x9e140086,0x7d06136a,0x00000000}},	//   чыя_, ндрі, _baks,
  { {0x7607004c,0x88bd0022,0x625b009d,0x00000000}},	//   lézá, _pośm, _לכוה,
  { {0x69c7017f,0xd11a0053,0x60cd136b,0x00000000}},	// [1970] _svje, धारण_, _idam,
  { {0x69c3017d,0x69c5136c,0x6aa5004d,0x00000000}},	//   âneo, tshe, uchf,
  { {0x6aa5136d,0xf9f90593,0x7d06136e,0x00000000}},	//   rchf, تفاع_, _faks,
  { {0x26cc001f,0x6aa5004d,0xe2930047,0x00000000}},	//   _addo_, schf, גװע_,
  { {0x394d00c3,0xfc64005a,0x69c5136f,0x00000000}},	//   _vmes_, _зърн, sshe,
  { {0xe29a0013,0xb9e70054,0x8c1a0063,0x00000000}},	//   _ngư_, _ніби, _וושי,
  { {0x69c70117,0x945d0051,0xba77007e,0x00000000}},	//   _uvje, kańc, _راست,
  { {0xbe3c0063,0x76430051,0x27f0004c,0x00000000}},	//   מעות, rzny, ílný_,
  { {0xb4ad0053,0x387f0089,0x67d40b4c,0x00000000}},	//   _कभी_, _uzur_, _поту,
  { {0xd75b006a,0x81c90e12,0xe0df01f4,0x00000000}},	//   _اجرا_, огов_, egò_,
  { {0x776400cd,0xa51d000d,0xb6350044,0x00000000}},	//   éixe, _вялi, _تفاع,
  { {0x2d9c013d,0x00000000,0x00000000,0x00000000}},	//   _évei_,   ,   ,
  { {0x7d06003d,0x6b4000c7,0x60cd001f,0x00000000}},	//   _raks, _höge, _ddam,
  { {0x6d4f1370,0x7d061371,0xf456089e,0x00000000}},	//   _amca, _saks, _קיסר_,
  { {0x2d9e03b2,0x4df5019d,0x7d061372,0x00000000}},	//   ête_, нятт, _paks,
  { {0x6b400e77,0xee370054,0xf236005d,0x00000000}},	//   _möge, єнт_, _تبهک,
  { {0xed57000a,0x7d061373,0x98ad0022,0x00000000}},	// [1980] фот_, _vaks, _zleć_,
  { {0x4c830002,0x7c2b00a5,0x5aca0083,0x00000000}},	//   тлув, ägra, ілем_,
  { {0x637400cd,0x63510080,0x823a0047,0x00000000}},	//   mànt, měně, ֿענצ,
  { {0x637400cd,0x7d0600d1,0x00000000,0x00000000}},	//   lànt, _uaks,   ,
  { {0x661d0078,0xa09b009f,0x07fa00f2,0x00000000}},	//   _ąska, קיסט, تراع_,
  { {0xeb9f0307,0xd5b0007e,0xf1c00066,0x00000000}},	//   _prøv_, هفت_, úšky_,
  { {0x8a030794,0x00000000,0x00000000,0x00000000}},	//   _изре,   ,   ,
  { {0x3ce00146,0xa926000d,0xdb0d0014,0x00000000}},	//   ngiv_, _ўдал, lsað,
  { {0x671e0053,0x14180021,0xb3660062,0x00000000}},	//   पादक_, سيدة_, дънк,
  { {0xf7720021,0xdb0d0014,0x6b4000a5,0x00000000}},	//   _شاء_, nsað, _högb,
  { {0x2fc91374,0xcad70063,0x945d0051,0x00000000}},	//   _svag_, ווית_, tańc,
  { {0x914b01dd,0xd2570766,0x7bcb013d,0x00000000}},	//   ічна_, ьцы_, águk,
  { {0x3ce000b9,0x6b40004d,0xf41f0072,0x00000000}},	//   dgiv_, _zöge, äät_,
  { {0x6374051e,0x2d8c006f,0x5f940062,0x00000000}},	//   tànu, ïden_, кият,
  { {0xf206005a,0x254c0051,0x9f52013d,0x00000000}},	//   _цяло, eśli_, óbát_,
  { {0x9d18005a,0x00000000,0x00000000,0x00000000}},	//   мост_,   ,   ,
  { {0xfd1f0013,0x7b1506da,0x62850066,0x00000000}},	// [1990] _chìa_, ндах, _úhor,
  { {0xdb0d0014,0x7a39009c,0xea630043,0x00000000}},	//   gsað, jútö, نپذی,
  { {0x69c800b9,0xe9ab0043,0x00000000,0x00000000}},	//   _ædel, زدان_,   ,
  { {0xeb9f00d1,0xdce4005b,0x98f4000d,0x00000000}},	//   _brøt_, mliğ, вяшч,
  { {0xdce4005b,0x7ac71375,0xe894012c,0x00000000}},	//   lliğ, _осве, ваць,
  { {0x6d910066,0xd5e50062,0x254c004c,0x00000000}},	//   _sťah, ежки, měly_,
  { {0xd5b10032,0xdce401f7,0x58d51376,0x00000000}},	//   دفع_, nliğ, _повт,
  { {0x6b4000bd,0xd61800f2,0xd7fb1377,0x00000000}},	//   _vöge, بتها_, _муз_,
  { {0x6d5a0164,0x65620150,0x44391378,0x00000000}},	//   étai, _djoh, ás_,
  { {0xdce4005b,0x42251379,0x6d4300dd,0x00000000}},	//   kliğ, едов, _înaf,
  { {0x78a402e2,0x63a40025,0x4439001c,0x00000000}},	//   žive, _éinn, šs_,
  { {0xa06a0001,0x64a50002,0x254c0022,0x00000000}},	//   зама_, _џала, yśli_,
  { {0x2c6c004c,0x98a4008f,0x9259005d,0x00000000}},	//   _kódů_, _jomā_, تشکر_,
  { {0x2d990003,0x254c004c,0x657b004e,0x00000000}},	//   _aise_, děly_, lluh,
  { {0x2d99006c,0x72050044,0x975a009a,0x00000000}},	//   _bise_, _أوبم, לדשט,
  { {0x62830117,0x20040026,0xa1c20062,0x00000000}},	//   _izno, æmis_, _сбъд,
  { {0x60c60360,0xbea6137a,0x2d99137b,0x00000000}},	// [19a0] makm, _папк, _dise_,
  { {0x539a0063,0x2d9900ac,0x1ae312b9,0x00000000}},	//   פיעו, _eise_, лоум,
  { {0x533600b5,0xdebb0063,0xe8fa137c,0x00000000}},	//   ענען_, _ממיל, зле_,
  { {0xe1ff0045,0xdb1d00c7,0x5976007e,0x00000000}},	//   łów_, _avsä, رداز,
  { {0x6d5605b4,0x69d700cd,0x3f9a004e,0x00000000}},	//   miya, arxe, _kipu_,
  { {0x2d99000c,0x657b0150,0x6d56137d,0x00000000}},	//   _zise_, eluh, liya,
  { {0xceb3014e,0xfe79011b,0x6b63137e,0x00000000}},	//   ניה_, řův_, _скра,
  { {0x6d56137f,0x6d44017d,0x7afe1380,0x00000000}},	//   niya, nhia, lept,
  { {0x75d4006a,0xa3e70001,0xe3af006a,0x00000000}},	//   ريکا, едња_, یری_,
  { {0xfd1f001b,0x6d561381,0x7afe1382,0x00000000}},	//   _nhìn_, hiya, nept,
  { {0xf41f0019,0x6d44017e,0xd25a0062,0x00000000}},	//   äär_, khia, яци_,
  { {0x8466005a,0x88bd0051,0x64a3005e,0x00000000}},	//   _пъле, _dośw, _баца,
  { {0x557700b5,0x6d56028d,0x2d990034,0x00000000}},	//   _װעגן_, diya, _rise_,
  { {0x637400cd,0x69de1383,0x2d991384,0x00000000}},	//   ràns, kupe, _sise_,
  { {0x63a21385,0xe2130021,0xa2bb0066,0x00000000}},	//   _huon, _مبيع, äčše,
  { {0x63a20009,0xdce401f7,0x6d441386,0x00000000}},	//   _kuon, rliğ, ghia,
  { {0x2d991387,0x63a200fe,0xdce40058,0x00000000}},	// [19b0] _vise_, _juon, sliğ,
  { {0x2d9904bf,0xdce4005b,0x5f950092,0x00000000}},	//   _wise_, pliğ, _шипт,
  { {0x63a2024a,0xda6708aa,0x69de0019,0x00000000}},	//   _luon, رائي, gupe,
  { {0xacbb0164,0x6d441388,0xe8590085,0x00000000}},	//   _coût, chia, маеш_,
  { {0x63a2002c,0xe72e000d,0x7afe0058,0x00000000}},	//   _nuon, ае_, bept,
  { {0xf72b000d,0x7d0d1389,0x7afe138a,0x00000000}},	//   яцей_, ldas, cept,
  { {0xc1790078,0x69de0530,0x7bdf138b,0x00000000}},	//   ntės_, cupe, luqu,
  { {0x63a2138c,0x7d0d138d,0xacbb0003,0x00000000}},	//   _buon, ndas, _goût,
  { {0x59640062,0x6b400137,0x7d0d138e,0x00000000}},	//   _съра, _höga, idas,
  { {0x7d0d00fe,0x88bd0051,0xf6470154,0x00000000}},	//   hdas, _pośw, _пхен,
  { {0x60c6138f,0x61460ab1,0x26c708c9,0x00000000}},	//   takm, вена, mano_,
  { {0x7afe00bd,0x26c71390,0x81d4000d,0x00000000}},	//   zept, lano_, ыцьц,
  { {0xf99200b5,0x60c6005b,0x62830051,0x00000000}},	//   ירט_, rakm, _wzno,
  { {0x7529074f,0x26c71391,0x7bdf1392,0x00000000}},	//   ljez, nano_, duqu,
  { {0x26c71393,0x6449004d,0x6d561394,0x00000000}},	//   iano_, lzei, tiya,
  { {0xdcf60078,0x3207004d,0x7c360072,0x00000000}},	//   plyč, _isny_, tyyr,
  { {0x7afe0529,0x644900bd,0x6d4408a4,0x00000000}},	// [19c0] tept, nzei, rhia,
  { {0x60c40627,0x6d561395,0xdb590086,0x00000000}},	//   _heim, siya, нює_,
  { {0x644900bd,0x3ed900b5,0x6d5600a4,0x00000000}},	//   hzei, _אַרא, piya,
  { {0x7afe1396,0x7989035a,0x39401397,0x00000000}},	//   sept, _chew, óis_,
  { {0x87e30076,0x68e21398,0xacbb0164,0x00000000}},	//   ающе, rgod, _voût,
  { {0x26c71399,0xa77302fe,0x68e2139a,0x00000000}},	//   gano_, аліч, sgod,
  { {0x63a2051e,0x2480003d,0x644900bd,0x00000000}},	//   _suon, _šim_, ezei,
  { {0x644900bd,0x26c700a4,0x60c4139b,0x00000000}},	//   fzei, aano_, _neim,
  { {0x26c7139c,0x6449004d,0xdced007d,0x00000000}},	//   bano_, gzei, slać,
  { {0x394603d9,0x63a2024a,0xdced017f,0x00000000}},	//   lhos_, _vuon, plać,
  { {0xf549008b,0x60c4004d,0xfb150041,0x00000000}},	//   hấy_, _beim, אַרט_,
  { {0x394603d9,0x51870001,0x60c40025,0x00000000}},	//   nhos_, ђуна, _ceim,
  { {0x60c4139d,0x9346139e,0x14d7009f,0x00000000}},	//   _deim, _инде, _יואל_,
  { {0x533300e1,0xee870121,0x6b9c004d,0x00000000}},	//   _вешт, выбо, _nirg,
  { {0x2fc0135f,0xc7c8008b,0xa3a80053,0x00000000}},	//   _ewig_, hố_, _खंड_,
  { {0x6b9c057a,0xc1790006,0x6da40002,0x00000000}},	//   _airg, rtės_, риѓа,
  { {0x7d0d06a7,0xc1790006,0x26c7139f,0x00000000}},	// [19d0] rdas, stės_, yano_,
  { {0x7cde000c,0x16020053,0x6b9c0025,0x00000000}},	//   tărâ, लबार_, _cirg,
  { {0x26c713a0,0x995c004c,0x6b9c13a1,0x00000000}},	//   vano_, líř_, _dirg,
  { {0x26c70045,0x09e40054,0xc98413a2,0x00000000}},	//   wano_, роїн, аучи,
  { {0x9bc4000d,0x386913a3,0x26c713a4,0x00000000}},	//   _вёск, çar_, tano_,
  { {0xa03c0063,0x69d8004c,0x9665030b,0x00000000}},	//   ועדפ, ávec, лкле,
  { {0x78a413a5,0x26c713a6,0x7bcd13a7,0x00000000}},	//   živa, rano_, lsau,
  { {0xf3ff13a8,0x24090055,0x394613a9,0x00000000}},	//   ção_, ении_, chos_,
  { {0x60c413aa,0xf2a50121,0x26c713ab,0x00000000}},	//   _reim, липп, pano_,
  { {0x64490199,0x2b1c0161,0x753b0080,0x00000000}},	//   rzei, नाएँ_, skuz,
  { {0x644913ac,0xd4f5000d,0x7ae513ad,0x00000000}},	//   szei, _бялы, ight,
  { {0x26c5001f,0xe4cb007e,0x7bcd13ae,0x00000000}},	//   _helo_, _آبان_, ksau,
  { {0xb4df016a,0x25a513af,0xdb0f006d,0x00000000}},	//   तली_, _hull_, _etcé,
  { {0x7bcd01e1,0x26c5007c,0xe8e00042,0x00000000}},	//   dsau, _jelo_, _पञ्च,
  { {0x60c40185,0x20090150,0x26c50552,0x00000000}},	//   _teim, _esai_, _melo_,
  { {0x6b9c004b,0x7bcd004d,0xf1b2009f,0x00000000}},	//   _sirg, fsau, _פסח_,
  { {0x61e10556,0x7bcd13b0,0x7ff60021,0x00000000}},	// [19e0] lull, gsau, _إسبا,
  { {0x68e90016,0xec7713b1,0x909b0063,0x00000000}},	//   _aced, упу_, _אספק,
  { {0x21200080,0x637d00cd,0x25a513b2,0x00000000}},	//   _knih_, gèni, _null_,
  { {0x6b400026,0x07a6000d,0x68e913b3,0x00000000}},	//   _gögn, гадн, _cced,
  { {0x6b9c001c,0x7e7e13b4,0x26c513b5,0x00000000}},	//   _tirg, _hypp, _belo_,
  { {0x26c508ea,0x2d8013b6,0x25a513b7,0x00000000}},	//   _celo_, llie_, _bull_,
  { {0x2120017f,0x26c5082a,0xaa460062,0x00000000}},	//   _onih_, _delo_, _севл,
  { {0x61e113b8,0x25a504bf,0x29560062,0x00000000}},	//   dull, _dull_, _съгр,
  { {0xdd040006,0xb8660021,0x786613b9,0x00000000}},	//   ūrės, _صارو, _сказ,
  { {0x26c513ba,0x25a513bb,0x61e113bc,0x00000000}},	//   _gelo_, _full_, full,
  { {0x61e1076d,0x9f420072,0x7bcd008f,0x00000000}},	//   gull, itkä_, zsau,
  { {0x26c50198,0xa15913bd,0x248604fa,0x00000000}},	//   _zelo_, таму_, _tzom_,
  { {0xd0e60161,0x2d800066,0x61e10072,0x00000000}},	//   _कारण_, dlie_, aull,
  { {0xa2940500,0x20d5008d,0x6b400046,0x00000000}},	//   _калі, ụi_, _sögn,
  { {0x61e113be,0x1df802dc,0x3d8b0094,0x00000000}},	//   cull, леры_, ещан_,
  { {0x637d00cd,0x2d8004e4,0x7bcd13bf,0x00000000}},	//   vèni, glie_, tsau,
  { {0x200900f3,0xcb55005e,0xbed50141,0x00000000}},	// [19f0] _usai_, аваћ, _копј,
  { {0x7ae50034,0x6d5a0003,0x7bcd13c0,0x00000000}},	//   ught, étar, rsau,
  { {0x2d8013c1,0x7d0e0072,0x9b6808a8,0x00000000}},	//   blie_, önsä, ушта_,
  { {0x7bcd09ff,0xb815000a,0xfd1f0290,0x00000000}},	//   psau, идеј, _unì_,
  { {0x26c503d9,0x25a502f6,0xf77101a7,0x00000000}},	//   _pelo_, _sull_, يات_,
  { {0x25a50465,0x7bda0063,0x7d0f013d,0x00000000}},	//   _pull_, _בקשו, _hacs,
  { {0x6b400199,0x65c20ac5,0x26c513c2,0x00000000}},	//   _mögl, обща, _velo_,
  { {0x61e1024a,0xb4df016a,0x25a50268,0x00000000}},	//   vull, तले_, _vull_,
  { {0xa3e50053,0x2d160047,0x26c50648,0x00000000}},	//   बंध_, בֿים_, _telo_,
  { {0x61e113c3,0x25a513c4,0xe29913c5,0x00000000}},	//   tull, _tull_, кап_,
  { {0xcb12009f,0x61e10072,0xe12613c6,0x00000000}},	//   קלט_, uull, амни,
  { {0x61e113c7,0xa3e50042,0x98a40078,0x00000000}},	//   rull, बंद_, _tomą_,
  { {0x22590022,0x4fa60062,0x61e113c8,0x00000000}},	//   ńsk_, ригв, sull,
  { {0x61e100fe,0xd007005e,0x3f9e13c9,0x00000000}},	//   pull, јере_, ötu_,
  { {0x3f84001c,0xef17018e,0xed5a0160,0x00000000}},	//   ēmu_, јмс_, вов_,
  { {0xdca30071,0x205613ca,0x2d8013cb,0x00000000}},	//   жати, _втор, ulie_,
  { {0xebe60054,0x7d0f00a3,0x2d8013cc,0x00000000}},	// [1a00] розп, _dacs, rlie_,
  { {0xa03b0063,0x2d8013cd,0x7e7e1256,0x00000000}},	//   _סעיפ, slie_, _typp,
  { {0x6edb0063,0xa3e50053,0x2d8013ce,0x00000000}},	//   _בחיפ, बूत_, plie_,
  { {0xd9460001,0xebe60f50,0xcc8a0043,0x00000000}},	//   једи, _комп, _لنجه_,
  { {0x88bd0051,0x7d0413cf,0x98560002,0x00000000}},	//   _pośr, meis, јтеш,
  { {0xed590024,0x5777000d,0x63a40003,0x00000000}},	//   ďže_, абіў_, _éini,
  { {0x94d4000d,0x76a90054,0xe737007b,0x00000000}},	//   бойц, утів_, реј_,
  { {0x7d04024a,0x940404a0,0xb7da04a0,0x00000000}},	//   neis, موعه, _لورا_,
  { {0xc34a005a,0x66e6018e,0x6b400026,0x00000000}},	//   вяне_, _воза, _lögm,
  { {0x79820034,0x16760001,0x973c007d,0x00000000}},	//   llow, _кћер, _biće,
  { {0x7d0413d0,0x6d460072,0x3218004c,0x00000000}},	//   keis, _olka, íry_,
  { {0x7d0400fe,0x92570121,0x69de00e5,0x00000000}},	//   jeis, рают_, irpe,
  { {0x60d6001f,0x32020080,0x7522007d,0x00000000}},	//   _ddym, ňky_, _inoz,
  { {0xc0580086,0x6d4613d1,0x76670078,0x00000000}},	//   рію_, _alka, šryš,
  { {0xd3780117,0x7d0413d2,0x79820022,0x00000000}},	//   moć_, feis, klow,
  { {0x929b014e,0xe29b0063,0x7c870fd0,0x00000000}},	//   _ביות, _בשור, аузе,
  { {0x75220080,0xfaa713d3,0x69de13d4,0x00000000}},	// [1a10] _mnoz, ашен, erpe,
  { {0x6d460122,0x78a4027c,0x6e3c00b9,0x00000000}},	//   _elka, živl, byrb,
  { {0x3f83027c,0xce680121,0x7d0f13d5,0x00000000}},	//   mlju_, _вряд_, _tacs,
  { {0x97c50021,0x4978000d,0x79820022,0x00000000}},	//   مقصو, асіў_, glow,
  { {0x69de13d6,0x3f8302f7,0xd37813d7,0x00000000}},	//   arpe, olju_, koć_,
  { {0xd246006a,0x907a0047,0xdb23007e,0x00000000}},	//   _فن_, נטװי, _بوسی,
  { {0x5a44000d,0x798213d8,0x317913d9,0x00000000}},	//   _дэта, blow, kosz_,
  { {0x7bdf0b23,0x893813da,0x00000000,0x00000000}},	//   orqu, _кпсс_,   ,
  { {0x1422000d,0x4615005d,0x2eb70042,0x00000000}},	//   здым, _گوار, _अभूत,
  { {0x51b90085,0xf7850044,0x7d040c57,0x00000000}},	//   лымя_, _الطَ, zeis,
  { {0x27e90078,0x00000000,0x00000000,0x00000000}},	//   šinę_,   ,   ,
  { {0x4254000d,0x64580051,0xcea9009f,0x00000000}},	//   ітэт, _ściś, _טי_,
  { {0x05740021,0x442913db,0xd91a0047,0x00000000}},	//   _بالد, _ça_, אורל,
  { {0x7d040199,0x6e3c02f0,0x63bb13dc,0x00000000}},	//   weis, tyrb, mpun,
  { {0xeb9f0031,0x7bdf0268,0x7d0413dd,0x00000000}},	//   _esøk_, erqu, teis,
  { {0x90c61001,0x3f830ba5,0x27ff003b,0x00000000}},	//   _убие, alju_, _opun_,
  { {0x3f83017f,0x6d580078,0x7d0413de,0x00000000}},	// [1a20] blju_, _įvad, reis,
  { {0x7d040d68,0x63bb13df,0x637d00cd,0x00000000}},	//   seis, ipun, cènt,
  { {0xe9da1321,0x6b400137,0x7d0413e0,0x00000000}},	//   уке_, _högk, peis,
  { {0x63bb1203,0x6d460050,0xf1b2009a,0x00000000}},	//   kpun, _ulka, פסד_,
  { {0x1867005e,0x645d0066,0xe73a13e1,0x00000000}},	//   баци_, úsil, лед_,
  { {0x63bb13e2,0x78250021,0xa09b0063,0x00000000}},	//   dpun, تعمل, אינט,
  { {0xd6d90086,0xceb3009f,0xa96a0818,0x00000000}},	//   рті_, היו_, _бива_,
  { {0x93b40054,0x63bb0285,0xd90e005d,0x00000000}},	//   обиц, fpun, _سیت_,
  { {0x63bb13e3,0xa5070002,0xe56f0044,0x00000000}},	//   gpun, сења_, عطى_,
  { {0xaaba0161,0x51f80086,0x68fb13e4,0x00000000}},	//   ेरिक, аною_, _zbud,
  { {0x3f83017f,0x63bb00a4,0x62340002,0x00000000}},	//   vlju_, apun, цену,
  { {0x73e60088,0x71470076,0x1a9b0047,0x00000000}},	//   _годз, схож, טייע,
  { {0x637d00cd,0x3179013d,0x7afc08ed,0x00000000}},	//   tènt, rosz_, _obrt,
  { {0x85040043,0x00000000,0x00000000,0x00000000}},	//   _دوچن,   ,   ,
  { {0x637d00cd,0xd5d8009a,0xa226005d,0x00000000}},	//   rènt, יַּש, _درشه,
  { {0x78a4007d,0x3f8300c2,0x6b400137,0x00000000}},	//   živj, slju_, _högh,
  { {0xfd4f008b,0x3f83007d,0x3ce913e5,0x00000000}},	// [1a30] _khiế, plju_, rgav_,
  { {0xd5b80023,0x00000000,0x00000000,0x00000000}},	//   _otā_,   ,   ,
  { {0x27ff13e6,0x3ce913e7,0x63bb004d,0x00000000}},	//   _spun_, pgav_, zpun,
  { {0x28f90121,0x6b400014,0x6f070022,0x00000000}},	//   редь_, _lögh, lejc,
  { {0x6aa9000c,0x6d5f00ac,0x63bb13e8,0x00000000}},	//   _şefu, miqa, xpun,
  { {0xfd4f008b,0x6d4d13e9,0x68fb0022,0x00000000}},	//   _nhiế, lhaa, _wbud,
  { {0xc5d50086,0xaa5d012c,0xf6f60043,0x00000000}},	//   ціль, _ревi, تزنگ,
  { {0x63bb13ea,0x68fb007d,0xcdaa0041,0x00000000}},	//   tpun, _ubud, סיפֿ,
  { {0x69da01e3,0x14250086,0x68e4017d,0x00000000}},	//   _åter, ідом, óide,
  { {0xfd4f00aa,0x27e00025,0x63bb13eb,0x00000000}},	//   _chiế, áine_, rpun,
  { {0x63bb13ec,0x6f070080,0x6d4813ed,0x00000000}},	//   spun, dejc, ūdai,
  { {0xd24e006a,0xdced017f,0x27e007b4,0x00000000}},	//   خچه_, klađ, šine_,
  { {0x297a0047,0x6d4d0089,0x232913ee,0x00000000}},	//   שטרא, dhaa, _воли_,
  { {0x63ab00a4,0x69d500c2,0x656913ef,0x00000000}},	//   _iugn, _ovze, lneh,
  { {0x4176006a,0x6d5f0089,0x8d5a02b6,0x00000000}},	//   _وابس, fiqa, ашат_,
  { {0x63a3047f,0x6d43000c,0x6283002c,0x00000000}},	//   _hinn, _înal, _iyno,
  { {0x63a30004,0x3c660088,0x6283001f,0x00000000}},	// [1a40] _kinn, цкаг, _hyno,
  { {0xbad5000d,0x63ab13f0,0x657b0066,0x00000000}},	//   зіцы, _mugn, houh,
  { {0x443f014f,0x63ab0137,0x63a313f1,0x00000000}},	//   hyu_, _lugn, _minn,
  { {0x6d4d0122,0x63a30449,0x27e600a4,0x00000000}},	//   chaa, _linn, tuon_,
  { {0x65690024,0x63a30025,0x38cb007e,0x00000000}},	//   dneh, _oinn, شانی_,
  { {0x6d440006,0x501b0063,0x17540376,0x00000000}},	//   lkia, יונו, явля,
  { {0x63ab007a,0x656900bd,0xdce402e2,0x00000000}},	//   _augn, fneh, hnič,
  { {0x6d4400eb,0x63a30025,0xdb04006d,0x00000000}},	//   nkia, _ainn, mpiñ,
  { {0x63a30102,0xfd4f008b,0x6d440006,0x00000000}},	//   _binn, _phiế, ikia,
  { {0x63a30027,0x5fa50235,0xdce413f2,0x00000000}},	//   _cinn, _गूगल, dnič,
  { {0x63a30034,0x6283001f,0x6d4400fe,0x00000000}},	//   _dinn, _cyno, kkia,
  { {0x63a313f3,0x6283001f,0x443f00a4,0x00000000}},	//   _einn, _dyno, byu_,
  { {0xfd4f001b,0x61e1001f,0x7d160731,0x00000000}},	//   _thiế, arll, ddys,
  { {0x63a313f4,0x6d4413f5,0x6283002b,0x00000000}},	//   _ginn, ekia, _fyno,
  { {0x26cc0016,0x6d5f0089,0xdd95000d,0x00000000}},	//   _medo_, tiqa, завы,
  { {0x91b7007e,0x63a313f6,0x1bb5000d,0x00000000}},	//   _بطور_, _zinn, збаў,
  { {0x6d5f0089,0x317200ea,0x6d4d13f7,0x00000000}},	// [1a50] riqa, ézze_, rhaa,
  { {0xce95005a,0x6d440ddd,0x7c2d01a8,0x00000000}},	//   _напъ, akia, rxar,
  { {0x60cd014f,0x657b0035,0x7d160078,0x00000000}},	//   _keam, youh, bdys,
  { {0x644000fe,0x89a80054,0x6ee7005d,0x00000000}},	//   kymi, іків_, _اسکل,
  { {0x65690024,0x8807007e,0xb80701fb,0x00000000}},	//   vneh, تظام, تباه,
  { {0x26cc13f8,0xdc3a0063,0x60cd0d17,0x00000000}},	//   _cedo_, _העשר, _leam,
  { {0x656913f9,0x63a313fa,0x26cc00f8,0x00000000}},	//   tneh, _rinn, _dedo_,
  { {0x60cd13fb,0x442d00cd,0x63ab13fc,0x00000000}},	//   _neam, txe_, _pugn,
  { {0x3f980185,0x656913fd,0xb4bb0053,0x00000000}},	//   ymru_, rneh, _अभी_,
  { {0xaacb0161,0x657b0080,0x6d9304a5,0x00000000}},	//   िरिक, souh, lçad,
  { {0x171a0063,0x443f00a4,0x63a313fe,0x00000000}},	//   _לֵאמ, syu_, _vinn,
  { {0x6d9313ff,0xdce40c61,0x63a31400,0x00000000}},	//   nçad, tnič, _winn,
  { {0x8235006a,0x62830051,0x63ab00a4,0x00000000}},	//   زرگا, _wyno, _uugn,
  { {0x61e81401,0x20dc008b,0x63a31402,0x00000000}},	//   budl, ửi_, _uinn,
  { {0xdce4055e,0x61461403,0xddde011b,0x00000000}},	//   snič, _нека, _vypů,
  { {0x6d441404,0x60cd032c,0xdce40734,0x00000000}},	//   ukia, _geam, pnič,
  { {0x2fc9001f,0x945d0022,0x6d441405,0x00000000}},	// [1a60] _gwag_, mańs, rkia,
  { {0x8eea0086,0x78a90290,0xbcfb0003,0x00000000}},	//   _умов_, _agev, _améd,
  { {0x26cc1101,0x64400051,0xb05b004d,0x00000000}},	//   _redo_, zymi, nbän,
  { {0x4c6a0121,0x64400050,0xc9590085,0x00000000}},	//   _гимн_, yymi, оўі_,
  { {0x2d8202ab,0x0c23000d,0xad1b0063,0x00000000}},	//   _ikke_, _змян, _הוכר,
  { {0x6d93017d,0x98a30456,0xeb971406,0x00000000}},	//   açad, хиче, _ния_,
  { {0x78ad0add,0x945d0051,0x8b23005a,0x00000000}},	//   žava, kańs, _ядре,
  { {0xe5a30001,0x945d0051,0x64401407,0x00000000}},	//   нији, jańs, tymi,
  { {0x7bd60150,0x60cd1408,0xd37a0062,0x00000000}},	//   nsyu, _ream, йчо_,
  { {0x60cd1409,0xcc570063,0x6440057c,0x00000000}},	//   _seam, פסיק_, rymi,
  { {0x60cd0004,0x78a900ac,0x91e30002,0x00000000}},	//   _peam, _ygev, ноќе,
  { {0xf8cc0161,0x39460006,0x7bd600a4,0x00000000}},	//   ारिय, nkos_, ksyu,
  { {0x60cd140a,0xb97b0063,0xb4e80042,0x00000000}},	//   _veam, מנטי, बली_,
  { {0xd14b006a,0x90980062,0xdfa40002,0x00000000}},	//   _گشتن_, явят_, ејсо,
  { {0x7bd60089,0xfe700021,0x60cd140b,0x00000000}},	//   esyu, هدف_, _team,
  { {0x2d580055,0x6b40007a,0xe21300de,0x00000000}},	//   пись_, _mögu, _أبوع,
  { {0x2fc90bc1,0x6b400026,0x6728007d,0x00000000}},	// [1a70] _uwag_, _lögu, _ondj,
  { {0x2aab0138,0xe451009a,0x7ff400de,0x00000000}},	//   стао_, כֶב_, _أسيا,
  { {0x442b008b,0x7f3c0063,0x62860051,0x00000000}},	//   ̣c_, _לעזו, ękow,
  { {0xbcfb02dd,0x39460150,0x67280019,0x00000000}},	//   _ejér, gkos_, _andj,
  { {0x16a90076,0xe7391001,0x6d930367,0x00000000}},	//   овли_, жел_, rçad,
  { {0x945d0022,0x2be20042,0x2d89140c,0x00000000}},	//   zańs, _पिता, llae_,
  { {0x25a6140d,0x75390022,0x00000000,0x00000000}},	//   _biol_, _powz,   ,
  { {0x6b400026,0xf993007e,0xe3b9140e,0x00000000}},	//   _dögu, _سبز_, оби_,
  { {0x56f50002,0x395f059f,0x0ebf0042,0x00000000}},	//   _опаѓ, _imus_, ्राड,
  { {0xaadd0053,0xc245140f,0xf8680044,0x00000000}},	//   मणिक, днок, _عملي_,
  { {0x945d0051,0x7790007e,0x66f20042,0x00000000}},	//   tańs, _حیوا, _घातक_,
  { {0x69d80016,0xb05b00bd,0x6b400137,0x00000000}},	//   ávei, rbän, _högt,
  { {0x34940141,0x657c013d,0x6f17008d,0x00000000}},	//   _зацр, _írha, _baxc,
  { {0x2d8900ac,0x2268004c,0x6265012d,0x00000000}},	//   elae_, átká_, _овла,
  { {0xdef9000d,0x945d0051,0x8fa31410,0x00000000}},	//   чыў_, pańs, таре,
  { {0xa187005a,0xdb240043,0x00000000,0x00000000}},	//   _обща_, کوئی,   ,
  { {0x31600075,0xad6500de,0x50db009d,0x00000000}},	// [1a80] _imiz_, رافه, _וחפצ,
  { {0x7bd60397,0x32ba0047,0x394d1411,0x00000000}},	//   rsyu, ַזנד, _ales_,
  { {0x6b5210c4,0x394d00ac,0xceb312cd,0x00000000}},	//   _lægg, _bles_, _בית_,
  { {0x39460006,0x78ad01b3,0x9cb6007e,0x00000000}},	//   ukos_, žavn, _زمست,
  { {0x6b400026,0xeb9a06da,0x39461412,0x00000000}},	//   _sögu, _мим_, rkos_,
  { {0x394d03d9,0xd5ba0187,0x46140021,0x00000000}},	//   _eles_, оси_, فوتر,
  { {0xda650021,0x394d00ca,0x00000000,0x00000000}},	//   _كافي, _fles_,   ,
  { {0xe947007e,0xb4e80053,0x38790003,0x00000000}},	//   _قرقی, बले_, égré_,
  { {0xd90d007e,0x25a61413,0x03c3014b,0x00000000}},	//   _دین_, _viol_, ксэм,
  { {0x628f0051,0x2129004c,0x25f60042,0x00000000}},	//   ęcon, _snah_, _एमपी_,
  { {0x6b4001e3,0xcb130063,0x394d004e,0x00000000}},	//   _högs, דלת_, _yles_,
  { {0x2d4700be,0x27e61414,0x05661415,0x00000000}},	//   _põem_, oron_, _ювен,
  { {0x6d430529,0x104b0086,0x27e601f4,0x00000000}},	//   _înai, іями_, nron_,
  { {0x4034005e,0x2bb50042,0x63bd1416,0x00000000}},	//   њерс, _अंबा, ísne,
  { {0x3da70088,0x6b400014,0x27e61417,0x00000000}},	//   драб, _lögs, hron_,
  { {0x3f8a005f,0x00000000,0x00000000,0x00000000}},	//   albu_,   ,   ,
  { {0x1eab0021,0x2bbb0044,0x00000000,0x00000000}},	// [1a90] _وادي_, تازة_,   ,
  { {0xa3e60161,0x2d8900ac,0x1b780021,0x00000000}},	//   _बटन_, slae_, وصلة_,
  { {0x27e602dd,0x6b4000ea,0x27e00139,0x00000000}},	//   eron_, _rögt, áinn_,
  { {0xab5b0058,0x61fa1418,0x7e9a009a,0x00000000}},	//   _stüd, ittl, _מסתו,
  { {0x7d0d13e6,0x78ad007d,0x7643002b,0x00000000}},	//   meas, žavo, wyny,
  { {0x7d0d1419,0xf77301a7,0x764300fe,0x00000000}},	//   leas, خاص_, tyny,
  { {0x27e6141a,0xfbb50042,0x2bb50082,0x00000000}},	//   aron_, _अंडम, _अंडा,
  { {0x7d0d141b,0x27e6141c,0x1a68005d,0x00000000}},	//   neas, bron_, _تیمی_,
  { {0xa775000d,0x998500ea,0x61fa141d,0x00000000}},	//   _злач, _élő_, ettl,
  { {0x6b4000c7,0x6b5200b9,0xdb0600ea,0x00000000}},	//   _högr, _vægg, _kuká,
  { {0x26c700c3,0x7d0d00fe,0x59990063,0x00000000}},	//   mbno_, keas, ּשָׁ,
  { {0x361a0063,0x200500dd,0x7d0d00dd,0x00000000}},	//   _מועד, ălin_, jeas,
  { {0x61fa0034,0x2d80141e,0xab640058,0x00000000}},	//   attl, voie_, lmüş,
  { {0x6d4f141f,0x3eac06a5,0x03a50002,0x00000000}},	//   _alca, ødt_, _џико,
  { {0x236500c7,0x6b5200b9,0xfd960121,0x00000000}},	//   milj_, _jæge, ешаю,
  { {0x7d0d1420,0x27e61421,0x65a7013d,0x00000000}},	//   geas, yron_, _műho,
  { {0x6b520146,0xed571001,0xbf9b00ac,0x00000000}},	// [1aa0] _læge, хот_, rwêr,
  { {0x78ad082a,0xdb06013d,0x27e61422,0x00000000}},	//   žavl, _buká, vron_,
  { {0x7d0d1423,0x2d73007d,0x27e61424,0x00000000}},	//   beas, mćen_, wron_,
  { {0x7d0d09ee,0x6d930058,0x27e61425,0x00000000}},	//   ceas, rçac, tron_,
  { {0x58830be6,0x6846000d,0x27e61426,0x00000000}},	//   лыша, энда, uron_,
  { {0x7bc41427,0xf09300b5,0x27e000c3,0x00000000}},	//   mpiu, אנד_, šino_,
  { {0x3872000c,0xd5b10013,0xe1e701fb,0x00000000}},	//   _ţară_, _cú_, _حس_,
  { {0x69dc1428,0x88c50021,0x76a90054,0x00000000}},	//   _ivre, _لتكل, фтів_,
  { {0x8881006a,0xb603003d,0xd7ca0044,0x00000000}},	//   _پیون, āšan, _رواه_,
  { {0xb7d70021,0x7d0d003b,0x41e60454,0x00000000}},	//   _أولا_, zeas, німа,
  { {0xf6290021,0xf7770063,0xc2980054,0x00000000}},	//   _يسمى_, _טעמי_, ькох_,
  { {0x29020137,0x914b012c,0xb5050044,0x00000000}},	//   _ökad_, їчна_, _لظهو,
  { {0x30a7000d,0x7d0d000c,0xe53b0063,0x00000000}},	//   эров, veas, _מתאר,
  { {0x69dc1429,0x4ea7142a,0x23780044,0x00000000}},	//   _ovre, ерба, _تمتد_,
  { {0x7d0d142b,0x3ea5142c,0x831b0063,0x00000000}},	//   teas, ält_, _מוגז,
  { {0x2bb50053,0xdb060061,0x6286011b,0x00000000}},	//   _अंदा, _ruká, řkos,
  { {0x69dc142d,0xe7cf0053,0x7d0d142e,0x00000000}},	// [1ab0] _avre, _सौंप, reas,
  { {0x7d0d142f,0x61e81430,0xfaa5005d,0x00000000}},	//   seas, ordl, نجای,
  { {0x5ee80063,0xdcfd001c,0x7d0d1431,0x00000000}},	//   _אַרְ, _eksā, peas,
  { {0x64c41035,0x20090150,0x63aa0014,0x00000000}},	//   nčič, _kpai_, _lifn,
  { {0x69dc1432,0x399e0080,0xe894045b,0x00000000}},	//   _evre, _růst_, гаць,
  { {0x3f830249,0x7af50022,0xe7580054,0x00000000}},	//   noju_, _uczt, ничі_,
  { {0xc8f5011c,0x26c70384,0xe7360062,0x00000000}},	//   _извъ, rbno_, тещ_,
  { {0xab640058,0x6b4000a5,0x69c51433,0x00000000}},	//   rmüş, _högp, mphe,
  { {0x290f1434,0x3f831435,0x03950330,0x00000000}},	//   mega_, koju_, кроя,
  { {0x290f0b9c,0x628a01e1,0x42250054,0x00000000}},	//   lega_, _byfo, вдов,
  { {0x628a001f,0x7bcf001f,0x2d68005b,0x00000000}},	//   _cyfo, _lwcu, iğer_,
  { {0x290f0198,0x50460138,0x291d0009,0x00000000}},	//   nega_, вемб, ndwa_,
  { {0x30760699,0xc8da0063,0x628e01c8,0x00000000}},	//   тунс, וקרט, ýbor,
  { {0xdf15019d,0x5f060062,0x290f1436,0x00000000}},	//   льсь, ъзга, hega_,
  { {0x290f1437,0x628a001f,0x02190054,0x00000000}},	//   kega_, _gyfo, _ціль_,
  { {0x290f1312,0x2d680058,0x78ad00c2,0x00000000}},	//   jega_, eğer_, žavj,
  { {0x290f0004,0xc4d20e2a,0x8c430076,0x00000000}},	// [1ac0] dega_, יגן_, аете,
  { {0x7bc40078,0x290f004b,0x7fd70041,0x00000000}},	//   rpiu, eega_, _שויס_,
  { {0xe8fa0088,0xa9a6005a,0xab5b00bd,0x00000000}},	//   дле_, вижд, _stüc,
  { {0x290f1438,0x81bc008f,0x48660062,0x00000000}},	//   gega_, lvēc, кълб,
  { {0xd943005e,0xe7b3043e,0x981300de,0x00000000}},	//   јечи, لمند, لبوا,
  { {0xbcfb0080,0x6d931439,0x69d8004a,0x00000000}},	//   _jmén, nçan, áves,
  { {0x6f0301f7,0xceb30063,0x69dc007d,0x00000000}},	//   _önce, סיה_, _uvre,
  { {0x94180121,0x38c8005d,0x15140456,0x00000000}},	//   ежит_, _ساری_, удия,
  { {0xa5070001,0x98a300e2,0xa96702b3,0x00000000}},	//   тења_, _вите, _рита_,
  { {0x5fdc0053,0x926a0002,0xf5390066,0x00000000}},	//   _बिजल, дрма_, ajť_,
  { {0x973c007d,0x3f83143a,0xe737032d,0x00000000}},	//   _nići, voju_, _шеф_,
  { {0xbcfb0164,0x27e908ed,0x3f830022,0x00000000}},	//   _amén, šane_, woju_,
  { {0x3f83143b,0x5064143c,0x10740054,0x00000000}},	//   toju_, атра, илюю,
  { {0x20e3008b,0x3f830078,0x643b0047,0x00000000}},	//   ổi_, uoju_, _קעגנ,
  { {0x7e440001,0xaed405ac,0x291d0022,0x00000000}},	//   ахте, росш, ydwa_,
  { {0xf1a40088,0x6d93017d,0xb0630072,0x00000000}},	//   _крын, açan, ääss,
  { {0x290f143d,0x9da80062,0xdb0700cd,0x00000000}},	// [1ad0] vega_, търа_, ŀlíc,
  { {0x3b54000d,0xdca40001,0x69c510f9,0x00000000}},	//   акур, рађи, tphe,
  { {0x2bdf016a,0x7c2600bd,0x290f143e,0x00000000}},	//   _फटका, _erkr, tega_,
  { {0x4426143f,0xdced007c,0x69c51440,0x00000000}},	//   _oro_, onač, rphe,
  { {0x69c50034,0x290f1441,0x44260072,0x00000000}},	//   sphe, rega_, _nro_,
  { {0x290f1442,0x77840097,0x6d4d1443,0x00000000}},	//   sega_, аліз, lkaa,
  { {0x64460031,0x69d80078,0x7d1d1444,0x00000000}},	//   økin, šver, _kass,
  { {0xdb0d048e,0x44260185,0x6d4d1445,0x00000000}},	//   mpañ, _bro_, nkaa,
  { {0xb465007e,0x7d1d053f,0x6b520014,0x00000000}},	//   دگاه, _mass, _hæga,
  { {0x44261446,0xdced017f,0x7d1d1447,0x00000000}},	//   _dro_, dnač, _lass,
  { {0x6d4d024a,0xe6590021,0x44261448,0x00000000}},	//   kkaa, _ثلاث_, _ero_,
  { {0x6d4d1449,0x4426144a,0x7d1d144b,0x00000000}},	//   jkaa, _fro_, _nass,
  { {0xd9e00161,0x656900fe,0x73e50002,0x00000000}},	//   _पट्ट, mieh, _солз,
  { {0x7d1d00a4,0x6569144c,0x9264005d,0x00000000}},	//   _aass, lieh, ادیم,
  { {0xd3360063,0xb0630019,0x7d1d144d,0x00000000}},	//   _תרצה_, äärs, _bass,
  { {0x6d4d002c,0x8d550002,0x7d1d144e,0x00000000}},	//   gkaa, атуч, _cass,
  { {0x0c260088,0x5f76007e,0x7d1d144f,0x00000000}},	// [1ae0] ыман, _مادر, _dass,
  { {0x656900bd,0xc7b9013d,0x6d4d1450,0x00000000}},	//   hieh, _erők_, akaa,
  { {0xeb970001,0x0e75000d,0x60d61451,0x00000000}},	//   ћих_, _выяў, _keym,
  { {0x3940007a,0x6d931452,0x7d1d0853,0x00000000}},	//   ðis_, nçal, _gass,
  { {0x6f1e03e8,0x48e30878,0xf74600fd,0x00000000}},	//   _kapc, сочв, ледо,
  { {0xe737005a,0x4426017d,0x7791007e,0x00000000}},	//   леч_, _rro_, قیقا,
  { {0xf6e5000d,0x7c241453,0x7d1d1454,0x00000000}},	//   рцін, lvir, _yass,
  { {0x44261455,0x398e004c,0xdb0d0014,0x00000000}},	//   _pro_, kýsi_, lpað,
  { {0x3856005a,0x136a026b,0x7c241456,0x00000000}},	//   _съвс, ешни_, nvir,
  { {0xbcfb03b2,0x07a60138,0xa3e50053,0x00000000}},	//   _amél, _сазн, _फिर_,
  { {0xe1350055,0x65690024,0x22940121,0x00000000}},	//   анны, bieh, риня,
  { {0x6569034d,0x51870079,0xd2570088,0x00000000}},	//   cieh, ѓуна, уць_,
  { {0x64460019,0x44261457,0xa3d4007f,0x00000000}},	//   äkid, _uro_, _толч,
  { {0x2b8f0199,0x7c241458,0x7d1d1459,0x00000000}},	//   rück_, dvir, _sass,
  { {0xadd50001,0x41e6000d,0x6d4d145a,0x00000000}},	//   робљ, _сіла, tkaa,
  { {0x60d6007a,0x7c24007a,0x6d4d00fe,0x00000000}},	//   _geym, fvir, ukaa,
  { {0x6d4d145b,0x7d1d145c,0xdce40130,0x00000000}},	// [1af0] rkaa, _vass, znić,
  { {0x65690199,0x7d1d145d,0xda7b000d,0x00000000}},	//   zieh, _wass, няе_,
  { {0x7d1d145e,0xda15000a,0x6d9300cd,0x00000000}},	//   _tass, рдењ, lçam,
  { {0xdce40045,0x6b9c004d,0x316b0022,0x00000000}},	//   knię, _ehrg, nicz_,
  { {0x6d930bc8,0xdb0d0871,0x69de145f,0x00000000}},	//   nçam, spañ, aspe,
  { {0x6d580006,0x5fbc0047,0xd6a9007e,0x00000000}},	//   _įvai, עצונ, نگام_,
  { {0xf8c903b2,0x65691460,0x05550062,0x00000000}},	//   _créé_, tieh, ития,
  { {0x79a4000a,0x15450076,0x7bdf0516,0x00000000}},	//   _груе, реим, osqu,
  { {0x645b0035,0xdb0f05ab,0x7bdf1461,0x00000000}},	//   uzui, _lucí, nsqu,
  { {0x7bdf0732,0x33650b3f,0x645b006f,0x00000000}},	//   isqu, рвог, rzui,
  { {0x291f0019,0x7d041462,0x7c241463,0x00000000}},	//   _kaua_, yfis, zvir,
  { {0xc4f80021,0xdb0f00dd,0x216a1464,0x00000000}},	//   _معها_, _jucâ, тими_,
  { {0xb4c30394,0x6d93005b,0x68e40025,0x00000000}},	//   ्री_, rçal, óidi,
  { {0x2d8b0080,0x64460072,0xab5b004d,0x00000000}},	//   _akce_, äkie, _stün,
  { {0x6d930268,0x7bdf048c,0x60d60026,0x00000000}},	//   pçal, esqu, _teym,
  { {0x7c2400eb,0x27e001b3,0x69de1465,0x00000000}},	//   tvir, šini_, vspe,
  { {0x7d040026,0x6b660002,0x3ab6005e,0x00000000}},	// [1b00] rfis, акаа, аљет,
  { {0x69de1466,0x9e660071,0xd00f007e,0x00000000}},	//   tspe, _ввод, _کلی_,
  { {0x399c0025,0x20020019,0x2be20053,0x00000000}},	//   híse_, ltki_, _पिका,
  { {0x6d43000c,0x929a0063,0x69de1467,0x00000000}},	//   _înap, דיעת, rspe,
  { {0x27e00025,0xdb0f003b,0x69de1468,0x00000000}},	//   éin_, _ducâ, sspe,
  { {0x35e60001,0x69de0137,0xbf360047,0x00000000}},	//   ацив, pspe, שאַץ_,
  { {0x09e30095,0xe9d70062,0x65c3007b,0x00000000}},	//   _морн, _вкс_, обја,
  { {0x27e9003d,0xa5340459,0x399c0025,0x00000000}},	//   šana_, снич, físe_,
  { {0xc955000d,0x93460021,0xa98b0063,0x00000000}},	//   _утры, لخدم, _יָמִ,
  { {0x316b0976,0x9f4b004c,0xe7630330,0x00000000}},	//   wicz_, tucí_, _двуп,
  { {0x394400ac,0x236b0066,0x8ab71469,0x00000000}},	//   _koms_, _žijú_, יליג_,
  { {0x26dc146a,0x7bc60d83,0x39440078,0x00000000}},	//   lavo_, _otku, _joms_,
  { {0xb4d20053,0x64a605c5,0x3944146b,0x00000000}},	//   वरी_, _тада, _moms_,
  { {0x6d930555,0x26dc146c,0xe72e0085,0x00000000}},	//   rçam, navo_, зеi_,
  { {0xc1790006,0x7bc60b4f,0x539b0063,0x00000000}},	//   urės_, _atku, _שיוו,
  { {0x39440bbd,0xac1901d5,0x06570063,0x00000000}},	//   _noms_, лобу_, בילך_,
  { {0x7bdf146d,0x26dc146e,0x4bd80044,0x00000000}},	// [1b10] usqu, kavo_, لبلد_,
  { {0x7bdf03b2,0x26dc146f,0x68fb1470,0x00000000}},	//   rsqu, javo_, _scud,
  { {0x26dc0006,0x49a70141,0x6f150331,0x00000000}},	//   davo_, ајда, mezc,
  { {0x8c4801f7,0x58d90054,0xdb0e109c,0x00000000}},	//   _bağı, уддя_, _libè,
  { {0xdc3500b7,0xd7fb000d,0x9be40054,0x00000000}},	//   _האָט_, туе_, _мірк,
  { {0x8c4801f7,0x6f15006d,0x26dc0006,0x00000000}},	//   _dağı, nezc, gavo_,
  { {0x6b5200b9,0xcf580063,0x60dd1471,0x00000000}},	//   _mægl, שבות_, kasm,
  { {0x74150032,0x5e780063,0x20020022,0x00000000}},	//   موعا, יתון_, ytki_,
  { {0x69c7017f,0xb345017d,0x21201472,0x00000000}},	//   _htje, _noçã, _raih_,
  { {0x43740086,0x26dc0290,0xda0e0053,0x00000000}},	//   жуют, cavo_, _सहमत_,
  { {0xe6950032,0x6f15006d,0x399c0139,0x00000000}},	//   _الاد, dezc, síse_,
  { {0xf65201f9,0x8c48005b,0x60dd1473,0x00000000}},	//   _מצב_, _yağı, gasm,
  { {0x98790047,0x657e013d,0xf48702d8,0x00000000}},	//   ראָט, éphe, _тужн,
  { {0x200213d7,0x69c7007d,0x8f760054,0x00000000}},	//   rtki_, _otje, сумі,
  { {0x67211474,0x6b6f0078,0x60dd0150,0x00000000}},	//   _malj, _mėgė, basm,
  { {0x26dc146f,0xc2120063,0x5f76005d,0x00000000}},	//   zavo_, _זהה_, _گابر,
  { {0x0ab60021,0x39441475,0xdca30054,0x00000000}},	// [1b20] محاد, _roms_, зати,
  { {0xb05b01e3,0xef1a0138,0x39440162,0x00000000}},	//   rbät, _смо_, _soms_,
  { {0x26dc0006,0x8c480058,0x72da0041,0x00000000}},	//   vavo_, _sağı, רקעג,
  { {0xb4c3024c,0x69c31476,0xd910005d,0x00000000}},	//   ्रो_, ínea, بیر_,
  { {0xdb0e0ec6,0x26dc1477,0x81bc008f,0x00000000}},	//   _libé, tavo_, evēl,
  { {0x66e30001,0x6d461478,0xa09b00ff,0x00000000}},	//   поља, _hoka, ניסט,
  { {0x67210add,0x8626000d,0x6d461479,0x00000000}},	//   _dalj, сьле, _koka,
  { {0x6d46024a,0x6723082a,0xdb0e00cd,0x00000000}},	//   _joka, adnj, _sibè,
  { {0x6d460006,0x3f8a007d,0x26dc147a,0x00000000}},	//   _moka, kobu_, pavo_,
  { {0x8c1b014e,0x69c103b2,0x6d46147b,0x00000000}},	//   נויי, _élec, _loka,
  { {0x6d4600e8,0x6d5a001c,0xdd210078,0x00000000}},	//   _ooka, ītaj, _rįžk,
  { {0x6721074f,0x6d46147c,0x27e0147d,0x00000000}},	//   _zalj, _noka, šinu_,
  { {0x60dd147e,0x7d16005b,0xc058013c,0x00000000}},	//   rasm, deys, бір_,
  { {0x93fb0063,0x60dd147f,0xc0580454,0x00000000}},	//   _עלוי, sasm, сію_,
  { {0x6f1502dd,0x6d461480,0xde580054,0x00000000}},	//   rezc, _boka, барі_,
  { {0x2b940989,0x2d980044,0x88bd056c,0x00000000}},	//   bäck_, مَّد_, _maśc,
  { {0x81bc003d,0xc1740063,0x6d9302a7,0x00000000}},	// [1b30] zvēl, _מחק_, nçai,
  { {0x8aa70699,0x6b520014,0x1aa7005e,0x00000000}},	//   бред, _hægj, бјег,
  { {0x83fd013d,0xc8b50766,0xdb26005d,0x00000000}},	//   mzőe, ослы, تولی,
  { {0x75220024,0x6dbc007d,0x67211481,0x00000000}},	//   _naoz, _očaj, _salj,
  { {0x67210aba,0xf7450121,0xbcfb0139,0x00000000}},	//   _palj, жело, _nméi,
  { {0x7bcd1482,0x27e91483,0x81bc008f,0x00000000}},	//   mpau, šano_, tvēl,
  { {0x69c7017f,0x6723017f,0x67211484,0x00000000}},	//   _utje, rdnj, _valj,
  { {0x67210089,0x6b520014,0x2d680075,0x00000000}},	//   _walj, _nægj, vşek_,
  { {0xe3b61485,0x27e00027,0x6b4000ea,0x00000000}},	//   обы_, áint_, _rögz,
  { {0x98ad0024,0xd6d80002,0x798b1486,0x00000000}},	//   _hneď_, _гтц_, logw,
  { {0x81bc008f,0x4427007e,0x6dbc00a8,0x00000000}},	//   lvēj, _گراف, _ečaj,
  { {0x798b002b,0xe435007e,0x75221098,0x00000000}},	//   nogw, _وفاد, _gaoz,
  { {0x6d461487,0xbf9b017d,0x7d1600fe,0x00000000}},	//   _roka, rtên, veys,
  { {0xbf9b0016,0x83fd00ea,0x20ea008b,0x00000000}},	//   stên, rződ, ời_,
  { {0x7d16024a,0x6d461488,0x83fd013d,0x00000000}},	//   teys, _poka, sződ,
  { {0xb05b0137,0x2b94004d,0x3f8a1026,0x00000000}},	//   rbär, päck_, sobu_,
  { {0xed57000a,0x7bcd00a4,0x0b461489,0x00000000}},	// [1b40] цот_, gpau, онан,
  { {0x6d460022,0x68e90058,0x7c2b0046,0x00000000}},	//   _woka, _aded, ægra,
  { {0x32050037,0x6d46148a,0x7bcd00fe,0x00000000}},	//   ntly_, _toka, apau,
  { {0xc27a0047,0x6d460072,0x00000000,0x00000000}},	//   ברעי, _uoka,   ,
  { {0x6dbc0024,0x68e9001f,0x57a6036a,0x00000000}},	//   _očak, _dded, ошка,
  { {0xe3a70021,0x05ea148b,0x68e9148c,0x00000000}},	//   _زر_, афии_, _eded,
  { {0xd6d9148d,0xd5b70055,0xda0e0053,0x00000000}},	//   сті_, осы_, _सहित_,
  { {0x7c29148e,0xceb3009a,0xe5a301ce,0x00000000}},	//   _šeri, ויו_, мији,
  { {0x8d5b0047,0x320500e5,0x83fd013d,0x00000000}},	//   יכקי, etly_, ezőb,
  { {0x46a60088,0x6d930003,0xc7b900ea,0x00000000}},	//   _дазв, rçai, _erős_,
  { {0x2b94004d,0x7bcd008f,0xd377000d,0x00000000}},	//   räch_, zpau, ўчы_,
  { {0x81bc003d,0xdbd20058,0xa2ae0042,0x00000000}},	//   lvēk, _güçt, ीशब्,
  { {0x32050034,0x00000000,0x00000000,0x00000000}},	//   atly_,   ,   ,
  { {0xdefb0088,0x6d930858,0x389b0047,0x00000000}},	//   шым_, nçav, ייכנ,
  { {0x32050037,0xd2500032,0x6d580078,0x00000000}},	//   ctly_, _سنة_, _įvar,
  { {0x6ecb0161,0x5cb9000d,0xd1310044,0x00000000}},	//   _त्रु, слаў_, _أمة_,
  { {0x4c940076,0x351b0063,0x0cab148f,0x00000000}},	// [1b50] дитс, סומנ, ртви_,
  { {0x7f19007e,0x7bcd1490,0x69c30516,0x00000000}},	//   _ايدز_, rpau, íneo,
  { {0x7bcd0812,0x99870080,0xdb0e00ea,0x00000000}},	//   spau, ínů_, óján,
  { {0x7bcd00fe,0x58d40054,0x28f80054,0x00000000}},	//   ppau, доцт, жець_,
  { {0xdd3a0063,0x5d3a0063,0x3d3a0063,0x00000000}},	//   _הערכ, _התרא, _הגרס,
  { {0x9f530003,0x70b70053,0x3205004c,0x00000000}},	//   écès_, ःशुल, ytly_,
  { {0x644601a9,0x00000000,0x00000000,0x00000000}},	//   äkin,   ,   ,
  { {0x6d93017d,0xea000013,0xab5b0244,0x00000000}},	//   açav, _hiếp_, _stüh,
  { {0xf3f10021,0x657e00f4,0xea000013,0x00000000}},	//   رأة_, épha, _kiếp_,
  { {0x6d5a001c,0xdce40058,0xe7330044,0x00000000}},	//   ītai, kniğ, _تصر_,
  { {0x672e0046,0x83640044,0x3d0c0082,0x00000000}},	//   _óbja, بديل, ड्डे_,
  { {0x32050034,0xa5c60026,0xd24e0021,0x00000000}},	//   rtly_, slóð, انَ_,
  { {0x3205033c,0x9f4201c2,0x40960085,0x00000000}},	//   stly_, lské_, ярот,
  { {0x320500e5,0x657b004b,0x80cc0042,0x00000000}},	//   ptly_, lnuh, _थ्रे,
  { {0x6da61491,0x9f420114,0xd24e007e,0x00000000}},	//   зива, nské_, _منو_,
  { {0xf8b9008b,0xc6920047,0x3cf60053,0x00000000}},	//   _ngũ_, גאל_, इलें_,
  { {0x27e91253,0x657b00a4,0xf3f9003b,0x00000000}},	// [1b60] šanj_, inuh, nuţ_,
  { {0x8b230076,0x8b260088,0x0c79000d,0x00000000}},	//   ндуе, ядзе, істы_,
  { {0xdebb0063,0x2d9e0813,0x9f420114,0x00000000}},	//   _למיל, ïtes_, jské_,
  { {0x442f1492,0x9f420114,0xf9690086,0x00000000}},	//   _org_, dské_, орій_,
  { {0x1818007e,0x9f42004c,0x28cb0042,0x00000000}},	//   تراک_, eské_, ाड़ि,
  { {0xbb4a0032,0x7bcb1493,0x38330085,0x00000000}},	//   _الآن_, ígue, энір,
  { {0x6b520026,0x6d931494,0x442f1495,0x00000000}},	//   _nægi, rçav, _arg_,
  { {0xa824007e,0x6d441496,0xd90d007e,0x00000000}},	//   _يکشن, njia, _نیم_,
  { {0x9f591497,0x6d441498,0xdc3a0054,0x00000000}},	//   ltså_, ijia, ицiї_,
  { {0xdb1d017d,0x32541499,0x442f149a,0x00000000}},	//   _ausê, двор, _drg_,
  { {0x442f0173,0x27e6149b,0xdb21013d,0x00000000}},	//   _erg_, lson_, ötés,
  { {0x6d93149c,0x463b0047,0x3cf60042,0x00000000}},	//   nçat, _לעבע, इलों_,
  { {0xdb0e0025,0x9054000d,0xdb050139,0x00000000}},	//   _aibí, евяц, smhé,
  { {0xd370007e,0x27e60269,0xbf9b0003,0x00000000}},	//   _جهت_, ison_, ptêm,
  { {0xdd95000d,0x26de149d,0x639b009a,0x00000000}},	//   давы, _meto_, _הסגנ,
  { {0x5d990088,0x26de08ea,0xebd90062,0x00000000}},	//   ікаў_, _leto_, ждаш_,
  { {0x7bc00003,0x68e20078,0x9f42004c,0x00000000}},	// [1b70] _émul, daod, zské_,
  { {0x6d56053b,0x7ac4149e,0x32130051,0x00000000}},	//   akya, есце, łbyś_,
  { {0x98bf0529,0x61fa149f,0x25a9017c,0x00000000}},	//   _nouă_, nutl, ňali_,
  { {0x1a68007e,0xdb06004d,0x9f420114,0x00000000}},	//   سیقی_, _zukü, vské_,
  { {0xea00001b,0x7b0200fe,0x7d0d14a0,0x00000000}},	//   _tiếp_, äytö, mfas,
  { {0x7c2d14a1,0x9f420114,0x26de01f4,0x00000000}},	//   mvar, tské_, _ceto_,
  { {0x7c2d14a2,0x61fa004b,0xa3df0053,0x00000000}},	//   lvar, jutl, धीन_,
  { {0x98bf0529,0x53c90184,0x9f420114,0x00000000}},	//   _două_, огим_, rské_,
  { {0xb4bd016a,0xbcfb00ea,0x61fa004d,0x00000000}},	//   _आली_, _elég, eutl,
  { {0x9f420080,0xdb1d0137,0xa774000d,0x00000000}},	//   pské_, _utsä, _злуч,
  { {0x7d0d08a5,0x6d5d005b,0x7c2d004b,0x00000000}},	//   kfas, _olsa, hvar,
  { {0x442f082a,0x65600025,0x2d680058,0x00000000}},	//   _trg_, chmh, nşet_,
  { {0x995c0124,0xdb0e0066,0xcfaa009e,0x00000000}},	//   níš_, _sibí, قاسم_,
  { {0x61fa1472,0x7c2d14a3,0x6d5d14a4,0x00000000}},	//   butl, dvar, _alsa,
  { {0x7d0d00bd,0xe607007e,0x7c2d14a5,0x00000000}},	//   ffas, خش_, evar,
  { {0x78bb0035,0xf8a5007e,0x752914a6,0x00000000}},	//   _nguv, _مک_, ndez,
  { {0x9f520026,0x7529004d,0x7c2d14a7,0x00000000}},	// [1b80] ðbót_, idez, gvar,
  { {0xeb9f00d1,0x7d0d0035,0x0aea0054,0x00000000}},	//   _spør_, afas, ідей_,
  { {0x2fc00025,0x26de14a8,0x6f1c14a9,0x00000000}},	//   _huig_, _reto_, merc,
  { {0x442d0117,0x26de14aa,0x98a000c2,0x00000000}},	//   kve_, _seto_, žič_,
  { {0x510d0047,0x6d930110,0x752901f4,0x00000000}},	//   מהאַ, rçat, ddez,
  { {0x64460019,0x61fa005b,0x442d14ab,0x00000000}},	//   äkim, yutl, dve_,
  { {0x27e614ac,0x442d14ad,0x657e0003,0x00000000}},	//   sson_, eve_, épho,
  { {0x6f1c14ae,0x442d14af,0x27e614b0,0x00000000}},	//   herc, fve_, pson_,
  { {0xea00008b,0x26de0827,0xa8030062,0x00000000}},	//   _khắp_, _teto_, _изтл,
  { {0x6d9314b1,0x6f1c006d,0x61fa0089,0x00000000}},	//   nçar, jerc, tutl,
  { {0x7d0d01f7,0x442d14b2,0xf74306b4,0x00000000}},	//   yfas, ave_, _шефо,
  { {0x2fc000ac,0xdb1d0003,0x7c2d0078,0x00000000}},	//   _buig_, _eusè, yvar,
  { {0x61fa05e7,0x386614b3,0x232a14b4,0x00000000}},	//   sutl, nzor_, _моди_,
  { {0xcddb0001,0x68e00150,0x69c300ea,0x00000000}},	//   жња_, _lemd, ínek,
  { {0x672814b5,0x6e940e51,0x42fb0063,0x00000000}},	//   _madj, виру, _והוס,
  { {0x672800c3,0x7c2d14b6,0xbcfb14b7,0x00000000}},	//   _ladj, tvar, _amér,
  { {0x7d0d00bd,0x25a60025,0x7c2d14b8,0x00000000}},	// [1b90] rfas, _mhol_, uvar,
  { {0x6f1c14b9,0x672814ba,0x3866082a,0x00000000}},	//   cerc, _nadj, dzor_,
  { {0xfe350047,0x442d14bb,0x6b520014,0x00000000}},	//   _װאָך_, zve_, _nægu,
  { {0xdb1d0164,0x6d9314bc,0x7c2d069f,0x00000000}},	//   _musé, rças, pvar,
  { {0x27e914bd,0xe73914be,0x69dc004d,0x00000000}},	//   éan_, зел_, _ewre,
  { {0x25a6000f,0x9f590164,0xd8220121,0x00000000}},	//   _ahol_, fusé_, удши,
  { {0xe611006a,0xdb050025,0x69dc001f,0x00000000}},	//   اشت_, nmhí, _gwre,
  { {0x442d14bf,0x94250581,0x6f1c14c0,0x00000000}},	//   tve_, емие, zerc,
  { {0x442d03b2,0xdb0e00ea,0x752900ea,0x00000000}},	//   uve_, _hibá, rdez,
  { {0x6298021f,0x291d0009,0x7ae501f7,0x00000000}},	//   _byvo, lewa_, naht,
  { {0x9f590003,0x442d08cf,0x63b814c1,0x00000000}},	//   cusé_, sve_, _divn,
  { {0x2fc002c3,0x291d0dde,0x1a160041,0x00000000}},	//   _puig_, newa_, ײַטש_,
  { {0x394d14c2,0x25ad14c3,0xdbd7021e,0x00000000}},	//   _moes_, mmel_, _jäät,
  { {0x7ae5003e,0x291d0035,0xdb1d0003,0x00000000}},	//   jaht, hewa_, _fusé,
  { {0x291d0035,0x6b5200b9,0xdbd7004b,0x00000000}},	//   kewa_, _mægt, _läät,
  { {0x6f1c14c4,0xa0a60085,0x291d0022,0x00000000}},	//   serc, _пайд, jewa_,
  { {0x68e00006,0xdde3001c,0x6f1c14c5,0x00000000}},	// [1ba0] _remd, ērša, perc,
  { {0x6b520146,0xe625001b,0x395f11d0,0x00000000}},	//   _nægt, _đông_, _alus_,
  { {0xfce614c6,0x68e000f3,0x4ae10053,0x00000000}},	//   _поно, _pemd, _फ़रव,
  { {0xab5b00bd,0x7077007e,0x672814c7,0x00000000}},	//   _stüt, _آمیز_, _sadj,
  { {0x394d04bf,0x672814c8,0xea000013,0x00000000}},	//   _does_, _padj, _thắp_,
  { {0x2d800efa,0x395f0019,0x7c26034a,0x00000000}},	//   lnie_, _elus_, _iskr,
  { {0x69ce0c4a,0x63b80137,0x56930193,0x00000000}},	//   _utbe, _rivn, лашт,
  { {0x291d0397,0x394d00f6,0x2d8014c9,0x00000000}},	//   cewa_, _goes_, nnie_,
  { {0x672814ca,0x63b814cb,0x2d8014cc,0x00000000}},	//   _tadj, _pivn, inie_,
  { {0x21290035,0xd62a06da,0x7c3b1358,0x00000000}},	//   _saah_, _нозе_, _áure,
  { {0x7d0601e3,0xd0d5005a,0x6fa70053,0x00000000}},	//   _ocks, конъ, _गठबं,
  { {0xea00001b,0x2d800051,0x25d9007e,0x00000000}},	//   _nhập_, jnie_, _آهنگ_,
  { {0x2d800045,0xe5a314cd,0xbfab0085,0x00000000}},	//   dnie_, _сици, зтве_,
  { {0x2d800045,0x291d14ce,0xab64005b,0x00000000}},	//   enie_, zewa_, nlüğ,
  { {0xbe8814cf,0x6b520014,0x6e950054,0x00000000}},	//   есте_, _lægs, тиву,
  { {0x5eb40076,0x2d8014d0,0xe29b0063,0x00000000}},	//   уйст, gnie_, _משור,
  { {0x7ae50019,0xacf8000d,0xab640058,0x00000000}},	// [1bb0] taht, энту_, klüğ,
  { {0x7c2600b9,0x2d800051,0x200c003b,0x00000000}},	//   _dskr, anie_, ădit_,
  { {0x2d800051,0x395f04bc,0xdbd700fe,0x00000000}},	//   bnie_, _plus_, _säät,
  { {0xdbd7024a,0x2d800045,0xd8790032,0x00000000}},	//   _päät, cnie_, ومات_,
  { {0x7ae5024a,0xbcfb0942,0xd705030b,0x00000000}},	//   paht, _eléc, взли,
  { {0xbcfb0003,0x291d14d1,0x23a20014,0x00000000}},	//   _fléc, sewa_, yðja_,
  { {0x291d0009,0x8698005a,0x6b5200b9,0x00000000}},	//   pewa_, нтът_, _vægt,
  { {0x1da70053,0xdb08013d,0x9f420066,0x00000000}},	//   _कीमत, ülöt, vskí_,
  { {0x42d5000d,0x442601db,0xe4c80049,0x00000000}},	//   кіну, _cso_, ربين_,
  { {0x6b520026,0x9874000d,0x6d4f14d2,0x00000000}},	//   _hægr, _слуц, _loca,
  { {0x36d40055,0x2d800045,0x442614d3,0x00000000}},	//   _сохр, ynie_, _eso_,
  { {0x27e9003d,0x27ed14d4,0x29020137,0x00000000}},	//   šanu_, _kven_, _ökat_,
  { {0xd24e007e,0x25fd0053,0x2d9200a1,0x00000000}},	//   منی_, रूरी_, voye_,
  { {0x6b520026,0x2d800886,0x3ebe00d1,0x00000000}},	//   _lægr, wnie_, øtt_,
  { {0x2d800efa,0xdee308b9,0x6d4f0e0f,0x00000000}},	//   tnie_, роси, _boca,
  { {0x27ed08dc,0x6dbc14d5,0xee370062,0x00000000}},	//   _oven_, _sčas, ънс_,
  { {0x752b013d,0x2d8014d6,0x9cb30044,0x00000000}},	// [1bc0] _magz, rnie_, لمفت,
  { {0xab5b00bd,0x2ca70002,0x998d085a,0x00000000}},	//   _stür, ткуп_, _češ_,
  { {0x6d4f0027,0xeb970138,0xea00008b,0x00000000}},	//   _foca, њих_, _thập_,
  { {0x81bc001c,0xb8f30044,0xba1714d7,0x00000000}},	//   ovēr, لكمب, ضيها_,
  { {0xf74601aa,0x7c2614d8,0x4c830062,0x00000000}},	//   кедо, _uskr, _вляв,
  { {0x7bd60009,0x7d0414d9,0x00000000,0x00000000}},	//   mpyu, lgis,   ,
  { {0x27ed14da,0xab64005b,0x7c24004d,0x00000000}},	//   _even_, rlüğ, lwir,
  { {0xa507005e,0x6d4f01a8,0x83fd013d,0x00000000}},	//   већа_, _xoca, mzőj,
  { {0x7c2400bd,0x7d041013,0x4426008d,0x00000000}},	//   nwir, igis, _qso_,
  { {0x442600c3,0xdb050025,0xa263008b,0x00000000}},	//   _vso_, omhá, _trố,
  { {0xa266005a,0x81bc001c,0x79820051,0x00000000}},	//   тъпл, evēr, onow,
  { {0x92570076,0xd5e90021,0x427314db,0x00000000}},	//   тают_, _أعلن_, ргюс,
  { {0x442614dc,0x6d4f14dd,0x76450072,0x00000000}},	//   _uso_, _roca, ähyv,
  { {0x64a3005e,0xc7b40047,0x7520013d,0x00000000}},	//   _тача, רבֿ_, lemz,
  { {0x79820034,0x6d4f14de,0x4424001f,0x00000000}},	//   know, _poca, lwm_,
  { {0x2d550146,0x79820051,0x9f59004a,0x00000000}},	//   _nået_, jnow, musí_,
  { {0x81bd008f,0x5b150142,0x31790022,0x00000000}},	// [1bd0] svēs, лмат, misz_,
  { {0x765800fe,0xf0e30053,0xd37814df,0x00000000}},	//   kyvy, _ख़ुद_, nić_,
  { {0xdb050027,0xfdb907da,0x6d4f00c5,0x00000000}},	//   gmhá, _площ_, _toca,
  { {0x79820051,0x317914e0,0xbcfb0003,0x00000000}},	//   gnow, nisz_, _fléa,
  { {0xbcfb0025,0x9f420114,0xd378007d,0x00000000}},	//   _gléa, lská_, kić_,
  { {0xd378007d,0x9f59004c,0x628a14e1,0x00000000}},	//   jić_, kusí_, _oxfo,
  { {0x2d550146,0xd378017f,0x9f42004a,0x00000000}},	//   _fået_, dić_, nská_,
  { {0x2d550146,0xdb1d0512,0xc3d90086,0x00000000}},	//   _gået_, _musí, ньої_,
  { {0x5435006a,0xd37814d8,0xe705007e,0x00000000}},	//   اربر, fić_, _مسای,
  { {0x290200c7,0x399c0026,0xd378007d,0x00000000}},	//   _ökar_, vísi_, gić_,
  { {0x3f83017f,0x9f42027d,0x2fd200ac,0x00000000}},	//   dnju_, jská_, _styg_,
  { {0x44240185,0xf5300032,0x7412007e,0x00000000}},	//   bwm_, _وإن_, جویا,
  { {0x81bd001c,0xa3df0053,0xd37814e2,0x00000000}},	//   tvēr, धीश_, bić_,
  { {0xd3780045,0x40850001,0x2d9914e3,0x00000000}},	//   cić_, руџб, _akse_,
  { {0x81bd001c,0x79820051,0xdb15004c,0x00000000}},	//   rvēr, ynow, _cizí,
  { {0x7c2414e4,0x91060002,0x31790051,0x00000000}},	//   twir, _спие, cisz_,
  { {0x3f83007d,0x8c430092,0x7d0414e5,0x00000000}},	// [1be0] bnju_, бете, rgis,
  { {0x7c2414e6,0x4f260062,0x79820051,0x00000000}},	//   rwir, _сдоб, wnow,
  { {0x7c2414e7,0x200214e8,0xe8fa14e9,0x00000000}},	//   swir, luki_, еле_,
  { {0xd3780045,0x88e6047e,0xea000013,0x00000000}},	//   zić_, ужде, _chạp_,
  { {0xe3c8008b,0x79820051,0x83fd00ea,0x00000000}},	//   _mực_, rnow, szőj,
  { {0xe3c8001b,0xdbd2004b,0x79820022,0x00000000}},	//   _lực_, _müüt, snow,
  { {0xd3780117,0x6b6314ea,0x7bc614eb,0x00000000}},	//   vić_, _укра, _huku,
  { {0x44240185,0xd3780045,0xbf9b00ac,0x00000000}},	//   twm_, wić_, ntêr,
  { {0xd378017f,0xe644005b,0x88860001,0x00000000}},	//   tić_, ılığ, _слаж,
  { {0x31790051,0x4424001f,0x61fa00c2,0x00000000}},	//   wisz_, rwm_, trtl,
  { {0x4424001f,0xd378017f,0x7bc60213,0x00000000}},	//   swm_, rić_, _luku,
  { {0xe3c8008b,0x6ae10053,0x9f42027d,0x00000000}},	//   _cực_, _फ़्र, vská_,
  { {0x69c10164,0xf5930021,0x7bc614ec,0x00000000}},	//   _élev, _النج, _nuku,
  { {0x31790045,0x9f42004a,0x8cba0042,0x00000000}},	//   sisz_, tská_, ्शनो,
  { {0x31790045,0x3f83007d,0xddab0e5e,0x00000000}},	//   pisz_, rnju_, етал_,
  { {0x9f42004a,0xac19005e,0x7bc614ed,0x00000000}},	//   rská_, кобу_, _buku,
  { {0x7bc6014f,0x3f83017f,0xbb75007b,0x00000000}},	// [1bf0] _cuku, pnju_, агај,
  { {0x7bc614ee,0x9f420080,0xbcfb006c,0x00000000}},	//   _duku, pská_, _glén,
  { {0xb60a000d,0x0b8808a8,0x75c3013d,0x00000000}},	//   _жнiв, усти_, _kőze,
  { {0xdc340240,0x2d99004b,0xf1c90013,0x00000000}},	//   _zúča, _ukse_, _hạc_,
  { {0x83fd013d,0xdb1500dd,0x88c80054,0x00000000}},	//   rzők, _vizâ, улів_,
  { {0x6d4d0019,0x38ba0058,0x2b140053,0x00000000}},	//   ljaa, _sürü_, न्दु_,
  { {0x200214ef,0x7bc600bd,0xcf580063,0x00000000}},	//   zuki_, _zuku, רבות_,
  { {0xf1c9001b,0xdb1d017d,0x7ae7004c,0x00000000}},	//   _lạc_, _fusã, _hejt,
  { {0x68eb002c,0xe3c80013,0x6d4d0072,0x00000000}},	//   magd, _rực_, ijaa,
  { {0x466b0086,0x69c70035,0xdced005b,0x00000000}},	//   _прем_, _kuje, ynağ,
  { {0x672306bb,0x38ba01f7,0xdbd20019,0x00000000}},	//   menj, _türü_, _süüt,
  { {0x69c702dd,0xdc340024,0x27e00529,0x00000000}},	//   _muje, _súča, ţine_,
  { {0xe3c8001b,0xf1c9008b,0xfc3f00ea,0x00000000}},	//   _vực_, _bạc_, _szín_,
  { {0x23ab00b9,0x200214f0,0xc484000d,0x00000000}},	//   føje_, ruki_, _улік,
  { {0x7bc613d0,0x2002003e,0xbcfb0003,0x00000000}},	//   _suku, suki_, _cléo,
  { {0x7bc614f1,0x64460137,0x200200a4,0x00000000}},	//   _puku, åkig, puki_,

  { {0x68eb00bb,0x672314f2,0x98a4003b,0x00000000}},	// [1c00] dagd, kenj, _mamă_,
  { {0x6723065f,0xdb590086,0xaae50021,0x00000000}},	//   jenj, лює_, مسمو,
  { {0x67230198,0x66030006,0x78a9017d,0x00000000}},	//   denj, junk, _azev,
  { {0xe3c8001b,0x7bc614f3,0xd7fa000d,0x00000000}},	//   _lựa_, _tuku, вук_,
  { {0x386014f4,0xd8f70054,0x7ae7013d,0x00000000}},	//   áir_, рнії_, _fejt,
  { {0x672314f5,0x61e314f6,0x7ae7007d,0x00000000}},	//   genj, _ownl, _gejt,
  { {0xf62a0086,0xf6e5000d,0x386014f7,0x00000000}},	//   тіли_, сцін, šir_,
  { {0xa6e9001b,0x3f980080,0xdb050137,0x00000000}},	//   _ngươ, horu_, amhä,
  { {0x65880080,0x53460062,0xdb0714f8,0x00000000}},	//   běhn, ахна, _gijó,
  { {0xdb15000f,0x44970076,0x672301b3,0x00000000}},	//   _kizá, рвью_, cenj,
  { {0x69c1000f,0xe3c8008b,0x69c014f9,0x00000000}},	//   _élet, _dựa_, _kime,
  { {0x2c5e001c,0x69c014fa,0x6446078c,0x00000000}},	//   _kādā_, _jime, äkis,
  { {0x938a005a,0x69c014fb,0x60dd004d,0x00000000}},	//   _иска_, _mime, rbsm,
  { {0x69c014fc,0x6d4d006f,0x3f9814fd,0x00000000}},	//   _lime, wjaa, goru_,
  { {0xdef80088,0xdb1d0139,0x9ce70074,0x00000000}},	//   шыя_, _nusá, ицал,
  { {0x67230c61,0x69c014fe,0x7ae7013d,0x00000000}},	//   zenj, _nime, _sejt,
  { {0x2ac70001,0x7ae700b9,0x65a500ea,0x00000000}},	// [1c10] аљев, _pejt, zóho,
  { {0x69c014ff,0xdb15013d,0x6d4d1500,0x00000000}},	//   _aime, _bizá, sjaa,
  { {0xc879003b,0x5e591501,0x67231502,0x00000000}},	//   _ieşi_, _синя_, venj,
  { {0x49980054,0x69c01503,0x66030050,0x00000000}},	//   атія_, _cime, vunk,
  { {0x68eb00bb,0x7ae70024,0x68270076,0x00000000}},	//   ragd, _tejt, рьез,
  { {0x69c700c2,0x21cc004c,0x66031504,0x00000000}},	//   _tuje, _něho_, tunk,
  { {0x67230117,0x68eb002c,0x69d5004d,0x00000000}},	//   renj, pagd, _utze,
  { {0xe6160088,0x99850032,0x1994000d,0x00000000}},	//   ёды_, _الرو, _дася,
  { {0x681a003d,0x44391505,0x67231506,0x00000000}},	//   gādā, ís_, penj,
  { {0x69c00009,0xe7300032,0x660301db,0x00000000}},	//   _zime, _يصل_, punk,
  { {0x69c100ea,0xb0630072,0x64460072,0x00000000}},	//   _éles, ääns, äkir,
  { {0x3f980324,0x35b50e82,0x00000000,0x00000000}},	//   woru_, _убер,   ,
  { {0xbcfb0003,0x2d5c00cd,0xe3c80013,0x00000000}},	//   _clém, _kíev_, _tựa_,
  { {0xdb1c0003,0x20f8008b,0x98a0007d,0x00000000}},	//   _tiré, ọi_, žić_,
  { {0xc879000c,0x59b90053,0x25fd0053,0x00000000}},	//   _deşi_, ेदार, रंटी_,
  { {0x68e90034,0xbf9b0016,0x3f981507,0x00000000}},	//   _need, quên, soru_,
  { {0x7d16001f,0x69c01508,0x3f981261,0x00000000}},	// [1c20] rfys, _rime, poru_,
  { {0x290d000c,0xaf060a91,0x69c01509,0x00000000}},	//   _acea_, _упол, _sime,
  { {0xcf5701f9,0x0f570047,0x3205004c,0x00000000}},	//   _הבית_, _היים_, nuly_,
  { {0xea00008b,0xb4e60053,0xc7c6150a,0x00000000}},	//   _nhấp_, _बजे_, бски,
  { {0x69c00b54,0x68e9059f,0xad37009a,0x00000000}},	//   _vime, _deed, _הנכס_,
  { {0xaa4605bd,0x681a008f,0x32050061,0x00000000}},	//   _легл, vādā, kuly_,
  { {0x1b7b0047,0x65880080,0x6b63026c,0x00000000}},	//   _עטלע, běhl, _экра,
  { {0xea00001b,0x2c5e001c,0x3205004a,0x00000000}},	//   _chấp_, _tādā_, duly_,
  { {0x786605f7,0x23b40044,0x3ce90082,0x00000000}},	//   _указ, يمبس, जरते_,
  { {0x681a003d,0x68e900ca,0x3f72008f,0x00000000}},	//   rādā, _zeed, iņus_,
  { {0x6b9b0047,0xcb9b03c3,0x2d85013d,0x00000000}},	//   רשיד, רסיט, élek_,
  { {0xa0b9005e,0xb0630072,0x91fc008f,0x00000000}},	//   игну_, ääos, dzāt,
  { {0xf8ba0053,0x91ca0042,0xdc1d0023,0x00000000}},	//   ेशिय, _संवै, kņāt,
  { {0x995c0080,0x98a4005f,0xbed401ce,0x00000000}},	//   jíž_, _gamą_, зорј,
  { {0xf1c9001b,0x995c004c,0x15f80063,0x00000000}},	//   _hạn_, díž_, יִּמ,
  { {0x2fc9001f,0x9d150085,0x0dc8150b,0x00000000}},	//   _tuag_, ўдач, сури_,
  { {0x68e9150c,0x636d0139,0x83fd013d,0x00000000}},	// [1c30] _reed, _dúnf, szőv,
  { {0x68e9010e,0x9aab0021,0xf1c90013,0x00000000}},	//   _seed, هداف_, _mạn_,
  { {0x799900ac,0x6aba0014,0x68e9004e,0x00000000}},	//   toww, _útfl, _peed,
  { {0xad2701fb,0xe9190054,0x8ed8005d,0x00000000}},	//   _اردو, роді_, _پذیر_,
  { {0xf1c9008b,0x98a90066,0xb4e60053,0x00000000}},	//   _nạn_, ľaď_, _बड़े_,
  { {0x7c2f150d,0x6d81003d,0x45d51259,0x00000000}},	//   _iscr, rķau, оцит,
  { {0x636d0460,0x68e9150e,0x27e0008f,0x00000000}},	//   _húng, _teed, ģina_,
  { {0xf1c900aa,0xf773006a,0x160b0161,0x00000000}},	//   _bạn_, _کار_, संबर_,
  { {0xf1c90013,0x6d5a0003,0x2d8904aa,0x00000000}},	//   _cạn_, êtai, inae_,
  { {0x43740376,0xf1c90013,0x23b2007e,0x00000000}},	//   зуют, _dạn_, وميس,
  { {0xea00001b,0xe126150f,0x00000000,0x00000000}},	//   _thấp_, омни,   ,
  { {0x26130016,0x24190be6,0xd1c6000d,0x00000000}},	//   mão_, _воды_, ўляе_,
  { {0x26130016,0x7c2f1510,0x9f42017c,0x00000000}},	//   lão_, _nscr, mskú_,
  { {0x2613017d,0x53340121,0x7f75000d,0x00000000}},	//   oão_, _нечт, пусц,
  { {0x3ebe1511,0x26130016,0x3eac06a5,0x00000000}},	//   ätt_, não_, ådt_,
  { {0x9f420066,0xf1c9008d,0x75f0013d,0x00000000}},	//   nskú_, _hạo_, _hózá,
  { {0x636d0025,0x2613017d,0x3cd9000d,0x00000000}},	// [1c40] _cúng, hão_, сьсю_,
  { {0x8a3a0076,0x442f1512,0x8b26000d,0x00000000}},	//   ияет_, _msg_, юдзе,
  { {0x7c2f1513,0x2613017d,0x2d9e0003,0x00000000}},	//   _escr, jão_, îtes_,
  { {0x26130016,0xc879003b,0x9f420066,0x00000000}},	//   dão_, _leşu_, jskú_,
  { {0x6d461514,0x274a0980,0x9f42017c,0x00000000}},	//   _inka, ичко_, dskú_,
  { {0x2613017d,0xdb1d0058,0xf1c9008d,0x00000000}},	//   fão_, _rusç, _nạo_,
  { {0x26130016,0xf1c9008b,0x443d002b,0x00000000}},	//   gão_, _sạn_, _arw_,
  { {0x69de00fe,0x54541515,0xa923005e,0x00000000}},	//   mppe, звит, _одсл,
  { {0xf1c9008b,0x68e21516,0xe947005d,0x00000000}},	//   _bạo_, mbod, _ظرفی,
  { {0x2613017d,0xf1c90013,0x69de1517,0x00000000}},	//   bão_, _vạn_, oppe,
  { {0x26130016,0x8b030080,0xf1c90013,0x00000000}},	//   cão_, _úřed, _dạo_,
  { {0xdb1d00bd,0x69de0d11,0x77a401a8,0x00000000}},	//   _zusä, ippe, dòxi,
  { {0xf5770044,0x50670054,0x1074030b,0x00000000}},	//   _بمنع_, ітма, дляю,
  { {0xf1c9008b,0x83fd00ea,0x533405ce,0x00000000}},	//   _gạo_, rzőt, _хект,
  { {0xcdd80001,0xdb1c0680,0x9e340363,0x00000000}},	//   жњу_, _cirí, мерч,
  { {0xdb1c006d,0xd6570063,0x3169007d,0x00000000}},	//   _dirí, חילת_, _ulaz_,
  { {0x26130016,0x2b5813d5,0x68e2004d,0x00000000}},	// [1c50] zão_, _borc_, dbod,
  { {0x1aa7005e,0xfaa71518,0x6a670021,0x00000000}},	//   ојег, ошен, يطال,
  { {0x26130016,0x539b0063,0x7e2b012c,0x00000000}},	//   xão_, סיבו, _тіпа_,
  { {0xdeb6014e,0x2613017d,0x49c8000d,0x00000000}},	//   _מפתח_, vão_, ілін_,
  { {0x9f420024,0x7d0d092a,0x9cd60063,0x00000000}},	//   vskú_, mgas, _מורה_,
  { {0x261303d9,0x6fdc0047,0x7d0d1519,0x00000000}},	//   tão_, סקוס, lgas,
  { {0x9f420066,0xa9550054,0x68e2013d,0x00000000}},	//   tskú_, _екві, bbod,
  { {0x261303d9,0x7d0d151a,0x7c2d13d8,0x00000000}},	//   rão_, ngas, owar,
  { {0x261303d9,0xbcfb0139,0x9f420066,0x00000000}},	//   são_, _cléi, rskú_,
  { {0x26130016,0x7c2d0089,0x31b60042,0x00000000}},	//   pão_, iwar, ृद्ध,
  { {0x636d0025,0x7c2d0790,0xe299151b,0x00000000}},	//   _rúnd, hwar, сан_,
  { {0x22580504,0x7c2d151c,0x661c004b,0x00000000}},	//   ärka_, kwar, _ärka,
  { {0xf1c9001b,0x645d00bd,0xd788008b,0x00000000}},	//   _tạo_, äsid, iển_,
  { {0x442d0035,0x69de00fe,0xf1c90013,0x00000000}},	//   mwe_, yppe, _hạm_,
  { {0x442d00e8,0xf2d200b5,0x68e204bf,0x00000000}},	//   lwe_, _טעג_, ybod,
  { {0x7d0d002c,0xfc3f0025,0x3cca0001,0x00000000}},	//   ggas, _brí_, слао_,
  { {0xed57000a,0x2b58151d,0x2bba0021,0x00000000}},	// [1c60] чот_, _porc_, مائة_,
  { {0xf1c9008b,0x636d07a8,0x103b0063,0x00000000}},	//   _lạm_, _fúne, _פגיע,
  { {0xa926151e,0xdb1c017d,0x7c2d151f,0x00000000}},	//   здел, _pirâ, awar,
  { {0xc7c60fe2,0x442d0757,0x31b201c2,0x00000000}},	//   пски, kwe_, báze_,
  { {0x68e21520,0x6d3b0063,0x07340054,0x00000000}},	//   rbod, _התכנ, делю,
  { {0xe3a703eb,0x501b0063,0x656b1521,0x00000000}},	//   _سر_, מונו, _algh,
  { {0x442d1522,0xbcfb0139,0x00000000,0x00000000}},	//   ewe_, _sléi,   ,
  { {0xb06300fe,0x6b9e00b9,0x15130076,0x00000000}},	//   ääks, lopg, едъя,
  { {0x69ce1523,0x7ae3013d,0xe3af005d,0x00000000}},	//   _hube, űnte, گري_,
  { {0x27f70080,0x79821524,0x51f80086,0x00000000}},	//   ření_, liow, оною_,
  { {0x29f81525,0x22580121,0x32630062,0x00000000}},	//   nča_, цины_, етяв,
  { {0x79820045,0x7aee00bd,0xe3b8005b,0x00000000}},	//   niow, _lebt, smı_,
  { {0xafe4000d,0x69ce1526,0x43461527,0x00000000}},	//   ноўл, _lube, _недв,
  { {0x4fc41528,0x69dc1529,0x33940044,0x00000000}},	//   есса, _otre, _تلتز,
  { {0xd788001b,0x798b0185,0x69ce006d,0x00000000}},	//   yển_, yngw, _nube,
  { {0x7c2d0886,0x7d0d0089,0xbcfb0331,0x00000000}},	//   twar, ugas, _llév,
  { {0x2d580619,0x7c2d09fe,0x212b152a,0x00000000}},	// [1c70] чить_, uwar, mech_,
  { {0x636d06d5,0x7c2d152b,0x7d0d152c,0x00000000}},	//   _túne, rwar, sgas,
  { {0x20190019,0x442d00ac,0xbdb50001,0x00000000}},	//   ltsi_, zwe_, _обој,
  { {0x798b0035,0xfc3f152d,0x442d00ac,0x00000000}},	//   ungw, _trí_, ywe_,
  { {0xf770006a,0x7e6100c7,0x2019152e,0x00000000}},	//   گان_, älpf, ntsi_,
  { {0x80a00161,0xf09400b5,0x3f83152f,0x00000000}},	//   _ऐडसे, ענס_, niju_,
  { {0x442d00e8,0x644602fb,0x69ce1530,0x00000000}},	//   wwe_, åkin, _gube,
  { {0x79820051,0x3f83007d,0xbcfb013d,0x00000000}},	//   ciow, hiju_, _elév,
  { {0x442d0a53,0x200b017f,0x212b1531,0x00000000}},	//   uwe_, juci_, dech_,
  { {0x442d021f,0x200b1532,0xe1f91533,0x00000000}},	//   rwe_, duci_, ого_,
  { {0xc2c50032,0x290f00c7,0xf1c9001b,0x00000000}},	//   بيدي, ogga_, _tạm_,
  { {0x7bdd0004,0x290f1534,0xdb1c006d,0x00000000}},	//   _otsu, ngga_, _mirá,
  { {0xbf9b0016,0x3f831535,0x7bcf00dd,0x00000000}},	//   rrên, fiju_, _nucu,
  { {0x3f83017f,0x79820022,0x94ba009d,0x00000000}},	//   giju_, ziow, _ומנת,
  { {0x7bcf03b2,0xddd40024,0xada6015a,0x00000000}},	//   _aucu, ňažn, давл,
  { {0x7bcf0529,0x212b004c,0x29f81536,0x00000000}},	//   _bucu, cech_, vča_,
  { {0x3f83017f,0xdb1c00cd,0x672108ea,0x00000000}},	// [1c80] biju_, _pirà, _oblj,
  { {0x3f831537,0x3c19000d,0x69ce1538,0x00000000}},	//   ciju_, яўся_, _pube,
  { {0x7bc7003e,0x7982006d,0x639a0047,0x00000000}},	//   _diju, tiow, קסענ,
  { {0x7aee1539,0x6b9e153a,0xdb1c0331,0x00000000}},	//   _webt, sopg, _dirá,
  { {0x63a8000e,0x7641001f,0x87d7007e,0x00000000}},	//   yldn, _arly, وبوس_,
  { {0x212b03a4,0x7e610137,0x69ce153b,0x00000000}},	//   zech_, älpg, _tube,
  { {0x8b030080,0x79820051,0x69dc153c,0x00000000}},	//   _úřad, piow, _utre,
  { {0x3f831535,0xd82602a9,0xafdb01e1,0x00000000}},	//   ziju_, _одби, lvøe,
  { {0x212b0080,0x7641001f,0xf8b20053,0x00000000}},	//   vech_, _erly, _जरिय,
  { {0xd37003eb,0x212b001f,0x22860002,0x00000000}},	//   اهد_, wech_, думг,
  { {0x3f83017f,0x636400cd,0x9f5900ea,0x00000000}},	//   viju_, _jòni, pusú_,
  { {0x7c260146,0xf6530063,0xd788008b,0x00000000}},	//   _opkr, _בצע_, iểm_,
  { {0x32050034,0x3f830c61,0x55bb0063,0x00000000}},	//   arly_, tiju_, _ומאו,
  { {0xa2940088,0x200b017f,0x20190019,0x00000000}},	//   _палі, ruci_, rtsi_,
  { {0x212b027d,0x3f83153d,0x7bcf153e,0x00000000}},	//   pech_, riju_, _sucu,
  { {0x7bcf0397,0x3f83153f,0x200b00dd,0x00000000}},	//   _pucu, siju_, puci_,
  { {0x9f420114,0x3f831540,0x91b80021,0x00000000}},	// [1c90] lský_, piju_, _تطور_,
  { {0xdb1c1541,0xfbab000d,0x3196008f,0x00000000}},	//   _pirá, ітай_, rāze_,
  { {0x09e40086,0x9f420114,0x2d8500ea,0x00000000}},	//   воєн, nský_, éles_,
  { {0xaadf0394,0x4adf0161,0x3949048e,0x00000000}},	//   _प्रक, _प्रव, ñas_,
  { {0xba74006a,0x636d0025,0x9d1a0047,0x00000000}},	//   _یافت, _lúna, _צושט,
  { {0xbcfb0016,0x6d5d1542,0xbae50044,0x00000000}},	//   _elét, _hosa, _سكري,
  { {0x44261543,0x64420072,0x6d5d1544,0x00000000}},	//   _apo_, _aroi, _kosa,
  { {0x60cd1545,0x673f0022,0x9f4201d1,0x00000000}},	//   _ngam, _żyją, dský_,
  { {0x644203b2,0x44260150,0x3f8101e1,0x00000000}},	//   _croi, _cpo_, _omhu_,
  { {0x64421546,0x60cd014f,0xf1c9008b,0x00000000}},	//   _droi, _agam, _hại_,
  { {0x636d0025,0xdb050025,0x249b0006,0x00000000}},	//   _cúna, lmhó, _žymę_,
  { {0x64420164,0x6d5d1547,0x636d0025,0x00000000}},	//   _froi, _nosa, _dúna,
  { {0xf1c9008b,0x65691548,0x4f960200,0x00000000}},	//   _mại_, mkeh, ерву,
  { {0xf1c900aa,0x25710080,0x99710051,0x00000000}},	//   _lại_, _dále_, nął_,
  { {0xf8a5007e,0x443f1549,0x753b007d,0x00000000}},	//   _چک_, lvu_, oduz,
  { {0xf6520047,0x443f154a,0x753b154b,0x00000000}},	//   נצן_, ovu_, nduz,
  { {0xf1ca008b,0x6d5d154c,0xbcfb006c,0x00000000}},	// [1ca0] _nại_, _dosa, _alés,
  { {0x99710051,0x443f00fe,0x909b0063,0x00000000}},	//   jął_, ivu_, _מספק,
  { {0x9f5f00ea,0x6d5d0331,0x27ed002b,0x00000000}},	//   _órán_, _fosa, _awen_,
  { {0x7e6100c7,0x443f017f,0xf1ca008b,0x00000000}},	//   älpe, kvu_, _bại_,
  { {0x63a1154d,0x18670ae8,0x69c9154e,0x00000000}},	//   koln, наци_, _diee,
  { {0x636400cd,0xf1ca0013,0x78ad004b,0x00000000}},	//   _tòni, _dại_, üava,
  { {0xe5c6042c,0x443f154f,0xdb050139,0x00000000}},	//   нсио, evu_, amhó,
  { {0xdb1c005b,0x64421550,0x9f42004a,0x00000000}},	//   _birç, _proi, vský_,
  { {0xed5e0013,0x70af0053,0xe452002a,0x00000000}},	//   _đột_, _घरेल, اضع_,
  { {0xbf9b0164,0x2c170047,0x9f42004a,0x00000000}},	//   trêm, עקיש_, tský_,
  { {0x443f003d,0x2294130d,0x27ed004d,0x00000000}},	//   avu_, тиня, _zwen_,
  { {0x64421546,0x9f42027d,0x9f400026,0x00000000}},	//   _troi, rský_, _svið_,
  { {0x38661551,0x44260035,0x6d5d1552,0x00000000}},	//   nyor_, _upo_, _rosa,
  { {0xbf9b0164,0x9f420080,0x31b20124,0x00000000}},	//   prêm, pský_, ráza_,
  { {0x6447001c,0x6d5d1553,0x673a00c2,0x00000000}},	//   ājie, _posa, _matj,
  { {0x99710022,0x1cbb00de,0x00000000,0x00000000}},	//   zął_, كاذب_,   ,
  { {0x6d5d0268,0x63860003,0x7e610137,0x00000000}},	// [1cb0] _vosa, _génè, älpb,
  { {0x673a017f,0xbcfb1554,0x65690066,0x00000000}},	//   _natj, _clér, zkeh,
  { {0x69c9003d,0x6d5d0025,0x61fa1555,0x00000000}},	//   _piee, _tosa, nstl,
  { {0xbcfb000f,0x63a11556,0x443f1557,0x00000000}},	//   _elér, zoln, yvu_,
  { {0x673a003b,0xa3c00053,0x7a0a008d,0x00000000}},	//   _batj, ंगा_, ốtph,
  { {0xdb050025,0x21040006,0xd7020062,0x00000000}},	//   rmhó, mčių_, азши,
  { {0x38661558,0x63a101c2,0xab940086,0x00000000}},	//   ayor_, voln, _сирі,
  { {0xf1ca00aa,0x63a10045,0x75d1008f,0x00000000}},	//   _tại_, woln, _jāzi,
  { {0x210400eb,0x656900bd,0xe8940086,0x00000000}},	//   nčių_, rkeh, _бать,
  { {0x21040006,0xf1bf0061,0x65691559,0x00000000}},	//   ičių_, emá_, skeh,
  { {0x7790007e,0x443f021e,0x61fa0d13,0x00000000}},	//   _دیوا, svu_, gstl,
  { {0x63a100ea,0x63860003,0x46560047,0x00000000}},	//   soln, _pénè, _בױען_,
  { {0x63a1155a,0x61e4007d,0x25bf004e,0x00000000}},	//   poln, _čile, mmul_,
  { {0x25a0082a,0x25bf003b,0x25ad155b,0x00000000}},	//   čile_, lmul_, llel_,
  { {0x394d155c,0xe3c8008b,0x21040006,0x00000000}},	//   _ones_, _cựu_, ečių_,
  { {0x395f155d,0x63860003,0x27e0003b,0x00000000}},	//   _nous_, _ténè, ţini_,
  { {0x29d7155e,0x636d017c,0x2104005f,0x00000000}},	// [1cc0] _aça_, _júno, gčių_,
  { {0x7e6100c7,0x09ca0053,0x394d155f,0x00000000}},	//   älpc, िद्य, _anes_,
  { {0xc3320063,0x395f0813,0xb6d90085,0x00000000}},	//   שוב_, _bous_, _эмiг,
  { {0x02b60041,0xa9270054,0x8e97009a,0x00000000}},	//   דלעך_, віше_, _ידיו_,
  { {0x394d0114,0x395f1560,0x29d7017d,0x00000000}},	//   _dnes_, _dous_, _eça_,
  { {0xbf9b03b2,0x18670001,0x25ad1561,0x00000000}},	//   quêt, ђаји_, elel_,
  { {0xd6270001,0x2bd80053,0x6aa300bd,0x00000000}},	//   воје_, _भंडा, ünft,
  { {0x395f0089,0x2ef80206,0x746a0f9f,0x00000000}},	//   _gous_, harf_, дров_,
  { {0x47c60088,0xd0e30042,0x673a1562,0x00000000}},	//   _абав, _क्षण_, _tatj,
  { {0x6376003b,0x27e61563,0xc445005d,0x00000000}},	//   _mâng, mpon_, ایون_,
  { {0xcb13014e,0x6376000c,0x2ef800bd,0x00000000}},	//   בלת_, _lâng, darf_,
  { {0x25a600bb,0x21040078,0xf1bf004c,0x00000000}},	//   _ukol_, yčių_, umá_,
  { {0xf1bf0827,0x69d8004c,0x61fa1564,0x00000000}},	//   rmá_, ívej, sstl,
  { {0x2d920035,0x27e600a4,0x61fa004d,0x00000000}},	//   enye_, ipon_, pstl,
  { {0x3da7000a,0x26060042,0x2571009c,0x00000000}},	//   враб, सूची_, _hála_,
  { {0xc115005e,0x463b0047,0x3ebe0014,0x00000000}},	//   _смиј, ועלע, ýtta_,
  { {0xc05b0086,0x0dc81565,0x21040078,0x00000000}},	// [1cd0] _цій_, тури_, učių_,
  { {0x395f03b2,0x201e000c,0xbb740001,0x00000000}},	//   _sous_, ătit_, агуј,
  { {0x210400eb,0x395f00cd,0xe8050053,0x00000000}},	//   sčių_, _pous_, _रिहा_,
  { {0x200b1566,0x21040078,0x67d51567,0x00000000}},	//   orci_, pčių_, году,
  { {0x395f0c6e,0x6d4f1568,0x637600be,0x00000000}},	//   _vous_, _inca, _gâng,
  { {0xf1ca008b,0x394d001f,0x2d89005f,0x00000000}},	//   _hạt_, _wnes_, liae_,
  { {0x395f03b2,0x6376003b,0x25bf003b,0x00000000}},	//   _tous_, _mând, tmul_,
  { {0x84590079,0x2249017f,0x394d1569,0x00000000}},	//   ерот_, _čak_, _unes_,
  { {0x69940121,0xf1ca0013,0x25bf156a,0x00000000}},	//   _трёх, _mạt_, rmul_,
  { {0x25bf000c,0x69d5005b,0xb8820024,0x00000000}},	//   smul_, _kuze, číto,
  { {0x200b0051,0x9f590331,0xe2850854,0x00000000}},	//   erci_, husó_, улни,
  { {0x9f5e0080,0xdb1d00bd,0xd00a05fb,0x00000000}},	//   čtí_, _ausü, неме_,
  { {0x636400cd,0xe44e047e,0x69d5156b,0x00000000}},	//   _còns, _уж_, _luze,
  { {0x6376156c,0x6d4f156d,0x7af5004c,0x00000000}},	//   _când, _anca, _nezt,
  { {0x27e600c3,0x6376156e,0x3eac00b9,0x00000000}},	//   zpon_, _sâng, ædt_,
  { {0x7e610137,0xcd36005d,0x00000000,0x00000000}},	//   älpa, درآب,   ,
  { {0x2d9200d1,0x1c46000d,0x69d511ad,0x00000000}},	// [1ce0] rnye_, ынам, _auze,
  { {0x6376000c,0x6d4f156f,0x69d51570,0x00000000}},	//   _gând, _enca, _buze,
  { {0xa96a12b9,0x48e60131,0x3f8a0023,0x00000000}},	//   нижа_, гоев, mibu_,
  { {0xfe370063,0x69d51571,0xf1ca0013,0x00000000}},	//   _ערכי_, _duze, _gạt_,
  { {0x776100cd,0xf3f9003b,0x58d70054,0x00000000}},	//   _bolx, byţi_, удія_,
  { {0x321e00fe,0x3f8a0035,0xc7a30f56,0x00000000}},	//   ytty_, nibu_, бичк,
  { {0x27e61572,0x36870062,0xeb970a8f,0x00000000}},	//   spon_, лсън_, _сир_,
  { {0x7bce0974,0x636d0139,0x78b10014,0x00000000}},	//   _hibu, _dúnm, ðkvæ,
  { {0xa3c2016a,0x3494000d,0xb7160021,0x00000000}},	//   ्दल_, рапр, _مباش,
  { {0x3f8a0009,0x69c2006f,0x41e6013c,0x00000000}},	//   jibu_, lmoe, ліма,
  { {0x6376000c,0x6b7b0047,0x200b002b,0x00000000}},	//   _rând, גרינ, wrci_,
  { {0x257800ac,0x7bce1573,0xdb1c017d,0x00000000}},	//   _sélf_, _libu, _cirú,
  { {0x200b0003,0x63760f84,0x7d16002b,0x00000000}},	//   urci_, _pând, dgys,
  { {0x447b00b5,0x84170063,0xf487005d,0x00000000}},	//   _אנדע, _עקוב_, _حامی,
  { {0x6376000c,0x63030021,0x6da50044,0x00000000}},	//   _vând, _طويل, لمسم,
  { {0xfbdf002b,0x7d161574,0x3d0f0042,0x00000000}},	//   _drên_, ggys, िलें_,
  { {0x0fb9005e,0x69d51575,0xf1ca008d,0x00000000}},	// [1cf0] _илић_, _suze, _vạt_,
  { {0x59d90053,0x320c1566,0x76481576,0x00000000}},	//   _बंदर, ordy_, _ordy,
  { {0x7bce0d75,0x5a350257,0x5f74005d,0x00000000}},	//   _dibu, рнет, _داير,
  { {0xe9ab007e,0xd788008b,0xe0df0290,0x00000000}},	//   ردان_, iểu_, ncò_,
  { {0x68f90045,0x69da0164,0x21290150,0x00000000}},	//   rawd, _éten, _mbah_,
  { {0x68f9001f,0x9665055d,0xf7451577,0x00000000}},	//   sawd, икле, реко,
  { {0x7f3c0047,0x870401d5,0x2d9e009c,0x00000000}},	//   געוו, сяче, éteg_,
  { {0x49bb007e,0x24920078,0x05651578,0x00000000}},	//   _سازد_, _žyma_, рвин,
  { {0x320b0051,0x23d40085,0x00000000,0x00000000}},	//   ącym_, йцэр,   ,
  { {0x25a00198,0xb7bd0529,0x42251579,0x00000000}},	//   čila_, _opţi, адов,
  { {0x67250019,0x45d50878,0xe299157a,0x00000000}},	//   õhju, _тоес, тан_,
  { {0x69d80016,0x798b001f,0xa06a05c5,0x00000000}},	//   ívei, nigw, вама_,
  { {0x3f8a0035,0x671c0053,0xdb1c0013,0x00000000}},	//   tibu_, _नामक_, _virú,
  { {0xb4c10053,0x747a009a,0x926500de,0x00000000}},	//   ंधी_, _שנסג, _ندعم,
  { {0x3f8a10ca,0x0fc3019d,0x7bce003e,0x00000000}},	//   ribu_, ійсн, _ribu,
  { {0xe0df0290,0x3f8a0035,0x7bce157b,0x00000000}},	//   ccò_, sibu_, _sibu,
  { {0x3b86000d,0x798b002b,0x9c870124,0x00000000}},	// [1d00] алаг, digw, vočí,
  { {0xfbdf00aa,0xdcf60058,0x6ffb069a,0x00000000}},	//   _trên_, ıcın, _שפיג,
  { {0x69c20162,0xca56018e,0xe8fa157c,0x00000000}},	//   tmoe, штањ, вле_,
  { {0x5ca60141,0xc8ca013a,0xfd1214d7,0x00000000}},	//   _вимб, نوان_, _بجد_,
  { {0xa01b00bd,0x69c2157d,0x7bce157e,0x00000000}},	//   rzög, rmoe, _tibu,
  { {0x6376000c,0x6e3300ea,0xa01b0740,0x00000000}},	//   _mânc, _újbó, szög,
  { {0xd6d90086,0x9c87004a,0xb633005d,0x00000000}},	//   уті_, počí, قعيت,
  { {0x2904017c,0x342602f9,0xe9a30085,0x00000000}},	//   _udma_, афов, _дасп,
  { {0xa3e70001,0xa967157f,0xd49a0094,0x00000000}},	//   адња_, _тита_, ърк_,
  { {0xd6f80063,0xf3660f50,0x3374030b,0x00000000}},	//   _תִּש, ртин, сгор,
  { {0xd0d50062,0x0bb7089e,0x7d06056c,0x00000000}},	//   йонъ, שלים_, _odks,
  { {0x240a0062,0x51f70766,0x672d0130,0x00000000}},	//   _анди_, шнюю_, đaje,
  { {0x63760016,0xe0df0290,0x50641580,0x00000000}},	//   _cânc, rcò_, отра,
  { {0x93fb0063,0x547b0063,0x2578004c,0x00000000}},	//   _ילדי, _שְׁנ, _déle_,
  { {0x63a8010a,0x59a60042,0x03bb009a,0x00000000}},	//   modn, गकार, _שצול,
  { {0x21290397,0x2578013d,0x63a81581,0x00000000}},	//   _ubah_, _féle_, lodn,
  { {0x91bc0063,0x5cb90085,0x8c190044,0x00000000}},	// [1d10] _במהי, улаў_, طيار_,
  { {0x8ae7019d,0x2d8c0164,0xf1ca008d,0x00000000}},	//   ріал, éder_, _hạp_,
  { {0x69da013d,0x83370041,0x2bc81006,0x00000000}},	//   _étel, שאבס_, руто_,
  { {0x63a81582,0x645d0656,0x2bd9005d,0x00000000}},	//   hodn, äsik, _ماسک_,
  { {0x8d5a0063,0x798b002b,0x63a81583,0x00000000}},	//   _עכשי, rigw, kodn,
  { {0xcc3a00b5,0xdc3a00b5,0xf1ca008b,0x00000000}},	//   _געשט, _געשר, _lạp_,
  { {0x798b0035,0x64460026,0xb9e40086,0x00000000}},	//   pigw, ækin, _міти,
  { {0xf1ca008b,0x1e98009a,0xd5e80044,0x00000000}},	//   _nạp_, יכול_, جعون_,
  { {0x79890035,0x26130053,0xe8180044,0x00000000}},	//   _imew, _धमकी_, _نزلت_,
  { {0xf773006a,0xc6a702a9,0x83390121,0x00000000}},	//   _بار_, _креи, учит_,
  { {0x636d1584,0x614602b6,0x81ca0121,0x00000000}},	//   _júni, бена, лгов_,
  { {0x636d0857,0xdb050354,0xf1ca008d,0x00000000}},	//   _múni, llhä, _cạp_,
  { {0x2418000d,0x63a8073c,0x001a0085,0x00000000}},	//   _вочы_, bodn, ыўны_,
  { {0x2bdb0161,0xdee300e2,0x53341585,0x00000000}},	//   _बढ़ा, зори, _мечт,
  { {0x1d0a0d64,0xdb050003,0xdef9000d,0x00000000}},	//   леви_, cohé, шыў_,
  { {0xf1d00235,0xa19300e1,0xed46005e,0x00000000}},	//   _सूचन, _најч, љнап,
  { {0x442f1586,0x645d0072,0xd117009a,0x00000000}},	// [1d20] _jpg_, äsih, _הקפה_,
  { {0xcef6005e,0x636d0014,0x20021587,0x00000000}},	//   _учињ, _búni, mski_,
  { {0x20021588,0x6e46006a,0xc0a9007e,0x00000000}},	//   lski_, _انجم, _مایل_,
  { {0x9f49007a,0xf8fa0021,0x644b1589,0x00000000}},	//   _hvað_, اءات_, _orgi,
  { {0x2002065f,0xbf9b0003,0x9f490014,0x00000000}},	//   nski_, prêt, _kvað_,
  { {0x7c24001c,0x39400078,0x6d44158a,0x00000000}},	//   mtir, žis_, ldia,
  { {0x443d158b,0x644b158c,0x8afb01f9,0x00000000}},	//   _asw_, _argi, _תהלי,
  { {0x25a00198,0x657b002c,0x63a80051,0x00000000}},	//   čilo_, ghuh, wodn,
  { {0x7c24158d,0x6d44001f,0xf1ca0013,0x00000000}},	//   ntir, idia, _rạp_,
  { {0x2002158e,0xc1ea093e,0x68e2158f,0x00000000}},	//   dski_, льме_, lcod,
  { {0x442f00e3,0xdb1c0164,0xe1351485,0x00000000}},	//   _epg_, _chré, онны,
  { {0x68e2102c,0x5a9b0047,0xdb1c0025,0x00000000}},	//   ncod, רשטא, _dhré,
  { {0x6d440c70,0x60e4000d,0x63a80008,0x00000000}},	//   ddia, яцэз, podn,
  { {0x6d441590,0x40340141,0x7c24051f,0x00000000}},	//   edia, џерс, dtir,
  { {0x41e6006a,0xdb1c0027,0xf1ca001b,0x00000000}},	//   _استف, _ghré, _tạp_,
  { {0x7c240026,0x20021591,0xd011002a,0x00000000}},	//   ftir, bski_, _قلب_,
  { {0x68e2006f,0xe5200053,0xa01b013d,0x00000000}},	// [1d30] dcod, _यानि_, szöb,
  { {0x68e20122,0x2474008b,0xda7b000d,0x00000000}},	//   ecod, ìm_, ляе_,
  { {0x7a350032,0x6d441592,0x7c241593,0x00000000}},	//   تفاص, bdia, atir,
  { {0x7bc50139,0xac191594,0xc179005f,0x00000000}},	//   smhu, _кому_, mpės_,
  { {0xc88b0021,0xe9d00021,0xe8f8013c,0x00000000}},	//   دخال_, رغم_, слі_,
  { {0x7afe1595,0x636d1596,0x442f1597,0x00000000}},	//   capt, _túni, _rpg_,
  { {0x24740013,0xb5790054,0x85790121,0x00000000}},	//   èm_, ищих_, исит_,
  { {0x24090795,0x68e20290,0x20020ac3,0x00000000}},	//   ании_, ccod, yski_,
  { {0x75ca0045,0xdb20005b,0x9359018b,0x00000000}},	//   _języ, ütçe, арну_,
  { {0x387200d1,0x6d440066,0x83891598,0x00000000}},	//   øyre_, zdia, рбов_,
  { {0xa1ba1599,0x657b00ac,0xe6950021,0x00000000}},	//   иумф_, phuh, _بلاد,
  { {0x2002055e,0xa4f7007e,0x68fb0003,0x00000000}},	//   tski_, _اکثر_, _jeud,
  { {0x443d00bd,0x8447007e,0x2002159a,0x00000000}},	//   _usw_, _دخال, uski_,
  { {0xf7670032,0xe8df008b,0xdb1c0139,0x00000000}},	//   ذا_, _baịn_, _thré,
  { {0xfc3f048e,0x6449159b,0x2002004e,0x00000000}},	//   _así_, lvei, sski_,
  { {0x75290290,0x2002159c,0x64490078,0x00000000}},	//   nfez, pski_, ovei,
  { {0x6449087a,0xab6610e4,0x6fb60021,0x00000000}},	// [1d40] nvei, овал, _ومعا,
  { {0x2fd7006a,0x6d44159d,0x7c2413b3,0x00000000}},	//   _گوید_, sdia, rtir,
  { {0x7afe159e,0x68e20d13,0x39460121,0x00000000}},	//   rapt, tcod, жнег,
  { {0x7afe159f,0x7c2415a0,0x2d960c59,0x00000000}},	//   sapt, ptir, _фрос,
  { {0x68ed006d,0x68fb15a1,0xade00053,0x00000000}},	//   ñada, _deud, _खंडन_,
  { {0x68e215a2,0xbb560021,0x644915a3,0x00000000}},	//   scod, _بنسب, dvei,
  { {0xd95a0001,0x7afc003b,0x7e7a0047,0x00000000}},	//   _краљ_, _iert, יאַז,
  { {0x7afc15a4,0x3196008f,0xdb21013d,0x00000000}},	//   _hert, bāzi_, ütöt,
  { {0x644900d1,0x7afc15a5,0x3944005f,0x00000000}},	//   gvei, _kert, _iams_,
  { {0x69dc15a6,0xe3b20021,0x7afc15a7,0x00000000}},	//   _kure, برع_, _jert,
  { {0x394604a6,0x64490006,0x7afc15a8,0x00000000}},	//   odos_, avei, _mert,
  { {0x69dc15a9,0xe1ef007e,0x7afc15aa,0x00000000}},	//   _mure, کسی_, _lert,
  { {0x394615ab,0xf8ca0053,0x6281027c,0x00000000}},	//   idos_, िधिय, azlo,
  { {0x25a900b2,0x7afc0ea7,0xdced1333,0x00000000}},	//   čale_, _nert, rkač,
  { {0xccfb0001,0x2e48005a,0x645d00fe,0x00000000}},	//   ића_, оято_, äsiv,
  { {0xc1790078,0x39440023,0xfc3f01c8,0x00000000}},	//   rpės_, _nams_, _psí_,
  { {0x7afc15ac,0xdcef000c,0xef670062,0x00000000}},	// [1d50] _bert, _alcă, _дъно,
  { {0x394600ed,0x201915ad,0x7afc15ae,0x00000000}},	//   edos_, musi_, _cert,
  { {0x6449001c,0xea00008b,0x69dc09ee,0x00000000}},	//   zvei, _đảo_, _cure,
  { {0xe9d80088,0x69dc15af,0x3f910734,0x00000000}},	//   ікі_, _dure, lizu_,
  { {0x7afc15b0,0x8d5a0063,0x394400e5,0x00000000}},	//   _fert, _הכרי, _dams_,
  { {0x69dc0164,0x394604a6,0x37ab00e1,0x00000000}},	//   _fure, ados_, штен_,
  { {0x7c3901f7,0x20190035,0x7bdd0058,0x00000000}},	//   şarı, husi_, _husu,
  { {0x7afc00bd,0x7bdd15b1,0x644915b2,0x00000000}},	//   _zert, _kusu, tvei,
  { {0x7bd50009,0x752915b3,0xb345017d,0x00000000}},	//   _kizu, rfez, _naçã,
  { {0x25710026,0x644915b4,0x201915b5,0x00000000}},	//   _máli_, rvei, dusi_,
  { {0xcb1200b5,0xa91d0006,0x7bdd0089,0x00000000}},	//   עלט_, _amži, _lusu,
  { {0x291d0009,0x24190076,0xb6ba0063,0x00000000}},	//   ngwa_, _годы_, _הצעי,
  { {0x291d0035,0x201915b6,0x62810163,0x00000000}},	//   igwa_, gusi_, szlo,
  { {0x636d0025,0x39460078,0x3f9e004b,0x00000000}},	//   _cúnt, zdos_, õtu_,
  { {0x3ebe0e3f,0x272f01f7,0x20191404,0x00000000}},	//   ått_, mını_, ausi_,
  { {0x201915b7,0x69da0164,0x7afc15b8,0x00000000}},	//   busi_, _étei, _sert,
  { {0x7afc15b9,0xf5390066,0xdca315ba,0x00000000}},	// [1d60] _pert, ieť_, еати,
  { {0x272f005b,0x7bdd017e,0x69dc15bb,0x00000000}},	//   nını_, _dusu, _pure,
  { {0x7afc15bc,0x6edb0063,0x19ba0376,0x00000000}},	//   _vert, _לחיפ, будь_,
  { {0x7ae515bd,0x7afc09f8,0x7bdd003b,0x00000000}},	//   acht, _wert, _fusu,
  { {0x7afc08f0,0x25ad0438,0x7bdd0150,0x00000000}},	//   _tert, doel_, _gusu,
  { {0x4cbb0063,0x6d4615be,0x272f0058,0x00000000}},	//   _לזכו, _haka, jını_,
  { {0x6d4615bf,0x272f005b,0x2019013d,0x00000000}},	//   _kaka, dını_, zusi_,
  { {0x6d4615c0,0x7ec7000f,0x320500ac,0x00000000}},	//   _jaka, lépé, dsly_,
  { {0x6d4615c1,0x272f0058,0xb4c80042,0x00000000}},	//   _maka, fını_, ोखे_,
  { {0x6843011c,0xa87b0063,0x6d4615c2,0x00000000}},	//   _януа, _האמר, _laka,
  { {0x2d92005b,0x25ad00ca,0x0cb90042,0x00000000}},	//   kiye_, boel_, _आर्म,
  { {0x6d4615c3,0x20190c76,0x92c20058,0x00000000}},	//   _naka, tusi_, _ışın,
  { {0x2d92005b,0x272f005b,0x645d0213,0x00000000}},	//   diye_, bını_, äsit,
  { {0x2019058c,0x272f005b,0x08770047,0x00000000}},	//   rusi_, cını_, לעכט_,
  { {0x7bdd15c4,0xe3b8005b,0x2d92005b,0x00000000}},	//   _susu, mlı_, fiye_,
  { {0xf1a40088,0x6d460228,0xd2b70063,0x00000000}},	//   _прын, _caka, _מלות_,
  { {0xea00001b,0x6d4615c5,0x2004004c,0x00000000}},	// [1d70] _đạo_, _daka, ámit_,
  { {0xe3b801f7,0x7ae505e4,0x0bb40376,0x00000000}},	//   nlı_, ucht, ебую,
  { {0x6d4601f7,0x68ed02dd,0x7ae500bd,0x00000000}},	//   _faka, ñado, rcht,
  { {0x644209ff,0x7ae500bd,0xe3b8005b,0x00000000}},	//   _osoi, scht, hlı_,
  { {0xe3b801f7,0x272f005b,0x25ad0229,0x00000000}},	//   klı_, yını_, voel_,
  { {0x6d4615c6,0xe3b80075,0x32050260,0x00000000}},	//   _zaka, jlı_, ysly_,
  { {0x81bd003d,0xda34000d,0x25ad006f,0x00000000}},	//   ttēl, _перы, toel_,
  { {0xd11f0053,0xdb1c0014,0x13e90054,0x00000000}},	//   _भाषण_, _hirð, омий_,
  { {0x272f005b,0x2009001c,0xe3b80058,0x00000000}},	//   tını_, _nvai_, flı_,
  { {0xd3890086,0xe2990001,0xb2f40076,0x00000000}},	//   ійне_, жао_, няющ,
  { {0x272f04ab,0x32050037,0xda7a00b5,0x00000000}},	//   rını_, usly_, ַנשר,
  { {0x272f01f7,0x645d0072,0x81bd008f,0x00000000}},	//   sını_, äsis, ltēj,
  { {0xe3ae0088,0xa01b000f,0x32050034,0x00000000}},	//   _аб_, szön, ssly_,
  { {0xdb1c0025,0x81bd001c,0x753b0657,0x00000000}},	//   _phrí, ntēj, leuz,
  { {0x1d0a000a,0x53320635,0x6d4615c7,0x00000000}},	//   жеби_, _рејт, _paka,
  { {0x9f5900fe,0x24920078,0xed570b69,0x00000000}},	//   essä_, _žymi_, мос_,
  { {0xdb070026,0x2d92005b,0x65660137,0x00000000}},	// [1d80] _skjá, riye_, ökhi,
  { {0x6d4610ca,0x69cb0717,0x2d92005b,0x00000000}},	//   _waka, emge, siye_,
  { {0x2d8015c8,0x753b0122,0x637f0732,0x00000000}},	//   phie_, keuz, _gêne,
  { {0xe3b8005b,0x3ebe0014,0x81bd0023,0x00000000}},	//   zlı_, ýttu_, etēj,
  { {0xe3b8005b,0x7d0415c9,0xd90d007e,0x00000000}},	//   ylı_, mais, صیل_,
  { {0x75220290,0x7d0415ca,0xdc8b0063,0x00000000}},	//   _scoz, lais, _וְלָ,
  { {0x27ed0122,0x68e9001f,0x656b15cb,0x00000000}},	//   _eten_, _ffed, _bogh,
  { {0x7d0415cc,0xc966000d,0x25780003,0x00000000}},	//   nais, _ўвай, _vélo_,
  { {0xe3b8005b,0x87260002,0xdb05011b,0x00000000}},	//   tlı_, _омаж, lohá,
  { {0x656b0025,0x7d0415cd,0x3196008f,0x00000000}},	//   _eogh, hais, kāzs_,
  { {0x7d04024a,0x81bd003d,0x656b0027,0x00000000}},	//   kais, stēm, _fogh,
  { {0x2d9e000f,0x7d040659,0xc5f30063,0x00000000}},	//   étel_, jais, _ידע_,
  { {0x9f590072,0xe3b80058,0x31b9013d,0x00000000}},	//   yssä_, plı_, nézi_,
  { {0x81bd001c,0xc05815ce,0xe28f0043,0x00000000}},	//   otēk, фію_, اذی_,
  { {0xdfd415cf,0x671c016a,0xd904006a,0x00000000}},	//   торы, _नाईक_, _پی_,
  { {0x7d0415d0,0x27440078,0x31b9013d,0x00000000}},	//   gais, lūnė_, kézi_,
  { {0x4c940076,0xfbdf15d1,0x79820150,0x00000000}},	// [1d90] витс, _quê_, dhow,
  { {0x31a4005b,0x1bd50121,0x60c000e7,0x00000000}},	//   mıza_, хозя, ümme,
  { {0xc9150138,0xdb1c007a,0x27ed15d2,0x00000000}},	//   едећ, _virð, _sten_,
  { {0x7d0412f7,0x443f0022,0x28f80054,0x00000000}},	//   cais, ywu_, дець_,
  { {0x656b018d,0x31a401f7,0xa3c30161,0x00000000}},	//   _rogh, nıza_, ्षम_,
  { {0x656b0025,0xf1ca008b,0xdb070093,0x00000000}},	//   _sogh, _dạy_, _skjæ,
  { {0x45d515d3,0x81bd003d,0xbbbd0053,0x00000000}},	//   нцит, rtēj, ्गीक,
  { {0x79820045,0x81bd008f,0x443f0022,0x00000000}},	//   chow, stēj, twu_,
  { {0x27ed0031,0x81bd001c,0x656b01f4,0x00000000}},	//   _uten_, ptēj, _vogh,
  { {0x2d8c0164,0xd70801ce,0x443f056c,0x00000000}},	//   édez_, _онђе_, rwu_,
  { {0x0322000d,0x656b0025,0x68e4007c,0x00000000}},	//   ыдэн, _togh, žide,
  { {0x46380021,0x31a40058,0x63ba0046,0x00000000}},	//   _تأكد_, fıza_, altn,
  { {0x600715d4,0x7bc70072,0x3076005e,0x00000000}},	//   нням_, _ohju, хунс,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x6da60121,0xf772009f,0x7d0415d5,0x00000000}},	//   еива, נקל_, tais,
  { {0x7d04017d,0x3f83004b,0x61ee0331,0x00000000}},	//   uais, ahju_, íble,
  { {0xdee60e14,0xdb1e0072,0x7d0415d6,0x00000000}},	// [1da0] _попи, ympä, rais,
  { {0x7d0415d7,0x9b460021,0xdb1c0025,0x00000000}},	//   sais, عناو, _bhrá,
  { {0x61eb0529,0xe9da12ad,0x7e610137,0x00000000}},	//   _înlă, чке_, älpt,
  { {0xfbdf0164,0x307a0047,0x25710014,0x00000000}},	//   _prêt_, ּאַנ, _máls_,
  { {0x75c3013d,0x75e70058,0x63ba00a5,0x00000000}},	//   _főzz, _rıza, yltn,
  { {0x60c40009,0x38cb007e,0xdb1c0025,0x00000000}},	//   _mzim, سانی_, _fhrá,
  { {0xe2870021,0xdb1c0139,0xe60f0044,0x00000000}},	//   _إذ_, _ghrá, مشي_,
  { {0xe5540092,0xd6d9012c,0x99d600de,0x00000000}},	//   ткињ, фті_, _أقرت,
  { {0x60c40009,0x64a30001,0x98a30caa,0x00000000}},	//   _nzim, лаћа, _бите,
  { {0xb8f30053,0x54330021,0x88350085,0x00000000}},	//   हे_, ارير, _шэсц,
  { {0x26de00a4,0x60c415d8,0xf6560054,0x00000000}},	//   _igto_, _azim, _ятаю,
  { {0x546a005a,0xbcfb0003,0x4a9b0047,0x00000000}},	//   _наем_, _inég, לייג,
  { {0xc953014e,0x257100ea,0x74130cac,0x00000000}},	//   אמר_, _vált_, _مونا,
  { {0x25a00198,0xa3c30161,0x60c4001c,0x00000000}},	//   čilu_, ्षण_, _dzim,
  { {0x43770041,0xde580054,0xbdc70363,0x00000000}},	//   _אײגן_, нарі_, ещай,
  { {0x3eba00d1,0xdb23013d,0x315b0044,0x00000000}},	//   _dypt_, őrül, _رجعة_,
  { {0x2ef5011c,0xdb1c0139,0x321e0051,0x00000000}},	// [1db0] _изпр, _shrá, luty_,
  { {0x7e610137,0x200b15d9,0x8aa70571,0x00000000}},	//   älps, msci_, нред,
  { {0x321e03a4,0x314b0063,0xd5df0042,0x00000000}},	//   nuty_, ּתְּ, _पूंज,
  { {0x201915da,0x3978013c,0x62880a10,0x00000000}},	//   orsi_, нсію_, izdo,
  { {0x6d5d15db,0xa09c0041,0x6d4d0046,0x00000000}},	//   _insa, ּיוט, mdaa,
  { {0x6d4d15dc,0xb6590b3f,0x2b1e0053,0x00000000}},	//   ldaa, дших_, _पाएँ_,
  { {0xfbdf03d9,0x7c2d15dd,0x69c301a8,0x00000000}},	//   _três_, ltar, ïnes,
  { {0x6d4d15de,0x4904007e,0x25a915df,0x00000000}},	//   ndaa, _موفق, čalo_,
  { {0x6d4d00fe,0xd6db0002,0x200b007d,0x00000000}},	//   idaa, _ете_, jsci_,
  { {0x69da0164,0x7c2d15e0,0x25710046,0x00000000}},	//   _éter, itar, _páls_,
  { {0x6f070b33,0x60c400ea,0x7c2d15e1,0x00000000}},	//   dajc, _szim, htar,
  { {0x7c2d15e2,0x04b50062,0x2509007e,0x00000000}},	//   ktar, _исля, _آرای_,
  { {0x15180021,0xdce6008f,0x21a30121,0x00000000}},	//   _أزمة_, _nokā, риям,
  { {0x6d5d15e3,0x6d4d006f,0x7c2d15e4,0x00000000}},	//   _ansa, edaa, dtar,
  { {0x20190290,0xee15000d,0x7c2d15e5,0x00000000}},	//   arsi_, льтэ, etar,
  { {0x6d4d00a4,0x40960021,0x6d5d003b,0x00000000}},	//   gdaa, _للعر, _cnsa,
  { {0x60c4017f,0x1ae60edd,0x442d0dd1,0x00000000}},	// [1dc0] _uzim, возм, nte_,
  { {0x3eba0122,0x8ad60021,0x6376017d,0x00000000}},	//   _typt_, نتائ, _pâni,
  { {0x4dd60021,0xdce402f7,0xab270062,0x00000000}},	//   _لتحس, ljič, тоха_,
  { {0x442d0386,0x3f98003e,0x69c915e6,0x00000000}},	//   kte_, liru_, _chee,
  { {0xa3c30161,0x69db00cd,0xa3c10053,0x00000000}},	//   ्षा_, _diue, ंता_,
  { {0x69c90122,0xbb76005a,0x18670001,0x00000000}},	//   _ehee, _румъ, таљи_,
  { {0xbf9b0047,0xb5a61501,0x36870062,0x00000000}},	//   ויסש, крий, ксън_,
  { {0x657b15e7,0xe5c6005e,0x442d15e8,0x00000000}},	//   gkuh, њско, fte_,
  { {0x37e6019d,0x75e701f7,0xa3c00161,0x00000000}},	//   _розг, _hızl, ूगल_,
  { {0x637f017d,0x61e315e9,0x75e70058,0x00000000}},	//   _pêna, _bunl, _kızl,
  { {0x3f98007d,0x442d0641,0x2019002b,0x00000000}},	//   diru_, ate_, wrsi_,
  { {0x64460026,0x9293000d,0x96950095,0x00000000}},	//   ækis, раюц, _сруш,
  { {0x53340088,0x68ed02dd,0x442d15ea,0x00000000}},	//   _белт, ñadi, cte_,
  { {0x321e0034,0x29040e57,0xdce6008f,0x00000000}},	//   puty_, _lema_, _rokā,
  { {0x91e30001,0xcddb0001,0x7c2d0051,0x00000000}},	//   _које, дња_, wtar,
  { {0x7c2d067a,0x290415eb,0xed140086,0x00000000}},	//   ttar, _nema_, имсь,
  { {0x3f9815ec,0x6d4d15ed,0x7bdc15ee,0x00000000}},	// [1dd0] biru_, rdaa, _biru,
  { {0x2d820102,0x6d4d0250,0xbcfb0164,0x00000000}},	//   _elke_, sdaa, _poés,
  { {0x7bdc0397,0x6abc001f,0x69c9002b,0x00000000}},	//   _diru, _cyrf, _phee,
  { {0x27e400f3,0x442d15ef,0x7bdc002b,0x00000000}},	//   _bumn_, yte_, _eiru,
  { {0x69db00cd,0x442d15f0,0x7bdc095a,0x00000000}},	//   _viue, xte_, _firu,
  { {0x69c90034,0x442d0512,0x07090021,0x00000000}},	//   _whee, vte_, ريبي_,
  { {0x6abc001f,0xc794007e,0x69c915f1,0x00000000}},	//   _gyrf, جشنب, _thee,
  { {0x05540076,0x442d15f2,0x290415f3,0x00000000}},	//   атья, tte_, _gema_,
  { {0xf1bf15f4,0x7793007e,0x6569021e,0x00000000}},	//   dlá_, _پیغا, rjeh,
  { {0x442d15f5,0x2904001c,0x61e300a4,0x00000000}},	//   rte_, _zema_, _punl,
  { {0x3f9801b3,0x6569007d,0x442d15f6,0x00000000}},	//   viru_, pjeh, ste_,
  { {0x442d15f7,0xdd110058,0xeab2009a,0x00000000}},	//   pte_, _rüşd, מֹר_,
  { {0x394d0185,0x628e0024,0x3f9815f8,0x00000000}},	//   _maes_, úbor, tiru_,
  { {0x649a00b7,0x749a00b5,0xe7c30042,0x00000000}},	//   _אינה, _אינפ, षतिप,
  { {0xe1f104de,0x200000e5,0x6fc0004d,0x00000000}},	//   _است_, _wwii_, löck,
  { {0x22580146,0x7bdc15f9,0x6e930044,0x00000000}},	//   ærke_, _siru, حلفا,
  { {0x25bf000c,0xe0da0a36,0x3f98007d,0x00000000}},	// [1de0] ilul_, _яви_, piru_,
  { {0xdd0401f7,0xbb4a0021,0x25bf0150,0x00000000}},	//   ısın, علان_, hlul_,
  { {0xe37a07e9,0x7bdc15fa,0x2d8c006c,0x00000000}},	//   ערער, _viru, èdes_,
  { {0xdcf7003b,0x7bdc0051,0xfe9b0149,0x00000000}},	//   ăcăr, _wiru, _טיימ,
  { {0x7bdc15fb,0x8eda005d,0xed570094,0x00000000}},	//   _tiru, _تذکر_, _соя_,
  { {0xc808008b,0x81bd008f,0x47330054,0x00000000}},	//   rở_, ltēt, йніс,
  { {0x394d001f,0x290415fc,0x645d04c7,0x00000000}},	//   _faes_, _tema_, åsin,
  { {0x746a0160,0x5e570047,0x81bd001c,0x00000000}},	//   еров_, ריקע_, ntēt,
  { {0x69d80078,0xdb1c004d,0x7d0615fd,0x00000000}},	//   įved, _thrä, _meks,
  { {0x25bf003b,0xa265008d,0x7d0615fe,0x00000000}},	//   alul_, _trộ, _leks,
  { {0x25bf003b,0x877b0041,0x81bd008f,0x00000000}},	//   blul_, _ראבי, ktēt,
  { {0x25bf003b,0x6fc00354,0xd0d50062,0x00000000}},	//   clul_, böck, ионъ,
  { {0x637615ff,0x637f00be,0xbfab01ce,0x00000000}},	//   _sânu, _gêno, етве_,
  { {0x6376000c,0xf1bf1600,0x7d06005f,0x00000000}},	//   _cânt, slá_, _aeks,
  { {0xa3c30161,0xa3c10053,0xbed50699,0x00000000}},	//   ्षर_, ंतर_, ровј,
  { {0x8cf50002,0xbca50021,0x9e430061,0x00000000}},	//   рзац, لمزي, žďov,
  { {0xcb1b000a,0xbcfb006d,0x6376003b,0x00000000}},	// [1df0] еќе_, _anéc, _fânt,
  { {0x3ce60066,0xeb930044,0x75e70058,0x00000000}},	//   ľova_, حظر_, _sızm,
  { {0x7d06013d,0x394d00be,0x9a27005d,0x00000000}},	//   _feks, _paes_, طعان,
  { {0x4dfa00b5,0xa9070049,0x99d4009e,0x00000000}},	//   _שפרא, ابان, متنا,
  { {0xd7050867,0xa1ac009d,0x00000000,0x00000000}},	//   азли, עֱבִ,   ,
  { {0x07a5000a,0x91720013,0x17f80021,0x00000000}},	//   јакн, rở_, ارنة_,
  { {0x6d4f014f,0x25bf000c,0x27f800c2,0x00000000}},	//   _kaca, tlul_, _črne_,
  { {0x6d4f1601,0x6fc0004d,0x59a90082,0x00000000}},	//   _jaca, töck, _कदिर,
  { {0xb81c0053,0x64a5000d,0x27f80240,0x00000000}},	//   _नियम_, рапа, čený_,
  { {0x6d4f1602,0x25bf011b,0xd7f801ce,0x00000000}},	//   _laca, slul_, _љут_,
  { {0x25bf1603,0x3dc0002b,0xa2d00082,0x00000000}},	//   plul_, yliw_, डेल्,
  { {0x2496006a,0x6376003b,0x672d007d,0x00000000}},	//   انید_, _sânt, đaju,
  { {0x764e0026,0x7d060d38,0x6376156c,0x00000000}},	//   _ábyr, _reks, _pânt,
  { {0x6376000c,0x7d061604,0x64591605,0x00000000}},	//   _dâns, _seks, _irwi,
  { {0x3ebe0026,0x6376003b,0x645c001c,0x00000000}},	//   ætt_, _vânt, ārie,
  { {0xed460699,0x6d4f1606,0x64590022,0x00000000}},	//   јнап, _caca, _krwi,
  { {0x7d061607,0x81bd001c,0xcaf60021,0x00000000}},	// [1e00] _veks, rtēt, لساب,
  { {0xb8820080,0x6e2f00ea,0x25780014,0x00000000}},	//   říkl, önbö, _hélt_,
  { {0xeb970001,0x7d061608,0x590a0062,0x00000000}},	//   јих_, _teks, веем_,
  { {0x32360047,0xc236009a,0x010d009d,0x00000000}},	//   יטען_, ירעו_, ֲלוּ,
  { {0xa01b00ea,0x6d440f84,0x7b01013d,0x00000000}},	//   szöv, meia, éztü,
  { {0x2d800051,0xc7a306be,0x6d4f1100,0x00000000}},	//   lkie_, оичк, _zaca,
  { {0x7c2402dd,0xbb3b0063,0xdaba007e,0x00000000}},	//   luir, _שעלי, _شهرت_,
  { {0x2d80021f,0xdb071609,0x6d44155f,0x00000000}},	//   nkie_, _skjø, neia,
  { {0xb716007e,0x69c2004b,0x7c24160a,0x00000000}},	//   _نباش, mloe, nuir,
  { {0x6e3e0031,0x69c2160b,0x443d0509,0x00000000}},	//   _oppb, lloe, _dpw_,
  { {0x2d80160c,0x82a60002,0xdb1c0025,0x00000000}},	//   kkie_, ршпе, _bhrú,
  { {0x7c2400b2,0x2578013d,0x067b009a,0x00000000}},	//   kuir, _célt_, _שנאל,
  { {0x6d44017d,0x248d0051,0xdb050331,0x00000000}},	//   deia, czem_, rohú,
  { {0xdb0500c7,0x6d4f0297,0x7c2402a5,0x00000000}},	//   llhö, _saca, duir,
  { {0xf206005a,0xbcfb0003,0x6d4f160d,0x00000000}},	//   _тяло, _anéa, _paca,
  { {0xdb1c0027,0xccf80001,0x69c8001c,0x00000000}},	//   _ghrú, ићу_, _ūden,
  { {0x4424160e,0x7c240741,0x6562108f,0x00000000}},	// [1e10] num_, guir, _mnoh,
  { {0x6d4f014f,0x25a9160f,0x2d800022,0x00000000}},	//   _waca, čali_, akie_,
  { {0x6d4f0027,0x5a3506be,0x44241610,0x00000000}},	//   _taca, снет, hum_,
  { {0xac190086,0x7c241611,0x44241612,0x00000000}},	//   _йому_, buir, kum_,
  { {0x765a0045,0x44241613,0x7c24003b,0x00000000}},	//   _arty, jum_, cuir,
  { {0xbb850032,0x44241614,0x248d00c2,0x00000000}},	//   _السي, dum_, vzem_,
  { {0x69c21615,0xe28e0131,0xff18009a,0x00000000}},	//   bloe, _наi_, בקות_,
  { {0x4424007a,0x69c20268,0x248d0268,0x00000000}},	//   fum_, cloe, tzem_,
  { {0x44241616,0xe3b90ab1,0x00000000,0x00000000}},	//   gum_, лби_,   ,
  { {0xd7740032,0x8c1a0063,0xdb0506a5,0x00000000}},	//   _والع, נותי, gohø,
  { {0x237800c7,0x7c24000c,0x248d101d,0x00000000}},	//   örja_, zuir, szem_,
  { {0xa06a0001,0x7d0d0656,0x442407ab,0x00000000}},	//   гама_, jaas, bum_,
  { {0x44240529,0x645d0146,0xb09a0086,0x00000000}},	//   cum_, æsid, утнє_,
  { {0xa027007a,0x64491617,0x7d0d004b,0x00000000}},	//   _stöð, mwei, eaas,
  { {0x644900bd,0x2d800051,0x51f50242,0x00000000}},	//   lwei, tkie_, _استر,
  { {0xdb05017d,0x75291618,0x7d0d0019,0x00000000}},	//   ilhõ, ngez, gaas,
  { {0x644900bd,0x69c20173,0x2d800474,0x00000000}},	// [1e20] nwei, vloe, rkie_,
  { {0x7c241619,0xcb0a007e,0x2d80030f,0x00000000}},	//   ruir, ايان_, skie_,
  { {0x7d0d0019,0x6449161a,0x6e3e161b,0x00000000}},	//   baas, hwei, _uppb,
  { {0xed5f0024,0x7529006f,0x644906aa,0x00000000}},	//   ážte_, jgez, kwei,
  { {0xa3e70053,0x7c240f15,0x48130054,0x00000000}},	//   _मूल_, quir, зміс,
  { {0x6449001f,0x31b20066,0x69c205d4,0x00000000}},	//   dwei, rázy_, sloe,
  { {0x44240051,0x69c2006f,0x6449087d,0x00000000}},	//   wum_, ploe, ewei,
  { {0x644900bd,0x9f8400fe,0x7529161c,0x00000000}},	//   fwei, löä_, ggez,
  { {0x79820051,0x3946161d,0x161a0053,0x00000000}},	//   mkow, meos_, _नटवर_,
  { {0xd2140001,0x4424161e,0x7982161f,0x00000000}},	//   омоћ, rum_, lkow,
  { {0x44241620,0xd4e60062,0xb7d70593,0x00000000}},	//   sum_, _люли, _اولا_,
  { {0x79820045,0x4424007a,0x656200fe,0x00000000}},	//   nkow, pum_, _unoh,
  { {0x5433007e,0x7d0d0072,0x9f840072,0x00000000}},	//   _فرور, vaas, köä_,
  { {0xd5be0023,0x1ee7005d,0xc4c50044,0x00000000}},	//   žādo_, صوری_, _بتمو,
  { {0x7a1c0529,0x7d0d1621,0x877b0aeb,0x00000000}},	//   nătă, taas, נאלי,
  { {0x63ba1622,0xdd940088,0x3253005a,0x00000000}},	//   lotn, пасы, _хвър,
  { {0x79820051,0x2d580b3f,0x39460bea,0x00000000}},	// [1e30] dkow, щить_, deos_,
  { {0x7d0d0019,0x2d9e0153,0x63ba1623,0x00000000}},	//   saas, éter_, notn,
  { {0x7d0d00fe,0x644900bd,0x27f800c2,0x00000000}},	//   paas, zwei, _črna_,
  { {0xf1c90161,0x61ea1624,0x63ba1625,0x00000000}},	//   रतिन, _mufl, hotn,
  { {0x63ba1626,0x1869151b,0x6e2700dd,0x00000000}},	//   kotn, рали_, lujb,
  { {0x36190055,0xa09c0047,0xb09c0047,0x00000000}},	//   ацию_, ניגט, ניגר,
  { {0x994d0024,0x75290194,0x79821627,0x00000000}},	//   môžu_, tgez, bkow,
  { {0x64491628,0x0e9c0047,0x394605d5,0x00000000}},	//   twei, טשול, ceos_,
  { {0x61ea00bd,0xa3e9000a,0x75291629,0x00000000}},	//   _aufl, јдоа_, rgez,
  { {0x290f162a,0x6449162b,0x13090121,0x00000000}},	//   laga_, rwei, шной_,
  { {0x6449162c,0x7529006f,0x7a1c003b,0x00000000}},	//   swei, pgez, cătă,
  { {0x290f0214,0x15a80062,0x63a8004e,0x00000000}},	//   naga_, _лъчи_, andn,
  { {0x2bbe0161,0xafdb00d1,0x290f0089,0x00000000}},	//   ्तमा, lvøy, iaga_,
  { {0x3e8a000d,0x79820051,0x7989162d,0x00000000}},	//   айго_, zkow, _llew,
  { {0xaf990376,0x290f162e,0x79820051,0x00000000}},	//   стях_, kaga_, ykow,
  { {0xa3c30053,0x290f162f,0xa6e20014,0x00000000}},	//   ्षक_, jaga_, æðik,
  { {0x9f8400fe,0x0eb60053,0x290f1630,0x00000000}},	// [1e40] töä_, _आँकड, daga_,
  { {0x76411631,0x290f1632,0x79820022,0x00000000}},	//   _oply, eaga_, wkow,
  { {0x79820045,0x798900f1,0x61e401a9,0x00000000}},	//   tkow, _blew, _kiil,
  { {0x5f46006a,0xed5a10e4,0x9f840072,0x00000000}},	//   _انگل, _том_, söä_,
  { {0x79820051,0x39461633,0x91720013,0x00000000}},	//   rkow, reos_, iờ_,
  { {0x394602dd,0x79820051,0x79891147,0x00000000}},	//   seos_, skow, _elew,
  { {0x394602dd,0x290f0551,0x637f017d,0x00000000}},	//   peos_, baga_, _gêni,
  { {0x61e400fe,0x63ba1634,0x79890244,0x00000000}},	//   _niil, wotn, _glew,
  { {0x61ea000c,0x236a00e1,0x63ba1308,0x00000000}},	//   _sufl, ајно_, totn,
  { {0xe72a005d,0xbcfb013d,0x63a80046,0x00000000}},	//   _خسرو_, _anél, undn,
  { {0x32660086,0x63ba1635,0xa1591636,0x00000000}},	//   ітов, rotn, бану_,
  { {0x63ba00c3,0x656f00bd,0xe578008f,0x00000000}},	//   sotn, öcht, _puķu_,
  { {0x61e410a5,0x83f80062,0x63ba1637,0x00000000}},	//   _diil, _уелс_, potn,
  { {0x60cd00c2,0xa2940500,0xbcfb013d,0x00000000}},	//   _vzam, _налі, _enél,
  { {0x290f002c,0x3f830014,0x61e41638,0x00000000}},	//   yaga_, rkju_, _fiil,
  { {0x3f830046,0xd0110044,0x71f704a0,0x00000000}},	//   skju_, _كلب_, _بروس_,
  { {0xe57100b5,0x6ebb0053,0x290f10c8,0x00000000}},	// [1e50] ײַן_, _शुरु, vaga_,
  { {0x7e2b0088,0x6d5600a4,0xddeb007e,0x00000000}},	//   _кіма_, adya, _پرده_,
  { {0xdced017f,0xdb070014,0xfc3f0013,0x00000000}},	//   ljač, _skjó, _axít_,
  { {0x9981004c,0xdced0130,0xe81c0082,0x00000000}},	//   ruhů_, ojač, _निशा_,
  { {0xa8040088,0x290f1639,0xdced0734,0x00000000}},	//   дзіл, raga_, njač,
  { {0x637f017d,0x2009163a,0x69c00058,0x00000000}},	//   _têni, _mwai_, _ekme,
  { {0x64420016,0xf96b163b,0x91720013,0x00000000}},	//   _apoi, _край_, hớ_,
  { {0x76410024,0xe795007e,0x799b00a4,0x00000000}},	//   _vply, _کارک, _umuw,
  { {0xdced007d,0xd7f804f2,0xc952009a,0x00000000}},	//   jjač, _дух_, _אמן_,
  { {0xdced007d,0x61e4163c,0xe3b10044,0x00000000}},	//   djač, _siil, عرة_,
  { {0x61e400fe,0x4b7c00b5,0x76410240,0x00000000}},	//   _piil, יאזו, _uply,
  { {0xe8020161,0x644f0146,0x75e7013d,0x00000000}},	//   रीका_, æcis, _tűzb,
  { {0xe5c4000d,0x61e4163d,0x7fd60085,0x00000000}},	//   _ўсхо, _viil, зіві,
  { {0x22150062,0xf767014d,0xe0d70062,0x00000000}},	//   _ефир, را_, явя_,
  { {0x61e40072,0x63a1163e,0x27ed0050,0x00000000}},	//   _tiil, miln, _luen_,
  { {0x63a1163f,0x661c00b9,0x68e9006f,0x00000000}},	//   liln, _ærke, _nged,
  { {0x27f800c2,0x8b26000d,0x201a0021,0x00000000}},	// [1e60] _črno_, здзе, _اتبع_,
  { {0x645b00fe,0x63a11640,0xe7ef0042,0x00000000}},	//   ivui, niln, _चढ़ा_,
  { {0x7c361641,0xaac5007e,0x3f7b0063,0x00000000}},	//   styr, وتمن, _האיס,
  { {0x7e610146,0x27ed02dd,0x290d0529,0x00000000}},	//   ælpe, _buen_, _ceea_,
  { {0xa3cb0053,0x7d041642,0xbc190054,0x00000000}},	//   लता_, mbis, _мірі_,
  { {0x26c50080,0x68ed0024,0x63a100c2,0x00000000}},	//   _bylo_, ľada, jiln,
  { {0x68ed02f4,0x63a10198,0x6b630500,0x00000000}},	//   žada, diln, _якра,
  { {0xb6080080,0x442a000d,0x63a1004d,0x00000000}},	//   jišť, бцом_, eiln,
  { {0xdb05006d,0xbcfb0066,0x63a106f1,0x00000000}},	//   cohó, _poéz, filn,
  { {0x57fb0063,0xb882004c,0x53980054,0x00000000}},	//   _ללמו, řísl, івня_,
  { {0xa294046e,0x97310043,0xdb37009a,0x00000000}},	//   фані, _شکوا, הניח_,
  { {0x64420072,0x7c240130,0xa3e70082,0x00000000}},	//   _tpoi, krir, _मूक_,
  { {0x53340076,0x7d04007d,0x777a00cd,0x00000000}},	//   _желт, dbis, _kotx,
  { {0x63a11643,0x7d041644,0x62811645,0x00000000}},	//   ciln, ebis, bylo,
  { {0xe3b30047,0x433b0063,0x733b0063,0x00000000}},	//   _אױס_, _העוב, _העוס,
  { {0x7d04002c,0x7c241646,0x44241647,0x00000000}},	//   gbis, frir, orm_,
  { {0xb606007d,0x7c241648,0xdfb5005e,0x00000000}},	// [1e70] lošć, grir, _обињ,
  { {0x7d04061e,0x44240c0c,0x25a0004c,0x00000000}},	//   abis, irm_, čily_,
  { {0x7c241649,0xb606007d,0x7d04164a,0x00000000}},	//   arir, nošć, bbis,
  { {0x7c240e57,0x7c87005e,0x63a100a8,0x00000000}},	//   brir, _еуге, ziln,
  { {0x7c240003,0x27ed008b,0xdb1c164b,0x00000000}},	//   crir, _quen_, _chró,
  { {0x777a0268,0xf794000d,0x3dc9002b,0x00000000}},	//   _cotx, начэ, llaw_,
  { {0x63a1164c,0x4424164d,0x7d0f013d,0x00000000}},	//   viln, erm_, _kecs,
  { {0x4975000d,0xdb0500cd,0x27ed00fe,0x00000000}},	//   _ўлас, cohò, _tuen_,
  { {0x3dc900a4,0x69c30003,0x63a1164e,0x00000000}},	//   ilaw_, îneu, tiln,
  { {0x7d0400bd,0x645b006f,0x7d0f00ea,0x00000000}},	//   zbis, rvui, _lecs,
  { {0x3ce60024,0x63a1164f,0x3dc900a4,0x00000000}},	//   ľovi_, riln, klaw_,
  { {0x7c24007a,0x62811650,0xa0a6005e,0x00000000}},	//   yrir, rylo, дамд,
  { {0xbcfb0024,0x63a11651,0x25ad004e,0x00000000}},	//   _inéh, piln, mnel_,
  { {0x7df50006,0x3f8c027d,0x7c241652,0x00000000}},	//   _sąsa, ódu_, vrir,
  { {0x25ad0146,0x7d0f000f,0xb2220014,0x00000000}},	//   onel_, _becs, þætt,
  { {0x3cf50161,0x25ad0238,0x25bf1653,0x00000000}},	//   एँगे_, nnel_, noul_,
  { {0x7d0400bb,0xa01b00fe,0x629c0195,0x00000000}},	// [1e80] rbis, lyön, úrov,
  { {0x7c241654,0x7d041655,0x60c0004d,0x00000000}},	//   rrir, sbis, ümmu,
  { {0x3dc9001f,0x68ed0066,0x41b3005d,0x00000000}},	//   blaw_, ľadn, _سمیر,
  { {0x7c241656,0xdb1c0025,0x18a60ee5,0x00000000}},	//   prir, _phró, маем,
  { {0xb8f60161,0xd7ef0021,0x00000000,0x00000000}},	//   _हर_, لكن_,   ,
  { {0xa6340086,0x4b550062,0x25ad0058,0x00000000}},	//   енкі, _пъст, enel_,
  { {0x9f8d0026,0x97c50044,0x5ee9009a,0x00000000}},	//   nþá_, رتهم, הַפְ,
  { {0xa5340962,0xb606007d,0x54541657,0x00000000}},	//   хнич, vošć, евит,
  { {0x31b90066,0x9326005d,0x6b73056c,0x00000000}},	//   cézy_, وردن, _węgł,
  { {0x42740076,0x7c2b00cd,0x29061658,0x00000000}},	//   егос, àgri, lboa_,
  { {0xa159005e,0x2b581659,0x25bf006c,0x00000000}},	//   пану_, _marc_, boul_,
  { {0xc486019d,0x21670086,0x5a170047,0x00000000}},	//   _олек, фтог, וקטן_,
  { {0x10740071,0xdced0066,0xf5770021,0x00000000}},	//   вляю, tiaľ, _تمنع_,
  { {0x0efb0161,0x81bd0023,0xbefb0042,0x00000000}},	//   ्रेस_, ntēz, ्रेन_,
  { {0x3dc9059f,0x7d0f013d,0x4ea41313,0x00000000}},	//   tlaw_, _pecs, врта,
  { {0xcdd80001,0xa5d80aeb,0xe2870043,0x00000000}},	//   дњу_, לַּי, _تطهی,
  { {0x7d02006d,0x2b58002b,0x60c0004d,0x00000000}},	// [1e90] ñosa, _barc_, ümmt,
  { {0x3dc9165a,0x2bb80044,0x1a8b0044,0x00000000}},	//   slaw_, والة_, يضاً_,
  { {0x7d0f155f,0x2019165b,0xb50e0042,0x00000000}},	//   _tecs, lssi_, सराय_,
  { {0x68ed0024,0x7d1d004d,0x645c008f,0x00000000}},	//   ľado, _udss, ārij,
  { {0x6cfa0063,0x68ed0512,0x2b58165c,0x00000000}},	//   _מפרס, žado, _farc_,
  { {0x237c08ed,0x00000000,0x00000000,0x00000000}},	//   _novj_,   ,   ,
  { {0x7c2d165d,0xbcfb017d,0x2bbe0053,0x00000000}},	//   luar, _anéi, ्तरा,
  { {0xc8670062,0x6d4d165e,0x00000000,0x00000000}},	//   _отзи, neaa,   ,
  { {0x25bf003b,0x73e50062,0x7c2d165f,0x00000000}},	//   roul_, ноиз, nuar,
  { {0xe2990001,0x69cb1660,0x6d4d004b,0x00000000}},	//   зао_, llge, heaa,
  { {0x20190026,0x69cb010b,0x6d4d00fe,0x00000000}},	//   essi_, olge, keaa,
  { {0x7c2d0bda,0x865a009a,0xa3cf0042,0x00000000}},	//   kuar, _מדעי, _वीर_,
  { {0x656b051e,0xbcfb0025,0x1fb60002,0x00000000}},	//   _ingh, _gnéi, есвр,
  { {0x7c2d1661,0x69cb00bd,0x442d1662,0x00000000}},	//   duar, hlge, mue_,
  { {0x20191663,0x3c43001c,0x442d1664,0x00000000}},	//   assi_, hīvā_, lue_,
  { {0x7c2d0025,0x52740021,0x29e80058,0x00000000}},	//   fuar, _جاهز, _aşan_,
  { {0x442d04bc,0x7c2d1665,0x6aa80053,0x00000000}},	// [1ea0] nue_, guar, कप्र,
  { {0xe0d7000d,0x3a06007e,0x69cb1666,0x00000000}},	//   _явы_, فکری_, elge,
  { {0x6376003b,0x656b1667,0xa9260f34,0x00000000}},	//   _pânz, _ongh, едел,
  { {0xb17b00c7,0x6d4d006f,0x442d1668,0x00000000}},	//   rmåg, ceaa, kue_,
  { {0x63760529,0x442d0035,0x7c2d1669,0x00000000}},	//   _vânz, jue_, cuar,
  { {0x7d16166a,0x656b0185,0xdb070026,0x00000000}},	//   lays, _angh, _skjö,
  { {0x442d166b,0x3ce60066,0xb17b0137,0x00000000}},	//   eue_, ľovu_, lmåe,
  { {0xfa89000d,0x09e3166c,0x89da0044,0x00000000}},	//   _ўсёй_, _босн, _روذر_,
  { {0x6e2e0717,0xdb1e01a8,0x98af0078,0x00000000}},	//   hubb, topè, degė_,
  { {0x656b001f,0x96960925,0xa6960141,0x00000000}},	//   _engh, _преш, _преј,
  { {0xeb970063,0x7bde003b,0xbcfb0003,0x00000000}},	//   גדיר_, impu, _inév,
  { {0x7c2d0089,0x6e2e166d,0x442d166e,0x00000000}},	//   yuar, dubb, bue_,
  { {0x20190164,0xf1a4000d,0xe82a0063,0x00000000}},	//   ussi_, урэн, הוָֽ,
  { {0x20190cb0,0xa3cb0042,0xccf9056c,0x00000000}},	//   rssi_, लतः_, _żś_,
  { {0x6f1500c3,0x656b001f,0x2e480156,0x00000000}},	//   razc, _yngh, нято_,
  { {0x7bde053b,0x40950021,0x9981004c,0x00000000}},	//   empu, _للبر, vrhů_,
  { {0x6d4d166f,0xb81c0042,0xb17b00a5,0x00000000}},	// [1eb0] reaa, _निगम_, rmåd,
  { {0xb17b0146,0x69cb006f,0x764805a5,0x00000000}},	//   småd, wlge, _opdy,
  { {0x7c2d1670,0x6d4d1671,0x4939000d,0x00000000}},	//   suar, peaa, дзею_,
  { {0x4ac40021,0x3c43001c,0xa91d00c2,0x00000000}},	//   ديمق, tīvā_, _možg,
  { {0xe10c00b5,0xdee7007e,0x89340044,0x00000000}},	//   פּאָ, _تأکي, اعما,
  { {0x9be4000d,0x442d1672,0xa3cf0053,0x00000000}},	//   _біск, vue_, _वीं_,
  { {0xead40076,0x9732005d,0xcb12009a,0x00000000}},	//   _борь, شکلا, _כלם_,
  { {0x442d1673,0x68fb002b,0x9c870066,0x00000000}},	//   tue_, _ufud, cičí,
  { {0xe4320032,0x00000000,0x00000000,0x00000000}},	//   لفيد,   ,   ,
  { {0x394f1674,0x2d9e0003,0x442d1675,0x00000000}},	//   legs_, étez_, rue_,
  { {0x442d11e8,0x27f800c2,0xbb3c0047,0x00000000}},	//   sue_, _črni_, לעזי,
  { {0x656b08c8,0xe4d90021,0xdb1e1676,0x00000000}},	//   _ungh, _قوات_, ropé,
  { {0x442d1677,0x80d90054,0x7bde1678,0x00000000}},	//   que_, еєру_, ympu,
  { {0x6e2e1679,0xdb1c011b,0x00000000,0x00000000}},	//   tubb, _okrá,   ,
  { {0x7d02006d,0x6da60fec,0x5cf6014b,0x00000000}},	//   ñoso, вива, вязу,
  { {0x32050034,0x12e80149,0xc692069a,0x00000000}},	//   mply_, _אַפּ, באל_,
  { {0xa91d0117,0x2bf60076,0x5f06005a,0x00000000}},	// [1ec0] _možd, тябр, _изпа,
  { {0x6e2e051e,0x7d16002c,0x7bde0228,0x00000000}},	//   pubb, says, umpu,
  { {0xdee602d8,0xfeba0044,0x00000000,0x00000000}},	//   _јони, _زادت_,   ,
  { {0x99750121,0xdd05003b,0x637e004c,0x00000000}},	//   лучш, ăsăr, _záně,
  { {0x81bd001c,0xe995005d,0xc7ba014b,0x00000000}},	//   frēj, دهنگ, мёк_,
  { {0xc66a0121,0xe7180044,0x81bd0023,0x00000000}},	//   дшие_, ريبت_, grēj,
  { {0x98b201f7,0x092a0044,0xe93a0896,0x00000000}},	//   ıyı_, _يسري_, _очај_,
  { {0xceb30063,0xd6d90054,0x644700dd,0x00000000}},	//   ייו_, хті_, ăjin,
  { {0xdb1c0080,0x3205167a,0xa01b0050,0x00000000}},	//   _zkrá, eply_, työm,
  { {0xa91d00c2,0x3254167b,0x98750058,0x00000000}},	//   _požg, гвор, lüğe_,
  { {0xc56a0021,0xc5f60094,0x66e607ed,0x00000000}},	//   _يحصل_, _рязъ, _рожа,
  { {0xfbdf001f,0x316d0871,0x91fc0023,0x00000000}},	//   _apêl_, ñez_, evāc,
  { {0x9054000d,0x60d60022,0x71a40085,0x00000000}},	//   авяц, _czym, раўз,
  { {0x547b014e,0x9e3505ac,0xa382004e,0x00000000}},	//   _קטגו, легч, õõdu,
  { {0x63a8167c,0xdb06004c,0xdd950085,0x00000000}},	//   midn, ámýc, гавы,
  { {0x7bc7105a,0xf2d30047,0xa91d004c,0x00000000}},	//   _skju, _דעצ_, _kože,
  { {0xdb1c007a,0xfbd90259,0xa91d085a,0x00000000}},	// [1ed0] _skrá, едај_, _jože,
  { {0xa91d0117,0x8f55019d,0xfecb0021,0x00000000}},	//   _može, _свої, _يبدو_,
  { {0x75221401,0x61ed1037,0xdb050014,0x00000000}},	//   _odoz, _kial, nihé,
  { {0xeb9f00b9,0xafdb00b9,0x629a00ea,0x00000000}},	//   _stød_, stød, izto,
  { {0xa3c2016a,0x61ed0035,0x63a8007d,0x00000000}},	//   ंवा_, _mial, kidn,
  { {0x75220290,0x6d5d167d,0xab840154,0x00000000}},	//   _adoz, _hasa, _куск,
  { {0x6d5d0273,0x3f810080,0x27ec0034,0x00000000}},	//   _kasa, _mohu_, _didn_,
  { {0x7bc50035,0x63a8167e,0x62881566,0x00000000}},	//   lohu, eidn, dydo,
  { {0x6d5d167f,0x60cd091c,0x629a001c,0x00000000}},	//   _masa, _nyam, ezto,
  { {0x60d60051,0x6d5d1680,0xdb1c00b9,0x00000000}},	//   _rzym, _lasa, _ekræ,
  { {0x60d60022,0xe2070022,0x42541681,0x00000000}},	//   _szym, _ogół_, атят,
  { {0x74b9000a,0x61ed0025,0x6d5d1682,0x00000000}},	//   _пулс_, _cial, _nasa,
  { {0x343900b5,0x7bc50019,0x442905d5,0x00000000}},	//   _נײַע, kohu, _ía_,
  { {0x443f003d,0x947404f6,0x32051683,0x00000000}},	//   mtu_, _خدما, pply_,
  { {0x443f0884,0x225805b9,0x62880051,0x00000000}},	//   ltu_, ærkt_, cydo,
  { {0x2d950088,0x61ed051e,0x6d5d00c5,0x00000000}},	//   арус, _gial, _casa,
  { {0x443f1684,0x6d5d08f0,0x20040025,0x00000000}},	// [1ee0] ntu_, _dasa, ímid_,
  { {0x79800035,0x28b70053,0x6d5d0139,0x00000000}},	//   _somw, _आख़ि, _easa,
  { {0x443f0004,0x092a0076,0x69db0025,0x00000000}},	//   htu_, ежей_, _bhue,
  { {0x644b1685,0x7d560086,0x69db0331,0x00000000}},	//   _opgi, _стої, _chue,
  { {0x657b0019,0x443f0743,0xa2ca0053,0x00000000}},	//   djuh, jtu_, _सुन्,
  { {0xdb1c1686,0xcb760001,0xa91d00c2,0x00000000}},	//   _skræ, _сумњ, _rože,
  { {0x6d5d01f7,0xa01b00fe,0xbb3b0047,0x00000000}},	//   _yasa, työk, _רעלי,
  { {0x7df50812,0x6d440b16,0x7792007e,0x00000000}},	//   _sąsk, nfia, _گیتا,
  { {0x61ed0027,0x443f001c,0x63a80415,0x00000000}},	//   _rial, gtu_, tidn,
  { {0xf2060878,0xdb1e0240,0xb8930021,0x00000000}},	//   лямо, kopí, _الكع,
  { {0x61ed0397,0x60cd0397,0x443f1687,0x00000000}},	//   _pial, _syam, atu_,
  { {0x7bc50009,0x443f003e,0x6288001f,0x00000000}},	//   zohu, btu_, rydo,
  { {0x7bc50009,0x629a1688,0x6d5d1689,0x00000000}},	//   yohu, szto, _rasa,
  { {0x225800b9,0x60cd0035,0x6d5d168a,0x00000000}},	//   ærks_, _vyam, _sasa,
  { {0xcddb0459,0x6d5d168b,0x2d820130,0x00000000}},	//   ења_, _pasa, _boke_,
  { {0x2d580619,0x5d55000a,0x7ae11114,0x00000000}},	//   лись_, јкат, _últi,
  { {0x7bdc0027,0x65600025,0x6d5d168c,0x00000000}},	// [1ef0] _bhru, idmh, _vasa,
  { {0x7bdc0027,0xa01b00fe,0x39b10006,0x00000000}},	//   _chru, vyöh, mąsi_,
  { {0x63af00f8,0x6440004b,0xaa5509da,0x00000000}},	//   écni, htmi, рвеш,
  { {0xbcfb0460,0x7bc5004b,0x6d5d0139,0x00000000}},	//   _enér, sohu, _uasa,
  { {0x998700ea,0x443f016b,0x657b004b,0x00000000}},	//   énő_, xtu_, vjuh,
  { {0x6605000a,0x16390021,0x8ae70304,0x00000000}},	//   апка, نسبة_, _бібл,
  { {0x66240021,0x2d82077d,0x9675000d,0x00000000}},	//   مريك, _yoke_, рылі,
  { {0x7c2d051e,0x443f168d,0x7bdc0114,0x00000000}},	//   orar, ttu_, _zhru,
  { {0x99840032,0x765a168e,0xa91d00c2,0x00000000}},	//   _القو, _esty, _tožb,
  { {0xc245000a,0x657b0ff2,0x4734007e,0x00000000}},	//   анок, sjuh, _هرمز,
  { {0x7d0d00c7,0x395f0150,0xa2290062,0x00000000}},	//   kbas, _kaus_, ъжна_,
  { {0x9f49007a,0x7c2d168f,0x3f850014,0x00000000}},	//   _stað_, krar, ölun_,
  { {0x64590035,0x2d8200c2,0x95c4007e,0x00000000}},	//   _uswi, _roke_, _اينه,
  { {0x442d1690,0x23290086,0x765a0185,0x00000000}},	//   mre_, _роки_, _ysty,
  { {0x442d000f,0x7c2d1691,0xc3320041,0x00000000}},	//   lre_, erar, _ווו_,
  { {0x442d1692,0x7d0d0a9f,0x395f03ea,0x00000000}},	//   ore_, gbas, _naus_,
  { {0xed570002,0x7c2d1693,0x6db7007d,0x00000000}},	// [1f00] шот_, grar, pćan,
  { {0x442d1694,0xdb230026,0x8b260086,0x00000000}},	//   ire_, ærða, рдже,
  { {0x442d0199,0x2d9e0164,0x2d8200a4,0x00000000}},	//   hre_, ètes_, _toke_,
  { {0xdb1c00c7,0x442d1695,0x7c2d1696,0x00000000}},	//   _skrä, kre_, brar,
  { {0x442d0146,0xed57005a,0x7c2d1697,0x00000000}},	//   jre_, _тоя_, crar,
  { {0x442d04b1,0x7df51435,0xaa0601fb,0x00000000}},	//   dre_, _sąsi, _نظره,
  { {0x6603000a,0x442d02e3,0x6753005d,0x00000000}},	//   опја, ere_, زخور,
  { {0x395f0006,0x6f1c1698,0x69d80078,0x00000000}},	//   _gaus_, harc, įves,
  { {0x442d1699,0x765a0022,0x9f8d0014,0x00000000}},	//   gre_, _wsty, rþú_,
  { {0x46a6011c,0x883b014e,0x9378000a,0x00000000}},	//   _казв, _בתמו, убот_,
  { {0x6440169a,0x442d169b,0xd25701dd,0x00000000}},	//   stmi, are_, аця_,
  { {0xa50a0676,0x04460189,0x442d169c,0x00000000}},	//   _реда_, _ведн, bre_,
  { {0xdcef003d,0x9f840026,0x6f1c001f,0x00000000}},	//   ādīt, töð_, farc,
  { {0x7c2d169d,0x6f1c169e,0x6304005d,0x00000000}},	//   vrar, garc, _اوغل,
  { {0xa3110066,0xfda7005e,0x7d0d169f,0x00000000}},	//   äčšo, ајам, tbas,
  { {0x200400cd,0xb1150a74,0x527b0063,0x00000000}},	//   ímic_, _умиш, _ינוא,
  { {0xdce600eb,0x5ce70086,0x7d0d16a0,0x00000000}},	// [1f10] _mokė, рюва, rbas,
  { {0x7c2d16a1,0xea670001,0x7d0d0f8c,0x00000000}},	//   rrar, ињен, sbas,
  { {0x200b00c2,0x3866004d,0x395f0f7d,0x00000000}},	//   lpci_, evor_, _paus_,
  { {0x442d16a2,0xa91d074f,0x7c2d16a3,0x00000000}},	//   yre_, _boža, prar,
  { {0x67d5000a,0x9f40032a,0xdb1c060b,0x00000000}},	//   боду, _guió_, _skrå,
  { {0xd874006a,0x442d16a4,0x6747000d,0x00000000}},	//   تامب, vre_, рэдз,
  { {0x36180088,0x442d0089,0x386616a5,0x00000000}},	//   ацыю_, wre_, avor_,
  { {0x05620062,0x442d16a6,0xdeb8009a,0x00000000}},	//   звън, tre_, יפוח_,
  { {0x291d00bb,0x31600016,0x442d16a7,0x00000000}},	//   mawa_, _raiz_, ure_,
  { {0x442d16a8,0x316000e3,0x291d15e7,0x00000000}},	//   rre_, _saiz_, lawa_,
  { {0x442d000f,0xa91d16a9,0xb17b0a3f,0x00000000}},	//   sre_, _zoža, rmån,
  { {0x291d16aa,0x68ed0240,0x568c0047,0x00000000}},	//   nawa_, žadu, _שטאַ,
  { {0xa4d40086,0xafe60054,0x25ad16ab,0x00000000}},	//   _доці, йомл, miel_,
  { {0x291d00e3,0xb17b0b19,0xafe601e4,0x00000000}},	//   hawa_, lmål, согл,
  { {0x291d16ac,0x29dc01a8,0xc7d60063,0x00000000}},	//   kawa_, níac_, מושי_,
  { {0x6f1c16ad,0x6dac0058,0x3f8c004b,0x00000000}},	//   sarc, aşan, ödub_,
  { {0x248d00cd,0x291d16ae,0xdd8f0021,0x00000000}},	// [1f20] nyem_, dawa_, روك_,
  { {0xa91d00b2,0x61e616af,0x6dac003b,0x00000000}},	//   _roža, lmkl, cşan,
  { {0xa96a0138,0xdb07000f,0xb17b0d1a,0x00000000}},	//   лижа_, ámár, kmål,
  { {0xa91d016b,0x291d114c,0x38cb007e,0x00000000}},	//   _poža, gawa_, گامی_,
  { {0x25ad0024,0x53c70161,0xb17b0b19,0x00000000}},	//   diel_, रकाश, dmål,
  { {0x1853000d,0x38cb007e,0x6d560ca7,0x00000000}},	//   явіў, دامی_, leya,
  { {0x25ad03a8,0x291d16b0,0xd7f10013,0x00000000}},	//   fiel_, bawa_, _dĩ_,
  { {0xe5c60001,0x2d8000ac,0x6d5616b1,0x00000000}},	//   љско, njie_, neya,
  { {0x7643028d,0x03f8005e,0x53980330,0x00000000}},	//   atny, јној_, ивия_,
  { {0x388e003d,0x5c5b0e2a,0x61e6006f,0x00000000}},	//   _vērā_, נדיק, emkl,
  { {0x25ad0162,0x3f850026,0x91b90002,0x00000000}},	//   biel_, ölum_, игот_,
  { {0xf09f00cd,0x25ad16b2,0x7df50078,0x00000000}},	//   tzà_, ciel_, _mąst,
  { {0x7df50006,0x2d8000ac,0x200b16b3,0x00000000}},	//   _ląst, djie_, upci_,
  { {0xdbf10080,0xa2940088,0x9294026b,0x00000000}},	//   _příl, _малі, _малц,
  { {0x291d0e83,0x6d8a0014,0x6e9416b4,0x00000000}},	//   yawa_, _nýas, пиру,
  { {0x81bd008f,0x00000000,0x00000000,0x00000000}},	//   grēt,   ,   ,
  { {0x75e7013d,0x7dd30075,0x9f84004e,0x00000000}},	// [1f30] _tűzv, nçsi, vöö_,
  { {0x81bd001c,0x291d16b5,0xdea4007e,0x00000000}},	//   arēt, wawa_, _کیفی,
  { {0x9f840019,0x291d16b6,0x2d85006c,0x00000000}},	//   töö_, tawa_, êles_,
  { {0x8f55007e,0xd7f10013,0x6d560075,0x00000000}},	//   _انگش, _sĩ_, ceya,
  { {0xf770006a,0xc9740021,0x291d16b7,0x00000000}},	//   کان_, ثالث, rawa_,
  { {0x25ad0717,0x291d16b8,0xcc76009a,0x00000000}},	//   wiel_, sawa_, _ועשה_,
  { {0x1995000d,0xd7f10013,0x19590085,0x00000000}},	//   _давя, _vĩ_, _кавы_,
  { {0x6fd200b9,0x20090089,0x91fc001c,0x00000000}},	//   ræci, _otai_, rvāl,
  { {0x25ad16b9,0x764316ba,0xb17b02c0,0x00000000}},	//   riel_, stny, rmål,
  { {0xb17b02ea,0x25ad16bb,0x69cb13bb,0x00000000}},	//   smål, siel_, loge,
  { {0x09b500b5,0x25ad16bc,0xf486007e,0x00000000}},	//   ַפֿט_, piel_, مایی,
  { {0xe3b80058,0x69cb16bd,0x6a3a009a,0x00000000}},	//   anı_, noge, סגרפ,
  { {0x69cb001f,0x6d5600e5,0x61e60e46,0x00000000}},	//   ioge, veya, rmkl,
  { {0xaab90053,0x69cb16be,0x2d9900ca,0x00000000}},	//   _आशंक, hoge, _alse_,
  { {0x59c90161,0x2d8000e8,0x394d0222,0x00000000}},	//   िकार, tjie_, _obes_,
  { {0x753b0009,0xa01b0072,0xe627008d,0x00000000}},	//   nguz, työt, _đổ_,
  { {0x6d5616bf,0x81bd008f,0x8c4304c3,0x00000000}},	// [1f40] reya, arēs, мете,
  { {0x2d9916c0,0x6d560003,0xeab20044,0x00000000}},	//   _else_, seya, وعا_,
  { {0x386d00d1,0xe8fa16c1,0xa01b0072,0x00000000}},	//   _arer_, але_, syöt,
  { {0xfd120021,0xcd36005d,0x69cb16c2,0x00000000}},	//   _تجد_, _بردب, goge,
  { {0xe3b8005b,0x386d017d,0x7d0416c3,0x00000000}},	//   ynı_, _crer_, mcis,
  { {0x7c2416c4,0x7d0416c5,0x262a02d8,0x00000000}},	//   msir, lcis, ацио_,
  { {0x07a3000a,0xbf9b0003,0x41ca0053,0x00000000}},	//   ќајн, mpêt, रवास,
  { {0x69cb16c6,0x38aa0022,0x342602d8,0x00000000}},	//   coge, tórą_, офов,
  { {0xdb1e0146,0x7c2416c7,0xb866005d,0x00000000}},	//   ropæ, nsir, _بازو,
  { {0xa3e70001,0x7792007e,0x7c2416c8,0x00000000}},	//   одња_, _زیبا, isir,
  { {0x200908c8,0x6b830026,0x8afb16c9,0x00000000}},	//   _stai_, öngi, יליז,
  { {0x7c2416ca,0x96330454,0x78a2007c,0x00000000}},	//   ksir, _ініц, ozov,
  { {0xa2ca0161,0x7c241235,0xd5e90044,0x00000000}},	//   _सुर्, jsir, _اعلن_,
  { {0xc058019d,0x69cb00bd,0x09b70053,0x00000000}},	//   цію_, zoge, _अद्य,
  { {0x7c2604c7,0xdef4000d,0x44261186,0x00000000}},	//   _avkr, дпры, _hvo_,
  { {0x212900f3,0x7c2416cb,0x3f9a0023,0x00000000}},	//   _udah_, fsir, _elpu_,
  { {0x7dda00cd,0xe5710063,0xdfdb0062,0x00000000}},	// [1f50] aïso, עַל_, _вън_,
  { {0x78a20024,0x63ba00bd,0x79820022,0x00000000}},	//   dzov, nntn, ejow,
  { {0x7c2400eb,0x6b510014,0x69cb16cc,0x00000000}},	//   asir, _aðgæ, toge,
  { {0x4426055e,0x7d0416cd,0x91fc0023,0x00000000}},	//   _ovo_, ccis, evāk,
  { {0xdb1e004b,0x6c790047,0x69cb16ce,0x00000000}},	//   fopä, _האָפ, roge,
  { {0xbdf8007e,0x69cb16cf,0x7d1d16d0,0x00000000}},	//   _دریا_, soge, _hess,
  { {0x29dc006d,0x69cb0baf,0x442616d1,0x00000000}},	//   mían_, poge, _avo_,
  { {0x386d00d1,0x29dc006d,0x79820051,0x00000000}},	//   _trer_, lían_, cjow,
  { {0x7d1d1130,0x93790021,0x7d01013d,0x00000000}},	//   _mess, مصدر_, _záró,
  { {0x29dc02dd,0x79890173,0x645b00ac,0x00000000}},	//   nían_, _hoew, rwui,
  { {0x442616d2,0x7d040051,0x0322000d,0x00000000}},	//   _evo_, ycis, эдэн,
  { {0x7d1d16d3,0xe610007e,0xc19a0054,0x00000000}},	//   _ness, _ششم_, стої_,
  { {0xb4fa0063,0x764b0006,0x3076005e,0x00000000}},	//   _הפני, žnyč, чунс,
  { {0x6dac0058,0x798916d4,0x0ef90085,0x00000000}},	//   rşam, _loew, жэты_,
  { {0x29dc02dd,0x7d1d16d5,0x661c00b9,0x00000000}},	//   dían_, _bess, _ærkt,
  { {0xb8830e28,0x91e3005a,0x7c240218,0x00000000}},	//   _klíč, _поще, tsir,
  { {0xe319008b,0x7d0416d6,0x7d1d16d7,0x00000000}},	// [1f60] _điể, rcis, _dess,
  { {0x29dc006d,0x7c2416d8,0xa01b0072,0x00000000}},	//   gían_, rsir, pyör,
  { {0xafdb0146,0x4efb0063,0xc3320063,0x00000000}},	//   ktøj, _להיו, תוב_,
  { {0xfbc90063,0x7d1d13f4,0x7d01013d,0x00000000}},	//   את_, _gess, _váró,
  { {0x29dc02dd,0x61e40139,0xafdb01e1,0x00000000}},	//   bían_, _mhil, dtøj,
  { {0x29dc02dd,0x60d600fe,0xc7a316d9,0x00000000}},	//   cían_, _myym, ничк,
  { {0x4426007a,0x4e7a00b5,0xdb1e16da,0x00000000}},	//   _svo_, מאַצ, ropä,
  { {0x798900ac,0x2abb0063,0x442616db,0x00000000}},	//   _goew, _המלא, _pvo_,
  { {0xa5070001,0x18a30121,0x86c6005d,0x00000000}},	//   чења_, _затм, _کيان,
  { {0xe44f0032,0x389b0063,0x6f1e007d,0x00000000}},	//   اضي_, _הימנ, _nepc,
  { {0x7dda006f,0xa91d005f,0x60c416dc,0x00000000}},	//   eïsm, _alžy, _axim,
  { {0x44260026,0x61e40f15,0x867b0063,0x00000000}},	//   _tvo_, _chil, _לרבו,
  { {0xa91d027c,0x7d1d16dd,0x6d980014,0x00000000}},	//   _božj, _ress, _pían,
  { {0x6447003b,0x7a050078,0x7d1d16de,0x00000000}},	//   ăjit, _lėta, _sess,
  { {0x7d1d16df,0x29dc02dd,0x61e40025,0x00000000}},	//   _pess, vían_, _fhil,
  { {0x61e4000c,0xbcfb1554,0x5d6416e0,0x00000000}},	//   _ghil, _gaél, нтуз,
  { {0x29dc006d,0x7d1d16e1,0x6ecd0053,0x00000000}},	// [1f70] tían_, _vess, _दुरु,
  { {0x7e6100b9,0x798916e2,0x7d1d16e3,0x00000000}},	//   ælps, _soew, _wess,
  { {0x29dc02dd,0x7d1d16e4,0xbb840021,0x00000000}},	//   rían_, _tess, علمي,
  { {0x29dc0046,0x6f1e0022,0xbcfb013d,0x00000000}},	//   sían_, _zepc, _lnéz,
  { {0xa3cc0082,0x00000000,0x00000000,0x00000000}},	//   लवा_,   ,   ,
  { {0x6d4d00ca,0x212216e5,0x2d8b0130,0x00000000}},	//   lfaa, zakh_, _hoce_,
  { {0x79890122,0x6b830026,0xc7c8000d,0x00000000}},	//   _toew, öngu, чыце_,
  { {0x6d4d06a7,0x24090076,0x75d50044,0x00000000}},	//   nfaa, онии_, بيعا,
  { {0x29000024,0xafdb00b9,0xa834005e,0x00000000}},	//   žiac_, rtøj, _петљ,
  { {0x9f530003,0x69d916e6,0xeb9f01e1,0x00000000}},	//   _fixé_, llwe, _støj_,
  { {0x672306bb,0x6f1e00c2,0x61e40136,0x00000000}},	//   manj, _repc, _phil,
  { {0xa5c6007a,0x672316e7,0x27ff0072,0x00000000}},	//   rkóð, lanj, _kuun_,
  { {0x291f00cd,0xa5c60026,0x21a30121,0x00000000}},	//   _meua_, skóð, тиям,
  { {0x61e40034,0x27ff00fe,0x98b20051,0x00000000}},	//   _whil, _muun_, żyć_,
  { {0x644916e8,0xa01b0050,0x00000000,0x00000000}},	//   ltei, syöp,   ,
  { {0xf2d211b4,0x6449001c,0x672316e9,0x00000000}},	//   _שעה_, otei, hanj,
  { {0x67231312,0xbfc606be,0xab66000d,0x00000000}},	// [1f80] kanj, _обик, мвал,
  { {0x672316ea,0x68fb16eb,0xd9b80053,0x00000000}},	//   janj, _agud, ेक्ट,
  { {0x236700c3,0x64490d9e,0x67230add,0x00000000}},	//   _manj_, htei, danj,
  { {0x3a3a10b9,0x2d8b0e06,0xdcfd0022,0x00000000}},	//   rupp_, _goce_, _posą,
  { {0x2603048e,0xdb0e007a,0xdcb90076,0x00000000}},	//   _año_, þjón, _ещё_,
  { {0x69d900e8,0x236700c3,0x31bb0053,0x00000000}},	//   alwe, _nanj_, _उद्ध,
  { {0xc34e0013,0x88bd0051,0x644916ec,0x00000000}},	//   _bổng_, _odśw, etei,
  { {0xc34e008b,0x6449004d,0x3e48004d,0x00000000}},	//   _cổng_, ftei, ißt_,
  { {0x672316ed,0x3f980014,0x6e3c0058,0x00000000}},	//   banj, kkru_, hurb,
  { {0x6723074f,0xdb050058,0x68fb003b,0x00000000}},	//   canj, rihç, _zgud,
  { {0x7d1600ac,0x644916ee,0xa29401dd,0x00000000}},	//   kbys, atei, хані,
  { {0x6e3c0026,0x6449004d,0x9293000d,0x00000000}},	//   durb, btei, таюц,
  { {0x14e20161,0x2d8b0080,0x64490268,0x00000000}},	//   _परिण, _roce_, ctei,
  { {0x61ee0024,0x6e3c00e5,0x7052005d,0x00000000}},	//   _ďale, furb, اچيا,
  { {0x518716ef,0x69d9002b,0xfbbf0042,0x00000000}},	//   _жупа, ylwe, ्वसम,
  { {0x6723074f,0x236700c2,0xa2ad0082,0x00000000}},	//   zanj, _zanj_, ुपर्,
  { {0x2d8b104f,0xf1bf14c0,0xb6010046,0x00000000}},	// [1f90] _voce_, mná_, _þáve,
  { {0x291f0268,0x7f5c0268,0x3f150062,0x00000000}},	//   _seua_, cerq, _ядос,
  { {0x672316f0,0x6449008f,0xf1bf00be,0x00000000}},	//   vanj, ztei, oná_,
  { {0x672305b3,0xead80054,0xf1bf16f1,0x00000000}},	//   wanj, ємці_, nná_,
  { {0x6723055e,0x6449017d,0xd8b800f2,0x00000000}},	//   tanj, xtei, ودها_,
  { {0xf7710032,0xa3dd0053,0xe8f816f2,0x00000000}},	//   طات_, _थीं_, флі_,
  { {0xe9190086,0x291f00cd,0x672316f3,0x00000000}},	//   _нові_, _teua_, ranj,
  { {0x672316f4,0x644916f5,0xf1bf0114,0x00000000}},	//   sanj, ttei, jná_,
  { {0xf1bf0114,0x644916f6,0xe4560085,0x00000000}},	//   dná_, utei, ежы_,
  { {0x43740086,0x644916f7,0x656916f8,0x00000000}},	//   вуют, rtei, sdeh,
  { {0xc34e001b,0xb345017d,0x236700c2,0x00000000}},	//   _tổng_, _acçã, _vanj_,
  { {0x0efa0394,0x644916f9,0xa91d07b4,0x00000000}},	//   ्ड्स_, ptei, _boži,
  { {0x25bf000c,0x66010019,0x4395000d,0x00000000}},	//   mnul_, _hulk, _падс,
  { {0x2d8f0c38,0x660116fa,0xb4640636,0x00000000}},	//   ögen_, _kulk, _шкіл,
  { {0x6601024a,0xf1bf0240,0x25bf003b,0x00000000}},	//   _julk, bná_, onul_,
  { {0xf1bf0114,0xdb0e0b6c,0xac0a0002,0x00000000}},	//   cná_, _imbé, знаа_,
  { {0x45da00b5,0x81bd001c,0xdca316fb,0x00000000}},	// [1fa0] פֿלא, ksēj, гати,
  { {0x7d160185,0xa3c10053,0x6721065c,0x00000000}},	//   sbys, ्कि_, _nelj,
  { {0xdb1c0051,0xa91d00c2,0x25bf004c,0x00000000}},	//   _skró, _zoži, knul_,
  { {0x08c6000a,0xb8660021,0x6da60086,0x00000000}},	//   нбен, فاتو, _чима,
  { {0x672100b2,0xa3c10053,0x69c30003,0x00000000}},	//   _belj, ्का_, énea,
  { {0xd7ef0032,0xe66600d7,0x672100c2,0x00000000}},	//   مكن_, етио, _celj,
  { {0x6721082a,0xdb1c0051,0xfbc30076,0x00000000}},	//   _delj, _wkró, _сбро,
  { {0x25bf003b,0xa96716fc,0x660116fd,0x00000000}},	//   gnul_, _писа_, _dulk,
  { {0xe73a000a,0x9f4a00cd,0xf1bf027d,0x00000000}},	//   _неа_, ambé_, vná_,
  { {0x25bf003b,0x42740086,0xa91d16fe,0x00000000}},	//   anul_, вгос, _roži,
  { {0x3636007e,0xf1bf0a63,0xa91d00a8,0x00000000}},	//   _سراس, tná_, _soži,
  { {0xa91d16ff,0x67210b59,0xf484005d,0x00000000}},	//   _poži, _zelj, _لاتی,
  { {0x557700b5,0x66011700,0x4fc70062,0x00000000}},	//   _רעדן_, _zulk, есва,
  { {0xf1bf004a,0xe47b00ff,0x54970085,0x00000000}},	//   sná_, _מרדכ, _явіў_,
  { {0xade70062,0xf1bf16f1,0x7d090044,0x00000000}},	//   ецак, pná_, ِيرِ_,
  { {0xcdd80001,0xa91d00c2,0xdce60058,0x00000000}},	//   ењу_, _toži, _alkı,
  { {0x41c4013a,0x00000000,0x00000000,0x00000000}},	// [1fb0] _حقيق,   ,   ,
  { {0x09c90082,0xd9c90082,0xf411009d,0x00000000}},	//   िक्य, िक्ट, ׁ֤ב_,
  { {0x7cea013d,0x67211701,0x29120058,0x00000000}},	//   töré, _relj, ıyan_,
  { {0xd2b70063,0xc9841702,0xdd160066,0x00000000}},	//   עלאת_, лучи, _päťd,
  { {0x66011703,0x09040086,0x395d00e5,0x00000000}},	//   _sulk, упін, rews_,
  { {0xd7f8005e,0xb17b0137,0x66011704,0x00000000}},	//   нуј_, llåd, _pulk,
  { {0xbbbf0161,0x3666005a,0x19ab1705,0x00000000}},	//   ्वीक, ващо_, _етап_,
  { {0x25bf003b,0xdcfd0022,0x66011706,0x00000000}},	//   unul_, _posę, _vulk,
  { {0x9f530994,0x25bf000c,0x67211707,0x00000000}},	//   _així_, rnul_, _telj,
  { {0xe2990001,0x25bf1708,0x66011709,0x00000000}},	//   дао_, snul_, _tulk,
  { {0xb2f40076,0xb4e200cd,0x5282000d,0x00000000}},	//   ляющ, çàri, агэб,
  { {0x7afa0026,0x6dac003b,0x2d8f004d,0x00000000}},	//   _útte, nşat, ögel_,
  { {0x2ca9007d,0xd4690131,0xd00f0044,0x00000000}},	//   jzad_, _циле_, يلَ_,
  { {0x656b018d,0xf70e0013,0xdb1e0058,0x00000000}},	//   _hagh, hủng_, üyüy,
  { {0x443f0f3f,0xb17b01e1,0x7e23007b,0x00000000}},	//   luu_, flåd, идрж,
  { {0x3f850026,0xfce6170a,0x91fc008f,0x00000000}},	//   ölur_, вобо, rvāt,
  { {0x656b170b,0x443f0729,0x6f02003b,0x00000000}},	// [1fc0] _magh, nuu_, _şocu,
  { {0xb17b0031,0x91fc001c,0x656b170c,0x00000000}},	//   småt, mvār, _lagh,
  { {0x6a86011c,0x628700fe,0x2ca9007d,0x00000000}},	//   ължа, äjoh, azad_,
  { {0x656b00bb,0x64590186,0xafdb00b9,0x00000000}},	//   _nagh, _opwi, ruøe,
  { {0x91fc001c,0x443f170d,0x68430121,0x00000000}},	//   nvār, juu_, инца,
  { {0x244b01e1,0xeb9f05a5,0x6d44170e,0x00000000}},	//   døm_, _støv_, lgia,
  { {0xacbb0003,0x6d44004b,0x656b170f,0x00000000}},	//   _jeûn, ogia, _bagh,
  { {0x7ae300ea,0x6d441710,0xd5b70766,0x00000000}},	//   ünte, ngia, ксы_,
  { {0x91fc001c,0xa766005e,0x80e10042,0x00000000}},	//   jvār, _икад, _नरें,
  { {0x96b6005e,0x00000000,0x00000000,0x00000000}},	//   _исељ,   ,   ,
  { {0x3263005a,0xc7d70063,0xbb3b0063,0x00000000}},	//   атяв, _יומי_, ועיי,
  { {0x69c2001f,0xc05b0054,0x00000000,0x00000000}},	//   nnoe, міг_,   ,
  { {0x91fc003d,0x20840021,0x64a3014a,0x00000000}},	//   gvār, للَّ, _каца,
  { {0x64401711,0x4fc40a91,0x6d441712,0x00000000}},	//   mumi, асса, egia,
  { {0x75e5000f,0x7c3a001c,0xa3c10053,0x00000000}},	//   lóza, _ātra, ्कर_,
  { {0x6d4402f6,0x64400003,0x65601713,0x00000000}},	//   ggia, oumi, nemh,
  { {0x64401714,0x69c202f7,0x5c7505ac,0x00000000}},	// [1fd0] numi, dnoe, ылат,
  { {0x6d4400f3,0x765a0045,0x5b140086,0x00000000}},	//   agia, _opty, имут,
  { {0x63af00cd,0x5a350699,0x64401715,0x00000000}},	//   ècni, унет, humi,
  { {0x64401716,0x09d4000d,0x69c2002b,0x00000000}},	//   kumi, аціў, gnoe,
  { {0x6440003d,0x28f80086,0x7d0d1717,0x00000000}},	//   jumi, вець_, mcas,
  { {0x656b0025,0xb605016b,0x60da0047,0x00000000}},	//   _sagh, hláš, ײַנג,
  { {0x656b0273,0xc6a7005a,0x45d505fb,0x00000000}},	//   _pagh, ърди, лцит,
  { {0x4efc014e,0x443f00fe,0xa91d007d,0x00000000}},	//   ולוג, tuu_, _požu,
  { {0x656b0290,0x64401718,0x7c2d1719,0x00000000}},	//   _vagh, gumi, nsar,
  { {0xa774000a,0x8c1a0063,0x244b01f2,0x00000000}},	//   _клуч, עותי, røm_,
  { {0x6d44171a,0xb6070062,0x656b0f20,0x00000000}},	//   ygia, _рязк, _tagh,
  { {0xa1360021,0x443f021e,0x7c2d171b,0x00000000}},	//   دردش, puu_, ksar,
  { {0x7c2d00c7,0xad9b017d,0x645c003b,0x00000000}},	//   jsar, _miúd, ăric,
  { {0xafdb00d1,0x442d171c,0xe46a0014,0x00000000}},	//   dtøs, mse_, sröð_,
  { {0x442d171d,0x7c2d171e,0xed5a0811,0x00000000}},	//   lse_, esar, нов_,
  { {0x442d0498,0x69c300ea,0x6d440078,0x00000000}},	//   ose_, énel, ugia,
  { {0x6d44171f,0x442d1720,0x7c2d1721,0x00000000}},	// [1fe0] rgia, nse_, gsar,
  { {0x442d1722,0x6d440322,0x2bba0021,0x00000000}},	//   ise_, sgia, راءة_,
  { {0xb17b0146,0x8ad50088,0x442d0375,0x00000000}},	//   slåe, аюцц, hse_,
  { {0x442d1723,0xafdb0031,0xeb9f069f,0x00000000}},	//   kse_, støt, _støt_,
  { {0x69c20162,0x442d1724,0x64e20053,0x00000000}},	//   rnoe, jse_, _परेश,
  { {0x38cb006a,0x6440001c,0x69c20104,0x00000000}},	//   رانی_, vumi, snoe,
  { {0x4994007e,0x442d015e,0x7f3b0047,0x00000000}},	//   _پیشر, ese_, געצו,
  { {0x64401725,0xad9b0025,0x442d1726,0x00000000}},	//   tumi, _giúd, fse_,
  { {0xd3260928,0xb9930021,0x48e3065b,0x00000000}},	//   льни, _القب, _готв,
  { {0x64401727,0x53340856,0x39461728,0x00000000}},	//   rumi, јент, lgos_,
  { {0x66e60076,0x442d1729,0x7c2d001c,0x00000000}},	//   _сожа, ase_, zsar,
  { {0x3946172a,0x7c2d172b,0x6440172c,0x00000000}},	//   ngos_, ysar, pumi,
  { {0xc5f3014e,0x39460006,0x88bd0051,0x00000000}},	//   _הדף_, igos_, _leśn,
  { {0xa91d172d,0x7d0d172e,0x1fa7005e,0x00000000}},	//   _inže, wcas, урмг,
  { {0x7d0d00e5,0x7c2d0c5f,0x99780078,0x00000000}},	//   tcas, wsar, nčų_,
  { {0x7c870086,0x27ec0089,0x63ba172f,0x00000000}},	//   лузе, _lhdn_, litn,
  { {0x69c30164,0xdfd10021,0x200400cd,0x00000000}},	// [1ff0] énem, _ويب_, ímit_,
  { {0x3946006d,0x7c2d1730,0x212b1731,0x00000000}},	//   egos_, rsar, lach_,
  { {0x7c2d1732,0x61ed13dc,0x442d0779,0x00000000}},	//   ssar, _khal, zse_,
  { {0x212b1733,0x32350047,0x7c2d1734,0x00000000}},	//   nach_, שטײן_, psar,
  { {0x3949003d,0x63ba1735,0x61ed0025,0x00000000}},	//   ļas_, kitn, _mhal,
  { {0x212b0027,0x442d0019,0xb6590cb5,0x00000000}},	//   hach_, vse_, вших_,
  { {0x69ca0003,0x16a61736,0x212b1737,0x00000000}},	//   éfec, ивши_, kach_,
  { {0x212b0051,0x629a1738,0x442d1739,0x00000000}},	//   jach_, dyto, tse_,
  { {0x212b173a,0x442d04bc,0x291d0035,0x00000000}},	//   dach_, use_, mbwa_,
  { {0x442d173b,0x92f50086,0x63ba173c,0x00000000}},	//   rse_, ичні, gitn,
  { {0x61ed0025,0x442d173d,0xa2e5173e,0x00000000}},	//   _bhal, sse_, ронд,
  { {0x61ed031d,0x7643017e,0x63ba0139,0x00000000}},	//   _chal, muny, aitn,
  { {0xd83e034d,0x7643173f,0xc5f20063,0x00000000}},	//   _účte_, luny, _ודא_,
  { {0x3946006d,0x629a1740,0x63ba04a8,0x00000000}},	//   zgos_, byto, citn,
  { {0xc7b20063,0x39460006,0x7db60d64,0x00000000}},	//   קבל_, ygos_, асац,
  { {0x3d200161,0x7bc50016,0x4ad90053,0x00000000}},	//   बरें_, enhu, _बुधव,

  { {0x8b260076,0xac071741,0xafdb069f,0x00000000}},	// [2000] идае, инта_, rtør,
  { {0xafdb07e6,0x76431742,0x109b0063,0x00000000}},	//   stør, kuny, _סביב,
  { {0x32070268,0x7f3b0063,0x7dda00cd,0x00000000}},	//   _juny_, _בעיו, uïss,
  { {0x394600eb,0x26de0078,0x8c461743,0x00000000}},	//   ugos_, _ryto_, _кеме,
  { {0x394612d1,0x8eb3007e,0x629a0051,0x00000000}},	//   rgos_, _همیش, zyto,
  { {0x81bd003d,0x39461143,0x57b30086,0x00000000}},	//   lsēt, sgos_, обіт,
  { {0xd7190086,0x212b002b,0x76431744,0x00000000}},	//   уючі_, yach_, guny,
  { {0xe5c60259,0x0d960063,0x81bd008f,0x00000000}},	//   јско, יכֶם_, nsēt,
  { {0x88bd0045,0x2fd800c7,0xf746005e,0x00000000}},	//   _jeśl, korg_, _везо,
  { {0x61ed1745,0x26de0080,0x212b0051,0x00000000}},	//   _shal, _tyto_, wach_,
  { {0x81bd001c,0x63ba1746,0x212b1747,0x00000000}},	//   ksēt, ritn, tach_,
  { {0x29dc006d,0x629a1748,0x3d200053,0x00000000}},	//   mías_, ryto, बरों_,
  { {0x29dc006d,0x67280137,0x7bdc1749,0x00000000}},	//   lías_, _kedj, _okru,
  { {0x644f0994,0x61ed174a,0xd83f0114,0x00000000}},	//   àcie, _whal, _účet_,
  { {0x29dc02dd,0x6728074f,0x212b174b,0x00000000}},	//   nías_, _medj, pach_,
  { {0xdce6001c,0x02fb0149,0xaada0042,0x00000000}},	//   _sakā, _בלומ, _भड़क,
  { {0xdce6001c,0x1df80121,0x50b8007e,0x00000000}},	// [2010] _pakā, реты_, _پديد_,
  { {0x69db05dd,0x76430089,0x67281186,0x00000000}},	//   _skue, yuny, _nedj,
  { {0x7ff400b3,0x29dc0331,0x6ff40044,0x00000000}},	//   _بسيا, jías_, _بسيط,
  { {0x29dc006d,0x785a0023,0x6a14014b,0x00000000}},	//   días_, kāvā, імчу,
  { {0x68e00185,0x75c8004c,0xf84b0121,0x00000000}},	//   _cymd, tězn, тчей_,
  { {0x785a003d,0x29dc02dd,0x7643003e,0x00000000}},	//   dāvā, fías_, tuny,
  { {0x29dc02dd,0xf7700242,0x68e00046,0x00000000}},	//   gías_, بان_, _eymd,
  { {0x9f960026,0x2fd8006f,0x645c003b,0x00000000}},	//   hæð_, zorg_, ărin,
  { {0x68e0001f,0x69d90051,0x24520021,0x00000000}},	//   _gymd, mowe, كنيس,
  { {0x29dc048e,0x7643053b,0x69d90886,0x00000000}},	//   bías_, puny, lowe,
  { {0x29dc02dd,0xd575000d,0x6b9503c7,0x00000000}},	//   cías_, _гуль, _mozg,
  { {0x69d90051,0xdcfd005f,0x13a7005d,0x00000000}},	//   nowe, _ansč, انگی_,
  { {0xd24e006a,0x20090089,0x2fd80026,0x00000000}},	//   ونی_, _cuai_, torg_,
  { {0x443f0c70,0x386d002b,0x40950054,0x00000000}},	//   mru_, _mser_, ірят,
  { {0x69d90051,0xafdb00d1,0x236502f7,0x00000000}},	//   kowe, frøb, melj_,
  { {0xdced034d,0x29000006,0x69d90051,0x00000000}},	//   adač, žiai_, jowe,
  { {0x2009174c,0xc5f20047,0x69d9174d,0x00000000}},	// [2020] _guai_, לדל_, dowe,
  { {0x68e000c7,0x443f174e,0x3f9e004b,0x00000000}},	//   _rymd, iru_, ötud_,
  { {0x49060032,0x443f174f,0x6728130e,0x00000000}},	//   مواق, hru_, _redj,
  { {0x7053006a,0x5d860021,0x29dc006d,0x00000000}},	//   _بنیا, _الحل, vías_,
  { {0xa85600d7,0x783a0259,0x236500c2,0x00000000}},	//   стеј, уџет_, kelj_,
  { {0x29dc006d,0x0f7a0047,0x3f7a0041,0x00000000}},	//   tías_, ראַב, ראַס,
  { {0x9f52006d,0x386d092a,0x69d90ac3,0x00000000}},	//   _huyó_, _eser_, bowe,
  { {0x29dc02dd,0x76a90086,0x2904002c,0x00000000}},	//   rías_, штів_, _ugma_,
  { {0x29dc0118,0x443f1750,0x7a050078,0x00000000}},	//   sías_, gru_, _dėtu,
  { {0x29dc006d,0x21290089,0xa3b40054,0x00000000}},	//   pías_, _seah_, ібні,
  { {0x22580076,0x20090089,0x443f1751,0x00000000}},	//   шины_, _suai_, aru_,
  { {0x443f1752,0x2001004b,0x60f9012c,0x00000000}},	//   bru_, _sihi_, иння_,
  { {0x443f0529,0x236500c2,0x20091753,0x00000000}},	//   cru_, belj_, _quai_,
  { {0x33f60fe2,0x4fc70076,0x69d90051,0x00000000}},	//   _учес, ссма, zowe,
  { {0x69d90035,0x6b950051,0xee84007f,0x00000000}},	//   yowe, _rozg, пыто,
  { {0xd131006a,0x64401754,0xbd191755,0x00000000}},	//   _کمک_, ormi, ржах_,
  { {0xd011007e,0x7c870002,0xdd9405ac,0x00000000}},	// [2030] _تلخ_, љубе, чаты,
  { {0x6ac40161,0x69d90051,0x69ca0003,0x00000000}},	//   वपूर, wowe, éfen,
  { {0x69d91756,0xdd95000d,0x6440004d,0x00000000}},	//   towe, _даны, hrmi,
  { {0x8819000d,0x195902dc,0x443f1757,0x00000000}},	//   аўку_, рады_, yru_,
  { {0xf09f0268,0x684501dd,0xdd310022,0x00000000}},	//   nyà_, інка, _mężo,
  { {0x645c0529,0x69d91758,0x443f1759,0x00000000}},	//   ăril, sowe, vru_,
  { {0x8698005a,0x69d9175a,0x753d013d,0x00000000}},	//   йтът_, powe, ószo,
  { {0x443f175b,0x84591133,0xe6280021,0x00000000}},	//   tru_, арот_, حثون_,
  { {0x236506bb,0x386d0465,0xc7c8008b,0x00000000}},	//   telj_, _user_, uốc_,
  { {0x443f175c,0xdb0e0014,0x9f5a01a8,0x00000000}},	//   rru_, _embæ, _pipí_,
  { {0x6d5d0512,0x0166015a,0x6440175d,0x00000000}},	//   _obsa, окно, armi,
  { {0x7d020078,0x236500c2,0xf1bf175e,0x00000000}},	//   žosi, selj_, giá_,
  { {0x25bf003b,0xb17b0137,0x236500a8,0x00000000}},	//   miul_, plån, pelj_,
  { {0x6d4f175f,0x25bf000c,0x6d5d0832,0x00000000}},	//   _acca, liul_, _absa,
  { {0x1d0a0854,0x249f0058,0x44260244,0x00000000}},	//   иеви_, lyum_, _zwo_,
  { {0x25bf0529,0x0c2600d7,0xf1bf017d,0x00000000}},	//   niul_, жман, ciá_,
  { {0x249f1760,0x752b013d,0xfce311fd,0x00000000}},	// [2040] nyum_, _megz, дото,
  { {0x3dc900a4,0x25bf003b,0x248d00cd,0x00000000}},	//   anaw_, hiul_, ixem_,
  { {0xed5a0079,0x3dc900a4,0x75390022,0x00000000}},	//   _кон_, bnaw_, _odwz,
  { {0xe9da1321,0xad5a000d,0xba17005d,0x00000000}},	//   шке_, _трох_, زيها_,
  { {0x25bf000c,0x999c00ea,0x515b009d,0x00000000}},	//   diul_, évő_, שכנו,
  { {0x907b0063,0x207b0047,0x3869017d,0x00000000}},	//   יטני, יאנא, çara_,
  { {0x645c003b,0x61e60023,0xbcfb009c,0x00000000}},	//   ărim, klkl, _ebéd,
  { {0xdb07007a,0x25bf003b,0x7e9b0047,0x00000000}},	//   ámör, giul_, יסצו,
  { {0xf1bf017d,0x938a0789,0xa73a005d,0x00000000}},	//   viá_, асна_, _نثار_,
  { {0x7c29005b,0x25ad004b,0x442600ca,0x00000000}},	//   _çere, ahel_, _vwo_,
  { {0x25bf1761,0xcb130063,0x66100022,0x00000000}},	//   biul_, ולת_, ójką,
  { {0x44260034,0xb606017f,0x25bf000c,0x00000000}},	//   _two_, rišć, ciul_,
  { {0xf1bf0024,0xcf9b0092,0x8f0b0094,0x00000000}},	//   riá_, ајв_, ихва_,
  { {0x4374006a,0x4ea70899,0x33730054,0x00000000}},	//   _رهبر, орба, _огір,
  { {0x3ea500ea,0xd13b0085,0x98ad056c,0x00000000}},	//   ált_, _кхп_, _ideą_,
  { {0x321e0783,0x3dc9002b,0xdb0d009c,0x00000000}},	//   mpty_, unaw_, űkül,
  { {0x030e0053,0xc19c0063,0xf19c009a,0x00000000}},	// [2050] _सलाह_, _כשהי, _כשהש,
  { {0x673a00b9,0xda7b0062,0xee87007f,0x00000000}},	//   _ndtj, ияе_, _дымо,
  { {0xf0b8007e,0x9ff80044,0x00000000,0x00000000}},	//   _هایش_, _بريء_,   ,
  { {0x2ca01762,0x7aed008f,0x00000000,0x00000000}},	//   byid_, _ģitā,   ,
  { {0xb17c0047,0x98f4000d,0xdcef0006,0x00000000}},	//   יטאר, мяшч, _įdėk,
  { {0x6cfa0063,0x7b640fec,0x6d4d0d46,0x00000000}},	//   _לפרס, _отсе, lgaa,
  { {0x67ed00ea,0x2d991763,0x25ad1764,0x00000000}},	//   gúja, _kose_, thel_,
  { {0x6d4d1765,0x2d9908cd,0x391515ce,0x00000000}},	//   ngaa, _jose_, _хмар,
  { {0x25bf000c,0xd877007e,0x69cb0137,0x00000000}},	//   riul_, _بازب, mnge,
  { {0x2d990780,0x752b030c,0x249f1766,0x00000000}},	//   _lose_, _wegz, ryum_,
  { {0x69cb1767,0x95cb0cb5,0x25bf003b,0x00000000}},	//   onge, _куда_, piul_,
  { {0x2d9903bd,0xa06a005e,0x6d4d00ca,0x00000000}},	//   _nose_, бама_, jgaa,
  { {0x69cb1768,0x26110013,0x920b0042,0x00000000}},	//   inge, _háo_, _सूरज_,
  { {0x7bcb0003,0x69cb004d,0xa4fa0063,0x00000000}},	//   égul, hnge, _פלסט,
  { {0x6d4d0162,0x64491769,0x395f0003,0x00000000}},	//   fgaa, luei, _obus_,
  { {0x2d99051e,0x6d4d176a,0x395f00ac,0x00000000}},	//   _cose_, ggaa, _nbus_,
  { {0x644900cd,0x26110013,0x2d99176b,0x00000000}},	// [2060] nuei, _láo_, _dose_,
  { {0x6d4d1761,0x69cb1742,0x2d8f01bb,0x00000000}},	//   agaa, enge, öger_,
  { {0x2ca00397,0x4f9b0063,0xbf9b0063,0x00000000}},	//   syid_, _הביצ, _הייש,
  { {0x5f46005d,0xd23a0041,0xb5f90085,0x00000000}},	//   _بنگل, מגעל, _кнiг,
  { {0x3f9a001c,0x7643176c,0x98a30071,0x00000000}},	//   _kopu_, erny, нице,
  { {0x2611001b,0x64490268,0xdb1e00cd,0x00000000}},	//   _báo_, duei, xipè,
  { {0x261100aa,0xe5c60062,0xdbc7021e,0x00000000}},	//   _cáo_, зспо, töös,
  { {0x69c300ea,0x94180121,0x3f9a0050,0x00000000}},	//   énet, ожит_, _lopu_,
  { {0xdce40006,0x6449176d,0x27f10078,0x00000000}},	//   keič, guei, _šonų_,
  { {0x673a00b9,0xdc9b0047,0xdbc70072,0x00000000}},	//   _udtj, צייל, söös,
  { {0xe4d6007e,0xf7730063,0x65870014,0x00000000}},	//   _کتاب, _רקע_, érhæ,
  { {0x92570076,0x64490268,0xafdb000e,0x00000000}},	//   чают_, buei, grøn,
  { {0x644903b2,0x7bde00fe,0xad9b0025,0x00000000}},	//   cuei, kopu, _diúl,
  { {0x22590051,0x7c3600ac,0x6f150022,0x00000000}},	//   ńska_, dsyr, uczc,
  { {0xdb1e0027,0x6d4d166f,0x3da7000d,0x00000000}},	//   cipé, tgaa, праб,
  { {0x91e40001,0x91720013,0xdd170082,0x00000000}},	//   _поје, rợ_, धुंध_,
  { {0x6d4d176e,0x113c0063,0x69c2176f,0x00000000}},	// [2070] rgaa, _התחל, dioe,
  { {0x7bde1770,0x6d4d1771,0x2bbb0044,0x00000000}},	//   gopu, sgaa, حارة_,
  { {0x2cbf0066,0x6d4d00ca,0xcb080044,0x00000000}},	//   _ľudu_, pgaa, أيمن_,
  { {0x69cb1772,0xdb1e00fe,0x69c2006f,0x00000000}},	//   unge, enpä, gioe,
  { {0xe72e0054,0x26110013,0x320e0022,0x00000000}},	//   ке_, _sáo_, _lufy_,
  { {0xdb23007e,0x69da017d,0x7bde11ad,0x00000000}},	//   _سوری, _íten, copu,
  { {0xe9190054,0xe73001fb,0x7d0200a8,0x00000000}},	//   _мові_, اصه_, žost,
  { {0x64491773,0x69c21774,0x49b8014d,0x00000000}},	//   tuei, cioe, _فاقد_,
  { {0x29000066,0xa3b90044,0x87070044,0x00000000}},	//   žiar_, قادر_, _فبال,
  { {0xe2a2001b,0x799b04a1,0x26110013,0x00000000}},	//   _thử_, _houw, _táo_,
  { {0xf6550002,0x6dac0058,0xd6270049,0x00000000}},	//   _цвеќ, aşay, _رعاي,
  { {0x799b00f5,0xdb1e1775,0xf8a70044,0x00000000}},	//   _jouw, ripé, نة_,
  { {0x644913a3,0x29360047,0x7bde0035,0x00000000}},	//   quei, וארן_, yopu,
  { {0xa7fd013d,0x03950085,0xb4fa009a,0x00000000}},	//   _zsűr, _ірля, _ופני,
  { {0x5de6000d,0x0ef9000d,0xdce40078,0x00000000}},	//   джва, зэты_, reič,
  { {0x69bf0053,0x7c360046,0xcd36005d,0x00000000}},	//   लोमी, tsyr, برآب,
  { {0xa5c60026,0x61e41776,0x7bde1777,0x00000000}},	// [2080] ljóð, _ikil, topu,
  { {0x78a20035,0xafdb00d1,0x7c361778,0x00000000}},	//   vyov, ktøy, rsyr,
  { {0x799b0122,0x7bde1779,0x7c3a001c,0x00000000}},	//   _bouw, ropu, _ātru,
  { {0x08c60cf7,0x986c017c,0xfbc90aeb,0x00000000}},	//   мбен, _vôľa_, בת_,
  { {0x644f00cd,0x7bde177a,0x69c2002b,0x00000000}},	//   àcil, popu, rioe,
  { {0x7a0c0529,0x69c2177b,0x69c311fa,0x00000000}},	//   _aşte, sioe, éner,
  { {0x6b9c177c,0x69c200ca,0x66e301ce,0x00000000}},	//   _iorg, pioe, коља,
  { {0x799b006f,0x7989002b,0x6b9c013d,0x00000000}},	//   _gouw, _gnew, _horg,
  { {0x4c9b00b5,0x236a00d7,0x69c0177d,0x00000000}},	//   ַשטע, ојно_, _imme,
  { {0x6b9c177e,0x889b0063,0x61e4101f,0x00000000}},	//   _jorg, _ובמי, _akil,
  { {0xbcfb0025,0x6b9c050b,0x316b0051,0x00000000}},	//   _mbéa, _morg, tecz_,
  { {0x6b9c177f,0x61f61780,0xc693009a,0x00000000}},	//   _lorg, _chyl, _שאף_,
  { {0x6b9c0250,0xdb1c013d,0x9554005d,0x00000000}},	//   _oorg, _emré, _يخچا,
  { {0xe4c7007e,0x6b9c1781,0x61e40058,0x00000000}},	//   _تصمی, _norg, _ekil,
  { {0x2fc300ca,0x69c01782,0xa3cb0042,0x00000000}},	//   rijg_, _omme, रचर_,
  { {0xc5f8008f,0x31c4000d,0x00000000,0x00000000}},	//   _spēj_, _асьв,   ,
  { {0x6b9c1783,0x799b00ca,0xfc300044,0x00000000}},	// [2090] _borg, _rouw, لحل_,
  { {0x69c01784,0x21f20024,0xf092009a,0x00000000}},	//   _amme, máha_, _עני_,
  { {0xafdb00d1,0x61e40046,0x656201d1,0x00000000}},	//   nrøm, _ykil, _oboh,
  { {0x49b8007e,0x6b9c1785,0x6d4b0139,0x00000000}},	//   واند_, _eorg, ógad,
  { {0x6b9c0d11,0x799b00ca,0x2d8b1786,0x00000000}},	//   _forg, _vouw, _ince_,
  { {0xdce401f7,0xafdb00d1,0x7989001f,0x00000000}},	//   ldiğ, ttøy, _wnew,
  { {0x4ae40088,0x799b006f,0xdcfd0078,0x00000000}},	//   _аўта, _touw, _posė,
  { {0x6b9c1787,0xdce4005b,0xafdb01f2,0x00000000}},	//   _zorg, ndiğ, rtøy,
  { {0x44391788,0xeb9f00d1,0x6b9c0b42,0x00000000}},	//   és_, _støy_, _yorg,
  { {0x61e41789,0xafdb04aa,0x56670044,0x00000000}},	//   _skil, ptøy, _يداف,
  { {0x2d8b0037,0x98a4000c,0xd7940062,0x00000000}},	//   _once_, _temă_, _шифъ,
  { {0xa91d0078,0x22590051,0xe29a0013,0x00000000}},	//   _požy, ńsko_, _ngưu_,
  { {0x54a70044,0x2256005d,0x001a014b,0x00000000}},	//   _تحاف, ولید_, яўны_,
  { {0xdff50085,0x65620445,0xdce40075,0x00000000}},	//   вясь, _zboh, ediğ,
  { {0x645b178a,0x61f6178b,0x00000000,0x00000000}},	//   ltui, _thyl,   ,
  { {0x64460078,0x6b9c178c,0x657b178d,0x00000000}},	//   škie, _sorg, nduh,
  { {0x8b26000d,0xf390008b,0x6b9c178e,0x00000000}},	// [20a0] едзе, _mảnh_, _porg,
  { {0xda660021,0x69c30003,0x6abd0053,0x00000000}},	//   فاصي, ènen, ्पूर,
  { {0x6b9c0199,0x645b0ff2,0xfe72007e,0x00000000}},	//   _vorg, htui, _صدد_,
  { {0x645b178f,0xed5f0066,0x6b9c00a3,0x00000000}},	//   ktui, ížte_, _worg,
  { {0x645b006f,0x69da0857,0xd7e602fe,0x00000000}},	//   jtui, _ítem, ніко,
  { {0x7c241790,0x6b9c05e7,0x00000000,0x00000000}},	//   mpir, _uorg,   ,
  { {0x61fd007a,0x7c24104e,0x645b006f,0x00000000}},	//   ymsl, lpir, etui,
  { {0xf390001b,0x645b00ac,0xd5b71791,0x00000000}},	//   _cảnh_, ftui, есь_,
  { {0x7c2400a4,0xdce6001c,0x645b0983,0x00000000}},	//   npir, _nokļ, gtui,
  { {0xafdb06a5,0xdce40058,0xb8e60042,0x00000000}},	//   trøm, zdiğ, ॉप_,
  { {0xf8bf0ac6,0x6283017f,0x645b0466,0x00000000}},	//   _þér_, _crno, atui,
  { {0x645b00e8,0x6562004c,0x00000000,0x00000000}},	//   btui, _uboh,   ,
  { {0x53a6000d,0xdce40058,0xc0ab0044,0x00000000}},	//   _падб, vdiğ, ساحل_,
  { {0x7c2400c3,0x32940021,0x44f3000d,0x00000000}},	//   dpir, _للتأ, _спіс,
  { {0x777a0013,0x7bc51792,0x7c24008f,0x00000000}},	//   _matx, vihu, epir,
  { {0xa0c500de,0xbdf800de,0xf1bb009d,0x00000000}},	//   _ليعو, فرقا_, _מֶ֖ל,
  { {0xdce401f7,0xd164005a,0x7bc51793,0x00000000}},	// [20b0] rdiğ, _същи, tihu,
  { {0x657b1794,0xe1ff1795,0xa91d1796,0x00000000}},	//   zduh, lmó_, _inži,
  { {0xc3330063,0xdcef003b,0x7bc51797,0x00000000}},	//   רוע_, _bacă, rihu,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xed600080,0x777a00cd,0xf3900013,0x00000000}},	//   ížet_, _batx, _rảnh_,
  { {0x98a20a83,0x307c0149,0x7c2f002b,0x00000000}},	//   рише, פאונ, _iwcr,
  { {0xd9150088,0xafdb01e1,0x68e90022,0x00000000}},	//   _адбы, trøj, _wyed,
  { {0x645b1798,0xd6ce0021,0xdb1e00dd,0x00000000}},	//   ttui, تقى_, cipâ,
  { {0x75c80080,0x645b0072,0xa5f6005e,0x00000000}},	//   vězt, utui, њењу_,
  { {0x645b1799,0x43740054,0xd2a9030b,0x00000000}},	//   rtui, гуют, дкое_,
  { {0x645b179a,0xafdb01e1,0x3f9e0014,0x00000000}},	//   stui, prøj, ötum_,
  { {0xb6d80047,0x645b003b,0xcec4004c,0x00000000}},	//   _אַױט, ptui, hoří_,
  { {0x98a40006,0x7529179b,0x7c24179c,0x00000000}},	//   _temą_, mbez, xpir,
  { {0x64490ea7,0x645c003b,0x03a20141,0x00000000}},	//   mrei, ărit, _вишо,
  { {0x6449179d,0xd0070cb5,0x9f5300cd,0x00000000}},	//   lrei, тере_, _aixó_,
  { {0x661c000f,0xb6020026,0x7529050c,0x00000000}},	//   _érke, _þátt, nbez,
  { {0x973c017f,0x6449179e,0x4d630002,0x00000000}},	// [20c0] _hoće, nrei, јкув,
  { {0x4b230086,0x7c24179f,0x442f002b,0x00000000}},	//   имув, rpir, _mwg_,
  { {0x2d9e0164,0x3bd50076,0x644917a0,0x00000000}},	//   êtes_, уютс, hrei,
  { {0x644917a1,0x7c2412be,0xd94602d8,0x00000000}},	//   krei, ppir, теди,
  { {0x38cb007e,0x777a01a8,0x5cf50085,0x00000000}},	//   واهی_, _patx, _бяру,
  { {0xb17b01e3,0x644917a2,0x752917a3,0x00000000}},	//   llåt, drei, ebez,
  { {0x16370021,0xad9b0025,0x7bcb0003,0x00000000}},	//   نسية_, _siúi, ègue,
  { {0x5574026b,0xfa770063,0xadf80053,0x00000000}},	//   угит, _בעלת_, ंगटन_,
  { {0x4806000d,0xc7c8008b,0x644917a4,0x00000000}},	//   _апав, hối_, grei,
  { {0xafdb00b9,0x75c80080,0x752917a5,0x00000000}},	//   msøg, tězs, abez,
  { {0xafdb00b9,0xbcfb17a6,0x644917a7,0x00000000}},	//   lsøg, _abél, arei,
  { {0x673800c2,0x64490c00,0x442f002b,0x00000000}},	//   lavj, brei, _fwg_,
  { {0xe1ff02dd,0xafdb0146,0x644917a8,0x00000000}},	//   rmó_, nsøg, crei,
  { {0x9f530994,0x2618008b,0x533400fb,0x00000000}},	//   _això_, _kéo_, _сект,
  { {0x9f340086,0xcec40080,0xb17b00d1,0x00000000}},	//   ресі, voří_, flåt,
  { {0x26180013,0x63bd008f,0x248617a9,0x00000000}},	//   _méo_, īsne, _krom_,
  { {0x69c30164,0x6abd0053,0x261817aa,0x00000000}},	// [20d0] ènem, ्प्र, _léo_,
  { {0xafdb0146,0xdb0700ea,0x2d9e0003,0x00000000}},	//   dsøg, _aljá, êter_,
  { {0xafdb0146,0x26180003,0x5c040121,0x00000000}},	//   esøg, _néo_, рята,
  { {0xdd9517ab,0x3eac06a5,0xe9190086,0x00000000}},	//   _самы, ødte_, ході_,
  { {0xafdb0146,0x3944013c,0x764a002b,0x00000000}},	//   gsøg, рніг, erfy,
  { {0xdb0700ea,0x26180013,0x6838004c,0x00000000}},	//   _eljá, _béo_, _súdá,
  { {0x6449002b,0xcf940149,0xfc3f0014,0x00000000}},	//   wrei, יטס_, _hví_,
  { {0xafdb00b9,0x644917ac,0x248617ad,0x00000000}},	//   bsøg, trei, _brom_,
  { {0x752900e3,0x6738007d,0x248617ae,0x00000000}},	//   rbez, bavj, _crom_,
  { {0x7529050c,0x628100ca,0x248617af,0x00000000}},	//   sbez, tvlo, _drom_,
  { {0x644917b0,0xd1ca005e,0x248600ca,0x00000000}},	//   srei, елне_, _erom_,
  { {0x248603e9,0x64460006,0x645c000c,0x00000000}},	//   _from_, škia, ărir,
  { {0xf5390024,0x3fc8007e,0x2486147c,0x00000000}},	//   mať_, ندسی_, _grom_,
  { {0xf5390024,0x8e760299,0x00000000,0x00000000}},	//   lať_, лубч,   ,
  { {0xc7c8008b,0x213912a9,0x1eaa0c0a,0x00000000}},	//   uối_, bash_, راسي_,
  { {0xf5390024,0x25ad042b,0x213917b1,0x00000000}},	//   nať_, nkel_, cash_,
  { {0xb17b1310,0x3dd2002b,0x25ad00a8,0x00000000}},	// [20e0] rlåt, rnyw_, ikel_,
  { {0xb17b00d1,0x9f5e00fe,0xb346017d,0x00000000}},	//   slåt, ötä_, moçõ,
  { {0xf5390024,0x2ca9002c,0x53360047,0x00000000}},	//   kať_, ayad_, רנען_,
  { {0xf5390024,0xe9e50086,0xafdb00b9,0x00000000}},	//   jať_, аціо, tsøg,
  { {0xf5390024,0x07a617b2,0xc7c60794,0x00000000}},	//   dať_, ладн, лски,
  { {0xafdb010a,0x98a302d8,0x50db0041,0x00000000}},	//   rsøg, сиље, עקסא,
  { {0x673800c3,0xad9b017d,0xafdb00b9,0x00000000}},	//   ravj, _viúv, ssøg,
  { {0x442a0138,0x6d5600bb,0xafdb00b9,0x00000000}},	//   нцом_, ngya, psøg,
  { {0x6d56002c,0x61e617b3,0xa84a002a,0x00000000}},	//   igya, dokl, _سلام_,
  { {0x21f2004c,0x610c008f,0x21391098,0x00000000}},	//   sáhl_, _mēlī, wash_,
  { {0xf5390066,0x4422008f,0xe57900a3,0x00000000}},	//   bať_, ūk_, rlŷr_,
  { {0x24860025,0xf5390066,0xd9f60053,0x00000000}},	//   _trom_, cať_, ेषित_,
  { {0x2d8017b4,0x213917b5,0x439405e0,0x00000000}},	//   ddie_, rash_, _валс,
  { {0x14d70063,0x2a660051,0xad9b0139,0x00000000}},	//   _גודל_, łoby_, _liút,
  { {0xe3370047,0x5d67005e,0xe2460044,0x00000000}},	//   _גרופ_, лтаз, _إختي,
  { {0x7c290058,0x6d56013d,0x00000000,0x00000000}},	//   _çerk, ggya,   ,
  { {0xdfd5000d,0xd5b1008d,0x4c9405f4,0x00000000}},	// [20f0] _вопы, _húc_, битс,
  { {0xf5390024,0x91fd003d,0x6ee70032,0x00000000}},	//   zať_, stād, _مسجل,
  { {0x20d4007e,0x2ca9017e,0x25ad17b6,0x00000000}},	//   _نتیج, syad_, ykel_,
  { {0x7aee00b9,0xe9ce0636,0x3e41005f,0x00000000}},	//   _dybt, ік_, mėt_,
  { {0xf539061a,0xd5b1001b,0x3d3a0063,0x00000000}},	//   vať_, _lúc_, _בגרס,
  { {0x22590045,0xdd1c0006,0x98af003b,0x00000000}},	//   ński_, _iššo, eagă_,
  { {0xf5390024,0x25ad0019,0x83fd013d,0x00000000}},	//   tať_, tkel_, ntőe,
  { {0x1662000d,0xa44517b7,0x00000000,0x00000000}},	//   івым, анид,   ,
  { {0x9848011c,0xf5390024,0x644617b8,0x00000000}},	//   _бяха_, rať_, škin,
  { {0xf5390024,0x81bd001c,0xd265000d,0x00000000}},	//   sať_, spēl, акой,
  { {0x2249005a,0x25b000ea,0x27e70d17,0x00000000}},	//   ъпни_, álló_, monn_,
  { {0x69cb0199,0x61e60006,0x6aba005b,0x00000000}},	//   nige, uokl, _ütfe,
  { {0x6e250025,0x81bd001c,0x61e617b9,0x00000000}},	//   _athb, opēj, rokl,
  { {0x69cb00bd,0x6d4b0025,0x95a0003b,0x00000000}},	//   hige, ógan, ăşeş,
  { {0xa91d0512,0x6da60076,0x443f17ba,0x00000000}},	//   _každ, аива, lsu_,
  { {0x32da0063,0x63a317bb,0x973c007d,0x00000000}},	//   _שחקנ, _honn, _moća,
  { {0x2d8010e9,0x63a317bc,0xa91d17bd,0x00000000}},	// [2100] rdie_, _konn, _mažd,
  { {0xeab20021,0x69cb0b06,0xaec60054,0x00000000}},	//   يعا_, eige, _вбол,
  { {0x69cb17be,0x63a317bf,0x973c0130,0x00000000}},	//   fige, _monn, _noća,
  { {0x69cb00bd,0x291200d1,0x63a30d12,0x00000000}},	//   gige, øya_, _lonn,
  { {0x443f0051,0x76410829,0x91fd008f,0x00000000}},	//   jsu_, _avly, ltāc,
  { {0x98a40080,0xc66a0076,0x63a317c0,0x00000000}},	//   _země_, вшие_, _nonn,
  { {0x2956005a,0x69cb00bd,0xafdb0831,0x00000000}},	//   _възр, bige, prøv,
  { {0xd378017f,0x18a60086,0x443f07f9,0x00000000}},	//   moći_, _кабм, fsu_,
  { {0x26160161,0x63a304bc,0xb0c50053,0x00000000}},	//   _पूरी_, _bonn, _लेंग,
  { {0x63a302a0,0xdb0e0046,0x798217c1,0x00000000}},	//   _conn, _umbó, ldow,
  { {0x6d460512,0x63a307bd,0xd378007d,0x00000000}},	//   _odka, _donn, noći_,
  { {0x7c26017f,0x645d00cd,0x753b17c2,0x00000000}},	//   _otkr, àsic, cauz,
  { {0x8463005a,0x27ec0089,0xdfa702d8,0x00000000}},	//   _дъще, _kkdn_, ајво,
  { {0x44260273,0x69cb17c3,0x644217c4,0x00000000}},	//   _ito_, zige, _ivoi,
  { {0x7c26143b,0x644017c5,0x639b0063,0x00000000}},	//   _atkr, lsmi, _בסגנ,
  { {0x63a3006f,0xa91d02e2,0x79820051,0x00000000}},	//   _zonn, _kaže, jdow,
  { {0x61ed002c,0x69cb17c6,0xdb1e00fe,0x00000000}},	// [2110] _ikal, vige, kipä,
  { {0x44260009,0xa91d0006,0x69d80164,0x00000000}},	//   _mto_, _maže, éven,
  { {0x69cb17c7,0xdb0e0c77,0x386d17c8,0x00000000}},	//   tige, _albâ, _sper_,
  { {0x44261041,0x644017c9,0x443f0cc4,0x00000000}},	//   _oto_, ksmi, ysu_,
  { {0xbcfb0164,0x7980001f,0x61ed0035,0x00000000}},	//   _obéi, _damw, _mkal,
  { {0xdb1e0019,0x6d58005b,0x628a001f,0x00000000}},	//   gipä, ıbaş, _orfo,
  { {0x3f8100e3,0x644204bc,0x753b0035,0x00000000}},	//   _mahu_, _avoi, tauz,
  { {0x81bd0418,0xdddc074f,0x63a317ca,0x00000000}},	//   spēj, ovrš, _sonn,
  { {0x69c90035,0x628a001f,0x63a317cb,0x00000000}},	//   _imee, _arfo, _ponn,
  { {0x63ba17cc,0x61ed17cd,0x442600a4,0x00000000}},	//   ghtn, _akal, _dto_,
  { {0x443f007a,0x44260185,0x6d5d0025,0x00000000}},	//   ssu_, _eto_, _ocsa,
  { {0x443f17ce,0x3f830130,0xc19a0054,0x00000000}},	//   psu_, edju_, утої_,
  { {0x628a0199,0x973c017f,0x95c40021,0x00000000}},	//   _erfo, _moćn, _بينه,
  { {0x79820051,0x63ba030c,0x63a30072,0x00000000}},	//   zdow, chtn, _uonn,
  { {0xdfcf01a7,0xa91d17cf,0x79820022,0x00000000}},	//   ريف_, _zaže, ydow,
  { {0x451900b5,0x3d28007e,0x973c007d,0x00000000}},	//   רוּװ, شتری_, _noćn,
  { {0x6da317d0,0xada30081,0x8f76014b,0x00000000}},	// [2120] чита, чатл, _луні,
  { {0x69c904b4,0xdd3c0051,0xa3ca0053,0x00000000}},	//   _amee, lążk, रोप_,
  { {0x8e8617d1,0xdddc017f,0x0a4a0b3f,0x00000000}},	//   _الجه, avrš, узей_,
  { {0xe9da0076,0xe93a0021,0x6d4600b9,0x00000000}},	//   ыке_, اسات_, _udka,
  { {0x79820051,0x60000137,0xbcfb0003,0x00000000}},	//   rdow, römf, _ccéd,
  { {0x9873000d,0x207b0041,0xd0f7009a,0x00000000}},	//   яліц, טאנא, זמנת_,
  { {0xa91d017f,0x79820221,0x7791007e,0x00000000}},	//   _saže, pdow, ظیما,
  { {0xa91d0006,0xdb1e0ff2,0x644617d2,0x00000000}},	//   _paže, sipä, škim,
  { {0x2d820034,0x32f70013,0x81bd008f,0x00000000}},	//   _make_, _ãy_, spēk,
  { {0x61ed17d3,0xa91d017f,0xd4e30076,0x00000000}},	//   _skal, _važe, яющи,
  { {0x9f8d0080,0xe2f80086,0xdddc082a,0x00000000}},	//   uží_, рені_, zvrš,
  { {0xdb1c0026,0xad9b0025,0xa159000d,0x00000000}},	//   _umræ, _mhúc, шаму_,
  { {0xafdb0d02,0x673a00fe,0x3f810150,0x00000000}},	//   drør, _ketj, _pahu_,
  { {0x8233007e,0x4394157a,0xe8d7009a,0x00000000}},	//   _کروا, _факс, מוכר_,
  { {0x25a60180,0x673a17d4,0x60000137,0x00000000}},	//   _kool_, _metj, dömd,
  { {0x69d80003,0x463b0047,0x2d820783,0x00000000}},	//   ével, טעלע, _cake_,
  { {0x3f81014f,0xdb0e00cd,0x21f9004a,0x00000000}},	// [2130] _tahu_, _albà, lého_,
  { {0x673a00f5,0x69c909fe,0x75d3003b,0x00000000}},	//   _netj, _smee, răzi,
  { {0x21f90114,0x2d82059f,0x68fb013d,0x00000000}},	//   ného_, _fake_, _szud,
  { {0xd378017f,0xad9b0025,0x725b0047,0x00000000}},	//   moću_, _dhúc, רכאפ,
  { {0x673a17d5,0x21f90114,0x973c007d,0x00000000}},	//   _betj, hého_, _voćn,
  { {0x2d820035,0x21f9016b,0x7c2d12d4,0x00000000}},	//   _zake_, kého_, mpar,
  { {0x2d820009,0x56920001,0x628800a8,0x00000000}},	//   _yake_, дајт, jvdo,
  { {0x79a70141,0x1425123e,0x25a60cb4,0x00000000}},	//   _урге, одим, _cool_,
  { {0x57d5000a,0x7c2d17d6,0x28f80054,0x00000000}},	//   _доаѓ, npar, _геть_,
  { {0x7c2d17d7,0xd87404a0,0x87d704a0,0x00000000}},	//   ipar, _عاقب, _اغرا,
  { {0x69d90051,0x27e00139,0x25a6059f,0x00000000}},	//   onwe, éine_, _fool_,
  { {0x7c2d17d8,0x69d9004d,0x201301a8,0x00000000}},	//   kpar, nnwe, _aixi_,
  { {0x69d9004d,0xa8790047,0xdbc6004b,0x00000000}},	//   inwe, באָר, mööb,
  { {0x2d8217d9,0x7c2d17da,0x440717db,0x00000000}},	//   _sake_, dpar, _учеб,
  { {0x2d8200f3,0x442d17dc,0x764317dd,0x00000000}},	//   _pake_, lpe_, nsny,
  { {0x60000137,0x8d66000d,0x69d9006f,0x00000000}},	//   döme, ўвае, jnwe,
  { {0xfaf8003d,0x90c30055,0x7c2d002c,0x00000000}},	// [2140] _šī_, _объе, gpar,
  { {0xdb1c0d2c,0x2d82077d,0x76430822,0x00000000}},	//   _områ, _wake_, ksny,
  { {0x2d8217de,0xafdb00d1,0x65b5027d,0x00000000}},	//   _take_, prør, _náho,
  { {0x673a0627,0x7c2d12a9,0xf2d20041,0x00000000}},	//   _setj, bpar, ועב_,
  { {0x7c2d017d,0x673a14c7,0x442d00ca,0x00000000}},	//   cpar, _petj, jpe_,
  { {0xe7930001,0x69d917df,0x64460078,0x00000000}},	//   дишњ, anwe, škik,
  { {0x442d17e0,0x25a6010e,0xd5ba17e1,0x00000000}},	//   epe_, _pool_, иси_,
  { {0x21f9027d,0x746a0098,0x7a0c003b,0x00000000}},	//   vého_, аров_, _oşti,
  { {0x65b5004c,0x673a013d,0x684317e2,0x00000000}},	//   _táhn, _tetj, _онта,
  { {0x661a17e3,0x21f90114,0x25a617e4,0x00000000}},	//   _tutk, tého_, _wool_,
  { {0xe57a005a,0x7414007e,0x8546000d,0x00000000}},	//   _взе_, _کوتا, _дэле,
  { {0x21f90240,0x386617e5,0xd46a17e6,0x00000000}},	//   rého_, otor_, _виде_,
  { {0x55d900b5,0x386617e7,0x14c70076,0x00000000}},	//   _פֿענ, ntor_, _мыши_,
  { {0xa91d0006,0x386617e8,0x9f430061,0x00000000}},	//   _maža, itor_, pojí_,
  { {0xa187000d,0xdb210014,0x69d9002b,0x00000000}},	//   _дыпл, ótís, ynwe,
  { {0x65b501c2,0x22510066,0x7c2d17e9,0x00000000}},	//   _náhl, ázke_, tpar,
  { {0xf1bf0027,0xa91d0c61,0x3a2a00a4,0x00000000}},	// [2150] mhá_, _naža, _atbp_,
  { {0x7c2d17ea,0xf1bf17eb,0xfe500058,0x00000000}},	//   rpar, lhá_, üçük_,
  { {0x7a400405,0x7c2d17ec,0xd3780051,0x00000000}},	//   _rátá, spar, ieć_,
  { {0xa3ca0161,0x3eac00bd,0x4e7a0047,0x00000000}},	//   रोत_, ädte_, _פארצ,
  { {0xf1b401f9,0x69d917ed,0xc87b0002,0x00000000}},	//   וסף_, rnwe, рџе_,
  { {0xec360063,0x907c0063,0xa91d13ed,0x00000000}},	//   _מאשר_, שְׁפ, _daža,
  { {0xb935005e,0x1f38009a,0x386617ee,0x00000000}},	//   _невј, חרור_, ator_,
  { {0x31790045,0x65b50195,0x386600e5,0x00000000}},	//   jesz_, _váho, btor_,
  { {0x442d17ef,0x6569004d,0x386603db,0x00000000}},	//   upe_, rfeh, ctor_,
  { {0x442d17f0,0x75d3000c,0x65b50240,0x00000000}},	//   rpe_, văzu, _záhl,
  { {0xa3ca0161,0x656900bd,0x442d17f1,0x00000000}},	//   रोध_, pfeh, spe_,
  { {0x442d0386,0x216a0b3f,0xe8e0008b,0x00000000}},	//   ppe_, щими_, uyệt_,
  { {0x439517f2,0xafdb05e7,0x33950121,0x00000000}},	//   _надс, rsøn, _надё,
  { {0x3f6a005e,0x660917f3,0x21f201c8,0x00000000}},	//   љиво_, lmek, váhu_,
  { {0xa3b80049,0xe3b20041,0x5f03089a,0x00000000}},	//   _ظاهر_, _אױג_, езра,
  { {0x31790045,0x6da30001,0x9c2617f4,0x00000000}},	//   cesz_, ниса, здад,
  { {0x600001e9,0x1d070b4c,0x90460021,0x00000000}},	// [2160] römb, зети_, _عنده,
  { {0x386600c2,0x0e6617f5,0xab1a000d,0x00000000}},	//   vtor_, _екон, сцах_,
  { {0x660917f6,0x3866002b,0xdbd90014,0x00000000}},	//   kmek, wtor_, ræðs,
  { {0xd3780051,0xa91d0006,0x5886014c,0x00000000}},	//   zeć_, _paža, зыка,
  { {0x66090019,0xafdb00b9,0x0395008f,0x00000000}},	//   dmek, ksøl, _ķīnā_,
  { {0xa91d017f,0x386617f7,0x69c30110,0x00000000}},	//   _važa, rtor_, èner,
  { {0x200a003b,0xf1bf0066,0x3e87004c,0x00000000}},	//   imbi_, yhá_, mítá_,
  { {0x05760032,0x9adb0063,0xbcfb17f8,0x00000000}},	//   ساعد, _החלט, _ibér,
  { {0x6d4b0025,0xa91d007d,0x47c60094,0x00000000}},	//   ógai, _kažn, _ебав,
  { {0x644f17f9,0x88bb0063,0xad9b0013,0x00000000}},	//   ácia, _הזמי, _nhún,
  { {0x2c6617fa,0xdcfd008f,0x217901eb,0x00000000}},	//   hôd_, _masā, ойны_,
  { {0xa91d02e2,0xf1bf0080,0xdcfd001c,0x00000000}},	//   _lažn, uhá_, _lasā,
  { {0x44200529,0xbcfb17fb,0x7bce17fc,0x00000000}},	//   _îi_, _océa, _ombu,
  { {0xad9b17fd,0xf09f00cd,0x75380022,0x00000000}},	//   _chún, rxà_, ńczą,
  { {0xad9b0025,0x33fb0063,0x6e940121,0x00000000}},	//   _dhún, _ההגנ, ниру,
  { {0x22f70063,0xe4570047,0x7bce17fe,0x00000000}},	//   _מזון_, _אָנזאָ, _ambu,
  { {0xa91d0006,0x62850014,0x7c150054,0x00000000}},	// [2170] _bažn, _áhor, ддає,
  { {0x91fd008f,0x660917ff,0xd9b50042,0x00000000}},	//   itām, zmek, ंस्ट,
  { {0xa91d00eb,0x66091800,0xfe2405ac,0x00000000}},	//   _dažn, ymek, _пьян,
  { {0x6aaa00c7,0x63aa002b,0x7bce1801,0x00000000}},	//   äffa, _lofn, _embu,
  { {0xdbc700fe,0x2d990415,0xc794005d,0x00000000}},	//   töäs, _inse_, کشنب,
  { {0xbcb60063,0xbcfb0025,0xa69500e1,0x00000000}},	//   _חפשו_, _gcéa, дриј,
  { {0x25bf00ac,0x66091802,0xe664005e,0x00000000}},	//   thul_, tmek, етњо,
  { {0x25bf0019,0xafdb00d1,0x7de50078,0x00000000}},	//   uhul_, ruøy, bėse,
  { {0x91fd0418,0xed600080,0x66091803,0x00000000}},	//   rtāl, ížit_, rmek,
  { {0xe3b10021,0x63aa1246,0x25bf0509,0x00000000}},	//   ئرة_, _cofn, shul_,
  { {0x6609001c,0x2d99006f,0x91e60a71,0x00000000}},	//   pmek, _onse_, доне,
  { {0x44b51804,0xa91d0006,0x600000a5,0x00000000}},	//   _обес, _mažo, döma,
  { {0xa3ca0053,0x69d8006c,0x955400de,0x00000000}},	//   रोह_, évei, _أخما,
  { {0x2d8900ac,0x63aa001f,0x200a00b2,0x00000000}},	//   edae_, _gofn, umbi_,
  { {0x248d1805,0x61ef017d,0x394d1806,0x00000000}},	//   lvem_, bocl, _odes_,
  { {0xbcfb0027,0x217601dd,0xbdda0054,0x00000000}},	//   _scéa, _цукр, ієві_,
  { {0xa91d017f,0xdcfd001c,0xceb80006,0x00000000}},	// [2180] _pažn, _pasā, šę_,
  { {0x2d991807,0xaaba007e,0x394d1808,0x00000000}},	//   _ense_, يدار_, _ades_,
  { {0xa91d0117,0x4f9b009a,0xe6dc0046,0x00000000}},	//   _važn, _וביצ, jóðú,
  { {0xa91d001c,0x248d00b9,0xed5a005d,0x00000000}},	//   _dažo, kvem_, _بشدت_,
  { {0x6d441809,0x394d01dc,0x58370085,0x00000000}},	//   maia, _ddes_, дзія_,
  { {0x6283065f,0x98a30001,0x6d44180a,0x00000000}},	//   _osno, тиље, laia,
  { {0x5a55005a,0x248d017d,0xa91d00c2,0x00000000}},	//   _пъту, evem_, _gažo,
  { {0x77b40994,0x1dde0053,0x39490014,0x00000000}},	//   _màxi, नचित, óast_,
  { {0x186a013f,0xa01b0244,0xe76601ce,0x00000000}},	//   _фази_, iwöc, _овап,
  { {0x69c21294,0xc6760021,0x7bde04a7,0x00000000}},	//   lhoe, _يطاب, nnpu,
  { {0x6d44180b,0x394d01e1,0xcb570063,0x00000000}},	//   kaia, _ydes_, וסיה_,
  { {0x69c2102c,0xf5930021,0x22510114,0x00000000}},	//   nhoe, _للمج, ázka_,
  { {0x6d440360,0x22590022,0x4613005d,0x00000000}},	//   daia, ąska_, _شوهر,
  { {0xafdb00d1,0x60000072,0xe3af0044,0x00000000}},	//   msøk, töma, _نرى_,
  { {0xafdb0031,0xddab0121,0x6d4400be,0x00000000}},	//   lsøk, отал_, faia,
  { {0xe3b8005b,0x60000137,0xa91d001c,0x00000000}},	//   lkı_, röma, _ražo,
  { {0xafdb0093,0x8c19005d,0x81bd0023,0x00000000}},	// [2190] nsøk, سيار_, spēs,
  { {0x69c2006f,0x2d8900ac,0xe3b80058,0x00000000}},	//   ehoe, sdae_, nkı_,
  { {0xb17b02f0,0x248d0080,0x657b0150,0x00000000}},	//   pnåd, zvem_, yeuh,
  { {0x69c200f5,0xafdb069f,0x317c0041,0x00000000}},	//   ghoe, ksøk, ַרומ,
  { {0xe3b8005b,0xf3f9003b,0x67d5180c,0x00000000}},	//   kkı_, luţe_, ноду,
  { {0x65bc0003,0xafdb0093,0x91fd008f,0x00000000}},	//   _réha, dsøk, utāj,
  { {0xafdb0031,0x6f7a009a,0x00000000,0x00000000}},	//   esøk, לְקו,   ,
  { {0x91fd001c,0x644f0066,0x34a9005e,0x00000000}},	//   stāj, ácio, звио_,
  { {0x600000c7,0xafdb00d1,0xd7fb0a25,0x00000000}},	//   dömn, gsøk, _дуж_,
  { {0xf770006a,0x65600027,0xd5b10013,0x00000000}},	//   _نام_, agmh, _múi_,
  { {0xeb92180d,0xe299180e,0xc6a40002,0x00000000}},	//   אָר_, чан_, _ирци,
  { {0xdb07007a,0xafdb00d1,0x56b60041,0x00000000}},	//   _hljó, bsøk, _אפען_,
  { {0xb143000d,0x6d4400be,0xdb05004d,0x00000000}},	//   ынял, vaia, chhö,
  { {0x78a400fe,0xe4560047,0x75290290,0x00000000}},	//   äivi, _ניצט_, lcez,
  { {0xa91d017f,0x69c2001f,0x64460006,0x00000000}},	//   _pažl, yhoe, škit,
  { {0x6286001c,0x7529180f,0xdca61810,0x00000000}},	//   ākot, ncez, наби,
  { {0x64491811,0x6d441812,0x752901f4,0x00000000}},	// [21a0] nsei, raia, icez,
  { {0x799b0306,0x6d441813,0x7c2b1814,0x00000000}},	//   _anuw, saia, ígra,
  { {0x6d440397,0x69c21815,0xc0a9007e,0x00000000}},	//   paia, thoe, _فایل_,
  { {0x39400025,0x64491816,0xdca60794,0x00000000}},	//   úis_, ksei, _зами,
  { {0x69c20438,0x644f0331,0xd9170085,0x00000000}},	//   rhoe, ácil, ньш_,
  { {0x69c21817,0xc7a3012d,0x64490e64,0x00000000}},	//   shoe, личк, dsei,
  { {0x644b0a2e,0xb6050195,0x64491818,0x00000000}},	//   _avgi, znáš, esei,
  { {0xafdb0031,0xa91d00c3,0x38cb007e,0x00000000}},	//   tsøk, _lažj, _کافی_,
  { {0xdb07007a,0x91fd001c,0x69c01819,0x00000000}},	//   _fljó, stāk, _ilme,
  { {0xafdb0031,0x61e40009,0xa3ca0053,0x00000000}},	//   rsøk, _ajil, रों_,
  { {0xa1590138,0x26d800c7,0xafdb00d1,0x00000000}},	//   ману_, _äro_, ssøk,
  { {0x644900bd,0xe3b8005b,0xafdb00d1,0x00000000}},	//   bsei, skı_, psøk,
  { {0x60000137,0xe3b80058,0x240a0141,0x00000000}},	//   römn, pkı_, _енди_,
  { {0x69c000d1,0xdb1e004b,0xa01b0014,0x00000000}},	//   _llme, gipü, fvör,
  { {0x65bc0003,0xb605004c,0x63b5013d,0x00000000}},	//   _jého, snáš, özne,
  { {0xb7b50013,0x290412a9,0x7a47004c,0x00000000}},	//   _kịc, _ozma_, _létá,
  { {0xf3f9003b,0xa01b181a,0xfc30009b,0x00000000}},	// [21b0] suţe_, rvös, محل_,
  { {0x69c0181b,0x61fd06ea,0xe8000042,0x00000000}},	//   _alme, llsl, _लीला_,
  { {0xb7b5008b,0x3209008d,0x63ba181c,0x00000000}},	//   _lịc, _khay_, iktn,
  { {0x91f6008b,0x644900fe,0x32370047,0x00000000}},	//   hún, ysei, גטאן_,
  { {0x61fd00b9,0x18690002,0x6449004d,0x00000000}},	//   ilsl, фали_, xsei,
  { {0x2d8b048e,0xa6990001,0xa91d0006,0x00000000}},	//   _hace_, дњих_, _kažk,
  { {0x998d0022,0x7d020023,0x7a47009c,0x00000000}},	//   _pień_, ļose, _détá,
  { {0x6449181d,0x442f0d52,0x644f007d,0x00000000}},	//   tsei, _ptg_, šcim,
  { {0x75290290,0xdb070066,0xd5ae0021,0x00000000}},	//   rcez, _mojí, تفي_,
  { {0xb7b5001b,0x6449181e,0x2d8b00e5,0x00000000}},	//   _dịc, rsei, _lace_,
  { {0x443d181f,0x13090055,0xbcfb0003,0x00000000}},	//   _www_, ьной_, _scél,
  { {0x2d8b006d,0x201a00a4,0x3209008b,0x00000000}},	//   _nace_, _sipi_, _chay_,
  { {0x201a1820,0x9f4a0114,0xb05b004d,0x00000000}},	//   _pipi_, sobí_, nzäh,
  { {0xdce60066,0x61fd0046,0x00000000,0x00000000}},	//   ámče, alsl,   ,
  { {0x201a0035,0xdb07004c,0x2d8b0130,0x00000000}},	//   _vipi_, _bojí, _bace_,
  { {0xc69207e9,0xa91d008f,0xf652009d,0x00000000}},	//   סאן_, _dažk, יצל_,
  { {0x201a1821,0xdb070080,0x7bd7003b,0x00000000}},	// [21c0] _tipi_, _dojí, fixu,
  { {0x291f02dd,0xa01b0026,0xdce4001c,0x00000000}},	//   _agua_, svör, ediģ,
  { {0x68fb048e,0xcf570063,0x0f570e2a,0x00000000}},	//   _ayud, _בבית_, _ביים_,
  { {0xfbc90063,0xf1bb0013,0x29d5004c,0x00000000}},	//   חת_, _luơn_, sťan_,
  { {0x07a6000d,0x2d800493,0x63ba00d1,0x00000000}},	//   кадн, meie_, yktn,
  { {0x2d8000d1,0xd7f70062,0x7bc504a7,0x00000000}},	//   leie_, кущ_, chhu,
  { {0x69261822,0x2d8b0331,0x9634005e,0x00000000}},	//   _амба, _yace_, ћниц,
  { {0x5e5700b5,0xafdb00b9,0x96b70001,0x00000000}},	//   דיקע_, rsøi, ђују_,
  { {0x65b5006d,0x3944005f,0x8a17009a,0x00000000}},	//   _náhu, _iems_, _יחלו_,
  { {0x2d800529,0x21200089,0x65bc004c,0x00000000}},	//   heie_, _agih_, _tého,
  { {0x2d80021f,0xd7ef0021,0x0bb70063,0x00000000}},	//   keie_, _بكل_, דלים_,
  { {0xb6d90047,0x30350121,0x04960021,0x00000000}},	//   _אַנט, лемё, _للصح,
  { {0x2d8b1823,0x3eb80014,0x00000000,0x00000000}},	//   _race_, eyrt_,   ,
  { {0x040d0013,0x403401d5,0xa4b7009d,0x00000000}},	//   _mườn, рерс, _בלדה_,
  { {0x320900aa,0x2d8b15e5,0x040d0013,0x00000000}},	//   _thay_, _pace_, _lườn,
  { {0xdddc1824,0x1317009a,0xc536009d,0x00000000}},	//   avrž, _בחול_, דָ֑ה_,
  { {0x1df80076,0xf3f9003b,0x7afc1825,0x00000000}},	// [21d0] теты_, luţa_, _ayrt,
  { {0xf0920063,0x1b7b0021,0xad9b0025,0x00000000}},	//   _פני_, بصرة_, _mhúi,
  { {0x2d8b1826,0x7afc00a3,0xcb680044,0x00000000}},	//   _tace_, _cyrt, ضمنه_,
  { {0xe1ff00ea,0x83fd013d,0xa91d0734,0x00000000}},	//   nló_, rtői, _kaži,
  { {0x3da40088,0x040d008b,0x7c220025,0x00000000}},	//   _трэб, _cườn, íort,
  { {0xa91d00eb,0x040d008b,0xb05b004d,0x00000000}},	//   _maži, _dườn, rzäh,
  { {0xf7700929,0xb05b004d,0x36190121,0x00000000}},	//   تان_, szäh, нцию_,
  { {0xd5b1008b,0xdddc004c,0x394400e5,0x00000000}},	//   _nút_, zvrž, _gems_,
  { {0xad9b0025,0x5884000d,0x44150062,0x00000000}},	//   _chúi, _выха, лфот,
  { {0x69d914ce,0x3944001c,0x600017cb,0x00000000}},	//   liwe, _zems_, tömm,
  { {0xd5b10013,0x61461827,0x216a0f0a,0x00000000}},	//   _bút_, лена, нини_,
  { {0x60001828,0xe1ff0331,0x69d91829,0x00000000}},	//   römm, gló_, niwe,
  { {0xd24e006a,0xe3b3006a,0x753b0035,0x00000000}},	//   ينی_, _پرش_, mbuz,
  { {0xd8da0063,0x3eb800d1,0xe1ff00ea,0x00000000}},	//   תקשר, tyrt_, aló_,
  { {0x3ebe0026,0xe1ff182a,0x2eb50076,0x00000000}},	//   átt_, bló_, астс,
  { {0x45b50047,0x01660601,0x0c3a0044,0x00000000}},	//   נפּל_, _скио, فكرة_,
  { {0x672100c2,0x69d9001f,0x7afc001f,0x00000000}},	// [21e0] _oglj, diwe, _syrt,
  { {0x8b260a36,0x3ea6182b,0x9f860094,0x00000000}},	//   удже, _биог, _сгод,
  { {0x645b0027,0x2d8000be,0x7c36182c,0x00000000}},	//   hrui, peie_, spyr,
  { {0x91fd001c,0x645b0250,0x5cf6000d,0x00000000}},	//   stāv, krui, _бягу,
  { {0x6d4613ed,0x7afc002b,0x985616b4,0x00000000}},	//   _ieka, _wyrt, утеш,
  { {0x91fd003d,0xa6340086,0x645b182d,0x00000000}},	//   ltāt, анкі, drui,
  { {0x6d460397,0xf1c1027d,0x645b006f,0x00000000}},	//   _keka, ášky_, erui,
  { {0x040d008b,0x5454093f,0x645b01e7,0x00000000}},	//   _tườn, авит, frui,
  { {0x136a005a,0x645b006f,0xd5b1008b,0x00000000}},	//   ншни_, grui, _rút_,
  { {0x6d461588,0xf6260054,0x4274182e,0x00000000}},	//   _leka, _бджо, агос,
  { {0xb3450016,0x7c26120a,0x2bf70047,0x00000000}},	//   _seçã, _lukr, רמין_,
  { {0x645b182f,0xd2570088,0x6d461830,0x00000000}},	//   brui, ыць_, _neka,
  { {0x7c2600eb,0xf3f9000c,0xa91d0006,0x00000000}},	//   _nukr, suţa_, _paži,
  { {0xa3e80053,0x69d914ce,0x4fc70a91,0x00000000}},	//   _यदि_, ziwe, усма,
  { {0x44260009,0x6d461831,0x7c2604aa,0x00000000}},	//   _huo_, _beka, _aukr,
  { {0x44260006,0x6d461832,0x98c40042,0x00000000}},	//   _kuo_, _ceka, वनाए,
  { {0x44260006,0x69d90035,0x6d461833,0x00000000}},	// [21f0] _juo_, viwe, _deka,
  { {0xf1bf0080,0x69d80003,0x7c260078,0x00000000}},	//   lká_, èven, _dukr,
  { {0x4426024a,0x99350021,0x3f830130,0x00000000}},	//   _luo_, لفات, meju_,
  { {0x3ebe07e6,0x6d460007,0x19590085,0x00000000}},	//   øtte_, _geka, тады_,
  { {0x442600eb,0xa948007e,0x31580041,0x00000000}},	//   _nuo_, الهٔ_, רידן_,
  { {0x7bd500bd,0x65b50240,0x62981834,0x00000000}},	//   _umzu, _náhr, _orvo,
  { {0xdb050026,0x6d461835,0xf1bf10c9,0x00000000}},	//   rkhó, _yeka, kká_,
  { {0x4426002c,0x645b1836,0x370a0042,0x00000000}},	//   _buo_, trui, ाधड़ी_,
  { {0x6298024a,0x05a60076,0x645b172b,0x00000000}},	//   _arvo, рвый_, urui,
  { {0xe2990138,0x6721017f,0x60000137,0x00000000}},	//   вао_, _uglj, römk,
  { {0x645b1837,0xd5ae007e,0xdb07013d,0x00000000}},	//   srui, سفی_, _eljö,
  { {0x3f91008f,0x11d60054,0x62980130,0x00000000}},	//   edzu_, ріор, _drvo,
  { {0x62980122,0x628a1838,0xf3f900dd,0x00000000}},	//   _ervo, _esfo, erţe_,
  { {0x6d4617ba,0x25ad0019,0x91fd001c,0x00000000}},	//   _seka, ljel_, tuāc,
  { {0x6d461839,0xf233007e,0x7c26183a,0x00000000}},	//   _peka, _ابتک, _sukr,
  { {0xf1bf016b,0x25bf183b,0x3dc900a4,0x00000000}},	//   cká_, nkul_, ghaw_,
  { {0x6d46183c,0x8fc5007e,0x0b461702,0x00000000}},	// [2200] _veka, _گزين, инан,
  { {0x91fd183d,0x7dc3004b,0x1d19183e,0x00000000}},	//   grāf, _võsa, уюсь_,
  { {0x6d46053b,0xa926183f,0xa91d1840,0x00000000}},	//   _teka, адел, _mažu,
  { {0x61e61841,0x25ad013d,0xd3780130,0x00000000}},	//   nnkl, jjel_, miće_,
  { {0xdb070080,0x61e60006,0xa967005a,0x00000000}},	//   _vojá, inkl, рича_,
  { {0x91fd003d,0xd90d007e,0xf1bf01c2,0x00000000}},	//   ntār, ریل_, zká_,
  { {0x442602f6,0x64420045,0xdb0700ea,0x00000000}},	//   _suo_, _swoi, _tojá,
  { {0xafdb076c,0x44260290,0xbcfb0025,0x00000000}},	//   nsør, _puo_, _scéi,
  { {0xa4d4000d,0x98bd0022,0xdb1e004b,0x00000000}},	//   сопі, tawą_, gipö,
  { {0xa5070001,0xa91d0006,0x629804d9,0x00000000}},	//   шења_, _pažv, _prvo,
  { {0x3f830006,0xa91d001c,0x98bd0022,0x00000000}},	//   veju_, _dažu, rawą_,
  { {0x64420045,0x44261842,0xd378007d,0x00000000}},	//   _twoi, _tuo_, diće_,
  { {0xdb0e005b,0xe3af007e,0x3f831843,0x00000000}},	//   _albü, سری_, teju_,
  { {0xf1bf108f,0xdfdb0062,0x645d0066,0x00000000}},	//   ská_, тъм_, ásie,
  { {0x3f831844,0x753d013d,0xdeb40183,0x00000000}},	//   reju_, űsze, обры,
  { {0x7ae10066,0xdb1e004b,0x3da4130f,0x00000000}},	//   _žlto, nipõ, оруб,
  { {0x4c9407b0,0x91fd001c,0x7de50078,0x00000000}},	// [2210] оитс, stās, lėsk,
  { {0x60c002ab,0xde670062,0x2d8f00a8,0x00000000}},	//   ømme, _къмп, žge_,
  { {0x6e950032,0x2003074f,0x3a751845,0x00000000}},	//   _الجا, mlji_, слер,
  { {0x62860045,0x3915000d,0xaa58173e,0x00000000}},	//   łkow, бмер, рицу_,
  { {0x9f510080,0x6d4d1846,0x2003007d,0x00000000}},	//   hozí_, maaa, olji_,
  { {0x60000072,0x29d5017c,0x8a370044,0x00000000}},	//   tömi, zťah_, _نعرض,
  { {0x91fd001c,0x45d5005a,0xc7c8000d,0x00000000}},	//   orād, йцит, шыце_,
  { {0x59f90055,0x77bd0268,0x39400026,0x00000000}},	//   _себя_, _mèxi, ðist_,
  { {0x7bc71847,0x26c10024,0xa5f60001,0x00000000}},	//   _klju, šho_, љењу_,
  { {0x645d00cd,0x25bf1848,0xb8dd0053,0x00000000}},	//   àsiq, skul_, ुई_,
  { {0x6d4d0ddd,0xdb1e004b,0x57fa0047,0x00000000}},	//   kaaa, bipõ, _עלעו,
  { {0xd378007d,0xad9b0139,0x930d0058,0x00000000}},	//   viće_, _mhús, _ışık,
  { {0x34ab0021,0xb34600be,0xe3ae1849,0x00000000}},	//   _جداً_, unçõ, _еб_,
  { {0x6d4b0026,0xd378007d,0x91fd008f,0x00000000}},	//   ðgan, tiće_, erād,
  { {0xada6184a,0x6da6184b,0x63bc184c,0x00000000}},	//   бавл, бива, örne,
  { {0x6569184d,0x1d26005e,0xd378007d,0x00000000}},	//   ngeh, смам, riće_,
  { {0x69d80164,0x998d0051,0xafdb05e7,0x00000000}},	// [2220] èvem, _wieś_, rsør,
  { {0x91fd001c,0x7dda0080,0x65bc0164,0x00000000}},	//   arād, půso, _véhi,
  { {0xb05b0137,0x4a9a000d,0x16170042,0x00000000}},	//   tyäg, ытаў_, दगार_,
  { {0xdb1c00c7,0x6569006f,0x27e90025,0x00000000}},	//   _omrö, jgeh, éann_,
  { {0x28d20235,0x63a300ac,0x6569184e,0x00000000}},	//   _देखि, _onnn, dgeh,
  { {0xfaa60088,0xab271259,0x207b0047,0x00000000}},	//   _лаго, _гора_, ראסא,
  { {0x7bde0228,0x656900bd,0xdb1e004b,0x00000000}},	//   mipu, fgeh, tipõ,
  { {0x69cb136d,0x7bde184f,0x656906aa,0x00000000}},	//   chge, lipu, ggeh,
  { {0xc34a1850,0xdb0e00be,0xe73a1851,0x00000000}},	//   ляне_, _mobí, _без_,
  { {0x91fd001c,0xa91d0078,0x7bde1852,0x00000000}},	//   zrād, _važt, nipu,
  { {0xd5af1853,0x6d4d00a4,0x200302f7,0x00000000}},	//   _ес_, yaaa, vlji_,
  { {0x645d0942,0x31c70076,0x69c2006f,0x00000000}},	//   ásic, ссов, nkoe,
  { {0x644f0331,0x7bde1854,0x83fd013d,0x00000000}},	//   ácit, kipu, rtőr,
  { {0x6d4d00a4,0x7de50078,0x6ee70021,0x00000000}},	//   waaa, mėsi, مسأل,
  { {0x7de500eb,0x91fd001c,0x6d4d00a4,0x00000000}},	//   lėsi, trād, taaa,
  { {0x7bcb001c,0x91e4005e,0x83fd013d,0x00000000}},	//   īgum, _ноје, ltőp,
  { {0xcf8e006a,0x7bcb001c,0x7bc702f7,0x00000000}},	// [2230] رژی_, ūgum, _plju,
  { {0xad9b0025,0x2bbb0021,0xdfd1007e,0x00000000}},	//   _chúr, دارة_, _آيد_,
  { {0xc333014e,0x6d4d00a4,0x7bc700c2,0x00000000}},	//   פוף_, paaa, _vlju,
  { {0x7de50006,0x6b850244,0x00000000,0x00000000}},	//   kėsi, sehg,   ,
  { {0x27e9006d,0xa01b00ea,0xf8650054,0x00000000}},	//   éano_, dvöz, івко,
  { {0x7de50006,0xdb0e000c,0x9848014c,0x00000000}},	//   dėsi, _dobâ, сяца_,
  { {0x5fbc014e,0x65691855,0x61ed1856,0x00000000}},	//   רצונ, tgeh, _ojal,
  { {0xe4591857,0xa91d008f,0x0609007b,0x00000000}},	//   ажи_, _dažr, јник_,
  { {0x65691858,0x7de50078,0x00000000,0x00000000}},	//   rgeh, gėsi,   ,
  { {0x656900bd,0x61ed0449,0xd7fb15d4,0x00000000}},	//   sgeh, _ajal, _суб_,
  { {0xf77004de,0x65690104,0x69c91859,0x00000000}},	//   _سال_, pgeh, _klee,
  { {0x7de50006,0xb1da0086,0x216a0499,0x00000000}},	//   bėsi, рьох_, шими_,
  { {0x61ed185a,0xd00a185b,0xdb0e0195,0x00000000}},	//   _djal, иеме_, _robí,
  { {0x69c9006f,0xd9b60053,0xee3a0cd6,0x00000000}},	//   _llee, _अक्ट, инг_,
  { {0x61ed0026,0x98bd0051,0x9f58185c,0x00000000}},	//   _fjal, rawę_, noré_,
  { {0x61ed007a,0x91fd001c,0x2251004a,0x00000000}},	//   _gjal, nuāl, ázku_,
  { {0xd378007d,0xfc1a0021,0x7bde185d,0x00000000}},	// [2240] lića_, لقرب_, tipu,
  { {0x69c9185e,0x60000072,0x6abe0e77,0x00000000}},	//   _alee, tömu, typf,
  { {0xdcff001c,0x69c90625,0x7bde185f,0x00000000}},	//   īvāk, _blee, ripu,
  { {0x7ae30025,0x600000bd,0x38660003,0x00000000}},	//   únta, römu, tuor_,
  { {0x91fd001c,0x98470062,0x69c21860,0x00000000}},	//   duāl, ояща_, rkoe,
  { {0x69c21861,0xa09b0149,0xd378007d,0x00000000}},	//   skoe, יינט, kića_,
  { {0x69c90034,0xeb9100b5,0xd378007d,0x00000000}},	//   _flee, _אָן_, jića_,
  { {0xd378017f,0x35f7007e,0xa9670896,0x00000000}},	//   dića_, يريد_, _миса_,
  { {0x6b990139,0x386612a9,0xb7e61862,0x00000000}},	//   _éagó, quor_, _джак,
  { {0x7de50006,0x61ed0d9f,0x249d001f,0x00000000}},	//   rėsi, _sjal, _drwm_,
  { {0x69c900fe,0xc7b30063,0x51f90636,0x00000000}},	//   _ylee, _קבע_, йною_,
  { {0xc2b70054,0x7de5005f,0x645d005f,0x00000000}},	//   іляє_, pėsi, šsia,
  { {0xc95301f9,0x80db0053,0xa5070713,0x00000000}},	//   ומר_, _पेशे, _деца_,
  { {0xd378007d,0x3a240783,0xa2e60044,0x00000000}},	//   bića_, _limp_, _وأثن,
  { {0xcddb041d,0x91fd001c,0x61ed1863,0x00000000}},	//   ања_, grāc, _tjal,
  { {0xd1310044,0x29040075,0x61ed0566,0x00000000}},	//   _ثمة_, _oyma_, _ujal,
  { {0x61fd1864,0xdc98012c,0xfc300044,0x00000000}},	// [2250] mosl, овті_, نحل_,
  { {0xaac7006a,0x9f43006d,0x69c91865,0x00000000}},	//   يتان, rojó_, _slee,
  { {0x8ae7019d,0xaa950021,0x69c91860,0x00000000}},	//   ціал, ثلاث, _plee,
  { {0x99d4007e,0xbcfb0066,0xfbdf002b,0x00000000}},	//   وتنا, _dcér, _gwên_,
  { {0x69c91031,0x394f004d,0xc7a50062,0x00000000}},	//   _vlee, rags_, зилк,
  { {0x9f58034d,0x29040185,0xd629167b,0x00000000}},	//   toré_, _dyma_, боке_,
  { {0x91fd001c,0x21290150,0x6fc20066,0x00000000}},	//   tuāl, _ogah_, _dôch,
  { {0xd378017f,0x21290089,0x61fd001c,0x00000000}},	//   vića_, _ngah_, josl,
  { {0x478b0076,0x61fd1866,0x44390003,0x00000000}},	//   _всем_, dosl, ës_,
  { {0x4439001c,0xd378007d,0x4734005d,0x00000000}},	//   īs_, tića_, _قرمز,
  { {0x44391867,0x9f4e0080,0x7dca0026,0x00000000}},	//   ūs_, áním_, _lýsa,
  { {0x249d001f,0xd378007d,0x61fd1868,0x00000000}},	//   _trwm_, rića_, gosl,
  { {0x394d1869,0xd378007d,0x1016000d,0x00000000}},	//   _mees_, sića_, зьвя,
  { {0x78a6007a,0x394d04c6,0x437500b5,0x00000000}},	//   _ákve, _lees_, _זײַן_,
  { {0x443f186a,0x60120026,0xc7b20047,0x00000000}},	//   lpu_, væmd, ײבן_,
  { {0x7bc500ac,0x62830290,0x443f001c,0x00000000}},	//   ekhu, _ipno, opu_,
  { {0xdd8f0067,0x3c66000d,0xc0e6186b,0x00000000}},	// [2260] دوق_, якаг, _хопк,
  { {0x443f186c,0x2c740137,0x3a2401f4,0x00000000}},	//   ipu_, räd_, _simp_,
  { {0x394d00e5,0x09e6030b,0x3a240168,0x00000000}},	//   _bees_, пожн, _pimp_,
  { {0x6fcb005b,0x2d89186d,0x394d00ca,0x00000000}},	//   _tücc, ceae_, _cees_,
  { {0x6d44186e,0x18670caa,0xdb0e01c8,0x00000000}},	//   mbia, зачи_, _dobá,
  { {0x6d440006,0x3f8a001f,0x25b2001f,0x00000000}},	//   lbia, nebu_, _ŵyl_,
  { {0x3a240529,0x63b80a63,0x394d186f,0x00000000}},	//   _timp_, _rovn, _fees_,
  { {0x394d00e8,0x6fcb005b,0x99500066,0x00000000}},	//   _gees_, _müca, lúži_,
  { {0x6d441870,0x61fd1871,0x6283011b,0x00000000}},	//   ibia, vosl, _apno,
  { {0x883b0063,0x7de50006,0x60270003,0x00000000}},	//   _לתמו, lėst, hémè,
  { {0x443f0368,0xd6c4007e,0x9473005d,0x00000000}},	//   apu_, _تمای, ودیا,
  { {0x25a6001f,0x7c3a004c,0x3f981872,0x00000000}},	//   _unol_, _čtrn, edru_,
  { {0x77bd00cd,0xf3f9003b,0x9f58002b,0x00000000}},	//   _tèxt, zuţi_, gorï_,
  { {0xb7bd0529,0x3f8a0150,0x6d44002b,0x00000000}},	//   _puţi, gebu_, ebia,
  { {0x6b95055e,0x64400a53,0x61fd09a1,0x00000000}},	//   _razg, lpmi, posl,
  { {0x463b0041,0x3f9800dd,0x92f200dd,0x00000000}},	//   מעלע, adru_, ăşăm,
  { {0x7de50006,0x394d035a,0x0c390021,0x00000000}},	// [2270] dėst, _rees_, زكاة_,
  { {0xfe6e006a,0xbca40032,0x394d010e,0x00000000}},	//   دگی_, عملي, _sees_,
  { {0x6b95005b,0x660200ea,0x6d441873,0x00000000}},	//   _vazg, _okok, bbia,
  { {0x3eac02ab,0x7bc501a8,0x3ebe1874,0x00000000}},	//   ådte_, skhu, ätte_,
  { {0x315800b5,0x6d5d069f,0x8819000d,0x00000000}},	//   ליאן_, _idsa, оўку_,
  { {0x394d021f,0x46390121,0x98a2157f,0x00000000}},	//   _wees_, очия_, тише,
  { {0x6d4f003e,0x9f5e0003,0x4ac5007e,0x00000000}},	//   _keca, ôté_, _غيرق,
  { {0x84591875,0x1994000d,0x248d0051,0x00000000}},	//   орот_, _пася, twem_,
  { {0x6d4f1876,0x8554007e,0x6f09004c,0x00000000}},	//   _meca, ریور_, řech,
  { {0x443f1877,0x798b002b,0x6d4f123c,0x00000000}},	//   rpu_, legw, _leca,
  { {0x7c2f1878,0x6d44001f,0xd7580021,0x00000000}},	//   _lucr, ybia, _رجلا_,
  { {0x798b001f,0x71da0086,0x6d4f1879,0x00000000}},	//   negw, ієнт_, _neca,
  { {0x9554007e,0xc4fb007e,0x66090058,0x00000000}},	//   _سخنا, _اعضا_, mlek,
  { {0x7d0608b3,0x6609187a,0x6d44002b,0x00000000}},	//   _ryks, llek, wbia,
  { {0x6d4f0037,0x4427187b,0x3f8a187c,0x00000000}},	//   _beca, _iin_, rebu_,
  { {0x7e61007a,0x6d4f0089,0x661b00fe,0x00000000}},	//   álpa, _ceca, nmuk,
  { {0x1d070001,0xfce3006e,0x6d44187d,0x00000000}},	// [2280] дети_, вото, rbia,
  { {0x7d060006,0xabaa0021,0x6609187e,0x00000000}},	//   _vyks, غهام_, hlek,
  { {0x6eb50053,0x442f187f,0x7d060051,0x00000000}},	//   _उपयु, _lug_, _wyks,
  { {0x44271880,0xfc3f0139,0x5886000d,0x00000000}},	//   _lin_, _bríd_, дыка,
  { {0x91fd008f,0x9f580066,0x645d16f1,0x00000000}},	//   krān, horí_, ásil,
  { {0x442701f7,0x66091881,0x661b1882,0x00000000}},	//   _nin_, elek, emuk,
  { {0xd6d00032,0x9f5801f4,0x66091883,0x00000000}},	//   طقة_, vorì_, flek,
  { {0xd5b00032,0x661b00a4,0x7c27006f,0x00000000}},	//   افة_, gmuk, _zijr,
  { {0x39460877,0x44271884,0x7c29013d,0x00000000}},	//   mbos_, _bin_, _éert,
  { {0x394600eb,0xa3d80053,0xe8d70063,0x00000000}},	//   lbos_, ठों_, _חומר_,
  { {0xbcfb1885,0x66091886,0x44271887,0x00000000}},	//   _idée, blek, _din_,
  { {0x7dc30019,0x44271888,0x66020035,0x00000000}},	//   _tõsi, _ein_, _ukok,
  { {0x44271889,0x361b0047,0x29f8007d,0x00000000}},	//   _fin_, _וואד, mčad_,
  { {0x6d4f014f,0x250b007e,0x4427188a,0x00000000}},	//   _seca, _برمی_, _gin_,
  { {0x442f00bd,0x6d4f188b,0x7dd102e0,0x00000000}},	//   _zug_, _peca, _låse,
  { {0x4427188c,0xa1870085,0x7bce188d,0x00000000}},	//   _zin_, _цыкл, _albu,
  { {0x6d4f001c,0x42180044,0x4427188e,0x00000000}},	// [2290] _veca, _تزوج_, _yin_,
  { {0x2fc700aa,0x4427001b,0x60c00d88,0x00000000}},	//   _ông_, _xin_, ämme,
  { {0x61ef0bdb,0xf09f01a8,0x6600188f,0x00000000}},	//   oncl, lvà_, komk,
  { {0x6d5d00b9,0x38660cc7,0x660900b8,0x00000000}},	//   _udsa, fror_, xlek,
  { {0xdd3a014e,0x798b00ac,0x66091890,0x00000000}},	//   _מערכ, regw, vlek,
  { {0xe611007e,0xa6950095,0x9695005e,0x00000000}},	//   گشت_, ериј, ериш,
  { {0x44271891,0x6b6800ea,0x66091892,0x00000000}},	//   _rin_, ségü, tlek,
  { {0x9f580024,0xfc3f0025,0x44271893,0x00000000}},	//   vorí_, _tríd_, _sin_,
  { {0x661b1894,0x66091895,0x0efc0053,0x00000000}},	//   rmuk, rlek, _एड्स_,
  { {0xe3b10032,0x78a60026,0x9f580024,0x00000000}},	//   ارة_, _ákva, torí_,
  { {0x0394000d,0x44271896,0x2d991897,0x00000000}},	//   трыя, _vin_, _oase_,
  { {0x4427120f,0x764300a4,0x442f059f,0x00000000}},	//   _win_, mpny, _tug_,
  { {0x44271898,0x2ec80042,0xe5340121,0x00000000}},	//   _tin_, रन्त, _речь,
  { {0x44271899,0xe4560047,0x3cf30042,0x00000000}},	//   _uin_, _טינט_, ंपने_,
  { {0x39460006,0x249f0014,0xdb1c0058,0x00000000}},	//   ybos_, lvum_, üzün,
  { {0xdb1c0164,0x2d990399,0x386600a5,0x00000000}},	//   _forê, _case_, yror_,
  { {0x3dd20185,0x8fa60f27,0x61e6189a,0x00000000}},	// [22a0] rhyw_, _запе, mikl,
  { {0xfc3f0027,0x2d990034,0x395f000c,0x00000000}},	//   _dtí_, _ease_, _adus_,
  { {0xb17b00c7,0x160f0053,0x2d99189b,0x00000000}},	//   pnåt, ातार_, _fase_,
  { {0x61e6189c,0x523a0047,0x2d99189d,0x00000000}},	//   nikl, לײענ, _gase_,
  { {0xb3460016,0xa927019d,0x61e60019,0x00000000}},	//   niçõ, ніше_, iikl,
  { {0x6d56189e,0x2d99189f,0x386603e1,0x00000000}},	//   laya, _zase_, rror_,
  { {0x25bd18a0,0x3c3600b9,0x61e618a1,0x00000000}},	//   _bowl_, _hæv_, kikl,
  { {0x3f9a003d,0x6d5615c4,0xceb30132,0x00000000}},	//   _lapu_, naya, ריה_,
  { {0x1867000a,0x61e618a2,0x660018a3,0x00000000}},	//   _пати_, dikl, romk,
  { {0x660018a4,0xb346017d,0x61e60006,0x00000000}},	//   somk, diçõ, eikl,
  { {0x6d5618a5,0xd2570086,0x66000035,0x00000000}},	//   kaya, нця_, pomk,
  { {0x6d5618a6,0xab64005b,0x60120026,0x00000000}},	//   jaya, ldüğ, væma,
  { {0x7dca0512,0x6d56014f,0x2ca0007d,0x00000000}},	//   _výsl, daya, jvid_,
  { {0x20050024,0x2ca000c7,0xb4be0053,0x00000000}},	//   ôli_, dvid_, ीनी_,
  { {0x2d9918a7,0xdb1518a8,0x6d560089,0x00000000}},	//   _pase_, _pozí, faya,
  { {0x3253011c,0x6d5600bb,0x3ebe0140,0x00000000}},	//   _свър, gaya, ätta_,
  { {0x9f5800cd,0x2d9918a9,0xacf818aa,0x00000000}},	// [22b0] borà_, _vase_, енту_,
  { {0x9f5801a8,0x1cb80044,0x3dc9056c,0x00000000}},	//   corà_, راقب_, skaw_,
  { {0x6d5618ab,0x20030006,0x2d9918ac,0x00000000}},	//   baya, moji_, _tase_,
  { {0x2003005b,0xafdb00d1,0x6d5618ad,0x00000000}},	//   loji_, vsøy, caya,
  { {0xcf27007e,0xe72e026b,0x7dda0080,0x00000000}},	//   _ترکي, ие_, růst,
  { {0xa01b0026,0xa09c0047,0x69d80003,0x00000000}},	//   stöf, פיוט, èver,
  { {0x60c60066,0x91fd008f,0x61e60075,0x00000000}},	//   zykm, trāl, yikl,
  { {0x36180085,0xc4850782,0xb4be0042,0x00000000}},	//   нцыю_, влик, ीनू_,
  { {0x61e618ae,0x91a9008b,0x99870078,0x00000000}},	//   vikl, _giả_, ūnų_,
  { {0x799b0035,0x69cb00f5,0x20030006,0x00000000}},	//   _hauw, lkge, joji_,
  { {0x6d5600bb,0x27e70026,0x2d8008b3,0x00000000}},	//   yaya, minn_, yfie_,
  { {0x27e718af,0xe3b1007e,0xb346017d,0x00000000}},	//   linn_, ارک_, tiçõ,
  { {0x69cb006f,0x32020114,0xc9520063,0x00000000}},	//   ikge, roky_, סמך_,
  { {0x200300c3,0xb3460016,0x6d560277,0x00000000}},	//   goji_, riçõ, waya,
  { {0xb3460016,0x26c70006,0x6d560bbf,0x00000000}},	//   siçõ, nyno_, taya,
  { {0x799b0122,0x69cb006f,0x753b18b0,0x00000000}},	//   _nauw, jkge, ncuz,
  { {0x27e70026,0x91fd001c,0x645b066d,0x00000000}},	// [22c0] kinn_, krāj, nsui,
  { {0x201a0032,0x9f4a006d,0xfaa60376,0x00000000}},	//   _تتبع_, robó_, казо,
  { {0x6d5618b1,0x799b00bd,0x27e70014,0x00000000}},	//   paya, _bauw, dinn_,
  { {0x5e5700b5,0xd5af0086,0x186a0002,0x00000000}},	//   _ביטע_, _всi_, дади_,
  { {0x61e40035,0x27e70026,0x76410078,0x00000000}},	//   _mmil, finn_, _atly,
  { {0x27e707cf,0xf0930047,0xda660049,0x00000000}},	//   ginn_, ינד_, _لاري,
  { {0x7dc30019,0xab64005b,0xbcfb18b2,0x00000000}},	//   _tõst, rdüğ, _idéa,
  { {0x69cb00bd,0x6b9c014f,0xd378007d,0x00000000}},	//   ckge, _harg, mići_,
  { {0xb4cc0161,0xd467000a,0xb4be0161,0x00000000}},	//   रने_, виње_, ीने_,
  { {0x674502f4,0x43940001,0x799b0051,0x00000000}},	//   čují, ћанс, _zauw,
  { {0xd6c4007e,0xad9b0024,0xa3e30053,0x00000000}},	//   _حمای, _skúm, _नगर_,
  { {0xdb1c18b3,0x6b9c18b4,0x38690734,0x00000000}},	//   _coré, _larg, šare_,
  { {0xdb1c0003,0xa2630013,0x50670062,0x00000000}},	//   _doré, _huố, ътна,
  { {0x9f580024,0xbcfb0025,0x3f850024,0x00000000}},	//   torá_, _ndéa, ýlu_,
  { {0x9e07019d,0xb0620072,0x3ea50014,0x00000000}},	//   вчал, _äänn, ílt_,
  { {0xa263001b,0x69c018b5,0x200300c2,0x00000000}},	//   _muố, _nome, soji_,
  { {0x9d150612,0x320900a4,0x6b9c050b,0x00000000}},	// [22d0] удач, _ikay_, _barg,
  { {0x6b9c12d8,0xfc3f006d,0x8bd40085,0x00000000}},	//   _carg, _cría_, ажуц,
  { {0x69c0006f,0x65620066,0x6fcb004d,0x00000000}},	//   _bome, _odoh, _lück,
  { {0xceb20047,0x27e7004d,0x69c00764,0x00000000}},	//   _היט_, winn_, _come,
  { {0x6b9c1609,0x26c7001f,0xfc3f006d,0x00000000}},	//   _farg, wyno_, _fría_,
  { {0x628a0146,0xd7f8005e,0x6b9c0bea,0x00000000}},	//   _opfo, куј_, _garg,
  { {0x27e70c35,0xa263008b,0x0654000d,0x00000000}},	//   rinn_, _cuố, атыў,
  { {0x3f9100bd,0x645b18b6,0x69c018b7,0x00000000}},	//   hezu_, tsui, _gome,
  { {0xad9b0024,0x27e70026,0x6b9c005b,0x00000000}},	//   _akúk, pinn_, _yarg,
  { {0x69c00122,0x61e418b8,0x645b18b9,0x00000000}},	//   _zome, _smil, rsui,
  { {0xdb1c0016,0x645b18ba,0x76411310,0x00000000}},	//   _poré, ssui, _utly,
  { {0x66270032,0xc6da00b5,0xcb120063,0x00000000}},	//   _شراك, _אַדר, מלי_,
  { {0xa91d00eb,0x6fcb004d,0x629800be,0x00000000}},	//   _pažy, _küch, _esvo,
  { {0x3a2d0122,0x68e40139,0x69da005f,0x00000000}},	//   _liep_, úidi, _įtem,
  { {0xa263001b,0x7dca0026,0x2fc50014,0x00000000}},	//   _xuố, _hýsi, ölga_,
  { {0xa01b00ea,0x63b50006,0xd378007d,0x00000000}},	//   gtöb, šanč, vići_,
  { {0x69c018bb,0x6da3005a,0xb8860080,0x00000000}},	// [22e0] _rome, щита, _kníž,
  { {0xa01b00fe,0x69c018bc,0xd378007d,0x00000000}},	//   ttöe, _some, tići_,
  { {0x7794006a,0xc332014e,0x7dca0026,0x00000000}},	//   ییرا, צוא_, _lýsi,
  { {0x6b9c014f,0x9f580268,0xbcfb006d,0x00000000}},	//   _warg, forç_, _idén,
  { {0x2d9201f7,0x6fcb00bd,0x6b9c18bd,0x00000000}},	//   meye_, _büch, _targ,
  { {0x6fcb0199,0x69c00034,0x2d920058,0x00000000}},	//   _rück, _wome, leye_,
  { {0x96f80076,0xa263008b,0xb7650086,0x00000000}},	//   ъект_, _quố, ртій,
  { {0x7a8b0063,0x7c2e18be,0x2d92107b,0x00000000}},	//   _אָמַ, _hibr, neye_,
  { {0x7c2e0035,0x27e5006d,0xf74618bf,0x00000000}},	//   _kibr, _fmln_, _безо,
  { {0x54330021,0x7c2e0c12,0x66da0121,0x00000000}},	//   حرير, _jibr, _пьер_,
  { {0x3f91017f,0x2d92005b,0x0bb70063,0x00000000}},	//   vezu_, keye_, אלים_,
  { {0x6fcb004d,0x7c2e0653,0xc2b70054,0x00000000}},	//   _züch, _libr, улює_,
  { {0x7c2e0027,0x2d921357,0x3f91007d,0x00000000}},	//   _oibr, deye_, tezu_,
  { {0xddc700c2,0xed590078,0x403408a8,0x00000000}},	//   dujš, _žž_, серс,
  { {0x6298017f,0x3f910b59,0xa6f80063,0x00000000}},	//   _usvo, rezu_, דִּי,
  { {0xb8860024,0x7c2e0025,0xb03509c2,0x00000000}},	//   _zníž, _aibr, _книш,
  { {0x3a2d006f,0xdb6b0086,0xcb55005e,0x00000000}},	// [22f0] _riep_, ерел_, иваћ,
  { {0xcb68005e,0x00000000,0x00000000,0x00000000}},	//   лађе_,   ,   ,
  { {0x795902b3,0xfc3f0046,0x7c2e18c0,0x00000000}},	//   виер_, _grín_, _dibr,
  { {0x2d920058,0x442e18c1,0x0dcb0044,0x00000000}},	//   ceye_, _lif_, _أبدى_,
  { {0xbcfb0003,0x9984003b,0x6d4d18c2,0x00000000}},	//   _idéo, _simţ_, mbaa,
  { {0x6d4d0250,0xdcfd001c,0x3669005e,0x00000000}},	//   lbaa, _lasī, вако_,
  { {0x45d506cb,0x1995000d,0xd3780130,0x00000000}},	//   ицит, _кавя, niću_,
  { {0xb8860080,0x6d4d0173,0x05a90b3f,0x00000000}},	//   _sníž, nbaa, твий_,
  { {0xe456000d,0x9c890086,0x6fcb004d,0x00000000}},	//   ажы_, ерiа, _tüch,
  { {0x98170021,0xc4e2000d,0x442e18c3,0x00000000}},	//   _إبرا, іжэй, _cif_,
  { {0x6d4d0102,0x629e18c4,0x6b6000ea,0x00000000}},	//   kbaa, _špor, lágí,
  { {0x78a90031,0x601200b9,0x10a6042c,0x00000000}},	//   _krev, ræmm, аимн,
  { {0x21a30076,0x6d4d006f,0x442e0150,0x00000000}},	//   циям, dbaa, _fif_,
  { {0x7dd800ed,0x442e18c5,0x644918c6,0x00000000}},	//   _míse, _gif_, mpei,
  { {0x2d92005b,0x6d4d006f,0x644900d1,0x00000000}},	//   teye_, fbaa, lpei,
  { {0x6d4d18c7,0x3860074f,0x645d0078,0x00000000}},	//   gbaa, širi_, šsiu,
  { {0x61fd00ea,0x2d92005b,0x6281087d,0x00000000}},	// [2300] érle, reye_, ltlo,
  { {0x628100ca,0x2d9218c8,0x8e760094,0x00000000}},	//   otlo, seye_, _кумч,
  { {0xfc3f006d,0x7f5c13db,0x628117ed,0x00000000}},	//   _frío_, marq, ntlo,
  { {0x2251027d,0x78a90dd1,0x180e0053,0x00000000}},	//   ázky_, _brev, ित्व_,
  { {0x913b00b5,0x38600d23,0x4c670086,0x00000000}},	//   דענק, éir_, _киян_,
  { {0xe66606b6,0x6f09005b,0x7f5c18c9,0x00000000}},	//   атио, şece, narq,
  { {0x644900e8,0x442e18ca,0xd910005d,0x00000000}},	//   epei, _rif_, _کیش_,
  { {0x69d918cb,0x7e610026,0x7dd80025,0x00000000}},	//   chwe, álpi, _físe,
  { {0x62810051,0xdb1c0118,0x030b0053,0x00000000}},	//   etlo, _morí, _सुबह_,
  { {0x66e608ac,0x03c61849,0x2bfb0042,0x00000000}},	//   _коза, рсим, ्वयं_,
  { {0xe7370076,0x442e0003,0x69cd004b,0x00000000}},	//   _тех_, _vif_, öaeg,
  { {0x92570076,0xd378007d,0xb80e0082,0x00000000}},	//   шают_, viću_, ितकम_,
  { {0x909818cc,0x7dd118cd,0x10740071,0x00000000}},	//   авят_, _såso, оляю,
  { {0xdbcf0066,0x7f5c0e1f,0xc8840058,0x00000000}},	//   sľúb, garq, mağı_,
  { {0x6d4d0179,0x63bc0026,0xdb23005b,0x00000000}},	//   tbaa, örnu, ürün,
  { {0xcdd80138,0x6d4d00e8,0x629d008f,0x00000000}},	//   ању_, ubaa, āsot,
  { {0xdce601f7,0x7f5c18ce,0xd904007e,0x00000000}},	// [2310] _bakı, barq, _آی_,
  { {0x6d4d1038,0x2b58003b,0x6e2418cf,0x00000000}},	//   sbaa, _cerc_, amib,
  { {0xd8b8006a,0x6d4d0250,0xfc3f006d,0x00000000}},	//   یدها_, pbaa, _trío_,
  { {0xf99303eb,0x7dd80080,0x78a918d0,0x00000000}},	//   تبط_, _píse, _prev,
  { {0xe0df01f4,0xcdb60063,0xaf08005d,0x00000000}},	//   nzò_, _הפרה_, _مقیم_,
  { {0xec360063,0x2bc80002,0xf8070002,0x00000000}},	//   _לאשר_, _кусо_, шчен,
  { {0x5a44000d,0x6b60013d,0xb6580085,0x00000000}},	//   _мэта, ságí, ашых_,
  { {0x29f800c3,0x973c007d,0xdce80022,0x00000000}},	//   nčal_, _raće, śląs,
  { {0xdce601f7,0x7c250025,0x95c8018e,0x00000000}},	//   _yakı, omhr, руја_,
  { {0x3cff0161,0xe2990001,0xa3e10053,0x00000000}},	//   _रखने_, гао_, नों_,
  { {0x11d60032,0x644918d1,0x7c250025,0x00000000}},	//   متحد, spei, imhr,
  { {0x9f51000f,0x644918d2,0x395d002b,0x00000000}},	//   kozó_, ppei, naws_,
  { {0xc884005b,0xd4690184,0x7f5c0b6d,0x00000000}},	//   cağı_, _силе_, tarq,
  { {0xd91a0047,0x7dca0026,0xa01b0072,0x00000000}},	//   טורל, _lýst, ttöa,
  { {0x6fd000c7,0x7f5c0e57,0xdce60058,0x00000000}},	//   _häck, rarq, _rakı,
  { {0x6e2400a4,0x660918d3,0x25bf18d4,0x00000000}},	//   umib, noek, njul_,
  { {0x2b5800ea,0x6e2400ea,0x5b36009e,0x00000000}},	// [2320] _perc_, rmib, معار,
  { {0x660900e8,0x2f56018b,0x83fd00ea,0x00000000}},	//   hoek, _утис, lsőb,
  { {0x4e1a006a,0x7dd80026,0x6fd00137,0x00000000}},	//   _متحد_, _vísb, _läck,
  { {0x60120014,0x200a18d5,0xc8840058,0x00000000}},	//   dæmi, lobi_, yağı_,
  { {0xc7c60432,0xdce6005b,0x660900ca,0x00000000}},	//   йски, _takı, doek,
  { {0x9ad6000d,0xdb1c00be,0x7dca0195,0x00000000}},	//   _любі, _corã, _výsu,
  { {0xe0df051e,0x91fd008f,0x8f9b0063,0x00000000}},	//   zzò_, nsāc, ריצי,
  { {0xd6d90086,0xc884005b,0x6fd018d6,0x00000000}},	//   шті_, tağı_, _bäck,
  { {0xdb1c0268,0x200a18d7,0x288b0043,0x00000000}},	//   _horà, kobi_, _مصلی_,
  { {0x764a00cf,0x6fd00137,0x91fd008f,0x00000000}},	//   ppfy, _däck, ksāc,
  { {0x200a00c3,0x51f90086,0x9f5800ea,0x00000000}},	//   dobi_, иною_, ború_,
  { {0x38600130,0xe45a0054,0xe57900a3,0x00000000}},	//   širu_, _бжд_, ghŷd_,
  { {0xe3af007e,0x200a1310,0x91fd008f,0x00000000}},	//   ذری_, fobi_, drāt,
  { {0xe0df01f4,0xe47b009a,0x44f3014b,0x00000000}},	//   rzò_, _ערוכ, _эпіс,
  { {0x6fd000bd,0xe2460067,0x200f0078,0x00000000}},	//   _mäch, _اختي, _ūgis_,
  { {0x6fd0004d,0x9f5100ea,0x8e150454,0x00000000}},	//   _läch, tozó_, ідац,
  { {0x91a9001b,0xf1f8006a,0x320b0051,0x00000000}},	// [2330] _giá_, _دعوت_, mocy_,
  { {0x660902b0,0x6fd000bd,0x44d4008b,0x00000000}},	//   zoek, _näch, ì_,
  { {0x6fb5006a,0x3ce0007d,0xcb1b0002,0x00000000}},	//   _همکا, aziv_, уќа_,
  { {0x7dd10146,0x61ef18d8,0x60120026,0x00000000}},	//   _måsk, nicl, væmi,
  { {0x89340032,0x7dca0114,0x229a001c,0x00000000}},	//   أعما, _výst, _lūk_,
  { {0x6fd000c7,0x29f8085a,0x61ef18d9,0x00000000}},	//   _räck, nčaj_, hicl,
  { {0x9f580024,0xa01b18da,0x2ca918db,0x00000000}},	//   torú_, ytön, lvad_,
  { {0xe6190079,0x59f90076,0x3ebe00fe,0x00000000}},	//   јди_, _тебя_, ätti_,
  { {0x44390016,0x660918dc,0x6fd0004d,0x00000000}},	//   ês_, roek, _fäch,
  { {0x6609021f,0x6498011c,0xdb1c18dd,0x00000000}},	//   soek, стър_, _horá,
  { {0xdb1c000f,0x44d4001b,0x2ca9004b,0x00000000}},	//   _korá, à_, hvad_,
  { {0x6fd000c7,0x29f800a8,0x412a02f8,0x00000000}},	//   _täck, ečaj_, ионо_,
  { {0x349415ba,0xa01b18de,0xdb1c18df,0x00000000}},	//   _нацр, rtön, _morá,
  { {0x34b2006a,0x232918e0,0x8c42005b,0x00000000}},	//   _آموز, _коли_, üğme,
  { {0x443f0164,0xa01b0026,0x200a18e1,0x00000000}},	//   lqu_, mtöl, robi_,
  { {0xa01b000f,0x61ef18e2,0x63a318e3,0x00000000}},	//   ltöl, cicl, _hann,
  { {0x7dd80080,0x443f18e4,0x2f2318e5,0x00000000}},	// [2340] _císa, nqu_, tégé_,
  { {0x443f18e6,0xab660086,0xa01b1471,0x00000000}},	//   iqu_, івел, ntöl,
  { {0x2ca90019,0x5fb70063,0x3f9818e7,0x00000000}},	//   avad_, _והיא_, meru_,
  { {0x9f990026,0x63a318e8,0xdb1c006d,0x00000000}},	//   láðu_, _lann, _corá,
  { {0x91a0001b,0x26ce002b,0xdced008f,0x00000000}},	//   _chỉ_, wyfo_, reaģ,
  { {0x6d44051e,0x3cff0053,0x6fcb005b,0x00000000}},	//   lcia, _रखते_, _hücr,
  { {0xdb1c0331,0x6d4418e9,0xfa6718ea,0x00000000}},	//   _forá, ocia, _марк_,
  { {0x39420004,0x7bc70122,0x63a30250,0x00000000}},	//   _üks_, _zoju, _aann,
  { {0x224900c3,0xa01b0014,0x44d40013,0x00000000}},	//   _čaka_, ftöl, ù_,
  { {0x657b002c,0x69c204c6,0x7dd118eb,0x00000000}},	//   aguh, ljoe, _påsk,
  { {0x764800d1,0x61ef02a0,0x63a318ec,0x00000000}},	//   _utdy, ticl, _dann,
  { {0xa01b00fe,0x63a30025,0x51f8007f,0x00000000}},	//   ttöo, _eann, жнюю_,
  { {0x85f90047,0x2d8700ea,0x44f6007e,0x00000000}},	//   _פּעק, őnek_, _بساز,
  { {0x63a3035a,0x80270021,0xa3ce0042,0x00000000}},	//   _gann, ترجم, _रवि_,
  { {0xbcfb0016,0xfeb8006a,0x9f340086,0x00000000}},	//   _idéi, يافت_, дері,
  { {0x65600025,0x7dd801d9,0x7bca0026,0x00000000}},	//   namh, _písa, öfun,
  { {0xad9b0024,0x61ed017f,0x65600035,0x00000000}},	// [2350] _skús, _imal, iamh,
  { {0xdb1c00ea,0x7dd80026,0x2ca918ed,0x00000000}},	//   _sorá, _vísa, rvad_,
  { {0x61ed00c3,0x2ca9004b,0xdb1c0061,0x00000000}},	//   _kmal, svad_, _porá,
  { {0x6d4402f6,0xfe9a00b5,0xf1bf18ee,0x00000000}},	//   ccia, _פירמ, zmán_,
  { {0x6d5d003d,0xa01b0072,0x6aae004d,0x00000000}},	//   _iesa, ytöl, _erbf,
  { {0x6d5d04ab,0x65600025,0xb6590076,0x00000000}},	//   _hesa, eamh, бших_,
  { {0x69c200e8,0xba74006a,0x6d5d014f,0x00000000}},	//   bjoe, _يافت, _kesa,
  { {0xfb340088,0x9f4300fe,0xe7080021,0x00000000}},	//   _інтэ, lijä_, غتون_,
  { {0xa01b00fe,0x6d5d18ef,0x3f980089,0x00000000}},	//   ttöl, _mesa, yeru_,
  { {0x61ed18f0,0x7c3d0150,0x33d40054,0x00000000}},	//   _amal, _musr, діют,
  { {0x443f03b2,0xa01b0026,0x63a318f1,0x00000000}},	//   squ_, rtöl, _vann,
  { {0x63a30102,0xdb1c0146,0x6d5d18f2,0x00000000}},	//   _wann, _foræ, _nesa,
  { {0x63a318f3,0xe20b0026,0xddce00c2,0x00000000}},	//   _tann, _slóð_, jubš,
  { {0xf8a504de,0x69db0857,0xa01b0072,0x00000000}},	//   _یک_, _llue, ltöj,
  { {0x6d5d014f,0x7c3d00bd,0x9f99007a,0x00000000}},	//   _besa, _ausr, ráðu_,
  { {0xa01b00fe,0x60120026,0xf1bf0014,0x00000000}},	//   ntöj, væmu, nmál_,
  { {0x6d5d18f4,0xdd8f0021,0x6d4418f5,0x00000000}},	// [2360] _desa, طول_, rcia,
  { {0x6d44051e,0x69db024a,0xac830085,0x00000000}},	//   scia, _alue, эгул,
  { {0x6d4405ab,0xcf570063,0xdce80058,0x00000000}},	//   pcia, _מבית_, ğlıs,
  { {0x6d5d18f6,0xb23a00b5,0x79a30b3f,0x00000000}},	//   _gesa, צענז, ерше,
  { {0x2d8200c7,0x27ec0150,0x9f4a01a8,0x00000000}},	//   _icke_, _pmdn_, hibí_,
  { {0x69c212f9,0x569418f7,0x69db18f8,0x00000000}},	//   sjoe, дакт, _elue,
  { {0x644b0078,0x91fd008f,0x69db18f9,0x00000000}},	//   _atgi, krāp, _flue,
  { {0x75e6000d,0x7c3d0052,0x44b402d8,0x00000000}},	//   яўле, _yusr, дбис,
  { {0xdb1c005b,0x65600014,0x9f940072,0x00000000}},	//   _borç, ramh, _kää_,
  { {0xa01b00fe,0x656018fa,0x443d001f,0x00000000}},	//   ttöm, samh, _duw_,
  { {0x394605d5,0x656000a4,0x386618fb,0x00000000}},	//   ocos_, pamh, lsor_,
  { {0x394618fc,0x1a9b0047,0xd49a0141,0x00000000}},	//   ncos_, זיטע, _грк_,
  { {0xdb1c18fd,0x386618fe,0x7dd80080,0x00000000}},	//   _forç, nsor_, _písn,
  { {0x925704de,0x7a230019,0x6d5d0da3,0x00000000}},	//   _کشور_, mõte, _sesa,
  { {0x6d5d18ff,0x7c3d1900,0xb17b00b9,0x00000000}},	//   _pesa, _susr, rhåb,
  { {0x42fb014e,0x61ed1901,0x7c3d0078,0x00000000}},	//   _להוס, _umal, _pusr,
  { {0x6d5d13c7,0xc882003b,0x4c941902,0x00000000}},	// [2370] _vesa, nuşă_, нитс,
  { {0x3946006d,0x69db00ac,0x2d82004d,0x00000000}},	//   ecos_, _slue, _ecke_,
  { {0xdb580076,0x69da0006,0xdd0c0051,0x00000000}},	//   яют_, _įter, góło,
  { {0x61fd007a,0xa5bd0078,0xc3330063,0x00000000}},	//   nnsl, amųj, גוע_,
  { {0xe73906da,0x78a60066,0x271c0013,0x00000000}},	//   оел_, _škvr, _ản_,
  { {0x27c70076,0x443d006f,0x945d0051,0x00000000}},	//   ящег, _ruw_, zyńs,
  { {0x56920d34,0x25a60139,0x64460014,0x00000000}},	//   вајт, _baol_, íkin,
  { {0x25a60025,0x39461903,0xcb340062,0x00000000}},	//   _caol_, ccos_, _чесъ,
  { {0xdb1c017d,0xa01b0014,0xf1bf1904,0x00000000}},	//   _porç, gtök, rmál_,
  { {0xa3e90636,0xa01b0072,0x395f01a8,0x00000000}},	//   ідна_, stöj, _heus_,
  { {0x395f006f,0xf3f10013,0xfc3f0139,0x00000000}},	//   _keus_, rị_, _luí_,
  { {0x25a60d12,0xa01b0072,0x6721007d,0x00000000}},	//   _gaol_, ltöh, _izlj,
  { {0x644b02f0,0x395f0bc8,0x55ac0047,0x00000000}},	//   _utgi, _meus_, _ליאַ,
  { {0x7dd80024,0x61fd1905,0xe8200053,0x00000000}},	//   _píso, ansl, यतया_,
  { {0x39461906,0x43920141,0x7413005d,0x00000000}},	//   ycos_, _рајс, _قوچا,
  { {0xe1f2007e,0x2613017d,0x395f1907,0x00000000}},	//   _جست_, mãos_, _neus_,
  { {0x39a60812,0xfc3f0025,0x9f9400fe,0x00000000}},	// [2380] _jūsų_, _cuí_, _pää_,
  { {0x39a600eb,0xafdb0dfb,0x3ebe0137,0x00000000}},	//   _mūsų_, spør, ätts_,
  { {0xa5bd0078,0xbad5000d,0x9f9401cf,0x00000000}},	//   rmųj, ніцы, _vää_,
  { {0xa01b0072,0x3866013d,0x39460023,0x00000000}},	//   ytök, tsor_, ucos_,
  { {0x395f1908,0x39461909,0x9f940072,0x00000000}},	//   _deus_, rcos_, _tää_,
  { {0x77630268,0x7a230019,0x25a60025,0x00000000}},	//   ganx, võte, _saol_,
  { {0x61fd0026,0xa3b10053,0x395f01a8,0x00000000}},	//   ynsl, _ऑफ़_, _feus_,
  { {0x26130016,0x2d80190a,0xa01b190b,0x00000000}},	//   dãos_, ngie_, ttök,
  { {0xd49a0086,0xd4060505,0x211d0042,0x00000000}},	//   іри_, дяни, _नरेश_,
  { {0x9f580024,0x628800df,0x2613017d,0x00000000}},	//   torý_, ttdo, fãos_,
  { {0x26130016,0xdb1c0205,0xa01b190c,0x00000000}},	//   gãos_, _forå, stök,
  { {0x22ac004c,0x62880934,0xa01b0014,0x00000000}},	//   _věk_, rtdo, ptök,
  { {0x7dd101e3,0x9f580331,0x6288114f,0x00000000}},	//   _måst, joró_, stdo,
  { {0x7dd108a9,0x251b009a,0xd6e2056c,0x00000000}},	//   _låst, _וודא, pułą_,
  { {0x2ca0001f,0xfc3f0139,0xa01b0072,0x00000000}},	//   ewid_, _suí_, ntöi,
  { {0x442c006f,0x2d800caf,0x644f0139,0x00000000}},	//   lmd_, ggie_, ícig,
  { {0x395f190d,0xfc3f190e,0x442c00ca,0x00000000}},	// [2390] _reus_, _quí_, omd_,
  { {0x395f13ff,0xd83814d5,0x1b7b0044,0x00000000}},	//   _seus_, _nič_, تصرة_,
  { {0xe1ff006d,0x395f00cd,0x442c006f,0x00000000}},	//   onó_, _peus_, imd_,
  { {0x3ebe0031,0x2011017f,0x9f58006d,0x00000000}},	//   åtte_, lozi_, boró_,
  { {0x7b67184a,0x6e2d190f,0x395f00cd,0x00000000}},	//   _отве, mmab, _veus_,
  { {0x7b74007e,0x907c0047,0x39520058,0x00000000}},	//   _لطفا, קטוי, ıysa_,
  { {0x395f14b1,0xe7361910,0xe80e0042,0x00000000}},	//   _teus_, неш_, ाक़ा_,
  { {0x442c016d,0x38c30078,0xdcef0058,0x00000000}},	//   emd_, tūrą_, _hacı,
  { {0x66021911,0x601200b9,0x91fd008f,0x00000000}},	//   _djok, kæmp, rsāl,
  { {0x69d90104,0xa9230078,0x57270043,0x00000000}},	//   lkwe, įžda, _قراق,
  { {0xd24e006a,0x7dd81912,0xd6d10021,0x00000000}},	//   ینی_, _sísm, _حقا_,
  { {0xe1ff006d,0x7dd80240,0x442c006f,0x00000000}},	//   gnó_, _písm, amd_,
  { {0x764100a4,0xa3d50ac5,0xea00008b,0x00000000}},	//   _huly, _подч, hiết_,
  { {0x2011051e,0x661b0659,0x4033000d,0x00000000}},	//   gozi_, lluk, леўс,
  { {0x44270199,0x9f4a00cd,0x76410089,0x00000000}},	//   _ihn_, ribà_, _july,
  { {0x764100f3,0x45b500b5,0xb17b00d1,0x00000000}},	//   _muly, עפּל_, lhån,
  { {0x91fd003d,0x921700b5,0x0c260ae8,0x00000000}},	// [23a0] ksāj, _אַזױ_, еман,
  { {0xfc3f0027,0x4427004d,0x69d91913,0x00000000}},	//   _arís_, _jhn_, ekwe,
  { {0x2f5b0132,0x9f580290,0xdb1c0066,0x00000000}},	//   _מדינ, borò_, _horú,
  { {0x6a16007e,0x69d900a4,0xdb1c0066,0x00000000}},	//   ربار, gkwe, _korú,
  { {0x661b0388,0x442c1914,0x6d3b0063,0x00000000}},	//   dluk, ymd_, _מתכנ,
  { {0x660200d1,0xfb56007e,0x998d0066,0x00000000}},	//   _sjok, _سپرد, _vieš_,
  { {0x09e60086,0x69961915,0x661b1916,0x00000000}},	//   _зовн, _прах, fluk,
  { {0x7bce0019,0x7641002b,0x69d91917,0x00000000}},	//   _hobu, _duly, ckwe,
  { {0xa01b0cb0,0x44980054,0xb4da0042,0x00000000}},	//   stöi, євою_, ठने_,
  { {0x443801e3,0xa01b00fe,0xb8d40053,0x00000000}},	//   ör_, ltöv, जट_,
  { {0x45e400aa,0x442c1918,0x79820051,0x00000000}},	//   _đượ, rmd_, ogow,
  { {0x79820051,0xdb0e0137,0x04460002,0x00000000}},	//   ngow, _inbä, _зедн,
  { {0x9f580290,0xe1ff1919,0xd5e90021,0x00000000}},	//   vorò_, rnó_, _تعلن_,
  { {0x29f80024,0x644f03ea,0x6d43004c,0x00000000}},	//   očas_, ície, ěnam,
  { {0x6e940612,0xce940062,0x2004191a,0x00000000}},	//   лиру, ларъ, émia_,
  { {0x63aa007a,0x6e2d00a4,0xfc3f0014,0x00000000}},	//   _hafn, umab, _asía_,
  { {0x7dd8191b,0x6e2d191c,0x4427004d,0x00000000}},	// [23b0] _získ, rmab, _yhn_,
  { {0x63aa007a,0x64420290,0xfbd3007e,0x00000000}},	//   _jafn, _muoi, دتر_,
  { {0xa036014e,0x9f8f004b,0x29d70058,0x00000000}},	//   _שאתה_, _müü_, _uçak_,
  { {0x9f58007a,0xdb0e017d,0x91a00013,0x00000000}},	//   lorð_, _robô, _khí_,
  { {0x99140086,0x69d9191d,0x76410078,0x00000000}},	//   льші, rkwe, _suly,
  { {0x63aa007a,0x62980162,0x36950071,0x00000000}},	//   _nafn, _opvo, вшис,
  { {0xd7050062,0x67d20002,0x35a50085,0x00000000}},	//   ъзки, роју, вайг,
  { {0xceb411b4,0xa8490021,0xf9930049,0x00000000}},	//   ריק_, _يلزم_, _حبس_,
  { {0x661b191e,0x7dd80025,0x64420290,0x00000000}},	//   rluk, _dísh, _cuoi,
  { {0x91aa0053,0x7dd8004c,0x6724004c,0x00000000}},	//   _जोड़े, _písk, řija,
  { {0xd6db0055,0xb17b191f,0x386d1920,0x00000000}},	//   _эта_, rhån, _hver_,
  { {0x9998001c,0xb17b0093,0xdb1c0066,0x00000000}},	//   _kurš_, shån, _porú,
  { {0x91a0008b,0xb17b0137,0xd1320021,0x00000000}},	//   _chí_, mhål, شمس_,
  { {0xb4bf016a,0xa0a3018e,0x25ad000e,0x00000000}},	//   ीही_, јард, ldel_,
  { {0x91a0008b,0x25ad1921,0x7bce1014,0x00000000}},	//   _thì_, odel_, _robu,
  { {0xbcfb0003,0x386d1922,0xb17b0137,0x00000000}},	//   _adéq, _over_, nhål,
  { {0x9f580026,0xe7f20053,0x600a005e,0x00000000}},	// [23c0] borð_, _अगला_, _оним_,
  { {0x248d0f2f,0xeafa0593,0x80890044,0x00000000}},	//   item_, ورات_, _أضيف_,
  { {0x386d02f6,0x6f790047,0xaf770047,0x00000000}},	//   _aver_, _אָרג, _בעיס_,
  { {0xe9da0086,0xe8fa0076,0xc332089e,0x00000000}},	//   ьке_, мле_, בוב_,
  { {0x7bce0006,0x25ad1923,0x88e60062,0x00000000}},	//   _tobu, ddel_, ъжде,
  { {0x248d040d,0xa01b1924,0xb17b0137,0x00000000}},	//   dtem_, stöv, ehål,
  { {0x386d0034,0x7c3c0072,0x39840043,0x00000000}},	//   _ever_, _iirr, _میاف,
  { {0x63aa0026,0xdbe30003,0xa01b1925,0x00000000}},	//   _safn, _réél, ltöt,
  { {0x64420164,0x9987000c,0x248d004d,0x00000000}},	//   _quoi, ţiţi_, gtem_,
  { {0x3202034d,0x660d0599,0xa85703c3,0x00000000}},	//   enky_, čaka, _סיבה_,
  { {0x5b7b0063,0x51f901dd,0x7c3c1926,0x00000000}},	//   וריא, енню_, _mirr,
  { {0x91a0001b,0x91a9001b,0xcb130132,0x00000000}},	//   _phí_, _khả_, ילת_,
  { {0x248d03ea,0x7cda008f,0x9f8f0058,0x00000000}},	//   ctem_, _jārā, _tüü_,
  { {0xdb1c0d02,0x2005004b,0x320201d1,0x00000000}},	//   _forø, õli_, anky_,
  { {0x9f580ac6,0x9294000d,0xdef4000d,0x00000000}},	//   rorð_, _сайц, апры,
  { {0x3253011c,0x22510066,0x443c1927,0x00000000}},	//   _твър, ízke_, _hiv_,
  { {0x7c3c1928,0xbddb18e6,0xcfab0044,0x00000000}},	// [23d0] _birr, _lièg, _قادم_,
  { {0x7c84018e,0xcb54005e,0x9c190021,0x00000000}},	//   јуте, ивућ, رياء_,
  { {0x443c00e8,0x0b880062,0x248d1929,0x00000000}},	//   _miv_, ъсти_, ztem_,
  { {0x443c06a3,0xaa58005e,0xe2930047,0x00000000}},	//   _liv_, тицу_, יװע_,
  { {0x248d0080,0x75fe008f,0x20030130,0x00000000}},	//   xtem_, cīzi, onji_,
  { {0x6e3d192a,0x77840054,0x8c440058,0x00000000}},	//   _hisb, иліз, üşer,
  { {0xa01b00fe,0x2f980063,0xb17b0137,0x00000000}},	//   ltös, דכון_, thål,
  { {0x06960032,0x26c9017f,0x248d1929,0x00000000}},	//   انية_, ćao_, ttem_,
  { {0xb17b00c7,0x248d192b,0xdced007d,0x00000000}},	//   rhål, utem_, ogađ,
  { {0x7dd80026,0xb17b0137,0x6e3d192c,0x00000000}},	//   _vísi, shål, _lisb,
  { {0x2003065f,0x17f80021,0xf6550002,0x00000000}},	//   dnji_, _شركة_, _свеќ,
  { {0x248d192d,0x6e3d192e,0x64b50049,0x00000000}},	//   ptem_, _nisb, _محتر,
  { {0x69cb006f,0x2004017d,0xe3ae005e,0x00000000}},	//   ijge, émio_, _лб_,
  { {0x443c18a4,0x75fe001c,0x93bc003b,0x00000000}},	//   _giv_, vīzi, umăt,
  { {0x6e3d0268,0xf3f00032,0x93bc000c,0x00000000}},	//   _bisb, _بأن_, rmăt,
  { {0x62811360,0x2003192f,0x65690656,0x00000000}},	//   mulo, anji_, naeh,
  { {0x6e3d1930,0x6b560086,0x61e41931,0x00000000}},	// [23e0] _disb, гтех, _ilil,
  { {0xa01b004d,0xfc3f0139,0x62811932,0x00000000}},	//   eröf, _tsín_, oulo,
  { {0x61e40da5,0xdce40078,0x4a9a000d,0x00000000}},	//   _klil, maič, этаў_,
  { {0x7cda003d,0x8e7b0047,0x7c3c03a7,0x00000000}},	//   _pārā, _אנטה, _wirr,
  { {0xbddb0164,0xd9170304,0x24491933,0x00000000}},	//   _sièg, льш_, _núm_,
  { {0xf1bf00ea,0x62811934,0xbddb0003,0x00000000}},	//   lmát_, kulo, _pièg,
  { {0x1ae60076,0x998d0024,0x61f60114,0x00000000}},	//   _совм, _sieť_, _omyl,
  { {0xa01b00c7,0x7bde00c7,0x91a9008b,0x00000000}},	//   ntör, lkpu, _thả_,
  { {0xd910006a,0xdce41935,0x69c01936,0x00000000}},	//   _بیش_, kaič, _inme,
  { {0x644f1937,0x27f8005b,0x61e41938,0x00000000}},	//   ícia, _örn_, _alil,
  { {0x2c170047,0xa01b04b3,0x92940085,0x00000000}},	//   רקיש_, ktör, шанц,
  { {0xa01b024a,0xe1350076,0x15461939,0x00000000}},	//   ytös, инны, _седм,
  { {0x2003007d,0x6e3d00c2,0x63a1193a,0x00000000}},	//   tnji_, _risb, beln,
  { {0x7d1d00c7,0x6281193b,0x3cff0078,0x00000000}},	//   _ryss, bulo, _žuvo_,
  { {0x9f35019d,0x62811174,0x539b0063,0x00000000}},	//   реві, culo, _ניהו,
  { {0xa01b193c,0x5d55193d,0xddd500ea,0x00000000}},	//   gtör, ркат, tsző,
  { {0x20031253,0x8f55007e,0x6e3d193e,0x00000000}},	// [23f0] pnji_, _پنجش, _visb,
  { {0x9f4b00fe,0x2ef50121,0xb17b0137,0x00000000}},	//   äjät_, _взор, skåd,
  { {0xa01b00fe,0xddd500ea,0x61e40072,0x00000000}},	//   stös, ssző, _ylil,
  { {0x7bde00ac,0x316b0051,0x78a9085a,0x00000000}},	//   akpu, nacz_, _psev,
  { {0xad9b0026,0x42380047,0xa9680021,0x00000000}},	//   _ljúk, אנאל_, امهم_,
  { {0x69c00331,0x3858007e,0x2d840058,0x00000000}},	//   _enme, اشند_, _ömer_,
  { {0x65c50076,0x0f580063,0xbddb0003,0x00000000}},	//   ибка, ניהם_, _tièd,
  { {0x660d00c3,0x9f410024,0x0495000d,0x00000000}},	//   čako, _dlhé_, ароў,
  { {0x3a3f00a4,0x63a1193f,0xa78701fb,0x00000000}},	//   _iiup_, teln, _مشاو,
  { {0xb909016a,0x62811940,0x9cd8009a,0x00000000}},	//   मन_, tulo, טוחה_,
  { {0x21290089,0xdce40078,0xa2060363,0x00000000}},	//   _azah_, vaič, ипод,
  { {0xdb070080,0x93bc000c,0xb4950001,0x00000000}},	//   _nají, umăr, _видљ,
  { {0x7dd80080,0x7a230004,0x3d040161,0x00000000}},	//   _míst, võtl, _रखें_,
  { {0xdff5000d,0x25af1941,0x30750121,0x00000000}},	//   бясь, _hagl_, щуюс,
  { {0x316b0045,0xb7f80053,0xa01b1942,0x00000000}},	//   bacz_, ्चतम_, ttör,
  { {0x61e40035,0x9046005d,0x00000000,0x00000000}},	//   _ulil, _پنده,   ,

  { {0xdb0500b9,0xf1bf1092,0x75fe008f,0x00000000}},	// [2400] ndhæ, amás_, cīzu,
  { {0x8b260088,0xa01b1943,0x3ff30044,0x00000000}},	//   адзе, stör, _وكير,
  { {0xa01b0b35,0x20181944,0x2367013d,0x00000000}},	//   ptör, mori_, _menj_,
  { {0x20181945,0xf2960047,0x82960047,0x00000000}},	//   lori_, יכער_, ידעס_,
  { {0xc7c600d7,0x9f511946,0xaf36007e,0x00000000}},	//   иски, lizá_, _حرکت,
  { {0xdb070080,0x22400019,0x6aba013d,0x00000000}},	//   _zají, _liik_, _átfo,
  { {0xb765019d,0xa5f803ec,0xdb0500b9,0x00000000}},	//   стій, леку_, edhæ,
  { {0x2018001f,0xd5b709d2,0xba5700ff,0x00000000}},	//   hori_, ась_, _כסלו_,
  { {0xa4f8007e,0xad9b0026,0xe4e60054,0x00000000}},	//   دکار_, _sjúk, рійн,
  { {0x47aa0021,0x224700e5,0xe3b80058,0x00000000}},	//   _جارٍ_, _bunk_, alın_,
  { {0x91fd003d,0x20181947,0x0bb70063,0x00000000}},	//   ksāt, dori_, בלים_,
  { {0x7dd804a5,0x2251017c,0xd49a1948,0x00000000}},	//   _míss, ízka_, _арк_,
  { {0x764800a4,0xf9930063,0x20181949,0x00000000}},	//   _hudy, חרר_, fori_,
  { {0x7a230004,0xb7f80053,0x75fe008f,0x00000000}},	//   võtm, ्चिम_, rīzu,
  { {0x6235026b,0xbddb0003,0xdb1c194a,0x00000000}},	//   _леку, _nièc, _moró,
  { {0xaac7006a,0x5d780076,0xfe79004c,0x00000000}},	//   یتان, ийся_, čů_,
  { {0x40950021,0x2018194b,0x7dd80066,0x00000000}},	// [2410] _الخر, bori_, _ríst,
  { {0x61fd17f6,0x5ba7007b,0xdd2f004c,0x00000000}},	//   lisl, јраз, _těžc,
  { {0x2ac7005e,0x4ea70002,0xeb48071f,0x00000000}},	//   шљав, _трпа, рчук_,
  { {0x12f90047,0x29d70058,0x7bca0014,0x00000000}},	//   נהײב, _açar_, öfur,
  { {0xa8a70076,0x7dd81795,0x76480022,0x00000000}},	//   ррек, _víst, _audy,
  { {0x387d001f,0x9f580153,0x7648194c,0x00000000}},	//   rrwr_, tiré_, _budy,
  { {0x2ca9001f,0x61fd194d,0x3f7a0041,0x00000000}},	//   lwad_, kisl, אָפע,
  { {0x644f194e,0x61fd194f,0x2a640062,0x00000000}},	//   ício, jisl, _фърг,
  { {0x22400019,0x2ca9001f,0x224700e5,0x00000000}},	//   _riik_, nwad_, _sunk_,
  { {0x61fd0150,0x91fd001c,0x9f580003,0x00000000}},	//   eisl, ksās, piré_,
  { {0x7a230004,0x201804cc,0xdb1c01a8,0x00000000}},	//   võtj, vori_, _horò,
  { {0x515a000d,0x61fd1950,0x78bb1951,0x00000000}},	//   ышоў_, gisl, _kruv,
  { {0x201814b9,0x63c20080,0xa01b0072,0x00000000}},	//   tori_, ávní, ttöp,
  { {0x90d50088,0x20181952,0xe8df008b,0x00000000}},	//   іцяч, uori_, _ngọn_,
  { {0x20181386,0xdee301f6,0x799b0022,0x00000000}},	//   rori_, пори, _obuw,
  { {0xdb1c00bd,0x93bc000c,0x229100ea,0x00000000}},	//   _vorü, plăc, mák_,
  { {0xbddb03b2,0x7bd5005b,0xac0a0002,0x00000000}},	// [2420] _sièc, _bozu, гнаа_,
  { {0xbddb0164,0x6faa0001,0xdb0e006d,0x00000000}},	//   _pièc, _свог_, _habé,
  { {0xfe7201a7,0x3f980093,0x1c390499,0x00000000}},	//   _عدد_, mfru_, рять_,
  { {0xed5a005a,0xb635014b,0xda650044,0x00000000}},	//   _щом_, _кнiз, تاكي,
  { {0xdb1c0051,0xcdb70063,0xd7fa1953,0x00000000}},	//   _poró, _הפכה_, лук_,
  { {0x229100ea,0x78bb0137,0xa09b009f,0x00000000}},	//   kák_, _druv, ריסט,
  { {0x645b0164,0x22911954,0x1be70141,0x00000000}},	//   epui, ják_, _удри_,
  { {0x3ebe00fe,0x442e0865,0xfbc90053,0x00000000}},	//   ätty_, _shf_, राथम,
  { {0x92a80051,0x78bb00df,0x61fd004a,0x00000000}},	//   _małż, _gruv, visl,
  { {0x61fd0185,0x03f80001,0x13f40086,0x00000000}},	//   wisl, рној_, ізня,
  { {0xdb9b0e2a,0x17570063,0x61fd1955,0x00000000}},	//   נסטר, _הסבר_, tisl,
  { {0xd46a0079,0x60dd00fe,0x9293000d,0x00000000}},	//   _биде_, tysm, чаюц,
  { {0x682d0024,0x61fd1956,0x6e24004d,0x00000000}},	//   súde, risl, dlib,
  { {0x6d4600a4,0x6e241957,0x22911958,0x00000000}},	//   _agka, elib, bák_,
  { {0x6397014e,0xdd9b005a,0x7bd51959,0x00000000}},	//   _הדוא_, лша_, _rozu,
  { {0xbcfb00ea,0x7bd5004d,0x2ca900a3,0x00000000}},	//   _idéz, _sozu, twad_,
  { {0xe1ff006d,0x8bd5195a,0x83fd013d,0x00000000}},	// [2430] mió_, ожац, csős,
  { {0xe1ff195b,0x6e24195c,0xdb1c0331,0x00000000}},	//   lió_, alib, _enrí,
  { {0x9f35071f,0xe7c70042,0x539b009a,0x00000000}},	//   _фені, लासप, ריבו,
  { {0x3ebe0146,0xddab01e8,0xe1ff195d,0x00000000}},	//   ætte_, _стол_, nió_,
  { {0x2291195e,0x2bc90082,0x00000000,0x00000000}},	//   zák_, रादा,   ,
  { {0x67d202d8,0xe787195f,0x2bcb0a3a,0x00000000}},	//   дољу, судо, _сумо_,
  { {0x998501fb,0x20040124,0xad27005d,0x00000000}},	//   _ولسو, émii_, _خرگو,
  { {0x91a9001b,0x8af80062,0x7a2a0066,0x00000000}},	//   _nhà_, _унсс_, pýta,
  { {0xe1ff1960,0xb4e30053,0xa5090852,0x00000000}},	//   dió_, नने_, репа_,
  { {0x229100ea,0xe2910021,0xdb0e0331,0x00000000}},	//   ták_, وذج_, _sabé,
  { {0xd1ca0138,0xd5ae007e,0xdb15004d,0x00000000}},	//   алне_, رفی_, _unzä,
  { {0xe1ff1961,0x36340021,0x798b00a4,0x00000000}},	//   gió_, _فرنس, nggw,
  { {0x661b1962,0x6609004b,0x20d6000d,0x00000000}},	//   mouk, mnek, цінс,
  { {0x3eb8007c,0xb143046e,0x661b1963,0x00000000}},	//   tvrt_, ьнял, louk,
  { {0x7f430b0f,0xe1ff0521,0x66091964,0x00000000}},	//   держ, bió_, onek,
  { {0xe1ff1965,0x644300bb,0x644b0035,0x00000000}},	//   ció_, _hini, _kugi,
  { {0x656b000f,0x6e24053b,0x64431966,0x00000000}},	// [2440] _megh, rlib, _kini,
  { {0xdb07000f,0x9f580027,0x62811967,0x00000000}},	//   _sajá, oirí_, orlo,
  { {0x9d461968,0x9f510331,0x661b1969,0x00000000}},	//   _менд, anzó_, kouk,
  { {0x18a60086,0x661b00fe,0x6281006d,0x00000000}},	//   жадм, jouk, irlo,
  { {0x644b1848,0x9c870066,0x6281004d,0x00000000}},	//   _nugi, rečí, hrlo,
  { {0xdb1c0026,0x6443196a,0x6609196b,0x00000000}},	//   _forð, _nini, enek,
  { {0x644b0006,0xdb070014,0x98a30078,0x00000000}},	//   _augi, _snjö, _ąją_,
  { {0xe1ff0268,0x3633007e,0x4425196c,0x00000000}},	//   xió_, وريس, ell_,
  { {0x644300bb,0xe1ff02dd,0x644b0290,0x00000000}},	//   _bini, vió_, _cugi,
  { {0xa2f40086,0x644b007d,0x6443196d,0x00000000}},	//   зпоч, _dugi, _cini,
  { {0xe1ff02dd,0xe3b8005b,0x64430b95,0x00000000}},	//   tió_, llık_, _dini,
  { {0x644307c7,0x4425057a,0x644b196e,0x00000000}},	//   _eini, all_, _fugi,
  { {0xe1ff02dd,0xe3b8005b,0x6281196f,0x00000000}},	//   rió_, nlık_, arlo,
  { {0xe1ff0994,0xbddb0268,0xd2500032,0x00000000}},	//   sió_, _cièn, _كنت_,
  { {0x3a26085a,0x2ee50026,0x7a311310,0x00000000}},	//   klop_, álf_, låte,
  { {0xc3390080,0x62881970,0x2d8f00bd,0x00000000}},	//   čítá, mudo, üge_,
  { {0x7dd8006d,0x5ce70086,0x61ef0025,0x00000000}},	// [2450] _vísp, цюва, mhcl,
  { {0xbc680021,0x93bc003b,0x60c001e1,0x00000000}},	//   تمكن_, zlăn, æmme,
  { {0x62881971,0x66000022,0x7a2a0046,0x00000000}},	//   nudo, kimk, rýtn,
  { {0x66000080,0xda7801dd,0xe3b80058,0x00000000}},	//   jimk, іях_, flık_,
  { {0x998d0024,0x44251972,0x7d2501fb,0x00000000}},	//   _tiež_, yll_, _رفسن,
  { {0x27c70076,0x63a81973,0x1a5b0021,0x00000000}},	//   ющег, jedn, _نشرة_,
  { {0xfbd2014e,0x64590051,0xd6a80021,0x00000000}},	//   _אתם_, _stwi, قديم_,
  { {0x644b0baf,0x64431974,0xb9550062,0x00000000}},	//   _pugi, _sini, _хващ,
  { {0x64431975,0x9990000c,0x973c0022,0x00000000}},	//   _pini, ţaţi_, _waćp,
  { {0x44251976,0x682d0066,0x656b00ca,0x00000000}},	//   ull_, búda, _wegh,
  { {0x62810104,0x64431977,0x9f580139,0x00000000}},	//   urlo, _vini, uirí_,
  { {0x644b0019,0x7a3100d1,0x91a90013,0x00000000}},	//   _tugi, båte, _phá_,
  { {0x6443002c,0x628800eb,0x7bc71978,0x00000000}},	//   _tini, audo, _onju,
  { {0x3a2600ea,0xafe60854,0x682401a8,0x00000000}},	//   zlop_, чогл, tòdi,
  { {0xf1bf0027,0x62881979,0x3ebe0014,0x00000000}},	//   mlán_, cudo, ítt_,
  { {0x67ef0146,0x7bc70397,0xf1bf1919,0x00000000}},	//   _højd, _anju, llán_,
  { {0xdca3197a,0x5ca30062,0x320201d1,0x00000000}},	// [2460] нати, нитб, miky_,
  { {0x917a008b,0xa097009f,0x32020195,0x00000000}},	//   _hầu_, _צדיק_, liky_,
  { {0xca75000d,0x9f5800cd,0x6fdb0063,0x00000000}},	//   дучы, mirà_, _הקיס,
  { {0x8c460076,0x63a80045,0x7bc7006d,0x00000000}},	//   _неме, zedn, _enju,
  { {0xfc3f0014,0x29120058,0x8c46197b,0x00000000}},	//   _asíu_, çya_, _хеге,
  { {0xdb0e048e,0xe3b8005b,0x9f58197c,0x00000000}},	//   _habí, rlık_, nirà_,
  { {0xfbc90161,0xdb0e0066,0x63a804d9,0x00000000}},	//   रारम, _kabí, vedn,
  { {0x9aeb0063,0x682d0025,0xceb30063,0x00000000}},	//   _הַמִ, rúda, תיה_,
  { {0x6600197d,0x63a8197e,0xb86500de,0x00000000}},	//   rimk, tedn, _ياكو,
  { {0x6288197f,0xb05b0504,0x13f30121,0x00000000}},	//   tudo, lväg, езья,
  { {0x320201d9,0x9f58078d,0x63a80648,0x00000000}},	//   fiky_, dirà_, redn,
  { {0xdb0e0080,0x62880146,0x917a001b,0x00000000}},	//   _nabí, rudo, _cầu_,
  { {0x7a230019,0x4fc7005a,0x68e20150,0x00000000}},	//   mõtt, псва, nyod,
  { {0x9f580268,0x2d9c00ea,0xa01b00ea,0x00000000}},	//   girà_, ővel_, ltöz,
  { {0xb05b00c7,0x539b0165,0x24520013,0x00000000}},	//   kväg, _היוו, _hâm_,
  { {0xe3b801f7,0x3ebe0026,0xdb0e00ed,0x00000000}},	//   ldı_, ætta_, _cabí,
  { {0x61ed00bb,0x67ef0146,0xb0150001,0x00000000}},	// [2470] _ilal, _høje, _омиљ,
  { {0xe3b801f7,0x9f5801f4,0x68e20058,0x00000000}},	//   ndı_, cirà_, dyod,
  { {0x24521980,0xbd02006f,0x20031981,0x00000000}},	//   _lâm_, _éénm, miji_,
  { {0xa9540086,0x200301b3,0x9f580e7c,0x00000000}},	//   екці, liji_, mirá_,
  { {0x9f58006d,0xbc770066,0x7a150051,0x00000000}},	//   lirá_, ýšľa, jąte,
  { {0x20030add,0x7a230019,0x61ed001f,0x00000000}},	//   niji_, võtu, _llal,
  { {0x67ef00b9,0xdce6001c,0x8679000d,0x00000000}},	//   _nøje, _iekā, цёлу_,
  { {0x61ed00a4,0xb9c50067,0x20031982,0x00000000}},	//   _nlal, _تقري, hiji_,
  { {0xdcfd005b,0xf1bf1983,0x69c9006f,0x00000000}},	//   _kası, tlán_, _inee,
  { {0x13090076,0x20030ab2,0x61ed1984,0x00000000}},	//   жной_, jiji_, _alal,
  { {0x69c90034,0x442b001c,0x200301b3,0x00000000}},	//   _knee, ēc_, diji_,
  { {0xd6d80055,0x69db0164,0x471a00b5,0x00000000}},	//   _эту_, _joue, _וועג,
  { {0x250904de,0x917a008b,0x9f5800cd,0x00000000}},	//   _برای_, _cấu_, tirà_,
  { {0xdcfd01f7,0x67ef00b9,0xdce6003d,0x00000000}},	//   _nası, _føje, _nekā,
  { {0x9f581985,0x69c91986,0x50430fd0,0x00000000}},	//   rirà_, _onee, терб,
  { {0x69db1987,0xed5a0054,0xacb60044,0x00000000}},	//   _noue, іоз_, ومزغ,
  { {0xdcfd01f7,0x2003074f,0x2452008b,0x00000000}},	// [2480] _bası, biji_, _xâm_,
  { {0x200306bb,0x9f580297,0x68e20035,0x00000000}},	//   ciji_, birá_, vyod,
  { {0x9f58006d,0xfc3f006d,0x69db006c,0x00000000}},	//   cirá_, _asís_, _boue,
  { {0xef170088,0x79a302a9,0xe3b8005b,0x00000000}},	//   _імя_, врше, zdı_,
  { {0x7a230004,0xb05b00c7,0xe3b8005b,0x00000000}},	//   võtt, rväg, ydı_,
  { {0xb05b0504,0x78ad017d,0x68e20a9f,0x00000000}},	//   sväg, çava, ryod,
  { {0x7a230019,0x7bdc0025,0x69db1988,0x00000000}},	//   tõtt, _ioru, _foue,
  { {0xc883005b,0x200301b3,0x1dd10053,0x00000000}},	//   üğü_, ziji_, हायत,
  { {0x7bdc1989,0x9f58017d,0xe4520044,0x00000000}},	//   _koru, zirá_, خضع_,
  { {0x88bd0051,0xdb0e017d,0x91830013,0x00000000}},	//   _myśl, _gabã, _iểu_,
  { {0xe3b8005b,0x2003027c,0x7a310137,0x00000000}},	//   rdı_, viji_, låta,
  { {0xd2570088,0x2452001b,0xdb1c0137,0x00000000}},	//   ьць_, _tâm_, _inrä,
  { {0x2003074f,0xd5cf0013,0x60f8066e,0x00000000}},	//   tiji_, _kềnh_, дняя_,
  { {0x9f58198a,0x7bdc198b,0x67ef01e1,0x00000000}},	//   tirá_, _noru, _tøje,
  { {0x2003198c,0xcddb005e,0x200400cd,0x00000000}},	//   riji_, оња_, èmia_,
  { {0x63b802ab,0x9f580942,0x2003027c,0x00000000}},	//   _havn, rirá_, siji_,
  { {0x2003198d,0x229800ea,0x69db198e,0x00000000}},	// [2490] piji_, lék_, _roue,
  { {0x63b80add,0xbcfb00ea,0x21290150,0x00000000}},	//   _javn, _beér, _iyah_,
  { {0xdcfd005b,0x7bdc198f,0x629a01cf,0x00000000}},	//   _vası, _doru, ntto,
  { {0xf1bf1990,0xc3330063,0xdb0e00be,0x00000000}},	//   klám_, דוע_, _sabã,
  { {0x69db1991,0x7bdc1992,0x60090078,0x00000000}},	//   _voue, _foru, ažme,
  { {0x63b802ab,0xdb071993,0xf1bf1994,0x00000000}},	//   _navn, _majú, dlám_,
  { {0x26c102f4,0xd6d10032,0x2298013d,0x00000000}},	//   ího_, اقع_, jék_,
  { {0x7bdc005b,0x917a001b,0x229800ea,0x00000000}},	//   _zoru, _mẫu_, dék_,
  { {0xdb070024,0x21290089,0x7bdc1995,0x00000000}},	//   _najú, _nyah_, _yoru,
  { {0x44230024,0xf6e70962,0xdb0e013d,0x00000000}},	//   ôj_, _оцен, _habá,
  { {0x2129053b,0xe9ff008b,0x2bb20053,0x00000000}},	//   _ayah_, _giản_, ीयता,
  { {0xbbdc0042,0xe1f2043e,0x00000000,0x00000000}},	//   _मक्क, اسد_,   ,
  { {0x64a50088,0xb17b00d1,0x63b81996,0x00000000}},	//   _чала, rhåp, _favn,
  { {0xdb0e0137,0x63b805b9,0x7fd60083,0x00000000}},	//   _inbö, _gavn, хімі,
  { {0xada60076,0x248d017d,0x6da60175,0x00000000}},	//   навл, luem_, нива,
  { {0x7bdc01f7,0x25ad0162,0x3ec2008f,0x00000000}},	//   _soru, neel_, _īstā_,
  { {0x248d1997,0x7bdc1998,0x63a6013d,0x00000000}},	// [24a0] nuem_, _poru, őkne,
  { {0x394d0034,0xa09b00b5,0x25ad1999,0x00000000}},	//   _ages_, _צייט, heel_,
  { {0x88bd0045,0x25ad199a,0x7a2a0014,0x00000000}},	//   _wyśl, keel_, lýti,
  { {0x60c4199b,0x7bdc004d,0xb05b0072,0x00000000}},	//   _krim, _woru, sväe,
  { {0x25ad0162,0x317b0063,0x7ae50072,0x00000000}},	//   deel_, פרסמ, ayht,
  { {0x394d002b,0x75fe008f,0x207b0041,0x00000000}},	//   _eges_, mūzi, לאנא,
  { {0x2cb20185,0x63b802e2,0xa96a199c,0x00000000}},	//   lwyd_, _ravn, _нива_,
  { {0x0466000d,0x7a310137,0x63b8199d,0x00000000}},	//   нтом, låtn, _savn,
  { {0x2cb20185,0x248d14b1,0x22490089,0x00000000}},	//   nwyd_, guem_, _riak_,
  { {0x2298000f,0x22490150,0xa87b0063,0x00000000}},	//   ték_, _siak_, _מאמר,
  { {0x2cb2001f,0x7dd800ea,0x21290360,0x00000000}},	//   hwyd_, _dísz, _syah_,
  { {0x248d017d,0x629a119d,0x645d1289,0x00000000}},	//   buem_, rtto, ísic,
  { {0xc0cb0001,0x644f0283,0x63b8199e,0x00000000}},	//   чуне_, ícit, _tavn,
  { {0x2cb20185,0x60c4199f,0x629a0244,0x00000000}},	//   dwyd_, _drim, ptto,
  { {0x443e0199,0x6e260150,0x64930ef0,0x00000000}},	//   mmt_, _bkkb, ržiš,
  { {0x2cb20185,0x442c19a0,0x7c3e19a1,0x00000000}},	//   fwyd_, lld_, empr,
  { {0x443e19a2,0x2cb2001f,0x60c419a3,0x00000000}},	// [24b0] omt_, gwyd_, _grim,
  { {0xf1c00066,0x628819a4,0xdb150066,0x00000000}},	//   čšej_, ordo, _enzý,
  { {0x67ef0146,0x443e19a5,0x1df90121,0x00000000}},	//   _nøja, imt_, _жены_,
  { {0x443e004d,0x2cb2002b,0x7ae50072,0x00000000}},	//   hmt_, bwyd_, ryht,
  { {0xa17c00b5,0x644a0025,0x25ad0162,0x00000000}},	//   לטאט, _oifi, veel_,
  { {0x07a5018e,0x7d000014,0x6e2d1130,0x00000000}},	//   такн, _ýmsa, llab,
  { {0x79a70088,0xf6b20021,0x6e2d19a6,0x00000000}},	//   _прае, لموج, olab,
  { {0x6e2d19a7,0x248d0555,0x7aea06a5,0x00000000}},	//   nlab, tuem_, øfte,
  { {0x8cc40161,0x628819a8,0x25ad09fe,0x00000000}},	//   रियो, erdo, reel_,
  { {0x6e2d083f,0x03a5005e,0xf1bf19a9,0x00000000}},	//   hlab, њино, lláh_,
  { {0xe285005a,0x25ad00f5,0x6e2d0026,0x00000000}},	//   ълни, peel_, klab,
  { {0x442c19aa,0x2cb2001f,0x644a002b,0x00000000}},	//   ald_, ywyd_, _eifi,
  { {0x69d9006f,0x644a0035,0x248d19ab,0x00000000}},	//   ijwe, _fifi, quem_,
  { {0x6e2d19ac,0x65690246,0xa01b004d,0x00000000}},	//   elab, lbeh, nröh,
  { {0x91fd003d,0x7a3819ad,0xb05b00a5,0x00000000}},	//   mpān, líte, tväc,
  { {0xa6e9001b,0x6e2d19ae,0x60c409ee,0x00000000}},	//   _trươ, glab, _trim,
  { {0x44270150,0x7a3819af,0x2cb2002b,0x00000000}},	// [24c0] _kkn_, níte, uwyd_,
  { {0x2cb20185,0x6e2d19b0,0x26c501f4,0x00000000}},	//   rwyd_, alab, _orlo_,
  { {0x2cb2001f,0x6e2d0e1a,0xee3a19b1,0x00000000}},	//   swyd_, blab, _оно_,
  { {0x65690122,0x5886000d,0x2cb2002b,0x00000000}},	//   jbeh, выка, pwyd_,
  { {0x442c19b2,0x443e0026,0x656919b3,0x00000000}},	//   yld_, ymt_, dbeh,
  { {0x65690024,0x660219b4,0xc8650021,0x00000000}},	//   ebeh, _smok, اطني,
  { {0x644a051e,0x764b00bb,0x60090734,0x00000000}},	//   _rifi, _bigy, nžma,
  { {0x442c0122,0x7ae317cb,0x644a187c,0x00000000}},	//   wld_, änte, _sifi,
  { {0x7a3800ea,0x41d60053,0x44270150,0x00000000}},	//   gíte, धानस, _bkn_,
  { {0x442c0034,0x6e240025,0x6e2d001c,0x00000000}},	//   uld_, hoib, zlab,
  { {0x442c19b5,0x7a310137,0x764b00ea,0x00000000}},	//   rld_, kåtl, _figy,
  { {0x764b00a3,0x91fd0023,0x4427004e,0x00000000}},	//   _gigy, apān, _ekn_,
  { {0x7a380331,0x7a150022,0x61f80085,0x00000000}},	//   cíte, kątn, тняў_,
  { {0xa91d1844,0x6e9519b6,0xe3b80075,0x00000000}},	//   _udže, лигу, alır_,
  { {0xdbdc0026,0xd3780051,0xa2e30002,0x00000000}},	//   _ráðl, mać_, _војд,
  { {0xd3780051,0xbddb0003,0x6e2d0058,0x00000000}},	//   lać_, _lièv, ulab,
  { {0x6e2d19b7,0x31790051,0x6c54130d,0x00000000}},	// [24d0] rlab, masz_, икту,
  { {0xd3780051,0x6e2d019f,0x31790758,0x00000000}},	//   nać_, slab, lasz_,
  { {0xf09f0682,0xe28b0080,0x16220053,0x00000000}},	//   ltà_, _účtů_, मवार_,
  { {0xa01b0026,0xf1bf19b8,0x31790022,0x00000000}},	//   fsög, ndá_, nasz_,
  { {0xd3780045,0xf09f19b9,0x9d140054,0x00000000}},	//   kać_, ntà_, _вдяч,
  { {0x7a3800ea,0xf8070062,0xd3780022,0x00000000}},	//   víte, ъчен, jać_,
  { {0xd3780045,0x9f5102dd,0xa01b0014,0x00000000}},	//   dać_, lizó_, psöf,
  { {0x26c5017f,0xcb12009f,0xa87b0021,0x00000000}},	//   _vrlo_, _הלל_, _يحذر_,
  { {0x75f50080,0x9f51006d,0x31790051,0x00000000}},	//   _náze, nizó_, dasz_,
  { {0xd3780051,0x7a3819ba,0x68e40213,0x00000000}},	//   gać_, ríte, äide,
  { {0xf09f051e,0x420a19bb,0x7a3819bc,0x00000000}},	//   età_, енно_, síte,
  { {0xf1bf0016,0x7a3800ea,0x3179056c,0x00000000}},	//   gdá_, píte, gasz_,
  { {0x7c25007d,0x660919bd,0xdb1c1775,0x00000000}},	//   kohr, miek, _carê,
  { {0x25bd001f,0x25bf000c,0xd3780051,0x00000000}},	//   _hawl_, ldul_, cać_,
  { {0x9324006a,0x539a0063,0x6441004d,0x00000000}},	//   _پرون, _ניקו, mmli,
  { {0xe1f2006a,0x25bf19be,0x660919bf,0x00000000}},	//   _دست_, ndul_, niek,
  { {0xf09f00cd,0x6e2419c0,0xa3c80053,0x00000000}},	// [24e0] ctà_, roib, _लोड_,
  { {0x44250c70,0x249f0026,0xeb9706da,0x00000000}},	//   nol_, itum_, лиу_,
  { {0xb05b01e3,0x6b5900ea,0x660919c1,0x00000000}},	//   nvän, _súgó, kiek,
  { {0xd3780051,0x644100bd,0x442510c1,0x00000000}},	//   zać_, hmli, hol_,
  { {0x442519c2,0x660919c3,0xdc75000d,0x00000000}},	//   kol_, diek, _высь,
  { {0xa01b0026,0x93bc000c,0x442519c4,0x00000000}},	//   rsög, nlăt, jol_,
  { {0x386600f3,0x660904c6,0x442510c1,0x00000000}},	//   spor_, fiek, dol_,
  { {0xd3781112,0xb05b00c7,0x200a005b,0x00000000}},	//   wać_, dvän, hibi_,
  { {0x44250185,0xd3780051,0x200a005b,0x00000000}},	//   fol_, tać_, kibi_,
  { {0x442519c5,0x3a260162,0x31790022,0x00000000}},	//   gol_, loop_, wasz_,
  { {0xd3780051,0x16660001,0x25bf0222,0x00000000}},	//   rać_, _свем, bdul_,
  { {0xf09f02f6,0x2ca00004,0xd3780051,0x00000000}},	//   ttà_, ktid_, sać_,
  { {0x3dc0001f,0x442519c6,0xf1bf19c7,0x00000000}},	//   ddiw_, bol_, kláv_,
  { {0xc356011c,0xf09f19b9,0x442519c8,0x00000000}},	//   _съдъ, rtà_, col_,
  { {0xa36f0024,0xf09f19c9,0x3a260229,0x00000000}},	//   äčši, stà_, koop_,
  { {0x9f51006d,0xf09f00cd,0x443c19ca,0x00000000}},	//   tizó_, ptà_, _hhv_,
  { {0xdbd20019,0x682d0024,0x67ef00b9,0x00000000}},	// [24f0] _füüs, súdi, _bøjl,
  { {0x41c30161,0x660919cb,0x320b0924,0x00000000}},	//   षयवस, ziek, licy_,
  { {0xddd0005b,0x7c2519cc,0x9e3505ce,0x00000000}},	//   _çeşi, rohr, _венч,
  { {0x320b0051,0x249f0026,0x443c004b,0x00000000}},	//   nicy_, ytum_, _lhv_,
  { {0x2ca0001f,0xbddb0003,0x25bd19cd,0x00000000}},	//   ctid_, _dièt, _rawl_,
  { {0x25bd0185,0x66090051,0xa265008b,0x00000000}},	//   _sawl_, wiek, _buộ,
  { {0xec36014e,0xa265001b,0x44251505,0x00000000}},	//   _כאשר_, _cuộ, vol_,
  { {0x3ebe0026,0x25bf0150,0x249f19ce,0x00000000}},	//   ætti_, udul_, ttum_,
  { {0xfa34007e,0x442519cf,0x25bf19d0,0x00000000}},	//   _طرفد, tol_, rdul_,
  { {0x660919d1,0x13e60076,0x442519d2,0x00000000}},	//   siek, имый_, uol_,
  { {0x249f13f3,0x7a3800ea,0xddc70006,0x00000000}},	//   stum_, líta, gpjū,
  { {0x44250185,0xb05b00c7,0x249f0026,0x00000000}},	//   sol_, rvän, ptum_,
  { {0xb05b00c7,0x442519d3,0x7a38013d,0x00000000}},	//   svän, pol_, níta,
  { {0x88bd0045,0xb4fa0063,0xb05b0137,0x00000000}},	//   _wyśw, _בפני, mväl,
  { {0x645b048e,0x200a19d4,0x245b008b,0x00000000}},	//   lqui, ribi_, _hêm_,
  { {0x8e55019d,0x4d660088,0x67ef00b9,0x00000000}},	//   стрі, ркав, _søjl,
  { {0x93bc000c,0xb05b0072,0x645b13cd,0x00000000}},	// [2500] plăt, nväl, nqui,
  { {0x645b0268,0x27220024,0x307b014e,0x00000000}},	//   iqui, nčné_, _שאינ,
  { {0xdb150016,0x78bb021e,0xf1da0053,0x00000000}},	//   _razã, _asuv, _बचान,
  { {0xb17b0e5a,0x61e400fe,0x7ae303c8,0x00000000}},	//   lkår, _joil, änta,
  { {0xdb1c0164,0x27220024,0x61e40025,0x00000000}},	//   _maré, kčné_, _moil,
  { {0x18670001,0xdb07006d,0xb2270014,0x00000000}},	//   шаљи_, _cajó, _klæð,
  { {0x5b35000d,0xa01b0137,0xdb05004d,0x00000000}},	//   _гэту, pröv, gehä,
  { {0x78660086,0x68eb02fb,0x61e419d5,0x00000000}},	//   _вказ, bygd, _noil,
  { {0x9183001b,0x7a380331,0x248d0fda,0x00000000}},	//   _nếu_, cíta, grem_,
  { {0xdb1c00cd,0x69c219d6,0xdb05004d,0x00000000}},	//   _parè, ldoe, behä,
  { {0x4b7b180d,0x61e40120,0x248d19d7,0x00000000}},	//   כטיג, _boil, arem_,
  { {0x69c019d8,0x61e419d9,0x69c20421,0x00000000}},	//   _jame, _coil, ndoe,
  { {0x245b0185,0xfeb8006a,0x61e419d5,0x00000000}},	//   _gêm_, یافت_, _doil,
  { {0x7a310137,0xb17b069f,0x69c006d5,0x00000000}},	//   tåtk, gkår, _lame,
  { {0x69c00529,0x61e40d12,0x9f35000d,0x00000000}},	//   _oame, _foil, севі,
  { {0xdb0501e3,0x5d5519da,0x61f600ac,0x00000000}},	//   nehå, скат, _glyl,
  { {0x78a2017f,0x7a310137,0xbddb0003,0x00000000}},	// [2510] jtov, såtk, _bièr,
  { {0x0a6b018e,0x69c20983,0x2ac7005e,0x00000000}},	//   врди_, edoe, иљев,
  { {0xcf92014e,0x645b006d,0x69c200ac,0x00000000}},	//   _צטט_, zqui, fdoe,
  { {0x9183008b,0xb05b0072,0xc98719db,0x00000000}},	//   _yếu_, yväl, ружи,
  { {0xf0940047,0xa01b0137,0xf1bf00ea,0x00000000}},	//   ַנק_, bröt, llás_,
  { {0x645d02dd,0xe8f8000d,0xa01b0137,0x00000000}},	//   ísim, шлі_, mrös,
  { {0x7a3819dc,0xc6680138,0x657b002c,0x00000000}},	//   mítn, ашње_, tauh,
  { {0xff180063,0x69c019dd,0x0495000d,0x00000000}},	//   יקות_, _game, броў,
  { {0x248d19de,0x78bb004b,0xdb051013,0x00000000}},	//   urem_, _usuv, sehä,
  { {0x248d19df,0x245b017d,0x61e419d9,0x00000000}},	//   rrem_, _vêm_, _soil,
  { {0x645b13a8,0x69c00009,0x27220024,0x00000000}},	//   squi, _yame, rčné_,
  { {0x245b03d9,0xdb0800ea,0x82f4000d,0x00000000}},	//   _têm_, ülés, ючыц,
  { {0x61e40164,0x70560021,0xe6040044,0x00000000}},	//   _voil, إنسا, _بِنَ,
  { {0x51f6006a,0x10160085,0xb1430085,0x00000000}},	//   _گستر, сьмя, янял,
  { {0x22950021,0x27e50137,0x52850021,0x00000000}},	//   _العس, _moln_, _البك,
  { {0x51f6006a,0x6459002c,0x78a2016b,0x00000000}},	//   _دستر, _kuwi, ytov,
  { {0x228301f7,0x78a20512,0x5baa000d,0x00000000}},	// [2520] lık_, xtov, лкам_,
  { {0x69c019e0,0x62811058,0xaf9a1159,0x00000000}},	//   _same, oslo, _стих_,
  { {0x69c019e1,0xdcef001c,0xcf570063,0x00000000}},	//   _pame, _vecā, _לבית_,
  { {0x62810035,0x3ebe0026,0x88860021,0x00000000}},	//   islo, ættu_, مؤتم,
  { {0x69c219e2,0x17540065,0x78a219e3,0x00000000}},	//   rdoe, овля, utov,
  { {0x69c00035,0x78a204c8,0x69c20229,0x00000000}},	//   _wame, rtov, sdoe,
  { {0x78a219e4,0x75f5004c,0x7aea00a5,0x00000000}},	//   stov, _sáza, äftd,
  { {0x2283005b,0x645900a4,0xf1bf0025,0x00000000}},	//   dık_, _buwi, hlár_,
  { {0x7a38000f,0x7a150051,0xe4e601dd,0x00000000}},	//   líto, zątk, сійн,
  { {0x8cbb014e,0x6459002b,0xa41c008f,0x00000000}},	//   נציק, _duwi, _ādēļ_,
  { {0x02a30156,0xdb050137,0x628119e5,0x00000000}},	//   прям, pehå, gslo,
  { {0x22400089,0x20181346,0xdd28008f,0x00000000}},	//   _chik_, enri_, zēšo,
  { {0x25b7006a,0x628108ea,0x9f410066,0x00000000}},	//   _دهند_, aslo, _dlhý_,
  { {0xb4d4016a,0x7a3800ea,0xb05b0072,0x00000000}},	//   हमी_, kíto, lväk,
  { {0xa3d50161,0x628114d5,0x6459004d,0x00000000}},	//   हार_, cslo, _zuwi,
  { {0x64630026,0xbd890021,0x7a3819e6,0x00000000}},	//   _óvið, شنطن_, díto,
  { {0xf1d60053,0xc4b60053,0x765a19e7,0x00000000}},	// [2530] धारन, _अनोख, _luty,
  { {0x3a2d021f,0xf1bf0025,0xa01b0137,0x00000000}},	//   _skep_, clár_, rrös,
  { {0x1dc40053,0x765a0006,0xee3f0013,0x00000000}},	//   _लोकत, _nuty, _thý_,
  { {0x5ee80063,0x60cd19e8,0xb6460085,0x00000000}},	//   _הַשְ, _kram, _кнiж,
  { {0x7a380080,0x27e500c2,0x28a70121,0x00000000}},	//   mítl, _poln_, сшег,
  { {0x26cc007d,0x22830058,0x628119e9,0x00000000}},	//   _brdo_, yık_, yslo,
  { {0xcf94016e,0xe7390f9f,0xa3dc0042,0x00000000}},	//   לטס_, шек_, डान_,
  { {0x7d090ac6,0x26c700c3,0x7aea0502,0x00000000}},	//   _þess, rvno_, äfte,
  { {0xa3d50161,0x9475005d,0x7c22006c,0x00000000}},	//   हाल_, زگشا, éorg,
  { {0x228301f7,0x981703eb,0x628119ea,0x00000000}},	//   tık_, _ابرا, tslo,
  { {0x60cd04ab,0xe9ff008b,0x28c70042,0x00000000}},	//   _aram, _nhẫn_, लिवि,
  { {0x6459002c,0x75f5027d,0x6aa513d5,0x00000000}},	//   _tuwi, _zázn, ithf,
  { {0x2419007f,0x628119eb,0x7a38013d,0x00000000}},	//   _коды_, sslo, zíto,
  { {0xdd01004c,0x628105e7,0x3f9e004b,0x00000000}},	//   štěv, pslo, ütu_,
  { {0x60cd0019,0xd347007e,0xed5a0002,0x00000000}},	//   _eram, _دیده_, иов_,
  { {0x7bd500bd,0xed57000a,0x60cd19ec,0x00000000}},	//   _anzu, жот_, _fram,
  { {0xac0a0002,0xa01b0137,0x60db004d,0x00000000}},	// [2540] анаа_, rrör, äumt,
  { {0x6026019d,0x9f6000fe,0xa01b0137,0x00000000}},	//   _єдна, ärät_, srör,
  { {0xb05b00fe,0x75f50061,0xda650021,0x00000000}},	//   yväk, _názo, كاني,
  { {0x7bc50b54,0xa3d50053,0x286a0caa,0x00000000}},	//   adhu, हाँ_, арко_,
  { {0x79890185,0x7a38000f,0x2db7014e,0x00000000}},	//   _ddew, síto, _ולכן_,
  { {0xdb1c19ed,0x7a3819ee,0xa3c80042,0x00000000}},	//   _harí, píto, _लों_,
  { {0xf1ca0161,0x2d80003b,0xdb1c0014,0x00000000}},	//   ियान, oaie_, _karí,
  { {0x95ca0138,0x94aa0635,0x6366004c,0x00000000}},	//   рука_, атоа_, kční,
  { {0x75fc000f,0xdb1c0283,0xe9ff008b,0x00000000}},	//   _néze, _marí, _hiến_,
  { {0xe9ff001b,0x03f80001,0x26cc00c2,0x00000000}},	//   _kiến_, сној_, _trdo_,
  { {0xbcfb017d,0x05660121,0x60cd0734,0x00000000}},	//   _afél, _двен, _sram,
  { {0xe9ff008b,0x60cd19ef,0xf207012c,0x00000000}},	//   _miến_, _pram, іяно,
  { {0x845a000a,0x32f50013,0x4fc70816,0x00000000}},	//   _трет_, áy_, осва,
  { {0x7a3100d1,0xe9ff0013,0xb05b0244,0x00000000}},	//   lått, _phẫn_, hwäg,
  { {0x22630024,0x442c19f0,0xdb1c19f1,0x00000000}},	//   ľské_, mod_, _barí,
  { {0x02fb0063,0x60cd19f2,0x2d580376,0x00000000}},	//   _כלומ, _tram, жить_,
  { {0xa80201f7,0xdb1c05d5,0x75fc00ea,0x00000000}},	// [2550] şıyo, _darí, _kézb,
  { {0x442c19f3,0xe9ff001b,0xab940054,0x00000000}},	//   nod_, _biến_, дифі,
  { {0x201119f4,0x7bc500d1,0x6448005b,0x00000000}},	//   mizi_, rdhu, imdi,
  { {0x24860117,0x6aa5001f,0x7a3800ea,0x00000000}},	//   _ovom_, rthf, lítj,
  { {0x442c19f5,0x8dda0063,0x7e6200a8,0x00000000}},	//   kod_, _הקרק, _čopi,
  { {0x201104ab,0xe0df0268,0x7bd500bd,0x00000000}},	//   nizi_, ixò_, _unzu,
  { {0x9675000d,0xb05b004b,0x442c19f6,0x00000000}},	//   чылі, sväh, dod_,
  { {0x7a3100a5,0x391519f7,0xc1da0042,0x00000000}},	//   gått, _ембр, _बचेग,
  { {0x442c0185,0x5884000d,0x7a3800ea,0x00000000}},	//   fod_, _жыха, kítj,
  { {0x442c19f8,0x2011007d,0x73050062,0x00000000}},	//   god_, jizi_, зпоз,
  { {0x4439003d,0x20110ee6,0x7a38013d,0x00000000}},	//   ēs_, dizi_, dítj,
  { {0x2011008f,0xdb0e004c,0x5ef10082,0x00000000}},	//   eizi_, _nabý, ीनन्_,
  { {0xa01b00bd,0xe9ff008b,0x442c19f9,0x00000000}},	//   rsön, _chẩn_, bod_,
  { {0x764901f7,0x20110035,0x644f00cd,0x00000000}},	//   lmey, gizi_, ïcid,
  { {0xdee60a36,0xdb1c19fa,0x661b0066,0x00000000}},	//   чови, _parí, onuk,
  { {0x661b024a,0x764901f7,0xe1ff006d,0x00000000}},	//   nnuk, nmey, chó_,
  { {0xdb1c05d5,0xb05b00fe,0x661b19fb,0x00000000}},	// [2560] _varí, yväi, inuk,
  { {0x60090006,0x2d800003,0x7a3801a8,0x00000000}},	//   yžmi, saie_, rítm,
  { {0xab690032,0x7a3800ea,0x7649005b,0x00000000}},	//   تحقق_, sítm, kmey,
  { {0xdb1c0016,0x9f580331,0x7a380061,0x00000000}},	//   _parâ, piró_, mítk,
  { {0x442c002c,0xed52007e,0xdb1c017d,0x00000000}},	//   yod_, _سپس_, _barã,
  { {0xe9ff001b,0xdb0e0080,0x291a003b,0x00000000}},	//   _tiến_, _zabý, ăpa_,
  { {0x2486017f,0x8c4319fc,0x7a3104aa,0x00000000}},	//   _svom_, _чере, tått,
  { {0xceb3014e,0x442c001f,0xd5ba0121,0x00000000}},	//   גיה_, wod_, сск_,
  { {0x38c8006a,0xdb1c017d,0x7d0419fd,0x00000000}},	//   _بازی_, _farã, nzis,
  { {0x7d000014,0xa2f417f2,0x644319fe,0x00000000}},	//   _ýmsu, дпоч, _chni,
  { {0x442c19ff,0x6448008f,0x20111a00,0x00000000}},	//   rod_, rmdi, vizi_,
  { {0xd2570088,0x79820035,0x442c1a01,0x00000000}},	//   яць_, naow, sod_,
  { {0x442c0117,0x20110290,0x50671a02,0x00000000}},	//   pod_, tizi_, ятна,
  { {0xe2f8000d,0x7d041a03,0xe1ff0139,0x00000000}},	//   _мелі_, dzis, shó_,
  { {0x9f580290,0x53330141,0x7a38013d,0x00000000}},	//   tirò_, _пешт, rítj,
  { {0x63ba1a04,0x7a3800ea,0x67ef00b9,0x00000000}},	//   letn, sítj, _højt,
  { {0x7d040006,0xdd94000d,0x6e2d00a8,0x00000000}},	// [2570] gzis, эаты, roab,
  { {0x629a1a05,0x7a381084,0x76490058,0x00000000}},	//   outo, líth, zmey,
  { {0xdb1c0994,0x3f831a06,0x629a1a07,0x00000000}},	//   _carà, maju_, nuto,
  { {0x7aea00c7,0x63ba00ea,0x7a3800ea,0x00000000}},	//   äfta, hetn, níth,
  { {0xf1bf0013,0x48ab1a08,0x63ba1a09,0x00000000}},	//   goái_, стем_, ketn,
  { {0xfe70007e,0x63ba027c,0x2ca90137,0x00000000}},	//   _جدی_, jetn, mtad_,
  { {0x67d2000a,0x2ca91a0a,0x7649005b,0x00000000}},	//   тоју, ltad_, tmey,
  { {0x629a1a0b,0x9b440021,0xceb40063,0x00000000}},	//   duto, _سنقو, תיק_,
  { {0x764901f7,0x3f83017f,0x2ca91a0c,0x00000000}},	//   rmey, kaju_, ntad_,
  { {0x3f83017f,0x43740086,0xdb1c1919,0x00000000}},	//   jaju_, нуют, _hará,
  { {0x3f83017f,0x7bc71a0d,0x7d04104e,0x00000000}},	//   daju_, _maju, zzis,
  { {0x2ca91a0e,0xcf890ee1,0x7a381a0f,0x00000000}},	//   ktad_, _כט_, gíth,
  { {0x25ad0137,0x629a1a10,0xaca30013,0x00000000}},	//   mfel_, auto, _diịc,
  { {0x63ba007d,0x7bc70d76,0x3f83007d,0x00000000}},	//   cetn, _naju, gaju_,
  { {0x67ef0146,0xe9ff008b,0x2bd10042,0x00000000}},	//   _højs, _nhắn_, _सफ़ा,
  { {0xee3a0304,0x2ca90137,0x515604e3,0x00000000}},	//   іна_, ftad_, _отпу,
  { {0xbc6a006a,0x3f83017f,0x7a380080,0x00000000}},	// [2580] زمان_, baju_, sítk,
  { {0xdb1c0268,0x3f83017f,0x60c41a11,0x00000000}},	//   _parà, caju_, _isim,
  { {0xdb1c000f,0xe9ff008b,0x7a381513,0x00000000}},	//   _bará, _chắn_, líti,
  { {0xdb1c06b2,0x25ad06aa,0x61e600c2,0x00000000}},	//   _cará, jfel_, njkl,
  { {0x307a0047,0x395200fe,0x22520066,0x00000000}},	//   קאַנ, äys_, ízky_,
  { {0x60c40035,0x7bc71a12,0x38cb007e,0x00000000}},	//   _msim, _gaju, غانی_,
  { {0xa3c80053,0xc6a60002,0xb05b00a5,0x00000000}},	//   _लोग_, фрли, lvät,
  { {0xe5a3005e,0xa91d005f,0x6f030058,0x00000000}},	//   вићи, _bežd, _ünce,
  { {0x91fd008f,0x63ba1a13,0x7a38013d,0x00000000}},	//   kpār, tetn, víth,
  { {0xb05b1a14,0xdb1c1a15,0x629a1a16,0x00000000}},	//   hwäc, _zará, tuto,
  { {0x3f830117,0x60c41a17,0x629a00fe,0x00000000}},	//   vaju_, _asim, uuto,
  { {0x63ba1a18,0x629a1a19,0x7413007e,0x00000000}},	//   setn, ruto, _یونا,
  { {0xc5f3014e,0x3f83017f,0x63ba0384,0x00000000}},	//   _בדף_, taju_, petn,
  { {0xa01b01e3,0xbbc80161,0x67ef010a,0x00000000}},	//   msök, रयोक, _højr,
  { {0xa01b00c7,0x3f831a1a,0x60c4037e,0x00000000}},	//   lsök, raju_, _esim,
  { {0x7a380025,0x3f831a1b,0x2ca91a1c,0x00000000}},	//   bíti, saju_, ttad_,
  { {0x3f831a1d,0xa01b0137,0x64581a1e,0x00000000}},	// [2590] paju_, nsök, _kivi,
  { {0x2c6400c7,0x9f4500ea,0x2ca91a1f,0x00000000}},	//   _död_, óló_, rtad_,
  { {0x386d1a20,0xdb1c1a21,0x7bc70019,0x00000000}},	//   _ster_, _pará, _vaju,
  { {0x64581a22,0xa01b00c7,0xceb200b5,0x00000000}},	//   _livi, ksök, _גיט_,
  { {0x9f580027,0x7bc71a23,0xdb1c00ea,0x00000000}},	//   mhrá_, _taju, _vará,
  { {0x07a2026b,0xb05b0072,0xe9ff0013,0x00000000}},	//   гашн, lväs, _thắn_,
  { {0x25ad0529,0x49bb006a,0xa01b00c7,0x00000000}},	//   tfel_, _وارد_, esök,
  { {0xcf580132,0x6b85003e,0x62881a24,0x00000000}},	//   ובות_, lahg, dsdo,
  { {0xa01b0137,0x64581a25,0xad9b0014,0x00000000}},	//   gsök, _bivi, _klúb,
  { {0x25ad00c7,0x13090be6,0xe299005e,0x00000000}},	//   sfel_, зной_, пао_,
  { {0xa91d00c3,0x6d5d0d02,0x61ed003b,0x00000000}},	//   _deže, _ogsa, _boal,
  { {0x69cb05e1,0x64581a26,0xa01b0137,0x00000000}},	//   ndge, _eivi, bsök,
  { {0xe9ff001b,0xb05b0db3,0x38a90139,0x00000000}},	//   _nhận_, dväs, núr_,
  { {0x2c6400c7,0x64580924,0x6d5d00a4,0x00000000}},	//   _röd_, _givi, _agsa,
  { {0xa3dc0053,0x6e290061,0x7a38013d,0x00000000}},	//   डार_, čebn, mítv,
  { {0x91fd001c,0x7a38013d,0x64581a27,0x00000000}},	//   spār, lítv, _zivi,
  { {0x60c40035,0xf6520047,0xe9ff0013,0x00000000}},	// [25a0] _usim, רצן_, _chận_,
  { {0x61ed02b0,0x26c51a28,0x69cb10da,0x00000000}},	//   _zoal, _oslo_, edge,
  { {0xdb1c0016,0x8f9b00b5,0x69cb006f,0x00000000}},	//   _març, _ציטי, fdge,
  { {0xb05b0137,0xa9c50085,0x75f5013d,0x00000000}},	//   mvär, ксік, _fázi,
  { {0xb05b00c7,0x27fe0150,0x4c670062,0x00000000}},	//   lvär, _pltn_, _пиян_,
  { {0x3c340137,0x69db1a29,0xa01b0137,0x00000000}},	//   rävs_, _enue, vsök,
  { {0x8f9b0047,0x4df40053,0x64581a2a,0x00000000}},	//   ליסי, _इकाई_, _rivi,
  { {0xb5aa0021,0xc1ca0053,0x69e2004c,0x00000000}},	//   سابك_, ियोग, áteč,
  { {0x76590185,0xdb1c0803,0x2d82007d,0x00000000}},	//   _diwy, _barç, _meke_,
  { {0xa01b01e3,0x61ed0397,0xb05b0137,0x00000000}},	//   rsök, _soal, kvär,
  { {0xa01b00c7,0x64581a2b,0x61ed1a2c,0x00000000}},	//   ssök, _vivi, _poal,
  { {0x2d821181,0xb05b0137,0xa01b00a5,0x00000000}},	//   _neke_, dvär, psök,
  { {0x7bdc0983,0xad9b01a8,0xb05b0a26,0x00000000}},	//   _onru, _llúc, evär,
  { {0xdb1c1a2d,0x7ee7030b,0x00000000,0x00000000}},	//   _garç, нцбе,   ,
  { {0x61ed1a2e,0x53a30141,0x7a38013d,0x00000000}},	//   _toal, _сајб, lítu,
  { {0xbddb0164,0xbdd5005a,0xe9ff008b,0x00000000}},	//   _thèm, ъобщ, _phận_,
  { {0x7d550062,0x4c941a2f,0x5d55193d,0x00000000}},	// [25b0] твах, литс, ткат,
  { {0xb6030024,0x69c91a30,0x5c04045b,0x00000000}},	//   čšin, _saee, ляха,
  { {0xa01b00ea,0xb05b1a31,0xda78000d,0x00000000}},	//   kröz, sväs, еяч_,
  { {0x6149001c,0xe9ff008b,0x69cb1a32,0x00000000}},	//   _tūlī, _thận_, udge,
  { {0x28f80086,0xf09f00cd,0x69cb1a33,0x00000000}},	//   нець_, nuà_, rdge,
  { {0xd942005e,0x307c0041,0x907c0041,0x00000000}},	//   јеши, לאדנ, לטדי,
  { {0xa01b004d,0x38a91a34,0x98c10058,0x00000000}},	//   rsöh, súr_, ısız_,
  { {0xb606017f,0x7ae300fe,0xa91d007d,0x00000000}},	//   ješć, äntu, _vežb,
  { {0xdb1c005b,0xf1bf0024,0xc5680044,0x00000000}},	//   _parç, deá_, رحيل_,
  { {0x75f50a63,0xf09f00cd,0x3914000d,0x00000000}},	//   _názv, duà_, _смур,
  { {0xb05b0137,0x7a38013d,0xfbd20063,0x00000000}},	//   yvär, rítv, בתי_,
  { {0x7a3800ea,0x151500a0,0x3f850026,0x00000000}},	//   sítv, _идея, ðlun_,
  { {0x7a3800ea,0xe44e0062,0x2d8208ed,0x00000000}},	//   pítv, _вж_, _reke_,
  { {0x35a70053,0x25bf00dd,0xe29901f6,0x00000000}},	//   _गाड़, leul_, _жак_,
  { {0xb05b00c7,0x2d821a35,0x765c0003,0x00000000}},	//   tvär, _peke_, _éryt,
  { {0xf1bf0025,0x25bf003b,0xc69203c3,0x00000000}},	//   ceá_, neul_, יאל_,
  { {0xb05b00c7,0x2d821a36,0xd24f0021,0x00000000}},	// [25c0] rvär, _veke_, _بني_,
  { {0x395f018d,0x2d8200e8,0xb05b03c8,0x00000000}},	//   _agus_, _weke_, svär,
  { {0x2d821a37,0xbad5000d,0x9ad50086,0x00000000}},	//   _teke_, ліцы, люці,
  { {0xb05b004d,0x20181a38,0x38c8005d,0x00000000}},	//   nwän, liri_, فاتی_,
  { {0x20180139,0x25bf003b,0x18670f55,0x00000000}},	//   oiri_, deul_, вачи_,
  { {0xe9ff001b,0x6d461a39,0x249f1417,0x00000000}},	//   _phản_, _izka, duum_,
  { {0xcac70184,0x2ca01a3a,0x2018004b,0x00000000}},	//   _игре_, luid_, iiri_,
  { {0x20181a3b,0x66030002,0x7c3e1a3c,0x00000000}},	//   hiri_, ипја, llpr,
  { {0x7c3e00ac,0x20181a3d,0xe4e60086,0x00000000}},	//   olpr, kiri_, тійн,
  { {0x20180035,0xe9ff0013,0x22491a3e,0x00000000}},	//   jiri_, _thản_, _shak_,
  { {0xf2c30878,0xb05b004d,0x2ca00139,0x00000000}},	//   асян, fwän, huid_,
  { {0x2ca00019,0xf09f00cd,0x7a381a3f,0x00000000}},	//   kuid_, tuà_, pítu,
  { {0x7a3800ea,0x20181a40,0x249f00e5,0x00000000}},	//   líts, firi_, cuum_,
  { {0xdb170016,0x2ca00122,0x20181a41,0x00000000}},	//   nexã, duid_, giri_,
  { {0x0d67005a,0x660205e5,0xbe880076,0x00000000}},	//   възм, _klok, ксте_,
  { {0x443e1a42,0xd3570063,0xa91d1a43,0x00000000}},	//   llt_, _בשוק_, _leža,
  { {0x20181a44,0x60d61a45,0xe9ff008d,0x00000000}},	// [25d0] biri_, _grym, _nhạn_,
  { {0x91a0001b,0x25bf000c,0x629a1a46,0x00000000}},	//   _thị_, zeul_, orto,
  { {0x49750001,0x61fd0078,0x443e1a47,0x00000000}},	//   глес, oksl, ilt_,
  { {0x443e0199,0x0a940086,0x7a3800ea,0x00000000}},	//   hlt_, рацю, díts,
  { {0xa91d0024,0x61fd0006,0x69341a48,0x00000000}},	//   _beža, iksl, анцу,
  { {0x66021a49,0x443e00ea,0x16a90256,0x00000000}},	//   _alok, jlt_, евки_,
  { {0x7a38000f,0xb6590086,0x66021a4a,0x00000000}},	//   gíts, нших_, _blok,
  { {0x20180035,0x443e1a4b,0x3618000d,0x00000000}},	//   ziri_, elt_, кцыю_,
  { {0x644a0025,0x629a1a4c,0x998f004c,0x00000000}},	//   _bhfi, erto, logů_,
  { {0xdce4003d,0x66021a4d,0x249f0019,0x00000000}},	//   nciā, _elok, ruum_,
  { {0x6602007a,0x7a381a4e,0x600200be,0x00000000}},	//   _flok, mítr, _nôma,
  { {0x66020089,0x60d60022,0x443e1a4f,0x00000000}},	//   _glok, _prym, alt_,
  { {0x657b06a7,0x25e00161,0x2018192b,0x00000000}},	//   mbuh, कारी_, tiri_,
  { {0x04920021,0x66020051,0x23290bd8,0x00000000}},	//   _الوح, _zlok, _поли_,
  { {0x20180009,0x44271a50,0x7f19013c,0x00000000}},	//   riri_, _ijn_, віту_,
  { {0x20180035,0x2ca00019,0x7c3e006f,0x00000000}},	//   siri_, tuid_, wlpr,
  { {0x248d1a51,0x75f5013d,0x7a38013d,0x00000000}},	// [25e0] nsem_, _házs, zíts,
  { {0x207b0047,0xb05b004d,0x6d46004c,0x00000000}},	//   _ראיא, nwäl, _vzka,
  { {0xda650032,0x657b002c,0xa01b0137,0x00000000}},	//   لاني, kbuh, tsöv,
  { {0x53360047,0x3f8a179b,0x7a3800ea,0x00000000}},	//   אנען_, labu_, víts,
  { {0x2ca01a52,0x443e0303,0x4614007e,0x00000000}},	//   quid_, ylt_, یوتر,
  { {0xd7e70062,0x98470062,0xdce6005f,0x00000000}},	//   лмче_, ляща_, _sekė,
  { {0xdcfd001c,0x443e01e1,0x6602135a,0x00000000}},	//   _iesā, vlt_, _plok,
  { {0x3f8a0035,0x443e05e4,0x657b00a4,0x00000000}},	//   habu_, wlt_, gbuh,
  { {0xa91d05c9,0x7a3819ba,0x6e2400a4,0x00000000}},	//   _teža, bítr, inib,
  { {0x78a202f6,0x439400e1,0x657b00a4,0x00000000}},	//   muov, јанс, abuh,
  { {0x7bce03d5,0x8c370063,0x3f850014,0x00000000}},	//   _mabu, רטיס_, ðlum_,
  { {0xdb1c0139,0x6002008d,0x95c709b3,0x00000000}},	//   _barú, _rôma, _буша_,
  { {0x78a201f4,0x61fd1a53,0x00000000,0x00000000}},	//   nuov, rksl,   ,
  { {0x7bce1a54,0xdcfd008f,0x3f850014,0x00000000}},	//   _nabu, _nesā, úlu_,
  { {0xb7db0047,0xa91d1a55,0x68f90022,0x00000000}},	//   עקלי, _nežn, zywd,
  { {0x7bce002c,0x78a20cff,0x6fde0042,0x00000000}},	//   _aabu, kuov, माउं,
  { {0x3f8a0009,0x69c2191f,0x9c39000a,0x00000000}},	// [25f0] babu_, deoe, впат_,
  { {0xa91d0024,0x3f150086,0x6e240da5,0x00000000}},	//   _bežn, _вдос, anib,
  { {0xdb1502dd,0xdce4001c,0xd7f1008b,0x00000000}},	//   _razó, rciā, _rõ_,
  { {0xdb15006d,0xa91d00c2,0x0d640062,0x00000000}},	//   _sazó, _dežn, _гърм,
  { {0x225901c8,0xdd05008f,0xb05b0244,0x00000000}},	//   írky_, āpēj, hwäm,
  { {0xb8cd0161,0xe8f80088,0x248d1438,0x00000000}},	//   _कम_, ылі_, vsem_,
  { {0xdd2f004c,0x75fc013d,0xe1ff013d,0x00000000}},	//   věřo, _kézh, kkó_,
  { {0x8645005e,0x7bce1a56,0x78a20061,0x00000000}},	//   јниж, _zabu, buov,
  { {0xdb0500bd,0xccf20047,0xf4290239,0x00000000}},	//   gehö, ַכט_, коил_,
  { {0x68f600fe,0xa01b0072,0xddd5013d,0x00000000}},	//   äyde, isös, iszű,
  { {0x248d1a57,0x657b00a4,0xb05b004d,0x00000000}},	//   ssem_, pbuh, rwäl,
  { {0x3f8a0035,0xa06a1a58,0xdb050502,0x00000000}},	//   wabu_, кама_, behö,
  { {0x3f8a0009,0x3eb1004d,0xa8790047,0x00000000}},	//   tabu_, etzt_, כאָר,
  { {0x8fa60079,0x661b0b4f,0x7d0d0051,0x00000000}},	//   јаве, liuk, dzas,
  { {0xa225006a,0x3f8a10d2,0x7d0d1a59,0x00000000}},	//   _گروه, rabu_, ezas,
  { {0x3f8a0035,0x7bce1a5a,0x64411a5b,0x00000000}},	//   sabu_, _sabu, llli,
  { {0xed5a0079,0x7bce00a4,0xddd500ea,0x00000000}},	// [2600] тоа_, _pabu, gszű,
  { {0x4f961a5c,0x6441002b,0x60c90058,0x00000000}},	//   _триу, nlli, çeme,
  { {0xbf9b009f,0xc9661a5d,0x64411a5e,0x00000000}},	//   _בייש, авей, illi,
  { {0xe8fa00e2,0xbcfb013d,0xdca60336,0x00000000}},	//   кле_, _igén, _ками,
  { {0x18b80088,0x7d0d0051,0x8d630086,0x00000000}},	//   углы_, czas, _євре,
  { {0x48130086,0x66090bda,0xa91d08ed,0x00000000}},	//   оміс, ehek, _težn,
  { {0xddc4001c,0x2cb21a5f,0x290016ff,0x00000000}},	//   rmiņ, ltyd_, šia_,
  { {0xa01b00c7,0x64410d9e,0x75fc013d,0x00000000}},	//   nsör, elli, _kézi,
  { {0x2cb200ac,0x186a0086,0x37e60da2,0x00000000}},	//   ntyd_, _рази_, _коаг,
  { {0xe9ff001b,0xf366041d,0x6908005b,0x00000000}},	//   _phần_, штин, ırdı,
  { {0x7bd900b5,0x3266018e,0x7d0d1a60,0x00000000}},	//   אַרק, јтов, zzas,
  { {0xd5b0007e,0x66090035,0x9f580025,0x00000000}},	//   _رفت_, chek, bhrú_,
  { {0x6002017d,0x629c0066,0x64740121,0x00000000}},	//   _cômo, árob, _углу,
  { {0xe9ff008b,0x3317007e,0xfe73002a,0x00000000}},	//   _thần_, ازید_, قدر_,
  { {0x3a260122,0x54390047,0xbd6b0002,0x00000000}},	//   knop_, _געװא, врзе_,
  { {0x2cb200ac,0x75fc0003,0xdcfd00dd,0x00000000}},	//   ftyd_, _bézi, _nesă,
  { {0x7c8705ac,0xde580054,0x7d0d056c,0x00000000}},	// [2610] рубе, раті_, uzas,
  { {0x60cd1a61,0x7d0d0022,0x113c009a,0x00000000}},	//   _isam, rzas, _בתחל,
  { {0x9e350854,0x798b1a62,0xdce70058,0x00000000}},	//   _генч, tagw, ılıd,
  { {0xa2d70053,0x00000000,0x00000000,0x00000000}},	//   यित्,   ,   ,
  { {0xe9ff001b,0xdcfd003b,0x01fc0041,0x00000000}},	//   _nhấn_, _desă, כפאל,
  { {0x60cd0035,0xf09f174c,0xed56009a,0x00000000}},	//   _msam, irà_, _לברר_,
  { {0xfeca0047,0xaa94049f,0x66090b06,0x00000000}},	//   ָמפּ, _мирч, thek,
  { {0x9f580025,0xc4850713,0x60cd0a97,0x00000000}},	//   thrú_, блик, _osam,
  { {0xf7950088,0xe9ff0013,0x644100cd,0x00000000}},	//   _газэ, _chấn_, tlli,
  { {0xf09f19c9,0xf7700021,0x75f50e7c,0x00000000}},	//   drà_, _قام_, _vázq,
  { {0x7c220164,0x60cd1a63,0xf09f174c,0x00000000}},	//   éori, _asam, erà_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x7bc51a64,0xf09f00cd,0x7989006f,0x00000000}},	//   kehu, grà_, _meew,
  { {0x249f0146,0x43850021,0x653a0047,0x00000000}},	//   mrum_, _الثق, _גענד,
  { {0xf09f19c9,0x60cd1a65,0xd1380051,0x00000000}},	//   arà_, _esam, łą_,
  { {0xf09f0268,0x629c001c,0x249f1a66,0x00000000}},	//   brà_, šroc, orum_,
  { {0x4d4a0001,0x249f00c7,0x61e41a67,0x00000000}},	// [2620] упан_, nrum_, _inil,
  { {0xf1bf0027,0x2cb200e8,0x249f0014,0x00000000}},	//   nnán_, rtyd_, irum_,
  { {0x7c2b0153,0x7ed50054,0x249f0058,0x00000000}},	//   égra, _діяч, hrum_,
  { {0xf1bf0025,0xb05b004d,0xdb0700ea,0x00000000}},	//   hnán_, ewäh, émár,
  { {0x2d801a68,0x98a30257,0x5e570041,0x00000000}},	//   mbie_, зиче, _ליטע_,
  { {0xdb1e000f,0x2bb70080,0x4c350085,0x00000000}},	//   lepí, _věcí_, _дэст,
  { {0xdb0e00fe,0x2d800051,0x3b0a0002,0x00000000}},	//   äjän, obie_, _сево_,
  { {0xe5c6093e,0x798900ac,0x443c0026,0x00000000}},	//   сско, _geew, _skv_,
  { {0x8cdb0053,0xdce40022,0xb9061415,0x00000000}},	//   नियो, bcią, _узак,
  { {0xf09f051e,0x600b005b,0x7989006f,0x00000000}},	//   vrà_, _küme, _zeew,
  { {0x61f61a69,0x60cd0072,0x7c3b0aeb,0x00000000}},	//   _boyl, _ssam, רגיז,
  { {0xf09f1a6a,0x201a0290,0x64a61a6b,0x00000000}},	//   trà_, _ampi_, _гада,
  { {0xf09f00cd,0x339402dc,0x763b0047,0x00000000}},	//   urà_, _далё, _געאג,
  { {0xf09f02f6,0x3e6e0080,0x61e4001f,0x00000000}},	//   rrà_, _být_, _enil,
  { {0x7bc504aa,0x2ca0004e,0xa3c50042,0x00000000}},	//   vehu, erid_, उजर_,
  { {0x60cd00f7,0x5eb40121,0xf09f099f,0x00000000}},	//   _tsam, яйст, prà_,
  { {0x7bc51a6c,0x60cd1a6d,0xdfd50085,0x00000000}},	// [2630] tehu, _usam, _допы,
  { {0xbddb0164,0x43780063,0xdcfd0078,0x00000000}},	//   _chèr, שְּׁ, _nesą,
  { {0x2ca00004,0xb99501fb,0xeb4b0fce,0x00000000}},	//   arid_, قلاب, учак_,
  { {0x2ca01a6e,0xf1bf004c,0x2bc70042,0x00000000}},	//   brid_, znán_, रजहा,
  { {0xb05b0024,0x75fc013d,0x37891849,0x00000000}},	//   dväz, _jézu, абло_,
  { {0xbddb0003,0x4cba0047,0x249f0137,0x00000000}},	//   _thès, _דזשו, vrum_,
  { {0xb05b004d,0x32090792,0x32020050,0x00000000}},	//   rwäh, _olay_, ykky_,
  { {0xb05b00bd,0x46490002,0xa5f6005e,0x00000000}},	//   swäh, јзин_, жећу_,
  { {0xdb1e000c,0xc7ab007e,0xc9840074,0x00000000}},	//   cepâ, _مدال_, _хуси,
  { {0x320904d2,0x61e40829,0x387d002b,0x00000000}},	//   _alay_, _snil, mpwr_,
  { {0x249f102d,0x2d800051,0xf1bf1a6f,0x00000000}},	//   srum_, ybie_, rnán_,
  { {0x2d8b007d,0xcad60063,0x32091a70,0x00000000}},	//   _nece_, קורת_, _clay_,
  { {0xa06a1a58,0x628e00ea,0x0574014d,0x00000000}},	//   рага_, ábor, _راند,
  { {0xee3f0024,0xa3d40085,0x2ca0004b,0x00000000}},	//   _aký_, _ночч, vrid_,
  { {0x645d005f,0x50431a71,0x9e050082,0x00000000}},	//   įsid, ферб, रसंघ_,
  { {0x61e41a72,0x2ca01a73,0xf1bf013d,0x00000000}},	//   _unil, trid_, nnál_,
  { {0xbddb0003,0x2d8b007d,0x2d800ea6,0x00000000}},	// [2640] _chèq, _dece_, rbie_,
  { {0x8b26000d,0xa91d00c2,0xeaba0062,0x00000000}},	//   одзе, _težj, ийз_,
  { {0x2d8b051e,0xf1bf00ea,0x38b2001f,0x00000000}},	//   _fece_, knál_, wâr_,
  { {0xa3d50053,0x752f0051,0x2d8b005b,0x00000000}},	//   ाएँ_, żczy, _gece_,
  { {0xf1bf013d,0x00000000,0x00000000,0x00000000}},	//   dnál_,   ,   ,
  { {0x2d8b000c,0x7aea004d,0xec34007e,0x00000000}},	//   _zece_, äfts, _روزگ,
  { {0x46670766,0x8a06046e,0xab270320,0x00000000}},	//   орым_, _дзве, _дора_,
  { {0x1637043b,0x7ae1000f,0xd5b709d2,0x00000000}},	//   يسية_, _álta, ось_,
  { {0x442a0001,0xa3d50053,0x0595007e,0x00000000}},	//   ицом_, ाएं_, سايگ,
  { {0x2240000f,0x344a0699,0x320900e5,0x00000000}},	//   _akik_, јчин_, _slay_,
  { {0x32091a74,0xe73a0086,0xb05b00a5,0x00000000}},	//   _play_, _теж_, mväx,
  { {0x601000c7,0xb05b0137,0xb6a400dd,0x00000000}},	//   _jämf, lväx, _crâş,
  { {0xd2580088,0x2d8b003b,0xddcd0051,0x00000000}},	//   юць_, _rece_, ymał,
  { {0x600b0019,0x2a640af9,0xb05b0137,0x00000000}},	//   _sümb, _limb_, nväx,
  { {0xed8b0138,0x28d10161,0x65790003,0x00000000}},	//   исак_, _दैनि, _éché,
  { {0xdb1c00bd,0x7c2e00a8,0x2136006c,0x00000000}},	//   _darü, _ajbr, éché_,
  { {0x69c60026,0x3169013d,0xb05b00a5,0x00000000}},	// [2650] _ókey, _igaz_, kväx,
  { {0x9f580026,0x3a3f14ba,0x26de0387,0x00000000}},	//   skrá_, _skup_, _orto_,
  { {0xa91d1253,0x2a640089,0x78a21a75,0x00000000}},	//   _težk, _bimb_, erov,
  { {0x3f91007d,0x78a201f5,0x25da0042,0x00000000}},	//   lazu_, frov, _खोली_,
  { {0xdb150016,0xe9d8000d,0xdb1c1a76,0x00000000}},	//   _razõ, ўкі_, _baró,
  { {0xf7710fe0,0x46f5005a,0xa91d1a77,0x00000000}},	//   رات_, зчит, _ježi,
  { {0xf1bf013d,0x46a51a78,0x78a21a79,0x00000000}},	//   tnál_, чайв, arov,
  { {0x2a6400c2,0x78a2081a,0xdce40022,0x00000000}},	//   _gimb_, brov, ecię,
  { {0xdb1c0025,0xad9b0139,0x629c0331,0x00000000}},	//   _faró, _clúi, áron,
  { {0x43740086,0xa91d1a7a,0x224001e1,0x00000000}},	//   муют, _neži, _skik_,
  { {0x7bd51a7b,0x3f9e0014,0xe299005e,0x00000000}},	//   _mazu, ótum_, љам_,
  { {0xdb1c0051,0xad9b0139,0x98bf0022,0x00000000}},	//   _zaró, _flúi, _czuć_,
  { {0xa91d04c9,0x2bac0053,0xad9b0139,0x00000000}},	//   _beži, _चाला, _glúi,
  { {0xdb0500ea,0x3f8c0066,0xd7f10013,0x00000000}},	//   eghí, údu_, _tĩu_,
  { {0x25ad1a7c,0x78a20066,0x79820022,0x00000000}},	//   ogel_, zrov, ybow,
  { {0x386d00e8,0x9f63004c,0xe9ff0013,0x00000000}},	//   _ouer_, ívám_, _thẹn_,
  { {0xed57000a,0x7bd51a7d,0x75fc013d,0x00000000}},	// [2660] зот_, _bazu, _kézr,
  { {0x7bd50529,0x394400a5,0x78a21a7e,0x00000000}},	//   _cazu, _ryms_, vrov,
  { {0x7bd5004d,0xf1bf004c,0x6ffb009a,0x00000000}},	//   _dazu, znám_, _הפיג,
  { {0xdb1e00cd,0x38c8007e,0x78a21a7f,0x00000000}},	//   repà, قاتی_, trov,
  { {0x2d920035,0x7bd50089,0xdce40051,0x00000000}},	//   maye_, _fazu, ycię,
  { {0x78a21a80,0x7bd5003b,0x386d1a81,0x00000000}},	//   rrov, _gazu, _duer_,
  { {0xdb1c006d,0xb05b0137,0x6002017d,0x00000000}},	//   _varó, rväx, _cômi,
  { {0x25ad00ea,0xddcf000c,0x78a209b7,0x00000000}},	//   ggel_, _micş, prov,
  { {0xb05b0137,0x0ee90042,0xa53404d6,0x00000000}},	//   pväx, _ऑप्स_, ьнич,
  { {0xdb1c0003,0x7c3e1a82,0xb8650021,0x00000000}},	//   _abré, nopr, _قالو,
  { {0x60c40006,0x26de0290,0x2d9d0051,0x00000000}},	//   _apim, _urto_, ówek_,
  { {0x60990044,0x00000000,0x00000000,0x00000000}},	//   ينجس_,   ,   ,
  { {0x2d920009,0x463b0047,0x3f910114,0x00000000}},	//   daye_, _פעדע, tazu_,
  { {0xa3e30235,0x54530086,0x644f0003,0x00000000}},	//   _पोप_, _звіт, ïcit,
  { {0x69c0034d,0x442c02eb,0x7bd502e2,0x00000000}},	//   _obme, mnd_, _razu,
  { {0x443e1a83,0x442c02d2,0xfbd3007e,0x00000000}},	//   lot_, lnd_, کتر_,
  { {0x442c1a84,0x1df80076,0x423801f9,0x00000000}},	// [2670] ond_, четы_, _מנהל_,
  { {0x443e003d,0xf09201f9,0x69c0004d,0x00000000}},	//   not_, _שני_, _abme,
  { {0x2d921a85,0x442c1a86,0x645a0dff,0x00000000}},	//   baye_, ind_, imti,
  { {0x7bd50035,0xdb1c01a8,0xa2a40053,0x00000000}},	//   _wazu, _parò, _किन्,
  { {0xa3ac024c,0xddc401f7,0x386d1a87,0x00000000}},	//   गला_, lmiş, _quer_,
  { {0x443e003d,0xd3660032,0x7c3e051e,0x00000000}},	//   jot_, _له_, copr,
  { {0xddc4005b,0x629c00ea,0x443e1a88,0x00000000}},	//   nmiş, árol, dot_,
  { {0x386d0003,0x64481a89,0x25ad06aa,0x00000000}},	//   _tuer_, eldi, ugel_,
  { {0xda340076,0x6298051e,0x443e1a8a,0x00000000}},	//   _четы, _avvo, fot_,
  { {0x2d920035,0x443e1a8b,0x93c2003b,0x00000000}},	//   zaye_, got_, _ţăra,
  { {0x69cb0179,0x69d9001f,0xd1ca0cb5,0x00000000}},	//   oege, odwe, олне_,
  { {0x7ae300fe,0x442c1a8c,0xddcd008f,0x00000000}},	//   änty, and_, lmaņ,
  { {0x20040016,0x6e2d001f,0x69cb004d,0x00000000}},	//   êmio_, dnab, iege,
  { {0x94740021,0x76491a8d,0x443e1a8e,0x00000000}},	//   _أدنا, lley, cot_,
  { {0x7f430055,0x7c3e1a8f,0x42d50054,0x00000000}},	//   верж, vopr, _цілу,
  { {0x6e2d007a,0x76491a90,0x765b0058,0x00000000}},	//   gnab, nley, nmuy,
  { {0x3eaa000c,0x60c40035,0x4095000d,0x00000000}},	// [2680] subt_, _upim, _прэт,
  { {0x2d920003,0x6faa0021,0x600b004b,0x00000000}},	//   saye_, _بهدف_, _hümn,
  { {0x764901f7,0x600b0019,0x69cb034e,0x00000000}},	//   kley, _kümn, fege,
  { {0x69cb1a91,0x6b8e1a92,0x443e1a93,0x00000000}},	//   gege, _webg, zot_,
  { {0x64481a94,0x442c1a95,0x64431a96,0x00000000}},	//   yldi, ynd_, _okni,
  { {0xdb1c007a,0xd6b40062,0x93bc003b,0x00000000}},	//   _farð, ейкъ, lnăv,
  { {0x6b63000d,0x7649005b,0xbb460002,0x00000000}},	//   _акра, fley, _цевк,
  { {0xceb3014e,0xb05b00bd,0xf1bf00ea,0x00000000}},	//   דיה_, nwär, rnák_,
  { {0x64a3000a,0x26c50019,0x443e1a97,0x00000000}},	//   вања, _eplo_, tot_,
  { {0x442c0780,0xb05b004d,0xa2f40121,0x00000000}},	//   und_, hwär, епоч,
  { {0xe57a0088,0x442c0649,0x443e1a98,0x00000000}},	//   _дзе_, rnd_, rot_,
  { {0x7d04024a,0x20ca0053,0x644306f1,0x00000000}},	//   kyis, िबंध, _ekni,
  { {0xc1050021,0x76401a99,0xdb1e004b,0x00000000}},	//   روسي, momy, lepä,
  { {0xdb1e017d,0xddc4005b,0x60dd00b9,0x00000000}},	//   cepç, tmiş, rvsm,
  { {0x629500ea,0xb05b004d,0x69d9002b,0x00000000}},	//   ázot, fwär, ydwe,
  { {0x7c870001,0x600b0019,0xddc4005b,0x00000000}},	//   дуже, _gümn, rmiş,
  { {0xde64005a,0xdc55018e,0x6e2d1a9a,0x00000000}},	// [2690] търп, евањ, rnab,
  { {0x7649005b,0x6e2d0c29,0x9f890014,0x00000000}},	//   zley, snab, _góðu_,
  { {0x7649005b,0x76401a9b,0xe0df01f4,0x00000000}},	//   yley, komy, lvò_,
  { {0xdb1c0026,0x76400051,0xf1bf0025,0x00000000}},	//   _varð, jomy, nfá_,
  { {0x7d160051,0xad9b0025,0x4e160063,0x00000000}},	//   czys, _dlút, _נחשב_,
  { {0x78ab1a20,0x69cb1a9c,0xf8070054,0x00000000}},	//   rugv, sege, ьчен,
  { {0x7649005b,0x69cb1a9d,0xcb440caa,0x00000000}},	//   tley, pege, _ахти,
  { {0xad9b00be,0x24f5012c,0x6ec20082,0x00000000}},	//   _glút, ечор, _लहसु,
  { {0xe7e00235,0x3e7500c7,0x76491a90,0x00000000}},	//   _गोवा_, _låt_, rley,
  { {0x62810250,0xdb1e004b,0x52850074,0x00000000}},	//   tplo, bepä, нгоб,
  { {0x764900a4,0x3e7500a5,0x0ece0042,0x00000000}},	//   pley, _nåt_, _हैंड,
  { {0x62811a9e,0x96350054,0x7d160022,0x00000000}},	//   rplo, _янец, yzys,
  { {0xa3b70053,0x62811a9f,0xe5070044,0x00000000}},	//   _छाप_, splo, _تباي,
  { {0x9f9b004b,0x66091aa0,0x3e7500cf,0x00000000}},	//   jääk_, lkek, _båt_,
  { {0x8464005a,0x44251aa1,0xb05b004d,0x00000000}},	//   _ръце, mil_, twär,
  { {0xee3a019d,0x7d04024a,0x25bf00e5,0x00000000}},	//   їна_, tyis, nful_,
  { {0x44250025,0x25bf0150,0x64411aa2,0x00000000}},	// [26a0] oil_, iful_, ooli,
  { {0x7d160045,0xb05b004d,0x6e24004b,0x00000000}},	//   rzys, swär, siib,
  { {0x7d160051,0x93bc003b,0x387f1aa3,0x00000000}},	//   szys, mnăt, _atur_,
  { {0x6aa30027,0x44251aa4,0xfaa30002,0x00000000}},	//   ánfa, hil_, ѓачо,
  { {0x2fda00a4,0x64411aa5,0x44251aa6,0x00000000}},	//   _kapg_, koli, kil_,
  { {0xf093009a,0x44251aa7,0xd7e7005e,0x00000000}},	//   ננו_, jil_, емље_,
  { {0x64411aa8,0x44251aa9,0x76401aaa,0x00000000}},	//   doli, dil_, tomy,
  { {0xdb1e0019,0xcb67000d,0x629c001c,0x00000000}},	//   repä, _часе_, šrok,
  { {0x442502e0,0xddde008f,0xdbd7004b,0x00000000}},	//   fil_, _atpū, _fääs,
  { {0x64410185,0x44251aab,0xdcef001c,0x00000000}},	//   goli, gil_, _secī,
  { {0xa3b60053,0xb05b004d,0x60d61aac,0x00000000}},	//   ङ्ग_, ltäg, _asym,
  { {0x44250027,0xdb21013d,0x6441004b,0x00000000}},	//   ail_, ütés, aoli,
  { {0xc05b0086,0x44251aad,0x489b0041,0x00000000}},	//   зів_, bil_, ּילװ,
  { {0x44251aae,0xe0df0290,0xdb1c006d,0x00000000}},	//   cil_, rvò_, _abrí,
  { {0xdd95000d,0x9f340054,0x7c250050,0x00000000}},	//   кавы, гері, vihr,
  { {0x629a1aaf,0x93bc00dd,0xe7e70082,0x00000000}},	//   msto, rnău, _टोना_,
  { {0x629a1ab0,0x61ed1ab1,0x3015000d,0x00000000}},	// [26b0] lsto, _inal, _адпр,
  { {0x600b1ab2,0x629a1ab3,0xad9b0046,0x00000000}},	//   _kümm, osto, _plús,
  { {0xd011007e,0x25bf00e5,0x7c250a80,0x00000000}},	//   _ملک_, yful_, rihr,
  { {0x64411147,0xdbd7065c,0x629a1ab4,0x00000000}},	//   zoli, _sääs, isto,
  { {0xfd96014e,0x64410035,0xdbd70d68,0x00000000}},	//   _בדרך_, yoli, _pääs,
  { {0x25bf0034,0x64580093,0x44251ab5,0x00000000}},	//   wful_, _nhvi, xil_,
  { {0x25bf0034,0x44251ab6,0x629a13d7,0x00000000}},	//   tful_, vil_, jsto,
  { {0x78a40117,0x44250cc4,0x2ca91ab7,0x00000000}},	//   šiva, wil_, orad_,
  { {0x25bf1729,0x44251ab8,0x629a1ab9,0x00000000}},	//   rful_, til_, esto,
  { {0x1309026c,0x2b9c0080,0x44250992,0x00000000}},	//   дной_, mácí_, uil_,
  { {0x38bb00ac,0x44251aba,0x64411abb,0x00000000}},	//   lêr_, ril_, roli,
  { {0x44251abc,0x412a0156,0x2ca90137,0x00000000}},	//   sil_, домо_, krad_,
  { {0x69db00bd,0x660600ea,0x629a1abd,0x00000000}},	//   _maue, ökke, asto,
  { {0x2ca91abe,0x629a1abf,0x69db1ac0,0x00000000}},	//   drad_, bsto, _laue,
  { {0x539a014e,0xa0671ac1,0x2ca91ac2,0x00000000}},	//   _חיצו, тара_, erad_,
  { {0xe8df008b,0xf1bf09b1,0x3ea508f5,0x00000000}},	//   _cuịa_, lián_, álta_,
  { {0x8e550086,0x3b960095,0x93bc003b,0x00000000}},	// [26c0] утрі, вјет, mnăr,
  { {0x61ed03a4,0xaf0601fe,0x3157009a,0x00000000}},	//   _znal, _апол, _ביפן_,
  { {0x69db103b,0x93bc003b,0x2ca91ac3,0x00000000}},	//   _baue, onăr, arad_,
  { {0xfaa30088,0x2ca91ac4,0x3c94007e,0x00000000}},	//   рацо, brad_, _میرز,
  { {0x69db00bd,0xa9670d4c,0xd7fa02fa,0x00000000}},	//   _daue, вица_, дуй_,
  { {0xbcfb000f,0xdb210024,0x3f981ac5,0x00000000}},	//   _egés, štát, naru_,
  { {0x48ee0053,0xfaa60002,0x629a1233,0x00000000}},	//   _आपको_, _јабо, xsto,
  { {0x7bdc014f,0x76591ac6,0x7f3b0063,0x00000000}},	//   _haru, _chwy, ועצו,
  { {0x2603048e,0x7866000d,0x7bdc1ac7,0x00000000}},	//   _años_, _аказ, _karu,
  { {0x7bde0d5e,0x629a1ac8,0x7bdc1ac9,0x00000000}},	//   ndpu, tsto, _jaru,
  { {0x629a1aca,0x7bdc1acb,0x04430002,0x00000000}},	//   usto, _maru, реќн,
  { {0x7bdc1acc,0x9293000d,0xe8df0013,0x00000000}},	//   _laru, шаюц, _uyển_,
  { {0x3f98002b,0xf1bf0331,0x63f60044,0x00000000}},	//   faru_, bián_, _لأغر,
  { {0x629a1acd,0xc9530063,0x7bde0137,0x00000000}},	//   psto, שמש_, jdpu,
  { {0xcddb005e,0x7f94007f,0x6e940121,0x00000000}},	//   мња_, расх, ииру,
  { {0x61ed075a,0x2ca91ace,0xddc40022,0x00000000}},	//   _unal, trad_, elił,
  { {0x7bdc0009,0xe390001b,0x7d550062,0x00000000}},	// [26d0] _baru, _điề, увах,
  { {0x600b005b,0x69db1acf,0xdfd1007e,0x00000000}},	//   _mümk, _saue, _ايد_,
  { {0x2ca90137,0x7bdc1ad0,0x69db007d,0x00000000}},	//   srad_, _daru, _paue,
  { {0xc33301f9,0x601000c7,0xc987005e,0x00000000}},	//   בוע_, _jämn, тужи,
  { {0x76590185,0x621c0047,0xa928004c,0x00000000}},	//   _rhwy, וואק, vyžá,
  { {0x601000c7,0x7bdc1ad1,0x38bb00e8,0x00000000}},	//   _lämn, _garu, rêr_,
  { {0x8cdb0053,0x68e2082a,0x7659001f,0x00000000}},	//   निको, avod, _phwy,
  { {0x601000c7,0x24590003,0xe8e00013,0x00000000}},	//   _nämn, ième_, huột_,
  { {0x24591090,0x63a70022,0x9525005d,0x00000000}},	//   hème_, ójno, دکام,
  { {0x6b95007d,0x23d50ae8,0x87d7002a,0x00000000}},	//   _jezg, уцир, _جغرا,
  { {0xa22a0ae8,0x7659002b,0x3f981ad2,0x00000000}},	//   ежна_, _thwy, varu_,
  { {0x6248006d,0x24590003,0x3f981ad3,0x00000000}},	//   eñor, dème_, waru_,
  { {0x93bc003b,0x3f981ad4,0x95670062,0x00000000}},	//   rnăr, taru_, _ръжд,
  { {0xdd2f0080,0x2a6d004d,0x79990150,0x00000000}},	//   měňo, _lieb_, haww,
  { {0xdb1c0512,0xada60b3f,0x68e21871,0x00000000}},	//   _obrá, лавл, zvod,
  { {0x7bdc1ad5,0x394d0331,0x3f981ad6,0x00000000}},	//   _saru, _oyes_, saru_,
  { {0x22980080,0xf1bf00ea,0xee3706c3,0x00000000}},	// [26e0] _týká_, rnát_, унт_,
  { {0xb05b00fe,0x4d631ad7,0x2b160766,0x00000000}},	//   ttäe, скув, льер,
  { {0x6b95003b,0x6010004d,0x7bdc1ad8,0x00000000}},	//   _dezg, _hämo, _varu,
  { {0x02b60047,0x6abe004d,0x7bdc1ad9,0x00000000}},	//   טלעך_, rtpf, _waru,
  { {0xa3b3016a,0x7bdc0f2b,0xb05b0072,0x00000000}},	//   टला_, _taru, stäe,
  { {0xa09b0149,0x394d00e5,0x6b950058,0x00000000}},	//   גיסט, _dyes_, _gezg,
  { {0x394d0034,0xb05b0137,0xfd500013,0x00000000}},	//   _eyes_, ltäc, _nghẹ,
  { {0xa5bd0078,0xfa670094,0xa6c7009b,0x00000000}},	//   liųj, _баск_, اويل_,
  { {0x27ef0080,0x75fc00ea,0x99160085,0x00000000}},	//   ální_, _kézz, _сьві,
  { {0x224900b9,0x1cbb0047,0x986a0044,0x00000000}},	//   _skak_, עמיע, _أحرف_,
  { {0xe9ff008b,0x2bc60053,0xdddc00c2,0x00000000}},	//   _chặn_, र्या, zprš,
  { {0x54e60242,0xdddc0195,0xdb05004d,0x00000000}},	//   _مستق, yprš, pfhö,
  { {0x3d000053,0x75d3009e,0x62831ada,0x00000000}},	//   ोनों_, _دينا, _etno,
  { {0x75fc000f,0x2bc60161,0x24590003,0x00000000}},	//   _nézz, र्मा, tème_,
  { {0x66021adb,0xce950062,0xaed50054,0x00000000}},	//   _kook, рабъ, шовш,
  { {0x66020004,0x24590003,0x62881adc,0x00000000}},	//   _jook, rème_, mpdo,
  { {0x20010019,0x8234007e,0xd0d50062,0x00000000}},	// [26f0] _tohi_, _دروا, _топъ,
  { {0x66020034,0x60cd002c,0x7d0200fe,0x00000000}},	//   _look, _ipam, äosa,
  { {0xf09f01a8,0xdddc007d,0xbcfb013d,0x00000000}},	//   lsà_, sprš, _egép,
  { {0xfde90042,0x5efa089e,0xeb480094,0x00000000}},	//   _ऑफिस_, _ספרד, учук_,
  { {0xa9350076,0xf09f00cd,0x200c0137,0x00000000}},	//   шедш, nsà_, ödig_,
  { {0x60100832,0x807c0041,0x2c6d005f,0x00000000}},	//   _näml, ענוצ, _iždo_,
  { {0xe5710021,0x66021add,0xc9871367,0x00000000}},	//   يطة_, _book, _бузи,
  { {0x7aea010a,0x46e60062,0x66021ade,0x00000000}},	//   æfte, рдън_, _cook,
  { {0xc7d90062,0xf1bf0240,0x84590002,0x00000000}},	//   _имах_, riál_, крот_,
  { {0xe4c80021,0x03a50092,0x44d60022,0x00000000}},	//   ابين_, јино, _dł_,
  { {0x244b05b9,0x6602004b,0xa5d50002,0x00000000}},	//   dømt_, _fook, _вжеш,
  { {0x0166042c,0xb34500cd,0x20050014,0x00000000}},	//   икно, _alçà, ölin_,
  { {0xe0d7011c,0x998f0006,0x291d05b3,0x00000000}},	//   авя_, logų_, nzwa_,
  { {0x8e860121,0x0fd90145,0xa06a01ce,0x00000000}},	//   игге, льсы_, ђава_,
  { {0x44d60051,0x249f1adf,0x69c901a8,0x00000000}},	//   _zł_, lsum_, _obee,
  { {0xdcfd008f,0x68e91ae0,0x40960cd6,0x00000000}},	//   _nesē, _ored, _крот,
  { {0x249f1ae1,0x6d4f1ae2,0x4c850021,0x00000000}},	// [2700] nsum_, _cyca, مؤلف,
  { {0x515b014e,0x4f260121,0x309b0063,0x00000000}},	//   _בכפו, _вдоб, _ששימ,
  { {0xdef90088,0xf1eb0053,0xb05b0137,0x00000000}},	//   _быў_, _जोड़_, stäc,
  { {0xb05b00c7,0xda650032,0xa5bd0078,0x00000000}},	//   ptäc, ماني, siųj,
  { {0x68e91ae3,0x3e7c0013,0x5cf60121,0x00000000}},	//   _cred, _hít_, _тяну,
  { {0xb8ce0394,0xc6a602b3,0x2d801ae4,0x00000000}},	//   _कि_, арии, lcie_,
  { {0x3e7c0080,0x68e91ae5,0x56940612,0x00000000}},	//   _jít_, _ered, щайт,
  { {0x3e7c0080,0x95ca0ace,0x44271ae6,0x00000000}},	//   _mít_, тука_, _amn_,
  { {0x442707b7,0x3e7c0013,0xe9ff0013,0x00000000}},	//   _bmn_, _lít_, _chẵn_,
  { {0xe3b8005b,0x2ca0004b,0x2a78004b,0x00000000}},	//   lnız_, isid_, _kurb_,
  { {0x2d8006ce,0xf7460002,0xe7370062,0x00000000}},	//   kcie_, _тежо, _кеф_,
  { {0x2ca00004,0x2bc60161,0xe4e60086,0x00000000}},	//   ksid_, र्ता, _вікн,
  { {0x60100137,0x25a61ae7,0xdce40023,0x00000000}},	//   _täml, _idol_, gaiļ,
  { {0x2d800051,0x2ca00019,0x629c00ea,0x00000000}},	//   ecie_, dsid_, áros,
  { {0xf09f1ae8,0x6448168b,0x244b06a5,0x00000000}},	//   ssà_, modi, rømt_,
  { {0xef190051,0x13170063,0x442c1ae9,0x00000000}},	//   ąż_, _כחול_, lid_,
  { {0x442c0122,0x64480213,0x60cd1aea,0x00000000}},	// [2710] oid_, oodi, _upam,
  { {0x64481aeb,0x442c1aec,0x7e64004b,0x00000000}},	//   nodi, nid_, amip,
  { {0x2bc60161,0x68e9065f,0x2a7800e5,0x00000000}},	//   र्धा, _sred, _curb_,
  { {0x68e91aed,0x442c1aee,0x2d801aef,0x00000000}},	//   _pred, hid_, ccie_,
  { {0x89a80086,0xb9c40021,0x64481af0,0x00000000}},	//   рків_, تقني, kodi,
  { {0x6e2d0034,0x68e91af1,0x442c1496,0x00000000}},	//   liab, _vred, jid_,
  { {0x442c1af2,0x2a780025,0x5692005e,0x00000000}},	//   did_, _gurb_, пајт,
  { {0x68e91781,0xdb160139,0x0f380063,0x00000000}},	//   _tred, _ócái, ירוט_,
  { {0x2d99051e,0x68e9065f,0x44270089,0x00000000}},	//   _mese_, _ured, _pmn_,
  { {0x2d99076c,0x33f50940,0x442c1af3,0x00000000}},	//   _lese_, счис, gid_,
  { {0x249f007a,0x8c1a0063,0x2d800051,0x00000000}},	//   ssum_, רותי, ycie_,
  { {0xc879005b,0x442c1af4,0x63c3008f,0x00000000}},	//   _kuş_, aid_, _žunā,
  { {0x442c1af5,0xddc6007d,0x6e2d1af6,0x00000000}},	//   bid_, _nikš, diab,
  { {0x64480641,0x7d0d1af7,0x442c1af8,0x00000000}},	//   codi, dyas, cid_,
  { {0x6e2d04bc,0x2d9900a4,0xddc60078,0x00000000}},	//   fiab, _bese_, _aikš,
  { {0xdb17017d,0x2d99006d,0x2ca00019,0x00000000}},	//   nexõ, _cese_, tsid_,
  { {0x6e360006,0x61eb0025,0x7fd60454,0x00000000}},	// [2720] rnyb, _ógla, _ліні,
  { {0x2ca00019,0xb05b10f0,0xe0fb0063,0x00000000}},	//   rsid_, ltän, _עליל,
  { {0x2ca00019,0xd24f007e,0x329a0041,0x00000000}},	//   ssid_, _زنی_, ָבנד,
  { {0x753d0051,0x2d9900ac,0x6e2d1af9,0x00000000}},	//   ższy, _gese_, ciab,
  { {0x91bb0063,0xdb1e00ea,0x6448005b,0x00000000}},	//   רמני, lepü, yodi,
  { {0xf0930063,0x442c1afa,0x98a70058,0x00000000}},	//   לנד_, xid_, şiği_,
  { {0x644806b9,0x07a30d34,0x09e60263,0x00000000}},	//   vodi, чајн, _ловн,
  { {0x442c1afb,0xf1bf00ea,0xd5ba1afc,0x00000000}},	//   wid_, riák_, уск_,
  { {0x38cb006a,0x442c1afd,0x64481afe,0x00000000}},	//   _مالی_, tid_, todi,
  { {0x3e4100eb,0x661b1aff,0x442c1b00,0x00000000}},	//   mėte_, ahuk, uid_,
  { {0x95ca019d,0x442c1b01,0x64481b02,0x00000000}},	//   _була_, rid_, rodi,
  { {0x442c0004,0x661b0009,0x64481b03,0x00000000}},	//   sid_, chuk, sodi,
  { {0x2d990290,0x248600c7,0x6b9e00a4,0x00000000}},	//   _rese_, _utom_, kapg,
  { {0x20050026,0x46dc0042,0x7d0d0072,0x00000000}},	//   ðli_, _मनाह, vyas,
  { {0x2d9902dd,0x53331b04,0xb425002a,0x00000000}},	//   _pese_, _нешт, _بعنو,
  { {0x3e410006,0x7e550086,0xddc6008f,0x00000000}},	//   kėte_, іває, _pikš,
  { {0x7c970021,0x5c740002,0x6e2d0897,0x00000000}},	// [2730] إشرا, злут, riab,
  { {0x3e410006,0x78a21244,0x2d9900ac,0x00000000}},	//   dėte_, dsov, _wese_,
  { {0x7d0d01f7,0xe37b0047,0x2d991b05,0x00000000}},	//   syas, ארבר, _tese_,
  { {0xb9550612,0x7d0d005b,0x9cf50085,0x00000000}},	//   овещ, pyas, _дзмі,
  { {0x6e3d006f,0x3e410078,0xb23c0047,0x00000000}},	//   _ijsb, gėte_, נעדז,
  { {0x6d5d001c,0x18691b06,0xba77009e,0x00000000}},	//   _izsa, шали_, _هارت,
  { {0xb05b024a,0x36190121,0x6fac0042,0x00000000}},	//   ytän, ицию_, _जयसू,
  { {0xc48512ad,0x34a90001,0x7bd7003b,0x00000000}},	//   олик, авио_, lexu,
  { {0x26de1b07,0x2bc60161,0xe6160086,0x00000000}},	//   _esto_, र्वा, ідь_,
  { {0x661b0035,0x799b00ac,0x78a600b9,0x00000000}},	//   shuk, _heuw, _ækva,
  { {0xb05b024a,0xd7f8008b,0xe2990d34,0x00000000}},	//   ttän, _khăn_, јам_,
  { {0xcf890ee1,0x04c90021,0x90c61b08,0x00000000}},	//   _יט_, _نوصي_, обме,
  { {0x290f0078,0x89da0063,0xb05b1b09,0x00000000}},	//   nyga_, בחרי, rtän,
  { {0xb05b1b0a,0x799b0150,0x0467005e,0x00000000}},	//   stän, _leuw, _утем,
  { {0x7bd71b0b,0x79820022,0xdee3012d,0x00000000}},	//   dexu, ycow, мори,
  { {0xe1ff006d,0xd5f90047,0x224b1b0c,0x00000000}},	//   lmón_, ספּר, cock_,
  { {0xad66006a,0xce470085,0x8f760083,0x00000000}},	// [2740] زاره, ізуе_, _муні,
  { {0x61e61b0d,0xb05b0d90,0x3e410078,0x00000000}},	//   ldkl, ntäl, vėte_,
  { {0x61e400bb,0xfe460854,0x20c40072,0x00000000}},	//   _kail, _мноо, löi_,
  { {0x61e60162,0x3e410006,0xdcfd0006,0x00000000}},	//   ndkl, tėte_, _nesė,
  { {0xc7ba0088,0x8d660086,0x63ba00b9,0x00000000}},	//   аёй_, _євге, ygtn,
  { {0xacd900b5,0x799b0122,0x2cb20185,0x00000000}},	//   _פֿרי, _eeuw, mryd_,
  { {0xa01b00fe,0xa7140054,0x78a21b0e,0x00000000}},	//   mpöt, ямкі, ssov,
  { {0x78ad0117,0x6b9c1b0f,0x61e41b10,0x00000000}},	//   šava, _herg, _nail,
  { {0x6b9c0019,0x7aee00c2,0x80da0042,0x00000000}},	//   _kerg, _hrbt, _पैले,
  { {0x61f6001f,0xdb1c017d,0x2fd801e1,0x00000000}},	//   _anyl, _acré, jerg_,
  { {0xb4e30161,0x61e41b11,0x6b9c09ee,0x00000000}},	//   कटॉप_, _bail, _merg,
  { {0x201a07de,0x61e414bd,0xe1ff0331,0x00000000}},	//   _alpi_, _cail, amón_,
  { {0x660f0d88,0x61e41b12,0x2d921b13,0x00000000}},	//   öcke, _dail, dbye_,
  { {0x3eb81b14,0x6b9c1b15,0x2cb2002b,0x00000000}},	//   furt_, _nerg, dryd_,
  { {0x9e070086,0x61e41b16,0xdd9b0f55,0x00000000}},	//   очал, _fail, иша_,
  { {0x2cb2001f,0x3ead0114,0x61e41b17,0x00000000}},	//   fryd_, čet_, _gail,
  { {0xc05b019d,0x6b9c1b18,0xb05b00fe,0x00000000}},	// [2750] _він_, _berg, ltäm,
  { {0x3eb800bd,0x6b9c1b19,0x61e40089,0x00000000}},	//   burt_, _cerg, _zail,
  { {0xb05b00fe,0x23c20053,0x3ce9004b,0x00000000}},	//   ntäm, _शानद, svav_,
  { {0x6b9c006f,0x2cb21b1a,0x290f0137,0x00000000}},	//   _eerg, bryd_, tyga_,
  { {0xd9450002,0x7aee004d,0x6d5d0023,0x00000000}},	//   џели, _erbt, _uzsa,
  { {0x3abb006a,0x6b9c1b1b,0xa69500e1,0x00000000}},	//   _پاسخ_, _gerg, приј,
  { {0x19951a02,0x4e0f0042,0x99d7009b,0x00000000}},	//   _навя, _सवाई_, _وترا,
  { {0xd6ce0032,0xc6680001,0x6b85001f,0x00000000}},	//   اقي_, ошње_, lchg,
  { {0x6d4300bd,0x27f60080,0x61e41b1c,0x00000000}},	//   ßnah, ádní_, _rail,
  { {0x94220076,0x69d91b1d,0x61e40399,0x00000000}},	//   емье, lewe, _sail,
  { {0xef200051,0x6b8500bd,0x69d9006f,0x00000000}},	//   ążki_, ichg, oewe,
  { {0xb05b01e3,0x60100137,0x614606b4,0x00000000}},	//   stäl, _jämv, зема,
  { {0xf9920063,0x61e41b1e,0x61e600b8,0x00000000}},	//   ערך_, _vail, rdkl,
  { {0xdff5000d,0xb05b00fe,0x20c40072,0x00000000}},	//   мясь, ltäj, röi_,
  { {0x26c702e2,0x63a11b1f,0x69d91b20,0x00000000}},	//   ntno_, maln, kewe,
  { {0x2cb21b21,0x63a11b22,0x625d0003,0x00000000}},	//   tryd_, laln, léon,
  { {0x69d91a33,0xee370086,0x6b9c1b23,0x00000000}},	// [2760] dewe, їну_, _perg,
  { {0xdce6003d,0x26c701b3,0x63a11b24,0x00000000}},	//   _iekļ, ktno_, naln,
  { {0x69cb004d,0x78b9006f,0x6b9c1b25,0x00000000}},	//   ffge, euwv, _verg,
  { {0xe8fa093e,0x69d91b26,0x3209008b,0x00000000}},	//   йле_, gewe, _xoay_,
  { {0x3a3f02eb,0x6b9c003e,0x63a11b27,0x00000000}},	//   _djup_, _terg, kaln,
  { {0xb05b00fe,0xddc40051,0x63a1107f,0x00000000}},	//   ytäm, yliś, jaln,
  { {0x8c1b014e,0x69d91b28,0x7c2e0b83,0x00000000}},	//   _פולי, bewe, _imbr,
  { {0xbb3b01f9,0xd5e2008b,0x44f41b29,0x00000000}},	//   _העלי, _khỏ, дпис,
  { {0x3e410078,0x27170013,0xdce6008f,0x00000000}},	//   nėta_, ãn_, _nekļ,
  { {0xb05b024a,0x22810014,0x63a11b2a,0x00000000}},	//   ttäm, _bók_, galn,
  { {0x31601b2b,0xe1d9019d,0x61d90062,0x00000000}},	//   _aziz_, одні_, омня_,
  { {0x63a10019,0xb05b00fe,0xe71711b4,0x00000000}},	//   aaln, rtäm, _מחבר_,
  { {0xb05b052c,0xd62501a7,0xdb2300ea,0x00000000}},	//   stäm, _تعلي, _örök,
  { {0x3e410006,0x225200ac,0x250b005d,0x00000000}},	//   dėta_, _ekyk_, _درمی_,
  { {0x628a02f0,0xdef8000d,0x7e7e1b2c,0x00000000}},	//   _utfo, пыт_, _cupp,
  { {0x7c2e1b2d,0xc3330063,0x6b85002b,0x00000000}},	//   _ambr, _רוק_, wchg,
  { {0x93bd0047,0xb05b0b6e,0x5d550094,0x00000000}},	// [2770] _אַלף_, ntäk, фкат,
  { {0x9ce4000d,0xf1bf00be,0xdb6b0121,0x00000000}},	//   эцсл, lgá_, брел_,
  { {0x6b8500bd,0xd7f8008b,0x69d905e9,0x00000000}},	//   rchg, _chăm_, tewe,
  { {0x69cb00bd,0xf1bf017d,0x6b85004d,0x00000000}},	//   ufge, ngá_, schg,
  { {0x37e503ec,0x7e7e01f4,0x69d9120e,0x00000000}},	//   долг, _zupp, rewe,
  { {0x69d91b2e,0x9be4071f,0xf8070505,0x00000000}},	//   sewe, _піск, ячен,
  { {0x63a10198,0xb05b024a,0xdb2300fe,0x00000000}},	//   valn, ttäj, ärän,
  { {0x601001e3,0x672300c2,0x26c702f7,0x00000000}},	//   _hämt, rznj, rtno_,
  { {0x63a11b2f,0x26c700c3,0x93fd000d,0x00000000}},	//   taln, stno_, аўнi,
  { {0x60100137,0xb05b00fe,0x7d020072,0x00000000}},	//   _jämt, stäj, äosi,
  { {0x56940138,0x2bcf0053,0x387f0104,0x00000000}},	//   _захт, स्या, _huur_,
  { {0x63a1014f,0x7e7e02e0,0x600b07be,0x00000000}},	//   saln, _rupp, _sümp,
  { {0xa5bd00eb,0x7e7e1b30,0xe44e0454,0x00000000}},	//   siųs, _supp, _аж_,
  { {0x22810026,0x387f0983,0xe46b0121,0x00000000}},	//   _tók_, _muur_, _ушел_,
  { {0x41c60053,0x93450eaf,0x00000000,0x00000000}},	//   _वापस, _юнке,   ,
  { {0x25bf1b31,0xd5e20013,0xdb08004c,0x00000000}},	//   ngul_, _phỏ, ílít,
  { {0xed570079,0xb5fd00c2,0xdca3150f,0x00000000}},	// [2780] дот_, emšk, кати,
  { {0x660b0146,0x8d630076,0x4d630086,0x00000000}},	//   _logk, твуе, ткув,
  { {0x78a902f6,0xb9e60086,0x0e661702,0x00000000}},	//   _avev, діли, _окон,
  { {0xd5e2008b,0xd378007d,0xdb1e0072,0x00000000}},	//   _thỏ, meće_, kepö,
  { {0xd378007d,0xb86a005e,0x02da0042,0x00000000}},	//   leće_, ојке_, _बन्न,
  { {0xd7f8001b,0x387f0173,0x368a0086,0x00000000}},	//   _thăm_, _duur_, осин_,
  { {0x660b01e1,0x7c3e0137,0xd5ba0054,0x00000000}},	//   _bogk, mnpr, осп_,
  { {0x973c017f,0xb05b00fe,0x94aa0002,0x00000000}},	//   _neće, ttäk, отоа_,
  { {0x47c60138,0xe3ce001b,0x387f00ac,0x00000000}},	//   _обав, _dựng_, _guur_,
  { {0x7e660150,0x25bf003b,0x7c3e1b32,0x00000000}},	//   _lhkp, agul_, nnpr,
  { {0x0bb7014e,0xd378017f,0xe2f80086,0x00000000}},	//   ולים_, jeće_, чені_,
  { {0xd3780117,0x00000000,0x00000000,0x00000000}},	//   deće_,   ,   ,
  { {0x442e09fe,0xbcfb00be,0xb05b078c,0x00000000}},	//   _tmf_, _ozéa, ltäi,
  { {0x8ca20053,0x00000000,0x00000000,0x00000000}},	//   गठनो,   ,   ,
  { {0xadd50001,0x443e1233,0x7687005b,0x00000000}},	//   новљ, mnt_, _kıya,
  { {0x645a1b33,0x601000bd,0xf1d0008b,0x00000000}},	//   llti, _sämt, _hạng_,
  { {0x5cb90088,0x645a17c2,0x2d580376,0x00000000}},	// [2790] ялаў_, olti, дить_,
  { {0x443e1b34,0x2bbb0021,0xdb1e004b,0x00000000}},	//   nnt_, تارة_, hepõ,
  { {0xf1d0001b,0x916d008b,0x387f1b35,0x00000000}},	//   _mạng_, _hồi_, _suur_,
  { {0x443e00bd,0x32190186,0xdb1c0025,0x00000000}},	//   hnt_, nksy_, _gcrí,
  { {0x99d40021,0x7e6d1b36,0x1bbb00f2,0x00000000}},	//   ئتما, mmap, _واسع_,
  { {0x443e0122,0xd366006a,0x387f006f,0x00000000}},	//   jnt_, _مه_, _vuur_,
  { {0x7ac41240,0xc8780075,0xb05b004e,0x00000000}},	//   _исте, _diğ_, rtäh,
  { {0x387f00e8,0x645a0026,0xb05b0019,0x00000000}},	//   _tuur_, elti, stäh,
  { {0x2bcf0161,0xa9540086,0x443e0026,0x00000000}},	//   स्था, _акті, fnt_,
  { {0xd378017f,0x73050d34,0x3e410078,0x00000000}},	//   zeće_, епоз, kėto_,
  { {0xf1d0001b,0x25a4002b,0xdb07004c,0x00000000}},	//   _dạng_, baml_, _odjí,
  { {0x2bcf0161,0x7afa00ea,0x2ca9004b,0x00000000}},	//   स्ता, _átte, ksad_,
  { {0xa155011c,0x973c007d,0xddc4005b,0x00000000}},	//   върш, _veće, eliş,
  { {0xdb1c0027,0x66060026,0x201e0026,0x00000000}},	//   _scrí, ökkv, óti_,
  { {0x7d0b0137,0x60100137,0xd378007d,0x00000000}},	//   ägsn, _säms, teće_,
  { {0x64b5005b,0x20180f49,0x42d40054,0x00000000}},	//   _eğiş, skri_, _рішу,
  { {0x1016000d,0xd378007d,0xfe431b37,0x00000000}},	// [27a0] _зьня, reće_, унто,
  { {0xaf9a0055,0x24820024,0xf5360047,0x00000000}},	//   _этих_, íkmi_, ײטער_,
  { {0x3f981b38,0x7e6d153a,0xb4160047,0x00000000}},	//   mbru_, bmap, עקעס_,
  { {0xda650021,0xe9e50086,0x0f370047,0x00000000}},	//   ناني, кціо, _טריט_,
  { {0x443e1b33,0x629c013d,0xc237009a,0x00000000}},	//   ynt_, ároz, ערנו_,
  { {0xb05b024a,0xf6e60699,0x6e24013d,0x00000000}},	//   ttäi, ецин, lhib,
  { {0x8c430928,0x443e02ab,0x7bde0035,0x00000000}},	//   _сере, vnt_, mepu,
  { {0x443e1b39,0xa7370021,0xa3d20053,0x00000000}},	//   wnt_, عثور_, ह्न_,
  { {0x6846000a,0xdb1c017d,0xb05b078c,0x00000000}},	//   _знаа, _ucrâ, stäi,
  { {0xb05b024a,0xe8d70063,0x7bde1b3a,0x00000000}},	//   ltäv, _אומר_, nepu,
  { {0x68e2002b,0x443e1b3b,0xa1950895,0x00000000}},	//   lwod, rnt_, канч,
  { {0x765b048e,0xb05b00fe,0x7bde004d,0x00000000}},	//   cluy, ntäv, hepu,
  { {0xf1d0008b,0x6e240035,0x66060014,0x00000000}},	//   _tạng_, dhib, ökku,
  { {0xb05b024a,0x60100137,0x251b0047,0x00000000}},	//   htäv, _sämr, _צוגא,
  { {0x7bde1b3c,0x916d0013,0x6e670062,0x00000000}},	//   depu, _dối_, етаж,
  { {0x7e6d00a4,0x916d0013,0x2ca9065e,0x00000000}},	//   umap, _tồi_, tsad_,
  { {0xd90404de,0x7e6d1b3d,0xdb1c0051,0x00000000}},	// [27b0] _ای_, rmap, _obró,
  { {0x6e24005b,0x7e6d0d14,0x7bde1b3e,0x00000000}},	//   ahib, smap, gepu,
  { {0x2ca900c7,0x76400014,0x69c2006f,0x00000000}},	//   ssad_, knmy, fgoe,
  { {0xddc4003b,0x5a350062,0x6e241b3f,0x00000000}},	//   rmiţ, ънет, chib,
  { {0x60100832,0xadf40085,0x26040042,0x00000000}},	//   _kämp, _спяш, वानी_,
  { {0x7bde0529,0xec350047,0x764000fe,0x00000000}},	//   cepu, _יאָר_, enmy,
  { {0x765b0058,0x68e20022,0x78bc0023,0x00000000}},	//   tluy, awod, _ārve,
  { {0x601004e1,0x6447074f,0xc8f50062,0x00000000}},	//   _lämp, čjim, _избъ,
  { {0x200c00ea,0xe1ff0051,0x765b1b40,0x00000000}},	//   ödik_, lmów_, rluy,
  { {0xa934000a,0x765b0014,0x2496005d,0x00000000}},	//   _сеуш, sluy, کنید_,
  { {0x916d0013,0x765b0058,0x23291b41,0x00000000}},	//   _rối_, pluy, фони_,
  { {0x7aea00b9,0x7bde0022,0x65951b42,0x00000000}},	//   æfti, zepu, _раду,
  { {0xc2431b43,0xbcfb013d,0x00000000,0x00000000}},	//   рняк, _szén,   ,
  { {0xc0e30856,0x7d160072,0x66091b44,0x00000000}},	//   јорк, vyys, ljek,
  { {0xb05b00fe,0xada60086,0x6e240441,0x00000000}},	//   ytäv, кавл, thib,
  { {0x68e20185,0x7bd500bd,0x66091b45,0x00000000}},	//   ywod, _abzu, njek,
  { {0x60260088,0x64410102,0x916d001b,0x00000000}},	// [27c0] _адпа, onli, _tối_,
  { {0x64411b46,0x6e241b47,0x63a31a28,0x00000000}},	//   nnli, shib, _jenn,
  { {0xb05b024a,0x63a304b1,0x7d1600fe,0x00000000}},	//   ttäv, _menn, syys,
  { {0x644100bd,0x3a200025,0x63a31b48,0x00000000}},	//   hnli, óip_, _lenn,
  { {0x7d0b1b49,0xe3a7007e,0x62831b4a,0x00000000}},	//   øgst, _پر_, _luno,
  { {0x64410122,0x63a300bd,0xb05b0bb7,0x00000000}},	//   jnli, _nenn, stäv,
  { {0x29000529,0x45d4000d,0x6f08004d,0x00000000}},	//   ţia_, гойс, ädch,
  { {0x661b002c,0xd378017f,0x64411b4b,0x00000000}},	//   gkuk, jeća_, enli,
  { {0x916d001b,0xd378017f,0x6aa104aa,0x00000000}},	//   _mỗi_, deća_, _ælfr,
  { {0x916d001b,0x661b1b4c,0x29550062,0x00000000}},	//   _lỗi_, akuk, _съср,
  { {0x62830529,0x60100019,0xddc4027c,0x00000000}},	//   _cuno, _rämp, zmiš,
  { {0x4425004d,0x27ec00e5,0x62831b4d,0x00000000}},	//   ahl_, _hadn_, _duno,
  { {0xc05b019d,0xb6350047,0x63a31b4e,0x00000000}},	//   дів_, _גרײס_, _fenn,
  { {0x63a31b4f,0xdfd80062,0x44251b50,0x00000000}},	//   _genn, къс_, chl_,
  { {0x6458001c,0x6283003b,0x9f411b51,0x00000000}},	//   _ikvi, _guno, _bahá_,
  { {0x3377014e,0xf3650086,0x78ad0ef0,0x00000000}},	//   _בתוך_, _стін, šavi,
  { {0xde580086,0x39490051,0x61ed00a4,0x00000000}},	// [27d0] таті_, żasz_, _iaal,
  { {0x61ed1b52,0xddc4007d,0xb05b004d,0x00000000}},	//   _haal, rmiš, ttäu,
  { {0x63a80024,0x61ed1b53,0xfe6e007e,0x00000000}},	//   iadn, _kaal, تگی_,
  { {0xc3330063,0xb05b004d,0x7d0b01e1,0x00000000}},	//   סוף_, rtäu, øgss,
  { {0x39490016,0x6609017f,0xa9540086,0x00000000}},	//   ças_, vjek, акці,
  { {0xab94019d,0x973c017f,0xd378017f,0x00000000}},	//   _вирі, _seća, zeća_,
  { {0x644102ab,0xb05b00fe,0x63a31b54,0x00000000}},	//   vnli, ltäs, _renn,
  { {0x3a260122,0x7ada0047,0xff7c0063,0x00000000}},	//   chop_, _אַמה, וטומ,
  { {0x661b1b55,0xb05b00fe,0x66090019,0x00000000}},	//   rkuk, ntäs, rjek,
  { {0xe3b10032,0x66091b56,0x661b024a,0x00000000}},	//   حرة_, sjek, skuk,
  { {0xc5d5019d,0x63a30398,0xbcfb00ea,0x00000000}},	//   _біль, _venn, _szél,
  { {0x26040053,0x7e7d0745,0x63a31b57,0x00000000}},	//   वाणी_, _nisp, _wenn,
  { {0xf484000a,0x61ed04a1,0xb05b0072,0x00000000}},	//   _кујн, _daal, ytät,
  { {0x628300a4,0x7e7d0025,0xb05b00a5,0x00000000}},	//   _tuno, _aisp, xtät,
  { {0xb05b1b58,0x61ed005b,0xa0671321,0x00000000}},	//   kräf, _faal, уара_,
  { {0xa3ab0235,0xd5e2001b,0xc69211b4,0x00000000}},	//   गणक_, _khó, מאל_,
  { {0x4d660785,0x8b960121,0xb05b0ede,0x00000000}},	// [27e0] укав, греч, ttät,
  { {0x69c9000c,0xab2a06b4,0x309b0a7a,0x00000000}},	//   _acee, ноза_, _רשימ,
  { {0x68e91b59,0xdd12008f,0x0af6000d,0x00000000}},	//   _ased, _kļūt, ычаў,
  { {0x63a800c3,0xb05b0ae2,0x1d0a06be,0x00000000}},	//   zadn, stät, _земи_,
  { {0xd5e2001b,0x522d0041,0xa9670131,0x00000000}},	//   _nhó, וואַ, гица_,
  { {0xdd3b00b5,0x3a261b5a,0xcaa60021,0x00000000}},	//   _װעלכ, shop_, _مصري,
  { {0x63a8018a,0xd5e2008b,0x3a261b5b,0x00000000}},	//   vadn, _phò, phop_,
  { {0xe4e6019d,0xa2810051,0xd49a0b69,0x00000000}},	//   гіон, łość_, нро_,
  { {0x39460001,0xd5e2008b,0xe1ff0139,0x00000000}},	//   _снаг, _chó, llóg_,
  { {0xc94b0063,0x656f004c,0x61ed1b5c,0x00000000}},	//   _אֲבֹ, ýcha, _saal,
  { {0x61ed002c,0xb05b00c7,0x26040053,0x00000000}},	//   _paal, ktär, वादी_,
  { {0x63a81959,0xa227014d,0xa1750054,0x00000000}},	//   sadn, ارده, игні,
  { {0x7e7d02f6,0x61ed0736,0x63a8081a,0x00000000}},	//   _risp, _vaal, padn,
  { {0x3e4100eb,0xf1bf0025,0x25a6001f,0x00000000}},	//   mėti_, chán_, _heol_,
  { {0x61ed04c6,0xb05b00bd,0x3e410006,0x00000000}},	//   _taal, hräg, lėti_,
  { {0xb05b0072,0x387e1b5d,0x3d950456,0x00000000}},	//   ttäs, _litr_, риар,
  { {0x7e7d003d,0x3e410006,0x527c0047,0x00000000}},	// [27f0] _visp, nėti_, _אנהא,
  { {0xb05b00c7,0x25a6001f,0x6d5d01c8,0x00000000}},	//   dräg, _leol_, _vysa,
  { {0xb05b04e1,0x7e7d04aa,0x78bc008f,0x00000000}},	//   träf, _tisp, _ārva,
  { {0x3e4100eb,0x636f00ea,0x973c007d,0x00000000}},	//   kėti_, lóné, _pećn,
  { {0x9df80121,0x28f80083,0x6d5d0075,0x00000000}},	//   _снят_, лець_, _uysa,
  { {0x3e4100eb,0x25a900c3,0x76b50001,0x00000000}},	//   dėti_, _žal_, аљиц,
  { {0xb05b004d,0x7ceb0137,0xe6110044,0x00000000}},	//   präf, _förå, قشة_,
  { {0x25a60025,0xd5e20013,0x2486002b,0x00000000}},	//   _ceol_, _phó, _buom_,
  { {0xf1bf0027,0xa5f6005e,0x25a600f1,0x00000000}},	//   thán_, рењу_, _deol_,
  { {0x2249017e,0x44230022,0xb05b0244,0x00000000}},	//   _ajak_, ój_, nräd,
  { {0x63bc007a,0xe784007e,0x316900ea,0x00000000}},	//   órna, _المپ, _azaz_,
  { {0x3e4100eb,0xa4d50086,0xd5751b5e,0x00000000}},	//   bėti_, _воді, _куль,
  { {0xb05b00a5,0xc1e7005d,0x64a51b5f,0x00000000}},	//   kräd, شکيل_, _тала,
  { {0xa06a0088,0xfaf8001c,0xe3b90054,0x00000000}},	//   тага_, _šīm_, _рбк_,
  { {0x43750047,0xb05b0072,0x6e360062,0x00000000}},	//   _דײַן_, ttär, ахах,
  { {0x644f0164,0x6e030044,0x425300de,0x00000000}},	//   écif, يِّن, _ونور,

  { {0x6fd60086,0xc0e60189,0x62730021,0x00000000}},	// [2800] _кінц, _топк, _بهيئ,
  { {0xd00f0021,0xb05b1b60,0xef1a01ce,0x00000000}},	//   _يلي_, stär, _амо_,
  { {0x394d1b61,0x79a6013f,0x5fbb009a,0x00000000}},	//   _axes_, арле, _בצינ,
  { {0xb05b00bd,0x2a6d004c,0x79850044,0x00000000}},	//   träg, _cheb_, مؤهل,
  { {0xda650021,0xd7940062,0x26040042,0x00000000}},	//   حالي, билъ, वासी_,
  { {0x25a60027,0xb05b0072,0x68431702,0x00000000}},	//   _seol_, ntäp, онча,
  { {0x973c007d,0x6f1c001f,0x24860072,0x00000000}},	//   _većo, nyrc, _suom_,
  { {0xb05b0c38,0x6b630086,0x998b00dd,0x00000000}},	//   präg, _єкта, ălţa_,
  { {0x87da007e,0x6f1c001f,0x7bc30014,0x00000000}},	//   _لباس_, hyrc, ónug,
  { {0x3e4100eb,0x7d0b0137,0xbcfb1b62,0x00000000}},	//   rėti_, ägsi, _szék,
  { {0x3e410078,0x23380895,0x6352004c,0x00000000}},	//   sėti_, упны_, děné,
  { {0xd2580086,0xd377000d,0x3e410006,0x00000000}},	//   иця_, шчы_, pėti_,
  { {0x04940032,0x6abe004d,0x66021b63,0x00000000}},	//   _التح, hrpf, _inok,
  { {0xd3a30062,0x443a0137,0x34fb0063,0x00000000}},	//   _дръп, _öp_, _שהגד,
  { {0x6f1c0185,0xfda70001,0x6367005a,0x00000000}},	//   gyrc, ијам, _кръг_,
  { {0x629a1b64,0x30a70133,0xdd981b65,0x00000000}},	//   mpto, _кров, ишу_,
  { {0xb05b00c7,0xcec40080,0x786d017d,0x00000000}},	// [2810] träd, teří_, lúve,
  { {0x2bb80021,0x515c009a,0xbca40044,0x00000000}},	//   لامة_, _בכחו, تمكي,
  { {0x660200ac,0xb05b0ae2,0x5fdc089e,0x00000000}},	//   _onok, rräd, _יחזק,
  { {0xdb1e0014,0x629a1b66,0x497501e4,0x00000000}},	//   efpó, ipto, блес,
  { {0x8cf4000d,0x26de0e7c,0xd8e70416,0x00000000}},	//   _дзяц, _apto_, рцеп,
  { {0x1d160063,0x3eb10051,0xb05b0244,0x00000000}},	//   _הקשר_, oszt_, bräe,
  { {0x2a7f0089,0x6dbb0022,0x68420085,0x00000000}},	//   _tiub_, ałał, янша,
  { {0x656f0114,0x3dc908f2,0xee320063,0x00000000}},	//   ýcho, ngaw_, ּֽה_,
  { {0xe4590189,0x00000000,0x00000000,0x00000000}},	//   лжи_,   ,   ,
  { {0x9f4c108f,0x981401fb,0x844400de,0x00000000}},	//   ždé_, _وبلا, ْخَل,
  { {0xe719007e,0x68fb0061,0x3e41005f,0x00000000}},	//   _حيات_, _hrud, lėtu_,
  { {0x3f910022,0xcf89016e,0xd1ba0044,0x00000000}},	//   eczu_, _טט_, دادا_,
  { {0x8505006a,0x291d02ae,0x6f1c001f,0x00000000}},	//   _دوشن, nywa_, wyrc,
  { {0xe3b8005b,0x33950021,0x644f006c,0x00000000}},	//   lkın_, _الغز, écid,
  { {0xd7f1001b,0xe3b0005d,0x66f70042,0x00000000}},	//   _mã_, _آره_, ंटिक_,
  { {0xb05b004d,0x68fb1b67,0x3e41005f,0x00000000}},	//   gräb, _orud, kėtu_,
  { {0x61e61b68,0xac831b43,0x00000000,0x00000000}},	// [2820] mekl, згул,   ,
  { {0x442700f3,0x69db006d,0x3b0a0ada,0x00000000}},	//   _jln_, _abue, лезо_,
  { {0xfc3f0994,0x998d00c2,0x61e600ca,0x00000000}},	//   _avís_, _smeš_, oekl,
  { {0x61e601f7,0xb346017d,0x38c8007e,0x00000000}},	//   nekl, leçõ, لاتی_,
  { {0x25ad0185,0x656f0024,0x68fb1b69,0x00000000}},	//   dael_, ýchl, _crud,
  { {0x7e641b6a,0x5fdb0042,0x68fb0d70,0x00000000}},	//   llip, म्पल, _drud,
  { {0xddcd005b,0x7bdc1b6b,0xf99f0002,0x00000000}},	//   nlaş, _ibru, _нè_,
  { {0x61e6017f,0x7afc004d,0x291d0051,0x00000000}},	//   jekl, _irrt, bywa_,
  { {0xa9260055,0x998f0006,0x7e641b6c,0x00000000}},	//   _удал, angų_, ilip,
  { {0xddcd01f7,0xb346017d,0x7c3e1b6d,0x00000000}},	//   klaş, jeçõ, nipr,
  { {0x5c5b00b5,0x2bf70063,0x7bdc0139,0x00000000}},	//   רדיק, זמין_, _mbru,
  { {0xad9b13a8,0xc0cb0138,0xcb130063,0x00000000}},	//   _anún, луге_, ללת_,
  { {0x661d00fe,0x7bdc1b6e,0x7c3e1b6f,0x00000000}},	//   öske, _obru, kipr,
  { {0x7e641b70,0xd7f10013,0xddcd0058,0x00000000}},	//   elip, _xã_, flaş,
  { {0x643b0047,0x644f0ec6,0x443e1b71,0x00000000}},	//   _געגנ, écie, mit_,
  { {0x7e64002c,0x61e601f7,0x6298006f,0x00000000}},	//   glip, cekl, _itvo,
  { {0x442c00e3,0x9c39000a,0x42380063,0x00000000}},	// [2830] ohd_, апат_, _לנהל_,
  { {0xb346017d,0xf3f1008b,0x443e1b72,0x00000000}},	//   ceçõ, họn_, nit_,
  { {0x207c0047,0x443e004b,0x9b6b0002,0x00000000}},	//   _גאזא, iit_, ушаа_,
  { {0x443e18ab,0x7bdc0162,0x1df90076,0x00000000}},	//   hit_, _ebru, _темы_,
  { {0x443e03f9,0x89a80054,0x645a1b73,0x00000000}},	//   kit_, сків_, koti,
  { {0xa69502a9,0x629804c9,0x63aa0026,0x00000000}},	//   ориј, _otvo, _nefn,
  { {0xa3be0053,0x645a1b74,0x443e1b75,0x00000000}},	//   ेलन_, doti, dit_,
  { {0x68fb1588,0xe6191b76,0xfc3f0025,0x00000000}},	//   _trud, рди_, _tvís_,
  { {0x442700f3,0x68fb0035,0x64480ea7,0x00000000}},	//   _pln_, _urud, fndi,
  { {0x63aa0185,0xddcd01f7,0x443e1b77,0x00000000}},	//   _cefn, ylaş, git_,
  { {0x63aa0185,0xdb1c0025,0x33650021,0x00000000}},	//   _defn, _scrú, تهدف,
  { {0x64480d74,0x443e1096,0x69cb1b78,0x00000000}},	//   andi, ait_, ngge,
  { {0xe3ae1b79,0x625d0003,0x61e61b7a,0x00000000}},	//   _об_, téor, rekl,
  { {0x63aa1b33,0xddcd0058,0x443e1b7b,0x00000000}},	//   _gefn, tlaş, cit_,
  { {0xb346017d,0x26c71b7c,0xdb07013d,0x00000000}},	//   reçõ, nuno_, _fejé,
  { {0x22b5003d,0x6e2d0a9f,0xb05b0832,0x00000000}},	//   māk_, ghab, träc,
  { {0xd7c9016a,0x22b5003d,0x22a700ea,0x00000000}},	// [2840] _रांच, lāk_, lők_,
  { {0x27e70031,0x6e2d00a4,0x7e641b7d,0x00000000}},	//   jenn_, ahab, slip,
  { {0xd24f007e,0x69d9004d,0x7c3e1b7e,0x00000000}},	//   _سنی_, ffwe, ripr,
  { {0xddcd0529,0x7c3e00eb,0x443e1b7f,0x00000000}},	//   rmaţ, sipr, zit_,
  { {0x3ead0117,0x64481b80,0x7d0b0832,0x00000000}},	//   ćete_, yndi, ägst,
  { {0x26c70011,0x7649005b,0x443e1b81,0x00000000}},	//   funo_, eney, xit_,
  { {0x26c702dd,0xdcf6005b,0x443e1b82,0x00000000}},	//   guno_, mayı, vit_,
  { {0xdcf601f7,0x443e0e5b,0xba9b0047,0x00000000}},	//   layı, wit_, _כסלי,
  { {0xa5070001,0xb80a007e,0x62981b83,0x00000000}},	//   жења_, _پيام_, _stvo,
  { {0x186a011c,0x68ed1b84,0x64481b85,0x00000000}},	//   _тази_, çade, undi,
  { {0x63aa0026,0x26c71059,0x1bfb0047,0x00000000}},	//   _vefn, cuno_, בליב,
  { {0xd378007d,0x443e00d8,0x645a1b86,0x00000000}},	//   neći_, sit_, soti,
  { {0xda7b014e,0x443e1b87,0x645a1b88,0x00000000}},	//   ינטר, pit_, poti,
  { {0x764000eb,0x22b5001c,0xc05b0086,0x00000000}},	//   limy, bāk_, рім_,
  { {0x539b0063,0x69cb060b,0x2a6600a4,0x00000000}},	//   _דיוו, ygge, klob_,
  { {0xd378017f,0x8d6b0002,0x76400ddd,0x00000000}},	//   jeći_, ајза_, nimy,
  { {0xd3780117,0x6e2d1b89,0x8d77014d,0x00000000}},	// [2850] deći_, rhab, زارا,
  { {0xad9b017d,0x1c050053,0x26c7006d,0x00000000}},	//   _inúm, राइल_, yuno_,
  { {0x27e700d1,0x6e2d0238,0x76401b8a,0x00000000}},	//   venn_, phab, kimy,
  { {0x26c705b3,0x7d0b0137,0x69d9004d,0x00000000}},	//   vuno_, ägss, ufwe,
  { {0x22b5001c,0x22a700ea,0x69d9001f,0x00000000}},	//   zāk_, zők_, rfwe,
  { {0x26c7001f,0xf80705f7,0xa7fc0075,0x00000000}},	//   tuno_, ючен, _akıb,
  { {0xdce6001c,0xd378007d,0x27e70e46,0x00000000}},	//   _izkā, beći_, renn_,
  { {0x68f00072,0x06091b8b,0x22b5008f,0x00000000}},	//   ähdä, сник_, vāk_,
  { {0x26c70290,0xe4d60021,0x764908d2,0x00000000}},	//   suno_, كويت_, rney,
  { {0x22a7000f,0x22b5001c,0x87070021,0x00000000}},	//   tők_, tāk_, _وبال,
  { {0x2bdd0053,0x786d0066,0xa2c00042,0x00000000}},	//   न्या, cúva, _विण्,
  { {0x22b5003d,0x26f90161,0x2c6d027d,0x00000000}},	//   rāk_, ्मीर_, _vždy_,
  { {0x22b5008f,0x22a7013d,0xdcf60058,0x00000000}},	//   sāk_, sők_, yayı,
  { {0xd848008b,0xd378007d,0xb4fa0063,0x00000000}},	//   họn_, zeći_, _לפני,
  { {0x644114f1,0x0e6a0021,0x973c007d,0x00000000}},	//   mili, مصري_, _peći,
  { {0xe1ff1b8c,0xb2ba0063,0xa2c00053,0x00000000}},	//   llón_, _המקר, _वित्,
  { {0x973c0117,0xd378007d,0x224200d1,0x00000000}},	// [2860] _veći, veći_, mikk_,
  { {0x22420031,0x6e241b8d,0x3c630002,0x00000000}},	//   likk_, skib, екуг,
  { {0xdcf601f7,0xd378017f,0x6297006d,0x00000000}},	//   rayı, teći_, _éxod,
  { {0x64411b8e,0x224200d1,0xf2960047,0x00000000}},	//   hili, nikk_, לכער_,
  { {0xd378017f,0x64411b8f,0x201a1b90,0x00000000}},	//   reći_, kili, _kopi_,
  { {0xb05b00bd,0xd378017f,0x644105b3,0x00000000}},	//   hrän, seći_, jili,
  { {0x64411b91,0xe9a60086,0xb05b0354,0x00000000}},	//   dili, _навп, krän,
  { {0xa3d90053,0x4425004c,0x64411b92,0x00000000}},	//   ड्स_, ekl_, eili,
  { {0xdced0024,0x786d0024,0xb05b004d,0x00000000}},	//   zbaľ, súva, drän,
  { {0xa2c00053,0x674700ea,0x988b0063,0x00000000}},	//   _विद्, árjá, _הָאֵ,
  { {0x644f03b2,0x22420031,0x78a9006f,0x00000000}},	//   écia, fikk_, _zwev,
  { {0xb05b01e3,0x7ae100bd,0x224200d1,0x00000000}},	//   grän, _älte, gikk_,
  { {0x682f1b49,0xe1ff1b93,0x64411b94,0x00000000}},	//   _fødd, blón_, bili,
  { {0x201a001f,0xe1ff006d,0x104b0121,0x00000000}},	//   _copi_, clón_, сями_,
  { {0x33db0063,0x629c0114,0x64b50058,0x00000000}},	//   _החוד, írod, _eşiğ,
  { {0x61f600e5,0x2242013d,0x00000000,0x00000000}},	//   _gayl, cikk_,   ,
  { {0x91bc014e,0xbcfb00ea,0xc1bc0063,0x00000000}},	// [2870] _המחי, _azér, _המחש,
  { {0x201a001f,0x9f43004c,0xa3be0042,0x00000000}},	//   _gopi_, lejí_, ेलि_,
  { {0x682f02ab,0x99890080,0x61f60058,0x00000000}},	//   _jøde, íkům_, _yayl,
  { {0x3a26002c,0x682f0146,0xb17b00a5,0x00000000}},	//   gkop_, _møde, gfåg,
  { {0xbcfb000f,0xca240121,0xd378007d,0x00000000}},	//   _ezér, эффи, meću_,
  { {0x64410764,0xd3780130,0xccf2009a,0x00000000}},	//   xili, leću_, _שכם_,
  { {0x3209005b,0x682f05b9,0x3a2600ca,0x00000000}},	//   _onay_, _rødd, bkop_,
  { {0x64410c70,0xdb070080,0x19590121,0x00000000}},	//   wili, _její, _дабы_,
  { {0x28080080,0xdb07006d,0x7bca0331,0x00000000}},	//   átní_, _mejí, ófug,
  { {0xe7b5006a,0xd8740044,0xc3250094,0x00000000}},	//   _آماد, _كالب, дмок,
  { {0x22420031,0x61f601f7,0x28080080,0x00000000}},	//   tikk_, _payl, štní_,
  { {0xd378017f,0x923a0086,0xdb0e017d,0x00000000}},	//   jeću_, ічну_, _bebê,
  { {0x22420031,0xd378017f,0x644118b1,0x00000000}},	//   rikk_, deću_, pili,
  { {0x22420031,0x682f05dd,0x3e48003b,0x00000000}},	//   sikk_, _føde, işte_,
  { {0xa0671b95,0xb05b0072,0x61f61b96,0x00000000}},	//   фара_, ntäy, _tayl,
  { {0x9f43004c,0x02060121,0x7bc30046,0x00000000}},	//   cejí_, _цзин, ónun,
  { {0xdb0e00e8,0xdb070066,0x201a1b97,0x00000000}},	// [2880] _gebê, _dejí, _topi_,
  { {0x682d0022,0xdb05004b,0x3a2d1b98,0x00000000}},	//   aźdz, kahä, _alep_,
  { {0x3e48000c,0x5f46007e,0x3a26006f,0x00000000}},	//   eşte_, _آنجل, tkop_,
  { {0xa2c00161,0xfaf8003d,0xc3320063,0x00000000}},	//   _विस्, _šīs_, כוב_,
  { {0x08970032,0xd83a000d,0x127b0041,0x00000000}},	//   وضوع_, жэй_, קאנע,
  { {0x68ed017d,0x9f430080,0x36d4005e,0x00000000}},	//   çada, zejí_, еокр,
  { {0xd6cf005a,0x66e3018e,0x3a261207,0x00000000}},	//   ът_, воја, pkop_,
  { {0x24870027,0x26c01b99,0x44f40781,0x00000000}},	//   _ainm_, čio_, епис,
  { {0x25af0290,0x83fc007d,0x05bf0042,0x00000000}},	//   _degl_, hođe, _एयरब,
  { {0x83fc0117,0xd378007d,0x224000ea,0x00000000}},	//   kođe, zeću_, _amik_,
  { {0x972601fb,0xd6cf002a,0x60c6030c,0x00000000}},	//   _تفاو, _نقل_, erkm,
  { {0xc7b8017f,0x64a60088,0xd626013a,0x00000000}},	//   _dođe_, _жада, _تعطي,
  { {0x7c2e1b9a,0xd378007d,0xdce7008f,0x00000000}},	//   _olbr, veću_, ālīb,
  { {0x9f430080,0x656f00bd,0xf1bf013d,0x00000000}},	//   sejí_, üche, ehát_,
  { {0x83fc017f,0xddc40022,0x60c60c01,0x00000000}},	//   gođe, dnił, arkm,
  { {0x41e70304,0xddc40022,0x7c2e1b9b,0x00000000}},	//   _ціка, enił, _albr,
  { {0xee84000d,0x5c751b9c,0xd378007d,0x00000000}},	// [2890] тыро, елат, reću_,
  { {0x78a20512,0x83fc017f,0x9f4c0240,0x00000000}},	//   dpov, bođe, ždá_,
  { {0xb5fd1b9d,0xdb0500a5,0x78a21b9e,0x00000000}},	//   loše, kahå, epov,
  { {0xdb1c0e7c,0xd37b0047,0x2cc40058,0x00000000}},	//   _acró, קראט, ürdü_,
  { {0xb5fd017f,0x682f0093,0x25af01e1,0x00000000}},	//   noše, _rødb, _regl_,
  { {0x46f50156,0xb05b0072,0x25af05a5,0x00000000}},	//   ечит, ttäy, _segl_,
  { {0x7b640121,0x78a200b2,0xa2c00042,0x00000000}},	//   _атте, apov, _विष्,
  { {0x2c740137,0xb5fd007d,0x7af5013d,0x00000000}},	//   räde_, koše, _iszt,
  { {0xa4d60001,0xa8a701dd,0xb05b0072,0x00000000}},	//   едњу_, _ірак, stäy,
  { {0xa2c00053,0x7af50051,0x25a2005b,0x00000000}},	//   _विश्, _kszt, ıkla_,
  { {0xe5e1000d,0x43740054,0xcad5009a,0x00000000}},	//   _былi_, куют, עוֹת_,
  { {0x83fc017f,0x34951b76,0xc7b8007d,0x00000000}},	//   vođe, _задр, _vođe_,
  { {0x65940138,0x660b1b9f,0x60c601e1,0x00000000}},	//   _рачу, _ingk, urkm,
  { {0x7bc30026,0x7af500ea,0x26c71ba0,0x00000000}},	//   ónul, _oszt, orno_,
  { {0xe4560047,0xbcfb00ea,0x9e76005e,0x00000000}},	//   _איסט_, _szép, ећај,
  { {0x26120053,0x83fc007d,0x224000c2,0x00000000}},	//   थायी_, rođe, _umik_,
  { {0x61e400a4,0x7af500ea,0x20130046,0x00000000}},	// [28a0] _ibil, _aszt, ýnið_,
  { {0x3ec5005b,0xa7fc0058,0x4d631ba1,0x00000000}},	//   üstü_, _akın, укув,
  { {0x4fd700b5,0x660b00f3,0x7fd700b5,0x00000000}},	//   _אויב_, _ongk, _אויס_,
  { {0xf2d2016e,0x5e460044,0xdca604ef,0x00000000}},	//   רעא_, _أَحْ, _пами,
  { {0x61e40009,0x186a064b,0x26c71ba2,0x00000000}},	//   _mbil, пади_, erno_,
  { {0x660b1acc,0xd6d00021,0x25dd0053,0x00000000}},	//   _angk, لقت_, क्सी_,
  { {0x61e41ba3,0xad9b0026,0x78a21ba4,0x00000000}},	//   _obil, _snúi, spov,
  { {0xdb1c0025,0x95d70062,0x61e40075,0x00000000}},	//   _ndré, едът_, _nbil,
  { {0xb17b00c7,0x5454026b,0x69c00078,0x00000000}},	//   neåt, квит, _idme,
  { {0xccf3014e,0x660b0397,0x29041ba5,0x00000000}},	//   רכז_, _engk, _irma_,
  { {0xf2e5000c,0xdb0e006d,0x2259007f,0x00000000}},	//   ţând_, _bebé, дины_,
  { {0x5ab700b7,0xb05b0072,0xf2c30085,0x00000000}},	//   עלכע_, rräm, ысьн,
  { {0x656f0024,0xd83f00a8,0x64a30500,0x00000000}},	//   ýcht, _ščit_, _бача,
  { {0xdb0700ea,0x442e1ba6,0xb5fd17cf,0x00000000}},	//   _lejá, _ulf_, roše,
  { {0xc0ab006a,0x63bc0026,0x6e950002,0x00000000}},	//   _کابل_, órnu, тибу,
  { {0x27ee002b,0x29041ba7,0xfe7314d7,0x00000000}},	//   hefn_, _orma_, ادس_,
  { {0xebc70001,0xf1bf0080,0xcbc7007e,0x00000000}},	// [28b0] ељен, nkám_, فزاي,
  { {0x69c00bbd,0x61fd1ba8,0x61e41ba9,0x00000000}},	//   _adme, ldsl, _zbil,
  { {0x29041095,0xdb07013d,0x61e8013d,0x00000000}},	//   _arma_, _bejá, ődle,
  { {0x68ed1997,0xb05b0137,0x61fd1baa,0x00000000}},	//   çado, kräk, ndsl,
  { {0xd366006a,0x7e6d003d,0xdb07006d,0x00000000}},	//   _چه_, mlap, _dejá,
  { {0xd366006a,0xab950001,0x97c20076,0x00000000}},	//   _نه_, _јављ, айше,
  { {0x316c0045,0xcc54005a,0x8f9c0047,0x00000000}},	//   ędzi_, _свръ, ליגי,
  { {0x7e6d00ea,0x61fd153a,0x60dd00df,0x00000000}},	//   nlap, jdsl, ktsm,
  { {0xe8950088,0x9f4a0268,0x61ef1bab,0x00000000}},	//   _разь, rebé_, decl,
  { {0xdb050014,0xe29902d8,0x7e6d1bac,0x00000000}},	//   dahú, мао_, hlap,
  { {0x26dc027d,0xe1bf0053,0x60dd00f5,0x00000000}},	//   ctvo_, ्लंघ, etsm,
  { {0x660b1bad,0xa696009f,0x7e6d008f,0x00000000}},	//   _ungk, _סכנה_, jlap,
  { {0x463a00b5,0x7e6d001c,0x60dd00b9,0x00000000}},	//   _קענע, dlap, gtsm,
  { {0x25dd0053,0x6a781bae,0x7e6d017e,0x00000000}},	//   क्री_, mífe, elap,
  { {0x998f0006,0x60dd0d13,0x6a7812c7,0x00000000}},	//   nigų_, atsm, lífe,
  { {0xa7fc005b,0x61e408ed,0x61ef00ca,0x00000000}},	//   _akıl, _ubil, cecl,
  { {0x6a780e1f,0x0d860f50,0x3e5a011b,0x00000000}},	// [28c0] nífe, тлан, jďte_,
  { {0x7e6d1baf,0xe0b7009f,0x6faa0021,0x00000000}},	//   alap, _שליט_, _تهدف_,
  { {0xe9da0076,0xb5fd0024,0x3daa0076,0x00000000}},	//   дке_, alši, _окно_,
  { {0x831a0047,0xceb80078,0x98a60962,0x00000000}},	//   וועז, šęs_, виде,
  { {0xb7b5008b,0x6c860021,0x314d009a,0x00000000}},	//   _vọn, _للحم, ּתוּ,
  { {0x7d061bb0,0x69dd0137,0xf1bf0195,0x00000000}},	//   _irks, _ösen, vkám_,
  { {0xddcd000c,0x27ee001f,0x8c430571,0x00000000}},	//   noaş, refn_, _тере,
  { {0xceb30063,0x64430ebd,0xd49a0141,0x00000000}},	//   ביה_, _amni, мро_,
  { {0x2904000c,0x26dc01a6,0x5e570047,0x00000000}},	//   _urma_, stvo_, כיקע_,
  { {0x98760092,0x7e6d0023,0xa84a043e,0x00000000}},	//   _рубљ, zlap, _غلام_,
  { {0x83fc007d,0x0bb70063,0xd7760021,0x00000000}},	//   gođa, כלים_, _شائع,
  { {0xbddb0003,0x27e9007d,0xd7d20053,0x00000000}},	//   _amèn, đane_, _साँच,
  { {0x61fd0f2d,0x68e9003b,0x61ef1bb1,0x00000000}},	//   rdsl, _xped, recl,
  { {0xdb050014,0xb5fd008f,0x4fc40a91,0x00000000}},	//   rahú, moša, исса,
  { {0xb5fd008f,0x53330062,0xd5e20013,0x00000000}},	//   loša, _вещт, _giọ,
  { {0x2d8f0146,0xfda40001,0x64430051,0x00000000}},	//   øge_, ијум, _zmni,
  { {0xb5fd003d,0x3d0d0161,0xbfab0062,0x00000000}},	// [28d0] noša, समें_, _отне_,
  { {0x7e6d0812,0xe1ff0331,0xd0f800ff,0x00000000}},	//   slap, ldó_, _יצחק_,
  { {0x68e91bb2,0xe0df0290,0xe945005d,0x00000000}},	//   _sped, ltò_, گرای,
  { {0xb5fd001c,0xe1ff0882,0x6e360114,0x00000000}},	//   koša, ndó_, chyb,
  { {0xe0df051e,0x89a80086,0xb5fd001c,0x00000000}},	//   ntò_, тків_, joša,
  { {0xb5fd003d,0x3e5a0240,0x29c3008b,0x00000000}},	//   doša, rďte_, ựa_,
  { {0x36690055,0x64481bb3,0x7d0b01e1,0x00000000}},	//   нако_, didi, ægsf,
  { {0x83fc017f,0xc7b8017f,0x6e2d1bb4,0x00000000}},	//   vođa, _vođa_, nkab,
  { {0x9f4300fe,0xb5fd001c,0x229a001c,0x00000000}},	//   lejä_, goša, _rīka_,
  { {0xb05b004d,0x64481bb5,0x229a0023,0x00000000}},	//   bräi, gidi, _sīka_,
  { {0x8458005a,0x6e2d005b,0x96fb0021,0x00000000}},	//   ърът_, kkab, _تعذر_,
  { {0xb5fd001c,0x8236007e,0x64481bb6,0x00000000}},	//   boša, اردا, aidi,
  { {0x3c360146,0x7d09007d,0x78f90047,0x00000000}},	//   _hæve_, _šesn, עפֿו,
  { {0x9f43024a,0x64481bb7,0xddc401da,0x00000000}},	//   kejä_, cidi, dliš,
  { {0x752900ea,0x3ebe0026,0xd5b70042,0x00000000}},	//   lyez, étt_, _इजाज,
  { {0x661b08f0,0x6e2d002c,0xb17b02ab,0x00000000}},	//   njuk, gkab, reår,
  { {0x75290009,0x753b00bd,0xddc40a1c,0x00000000}},	// [28e0] nyez, nzuz, gliš,
  { {0x6e2d1bb8,0x661b0ff2,0x1c0e0053,0x00000000}},	//   akab, hjuk, साइल_,
  { {0x49ca1527,0x27e0013d,0x9f8b004b,0x00000000}},	//   елен_, őink_, _söök_,
  { {0xddc400c2,0xb05b0137,0x64481bb9,0x00000000}},	//   bliš, tsäg, zidi,
  { {0x28f80b0f,0xad9b0024,0x64480306,0x00000000}},	//   тель_, _vnút, yidi,
  { {0x7d04011d,0xb5fd1bba,0xe1ff013d,0x00000000}},	//   mvis, voša, rlói_,
  { {0xfaa3018e,0x7d041bbb,0x627c0022,0x00000000}},	//   _гасо, lvis, _złoś,
  { {0xb5fd003d,0x64480185,0xceb30063,0x00000000}},	//   toša, widi, זיה_,
  { {0x25b90026,0x7d041bbc,0x752900ea,0x00000000}},	//   ðsla_, nvis, gyez,
  { {0x2a66002c,0x64480250,0xb5fd1bbd,0x00000000}},	//   loob_, uidi, roša,
  { {0x7d04024a,0xd7930032,0x3ce00019,0x00000000}},	//   hvis, _المخ, htiv_,
  { {0xe0df051e,0xb5fd1bbe,0x3ce00f4b,0x00000000}},	//   ttò_, lošn, ktiv_,
  { {0xc5f3014e,0xe1ff1bbf,0xa2c00053,0x00000000}},	//   _לדף_, rdó_, _विक्,
  { {0xe0df051e,0x7d041bc0,0xe1ff0022,0x00000000}},	//   rtò_, dvis, ylów_,
  { {0xf8d10161,0xe0df051e,0x9f340086,0x00000000}},	//   _सम्प, stò_, бері,
  { {0x7d0400b9,0x7bca0026,0x21360003,0x00000000}},	//   fvis, ófun, êché_,
  { {0xdb0e02dd,0x5bcb0001,0x786d0024,0x00000000}},	// [28f0] _debí, ећег_, súvi,
  { {0xad9b10d9,0x6e2d0b4b,0x9f4300fe,0x00000000}},	//   _saúd, skab, tejä_,
  { {0xddc4085a,0x63ba0089,0x212b1bc1,0x00000000}},	//   sliš, iatn, lych_,
  { {0x9f430072,0xb05b0137,0x98a9007d,0x00000000}},	//   rejä_, gräv, šač_,
  { {0x212b1bc2,0x3ce0000c,0xab950086,0x00000000}},	//   nych_, ctiv_, _вигі,
  { {0x63ba017f,0x9f4300fe,0xdb050025,0x00000000}},	//   jatn, pejä_, lbhí,
  { {0xdb580086,0xc7c40076,0x63ba1bc3,0x00000000}},	//   _бют_, ссчи, datn,
  { {0x212b0024,0x9f4a017d,0x645800c2,0x00000000}},	//   kych_, lebã_, _ajvi,
  { {0x680b003d,0xe3b1007e,0x63ba1bc4,0x00000000}},	//   _pēdē, يرد_, fatn,
  { {0x13090076,0x212b0106,0x661b1310,0x00000000}},	//   вной_, dych_, sjuk,
  { {0x9f4c0024,0xb05b004d,0x35f51bc5,0x00000000}},	//   ždú_, nräu, _впер,
  { {0x224b1101,0x2ca9006f,0x7d0400fe,0x00000000}},	//   gick_, kpad_, yvis,
  { {0x63ba003e,0x6d4b0014,0x23dd0042,0x00000000}},	//   batn, úgal, _मापद,
  { {0x645d03b2,0x7d041bc6,0x98a0017f,0x00000000}},	//   ésid, vvis, šić_,
  { {0x683f0006,0x25ad1bc7,0x682f0093,0x00000000}},	//   _išdė, obel_, _rødl,
  { {0x3126005a,0xb21b00b9,0x7d0406f1,0x00000000}},	//   _вдиг, lmæn, tvis,
  { {0x212b0045,0xb21b0146,0x3b9602d8,0x00000000}},	// [2900] cych_, omæn, ајет,
  { {0x69db048e,0x629e06b2,0x6abe004d,0x00000000}},	//   _acue, _époc, tspf,
  { {0xb5fd001c,0x0b460002,0x23dd0053,0x00000000}},	//   jošo, јнен, _मानद,
  { {0x25ad006f,0x3ebe0026,0xd3560063,0x00000000}},	//   jbel_, áttu_, ביעי_,
  { {0x9f580268,0xb21b00b9,0x63ba0360,0x00000000}},	//   ldrà_, kmæn, yatn,
  { {0xb05b00bd,0x69db0331,0xd90d007e,0x00000000}},	//   bräu, _ecue, عیل_,
  { {0x63ba1bc8,0x27fe14d4,0x9f580268,0x00000000}},	//   vatn, _vatn_, ndrà_,
  { {0x27e9017f,0x7bc30026,0xb05b01bb,0x00000000}},	//   đana_, ónuv, lrät,
  { {0x8e370047,0xddcd0195,0x98a31bc9,0x00000000}},	//   ינקא_, ymaž, _мите,
  { {0x3cf90053,0xb05b01bb,0x25ad1bca,0x00000000}},	//   _उनसे_, nrät, abel_,
  { {0x212b1112,0x8bd70047,0x29060072,0x00000000}},	//   wych_, סוטו_, lvoa_,
  { {0x63ba14b5,0x212b1a03,0x20df00dd,0x00000000}},	//   satn, tych_, tîi_,
  { {0x9258005a,0x63ba1bcb,0x224b03a3,0x00000000}},	//   раят_, patn, rick_,
  { {0x50670138,0x212b1bcc,0xddcd0078,0x00000000}},	//   ртма, rych_, umaž,
  { {0xe2970079,0xc058019d,0x645d0803,0x00000000}},	//   _кај_, рія_, ésie,
  { {0x2ca91bcd,0x63b800d1,0x71470121,0x00000000}},	//   tpad_, _hevn, _вхож,
  { {0xdb050027,0xb5fd1bce,0xb05b01bb,0x00000000}},	// [2910] rbhí, došl, frät,
  { {0x63b80031,0x0ba7000d,0xb05b092e,0x00000000}},	//   _jevn, ршам, grät,
  { {0xdb1500ea,0xddc40022,0x2ca91bcf,0x00000000}},	//   _kezé, nniś, spad_,
  { {0xdb05004b,0x2ca91bd0,0x3a240ca8,0x00000000}},	//   mahü, ppad_, _comp_,
  { {0xe1ff00cd,0xb05b004d,0xfe000053,0x00000000}},	//   llós_, sräu, _लोटस_,
  { {0x63b81bd1,0x9f58006d,0xb5fd001c,0x00000000}},	//   _nevn, ldrá_, tošo,
  { {0x26c11bd2,0x7bc30026,0x6298197c,0x00000000}},	//   ého_, ónuu, _nuvo,
  { {0xa2c00394,0x9f5802dd,0x200100a4,0x00000000}},	//   _विज्, ndrá_, _lahi_,
  { {0xdb0701c2,0x68fb1235,0x25ad1bd3,0x00000000}},	//   _nejú, _usud, rbel_,
  { {0xc6e7019d,0x20010150,0x62981bd4,0x00000000}},	//   _відп, _nahi_, _buvo,
  { {0xd6db0138,0xb21b00b9,0x9f5a01f4,0x00000000}},	//   _шта_, rmæn, _capì_,
  { {0xf5950021,0xb21b00b9,0x69d90b94,0x00000000}},	//   _الإج, smæn, ngwe,
  { {0x661d0014,0x5fdc0042,0xb05b0050,0x00000000}},	//   ösku, _बादल, yrät,
  { {0xf66a007a,0x22490089,0x0574007e,0x00000000}},	//   phæð_, _emak_, _بامد,
  { {0xdb1c0240,0xb05b0b6e,0x20010792,0x00000000}},	//   _odrá, vrät, _dahi_,
  { {0xb05b004d,0x9f5800cd,0x7bc70725,0x00000000}},	//   tsäc, rdrà_, _adju,
  { {0x629800bd,0x3a2409fe,0xb05b01bb,0x00000000}},	// [2920] _zuvo, _romp_, trät,
  { {0xd37e007d,0xddcd0051,0xb05b051c,0x00000000}},	//   šćem_, gnał, rsäc,
  { {0x628605b9,0x5f0609b4,0xb05b1bd5,0x00000000}},	//   omko, _узна, rrät,
  { {0x68e21bd6,0xb05b0cbf,0xddcd0022,0x00000000}},	//   ttod, srät, anał,
  { {0xa3d70235,0xb05b00c7,0xb5fd10f5,0x00000000}},	//   िला_, prät, rošl,
  { {0xd6da0086,0x6c36007e,0x29060072,0x00000000}},	//   гти_, _افسا, rvoa_,
  { {0xb21b0014,0x63b8080e,0x8706000d,0x00000000}},	//   fmæl, _revn, сяле,
  { {0xb05b0072,0x60c40734,0xf1bf013d,0x00000000}},	//   isäa, _ovim, nkát_,
  { {0x2733001b,0x63b8027d,0x62981bd7,0x00000000}},	//   ạn_, _pevn, _suvo,
  { {0x22491bd8,0x682f04aa,0x96ba143c,0x00000000}},	//   _smak_, _nødh, _буду_,
  { {0xe6960021,0xd5af1bd9,0x3618005d,0x00000000}},	//   _الصد, _нс_, _پراگ_,
  { {0xddcd0022,0xdb05004b,0xe717009a,0x00000000}},	//   znał, vahü, _לחבר_,
  { {0xdb1500ea,0x645d00ed,0x067b0047,0x00000000}},	//   _vezé, ésic, _ענדל,
  { {0x6e95000a,0xdb1c00b9,0xa0550086,0x00000000}},	//   живу, _idræ, івві,
  { {0xadbd0088,0x9f340086,0x2001004b,0x00000000}},	//   кавi, пері, _vahi_,
  { {0x66020004,0x44e20014,0xb05b00a5,0x00000000}},	//   _jaok, oð_, träs,
  { {0x61ed002c,0x20011bda,0x6144005e,0x00000000}},	// [2930] _ibal, _tahi_, _нећа,
  { {0x44e2007a,0xb606007d,0x2bb80044,0x00000000}},	//   ið_, lašć, مامة_,
  { {0xaab50054,0xf1bf013d,0x99990768,0x00000000}},	//   ійді, bkát_, акет_,
  { {0xb05b0c38,0x3c2f0058,0x49751579,0x00000000}},	//   präs, _sıvı_, олес,
  { {0x7bc3007a,0x61ed0009,0xa9690001,0x00000000}},	//   ónus, _mbal, јила_,
  { {0xbcfb0164,0x3c3601e1,0xdb050139,0x00000000}},	//   _exéc, _hævn_, abhá,
  { {0x44e2007a,0x682f05dd,0x61ed1bdb,0x00000000}},	//   eð_, _jødi, _obal,
  { {0xf6250086,0xe7f50053,0x644a1bdc,0x00000000}},	//   ідпо, _इसका_, _amfi,
  { {0x84591bdd,0xb5fd01b3,0x69c91bde,0x00000000}},	//   ирот_, lošk, _idee,
  { {0x61ed1bdf,0x94790002,0x78a900ca,0x00000000}},	//   _abal, јсиу_, _itev,
  { {0x44e2007a,0x60c4017f,0xfbd20063,0x00000000}},	//   að_, _svim, ותי_,
  { {0x3c3600b9,0x644a00be,0xe5ef0072,0x00000000}},	//   _nævn_, _emfi, äkää,
  { {0x644f0164,0x629e0003,0x62861be0,0x00000000}},	//   écis, _épon, rmko,
  { {0x22591be1,0xfc3f004c,0x66021be2,0x00000000}},	//   ansk_, _stín_, _zaok,
  { {0xb5fd007d,0x44271be3,0xbea30085,0x00000000}},	//   jošk, _ion_, даск,
  { {0x78a90080,0x44271be4,0x6d050042,0x00000000}},	//   _otev, _hon_, रिंग_,
  { {0xec4a0055,0xdb9a0001,0x44271be5,0x00000000}},	// [2940] азал_, атељ_, _kon_,
  { {0x44271be6,0x61ed0066,0x2004008f,0x00000000}},	//   _jon_, _zbal, ēmis_,
  { {0x44271be7,0x290d1be8,0xb5fd00b2,0x00000000}},	//   _mon_, _area_, gošk,
  { {0x38c8007e,0xb05b051c,0xddcd056c,0x00000000}},	//   ماتی_, nsän, gnań,
  { {0x290d1be9,0xb05b0072,0x61eb0058,0x00000000}},	//   _crea_, isän, _ögle,
  { {0x44271bea,0x764b001f,0xb8f20053,0x00000000}},	//   _non_, _amgy, _वि_,
  { {0xab2a0017,0x3e48003b,0xd6d00021,0x00000000}},	//   _това_, eşti_, رقة_,
  { {0x44270027,0xd4b807b0,0xcf930063,0x00000000}},	//   _aon_, блиц_, וטו_,
  { {0xe4e6019d,0x44271beb,0xb05b1bec,0x00000000}},	//   ційн, _bon_, kräp,
  { {0x44e2007a,0x44271bed,0x44381bee,0x00000000}},	//   rð_, _con_, ór_,
  { {0x78830080,0x69c900b9,0xe2f80086,0x00000000}},	//   _důvě, _ydee, щені_,
  { {0x92580076,0x44271bef,0x9f45004c,0x00000000}},	//   жают_, _eon_, ýlí_,
  { {0xc218019d,0x8556007e,0xa6330054,0x00000000}},	//   ією_, _بخاط, _інші,
  { {0xdb1e017d,0x9f4c0114,0x44271bf0,0x00000000}},	//   rapê, ždý_, _gon_,
  { {0x764b0185,0xa5c30051,0x645a0139,0x00000000}},	//   _ymgy, spół, mnti,
  { {0x44271bf1,0x61ed1bf2,0x5d990085,0x00000000}},	//   _zon_, _ubal, скаў_,
  { {0xe04b006a,0x645a0aca,0x443e004b,0x00000000}},	// [2950] _نشده_, onti, oht_,
  { {0xddcd003b,0x645a1bf3,0x656f004d,0x00000000}},	//   flaţ, nnti, üchi,
  { {0x645a1bf4,0xdefb000d,0x2bb80021,0x00000000}},	//   inti, _тып_, زالة_,
  { {0x7b64011c,0xb5fd1312,0xf9c7019d,0x00000000}},	//   фтуе, rošk, іщен,
  { {0xf99003eb,0x07a50854,0x8d871bf5,0x00000000}},	//   نبه_, палн, _фунд,
  { {0x290d000c,0x7c3e1bf6,0x09340021,0x00000000}},	//   _vrea_, chpr, برمج,
  { {0x443e0139,0xb5fd0a80,0x8c3b004d,0x00000000}},	//   dht_, loši, _außg,
  { {0x682f191f,0x290d0147,0x443e0b64,0x00000000}},	//   _nødv, _trea_, eht_,
  { {0xb05b0137,0x290d1bf7,0x25bf002b,0x00000000}},	//   vsän, _urea_, raul_,
  { {0x443e1bf8,0xfb96009a,0xf7730044,0x00000000}},	//   ght_, ּ֣ית_, _قاض_,
  { {0x44270cd4,0xdb0e00bd,0xddc4003b,0x00000000}},	//   _von_, _gebä, noiţ,
  { {0x44271bf9,0x98cf0053,0xfc3f0d5d,0x00000000}},	//   _won_, _हटाए, _stíl_,
  { {0x44271bfa,0xb5fd001c,0xb05b01bb,0x00000000}},	//   _ton_, joši, rsän,
  { {0x9f5a0290,0x443e1bfb,0xb5fd008f,0x00000000}},	//   _papà_, cht_, doši,
  { {0x7d0b01e1,0xa8560063,0x765b0058,0x00000000}},	//   ægsn, לישה_, onuy,
  { {0x9f4b000f,0x6446008f,0xc7b80130,0x00000000}},	//   áját_, īkie, _vođi_,
  { {0x229a001c,0xdb1c017d,0x6446008f,0x00000000}},	// [2960] _rīki_, _gerê, ūkie,
  { {0xdb1e00ea,0xddc4003b,0x4176005d,0x00000000}},	//   lapé, foiţ, _واکس,
  { {0xb05b024a,0x60c600d1,0x1c390086,0x00000000}},	//   isäl, lskm, цять_,
  { {0x6287004c,0x7d290046,0x0136009d,0x00000000}},	//   ňkov, ðssó, ּרַת_,
  { {0x645a1bfc,0x62840025,0xddcd003b,0x00000000}},	//   ynti, _mhio, slaţ,
  { {0x62960035,0x7b0100fe,0x18670896,0x00000000}},	//   _liyo, äytä, пачи_,
  { {0xb17b0d02,0x6e360078,0x765b0014,0x00000000}},	//   mgåe, okyb, fnuy,
  { {0x62960a9f,0x6e360006,0x6d44004d,0x00000000}},	//   _niyo, nkyb, ozia,
  { {0x6d441bfd,0xa4f8007e,0x38cb005d,0x00000000}},	//   nzia, تکار_, _هالی_,
  { {0x644f0164,0x6e240035,0x629600a4,0x00000000}},	//   écip, hjib, _aiyo,
  { {0xddcd02f4,0xe41a0024,0x62961bfe,0x00000000}},	//   hlaš, _kľúč, _biyo,
  { {0x6d440089,0xdb1e00cd,0xa77b0047,0x00000000}},	//   kzia, rapè, _פראפ,
  { {0x6296132d,0x61f8000d,0x518401ce,0x00000000}},	//   _diyo, чняў_, еура,
  { {0x6d440045,0xc953014e,0xc05b0500,0x00000000}},	//   dzia, תמש_, сім_,
  { {0xb17b0146,0x62840025,0x9f5a1bff,0x00000000}},	//   dgåe, _fhio, _papá_,
  { {0x3377014e,0xb5fd001c,0xddc4003b,0x00000000}},	//   _מתוך_, toši, voiţ,
  { {0x7e6d000c,0xddcd01a6,0xdb1c00cd,0x00000000}},	// [2970] roap, glaš, _herè,
  { {0x6e240035,0xb5fd1c00,0x7a330058,0x00000000}},	//   ajib, roši, _içti,
  { {0x3cf90053,0x682f00b9,0x69c2001f,0x00000000}},	//   _उनके_, _mødt, faoe,
  { {0xddcd00c3,0x7bde00a4,0xb05b0072,0x00000000}},	//   blaš, agpu, isäm,
  { {0x8c3b0199,0x99840080,0x88c80054,0x00000000}},	//   _auße, _domů_, злів_,
  { {0xe8f8000d,0x682f05a5,0x27e10244,0x00000000}},	//   ялі_, _nødt, ühn_,
  { {0x7d0d1c01,0xca7700f2,0x3e770058,0x00000000}},	//   lvas, _فارغ, eçti_,
  { {0xff180063,0x443c1c02,0x765b0058,0x00000000}},	//   לקות_, _alv_, unuy,
  { {0x3a84000d,0x58d4050f,0x645d0003,0x00000000}},	//   _чырв, _потт, ésio,
  { {0x23c6004c,0x3ce9007d,0x8c3b0244,0x00000000}},	//   víjí_, itav_, _fuße,
  { {0xb05b00c7,0x6d441c03,0x3ce90019,0x00000000}},	//   rsäl, zzia, htav_,
  { {0xdb1c00b9,0xc7b8007d,0x7640002b,0x00000000}},	//   _udrå, _dođu_, chmy,
  { {0xdb1e0e1a,0x6609005b,0x7d0b0583,0x00000000}},	//   rapé, mdek, ægsl,
  { {0x6d440024,0xddcd007d,0x660918d2,0x00000000}},	//   vzia, vlaš, ldek,
  { {0x62840027,0xdee31c04,0x64411c05,0x00000000}},	//   _thio, кори, mhli,
  { {0x2ca600ed,0x9e75005e,0x1e750002,0x00000000}},	//   íodo_, ећуј, еѓус,
  { {0x15e20053,0x6e240150,0xb17b00cf,0x00000000}},	// [2980] क्टर_, rjib, tgåe,
  { {0x660900fe,0x6d441c06,0x26c700b2,0x00000000}},	//   hdek, rzia, ksno_,
  { {0xb17b0203,0xdb050003,0x442500ca,0x00000000}},	//   rgåe, nchè, ijl_,
  { {0xddcd001c,0x2a600019,0xa2d50053,0x00000000}},	//   plaš, õib_, _भिन्,
  { {0x64411c07,0x682f06a5,0x66091c08,0x00000000}},	//   khli, _nøds, ddek,
  { {0x645d0003,0x76aa1c09,0x66091c0a,0x00000000}},	//   ésil, отив_, edek,
  { {0x8c3b00bd,0xda6600de,0x986900de,0x00000000}},	//   _fußb, _قاري, أحنف_,
  { {0x44250146,0xd5b00021,0x64411a59,0x00000000}},	//   ejl_, دفة_, ehli,
  { {0x7d1b0268,0x69c0003d,0x34940062,0x00000000}},	//   _àust, _ieme, наир,
  { {0x682f02ab,0xd4670001,0x64411c0b,0x00000000}},	//   _døds, миње_, ghli,
  { {0x69c00e53,0x39460331,0x734a0e82,0x00000000}},	//   _keme, lzos_, ючив_,
  { {0x9f580024,0x682f02ab,0xb05b0137,0x00000000}},	//   ceré_, _føds, rsäm,
  { {0x69c00e53,0x229a003d,0x656f00bd,0x00000000}},	//   _meme, _rīku_, ücht,
  { {0x64410199,0xd0840076,0x69c019ad,0x00000000}},	//   chli, выси, _leme,
  { {0x3267005a,0xfe73043e,0x33db009a,0x00000000}},	//   _отив, ندر_, _וחוד,
  { {0xbddb1b84,0xe508001b,0x27e9017f,0x00000000}},	//   _amèr, _kỷ_, đani_,
  { {0x61fd1c0c,0xa2da0053,0xdd03001c,0x00000000}},	// [2990] mesl, पूर्, _ārēj,
  { {0x6609005b,0xb05b00fe,0xb5fd1c0d,0x00000000}},	//   zdek, isäk, lošt,
  { {0xdb1500ea,0x7d0d1c0e,0x69c01c0f,0x00000000}},	//   _bezá, svas, _beme,
  { {0xfe3500b5,0x61fd1c10,0xdb050003,0x00000000}},	//   _נאָך_, nesl, nché,
  { {0xe8ee0076,0x61fd1c11,0x69c01c12,0x00000000}},	//   ыл_, iesl, _deme,
  { {0xb5fd004c,0x0138009a,0x66e502fa,0x00000000}},	//   hošt, ורדת_, еока,
  { {0x9f580080,0x66090179,0x3ea10019,0x00000000}},	//   teré_, tdek, _juht_,
  { {0x69c0094e,0x0654000d,0x8557007e,0x00000000}},	//   _geme, ктыў, ویار_,
  { {0x66091760,0x64411c13,0x61fd1c14,0x00000000}},	//   rdek, thli, desl,
  { {0x03250079,0x26dc0006,0x60dd0019,0x00000000}},	//   едон, buvo_, dusm,
  { {0x35b51c15,0x69cc0080,0xdb1c1c16,0x00000000}},	//   _збер, ůlež, _peré,
  { {0x61fd03a8,0x68340268,0xcb1200b5,0x00000000}},	//   gesl, _ràdi, אלט_,
  { {0x25b9007a,0x7bc5002c,0xddc40080,0x00000000}},	//   ðslu_, kahu, tliž,
  { {0x7bc51c17,0xf8b20063,0x6a781bae,0x00000000}},	//   jahu, רשם_, rífi,
  { {0x5e960032,0x3a3f005b,0x7bc50397,0x00000000}},	//   فلسط, _olup_, dahu,
  { {0x61fd1c18,0xf1bf013d,0xddcd056c,0x00000000}},	//   cesl, lján_, mnaś,
  { {0xc69211b4,0xac861137,0x5096005e,0x00000000}},	// [29a0] ראן_, егал, _прођ,
  { {0x69c01c19,0xf1bf013d,0x271c008d,0x00000000}},	//   _seme, nján_, _ủng_,
  { {0x69c006a7,0x22401c1a,0x4fbb0063,0x00000000}},	//   _peme, _klik_, _מציא,
  { {0xf38c0047,0x0f57069a,0xc9861c1b,0x00000000}},	//   קראָ, _טיים_, нули,
  { {0xd83a000d,0xa3cf0053,0x7bc500a4,0x00000000}},	//   зэй_, षणा_, bahu,
  { {0x26dc1c1c,0x394602dd,0x7bce00b9,0x00000000}},	//   tuvo_, rzos_, _udbu,
  { {0x316c0045,0x8c1b00b5,0xdb05006c,0x00000000}},	//   ędzy_, _צולי, yché,
  { {0xb21b00b9,0xddd10078,0xe5c60121,0x00000000}},	//   mlæg, _įgūd, хско,
  { {0xb21b00b9,0xb5fd007d,0x61fd0075,0x00000000}},	//   llæg, vošt, vesl,
  { {0xb05b00c7,0x7c2e1c1d,0x22401c1e,0x00000000}},	//   rsäk, _jobr, _alik_,
  { {0xb21b0146,0x229a001c,0xe1ff0025,0x00000000}},	//   nlæg, _rīks_, nnóg_,
  { {0x916d001b,0xe508001b,0xe5a3005e,0x00000000}},	//   _nội_, _tỷ_, _бици,
  { {0x7bc50035,0xdb0518b2,0x61fd1781,0x00000000}},	//   yahu, rché, resl,
  { {0x7c2e1c1f,0x61fd1c20,0x60dd1c21,0x00000000}},	//   _nobr, sesl, rusm,
  { {0xddc40051,0x22401c22,0x60dd004b,0x00000000}},	//   bliż, _flik_, susm,
  { {0xb21b1c23,0x442e0da0,0xb05b0072,0x00000000}},	//   dlæg, _hof_, isäi,
  { {0x3a2d0186,0x7bc51c24,0x3d1b0053,0x00000000}},	// [29b0] _roep_, tahu, नमें_,
  { {0xddeb04de,0x6f03017d,0xe1ff0857,0x00000000}},	//   _کرده_, _ânco, leó_,
  { {0x7c2e1c25,0x7bc51c26,0xdb140046,0x00000000}},	//   _dobr, rahu, óaði,
  { {0x7bc50512,0x442e1c27,0xe1ff006d,0x00000000}},	//   sahu, _lof_, neó_,
  { {0x7c950032,0xb21b0146,0x7bc5002c,0x00000000}},	//   _للحص, lmæs, pahu,
  { {0xbddb0164,0x46f50086,0x25a90022,0x00000000}},	//   _flèc, вчит, _żal_,
  { {0xddcd0051,0xb21b01e1,0x1c0a0053,0x00000000}},	//   miał, nmæs, _होटल_,
  { {0x60cd017f,0x7c2e027d,0xb05b00fe,0x00000000}},	//   _ovam, _zobr, ssäh,
  { {0xe1ff00ea,0x93fd000d,0x98f4013a,0x00000000}},	//   deó_, оўнi, _مثلا,
  { {0x22401c28,0x628f006f,0x9f580290,0x00000000}},	//   _slik_, emco, ferì_,
  { {0x22400045,0xf1c3001b,0xb21b00b9,0x00000000}},	//   _plik_, _trở_, klæd,
  { {0x6b9a0026,0xe6040044,0xddcd056c,0x00000000}},	//   _útge, _مِمَ, rnaś,
  { {0xf1bf000f,0xdd010080,0x41030062,0x00000000}},	//   pján_, čtět, азяв,
  { {0x65940138,0x442e002b,0xd4790047,0x00000000}},	//   _сачу, _gof_, _קאַל,
  { {0x7c2e1c29,0x83f6005e,0xd46602b6,0x00000000}},	//   _robr, _рејс_, _шише_,
  { {0xb17b00c7,0x7c2e1028,0x224000d1,0x00000000}},	//   mgån, _sobr, _ulik_,
  { {0x660b00bb,0xb17b00c7,0xdca303d6,0x00000000}},	// [29c0] _magk, lgån, иати,
  { {0x660b00a5,0x2137016e,0x30760145,0x00000000}},	//   _lagk, _סטיל_, _шуйс,
  { {0x9f4800fe,0xb17b0137,0xfaa30085,0x00000000}},	//   ähän_, ngån, аахо,
  { {0xb21b007a,0x660b002c,0x7c2e002b,0x00000000}},	//   rlæg, _nagk, _wobr,
  { {0xb21b0146,0xd94603d6,0xe3b80058,0x00000000}},	//   slæg, ъеди, ybı_,
  { {0xddcd0051,0x98730304,0x2b4d004c,0x00000000}},	//   ciał, аліц, _řece_,
  { {0x4420001b,0x7d04004d,0xd8380130,0x00000000}},	//   _đi_, lwis, _niče_,
  { {0xb17b0137,0x6b830378,0xddcd0195,0x00000000}},	//   dgån, ünge, plať,
  { {0x2ca6018d,0x57ea000a,0x7d041c2a,0x00000000}},	//   íodh_, _одам_, nwis,
  { {0x6a78039f,0x683401a8,0xd838007c,0x00000000}},	//   rífu, _pàdu, _biče_,
  { {0xdb15004d,0x7d040206,0x66270058,0x00000000}},	//   _gezä, hwis, ürkç,
  { {0xb21b1c2b,0x7d040035,0xddcd0051,0x00000000}},	//   emær, kwis, ział,
  { {0x76420035,0xe1ff006d,0xa4d40086,0x00000000}},	//   _iloy, reó_, _солі,
  { {0xb21b1c2b,0xe1ff0331,0x66970041,0x00000000}},	//   gmær, seó_, _נאַרײ,
  { {0xf8c8008b,0x7d040333,0xadd5005e,0x00000000}},	//   hứ_, ewis, ловљ,
  { {0x63970063,0x1287007e,0xddcd0051,0x00000000}},	//   _בדוא_, _جمعی_, wiał,
  { {0xd90404de,0xebc70138,0x2d580b0f,0x00000000}},	// [29d0] _بی_, вљен, вить_,
  { {0x225902e0,0x61f6004c,0x76421c2c,0x00000000}},	//   lisk_, _zbyl, _lloy,
  { {0xddcd0051,0x8c3b004d,0x0ba401e2,0x00000000}},	//   riał, _fußn, ршум,
  { {0x629e0164,0x22591c2d,0xddcd0051,0x00000000}},	//   _épou, nisk_, siał,
  { {0x4dda014e,0xbd6b0001,0xdb1c1c2e,0x00000000}},	//   _אחרו, _црне_, _cerâ,
  { {0x07090044,0xd3660043,0xd7c902da,0x00000000}},	//   فيتي_, _هه_, روبه_,
  { {0x660b0273,0x225906f1,0xf094069a,0x00000000}},	//   _pagk, kisk_, בנס_,
  { {0xf5090cbb,0xdb0700ea,0x2259000e,0x00000000}},	//   енил_, _bejö, jisk_,
  { {0x614a0003,0x22590d7d,0xb05b004d,0x00000000}},	//   _mêlé, disk_, lsäu,
  { {0xb17b0137,0x2c1c0042,0x14250054,0x00000000}},	//   tgån, नाएं_, удом,
  { {0x22590d7d,0xb05b004d,0x7d041c2f,0x00000000}},	//   fisk_, nsäu, zwis,
  { {0xb17b00c7,0x7d040051,0x22590f4b,0x00000000}},	//   rgån, ywis, gisk_,
  { {0xb21b01e1,0xdb05006c,0xb05b0244,0x00000000}},	//   tmær, nchâ, hsäu,
  { {0xdb1c02dd,0xd838074f,0xb17b00a5,0x00000000}},	//   _serí, _tiče_, pgån,
  { {0xdb1c1c30,0x225902c0,0x9e66005d,0x00000000}},	//   _perí, bisk_, هارن,
  { {0x22590045,0x25ad1c31,0xb21b00b9,0x00000000}},	//   cisk_, ncel_, smær,
  { {0xb21b00b9,0xdb1c1c32,0xddcd0022,0x00000000}},	// [29e0] pmær, _verí, diań,
  { {0x629e0268,0x5f76007e,0xdb1e0139,0x00000000}},	//   _èpoc, _ماجر, eapá,
  { {0xe9da1c33,0x7d04004d,0xb05b004d,0x00000000}},	//   еке_, swis, gsäu,
  { {0x61e61c34,0x9f58099f,0x27150013,0x00000000}},	//   ngkl, merà_, _ính_,
  { {0x9f58197c,0x27150013,0x3202017c,0x00000000}},	//   lerà_, _h́nh_, ieky_,
  { {0xdcfd003d,0xf539004c,0xe8940e74,0x00000000}},	//   _uzsā, dyť_, шаль,
  { {0xf1ba001b,0xeab401f9,0x9f581c35,0x00000000}},	//   _đơn_, _כִּי_, nerà_,
  { {0x7e640b34,0x6443085f,0xb05b01bb,0x00000000}},	//   nnip, _alni, lsät,
  { {0xc966000d,0x9f580290,0xdb1c00cd,0x00000000}},	//   _свай, herà_, _herà,
  { {0x545406be,0x68e20b4e,0x22590051,0x00000000}},	//   рвот, muod, wisk_,
  { {0xd5e2001b,0xb05b00fe,0x22591c36,0x00000000}},	//   _chọ, isät, tisk_,
  { {0x9f58197c,0x3eb800c2,0xbb3b0047,0x00000000}},	//   derà_, dprt_, געטי,
  { {0xf1bf00ea,0x7c3e00d1,0x2715008b,0x00000000}},	//   lják_, kkpr, _ánh_,
  { {0x61e600a4,0x225917d5,0x3394000d,0x00000000}},	//   agkl, sisk_, _калё,
  { {0x645a1c37,0x22591c38,0x33170021,0x00000000}},	//   miti, pisk_, _مزيد_,
  { {0x442c00c7,0x645a1852,0x7c3e00ca,0x00000000}},	//   ljd_, liti, ekpr,
  { {0x26c1000f,0xdc5502a9,0x644800fe,0x00000000}},	// [29f0] ához_, авањ, ohdi,
  { {0x68e20006,0xb05b0137,0xddcd0051,0x00000000}},	//   duod, gsät, wiań,
  { {0xcb550138,0x442c0122,0x443e1c39,0x00000000}},	//   јвећ, ijd_, ikt_,
  { {0xdb1c03d9,0xf1bf00ea,0xb05b004d,0x00000000}},	//   _serã, dják_, rsäu,
  { {0x443e0026,0xfc3f0025,0x89a80086,0x00000000}},	//   kkt_, _dtír_, уків_,
  { {0x443e0122,0xccf20063,0x7c3e1c3a,0x00000000}},	//   jkt_, _וכך_, ckpr,
  { {0xfc3f02dd,0xdb1c0016,0xaa950086,0x00000000}},	//   _guía_, _verã, _вивч,
  { {0x443e1c3b,0xe6c40021,0x6e2d1c3c,0x00000000}},	//   ekt_, حتوي, njab,
  { {0x7bc70397,0xdb1c0016,0x6d4d006f,0x00000000}},	//   _keju, _terã, nzaa,
  { {0xf5390024,0x64480025,0x4d7c0047,0x00000000}},	//   ryť_, ghdi, ערזע,
  { {0x9f581c3d,0x628d0139,0x63850699,0x00000000}},	//   xerà_, _bhao, ргна,
  { {0x443e0122,0x9f58051e,0x38ab0146,0x00000000}},	//   akt_, verà_, _kør_,
  { {0x9f581c3e,0x628d0027,0x38ab00d1,0x00000000}},	//   derá_, _dhao, _jør_,
  { {0x443e1c3f,0x6d4d006f,0x9f58197c,0x00000000}},	//   ckt_, dzaa, terà_,
  { {0x94740021,0x6d4d1c40,0x68e20006,0x00000000}},	//   _ادنا, ezaa, zuod,
  { {0x9f580290,0x628d0025,0x69cb1c41,0x00000000}},	//   rerà_, _ghao, jage,
  { {0xb05b03c8,0xdb1c00cd,0x527b0063,0x00000000}},	// [2a00] tsät, _serà, _בנקא,
  { {0xdb1c0025,0xb05b004d,0x69cb1c42,0x00000000}},	//   _aerá, usät, eage,
  { {0x49ca0076,0xb05b0d88,0x9f581c43,0x00000000}},	//   влен_, rsät, berá_,
  { {0x38ab191f,0x9f5806b2,0xdb1c006d,0x00000000}},	//   _bør_, cerá_, _cerá,
  { {0xb05b00c7,0x443e02ea,0x39400b9b,0x00000000}},	//   psät, ykt_, áis_,
  { {0xf1bf000f,0xdb1c00cd,0x68e20006,0x00000000}},	//   tják_, _terà, ruod,
  { {0x69cb1c44,0x68e200fe,0x39400006,0x00000000}},	//   bage, suod, šis_,
  { {0x38ab02ab,0xd6260021,0xf1bf00ea,0x00000000}},	//   _før_, شعبي, rják_,
  { {0x38ab010a,0x37e60076,0x645a1c45,0x00000000}},	//   _gør_, _возг, titi,
  { {0x628d0027,0x9f580024,0x443e008f,0x00000000}},	//   _shao, zerá_, ukt_,
  { {0x443e1c46,0xcc3b0047,0x7980002b,0x00000000}},	//   rkt_, דעיט, _hymw,
  { {0x443e1c47,0x7ae300cd,0x76491a62,0x00000000}},	//   skt_, ànti, chey,
  { {0x9f580016,0xc05b019d,0x645a1c48,0x00000000}},	//   verá_, вів_, piti,
  { {0xdb1e0268,0xc05b0086,0x44f000cd,0x00000000}},	//   capç, тім_, mà_,
  { {0xa2e3000a,0x628d0025,0xdb1e0019,0x00000000}},	//   _дојд, _thao, napä,
  { {0x7bc706a7,0x20030035,0x6d4d006f,0x00000000}},	//   _seju, seji_, tzaa,
  { {0x629f0164,0x7bc70397,0x2ba70001,0x00000000}},	// [2a10] _époq, _peju, ајев,
  { {0x44f002f6,0xdb1c02dd,0x6d4d0122,0x00000000}},	//   ià_, _será, rzaa,
  { {0x38ab1609,0x69cb1c49,0x44f0008b,0x00000000}},	//   _sør_, tage, hà_,
  { {0xceb200b7,0x7d0b00b9,0xe0df01f4,0x00000000}},	//   _מיט_, ægss, orò_,
  { {0xdb1c1143,0xe9d8000d,0x44f000cd,0x00000000}},	//   _verá, ркі_, jà_,
  { {0x44f000cd,0x69cb1c4a,0xdb051c4b,0x00000000}},	//   dà_, sage, achá,
  { {0xb9e70086,0xdb051c4c,0x69cb1c4d,0x00000000}},	//   _візи, rbhó, page,
  { {0x683d0268,0x62560006,0x38ab000e,0x00000000}},	//   _mèdi, ršok, _tør_,
  { {0x6486007a,0xf8070086,0x44f000cd,0x00000000}},	//   rðin, _вчен, gà_,
  { {0xddcd00c2,0x0445005e,0x61ed1c4e,0x00000000}},	//   jlaž, сеон, _acal,
  { {0x9f580268,0xe0df19c9,0x78a9006d,0x00000000}},	//   merç_, erò_, _huev,
  { {0x44f000cd,0x78a11c4f,0x7d160072,0x00000000}},	//   bà_, _hilv, yvys,
  { {0x78a91c50,0x44f00268,0x25bf165d,0x00000000}},	//   _juev, cà_, mbul_,
  { {0x78a9006d,0xf1bf00be,0xdb050566,0x00000000}},	//   _muev, abá_, zchá,
  { {0x7ae50019,0xe0df0290,0x61ed00fe,0x00000000}},	//   juht, arò_, ällö,
  { {0xf8a504de,0xb21b00b9,0x60db0006,0x00000000}},	//   _يک_, llæn, šuma,
  { {0x78a9048e,0x6441001c,0x925a005d,0x00000000}},	// [2a20] _nuev, okli, _لشکر_,
  { {0x64411c51,0x7e7d1c52,0x6aa01c53,0x00000000}},	//   nkli, _eksp, _simf,
  { {0x25bf0089,0x64411c54,0xb09b0063,0x00000000}},	//   kbul_, ikli, _תייר,
  { {0xdb1e0019,0xd910007e,0x0dba0021,0x00000000}},	//   vapä, ویز_, _حادث_,
  { {0x78a90118,0x44f000cd,0x64411c55,0x00000000}},	//   _cuev, xà_, kkli,
  { {0x78a1003d,0x44f01c56,0x7659002b,0x00000000}},	//   _cilv, và_, _amwy,
  { {0x64410246,0xb05b0050,0x1ae31c57,0x00000000}},	//   dkli, isäp, _норм,
  { {0x44f002f6,0x44b4019d,0xbb3b0047,0x00000000}},	//   tà_, обис, _געלי,
  { {0x78a9106e,0xdb1c0c77,0x3ebf0130,0x00000000}},	//   _guev, _berç, ćuti_,
  { {0x44f01c58,0x6441002c,0x9f5a0268,0x00000000}},	//   rà_, gkli, _japó_,
  { {0xcc7b00b5,0x44f000cd,0xe2f80086,0x00000000}},	//   רװיר, sà_, шені_,
  { {0x644100e8,0x78a10122,0xe0df051e,0x00000000}},	//   akli, _zilv, trò_,
  { {0xdb1c00fe,0x64411c59,0xe0df01f4,0x00000000}},	//   _herä, bkli, urò_,
  { {0xdb1c1c5a,0xe0df0290,0x64411c5b,0x00000000}},	//   _gerç, rrò_, ckli,
  { {0x7659001f,0xc0580454,0x3ce0004b,0x00000000}},	//   _ymwy, сія_, eriv_,
  { {0x2fdf00dd,0x74bf0042,0x8de500de,0x00000000}},	//   şug_, लीकृ, تكره,
  { {0x7c350024,0x3ea20829,0xdb1c0058,0x00000000}},	// [2a30] _pozr, _dikt_, _yerç,
  { {0x25bf0089,0x4d980475,0x3ea2008f,0x00000000}},	//   zbul_, скую_, _eikt_,
  { {0xfbd00021,0xdc300078,0x29d50021,0x00000000}},	//   عتك_, ažįs, قياس,
  { {0x6441001c,0x78a11c5c,0x7ae50b75,0x00000000}},	//   zkli, _silv, ruht,
  { {0xbcfb0016,0x7ae5003a,0x78a91c5d,0x00000000}},	//   _exér, suht, _quev,
  { {0xdb1c01e3,0xdd310051,0x8aa71c5e,0x00000000}},	//   _berä, zęśc, _град,
  { {0x20131c5f,0x6e3800a8,0xf6d50054,0x00000000}},	//   _maxi_, žabš, ціля,
  { {0xe8920066,0x56920092,0x44f90085,0x00000000}},	//   ĺňať_, мајт, ахоў_,
  { {0x78a107e2,0x8937007e,0xdb1c0003,0x00000000}},	//   _tilv, _اعزا, _perç,
  { {0x99480021,0xf9900021,0xa9880063,0x00000000}},	//   _الكل_, _سبق_, _הָעִ,
  { {0xdb1c00bd,0xb21b0146,0xc5d50086,0x00000000}},	//   _gerä, rlæn, _діль,
  { {0x625a0121,0x99f90047,0xb21b01e1,0x00000000}},	//   ррор_, ױפֿפ, slæn,
  { {0xdb1c1908,0x64411c60,0x3ea200df,0x00000000}},	//   _terç, pkli, _rikt_,
  { {0x224900e3,0x2d8200ac,0x3ea20829,0x00000000}},	//   _elak_, _ryke_, _sikt_,
  { {0x03250086,0x2d8200d1,0x4fa30062,0x00000000}},	//   _єдин, _syke_, дирв,
  { {0x3f840418,0xdcf70053,0xedf4005d,0x00000000}},	//   āmu_, ुबंध_, ثيرگ,
  { {0x3ea200c7,0x62730021,0x7d0b01e1,0x00000000}},	// [2a40] _vikt_, _تهيئ, ægsp,
  { {0x62861c61,0x39420019,0x3a241c62,0x00000000}},	//   llko, _üksi_, _snmp_,
  { {0x3ea2001c,0x6da6010d,0x0b46000d,0x00000000}},	//   _tikt_, _мина, ўнен,
  { {0x66fc008f,0xdb1c00a5,0x3ce01c63,0x00000000}},	//   nākš, _nerå, priv_,
  { {0x62861c64,0xf1bf013d,0xa3e90042,0x00000000}},	//   ilko, mját_, यला_,
  { {0xdb1c00fe,0xf1bf00ea,0x9f580072,0x00000000}},	//   _perä, lját_, perä_,
  { {0x27e001f7,0xdca30f55,0xf793000d,0x00000000}},	//   ğin_, _цари, машэ,
  { {0xdb1c00bd,0x628600b9,0x67f40026,0x00000000}},	//   _verä, jlko, fþjó,
  { {0xd40603d6,0xe46a0002,0x69c203bf,0x00000000}},	//   ояни, ишол_, mboe,
  { {0x6abe00d1,0xdb1c00fe,0x68e2001f,0x00000000}},	//   oppf, _terä, mrod,
  { {0x22490162,0x68e40025,0xf1bf00ea,0x00000000}},	//   _plak_, áidf, kját_,
  { {0x68e21c65,0x69c21c66,0x64a61c67,0x00000000}},	//   orod, nboe, _дада,
  { {0x2beb0235,0x1a9b00b5,0x22491c68,0x00000000}},	//   _चालू_, ייטע, _vlak_,
  { {0xadee0053,0x68e2013d,0x7414005d,0x00000000}},	//   ङ्घन_, irod, _روبا,
  { {0xd83800c3,0x69c21986,0xce950062,0x00000000}},	//   _moč_, kboe, завъ,
  { {0x68e20218,0xf1bf00ea,0x628601a8,0x00000000}},	//   krod, gját_, clko,
  { {0x5d550581,0xfbab0376,0x69c2006f,0x00000000}},	// [2a50] чкат, атей_, dboe,
  { {0xf1bf00ea,0xd83800c2,0x68e21c69,0x00000000}},	//   aját_, _noč_, drod,
  { {0xb5fd10f5,0x68e21c6a,0x625601d1,0x00000000}},	//   liše, erod, ršov,
  { {0x69c20122,0xc33300b5,0x5a35005a,0x00000000}},	//   gboe, ווע_, янет,
  { {0x2ca302b0,0x68e20051,0x62560114,0x00000000}},	//   _tijd_, grod, pšov,
  { {0xdb15013d,0xd7fb1580,0xe1ff013d,0x00000000}},	//   _kezü, руд_, liód_,
  { {0x4429001b,0x3ffc00b5,0xb6590076,0x00000000}},	//   _đa_, יפגע, йших_,
  { {0x67f40026,0x68e21c6b,0x644a1c6c,0x00000000}},	//   tþjó, brod, _alfi,
  { {0xdb050199,0x2919006d,0x7d0d1c6d,0x00000000}},	//   schä, _ésa_, nwas,
  { {0x67f40026,0x7d0d00a4,0x28e00082,0x00000000}},	//   rþjó, iwas, _निति,
  { {0x67f40026,0x5884000d,0x59cf0042,0x00000000}},	//   sþjó, _цыта, _हजार,
  { {0xdb12000f,0x7d0d1c6e,0x83fc007d,0x00000000}},	//   égév, kwas, viđe,
  { {0x271c001b,0xa567007e,0xb1430456,0x00000000}},	//   _ảnh_, _بدان, енял,
  { {0xdb1500bd,0x66fc001c,0xa8790041,0x00000000}},	//   _bezü, sākš, מאָר,
  { {0x7d0d1c6f,0x44271c70,0xf1bf013d,0x00000000}},	//   ewas, _inn_, tját_,
  { {0xdd920021,0x660908f3,0x68e20022,0x00000000}},	//   فوز_, neek, yrod,
  { {0xf1bf013d,0x59cf0042,0x16c80082,0x00000000}},	// [2a60] rját_, _हज़र, _रब्ब,
  { {0x66091c71,0x4c83036a,0xb17b0137,0x00000000}},	//   heek, елув, tgåv,
  { {0x291f0035,0x69c2006f,0x103b0063,0x00000000}},	//   _arua_, tboe, _הגיע,
  { {0xdca61c72,0x7d0d0035,0x200a005b,0x00000000}},	//   _нами, bwas, lebi_,
  { {0x69c2016d,0x68e20006,0xb05b0019,0x00000000}},	//   rboe, urod, späe,
  { {0xb17b0031,0x69c21c73,0xd823005e,0x00000000}},	//   mgåt, sboe, едљи,
  { {0xa91d0a63,0xe737018e,0x2018001c,0x00000000}},	//   _vyža, зеј_, idri_,
  { {0x44270027,0x54b803d6,0x660900b9,0x00000000}},	//   _ann_, огия_, geek,
  { {0x7bce06a7,0xb17b00d1,0x48e302a2,0x00000000}},	//   _kebu, ngåt, _потв,
  { {0x200a007d,0xb5fd0734,0x44271c74,0x00000000}},	//   jebi_, više, _cnn_,
  { {0x67bb0063,0x20180014,0xf3660505,0x00000000}},	//   _המבק, ddri_, ятин,
  { {0x44271c75,0x7d0d0051,0x7bce1472,0x00000000}},	//   _enn_, ywas, _lebu,
  { {0xba570041,0x7bdc1c76,0x867b009a,0x00000000}},	//   לסטו_, _odru, _פרדו,
  { {0xc058000d,0xb5fd082a,0x7bce1c77,0x00000000}},	//   піс_, riše, _nebu,
  { {0x8c3b00bd,0xff0408b9,0x33fb0165,0x00000000}},	//   _mußt, нятн, _להגנ,
  { {0x7d0d002c,0xb5fd082a,0xf3130044,0x00000000}},	//   twas, piše, _أبوظ,
  { {0x62560006,0x2d8f102d,0x200a005b,0x00000000}},	// [2a70] ršot, åge_, bebi_,
  { {0x200a017d,0x7c140086,0xdb07013d,0x00000000}},	//   cebi_, ндує, _ifjú,
  { {0x2bb80021,0x7afa0137,0x7d0d1c78,0x00000000}},	//   سالة_, _ättl, swas,
  { {0xa3dc0053,0xfd1f008b,0x291f0290,0x00000000}},	//   तृत_, _trì_, _prua_,
  { {0x9f5102dd,0x7bdc006f,0x6609004b,0x00000000}},	//   pezó_, _fdru, veek,
  { {0x7bce05e4,0x66091c79,0x7e6d013d,0x00000000}},	//   _gebu, week, lnap,
  { {0xe736005a,0x6d400019,0xac941c7a,0x00000000}},	//   дещ_, _ümar, _чарш,
  { {0x7bdc1c7b,0x61fd006f,0x7e6d032e,0x00000000}},	//   _zdru, jfsl, nnap,
  { {0x66090173,0x7cde000c,0x7e6d1c7c,0x00000000}},	//   reek, părţ, inap,
  { {0x68e40027,0x61fd0026,0x7e6d1c7d,0x00000000}},	//   áide, efsl, hnap,
  { {0x420a02e4,0x03a50002,0x7e6d0f4b,0x00000000}},	//   онно_, ќино, knap,
  { {0x1fc60394,0xd9ff0053,0xc049009a,0x00000000}},	//   वर्ड, ोजित_, _דז_,
  { {0xd4350021,0x7e6d1c7e,0x200a1c7f,0x00000000}},	//   _يعتب, dnap, tebi_,
  { {0x7e6d1c80,0xe8000042,0x24180085,0x00000000}},	//   enap, ल्पा_, _ночы_,
  { {0x7bce1c81,0xb5fd0195,0xa0a303e5,0x00000000}},	//   _rebu, enši, тард,
  { {0x7bce014f,0x7bdc01da,0x7e6d1c82,0x00000000}},	//   _sebu, _sdru, gnap,
  { {0xd59a0041,0x6abc1c83,0x6aae1c84,0x00000000}},	// [2a80] ַבעל, _strf, _subf,
  { {0x7e6d002c,0xb17b00a5,0xfce30d0a,0x00000000}},	//   anap, rgåt, тофо,
  { {0xddc60121,0x5f76005d,0x28e00042,0x00000000}},	//   _обни, _زادر, _निहि,
  { {0x533600b5,0x7bce1c85,0x1bf00042,0x00000000}},	//   ונען_, _webu, _चावल_,
  { {0x644f001c,0x7bce1c86,0x7c49013d,0x00000000}},	//   īcij, _tebu, ásró,
  { {0x7bdc017f,0xdb24003b,0x7e640072,0x00000000}},	//   _udru, ăsân, liip,
  { {0x2bc4016a,0x61fd00ac,0x62840078,0x00000000}},	//   _ल्या, yfsl, _okio,
  { {0x44200469,0x8c3b004d,0x15140330,0x00000000}},	//   _şi_, _wußt, едия,
  { {0x6d440397,0x7c3c1c87,0xf3f10013,0x00000000}},	//   nyia, _korr, hịu_,
  { {0x03f80001,0xdb1c0205,0x628405b3,0x00000000}},	//   чној_, _berø, _akio,
  { {0x7c3c1c88,0x7e6d1c89,0x17790085,0x00000000}},	//   _morr, ynap, _есць_,
  { {0x68ed0812,0x7546005a,0x63ad1c8a,0x00000000}},	//   žodž, _онез, _şant,
  { {0x61f40024,0x7c3c0104,0x61fd1c8b,0x00000000}},	//   _želá, _oorr, rfsl,
  { {0x7c3c1c8c,0x20840044,0x30840044,0x00000000}},	//   _norr, َلَّ, َلَف,
  { {0x9f5f005b,0xe3b8005b,0x7522004a,0x00000000}},	//   _ürün_, mcı_, _hroz,
  { {0x7e6d0035,0x91690013,0x443c1c8d,0x00000000}},	//   unap, _lửa_, _hov_,
  { {0x7c3c0d0f,0x7e6d1c8e,0xb5fd1840,0x00000000}},	// [2a90] _borr, rnap, niša,
  { {0xe3b8005b,0x2ca71c8f,0x7c3c1292,0x00000000}},	//   ncı_, önd_, _corr,
  { {0x7c3c035a,0x660200c2,0x443c1c90,0x00000000}},	//   _dorr, _obok, _mov_,
  { {0x60cd1c91,0xddeb007e,0xddc4000c,0x00000000}},	//   _kwam, _برده_, rniţ,
  { {0xa803005b,0x644804aa,0xb90b009e,0x00000000}},	//   _çıkt, kkdi, تزام_,
  { {0x68eb016d,0x9169008b,0x60cd0035,0x00000000}},	//   rugd, _cửa_, _mwam,
  { {0xddc400c3,0x98bf005b,0x39491867,0x00000000}},	//   lniš, ırım_, šas_,
  { {0x7c3c1c92,0xddc4007d,0x83fc007d,0x00000000}},	//   _zorr, oniš, viđa,
  { {0xc8f4005a,0x75221806,0x6e3d12a9,0x00000000}},	//   _изтъ, _croz, _mosb,
  { {0xe1ff0022,0x20cd1581,0xe5760085,0x00000000}},	//   onów_, dži_, эзы_,
  { {0x443c0a02,0x63ad1c93,0xddc400c2,0x00000000}},	//   _dov_, _şans, hniš,
  { {0xf0890063,0x75221c94,0x64480058,0x00000000}},	//   _הנ_, _froz, akdi,
  { {0x321e0080,0xddc402f7,0x75221c95,0x00000000}},	//   ěty_, jniš, _groz,
  { {0x443c1c96,0xddc402e2,0x661b1c97,0x00000000}},	//   _gov_, dniš, lduk,
  { {0x6e3d006f,0x75220a14,0x20cd1844,0x00000000}},	//   _bosb, _zroz, aži_,
  { {0x8236006a,0x7d060089,0x661b1c98,0x00000000}},	//   _سربا, _ppks, nduk,
  { {0x6e3d001f,0x1d071259,0xb05b0072,0x00000000}},	// [2aa0] _dosb, нети_, mpän,
  { {0x31570047,0xe0fb0063,0x661b0072,0x00000000}},	//   _ניין_, _צליל, hduk,
  { {0x7c3c1c99,0x4ff70047,0x9169008d,0x00000000}},	//   _vorr, _אזיע_, _rửa_,
  { {0xddc40198,0x78a800c7,0x7ae30027,0x00000000}},	//   bniš, _sidv, ánta,
  { {0xdb1e1c9a,0xe3b80058,0xc9831c9b,0x00000000}},	//   lapü, ycı_, луши,
  { {0x260a0013,0xb5fd1c9c,0x98a31c9d,0x00000000}},	//   _ẹo_, viša, гиче,
  { {0x09e6019d,0x7522004c,0x6aa91276,0x00000000}},	//   _повн, _sroz, _fief,
  { {0x75221c9e,0xe8fa0002,0x201a08f2,0x00000000}},	//   _proz, _нлб_, _lapi_,
  { {0x7d1b017d,0x78a808a9,0xc8ca014d,0x00000000}},	//   _áust, _tidv, _روان_,
  { {0x201a000f,0x07a615d4,0x78250021,0x00000000}},	//   _napi_, _зазн, _لعمل,
  { {0xddc408ea,0x60cd1c9f,0x2caa006d,0x00000000}},	//   zniš, _swam, _mibd_,
  { {0x75221ca0,0xb5fd114b,0xd377000d,0x00000000}},	//   _troz, lišn, эчы_,
  { {0x44f900cd,0x6e3d1ca1,0x865b009a,0x00000000}},	//   cè_, _rosb, _צדדי,
  { {0x201a1ca2,0xddc4027c,0x20cd074f,0x00000000}},	//   _capi_, vniš, rži_,
  { {0x6e3d00e8,0x141b0063,0x2ef50062,0x00000000}},	//   _posb, _מוגב, ъзвр,
  { {0xddc408ea,0x6d1c0042,0x9f60009c,0x00000000}},	//   tniš, निंग_, árát_,
  { {0x22ac0080,0x31350571,0x6aa91ca3,0x00000000}},	// [2ab0] _věku_, _репр, _rief,
  { {0xddc408ea,0xb5fd007d,0xb05b0072,0x00000000}},	//   rniš, jišn, ysäy,
  { {0xb5fd1ca4,0x99f5000d,0xcfb60063,0x00000000}},	//   dišn, вялі, _בלתי_,
  { {0xddc400b2,0xee210054,0xe1ff0022,0x00000000}},	//   pniš, _темi_, rnów_,
  { {0x9dd60047,0xb5fd0195,0xdfa7005d,0x00000000}},	//   _בורק_, inšt, _تحکي,
  { {0x7ae2008f,0x201a1ca5,0x64860014,0x00000000}},	//   ņota, _xapi_, iðis,
  { {0x6aa900bd,0x3946002c,0xe3b1007e,0x00000000}},	//   _tief, ayos_, یرد_,
  { {0x44f901a8,0xdb1e01a8,0x6b830244,0x00000000}},	//   tè_, aapó, üngu,
  { {0x44f90268,0xf4950121,0x661b0b38,0x00000000}},	//   uè_, крою, rduk,
  { {0x76491258,0x661b1ca6,0xe5040044,0x00000000}},	//   skey, sduk, ابيي,
  { {0x201a0397,0x35f5000d,0x95d90121,0x00000000}},	//   _rapi_, _апер, _ждет_,
  { {0x201a00f3,0x216a07da,0x3ce906f1,0x00000000}},	//   _sapi_, дими_, krav_,
  { {0x21240025,0x201a1ca7,0xe5350062,0x00000000}},	//   ímh_, _papi_, _шедь,
  { {0x3a3f1ca8,0xb05b0354,0xdcee008f,0x00000000}},	//   _loup_, spän, ūdīg,
  { {0xfc3f1088,0xe1ff006d,0xb05b0050,0x00000000}},	//   _luís_, mión_, ppän,
  { {0x201a0035,0xe1ff1ca9,0x2ee50014,0x00000000}},	//   _wapi_, lión_, álfa_,
  { {0x201a014f,0x3eab1caa,0xbea31cab,0x00000000}},	// [2ac0] _tapi_, _dict_, ратк,
  { {0xe1ff02dd,0x8b26000d,0xe572009a,0x00000000}},	//   nión_, кдзе, בַע_,
  { {0x8fa60635,0xb5fd007d,0x3ce900a5,0x00000000}},	//   _јане, višn, arav_,
  { {0xc332014e,0x3a3f1cac,0x2fd800cd,0x00000000}},	//   יוב_, _coup_, larg_,
  { {0xdb1e0026,0x3946006d,0x3ea01cad,0x00000000}},	//   tapó, uyos_, mmit_,
  { {0xdb1c000f,0xb7d80021,0xfbc30002,0x00000000}},	//   _kerü, روبا_, _вбро,
  { {0xc7b8007d,0x7c2e1cae,0x8c1b0063,0x00000000}},	//   _nađe_, _inbr, _קולי,
  { {0xdb1c00ea,0x96b7005e,0xeb971caf,0x00000000}},	//   _merü, њују_, _рис_,
  { {0xb5fd01b3,0x22920014,0xca750085,0x00000000}},	//   mišl, tákn_, _суры,
  { {0xe1ff1cb0,0x9f58006d,0x6264013d,0x00000000}},	//   gión_, neró_, sőol,
  { {0x225200e8,0x9f580080,0x25bd002b,0x00000000}},	//   _blyk_, terý_, _ffwl_,
  { {0xacbb0164,0xdb1c1cb1,0x26da004c,0x00000000}},	//   _brûl, _heró, ápou_,
  { {0x7c2e006f,0xb5fd004c,0x92580062,0x00000000}},	//   _onbr, rnšt, таят_,
  { {0xe1ff0814,0xdb1c1cb2,0x64860026,0x00000000}},	//   ción_, _berü, rðis,
  { {0x9f58006d,0xeeab0086,0x9f660014,0x00000000}},	//   deró_, дтак_, óuðu_,
  { {0x7c2e1cb3,0x645d001c,0x6dc40121,0x00000000}},	//   _anbr, īsie, исуж,
  { {0xb5fd0066,0x3a3f1cb4,0x645d008f,0x00000000}},	// [2ad0] dišl, _roup_, ūsie,
  { {0x7ae31919,0x3ea01cb5,0x3a3f00e5,0x00000000}},	//   ánto, amit_, _soup_,
  { {0x3ea01269,0xfc3f00cd,0xdb1c004d,0x00000000}},	//   bmit_, _suís_, _gerü,
  { {0x3ce900c3,0xd7f8000c,0xb21b00b9,0x00000000}},	//   prav_, _acă_, mlæs,
  { {0x26de00c2,0xdce7008f,0x9f580331,0x00000000}},	//   _avto_, īmēt, beró_,
  { {0xe1ff02dd,0x20111052,0x9f5801a8,0x00000000}},	//   xión_, nezi_, ceró_,
  { {0x20110035,0x27e9005b,0xef120063,0x00000000}},	//   iezi_, ğan_, ֶּה_,
  { {0x27e901f7,0x2011003b,0xa91d017c,0x00000000}},	//   şan_, hezi_, _lyži,
  { {0x2a64011c,0x9f580290,0x20110b88,0x00000000}},	//   _търг, nerò_, kezi_,
  { {0x69d91cb6,0x98a4005e,0x2011013d,0x00000000}},	//   lawe, _виђе, jezi_,
  { {0xe1ff006d,0x3ea000fe,0xf2a602b3,0x00000000}},	//   rión_, ymit_, лиоп,
  { {0xe1ff048e,0xb21b0146,0x69d91cb7,0x00000000}},	//   sión_, dlæs, nawe,
  { {0x64860026,0xe1ff0331,0xd5ae01fb,0x00000000}},	//   rðir, pión_, _عفو_,
  { {0xdb050025,0x9f580290,0x69d9083f,0x00000000}},	//   nchó, derò_, hawe,
  { {0x2d8f00bd,0x53320002,0x2eb50b3f,0x00000000}},	//   ügen_, _гејт, истс,
  { {0x229900ea,0x69d91cb8,0xdb1c004d,0x00000000}},	//   téke_, jawe, _verü,
  { {0xed571cb9,0x9f58006d,0x7bd51cba,0x00000000}},	// [2ae0] гот_, teró_, _bezu,
  { {0xdb1c000f,0x09cc0053,0x3ea0001c,0x00000000}},	//   _terü, ार्य, smit_,
  { {0x272301f7,0x5f460021,0x60db008f,0x00000000}},	//   _nın_, _إنجل, šumt,
  { {0x24851cbb,0x9f41006d,0x62861cbc,0x00000000}},	//   holm_, _echó_, noko,
  { {0x9f580118,0xb5fd0a80,0xdb1c1cbd,0x00000000}},	//   peró_, rišl, _peró,
  { {0xd9430138,0xddcd0051,0x7d16002b,0x00000000}},	//   сељи, chał, mwys,
  { {0x60c40290,0xdb1c1cbe,0x7d16001f,0x00000000}},	//   _ltim, _veró, lwys,
  { {0x60c40016,0x2011003b,0x60dd04aa,0x00000000}},	//   _otim, zezi_, yssm,
  { {0x2956005a,0x7d161cbf,0xb21b0205,0x00000000}},	//   _съвр, nwys, klær,
  { {0xb7b5008b,0x3cfb0047,0x61e41cc0,0x00000000}},	//   _hạn, עלינ, _adil,
  { {0x60c40078,0x22590121,0x7d16002b,0x00000000}},	//   _atim, вины_, hwys,
  { {0x20110009,0xe452006a,0x88c7004c,0x00000000}},	//   wezi_, _گفتگ, směš,
  { {0x61e40185,0xb7b5001b,0x20111cc1,0x00000000}},	//   _ddil, _mạn, tezi_,
  { {0x61e401f7,0xf5930032,0x7d1600ac,0x00000000}},	//   _edil, _الهج, dwys,
  { {0xa91d0024,0x69d90035,0x7d1600ac,0x00000000}},	//   _vyži, yawe, ewys,
  { {0x7d161cc2,0x24490014,0x20111cc3,0x00000000}},	//   fwys, _rúmi_, sezi_,
  { {0xdb0500bd,0x320900a4,0x629f00cd,0x00000000}},	// [2af0] schü, _ibay_, _èpoq,
  { {0x69d916ae,0x69c01cc4,0x6bd40021,0x00000000}},	//   wawe, _afme, متمر,
  { {0x7bd5007d,0x69d91cc5,0x9f350054,0x00000000}},	//   _vezu, tawe, _тені,
  { {0x7f3a0047,0xb7b5008b,0x9f58197c,0x00000000}},	//   _סערו, _cạn, però_,
  { {0xb7b5001b,0xe0df0290,0x80a4007e,0x00000000}},	//   _dạn, nsò_, _خمین,
  { {0xb346005b,0xe8000053,0x62861cc6,0x00000000}},	//   _kaçı, ल्ला_, zoko,
  { {0xe7390928,0x9169008b,0x62861cc7,0x00000000}},	//   тей_, _lừa_, yoko,
  { {0xb5fd17b8,0x24520003,0x8aa41cc8,0x00000000}},	//   mišk, _râma_, _груд,
  { {0xf1c80080,0xb5fd17d2,0x62861cc9,0x00000000}},	//   ndář_, lišk, voko,
  { {0x6286056c,0xb4650a30,0x4465129d,0x00000000}},	//   woko, ркол, рвов,
  { {0xe29a0001,0x2129053b,0xb5fd17d2,0x00000000}},	//   као_, _arah_, nišk,
  { {0xe1260121,0x8c44003b,0x7d16002b,0x00000000}},	//   амми, ăşit, ywys,
  { {0x2d8f00bd,0xb5fd00c2,0x62861cca,0x00000000}},	//   ügel_, hišk, roko,
  { {0x32091ccb,0x9f58007a,0xb5fd0006,0x00000000}},	//   _ebay_, ferð_, kišk,
  { {0x9f58007a,0xb5fd1ccc,0x25bf003b,0x00000000}},	//   gerð_, višj, ocul_,
  { {0x25bf06a7,0x201e0006,0xb5fd00fc,0x00000000}},	//   ncul_, žti_, dišk,
  { {0xb21b0031,0xbc66000d,0xb5fd0078,0x00000000}},	// [2b00] plær, авак, eišk,
  { {0x7d16021f,0xb5fd17d2,0x64431ccd,0x00000000}},	//   rwys, fišk, _joni,
  { {0xe9da14cf,0x7d1600ac,0xb5fd0006,0x00000000}},	//   вке_, swys, gišk,
  { {0x6287007d,0x536c0041,0xa9261cce,0x00000000}},	//   čkog, עכאַ, идел,
  { {0xb5fd0006,0xd378007d,0x6aa21ccf,0x00000000}},	//   aišk, maće_, rmof,
  { {0xdb1c0026,0xb5fd17b8,0x1c020042,0x00000000}},	//   _ferð, bišk, र्शल_,
  { {0xdb1c007a,0xd6d703e6,0x475a0062,0x00000000}},	//   _gerð, аты_, ърдя_,
  { {0xddcd1cd0,0x96341cd1,0x7ae3003b,0x00000000}},	//   mnaţ, сниц, ânte,
  { {0x64430dd1,0xd90e007e,0xe944007e,0x00000000}},	//   _boni, _آیت_, _ارزی,
  { {0xddcd000c,0x656f0025,0xc34a0062,0x00000000}},	//   onaţ, úcha, вяме_,
  { {0x0bb7014e,0x6f090045,0x84330086,0x00000000}},	//   ילים_, łecz, інює,
  { {0x9f580014,0x21291cd2,0xf5060200,0x00000000}},	//   verð_, _prah_, _вздо,
  { {0xdfdb011c,0xc6930063,0xd378007d,0x00000000}},	//   къв_, _ואף_, daće_,
  { {0xd48f0086,0xe0df0290,0x9169008b,0x00000000}},	//   _єр_, rsò_, _vừa_,
  { {0xe0df0682,0xb05b00fe,0xaf34007e,0x00000000}},	//   ssò_, npäi, يرفت,
  { {0x443e0137,0xb5fd17b8,0x3eaf0137,0x00000000}},	//   ljt_, višk, ögt_,
  { {0x656d0024,0xdbd10026,0x212900c3,0x00000000}},	// [2b10] _ľahk, _býðu, _urah_,
  { {0xb5fd00eb,0xa8020058,0x606400de,0x00000000}},	//   tišk, çıla, _وهيل,
  { {0xf2d300b5,0x6aa3006f,0x2d870051,0x00000000}},	//   ַעס_, ïnfo, łne_,
  { {0xdb1c0ac6,0xb5fd1cd3,0xc7b8007d,0x00000000}},	//   _verð, rišk, _rađa_,
  { {0xb5fd0006,0x645a0e83,0xdb1c00a3,0x00000000}},	//   sišk, khti, _ffrï,
  { {0x89340754,0x7e6d1cd4,0x26110013,0x00000000}},	//   تعما, liap, _ạo_,
  { {0xe1ff013d,0x9b45005d,0xd7f8076f,0x00000000}},	//   giók_, _انزو, руч_,
  { {0x64431cd5,0x645a0ff2,0x7e6d1cd6,0x00000000}},	//   _soni, ehti, niap,
  { {0x6d4d014f,0xd5490076,0x64431cd7,0x00000000}},	//   nyaa, уппе_, _poni,
  { {0x645a1cd8,0x628d0035,0x25bf1cd9,0x00000000}},	//   ghti, _akao, scul_,
  { {0xd7950032,0xe1ff00ea,0x6443147f,0x00000000}},	//   _الاخ, ciók_, _voni,
  { {0xc0491cda,0x64431cdb,0x443e007d,0x00000000}},	//   _אז_, _woni, ajt_,
  { {0xd378007d,0xa9790041,0x7e6d1cdc,0x00000000}},	//   vaće_, ראָכ, diap,
  { {0x645a1cdd,0x4613007e,0x305501ce,0x00000000}},	//   chti, _دوچر, ођст,
  { {0x8c3b004d,0xd378007d,0x7d0f013d,0x00000000}},	//   _fußz, taće_, _apcs,
  { {0x7e6d1cde,0x3392005d,0x92650044,0x00000000}},	//   giap, _عليز, _وديم,
  { {0xd378007d,0xe1ff013d,0x80b20042,0x00000000}},	// [2b20] raće_, ziók_, _इंटे,
  { {0x3ce00f8c,0x8f761cdf,0x00000000,0x00000000}},	//   rsiv_, _гумі,   ,
  { {0x6d4d014f,0xeafa007e,0xddc4003b,0x00000000}},	//   ayaa, طرات_, chiş,
  { {0xeb970b0f,0xddcd000c,0x99dd0066,0x00000000}},	//   щих_, rnaţ, _poňa,
  { {0x2d840164,0x645a00fe,0xdd920049,0x00000000}},	//   _âme_, yhti, _روس_,
  { {0x98730085,0xa91d0078,0x99dd017c,0x00000000}},	//   пліц, _ryžt, _voňa,
  { {0xf743000a,0x39520006,0x6b6313c6,0x00000000}},	//   зејо, šys_, _екра,
  { {0xdb1c00c7,0xceb30063,0x6e241ce0,0x00000000}},	//   _berö, היה_, ndib,
  { {0xb05b00fe,0x645d001c,0x7d041ce1,0x00000000}},	//   späi, īsin, ntis,
  { {0x14b70032,0xb05b00fe,0x7bde1acc,0x00000000}},	//   حديث_, ppäi, napu,
  { {0x53980086,0x7e6d0150,0x9f45005b,0x00000000}},	//   рвня_, yiap, ülü_,
  { {0x7ae3006d,0x68e21ce2,0x9169008b,0x00000000}},	//   ánti, osod, _nữa_,
  { {0xc05b0086,0x60d6001f,0x68e21ce3,0x00000000}},	//   гів_, _cwym, nsod,
  { {0xd3ba0086,0xdb1c0014,0x7d0400e0,0x00000000}},	//   _суді_, _afrí, dtis,
  { {0x7e6d0089,0x91690013,0xe3b80058,0x00000000}},	//   tiap, _bữa_, ndım_,
  { {0x33770063,0x7d1d1ce4,0xdceb14cb,0x00000000}},	//   _לתוך_, _psss, žičk,
  { {0x60d6002b,0x7d04013d,0x68e200a8,0x00000000}},	// [2b30] _gwym, gtis, jsod,
  { {0x7e6d0397,0x7bde1ce5,0xb5fd1ce6,0x00000000}},	//   siap, gapu, riši,
  { {0x6d4d0089,0x68e2002b,0xd011005d,0x00000000}},	//   syaa, esod, _فلک_,
  { {0xb5fd02e2,0x7bde0072,0x02fb0047,0x00000000}},	//   piši, aapu, רלאמ,
  { {0xe9d80088,0x645802dd,0xab62005b,0x00000000}},	//   скі_, _olvi, _çünk,
  { {0x6829013d,0xe9d90022,0xa6c91ce7,0x00000000}},	//   ködő, _weź_, алка_,
  { {0xf7420062,0x07a2150f,0x70b50053,0x00000000}},	//   дещо, машн, ंदुल,
  { {0x245b03b2,0x79960051,0xdb1c001f,0x00000000}},	//   _même_, żywa, _ffrâ,
  { {0x69db001f,0xe1ff0758,0xe4590794,0x00000000}},	//   _ieue, ciói_, ижи_,
  { {0xdb1c00bd,0x130905ac,0x60d600a3,0x00000000}},	//   _verö, аной_, _rwym,
  { {0xe1ff0022,0x60d60022,0xd6390085,0x00000000}},	//   niów_, _swym, _вялі_,
  { {0x7de6000f,0xdb1c005b,0x7d041ce8,0x00000000}},	//   _késő, _terö, ytis,
  { {0x7bde1ce9,0x69db00cd,0x3eba00dd,0x00000000}},	//   yapu, _meue, _supt_,
  { {0x9f580164,0x68e40025,0x66090089,0x00000000}},	//   lgré_, áidi, lfek,
  { {0xe29a1cea,0xdb1c017d,0x75291ceb,0x00000000}},	//   _как_, _jerô, lvez,
  { {0x69db0199,0x7d040bcf,0x7529082a,0x00000000}},	//   _neue, ttis, ovez,
  { {0xe0d20032,0x7bde1cec,0x7659001f,0x00000000}},	// [2b40] _غزة_, tapu, _mlwy,
  { {0x76590185,0x7c96000d,0xe3b80058,0x00000000}},	//   _llwy, ірац, ydım_,
  { {0x3bd50076,0xda660086,0x20181ced,0x00000000}},	//   яютс, овжи, meri_,
  { {0x20181cee,0x7ff6007e,0x7ae3003b,0x00000000}},	//   leri_, _اسکا, ânta,
  { {0x7bde1acc,0x69db00cd,0xcaa50021,0x00000000}},	//   papu, _deue, أصلي,
  { {0xab2a1b76,0x752900ea,0x7659002b,0x00000000}},	//   _кога_, dvez, _alwy,
  { {0xf8bf02b0,0x7659001f,0x69db1cef,0x00000000}},	//   _één_, _blwy, _feue,
  { {0xe3b801f7,0x7659001f,0x7bdc1cf0,0x00000000}},	//   rdım_, _clwy, _heru,
  { {0x7bdc0397,0x2018005b,0xdb210072,0x00000000}},	//   _keru, keri_, ätös,
  { {0xb05b00fe,0xddc41cf1,0x20181cf2,0x00000000}},	//   npät, jniž, jeri_,
  { {0x76590185,0x7bdc014f,0xdb0500bd,0x00000000}},	//   _flwy, _meru, schö,
  { {0x644100e3,0x752908ea,0xbddb0164,0x00000000}},	//   ajli, bvez, _poèm,
  { {0x290600fe,0xe3b8005b,0xddcd004c,0x00000000}},	//   ntoa_, ndık_, chař,
  { {0x20180397,0x3a241cf3,0x6fd90022,0x00000000}},	//   geri_, _lamp_, dźcó,
  { {0xcddb018e,0x6abc0089,0xff04026c,0x00000000}},	//   иња_, _nurf, мятн,
  { {0x7bdc1423,0xb5fd0078,0x00000000,0x00000000}},	//   _aeru, sišv,   ,
  { {0x7bdc1b18,0x20181cf4,0x8cf5000d,0x00000000}},	// [2b50] _beru, beri_, язац,
  { {0x7bdc000c,0x2018000c,0x69db0295,0x00000000}},	//   _ceru, ceri_, _seue,
  { {0x2001162d,0x7bdc1cf5,0x29060072,0x00000000}},	//   _ichi_, _deru, etoa_,
  { {0x61fd1c2d,0x6abc05e4,0xd959000d,0x00000000}},	//   ngsl, _durf, йшлі_,
  { {0x61fd1cf6,0x3ea901a5,0x69db00cd,0x00000000}},	//   igsl, mmat_, _veue,
  { {0xd8220076,0x7bdc1466,0xb5fd00c2,0x00000000}},	//   едши, _geru, hišt,
  { {0x7bc50025,0xf6510021,0x7659002b,0x00000000}},	//   mchu, فئة_, _plwy,
  { {0xe9df0ac6,0x3a24001f,0xb5fd1cf7,0x00000000}},	//   _þú_, _gamp_, jišt,
  { {0xb5fd0743,0x2001000c,0x5a34000d,0x00000000}},	//   dišt, _ochi_, _ўнут,
  { {0x20010009,0x7529000f,0x3ea9003e,0x00000000}},	//   _nchi_, rvez, hmat_,
  { {0x7bc500bd,0x3ea90360,0x20181cf8,0x00000000}},	//   ichu, kmat_, veri_,
  { {0xb05b0024,0x7bc50025,0x61fd00d1,0x00000000}},	//   zpät, hchu, ggsl,
  { {0x3ea900e3,0x55ba0063,0x20181cf9,0x00000000}},	//   dmat_, _המנו, teri_,
  { {0x394000fe,0xd00a005e,0x9fc7005e,0x00000000}},	//   äisi_, љеве_, згра_,
  { {0x602f0006,0x200500cd,0x20181cfa,0x00000000}},	//   dėmė, òlia_, reri_,
  { {0x7bdc070e,0x20181cfb,0x75f60058,0x00000000}},	//   _seru, seri_, müzü,
  { {0x20181cfc,0x6abc13b7,0x0d9a000d,0x00000000}},	// [2b60] peri_, _surf, ствы_,
  { {0x7bc50025,0xee3f0066,0x3ea901a9,0x00000000}},	//   gchu, _chýb_, amat_,
  { {0x68f9006f,0xddc40051,0x6f0c003b,0x00000000}},	//   euwd, oniż, încă,
  { {0x290600fe,0x82d60047,0x7bc50022,0x00000000}},	//   ttoa_, פונג_, achu,
  { {0x7bdc1cfd,0xb05b0072,0x7ae504aa,0x00000000}},	//   _teru, mpär, asht,
  { {0x6e2600bb,0x290600fe,0x7c5a0021,0x00000000}},	//   _hakb, rtoa_, _السر_,
  { {0x2906024a,0xc66a0076,0xdb830699,0x00000000}},	//   stoa_, йшие_, _згри,
  { {0x6e260051,0xb866007e,0xe6630086,0x00000000}},	//   _jakb, _کارو, етьо,
  { {0xb5fd1cfe,0xa7b60092,0xc7b8008d,0x00000000}},	//   eišs, _есеј, _tgđ_,
  { {0x6e261cff,0x22490168,0x29130043,0x00000000}},	//   _lakb, _soak_, _سومآ,
  { {0xb5fd1aa5,0xe9ff0013,0x68ec005f,0x00000000}},	//   tišt, _hoạn_, žodį,
  { {0x6e260089,0x76bb0063,0x22440044,0x00000000}},	//   _nakb, _המאפ, ّنَّ,
  { {0xb5fd0117,0x61fd1d00,0x32191d01,0x00000000}},	//   rišt, rgsl, resy_,
  { {0xb97b009a,0xa2ca04ef,0xf044014b,0x00000000}},	//   מרכז, _луиз_, нэсо,
  { {0xb5fd0080,0x9f340086,0xe9ff008b,0x00000000}},	//   pišt, нері, _loạn_,
  { {0x644a0917,0x5f940690,0x7bc5002b,0x00000000}},	//   _hofi, хист, wchu,
  { {0x628f0024,0x3ea91d02,0x200e005f,0x00000000}},	// [2b70] moco, rmat_, _ūkių_,
  { {0x7bc51d03,0xe1ff006d,0x628f1d04,0x00000000}},	//   uchu, lgó_, loco,
  { {0xe7a5001c,0x7bc51d05,0x7b6710f6,0x00000000}},	//   ādīš, rchu, чтае,
  { {0xe1ff1d06,0x7bc51d07,0x68ed00ea,0x00000000}},	//   ciót_, schu, áado,
  { {0xa954019d,0xddd6017c,0x08c40054,0x00000000}},	//   нкці, dkyň, ебін,
  { {0xf770006a,0x60cd0035,0x644a001f,0x00000000}},	//   گاه_, _mtam, _nofi,
  { {0xab950086,0xe1ff056d,0x572400f2,0x00000000}},	//   _циві, niós_, فريق,
  { {0x60cd00fe,0x2a7f07b7,0xb882013d,0x00000000}},	//   _otam, _ujub_, áírj,
  { {0x68e40027,0xad9b0066,0x644a1d08,0x00000000}},	//   áidt, _zbúr, _bofi,
  { {0x61ed1d09,0x644a0185,0x43750002,0x00000000}},	//   _adal, _cofi, думт,
  { {0x58840088,0x60cd005b,0x628700c2,0x00000000}},	//   _чыта, _atam, čkon,
  { {0xd7f8003b,0x442b0022,0xb5fd017c,0x00000000}},	//   _umăr_, śc_, rišs,
  { {0x98a4000c,0x61ed001f,0x2bfe0053,0x00000000}},	//   _urmă_, _ddal, _लालू_,
  { {0x644a001f,0x7c270f6a,0x661b1d0a,0x00000000}},	//   _gofi, _najr, leuk,
  { {0x92e80032,0xe1ff00cd,0xcec40080,0x00000000}},	//   _فريق_, giós_, daří_,
  { {0x44271d0b,0x644a1d0c,0xf1bf0260,0x00000000}},	//   _han_, _zofi, ndál_,
  { {0xfce30055,0x44271d0d,0x6e26006f,0x00000000}},	// [2b80] кото, _kan_, _vakb,
  { {0xb05b0019,0x61ed1959,0x2ca70782,0x00000000}},	//   spär, _zdal, дкуп_,
  { {0x661b00fe,0x6e261d0e,0xe9ff008b,0x00000000}},	//   keuk, _takb, _soạn_,
  { {0xe1ff0051,0x9208001c,0x44271d0f,0x00000000}},	//   chód_, _frāž, _lan_,
  { {0x44271d10,0xddc40078,0x09e31d11,0x00000000}},	//   _oan_, snių, точн,
  { {0x7afa0137,0xd943005e,0x44271d12,0x00000000}},	//   _åtto, тељи, _nan_,
  { {0x644a1d13,0xe73702f8,0xc7b00044,0x00000000}},	//   _rofi, деј_, دّث_,
  { {0x4427182f,0x68e40139,0x764b002b,0x00000000}},	//   _aan_, áids, _cogy,
  { {0xd7cf0053,0x628f00ed,0xc6a30062,0x00000000}},	//   _स्वच, voco, ърши,
  { {0x442703ae,0xddd60066,0x628f0022,0x00000000}},	//   _can_, skyň, woco,
  { {0x4427014f,0x68e91d14,0x60cd1d15,0x00000000}},	//   _dan_, _zved, _stam,
  { {0x92580076,0x44270025,0xc7b8007d,0x00000000}},	//   дают_, _ean_, _nađi_,
  { {0xe1ff1919,0x628f1d16,0x84460021,0x00000000}},	//   rgó_, roco, _يختل,
  { {0xa3df0161,0x628f1d17,0x44271d18,0x00000000}},	//   तरण_, soco, _gan_,
  { {0x764b00f3,0x626b0080,0xe580008f,0x00000000}},	//   _yogy, dřov, šķā_,
  { {0xe1ff00cd,0x2cb80025,0x61ed1d19,0x00000000}},	//   riós_, _aird_, _udal,
  { {0xce94005a,0x60cd1d1a,0x2cb81d1b,0x00000000}},	// [2b90] татъ, _utam, _bird_,
  { {0x69c9006f,0x8235007e,0x2299013d,0x00000000}},	//   _sfee, _آرژا, déki_,
  { {0x649400cd,0x68e91d1c,0xe945005d,0x00000000}},	//   làis, _sved, کرای,
  { {0xdb0e00ea,0xdd91007e,0xddcd0022,0x00000000}},	//   áján, _موج_, skał,
  { {0xcce70032,0xe6ed0024,0x661b0130,0x00000000}},	//   _تسجي, _väčš, veuk,
  { {0xa1580063,0x07a505f9,0xc7a50e82,0x00000000}},	//   ובדה_, налн, нилк,
  { {0x44271d1d,0x3eb900ca,0xf773014d,0x00000000}},	//   _ran_, _kist_, خاش_,
  { {0x1995000d,0x44271d1e,0x2d990072,0x00000000}},	//   _забя, _san_, _kyse_,
  { {0xe5790076,0x68e90114,0x44271d1f,0x00000000}},	//   язи_, _uved, _pan_,
  { {0x3eb91d20,0xe3b1005d,0x9cd6009a,0x00000000}},	//   _list_, ُرد_, עותה_,
  { {0x44271d21,0x8707007e,0xe29a1d22,0x00000000}},	//   _van_, _زبال, зан_,
  { {0x44271d23,0x3eb91d24,0x2378013d,0x00000000}},	//   _wan_, _nist_, úrja_,
  { {0xdb1c00c7,0xc19a0054,0x44271d25,0x00000000}},	//   _ifrå, ятої_, _tan_,
  { {0x442701a8,0x32040022,0x76460050,0x00000000}},	//   _uan_, żmy_, ökyv,
  { {0x3eb900bd,0x322900fe,0x68ed00ea,0x00000000}},	//   _bist_, ötyä_, áadj,
  { {0xf7720041,0x3eb91d26,0x6cd60044,0x00000000}},	//   אקל_, _cist_, فقرا,
  { {0x626b0080,0x3eb91276,0x63a60022,0x00000000}},	// [2ba0] třov, _dist_, ękne,
  { {0x3eb9006f,0x4f261d27,0xf2e6005d,0x00000000}},	//   _eist_, _здоб, _تکیه_,
  { {0xb346017d,0x20c60013,0x5fdb0063,0x00000000}},	//   maçõ, _hôi_, _מחיק,
  { {0x2cb80cd4,0xb3460016,0x88e60ac5,0x00000000}},	//   _wird_, laçõ, ежде,
  { {0xa3df0053,0x92690041,0x626b011b,0x00000000}},	//   तरा_, ובאַ_, přov,
  { {0xeee7006a,0xb3460016,0x20c6008b,0x00000000}},	//   _تغیی, naçõ, _môi_,
  { {0x20c6008b,0x8ba30121,0x44dd0066,0x00000000}},	//   _lôi_, _бирж, eň_,
  { {0x963400fb,0x3546080a,0x95ca1d28,0x00000000}},	//   тниц, ехов, чука_,
  { {0xd4060086,0xddcd003b,0x61e61d29,0x00000000}},	//   няни, liaţ, dakl,
  { {0x545406cb,0x6287007d,0xdbdf0014,0x00000000}},	//   твот, čkom, níði,
  { {0xb346017d,0xddcd003b,0xd7060054,0x00000000}},	//   daçõ, niaţ, _їзди,
  { {0x20c60013,0xa75b0063,0x78ba013d,0x00000000}},	//   _bôi_, _מדבר, _hitv,
  { {0xf1bf00ea,0x20c60013,0x3eb91d2a,0x00000000}},	//   ldák_, _côi_, _rist_,
  { {0xb3460016,0x3eb902f0,0x20051d2b,0x00000000}},	//   gaçõ, _sist_, üli_,
  { {0x61e61d2c,0x61f40137,0x78ba1d2d,0x00000000}},	//   bakl, ådlö, _mitv,
  { {0x61e6005b,0xddcd000c,0x645a00ca,0x00000000}},	//   cakl, diaţ, lkti,
  { {0x442c0185,0x3eb902ab,0x200c00cd,0x00000000}},	// [2bb0] odd_, _vist_, òdic_,
  { {0xb3460016,0x3eb90122,0x2bbb0021,0x00000000}},	//   caçõ, _wist_, ساطة_,
  { {0x2d9900e8,0x442c1b33,0x645a1d2e,0x00000000}},	//   _wyse_, idd_, ikti,
  { {0x7d09003b,0x7e641d2f,0x78ba005f,0x00000000}},	//   _ţesu, chip, _aitv,
  { {0x6e3d00bd,0x88c80086,0x7afe1d30,0x00000000}},	//   _insb, елів_, aupt,
  { {0xa3bc0053,0x645a006f,0x61e61d31,0x00000000}},	//   _अलग_, jkti, zakl,
  { {0xddcd000c,0x7d0d1d32,0x442c1d33,0x00000000}},	//   ciaţ, ltas, ddd_,
  { {0x442c0185,0xb3460016,0x7f3c0047,0x00000000}},	//   edd_, zaçõ, לעוו,
  { {0x0568000a,0x2c6400c7,0xc4850156,0x00000000}},	//   ејќи_, _född_, клик,
  { {0xcdaa0047,0x69d9004d,0xb34600be,0x00000000}},	//   ויפֿ, lbwe, xaçõ,
  { {0xd5d2016a,0xb3460016,0xb9040053,0x00000000}},	//   _ध्वज, vaçõ, भी_,
  { {0x27e70027,0x45d50612,0x442c1d34,0x00000000}},	//   lann_, _родс, add_,
  { {0xb3460016,0x69d900bd,0x320c0051,0x00000000}},	//   taçõ, ibwe, ędy_,
  { {0x7d0d010a,0x27e70027,0xdfd20021,0x00000000}},	//   dtas, nann_, شير_,
  { {0xb34603d9,0x24960021,0x5f060062,0x00000000}},	//   raçõ, _جنود_, ъзва,
  { {0x20c600aa,0xb3460016,0xdbc90019,0x00000000}},	//   _tôi_, saçõ, _mõõd,
  { {0xb346017d,0x27e70026,0x7d0d1d35,0x00000000}},	// [2bc0] paçõ, kann_, gtas,
  { {0x61e41d36,0x7e641d37,0xbc63000d,0x00000000}},	//   _heil, ship, авук,
  { {0xe3b8005b,0xbddb02a7,0x09e617e1,0x00000000}},	//   ldır_, _poèt, воен,
  { {0xddcd000c,0x60c40035,0x27e70025,0x00000000}},	//   riaţ, _kuim, eann_,
  { {0x442c0c70,0xe3b8005b,0x27e70137,0x00000000}},	//   ydd_, ndır_, fann_,
  { {0x27e71d38,0xddcd000c,0xcee9007e,0x00000000}},	//   gann_, piaţ, _ترین_,
  { {0x60c40025,0xa7fc005b,0x9183008b,0x00000000}},	//   _luim, _alıc, iếp_,
  { {0xdb1c0027,0x442c0185,0x61e41d39,0x00000000}},	//   _ngré, wdd_, _neil,
  { {0x60c40006,0x629d00b9,0x09060d34,0x00000000}},	//   _nuim, vlso, _шпан,
  { {0x78ba0102,0x27e70025,0xdb1c0164,0x00000000}},	//   _uitv, cann_, _agré,
  { {0x442c0185,0xa2b5005a,0x7d0d00ea,0x00000000}},	//   rdd_, лбоч, ztas,
  { {0xd378017f,0x442a00c2,0x645a00a4,0x00000000}},	//   naći_, žb_, skti,
  { {0x60c40025,0x83f80002,0x25a00139,0x00000000}},	//   _cuim, _зелс_, _áil_,
  { {0x2bfe0161,0x60c40104,0x3946021a,0x00000000}},	//   _लागू_, _duim, ixos_,
  { {0x61e41d3a,0x200c01a8,0x260f0042,0x00000000}},	//   _feil, òdia_, थ्वी_,
  { {0x7d0d1d3b,0x60c4006d,0x68ed007d,0x00000000}},	//   ttas, _fuim, šadi,
  { {0x6e2d1d3c,0x60c41510,0xf1c40061,0x00000000}},	// [2bd0] rdab, _guim, ášť_,
  { {0x7d0d1d3d,0x61e405e4,0x3f840058,0x00000000}},	//   rtas, _zeil, ğmur_,
  { {0xddc60051,0xda35000d,0x27e7129e,0x00000000}},	//   _dokł, лежы, vann_,
  { {0x27e700bd,0xc7ce0013,0x7d0d1d3e,0x00000000}},	//   wann_, uống_, ptas,
  { {0xe9d80088,0xee3f0024,0xf1bf0139,0x00000000}},	//   ткі_, _iný_, meád_,
  { {0x27e70025,0xd70905f4,0x66e5030b,0x00000000}},	//   uann_, енке_, гока,
  { {0xe3b8005b,0x27e71d3f,0x6aa91d40,0x00000000}},	//   zdır_, rann_, _thef,
  { {0xddcd003d,0xe3b8005b,0x68f60078,0x00000000}},	//   skaņ, ydır_, šyda,
  { {0x27e70026,0x61e41d41,0x765b0058,0x00000000}},	//   pann_, _reil, rkuy,
  { {0x60c40173,0x61e41d42,0x656900bd,0x00000000}},	//   _ruim, _seil, rzeh,
  { {0x656900ea,0x60c41d43,0x87040154,0x00000000}},	//   szeh, _suim, _вяче,
  { {0xa75a0041,0x216a030b,0x52860044,0x00000000}},	//   _אדער, еими_, الحك,
  { {0x4a5a0063,0x61e41d44,0x60c40955,0x00000000}},	//   גדרו, _veil, _quim,
  { {0xe3b801f7,0x26c500ac,0x61e41d45,0x00000000}},	//   rdır_, _kulo_, _weil,
  { {0x61e41d46,0x99750051,0xc29a0121,0x00000000}},	//   _teil, nęło_, _птиц_,
  { {0xa2060f9f,0x7afa08a9,0x60c41d47,0x00000000}},	//   _спид, _åtti, _tuim,
  { {0x0eb90475,0x66c7005b,0x4c861939,0x00000000}},	// [2be0] туры_, _sıkl, глав,
  { {0xdde3008f,0x91bb009a,0x5d1300de,0x00000000}},	//   ārša, _אמפי, إِلا,
  { {0x26c500f8,0xfaa61d48,0x99750022,0x00000000}},	//   _nulo_, гажо, jęło_,
  { {0x3ce80235,0x2cb00006,0x394600cd,0x00000000}},	//   _चौथे_, _žodį_, txos_,
  { {0xf9920021,0x127b0047,0xed570591,0x00000000}},	//   حبا_, עאנע, _боя_,
  { {0x66c704ab,0x3ea01d49,0xa9280124,0x00000000}},	//   _tıkl, llit_, južš,
  { {0xcb6a0699,0x3c630505,0x3ea01d4a,0x00000000}},	//   _џабе_, _укрг, olit_,
  { {0x7c2e1d4b,0x26c500a4,0x44f4137a,0x00000000}},	//   _habr, _dulo_, апис,
  { {0x3e7f00fe,0x5e570047,0xca75000d,0x00000000}},	//   lätä_, טיקע_, _туры,
  { {0x2452000c,0xd91b0047,0x38a90066,0x00000000}},	//   _câmp_, _אומל, túre_,
  { {0x68ed00ea,0x7c2e1d4c,0x26c51d4d,0x00000000}},	//   áadv, _mabr, _gulo_,
  { {0x21b5019d,0x0bb70063,0x7c2e1d4e,0x00000000}},	//   ийня, טלים_, _labr,
  { {0x667b0047,0x463b0047,0xe6930044,0x00000000}},	//   _אטאק, _רעדע, _الند,
  { {0x3e670019,0x3e7f0072,0xe1ff0331,0x00000000}},	//   _mõte_, kätä_, chón_,
  { {0xdb1c001f,0x316b0051,0x2327005e,0x00000000}},	//   _sgrî, szcz_, _боји_,
  { {0x442e001f,0x3ea019fb,0xddcd0562,0x00000000}},	//   _haf_, glit_, snaž,
  { {0x3cee0161,0x9f430080,0x2129053b,0x00000000}},	// [2bf0] ेंगे_, mají_, _usah_,
  { {0x9f430080,0x8c440001,0x93bc003b,0x00000000}},	//   lají_, беђе, bdăt,
  { {0xbb840021,0x3ea01d4f,0x2cb4004c,0x00000000}},	//   ملكي, blit_, _řadí_,
  { {0x9f430080,0xe37b0041,0x3ea01d50,0x00000000}},	//   nají_, עראר, clit_,
  { {0x7c2e1d51,0xd7c9005d,0xd3780130,0x00000000}},	//   _fabr, نوشه_, maću_,
  { {0x9f430080,0x26c51d52,0x5c790041,0x00000000}},	//   hají_, _pulo_, _יאָה,
  { {0x36690dd5,0x9f430080,0x1866005a,0x00000000}},	//   како_, kají_, ращи_,
  { {0xbb840032,0x7ae3000c,0x7c2e073e,0x00000000}},	//   _الفي, ântu, _zabr,
  { {0x9f430080,0xa4d6005e,0x49750062,0x00000000}},	//   dají_, адњу_, _тлас,
  { {0x99540001,0x26c50072,0x442e1d53,0x00000000}},	//   _укуц, _tulo_, _caf_,
  { {0x53a5000a,0x52aa005e,0x3ea00072,0x00000000}},	//   ранб, квом_, ylit_,
  { {0xcb120063,0x67b80593,0x2c6400a5,0x00000000}},	//   חלט_, _صالح_, _möda_,
  { {0x41030062,0xd378007d,0xb5fd0023,0x00000000}},	//   озяв, daću_, ekšg,
  { {0x05a80086,0x442e1d54,0xad9b0025,0x00000000}},	//   _свій_, _gaf_, _gcúi,
  { {0x9e76005e,0x3f9e0014,0xdee60b4c,0x00000000}},	//   аћај, ætu_, роби,
  { {0xdbdf007a,0x6e2f0013,0x7c2e1d55,0x00000000}},	//   _síðu, _cacb, _sabr,

  { {0x3ea0007a,0x7c2e1d56,0xac0a0002,0x00000000}},	// [2c00] rlit_, _pabr, кнаа_,
  { {0xa7fc01f7,0x62860066,0x6446008d,0x00000000}},	//   _alın, lnko, êkix,
  { {0x3ea01d57,0x62870ea3,0xf1a9005d,0x00000000}},	//   plit_, čkov, _لایه_,
  { {0x2c6400c7,0x3e7f00fe,0x2d870058,0x00000000}},	//   _döda_, rätä_, ğner_,
  { {0x3e7f024a,0x93bc000c,0x67d40002,0x00000000}},	//   sätä_, ndăr, болу,
  { {0x2c640137,0x7d041d58,0x6e241d59,0x00000000}},	//   _föda_, muis, leib,
  { {0x7d04119d,0x8c1b0063,0xe0b70063,0x00000000}},	//   luis, _שולי, בלסט_,
  { {0x95d7005a,0x442e1d5a,0x9856056c,0x00000000}},	//   адът_, _saf_, dłą_,
  { {0x9f430080,0x78b10026,0x7d041d5b,0x00000000}},	//   vají_, ákvæ, nuis,
  { {0xb806006a,0xb7960001,0x6e2400bd,0x00000000}},	//   _خبره, _крећ, heib,
  { {0x9f430080,0x7d041d5c,0x43941d5d,0x00000000}},	//   tají_, huis, санс,
  { {0x628605dd,0x7d041d5e,0x38a90046,0x00000000}},	//   gnko, kuis, múra_,
  { {0x7d041c71,0x61f6001f,0x4fc700a0,0x00000000}},	//   juis, _ddyl, исва,
  { {0x7d041d5f,0xdb1c00c5,0x0377005d,0x00000000}},	//   duis, _agrí, احیت_,
  { {0xf0b40086,0x6aa20014,0x1df9066e,0x00000000}},	//   ійсь, klof, левы_,
  { {0x2c6400c7,0xdce6005b,0xcdd8005e,0x00000000}},	//   _röda_, _aykı, ињу_,
  { {0xebc70001,0xd904007e,0xa2ca0053,0x00000000}},	// [2c10] аљен, _تی_, _सूत्,
  { {0x38a90066,0x8bd80cb7,0x2292011b,0x00000000}},	//   kúra_, имус_, dáky_,
  { {0xeb090021,0x7d040072,0xca150062,0x00000000}},	//   اقصى_, auis, йджъ,
  { {0xe8f50032,0x7d041d60,0x6f0100cd,0x00000000}},	//   مستخ, buis, àlcu,
  { {0x3cfe0053,0xb9270edb,0x7afe1d61,0x00000000}},	//   _लिये_, рфей, arpt,
  { {0xf1bf013d,0x5c040085,0x26d9011b,0x00000000}},	//   ldás_, _мяса, _čsob_,
  { {0xe7080021,0x62860022,0xe73914db,0x00000000}},	//   لتين_, ynko, уей_,
  { {0x7c251d62,0xcb120063,0xf1bf013d,0x00000000}},	//   lehr, _מלל_, ndás_,
  { {0xd842004c,0x95550044,0xaa5801ce,0x00000000}},	//   áčí_, إخبا, _титу_,
  { {0xb4650055,0x6e24004d,0x04491224,0x00000000}},	//   скол, zeib, упок_,
  { {0x36d40054,0x8c1a0063,0x60d61d63,0x00000000}},	//   _дохр, אותי, _stym,
  { {0x99800024,0x62861d64,0xca7a0041,0x00000000}},	//   žiť_, unko, ָנשט,
  { {0x7c2500bd,0xf6520063,0x62861d65,0x00000000}},	//   kehr, _מצא_, rnko,
  { {0x7d0400fe,0x75360047,0x200c0019,0x00000000}},	//   vuis, _לאנד_, üdi_,
  { {0x64430c35,0x78a3001c,0x44250d03,0x00000000}},	//   _inni, ilnv, mel_,
  { {0x66090d36,0x7d041d66,0x22f60aeb,0x00000000}},	//   ngek, tuis, _הזקן_,
  { {0x75290122,0x6e241a6c,0x628700c2,0x00000000}},	// [2c20] nwez, reib, čkot,
  { {0x7c25004d,0x7d041d67,0x8b26000d,0x00000000}},	//   gehr, ruis, йдзе,
  { {0x291f00fe,0x2018061f,0x44250296,0x00000000}},	//   _apua_, mfri_, iel_,
  { {0xa2ca0161,0x201800c7,0x44251d68,0x00000000}},	//   _संस्, lfri_, hel_,
  { {0x6443024a,0x66090173,0x44251d69,0x00000000}},	//   _onni, dgek, kel_,
  { {0xd90d007e,0x38a918a8,0x44251d6a,0x00000000}},	//   ئیل_, túra_, jel_,
  { {0xfaa6000d,0xf1bf1d6b,0xbad5000d,0x00000000}},	//   _гаво, ndár_, _міты,
  { {0x44250276,0x64431926,0x66091d6c,0x00000000}},	//   eel_, _anni, ggek,
  { {0xc966000d,0x89661d6d,0x96b7005e,0x00000000}},	//   _увай, _укаж, љују_,
  { {0xe8d70063,0x442502ce,0x68f3004c,0x00000000}},	//   _לומר_, gel_, ředí,
  { {0xd3d70021,0xd7960044,0xf7430f0a,0x00000000}},	//   حبًا_, _الضخ, _нефо,
  { {0x44250185,0x46690086,0x64430c78,0x00000000}},	//   ael_, _крім_, _enni,
  { {0x44251d6e,0xf4d70044,0x00000000,0x00000000}},	//   bel_, _هونغ_,   ,
  { {0x27ee0026,0x2018000e,0x2fc506a5,0x00000000}},	//   nafn_, gfri_, ølg_,
  { {0x447b0063,0xd6f80063,0x7e85005f,0x00000000}},	//   _תנוע, יִּש, lėpi,
  { {0x7c2500bd,0x63be004c,0x62871a77,0x00000000}},	//   wehr, ězně, čkos,
  { {0xdc550138,0x463b0047,0xdb1c00cd,0x00000000}},	// [2c30] овањ, נעמע, _agrà,
  { {0x61ef1d6f,0xba3d004c,0xddc6011b,0x00000000}},	//   lacl, _lhůt, _mokř,
  { {0x212b0185,0xf09f00cd,0x50d4007e,0x00000000}},	//   lwch_, stàs_, _وزیر,
  { {0x44251d70,0x7c251d71,0x61ef1d72,0x00000000}},	//   zel_, sehr, nacl,
  { {0x212b0185,0xa2bc0047,0x44250779,0x00000000}},	//   nwch_, אמאט, yel_,
  { {0x27ee002b,0x44251d73,0x212b002b,0x00000000}},	//   gafn_, xel_, iwch_,
  { {0x212b001f,0x66090229,0xb8d00053,0x00000000}},	//   hwch_, tgek, _टी_,
  { {0x44251d74,0xe9df0066,0x7e6d1d75,0x00000000}},	//   wel_, _ýú_, nhap,
  { {0x200a001f,0x66091d76,0x2018002b,0x00000000}},	//   ygbi_, rgek, yfri_,
  { {0x212b0185,0x75290122,0x44251d77,0x00000000}},	//   dwch_, rwez, uel_,
  { {0x224a000a,0x212b001f,0x44251d78,0x00000000}},	//   апни_, ewch_, rel_,
  { {0x44251d79,0x212b002b,0xd6ab0067,0x00000000}},	//   sel_, fwch_, _صدام_,
  { {0x212b0185,0xa4f7007e,0x44251d7a,0x00000000}},	//   gwch_, _اکبر_, pel_,
  { {0x64430026,0xd00a005e,0x316c0022,0x00000000}},	//   _unni, јеве_, ądz_,
  { {0x1fb511ec,0x7e56148f,0xe81b0042,0x00000000}},	//   зстр, отац, प्या_,
  { {0x212b001f,0x7e6d1d7b,0x201800df,0x00000000}},	//   bwch_, ghap, sfri_,
  { {0x63a30185,0xf1bf0025,0x212b002b,0x00000000}},	// [2c40] _hynn, leán_, cwch_,
  { {0x63a3007a,0xe80e016a,0x0c230076,0x00000000}},	//   _kynn, _साधा_, ммун,
  { {0x49ca1d7c,0xd1380051,0xddc4003b,0x00000000}},	//   ален_, łąd_, ghiţ,
  { {0x09e3000a,0x7e6d1d7d,0x63a30cc7,0x00000000}},	//   доцн, chap, _mynn,
  { {0xb5fd0066,0x63a3119a,0xe80e0042,0x00000000}},	//   chši, _lynn, _सादा_,
  { {0x6e360006,0x786f00b9,0x7e641d7e,0x00000000}},	//   ldyb, _løvf, lkip,
  { {0x7e640050,0x466a0816,0xc053009a,0x00000000}},	//   okip, ирим_, וזג_,
  { {0xf1bf0025,0x27ee0026,0xddc4003b,0x00000000}},	//   deán_, safn_, chiţ,
  { {0xceb30132,0x7e641d7f,0x7d161d80,0x00000000}},	//   ויה_, ikip, ntys,
  { {0x63a3001f,0xc8660021,0x7d161d81,0x00000000}},	//   _bynn, _بطري, itys,
  { {0x63a30185,0xe3b8005b,0x7e640072,0x00000000}},	//   _cynn, ldız_, kkip,
  { {0x212b001f,0x63a3001f,0x63b5004a,0x00000000}},	//   twch_, _dynn, ýzna,
  { {0x61ef0120,0x26cc1d82,0x212b002b,0x00000000}},	//   racl, _hudo_, uwch_,
  { {0x212b0185,0x63a3002b,0x74130049,0x00000000}},	//   rwch_, _fynn, _يونا,
  { {0x63a30185,0x212b0185,0x9f340086,0x00000000}},	//   _gynn, swch_, мері,
  { {0x97570063,0x60dd0137,0xa19501dd,0x00000000}},	//   חילו_, ppsm, _найч,
  { {0x7e6d1d83,0x26cc1d84,0x64581d85,0x00000000}},	// [2c50] rhap, _ludo_, _kovi,
  { {0x61ed1d86,0x2ba70001,0x7e641040,0x00000000}},	//   _heal, ојев, akip,
  { {0xf42900fe,0x26cc1059,0x60cd0331,0x00000000}},	//   lmää_, _nudo_, _huam,
  { {0x61ed0034,0x60cd0035,0x3ae7001f,0x00000000}},	//   _jeal, _kuam, rŵp_,
  { {0x6d4b0137,0x61ed1a74,0xd92b0062,0x00000000}},	//   ågad, _meal, рцел_,
  { {0x64581d87,0x61ed1d88,0x629d1d89,0x00000000}},	//   _novi, _leal, hoso,
  { {0xb5fd001c,0x915e008b,0xf42900fe,0x00000000}},	//   ekša, oặc_, hmää_,
  { {0xdb1c00ea,0x26cc0331,0x61ed1d8a,0x00000000}},	//   _ugrá, _dudo_, _neal,
  { {0x6560001f,0x629d1d8b,0x45850121,0x00000000}},	//   gymh, doso, ягив,
  { {0xf1bf0025,0x13090121,0x73050121,0x00000000}},	//   teán_, бной_, ппоз,
  { {0x61ed0025,0x07080021,0xdb1c01e1,0x00000000}},	//   _beal, _ويكي_, _egræ,
  { {0x61ed0027,0xf1bf0027,0x7d161d8c,0x00000000}},	//   _ceal, reán_, ytys,
  { {0xf1bf0025,0x61ed1d8d,0xf8cb0053,0x00000000}},	//   seán_, _deal, ादिय,
  { {0x653a00b5,0x7c350222,0x63a31d8e,0x00000000}},	//   _לענד, _nazr, _tynn,
  { {0x61ed0d12,0xdfcf014d,0x2aae0066,0x00000000}},	//   _feal, ايف_, hýba_,
  { {0xee3a0001,0x69c900ac,0x6446001c,0x00000000}},	//   љна_, _ngee, ēkie,
  { {0xf1bf0027,0x7e641d8f,0x60cd028b,0x00000000}},	// [2c60] neál_, rkip, _guam,
  { {0x7e641d90,0x61ed1d91,0x6e3604aa,0x00000000}},	//   skip, _zeal, sdyb,
  { {0xe8050235,0x8b260086,0x6d4b00c7,0x00000000}},	//   _राजा_, ядже, ägar,
  { {0x76590045,0x0ae90021,0x2bbd0042,0x00000000}},	//   _nowy, تركي_, ्ख़ा,
  { {0x63a60022,0x28f80085,0x9056009a,0x00000000}},	//   ękni, цель_, ּסֶף_,
  { {0x26cc02dd,0x68e9002b,0x28f70121,0x00000000}},	//   _pudo_, _dwed, чешь_,
  { {0xe1ff0051,0x629d0c55,0x75221cca,0x00000000}},	//   chów_, yoso, _spoz,
  { {0xfaa3019d,0x7d041d92,0x60db003b,0x00000000}},	//   _засо, oris, ţumi,
  { {0x68e9001f,0x61ed1d93,0xb5fd008f,0x00000000}},	//   _gwed, _real, ukša,
  { {0x26cc03d9,0xb21b00b9,0x7d041d94,0x00000000}},	//   _tudo_, nnæv, iris,
  { {0x61ed0004,0x60cd053b,0xe61a0675,0x00000000}},	//   _peal, _suam, _где_,
  { {0xd377000d,0x7d041d95,0xe707005d,0x00000000}},	//   ячы_, kris, _رسمی,
  { {0xe5340076,0xf1bf0025,0x104b0062,0x00000000}},	//   _цель, ceál_, бяви_,
  { {0x61ed0034,0x61e001f7,0x629d00fe,0x00000000}},	//   _weal, ımla, soso,
  { {0x7c3502e2,0xf42900fe,0x60c5004b,0x00000000}},	//   _razr, smää_, _vihm,
  { {0xe0df0290,0x7d041d96,0x7c35007d,0x00000000}},	//   ppò_, fris, _sazr,
  { {0x22490024,0xaffd0086,0x81fc0063,0x00000000}},	// [2c70] _inak_, _копi, _ההחז,
  { {0xdfd10021,0xfbd00044,0x00000000,0x00000000}},	//   _جيد_, هتم_,   ,
  { {0xde590086,0xaac703eb,0x7d041d97,0x00000000}},	//   _дані_, ستان, aris,
  { {0x7d180027,0x68e9002c,0x7d041d98,0x00000000}},	//   éasá, _pwed, bris,
  { {0x3ea90137,0x7d040a54,0x786f01f2,0x00000000}},	//   mlat_, cris, _løve,
  { {0xc7a50086,0x01380063,0x3ea91d99,0x00000000}},	//   милк, פרות_, llat_,
  { {0x3ea91d9a,0x76591d9b,0xdce40022,0x00000000}},	//   olat_, _powy, dzię,
  { {0xd877006a,0x645c01e3,0xb5fd00c3,0x00000000}},	//   _کارب, örin, akšn,
  { {0xdb1c0137,0x68e900a4,0x3ea90089,0x00000000}},	//   _egrä, _uwed, ilat_,
  { {0x22490397,0x3ea90072,0x9f410072,0x00000000}},	//   _anak_, hlat_, _kehä_,
  { {0x3ea91d9c,0xa22a1d9d,0xe76b01ce,0x00000000}},	//   klat_, ожна_, _ујак_,
  { {0x38b2003b,0x0394000d,0x1dbf0053,0x00000000}},	//   râre_, эрыя, ्शात,
  { {0x66c70058,0xb148005d,0x3ea91d9e,0x00000000}},	//   _fıkr, سیدم_, dlat_,
  { {0x63850138,0x22491d9f,0x3ea90137,0x00000000}},	//   _огла, _enak_, elat_,
  { {0xe29f007a,0x75450051,0xd335000d,0x00000000}},	//   boð_, łrzę, _цэлы,
  { {0x3ea91da0,0x0eaa000d,0xecea1406,0x00000000}},	//   glat_, ікай_, ждал_,
  { {0x32d3001b,0xb21b00b9,0xd12f007e,0x00000000}},	// [2c80] _hãy_, tnæv, _نمي_,
  { {0x7d041da1,0x25a2004b,0x22490938,0x00000000}},	//   rris, ükli_, _znak_,
  { {0x3ea91da2,0x7d041da3,0xbad6014b,0x00000000}},	//   blat_, sris, фізы,
  { {0x3ea90268,0x7d040399,0xb21b00b9,0x00000000}},	//   clat_, pris, snæv,
  { {0x20d4065c,0xaac5007e,0xbdfb007e,0x00000000}},	//   _jäi_, رتمن, _برپا_,
  { {0x3ea01da4,0xd6da1da5,0xe8940085,0x00000000}},	//   loit_, оти_, эаль,
  { {0xf7930088,0x3ea00983,0x45d4030b,0x00000000}},	//   кашэ, ooit_, нойс,
  { {0xa3c30053,0xdb1c0137,0x786f01f2,0x00000000}},	//   ्शन_, _vgrä, _røve,
  { {0x20d4004e,0x64c80042,0xd406030b,0x00000000}},	//   _näi_, रदेश, мяни,
  { {0x224900b9,0xc3540002,0x61e6069f,0x00000000}},	//   _snak_, екој, ebkl,
  { {0xd37a0685,0xe29f0014,0x3ea91da6,0x00000000}},	//   ючи_, toð_, ylat_,
  { {0x32d3008b,0x5725007e,0x68e21da7,0x00000000}},	//   _dãy_, _سرمق, opod,
  { {0xf1ab007e,0xa2ca0053,0xddcd0066,0x00000000}},	//   تاده_, _संक्, tiaž,
  { {0x9f430024,0x104b0086,0x786f00b9,0x00000000}},	//   majú_, цями_, _tøve,
  { {0x9f430024,0x644a1b2d,0xd838007d,0x00000000}},	//   lajú_, _infi, _mač_,
  { {0x3ea91d0e,0x442c1da8,0x92580021,0x00000000}},	//   ulat_, led_, _يشير_,
  { {0xdfd5122b,0x9f430024,0x865b0063,0x00000000}},	// [2c90] _попы, najú_, קדמי,
  { {0xb5fd003d,0x442c1da9,0x26de1daa,0x00000000}},	//   ekšl, ned_, _otto_,
  { {0x9f430066,0x628f17eb,0x68e21dab,0x00000000}},	//   hajú_, onco, epod,
  { {0x2bdf0394,0xfbdf0161,0x9f430024,0x00000000}},	//   _प्रा, _प्रम, kajú_,
  { {0x26de051e,0x442c1dac,0xd825050f,0x00000000}},	//   _atto_, ked_, едли,
  { {0x9f430024,0x442c1dad,0x7d0d017e,0x00000000}},	//   dajú_, jed_, muas,
  { {0xa2ca0053,0x442c1dae,0x46a5026b,0x00000000}},	//   _संग्, ded_, накв,
  { {0xbb48007e,0x628f006f,0xee320063,0x00000000}},	//   _تلفن_, jnco, ָֽה_,
  { {0x79a70fe2,0x660600ea,0x99890051,0x00000000}},	//   _црве, ókka, żał_,
  { {0xa2ca0161,0xe4510032,0x442c1daf,0x00000000}},	//   _संख्, اضة_, ged_,
  { {0xe2860da9,0xae0f0053,0x7d0d1db0,0x00000000}},	//   елни, िलान_, huas,
  { {0x644a1db1,0x7d0d07fa,0x442c004b,0x00000000}},	//   _enfi, kuas, aed_,
  { {0x442c1db2,0x3e6e0026,0x6e2d1db3,0x00000000}},	//   bed_, _nýta_, deab,
  { {0x442c1db4,0xa2ca0235,0xa06a000d,0x00000000}},	//   ced_, _सूक्, чага_,
  { {0x53320002,0x6e2d0025,0x3ea01db5,0x00000000}},	//   _бејт, feab, toit_,
  { {0x7d0d0035,0xd7f10013,0x6e2d1db6,0x00000000}},	//   fuas, _lẽ_, geab,
  { {0x3ea01db7,0x62861db8,0x7d0d1db9,0x00000000}},	// [2ca0] roit_, miko, guas,
  { {0x69db006d,0xc19b0063,0x3ea01dba,0x00000000}},	//   _afue, _משפי, soit_,
  { {0x9f430024,0xe1ff0025,0x961d001c,0x00000000}},	//   zajú_, mhór_, ziņa,
  { {0x442c0886,0xb21b0093,0x649c005b,0x00000000}},	//   zed_, lnær, _içiş,
  { {0x442c0034,0xd83800c2,0x3cd5000d,0x00000000}},	//   yed_, _pač_, _аўст,
  { {0x9f430024,0x442c0034,0x62860ff2,0x00000000}},	//   vajú_, xed_, hiko,
  { {0x442c0034,0xe66600e1,0x62861dbb,0x00000000}},	//   ved_, етпо, kiko,
  { {0x442c04bf,0x9f430024,0x961d008f,0x00000000}},	//   wed_, tajú_, tiņa,
  { {0xdb1c0025,0x442c1dbc,0x35b40062,0x00000000}},	//   _ngrú, ted_, ъбир,
  { {0x998000eb,0x6aa20179,0x9f430024,0x00000000}},	//   žių_, loof, rajú_,
  { {0x442c1dbd,0x99890066,0x62861dbe,0x00000000}},	//   red_, ľať_, fiko,
  { {0x62860004,0x99890024,0x442c1dbf,0x00000000}},	//   giko, žať_, sed_,
  { {0x442c1dc0,0x60f8007f,0x2c6f0022,0x00000000}},	//   ped_, нняя_, ażdy_,
  { {0x6aa2006f,0x62861dc1,0x644a00e5,0x00000000}},	//   hoof, aiko, _unfi,
  { {0xcf9800d7,0x2f280062,0x6e2d1dc2,0x00000000}},	//   ејт_, нюто_, teab,
  { {0xb21b0583,0x7bdc1dc3,0x7d0d1dc4,0x00000000}},	//   rnæs, _afru, tuas,
  { {0x6e2d1dc5,0x1bd51dc6,0x8d740044,0x00000000}},	// [2cb0] reab, возя, هاكا,
  { {0x6e2d1dc7,0xf8b8008b,0x9c38005e,0x00000000}},	//   seab, _nhĩ_, нпут_,
  { {0x39441dc8,0x68fb007d,0x7afa0014,0x00000000}},	//   _arms_, _svud, _ættl,
  { {0xd7f100aa,0x7d0d0397,0x636b00ea,0x00000000}},	//   _sẽ_, puas, lönö,
  { {0x7d0d01f4,0xb5fd0078,0x26da01c8,0x00000000}},	//   quas, ukšm, ípon_,
  { {0x62861dc9,0x717c009a,0xf1b4009a,0x00000000}},	//   ziko, הנדס, נסס_,
  { {0xa6950095,0x63aa002b,0x39441dca,0x00000000}},	//   криј, _nyfn, _erms_,
  { {0x6edc00c2,0x628611d9,0x99d40044,0x00000000}},	//   _učbe, xiko, _متكا,
  { {0x58d50086,0xf993014d,0x69c41dcb,0x00000000}},	//   _розт, _صبر_, žier,
  { {0x44651dcc,0x58d40afc,0x290f004b,0x00000000}},	//   твов, _софт, muga_,
  { {0x63aa0185,0xe3b90088,0xfbd20063,0x00000000}},	//   _cyfn, ьбо_, יתי_,
  { {0x20010150,0x63aa002b,0x63ae0058,0x00000000}},	//   _adhi_, _dyfn, übna,
  { {0x290f0019,0x0fda0121,0xa56400f2,0x00000000}},	//   nuga_, дьбы_, _مدون,
  { {0x291d1147,0x62861dcd,0x5576009a,0x00000000}},	//   itwa_, siko, _בענן_,
  { {0x63aa001f,0x8fa6026b,0x290f1c8f,0x00000000}},	//   _gyfn, таве, huga_,
  { {0x7bdc051e,0x290f0019,0xf2d20063,0x00000000}},	//   _sfru, kuga_, _דעה_,
  { {0x290f004b,0x7e23005e,0xc5f2009f,0x00000000}},	// [2cc0] juga_, јдуж, ידן_,
  { {0x20040006,0x78a300d1,0x290f1dce,0x00000000}},	//   ėmis_, jonv, duga_,
  { {0x753c008f,0x78a30050,0x9a25014b,0x00000000}},	//   ārzi, donv, сiяй_,
  { {0x290f1dcf,0xc9861dd0,0xf98a0044,0x00000000}},	//   fuga_, кули, وناي_,
  { {0x78a300df,0x290f004b,0x645c01cf,0x00000000}},	//   fonv, guga_, örik,
  { {0x7afc017f,0xa7fc005b,0x6aa20019,0x00000000}},	//   _tvrt, _alır, soof,
  { {0x7c3c0027,0x291d0150,0x7c3e0137,0x00000000}},	//   _iarr, atwa_, mdpr,
  { {0xc6a60062,0x96341dd1,0x7c3c1dd2,0x00000000}},	//   ърли, униц, _harr,
  { {0x291d0051,0x08c6000d,0xdd110058,0x00000000}},	//   ctwa_, _абан, _müşe,
  { {0xdb0e003b,0x3e67004b,0x7c3e1dd3,0x00000000}},	//   _izbâ, _võti_, ndpr,
  { {0x64a30079,0xd251006a,0x7c3c09e2,0x00000000}},	//   раќа, مند_, _marr,
  { {0x6d461dd4,0x7c3c1dd5,0x21790121,0x00000000}},	//   _orka, _larr, еймы_,
  { {0x9553006a,0xaf34007e,0x316d0331,0x00000000}},	//   _نخوا, یرفت, áez_,
  { {0x3e75076c,0xa3d31dd6,0x8cd60042,0x00000000}},	//   _måte_, _кошч, _बढ़ो,
  { {0x6d461a8d,0x5433002a,0x66020260,0x00000000}},	//   _arka, _ضرور, _kdok,
  { {0x443e1dd7,0x443c018c,0x290f0f20,0x00000000}},	//   ldt_, _hav_, yuga_,
  { {0x961d003d,0x5cb9000d,0x201e00cd,0x00000000}},	// [2cd0] ziņo, елаў_, òtic_,
  { {0x443e1dd8,0x1a65007e,0x443c1dd9,0x00000000}},	//   ndt_, گیری_, _jav_,
  { {0x7c3c1dda,0x6d4600bd,0x44e2001b,0x00000000}},	//   _darr, _erka, hư_,
  { {0x7c3c0027,0x99840006,0x443c1ddb,0x00000000}},	//   _earr, _namų_, _lav_,
  { {0xe8df0013,0x443c1ddc,0x7c3c1ddd,0x00000000}},	//   _trọn_, _oav_, _farr,
  { {0x443c0418,0xfc64005a,0x443e0122,0x00000000}},	//   _nav_, _късн, jdt_,
  { {0x290f0019,0x291d0051,0x46f4000d,0x00000000}},	//   suga_, stwa_, ачыт,
  { {0xc1e30235,0x443e0122,0x6d460137,0x00000000}},	//   _क्लब_, edt_, _yrka,
  { {0x6e3d00a4,0xfeca0047,0x7e6d193c,0x00000000}},	//   _masb, עמפּ, ikap,
  { {0x649d0268,0x38a90066,0x7e6d0072,0x00000000}},	//   nèix, túru_, hkap,
  { {0xf770007e,0x461501fb,0x7e6d1dde,0x00000000}},	//   _وام_, _موار, kkap,
  { {0xe0c900b5,0x443e006f,0x32ba0021,0x00000000}},	//   _זײ_, adt_, عددة_,
  { {0x321e0051,0x7e6d1ddf,0x51f70043,0x00000000}},	//   ęty_, dkap, دسپر,
  { {0x443c1de0,0x2c7600b9,0x66020240,0x00000000}},	//   _gav_, _kæde_, _zdok,
  { {0x44271de1,0x65690072,0x1e961de2,0x00000000}},	//   _ibn_, lyeh, грар,
  { {0xd7f1001b,0x93bc003b,0x9e75005e,0x00000000}},	//   _dõi_, sfăc, аћуј,
  { {0x61461968,0x261b0053,0x65690150,0x00000000}},	// [2ce0] _сепа, _यानी_, nyeh,
  { {0x7e6d0012,0x31570063,0x7e761de3,0x00000000}},	//   akap, _עיין_, shyp,
  { {0x8e8606f0,0x629d0003,0xaa460002,0x00000000}},	//   _бгне, érog, лежл,
  { {0x7c3c1926,0x26da0066,0x7e6d047b,0x00000000}},	//   _warr, ípom_, ckap,
  { {0x443e0c3d,0x7c3c1de4,0x99550058,0x00000000}},	//   ydt_, _tarr, rüşe_,
  { {0x8d4b0063,0x219b0041,0x20f20023,0x00000000}},	//   _אֲלֵ, עבסא, iņi_,
  { {0x6d441de5,0xc7af02dc,0x7fd7009f,0x00000000}},	//   lvia, сё_, נוקס_,
  { {0x9b930021,0x443c1de6,0x657b004d,0x00000000}},	//   _الفت, _sav_, fzuh,
  { {0x6d441de7,0x443c0006,0x44271de8,0x00000000}},	//   nvia, _pav_, _bbn_,
  { {0x443e006f,0xd5c00053,0xe8d70063,0x00000000}},	//   udt_, शेषज, _עובר_,
  { {0x443e0b7d,0x7e6d1de9,0x61f61dea,0x00000000}},	//   rdt_, ykap, _beyl,
  { {0x673a007d,0x443c1deb,0x61f61dec,0x00000000}},	//   _istj, _wav_, _ceyl,
  { {0x6d440024,0x61f8000d,0x9f51004a,0x00000000}},	//   jvia, ыняў_, razí_,
  { {0x60d6005b,0x6d440066,0x443c1ded,0x00000000}},	//   _duym, dvia, _uav_,
  { {0xcebb0001,0xb4c20053,0x7e6d0659,0x00000000}},	//   еља_, ्दी_, tkap,
  { {0x38bb00e8,0xe80e0053,0xe1ff009c,0x00000000}},	//   mêre_, _साझा_, kkói_,
  { {0x38bb00e8,0x5d55026b,0x6abb001f,0x00000000}},	// [2cf0] lêre_, шкат, _rhuf,
  { {0x673a0019,0x9ed90189,0x7e6d1dee,0x00000000}},	//   _ostj, _имот_, skap,
  { {0x649d0268,0x38bb00e8,0xca150062,0x00000000}},	//   rèix, nêre_, иджъ,
  { {0xbddb00cd,0x8bc4007f,0xb5fd0078,0x00000000}},	//   _enèr, ссуд, lkšv,
  { {0xc27c00b5,0x2c7605b9,0xe9d8000d,0x00000000}},	//   ערדי, _sæde_, укі_,
  { {0x1bd4137a,0xa9661def,0x8d48009a,0x00000000}},	//   _горя, риша_, _עֲרֵ,
  { {0x4af6007e,0xdc9a009a,0x4c9a009a,0x00000000}},	//   _نکند_, _יישל, _יבשו,
  { {0x44270150,0x0f580063,0xe1ff0022,0x00000000}},	//   _sbn_, ריהם_, mków_,
  { {0xd4550086,0x7d0d09ad,0xb4c20042,0x00000000}},	//   атнь, nras, ्दू_,
  { {0x032500d7,0x7c250025,0xddc40006,0x00000000}},	//   адон, nfhr, nkiš,
  { {0xe1ff0045,0x9655005a,0xee3f0066,0x00000000}},	//   nków_, _вълч, _akým_,
  { {0x216a0086,0x7d0d1df0,0x6d440006,0x00000000}},	//   вими_, kras, yvia,
  { {0xe2971df1,0x7d0d1df2,0x34951bf5,0x00000000}},	//   рая_, jras, _кадр,
  { {0xd4660138,0x38bb00e8,0x6d44051e,0x00000000}},	//   _више_, bêre_, vvia,
  { {0x6f630002,0x7d0d07ff,0xe1ff0022,0x00000000}},	//   оврз, eras, jków_,
  { {0x539a0f6d,0x7afa0026,0xe1ff0051,0x00000000}},	//   _ביצו, _ætti, dków_,
  { {0x4c86000d,0x7d0d1df3,0x629d006d,0x00000000}},	// [2d00] алав, gras, éroe,
  { {0xe0fb014e,0xd12f007e,0x6d441df4,0x00000000}},	//   _שליל, _کمی_, rvia,
  { {0xdddd000f,0x2abc006d,0x64411df5,0x00000000}},	//   _első, híbe_, idli,
  { {0x6da60086,0x8b650021,0x7d0d1df6,0x00000000}},	//   _вима, حاكم, bras,
  { {0x29000016,0x9f43006d,0x44e91df7,0x00000000}},	//   éia_, bajó_, _nº_,
  { {0x20181df8,0x64411df9,0xf1b9027d,0x00000000}},	//   ngri_, jdli, ýši_,
  { {0x26cf00a4,0x64411dfa,0x3e67004b,0x00000000}},	//   _bigo_, ddli, _tõtt_,
  { {0x644100bd,0xeb97019d,0x2240014f,0x00000000}},	//   edli, _тис_, _naik_,
  { {0xd5b70b62,0x26cf0460,0xd946005e,0x00000000}},	//   ись_, _digo_, _њези,
  { {0x38bb00e8,0xb4c00053,0x9169008b,0x00000000}},	//   têre_, ंगे_, _lựa_,
  { {0x2240014f,0x3e7500c7,0x26cf1dfb,0x00000000}},	//   _baik_, _låta_, _figo_,
  { {0x38bb00ac,0x39461dfc,0x9f580e7c,0x00000000}},	//   rêre_, ovos_, caré_,
  { {0xe1ff0022,0x50671dfd,0x867b0063,0x00000000}},	//   zków_, атва, _בראו,
  { {0x27fc0dfb,0x7d0d0387,0x3946017d,0x00000000}},	//   navn_, vras, ivos_,
  { {0x06fd0080,0x3eb204aa,0x7d0d00a3,0x00000000}},	//   žívá_, flyt_, wras,
  { {0x27fc06a5,0x7d0d1dfe,0x200d003b,0x00000000}},	//   havn_, tras, şei_,
  { {0x7d0d1dff,0x9169008b,0x61fd0443,0x00000000}},	// [2d10] uras, _dựa_, masl,
  { {0xe1ff0051,0x61fd1e00,0x9f581358,0x00000000}},	//   tków_, lasl, zaré_,
  { {0x22400089,0x2a641e01,0x9e350002,0x00000000}},	//   _yaik_, _bomb_, _ленч,
  { {0x7d0d1e02,0x7e55007e,0xe1ff0022,0x00000000}},	//   pras, _انحص, rków_,
  { {0x3949048e,0x0dcb000a,0xe1ff0051,0x00000000}},	//   ías_, _јуни_, sków_,
  { {0x229200c2,0xf8a8000d,0x26cf0e7c,0x00000000}},	//   mške_, авік_, _sigo_,
  { {0x9f581e03,0xb21b0014,0x6d400014,0x00000000}},	//   taré_, mhæf, _ámar,
  { {0x2a6400ea,0x2f980063,0x7d1b004d,0x00000000}},	//   _gomb_, יכון_, _äuss,
  { {0x88070242,0x26cf1e04,0x22920734,0x00000000}},	//   _نظام, _vigo_, nške_,
  { {0x2abc0025,0x9f581795,0x66d50a1e,0x00000000}},	//   ríbe_, saré_, _aške,
  { {0x64411e05,0xa25b017d,0x9f580003,0x00000000}},	//   rdli, rmôn, paré_,
  { {0x6f15048e,0x27211e06,0xdb0e006c,0x00000000}},	//   duzc, món_, édée,
  { {0x27211e07,0x200c00be,0x29350041,0x00000000}},	//   lón_, ódio_, זאָן_,
  { {0x672300c2,0x6f080124,0x61fd00a8,0x00000000}},	//   otnj, ádco, aasl,
  { {0xb21b0146,0x27211e08,0x20180046,0x00000000}},	//   dhæf, nón_, rgri_,
  { {0x39460078,0xbda60044,0x92930092,0x00000000}},	//   yvos_, محذو, _најц,
  { {0xee370001,0x27211919,0xed571e09,0x00000000}},	// [2d20] љну_, hón_, бот_,
  { {0x4f960002,0xb17b00a5,0xa3ab0042,0x00000000}},	//   _грму, rbåt, कअप_,
  { {0x4b260002,0x27211e0a,0x3ea91098,0x00000000}},	//   смев, jón_, boat_,
  { {0xef220051,0x82d60047,0x27211e0b,0x00000000}},	//   ążę_, צונג_, dón_,
  { {0x186a0ef3,0x27211e0c,0x39460072,0x00000000}},	//   лади_, eón_, uvos_,
  { {0xa967005e,0x394618f5,0x27211e0d,0x00000000}},	//   сиља_, rvos_, fón_,
  { {0x27211e0e,0x290f1e0f,0x39460078,0x00000000}},	//   gón_, arga_, svos_,
  { {0x3e6e004c,0x1efb0041,0xddcd0022,0x00000000}},	//   _býti_, אלקע, jjaś,
  { {0x61fd000f,0xb5fd001c,0x99920051,0x00000000}},	//   vasl, ekšs, żył_,
  { {0xd6d208aa,0x2721006d,0xb8650021,0x00000000}},	//   _فقط_, bón_, _والو,
  { {0x22590121,0x27211e10,0x61fd1e11,0x00000000}},	//   аины_, cón_, tasl,
  { {0xb5fd0006,0x41e4000d,0x7afa0014,0x00000000}},	//   ukšt, зіра, _ættu,
  { {0x61fd02e2,0xb5fd0078,0x645c1e12,0x00000000}},	//   rasl, rkšt, öris,
  { {0x2d801e13,0x8cd30053,0x7d160058,0x00000000}},	//   dzie_, _भूगो, duys,
  { {0x61e40185,0x7e6600c7,0x61fd1e14,0x00000000}},	//   _ffil, _bokp, pasl,
  { {0xa1950062,0x63970063,0x5f941e15,0x00000000}},	//   _майч, _לדוא_, чист,
  { {0x272102dd,0x3ea900e5,0x2d580065,0x00000000}},	// [2d30] zón_, roat_, бить_,
  { {0xebc70001,0xaae70021,0x628f1e16,0x00000000}},	//   бљен, مسؤو, lico,
  { {0xb5fd082a,0xb21b0026,0xddcf003b,0x00000000}},	//   ljše, rhæf, _focş,
  { {0xdb1f0026,0x6f010e7c,0x628f1e17,0x00000000}},	//   _ávís, álcu, nico,
  { {0xae1a00b5,0xb5fd1253,0x290f1e18,0x00000000}},	//   _דורכ, njše, urga_,
  { {0x27211e19,0x0c75007e,0x2bcb0002,0x00000000}},	//   tón_, _بگرد, _бубо_,
  { {0x2d9c0058,0xddcd0022,0xe708009b,0x00000000}},	//   şvet_, yjaś, متين_,
  { {0x27210885,0xb5fd001c,0x628f0130,0x00000000}},	//   rón_, ekšr, jico,
  { {0x628f1e1a,0x2721006d,0x64991e1b,0x00000000}},	//   dico, són_, итор_,
  { {0x7305019d,0x6aab1e1c,0x27211e1d,0x00000000}},	//   опоз, logf, pón_,
  { {0x628f0b23,0x8c1a0063,0xe3b10021,0x00000000}},	//   fico, בותי, برة_,
  { {0x628f06b2,0xd1ca005e,0xd5751b37,0x00000000}},	//   gico, илне_, _муль,
  { {0x26da0066,0xd5480593,0xf494005d,0x00000000}},	//   ípov_, _هجوم_, _کشند,
  { {0x201e004b,0xd01200f2,0x661b004e,0x00000000}},	//   üti_, بلس_, lguk,
  { {0x64430290,0x628f0877,0x661b004b,0x00000000}},	//   _iani, bico, oguk,
  { {0xee3a00e1,0x64431832,0x38b2003b,0x00000000}},	//   јна_, _hani, râri_,
  { {0x644303d5,0x7fd60097,0x6aab002b,0x00000000}},	// [2d40] _kani, _міні, dogf,
  { {0x2d800024,0x64431e1e,0xab2a066f,0x00000000}},	//   rzie_, _jani, иоза_,
  { {0x6a860edd,0x394d0dd2,0xe9da1e1f,0x00000000}},	//   олжа, _ares_, аке_,
  { {0x9c870080,0xddc60078,0x64431e20,0x00000000}},	//   _počá, _jokū, _lani,
  { {0xdb070080,0xef190022,0x09360044,0x00000000}},	//   _vyjá, ąże_, تراج,
  { {0x64431e21,0xd90d007e,0xc1730063,0x00000000}},	//   _nani, ایل_, וחד_,
  { {0xe3a7006a,0x8b23041d,0x394d02dd,0x00000000}},	//   _آر_, _одре, _eres_,
  { {0x7d041e22,0x628f1e23,0x7ae1013d,0x00000000}},	//   osis, xico, _élta,
  { {0x9f580024,0x64431e24,0xe4c60121,0x00000000}},	//   darí_, _bani, жённ,
  { {0x64431e25,0x29000078,0x7d041e26,0x00000000}},	//   _cani, šias_, isis,
  { {0x628f1e27,0x7d04049c,0x64431e28,0x00000000}},	//   tico, hsis, _dani,
  { {0xd3770088,0x7d041e29,0xdb2100ea,0x00000000}},	//   ючы_, ksis, étét,
  { {0x66d50006,0x628f1e2a,0x7d04001c,0x00000000}},	//   _iška, rico, jsis,
  { {0x64430a73,0xdfd8005a,0x628f1e2b,0x00000000}},	//   _gani, жът_, sico,
  { {0x628f0b23,0x4e8b0062,0x7d041e2c,0x00000000}},	//   pico, ащам_, esis,
  { {0x7d040009,0x64431e2d,0x66001e2e,0x00000000}},	//   fsis, _zani, namk,
  { {0x7d0400bb,0xd904006a,0xdddd0051,0x00000000}},	// [2d50] gsis, _جی_, _posł,
  { {0x660000e3,0xa0680001,0xfc330021,0x00000000}},	//   hamk, _мања_, بحر_,
  { {0x66000397,0x68e905e5,0x5a350002,0x00000000}},	//   kamk, _sted, знет,
  { {0x394d1e2f,0xc1750063,0x7d041e30,0x00000000}},	//   _pres_, ּחַ_, bsis,
  { {0x6aab00b9,0x9e5a0063,0x7d040072,0x00000000}},	//   rogf, _הכרט, csis,
  { {0x68e90024,0x3e7c0080,0x48ab005e,0x00000000}},	//   _vted, _víte_, штем_,
  { {0xf77104f6,0x68e90051,0x64431e31,0x00000000}},	//   عات_, _wted, _rani,
  { {0x394d1e32,0x44e0008b,0x05650156,0x00000000}},	//   _tres_, _bò_, звин,
  { {0x79820045,0x64431e33,0x661b004b,0x00000000}},	//   czow, _pani, rguk,
  { {0x44e0008b,0x629d0b6c,0x442e00be,0x00000000}},	//   _dò_, éron, _cbf_,
  { {0xf1a900b7,0x229200eb,0x0322000d,0x00000000}},	//   _עס_, eška_, ндэн,
  { {0x6443166a,0x67ba0063,0xe29a1e34,0x00000000}},	//   _wani, _המעק, сам_,
  { {0xa7fc005b,0x2bb80053,0x44e00013,0x00000000}},	//   _alıy, _अर्थ, _gò_,
  { {0xf09f00cd,0x7ae91aa5,0x22590078,0x00000000}},	//   dràs_, _četn, _čekų_,
  { {0x6e2f0016,0x7d040050,0x6d4f1e35,0x00000000}},	//   _bbcb, wsis, _arca,
  { {0x3e6e007a,0xc7b20063,0x7d041e36,0x00000000}},	//   _nýtt_, גבל_, tsis,
  { {0xed57036a,0x0d86005e,0x7d041e37,0x00000000}},	// [2d60] пот_, члан, usis,
  { {0x7d041e38,0xe058007e,0x32020445,0x00000000}},	//   rsis, _بیست_, laky_,
  { {0x6d4f1e39,0x7d041250,0x8ad601f3,0x00000000}},	//   _erca, ssis, ستائ,
  { {0xf09f00cd,0x9f5801a8,0xd491008d,0x00000000}},	//   bràs_, marà_, hì_,
  { {0x9f5800cd,0xda650044,0xadd7009a,0x00000000}},	//   larà_, بالي, _מוכח_,
  { {0x91bb0063,0x79820051,0x44e0008d,0x00000000}},	//   זמני, rzow, _rò_,
  { {0x9f580268,0xa3ab0053,0x79820051,0x00000000}},	//   narà_, _कुल_, szow,
  { {0x44e001f4,0x09e6005e,0x8b9b0063,0x00000000}},	//   _pò_, _хоан, _הבלת,
  { {0x66001e3a,0xa3c90042,0xfaa31e3b,0x00000000}},	//   ramk, लेस_, _чато,
  { {0x660000bd,0x628d0025,0x69c01e3c,0x00000000}},	//   samk, _smao, _izme,
  { {0xd251006a,0xe2150121,0x4adc0042,0x00000000}},	//   نند_, ммны, यदिव,
  { {0x9f580268,0x11d90021,0x44e00013,0x00000000}},	//   darà_, توحة_, _tò_,
  { {0xc05b0086,0x3254000d,0x2906007d,0x00000000}},	//   бів_, хвяр, nsoa_,
  { {0x229202f7,0x82f7005d,0x4ee70054,0x00000000}},	//   rška_, _کروز_, зіаз,
  { {0x9f580268,0xb5fd06bb,0x6448001f,0x00000000}},	//   garà_, ljša, mddi,
  { {0x02a40088,0xbddb00cd,0x877b0047,0x00000000}},	//   _прым, _gaèl, זאלי,
  { {0xb5fd00c3,0x442c006f,0x2d580071,0x00000000}},	// [2d70] njša, ofd_, пить_,
  { {0x26de00e8,0x9f5800cd,0xebc70001,0x00000000}},	//   _outo_, barà_, пљен,
  { {0x9f580268,0x20030035,0x6448001f,0x00000000}},	//   carà_, maji_, iddi,
  { {0x629d00d1,0x3935000d,0x20031e3d,0x00000000}},	//   nnso, дэкс, laji_,
  { {0x9f580460,0x6d4f003b,0x26de0719,0x00000000}},	//   mará_, _urca, _auto_,
  { {0x20030035,0x9f580e7c,0x629d1e3e,0x00000000}},	//   naji_, lará_, hnso,
  { {0x61e600c7,0x60df0089,0x6d4d0d47,0x00000000}},	//   yckl, _luqm, lvaa,
  { {0x9f580297,0x442c006f,0x64480767,0x00000000}},	//   nará_, efd_, eddi,
  { {0x6d4d1e3f,0x20030e29,0x64481e40,0x00000000}},	//   nvaa, kaji_, fddi,
  { {0x6d4d172b,0x13090121,0x9f5800be,0x00000000}},	//   ivaa, оной_, hará_,
  { {0x9f580268,0x3e7c0026,0x26de155f,0x00000000}},	//   xarà_, _líta_, _guto_,
  { {0x9f581e41,0x6d4d004b,0x64580764,0x00000000}},	//   varà_, kvaa, _envi,
  { {0x9f5806b2,0x6f150051,0x5155180c,0x00000000}},	//   dará_, erzc, нтру,
  { {0x9f580268,0x629d1e42,0x20030150,0x00000000}},	//   tarà_, anso, gaji_,
  { {0x7e640150,0x6d4d1986,0x6e2d1e43,0x00000000}},	//   tjip, evaa, ffab,
  { {0x9f581e44,0x229200c2,0x7649005b,0x00000000}},	//   rarà_, mško_, ndey,
  { {0x8236006a,0xa3c9016a,0x9f580268,0x00000000}},	// [2d80] _فرکا, लेर_, sarà_,
  { {0x28e10053,0x9f5800cd,0x66d500c2,0x00000000}},	//   _पढ़ि, parà_, _oško,
  { {0xab27100b,0x9f580e7c,0x786f000e,0x00000000}},	//   доха_, bará_, _løvs,
  { {0x9f5806b2,0x99dd0a63,0x29060072,0x00000000}},	//   cará_, _daňo, tsoa_,
  { {0x64480c70,0xa967006e,0x79a30002,0x00000000}},	//   yddi, мица_, крше,
  { {0x7659001f,0x3ead1e45,0x764900a4,0x00000000}},	//   _anwy, čete_, edey,
  { {0x29060016,0x8a060001,0x7bdc00a4,0x00000000}},	//   ssoa_, _озве, _igru,
  { {0x20030009,0xc9560076,0xf4290072,0x00000000}},	//   zaji_, _отзы, ylää_,
  { {0x6f1c1e46,0x66d50078,0x69c01bbd,0x00000000}},	//   hurc, _eško, _uzme,
  { {0x9f580297,0x26de01c2,0x68ed032a,0x00000000}},	//   zará_, _tuto_, íade,
  { {0x64481e47,0x20031e48,0x629d1e49,0x00000000}},	//   rddi, vaji_, tnso,
  { {0x6f1c0199,0x9f5800ed,0x7d161e4a,0x00000000}},	//   durc, xará_, krys,
  { {0x200310ca,0x9f5804a6,0x75291e4b,0x00000000}},	//   taji_, vará_, ctez,
  { {0x656f00bd,0x7bdc0150,0x27170013,0x00000000}},	//   äche, _ngru, ũng_,
  { {0x9f5806b2,0xd0d4005a,0xa295000d,0x00000000}},	//   tará_, торъ, _пакі,
  { {0x6d4d0122,0x4ea40189,0x7bdc1e4c,0x00000000}},	//   tvaa, вруа, _agru,
  { {0x9f5806b2,0x200300c2,0xf1a4000d,0x00000000}},	// [2d90] rará_, paji_, _арэн,
  { {0x3156014e,0x9f580b23,0x6d4d1e4d,0x00000000}},	//   _ניתן_, sará_, rvaa,
  { {0xda15000a,0x752900c2,0x9f580460,0x00000000}},	//   едењ, ztez, pará_,
  { {0x2249004b,0x6d4d0983,0x28c40042,0x00000000}},	//   _jaak_, pvaa, _लीबि,
  { {0x22491a20,0xeab00021,0xf5480013,0x00000000}},	//   _maak_, جعل_, _nụ_,
  { {0x212b0168,0x9178009a,0xacfa009d,0x00000000}},	//   itch_, ועדף_, _מהשכ,
  { {0x7afc0185,0x20010019,0xcb690044,0x00000000}},	//   _gwrt, _mehi_, _عمره_,
  { {0x7529051e,0x06091e4e,0x26c6179b,0x00000000}},	//   ttez, чник_, _choo_,
  { {0xf548001b,0x76490058,0x78f80044,0x00000000}},	//   _cụ_, rdey, _يعكس_,
  { {0xf548001b,0x75291e4f,0x2db80063,0x00000000}},	//   _dụ_, rtez, ולחן_,
  { {0xa3c90053,0xe66700a0,0x291d00a4,0x00000000}},	//   लें_, _отдо, luwa_,
  { {0xbbdc0053,0x2292085a,0x7529003b,0x00000000}},	//   _बल्क, rško_, ptez,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x7d1600ac,0x38a90066,0x2a6d1e50,0x00000000}},	//   vrys, túry_, _loeb_,
  { {0xc7b200b5,0x2baf0053,0x7e561e51,0x00000000}},	//   ָבן_, _जुला, нтац,
  { {0x9f5c0ac6,0x291d10ca,0x683301f7,0x00000000}},	//   _því_, kuwa_, lıdı,
  { {0xafe6064b,0xe3b80058,0xec7a01d5,0x00000000}},	// [2da0] _попл, ngın_, ппа_,
  { {0xb21b0146,0x22490122,0xcf46000d,0x00000000}},	//   nhæn, _zaak_, _зной,
  { {0xddcd08ed,0x66c5013d,0x6bd70044,0x00000000}},	//   rkaš, iókb, فوكس_,
  { {0xdceb005b,0x7d160b9d,0xb906066e,0x00000000}},	//   _çiğn, prys, ездк,
  { {0xe2970047,0x3ea01e52,0x38c8005d,0x00000000}},	//   עכנט_, mnit_, واتی_,
  { {0x6d461e53,0x4973000d,0x3ea01e54,0x00000000}},	//   _iska, ыліс, lnit_,
  { {0x7c3e0fea,0x501b0063,0x6386006c,0x00000000}},	//   mepr, לוסו, _méné,
  { {0x3ea01e55,0x3944004b,0x7c3e1e56,0x00000000}},	//   nnit_, _tsms_, lepr,
  { {0x224900e8,0xb21b0146,0x3ea0058e,0x00000000}},	//   _raak_, fhæn, init_,
  { {0xf548001b,0x224914c2,0xa9230078,0x00000000}},	//   _vụ_, _saak_, ėžta,
  { {0x7c3e1e57,0xd764007e,0x2c1e0082,0x00000000}},	//   iepr, _جنای, _पाईं_,
  { {0xd62a0076,0xf548008b,0x270c004c,0x00000000}},	//   _ходе_, _tụ_, měn_,
  { {0x224902b0,0x63860164,0xc05b0086,0x00000000}},	//   _vaak_, _béné, пів_,
  { {0x3ea01e58,0x68330058,0x7c3e1e59,0x00000000}},	//   enit_, cıdı, jepr,
  { {0x270c0080,0x22490179,0x9f340086,0x00000000}},	//   něn_, _taak_, лері,
  { {0x644a1e5a,0xada30066,0xceb8005e,0x00000000}},	//   _hafi, ylúč, ељу_,
  { {0x443e0173,0x5ff5005a,0x61ed0137,0x00000000}},	// [2db0] oet_, _изпу, _ifal,
  { {0x638603b2,0x443e1af0,0x3ea00072,0x00000000}},	//   _géné, net_, anit_,
  { {0x443e02b0,0x644a1e5b,0xa3c20053,0x00000000}},	//   iet_, _mafi, ्धि_,
  { {0x443e1e5c,0x291d00a4,0xd9990021,0x00000000}},	//   het_, tuwa_, ونات_,
  { {0x61ed0035,0x7c3e0006,0x443e1e5d,0x00000000}},	//   _mfal, bepr, ket_,
  { {0x443e1e5e,0x644a1e5f,0x1d160063,0x00000000}},	//   jet_, _nafi, _בקשר_,
  { {0x443e1e60,0x61ed001f,0x1ab5000d,0x00000000}},	//   det_, _ofal, _абвя,
  { {0x2f5c0047,0x443e1e61,0xead40085,0x00000000}},	//   לדונ, eet_, _бось,
  { {0x443e1e62,0xe5710021,0x16620121,0x00000000}},	//   fet_, شطة_, рвым,
  { {0xf990007e,0x443e1e63,0x3ea0004c,0x00000000}},	//   _طبق_, get_, znit_,
  { {0x6833005b,0x53a506b4,0x644a1e64,0x00000000}},	//   rıdı, танб, _dafi,
  { {0x7c3e1e65,0x6833005b,0xb21b00b9,0x00000000}},	//   zepr, sıdı, shæn,
  { {0x443e1e66,0x63860164,0x3ea00080,0x00000000}},	//   bet_, _péné, vnit_,
  { {0x61ed0185,0x6143005e,0x6d4600a8,0x00000000}},	//   _efal, јера, _rska,
  { {0x63860003,0xc0030095,0x3ea0004c,0x00000000}},	//   _véné, рпск, tnit_,
  { {0x6d460df9,0x644a1e67,0xb5fd0023,0x00000000}},	//   _pska, _zafi, ekšz,
  { {0x7c3e1e68,0x63860003,0xf1bf002b,0x00000000}},	// [2dc0] tepr, _téné, ffáu_,
  { {0x3ea01e69,0x764b002c,0x711b0047,0x00000000}},	//   snit_, _lagy, _קויפ,
  { {0x6d460045,0x290d1e6a,0x7c3e1e6b,0x00000000}},	//   _wska, _avea_, repr,
  { {0x7c3e1e6c,0x764b1e6d,0x443e1e6e,0x00000000}},	//   sepr, _nagy, zet_,
  { {0x443e1e6f,0x98a600a8,0x6d461e70,0x00000000}},	//   yet_, stoč_, _uska,
  { {0x443e1374,0x68ed00ed,0xfd5f0013,0x00000000}},	//   xet_, íada, huyệ,
  { {0x644a1e71,0x443e1c38,0xe7370699,0x00000000}},	//   _rafi, vet_, веј_,
  { {0x6e241e72,0x6d440051,0x443e1e73,0x00000000}},	//   ngib, owia, wet_,
  { {0x48e6019d,0x7ae9017f,0x644a001f,0x00000000}},	//   _розв, _četi, _pafi,
  { {0x54530076,0x443e1e74,0x44270290,0x00000000}},	//   авьт, uet_, _ccn_,
  { {0x6602024a,0x443e1e75,0xbc1b0047,0x00000000}},	//   _teok, ret_, וויש,
  { {0x92580076,0x443e1e76,0x644a05b3,0x00000000}},	//   вают_, set_, _wafi,
  { {0x443e1e77,0x3e750137,0x644a1e78,0x00000000}},	//   pet_, _mått_, _tafi,
  { {0x84380032,0x649a0054,0x66c5013d,0x00000000}},	//   _أكثر_, _ютер_, móka,
  { {0x66c500ea,0xe2080022,0xa381004e,0x00000000}},	//   lóka, _stół_, õõte,
  { {0x645d003d,0x3e7500c7,0x6e240290,0x00000000}},	//   ēsie, _nått_, ggib,
  { {0x51870304,0x3f8a004c,0x6aa2017c,0x00000000}},	// [2dd0] _шука, azbu_, dnof,
  { {0x673a09b0,0x1acb0053,0x20c40072,0x00000000}},	//   _optj, िष्ठ, löin_,
  { {0x764000fe,0xdfd1007e,0x290d0137,0x00000000}},	//   kemy, _ديد_, _svea_,
  { {0xb21b00b9,0x6aa200ac,0xc3330063,0x00000000}},	//   skæf, gnof, יוע_,
  { {0x0d640062,0x66ea0051,0x202a0014,0x00000000}},	//   _кърм, _ręka, _ýtið_,
  { {0x66d50006,0xfaf3005d,0x66c5013d,0x00000000}},	//   _iški, _نثر_, dóka,
  { {0x3e751e79,0x9f5100ea,0x764b0078,0x00000000}},	//   _fått_, mazó_, _pagy,
  { {0x3e750a2e,0x9f51006d,0xb21b01e1,0x00000000}},	//   _gått_, lazó_, nkæd,
  { {0xdd1201f7,0xb5fd00c2,0x7d0d1e7a,0x00000000}},	//   _müşt, ljšk, nsas,
  { {0x229200c3,0x7c25001f,0x9f510331,0x00000000}},	//   mški_, nghr, nazó_,
  { {0x2292007d,0xc759008f,0x6d440022,0x00000000}},	//   lški_, šībā, zwia,
  { {0xad9b0b23,0x09b50047,0x229200c2,0x00000000}},	//   _reún, ָפֿט_, oški_,
  { {0xd5bb0088,0x44270013,0x9f580003,0x00000000}},	//   _ўсе_, _tcn_, mbré_,
  { {0xd3780051,0x351a0047,0xc4840500,0x00000000}},	//   być_, _נוצנ, _клік,
  { {0xa3c90053,0xe29a086c,0x64411e7b,0x00000000}},	//   लेख_, _пак_, meli,
  { {0x26dd0150,0x6d440022,0xb22602b3,0x00000000}},	//   _jiwo_, twia, _смил,
  { {0x7d0d00bb,0x62840009,0xdd12005b,0x00000000}},	// [2de0] gsas, _ilio, _düşt,
  { {0x64411e7c,0x76400051,0x5046005e,0x00000000}},	//   neli, zemy, _сеоб,
  { {0x61e900c3,0x44e90025,0xe47a0047,0x00000000}},	//   žele, _lú_, ערעכ,
  { {0xa3ab0053,0x64410aba,0xaaba007e,0x00000000}},	//   _कुछ_, heli, ردار_,
  { {0x44e9007a,0xd3780051,0x64411e7d,0x00000000}},	//   _nú_, zyć_, keli,
  { {0x7ae9017f,0x64411e7e,0x200a002c,0x00000000}},	//   _četv, jeli, nabi_,
  { {0x64410fdf,0xeef60063,0xd6da1e7f,0x00000000}},	//   deli, אמֶר_, нти_,
  { {0x224200d1,0x200a0222,0x66c500ea,0x00000000}},	//   jekk_, habi_, tóka,
  { {0x49ca0138,0x64411e80,0x44e91e81,0x00000000}},	//   _члан_, feli, _cú_,
  { {0x200a172b,0x27f701c2,0x62841e82,0x00000000}},	//   jabi_, čení_, _alio,
  { {0x44e90024,0xa8570063,0x7d0d013d,0x00000000}},	//   _eú_, _תיבה_, zsas,
  { {0x26dd0150,0x66c500ea,0x75200035,0x00000000}},	//   _giwo_, lókn, pumz,
  { {0x44e91e83,0xd3780022,0x64411e84,0x00000000}},	//   _gú_, syć_, beli,
  { {0x657d000e,0x64411e85,0x224d189f,0x00000000}},	//   øshe, celi, žek_,
  { {0x447b00b5,0xdfd5014c,0x1ee7007e,0x00000000}},	//   _אנגע, ровы, اوری_,
  { {0x7d0d021e,0x20050022,0xdd2d0078,0x00000000}},	//   tsas, źli_, _vėžy,
  { {0x320b0034,0x629d0003,0x7d0d01cf,0x00000000}},	// [2df0] macy_, érou, usas,
  { {0x7d0d1e86,0xb21b01e1,0x320b0ac3,0x00000000}},	//   rsas, skæd, lacy_,
  { {0x628400fe,0x66d50006,0x7d0d1e87,0x00000000}},	//   _ylio, _iškv, ssas,
  { {0x64411e88,0x639b0047,0xd3570063,0x00000000}},	//   zeli, עסאנ, טיבי_,
  { {0x4425001f,0x64411e89,0x1958000d,0x00000000}},	//   ygl_, yeli, лацы_,
  { {0xfc67005a,0x7e6d0019,0x229202f7,0x00000000}},	//   _съмн, ljap, rški_,
  { {0x44e91e8a,0xb5fd00c3,0x64411e8b,0x00000000}},	//   _sú_, ljši, veli,
  { {0x7f3c0047,0x7be3005b,0x64411e8c,0x00000000}},	//   געהו, ştuğ, weli,
  { {0xb5fd00c3,0x26c3001c,0xc9870001,0x00000000}},	//   njši, ējo_, _суви,
  { {0x99840032,0x62841e8d,0x44e90013,0x00000000}},	//   _الكو, _slio, _vú_,
  { {0x4615006a,0x200a00c3,0x62841e8e,0x00000000}},	//   _نوار, vabi_, _plio,
  { {0x44e9018d,0xc5d5019d,0xa5f90001,0x00000000}},	//   _tú_, _кіль, _реду_,
  { {0x273100aa,0x22421609,0x200a002c,0x00000000}},	//   _hơn_, rekk_, tabi_,
  { {0xe3b0006a,0x0574005d,0x251a009d,0x00000000}},	//   _کره_, _دامد, _יונא,
  { {0x200a05c9,0x672308f0,0xd0071e8f,0x00000000}},	//   rabi_, nunj, ресе_,
  { {0x62840009,0x200a1e90,0x66c510fd,0x00000000}},	//   _ulio, sabi_, ióko,
  { {0x6146000a,0xb2bb0165,0xee370001,0x00000000}},	// [2e00] _тепа, _במקר, јну_,
  { {0xcc87000d,0x6723017e,0x3e7c004c,0x00000000}},	//   абуе_, kunj, _míti_,
  { {0x69c90089,0x6723017e,0x0b460cdf,0x00000000}},	//   _azee, junj, рнен,
  { {0x533600b5,0xb4c10053,0xba170044,0x00000000}},	//   ינען_, ंतु_, ليما_,
  { {0x656f00bd,0x66c500ea,0xe6da0014,0x00000000}},	//   ächl, tókn, ðsíð,
  { {0x57f30dd5,0x6abb00ac,0xfb26007e,0x00000000}},	//   општ, _ekuf, _پرسپ,
  { {0x61e401e3,0xa7b81485,0x2731008b,0x00000000}},	//   _ogil, ылку_, _cơn_,
  { {0x66c50026,0x2baf0042,0x22820046,0x00000000}},	//   sókn, _जुटा, _sókn_,
  { {0x54b80062,0x320b1e91,0xe5c60121,0x00000000}},	//   лгия_, vacy_, шско,
  { {0x6723017f,0x14180021,0x44380014,0x00000000}},	//   bunj, ديدة_, ýr_,
  { {0x69c01e92,0x94730044,0x88bb009a,0x00000000}},	//   _hyme, تديا, _יזמי,
  { {0x9f610003,0x442a0022,0x69c00050,0x00000000}},	//   _épée_, żb_, _kyme,
  { {0xe2980088,0x320b1e93,0x3254000d,0x00000000}},	//   раў_, racy_, цвяр,
  { {0x4035005e,0x61e41e94,0xdfa702d8,0x00000000}},	//   љевс, _egil, ајбо,
  { {0xcebb0001,0xddc4003d,0xddc60051,0x00000000}},	//   вља_, ndiņ, _nakł,
  { {0x33db0063,0x6e640054,0x6d58008f,0x00000000}},	//   _בחוד, отуж, āvan,
  { {0xe1ff1795,0x629d1e95,0x7e6d01a9,0x00000000}},	// [2e10] mbó_, miso, rjap,
  { {0xfd4d00aa,0x6aa900d1,0xc1bc0063,0x00000000}},	//   _khoả, _sjef, _במחש,
  { {0x69c01e96,0x629d1098,0xf092009d,0x00000000}},	//   _ayme, oiso, _זני_,
  { {0x69c000e8,0x67230035,0x6d4b0014,0x00000000}},	//   _byme, vunj, ægas,
  { {0x69c00185,0x2731008b,0xe9471e97,0x00000000}},	//   _cyme, _sơn_, рхео,
  { {0x6c850021,0x67231e98,0x629d1e99,0x00000000}},	//   _السم, tunj, hiso,
  { {0x3e7c0080,0x80380041,0x629d1e9a,0x00000000}},	//   _síti_, ינגע_, kiso,
  { {0x9aa5006a,0x629d0035,0x7ae00006,0x00000000}},	//   _امرو, jiso, _gimt,
  { {0xddc60045,0x69c00185,0xddc4004c,0x00000000}},	//   _zakł, _gyme, ojiš,
  { {0xd8740032,0x61e4001f,0x67231e9b,0x00000000}},	//   _والب, _sgil, punj,
  { {0xdb1c1e9c,0xe3b10021,0x58ba0041,0x00000000}},	//   _pyré, ثرة_, _עמעצ,
  { {0x22920066,0x216a0e82,0xeb3a0041,0x00000000}},	//   yšku_, гими_, נערש,
  { {0x68e102ab,0xe297007f,0x68e9004d,0x00000000}},	//   _kild, сая_, _jued,
  { {0x629d1e9d,0xd4660062,0xa4d40054,0x00000000}},	//   aiso, _гише_, _дочі,
  { {0xf1bf00ea,0x629d1e9e,0x61e91e9f,0x00000000}},	//   lgál_, biso, žela,
  { {0x681b003d,0x673c00fe,0x629d1ea0,0x00000000}},	//   lādē, _ärje, ciso,
  { {0x7ae00006,0x7afb003b,0x2292004c,0x00000000}},	// [2e20] _rimt, _ăuta, ušku_,
  { {0xcb6a0001,0x7ae91ea1,0x2292007d,0x00000000}},	//   лазе_, _četr, ršku_,
  { {0xb5fd00c3,0x60db0063,0x394d1ea2,0x00000000}},	//   ljšu, _תקינ, _ases_,
  { {0x68e1001f,0x7f3b0047,0x68e901e1,0x00000000}},	//   _aild, _געטו, _bued,
  { {0x39130086,0x68e11ea3,0xb5fd00c2,0x00000000}},	//   змір, _bild, njšu,
  { {0xbcfb0026,0x96f8000d,0x69c0027d,0x00000000}},	//   _bréf, аект_, _vyme,
  { {0xb21b0146,0xd6d00032,0xbb860021,0x00000000}},	//   mhæv, وقت_, _الأي,
  { {0xdd080024,0x994c0024,0x567800a0,0x00000000}},	//   _môže, môže_, рбия_,
  { {0xc9aa0088,0xd5ba0be6,0x68e1011d,0x00000000}},	//   _свае_, ыск_, _fild,
  { {0x68e1007a,0x629d001f,0x44fb00be,0x00000000}},	//   _gild, wiso, _dª_,
  { {0x66c500ea,0x629d0ece,0xa5bd0078,0x00000000}},	//   iókj, tiso, ngųj,
  { {0xc879003b,0x25a90130,0xe1d90054,0x00000000}},	//   _ruşi_, _žale_, идні_,
  { {0xe1ff1ea4,0x75d6007e,0x25ab0066,0x00000000}},	//   rbó_, _ايشا, čilú_,
  { {0xfd4d008b,0xc879003b,0xcff40062,0x00000000}},	//   _thoả, _puşi_, зпръ,
  { {0x66d50006,0xe7f00053,0xb21b01e1,0x00000000}},	//   _iškr, _चलना_, dhæv,
  { {0xc3330041,0x6e9408ac,0x82a4007b,0x00000000}},	//   _זוק_, пису, _најж,
  { {0xcc990138,0xe29f007a,0xcc75005e,0x00000000}},	// [2e30] авац_, mið_, огаћ,
  { {0xe29f007a,0x68e9006d,0x5c740054,0x00000000}},	//   lið_, _rued, плут,
  { {0xa0360063,0x68e91ea5,0x41b5007e,0x00000000}},	//   _ואתה_, _sued, _دمکر,
  { {0x68e90814,0x66f1003d,0xe29f0026,0x00000000}},	//   _pued, _nāka, nið_,
  { {0x68e91ea6,0x68e11ea7,0xa96908ef,0x00000000}},	//   _qued, _pild, рила_,
  { {0xbcfb0164,0xaf34006a,0x26c40a02,0x00000000}},	//   _préf, _بریت, elmo_,
  { {0xe29f007a,0x3ea91ea8,0x907c0047,0x00000000}},	//   kið_, onat_, רטוי,
  { {0x68e9001f,0x3ea91ea9,0x66e20062,0x00000000}},	//   _tued, nnat_, моща,
  { {0x394d0034,0x68e105dd,0x30e30047,0x00000000}},	//   _uses_, _tild, _שריפֿ,
  { {0x9f880026,0xa4d6005e,0xe29f0014,0x00000000}},	//   kóða_, одњу_, eið_,
  { {0xb8df016a,0xe29f007a,0x9f880026,0x00000000}},	//   ीत_, fið_, jóða_,
  { {0xe29f007a,0x6d5d1eaa,0x6d4f1eab,0x00000000}},	//   gið_, _orsa, _osca,
  { {0xa5091857,0xd176000d,0x3ea91eac,0x00000000}},	//   _тела_, цыны, dnat_,
  { {0xcfaa0021,0x39400058,0x3e7c0014,0x00000000}},	//   لازم_, çisi_, _lítt_,
  { {0x6d4f1ead,0x78a40139,0x6d5d1eae,0x00000000}},	//   _asca, éivi, _arsa,
  { {0x3ea90268,0xd5f90047,0xe8df008d,0x00000000}},	//   gnat_, שפּר, _baịo_,
  { {0x660b000f,0x3ce30122,0x61f600c7,0x00000000}},	// [2e40] _megk, _bijv_, _ifyl,
  { {0x660b00ea,0xa7fc005b,0x6d5d00c2,0x00000000}},	//   _legk, _anın, _drsa,
  { {0x6d5d089f,0x6d4f03e1,0x9b1a005d,0x00000000}},	//   _ersa, _esca, شتاز_,
  { {0xfaa31eaf,0x00000000,0x00000000,0x00000000}},	//   махо,   ,   ,
  { {0x82d70047,0xbcfb1eb0,0xb21b01e1,0x00000000}},	//   קונג_, _créd, phæv,
  { {0x3ea01eb1,0x66f1001c,0x66c5013d,0x00000000}},	//   liit_, _sāka, lókh,
  { {0x8cb90042,0xa3de0042,0x00000000,0x00000000}},	//   ्तरो, _दृढ_,   ,
  { {0xbcfb04d4,0x9f58006d,0x7bce003b,0x00000000}},	//   _fréd, laró_, _izbu,
  { {0x94aa000a,0x95d7005a,0x442e1eb2,0x00000000}},	//   итоа_, одът_, _pcf_,
  { {0x3ea91eb3,0x3ead01b3,0x7afe00d1,0x00000000}},	//   znat_, četi_, oppt,
  { {0xe29f007a,0xbcfb0c77,0x69c600d1,0x00000000}},	//   tið_, _trég, _økeb,
  { {0x556600de,0x00000000,0x00000000,0x00000000}},	//   _وهاك,   ,   ,
  { {0xe29f0ac6,0x3ea91260,0x3ea0004b,0x00000000}},	//   rið_, vnat_, diit_,
  { {0xe29f0026,0x648d0025,0xf8ca0053,0x00000000}},	//   sið_, _cúid, ितिय,
  { {0xc058019d,0x64481eb4,0x3f85004a,0x00000000}},	//   ція_, medi, álu_,
  { {0x442c0122,0x82f7007e,0xe29800e1,0x00000000}},	//   lgd_, _بروز_, _мај_,
  { {0x442c006f,0x3ea91eb5,0x2d580121,0x00000000}},	// [2e50] ogd_, rnat_, оить_,
  { {0xebc70001,0x64481eb6,0x442c1eb7,0x00000000}},	//   ољен, nedi, ngd_,
  { {0x442c006f,0x6448006f,0x3ea90137,0x00000000}},	//   igd_, iedi, pnat_,
  { {0x20110117,0xbcfb1eb8,0xe8df008d,0x00000000}},	//   lazi_, _préd, _taịo_,
  { {0x6d5d00bd,0x2900003b,0x660b1eb9,0x00000000}},	//   _ursa, ţian_, _regk,
  { {0x64480117,0xbcfb03b2,0x6f150022,0x00000000}},	//   jedi, _crée, oszc,
  { {0x6d4d0122,0x6e2d0290,0x64481eba,0x00000000}},	//   lwaa, ogab, dedi,
  { {0x442c006f,0x915e0013,0x657d05e7,0x00000000}},	//   egd_, hắc_, øsho,
  { {0x6e2d1ebb,0x6d4d0717,0x20111ebc,0x00000000}},	//   igab, nwaa, kazi_,
  { {0x442c0137,0x660b0760,0xbcfb006c,0x00000000}},	//   ggd_, _wegk, _grée,
  { {0xe7f00053,0xe3b9005e,0x6f150022,0x00000000}},	//   _चलता_, сбн_, jszc,
  { {0x442c016d,0x6d4d1ebd,0x395f08f2,0x00000000}},	//   agd_, kwaa, _krus_,
  { {0x6f150045,0x6464000c,0x6d4d00ca,0x00000000}},	//   eszc, _ştiţ, jwaa,
  { {0x6448156f,0x6d4d1031,0x6723007d,0x00000000}},	//   cedi, dwaa, ornj,
  { {0x6e2d00bd,0x6d4d0229,0x7529003b,0x00000000}},	//   fgab, ewaa, luez,
  { {0xa7fc005b,0xa2060121,0x6d4d0229,0x00000000}},	//   _anıl, _эпид, fwaa,
  { {0x6d4d0438,0x9f58032a,0xa0a60002,0x00000000}},	// [2e60] gwaa, taró_, _наид,
  { {0x3137014e,0x66f1001c,0xddcb005b,0x00000000}},	//   _צריך_, _nāko, şişl,
  { {0x307b014e,0x395f053b,0x6e2d004d,0x00000000}},	//   _האינ, _arus_, bgab,
  { {0x62861ebe,0x66c50014,0xe9da0121,0x00000000}},	//   nkko, bóki, бке_,
  { {0xb9e30086,0x9f58006d,0x628600fe,0x00000000}},	//   ніши, paró_, ikko,
  { {0x7d161ebf,0xcee9005d,0x6aab0740,0x00000000}},	//   msys, _درین_, angf,
  { {0xa7370021,0x7bce007d,0x64481ec0,0x00000000}},	//   كثير_, _uzbu, vedi,
  { {0xd90d007e,0x6448001f,0x98ac0058,0x00000000}},	//   _چین_, wedi, ılıp_,
  { {0x644801f7,0x7d161ec1,0x201102cc,0x00000000}},	//   tedi, nsys, yazi_,
  { {0x7ce90006,0x442c006f,0x6f150051,0x00000000}},	//   _užre, ugd_, yszc,
  { {0x442c006f,0x6d4d006f,0x64481ec2,0x00000000}},	//   rgd_, zwaa, redi,
  { {0x64481ec3,0xa25b0164,0x201102ae,0x00000000}},	//   sedi, plôm, wazi_,
  { {0xd6270086,0x64481b69,0x20111ec4,0x00000000}},	//   _хоче_, pedi, tazi_,
  { {0x7d161ec5,0x44f2002b,0x62861ec6,0x00000000}},	//   dsys, _iâ_, akko,
  { {0x543b00b5,0x2fc50146,0x201102e2,0x00000000}},	//   _לעגא, ælg_, razi_,
  { {0x6d4d006f,0x6f150022,0x62861ec7,0x00000000}},	//   twaa, rszc, ckko,
  { {0x20110290,0x6aa21c6c,0xa7fc0058,0x00000000}},	// [2e70] pazi_, diof, _anım,
  { {0x6d4d0ac8,0x6e2d00bd,0x787d0164,0x00000000}},	//   rwaa, sgab, _lèvr,
  { {0x2900000c,0x6d4d0f5e,0x6e2d008f,0x00000000}},	//   ţial_, swaa, pgab,
  { {0x67230198,0x7aee0268,0x66f1003d,0x00000000}},	//   vrnj, _dubt, _sāko,
  { {0x6d4d0089,0x224b030c,0x2d4d007d,0x00000000}},	//   qwaa, ieck_, _uže_,
  { {0xccf20063,0xba77007e,0xbcfb0b6c,0x00000000}},	//   _בכך_, _کاست, _tréb,
  { {0xe7391ec8,0xe7fe0042,0x00000000,0x00000000}},	//   цей_, _उभरा_,   ,
  { {0x61e9027c,0x05650076,0xbcfb1ec9,0x00000000}},	//   želj, двин, _gréc,
  { {0xb3450016,0x395f0228,0x648d0025,0x00000000}},	//   _opçã, _urus_, _núic,
  { {0xb21b0583,0x628d01cf,0x69c604aa,0x00000000}},	//   skæl, _alao, _økea,
  { {0xdc380047,0xa2670078,0x8c1a009a,0x00000000}},	//   לאזט_, _dėžę_, חותי,
  { {0x78a300fe,0xd29a0086,0x11d60086,0x00000000}},	//   linv, ітні_, дігр,
  { {0x6286024a,0x752904a6,0x78a301f4,0x00000000}},	//   rkko, quez, oinv,
  { {0x62860004,0x7d1617d5,0xc4db005e,0x00000000}},	//   skko, vsys, _уђе_,
  { {0xae7a0121,0x224b1eca,0xf486005d,0x00000000}},	//   осах_, beck_, _زاوی,
  { {0xee3a0088,0x92b60032,0x628d0025,0x00000000}},	//   ўна_, _تحتا, _glao,
  { {0x78a31ecb,0x7aee1ecc,0x7afc005f,0x00000000}},	// [2e80] kinv, _subt, _strt,
  { {0x79820035,0x7d161ecd,0x70770044,0x00000000}},	//   vyow, rsys, _يميز_,
  { {0xbcfb03b2,0x7d1602e0,0xbb4a01f3,0x00000000}},	//   _préc, ssys, تلان_,
  { {0x8b650032,0x49ca05bd,0x1e831ece,0x00000000}},	//   عالم, олен_, _алюм,
  { {0xd910007e,0x7d030062,0x7bc70046,0x00000000}},	//   ایط_, _изяж, _eyju,
  { {0x787d1ecf,0xa9670121,0x91bb009d,0x00000000}},	//   _sèvr, ьича_, חמני,
  { {0x93bc003b,0x212b0022,0x00000000,0x00000000}},	//   ngăt, zuch_,   ,
  { {0xdb0e0051,0x96341ed0,0x78a30050,0x00000000}},	//   _wybó, хниц, ainv,
  { {0xfaa30001,0x61e91ed1,0xd44a012c,0x00000000}},	//   _рато, želk, оянд_,
  { {0xb21b00b9,0x5454000d,0x224b004d,0x00000000}},	//   rkæm, хвот, weck_,
  { {0x224b004d,0xd251002a,0x7d0b013d,0x00000000}},	//   teck_, هند_, ágsz,
  { {0x6d460146,0x68e81ed2,0xddcd003b,0x00000000}},	//   _opka, _hidd, njaţ,
  { {0x656f00bd,0x93bc000c,0x224b1ed3,0x00000000}},	//   ächt, egăt, reck_,
  { {0x68e81ed4,0x557700b5,0x212b0221,0x00000000}},	//   _jidd, _קעגן_, ruch_,
  { {0x212b00bd,0x6d460df9,0x68e807f3,0x00000000}},	//   such_, _apka, _midd,
  { {0x65621ed5,0x68e81ed6,0x443e1ed7,0x00000000}},	//   _kroh, _lidd, lft_,
  { {0x7bca00bd,0x61ed0019,0x64581ed8,0x00000000}},	// [2e90] üfun, _igal, _kavi,
  { {0xbcfb03b2,0x443e00bd,0x61fa0080,0x00000000}},	//   _créa, nft_, ětle,
  { {0xbcfb0027,0x661d00eb,0x9be4000d,0x00000000}},	//   _dréa, ųski, віцк,
  { {0x69dd01d1,0x80ad0042,0x64581ed9,0x00000000}},	//   _úsek, ँचवे, _lavi,
  { {0xbcfb0025,0xdb1c0114,0x78a31eda,0x00000000}},	//   _fréa, _vyrá, tinv,
  { {0xbcfb0027,0x443e0122,0x68e8005b,0x00000000}},	//   _gréa, jft_, _cidd,
  { {0x68e80185,0x69c600d1,0x78a31edb,0x00000000}},	//   _didd, _øken, rinv,
  { {0x443e1edc,0x68e8001f,0xca240121,0x00000000}},	//   eft_, _eidd, _аффи,
  { {0x443e1edd,0x68e81ede,0x64581edf,0x00000000}},	//   fft_, _fidd, _bavi,
  { {0xe1fa0161,0x656200bd,0x61ed1ee0,0x00000000}},	//   ूर्ण_, _droh, _agal,
  { {0x53c90086,0x7ae90006,0x64581ee1,0x00000000}},	//   ягом_, _kiet, _davi,
  { {0x7e7d001c,0x656f00bd,0xb607000d,0x00000000}},	//   _nosp, ächs, _цяжк,
  { {0xe5690062,0x65621ee2,0xdce7004c,0x00000000}},	//   _хилд_, _groh, áměs,
  { {0x61ed1ee3,0x7ae91ee4,0x645812d0,0x00000000}},	//   _egal, _liet, _gavi,
  { {0xb4cb0053,0xf8b20063,0x7e7d1ee5,0x00000000}},	//   लती_, אשם_, _bosp,
  { {0x7e7d1ee6,0x7ae91ee7,0x645804d9,0x00000000}},	//   _cosp, _niet, _zavi,
  { {0xbcfb1ee8,0x7e7d1ee9,0x753b1eea,0x00000000}},	// [2ea0] _préa, _dosp, ntuz,
  { {0xe0d204f6,0x765900f6,0x6ab80053,0x00000000}},	//   _حزب_, _lawy, इक्र,
  { {0xa09b0047,0x7ae90321,0xcb090086,0x00000000}},	//   _זייט, _biet, дхід_,
  { {0x68e81eeb,0xc3320063,0x69c900ac,0x00000000}},	//   _sidd, רוא_, _byee,
  { {0x64430051,0x7ae91eec,0x443e0026,0x00000000}},	//   _obni, _diet, yft_,
  { {0x7d041eed,0x00000000,0x00000000,0x00000000}},	//   mpis,   ,   ,
  { {0x7ce90006,0x7d041eee,0x64581eef,0x00000000}},	//   _užra, lpis, _ravi,
  { {0xddcd017f,0x656204a3,0xd6d708a6,0x00000000}},	//   ljaš, _proh, нты_,
  { {0x7ae30173,0xddcd085a,0x65940ada,0x00000000}},	//   ïnte, ojaš, тапу,
  { {0xd91b014e,0x64a30001,0x443e00bd,0x00000000}},	//   _מומל, лања, uft_,
  { {0xa2950086,0x443e1ef0,0x22950ac5,0x00000000}},	//   вані, rft_, виня,
  { {0xda100161,0x6458075a,0x65621ef1,0x00000000}},	//   ारित_, _wavi, _troh,
  { {0xd251006a,0x51870088,0x443e00bd,0x00000000}},	//   هنگ_, хуна, pft_,
  { {0x7e7d1ef2,0x7d041ef3,0x648d0139,0x00000000}},	//   _sosp, dpis, _húin,
  { {0x6e671ef4,0xbcfb0003,0x4fe80121,0x00000000}},	//   нтаж, _crén, емён_,
  { {0x61ed1ef5,0x66c5013d,0xd13b066f,0x00000000}},	//   _ugal, lókr, _ехо_,
  { {0xd904007e,0xac271ef6,0x648d0139,0x00000000}},	// [2eb0] _دی_, ефек, _múin,
  { {0xd1400051,0x7ae91ef7,0x22b6001c,0x00000000}},	//   żący_, _siet, māka_,
  { {0x22b6001c,0x7ae91ef8,0x7d041ef9,0x00000000}},	//   lāka_, _piet, apis,
  { {0xe9f80054,0xc333009d,0x00000000,0x00000000}},	//   енці_, טוע_,   ,
  { {0x273a0122,0x69c600d1,0xddcd007d,0x00000000}},	//   eën_, _økel, bjaš,
  { {0x2ca50014,0x07a51efa,0xd8220363,0x00000000}},	//   _öld_, калн, адши,
  { {0x6b8300c7,0x648d0026,0x7ae91efb,0x00000000}},	//   ängd, _búin, _tiet,
  { {0xdddd003d,0x22b6001c,0x648d0139,0x00000000}},	//   _nosū, kāka_, _cúin,
  { {0x648d0027,0x765b0e6f,0xf5050094,0x00000000}},	//   _dúin, rduy, ъзпо,
  { {0xb4cb0053,0x753b1efc,0x66c50014,0x00000000}},	//   लते_, rtuz, tóks,
  { {0x7d040c22,0x648d0139,0xb7670054,0x00000000}},	//   zpis, _fúin, _ятай,
  { {0xddcd0b59,0x3dc60022,0x7d041efd,0x00000000}},	//   zjaš, żowi_, ypis,
  { {0x660908a4,0xe2971efe,0x22b6008f,0x00000000}},	//   mbek, тая_, gāka_,
  { {0xbcfb0003,0x66090170,0x93bc003b,0x00000000}},	//   _prén, lbek, rgăr,
  { {0xc059000d,0x3f8c0114,0x12aa0021,0x00000000}},	//   хіў_, ádu_, _يدعى_,
  { {0x7d04017f,0xe3e80047,0xbcfb1eff,0x00000000}},	//   tpis, _אַפֿ, _créo,
  { {0x7bd5051e,0xee370062,0x1ea90021,0x00000000}},	// [2ec0] _azzu, ънт_, رافي_,
  { {0x0cbe0161,0x7d04003e,0x64411f00,0x00000000}},	//   ्तेम, rpis, nfli,
  { {0x2018173f,0x26df0078,0x6441004d,0x00000000}},	//   mari_, kmuo_, ifli,
  { {0xca75000d,0x20181f01,0xfa89013c,0x00000000}},	//   лучы, lari_, нсій_,
  { {0xdb0e00c7,0x66091f02,0xc02f0013,0x00000000}},	//   _nybö, dbek, _điếu_,
  { {0x66d50006,0xd90d007e,0x75291f03,0x00000000}},	//   _išky, سیم_, drez,
  { {0x20180268,0xdb1c16af,0x22b6001c,0x00000000}},	//   iari_, _byrå, zāka_,
  { {0x201813dc,0x3eb21f04,0x6b83089f,0x00000000}},	//   hari_, nnyt_, änge,
  { {0xd9460138,0x20181f05,0xa3e40053,0x00000000}},	//   _јези, kari_, पेन_,
  { {0xb8f60235,0x3eb200fe,0x20181894,0x00000000}},	//   सत_, hnyt_, jari_,
  { {0x5334000d,0x20181f06,0x75291f07,0x00000000}},	//   ыент, dari_, arez,
  { {0x26cd1095,0x20131f08,0x558a06be,0x00000000}},	//   cleo_, _sexi_, _обем_,
  { {0x2018077d,0x75291f09,0x2499008f,0x00000000}},	//   fari_, crez, ūsma_,
  { {0x20181f0a,0xf3660f55,0x9f350454,0x00000000}},	//   gari_, _атин, легі,
  { {0xbcfb0003,0x22b6001c,0x78ad0003,0x00000000}},	//   _préo, sāka_, éavi,
  { {0x20181a61,0x26c41f0b,0xceb8005e,0x00000000}},	//   aari_, nomo_, вљу_,
  { {0x20180009,0x3f9e0014,0xf1bf009c,0x00000000}},	// [2ed0] bari_, útur_, rgás_,
  { {0x66090035,0x653b0063,0x20181f0c,0x00000000}},	//   zbek, ועמד, cari_,
  { {0x752900b2,0x6ce40054,0x26c41f0d,0x00000000}},	//   zrez, ріте, komo_,
  { {0x3e04005a,0xddcd0080,0x7d280058,0x00000000}},	//   _вярв, zdař, ürsü,
  { {0x6b830137,0x3ea91f0e,0x26c41f0f,0x00000000}},	//   ängb, miat_, domo_,
  { {0x7c870818,0x4759042c,0x08c401dd,0x00000000}},	//   _руме, ерия_, абін,
  { {0x46a5005a,0x648d0025,0xf6510021,0x00000000}},	//   лакв, _dúil, مئة_,
  { {0x75291f10,0x8579000a,0x3ea9145f,0x00000000}},	//   trez, есот_, niat_,
  { {0xd41517ab,0x2018053a,0x66091f11,0x00000000}},	//   льны, yari_, rbek,
  { {0x13090055,0x75291f12,0x478b005a,0x00000000}},	//   нной_, rrez, _осем_,
  { {0x3eb2024a,0x26cd006d,0x20181f13,0x00000000}},	//   ynyt_, pleo_, vari_,
  { {0xbcfb0164,0x26c41f14,0x20181f15,0x00000000}},	//   _prél, como_, wari_,
  { {0xe56e0138,0x3ea91f16,0x20181f17,0x00000000}},	//   _уз_, diat_, tari_,
  { {0x291d0150,0x291f05b3,0xbcfb0003,0x00000000}},	//   iswa_, _mvua_, _crém,
  { {0x20181f18,0x3ea91f19,0x212b1f1a,0x00000000}},	//   rari_, fiat_, arch_,
  { {0x20181f1b,0x22b6008f,0x22920066,0x00000000}},	//   sari_, māko_, yšky_,
  { {0x8d661485,0xbcfb0003,0x22b6001c,0x00000000}},	// [2ee0] ывае, _frém, lāko_,
  { {0x26c40035,0x219b009f,0xeb9a0fc3,0x00000000}},	//   zomo_, _נביא, низ_,
  { {0x26c40009,0x3ea90089,0x0c370021,0x00000000}},	//   yomo_, biat_, اكمة_,
  { {0x3ea91f1c,0x648d0139,0x7e5601ce,0x00000000}},	//   ciat_, _súil, _стоц,
  { {0x2292004c,0x38140085,0xa9671f1d,0x00000000}},	//   ušky_, амлё, лица_,
  { {0x61d70063,0x6e360078,0xdca601ce,0x00000000}},	//   נוסף_, lgyb, _саги,
  { {0x26c41f1e,0x37a70062,0x38cb007e,0x00000000}},	//   tomo_, лтън_, راهی_,
  { {0x212b001f,0x2120027c,0x7f3b0047,0x00000000}},	//   yrch_, _ovih_, געקו,
  { {0x7afb00c2,0x3f8a01c2,0x44f40141,0x00000000}},	//   _čuti, hybu_, јпос,
  { {0x44380199,0x26c40035,0xb9930021,0x00000000}},	//   ür_, somo_, _الكب,
  { {0x22b6008f,0x212b002b,0xa2b50e82,0x00000000}},	//   gāko_, wrch_, ибоч,
  { {0x92580076,0x6b8101a8,0x7ae2136f,0x00000000}},	//   гают_, _àlge, nmot,
  { {0x3ea90994,0x212b00bd,0xa507005e,0x00000000}},	//   viat_, urch_, _беча_,
  { {0xe3a4007e,0x3ea90051,0x22b6001c,0x00000000}},	//   _پشتی, wiat_, bāko_,
  { {0x7ae200c7,0x9295000d,0x22b6008f,0x00000000}},	//   kmot, _вайц, cāko_,
  { {0x5e58019d,0x25a9007d,0x201e0014,0x00000000}},	//   лися_, _žali_, ótir_,
  { {0x3ea91f1f,0xfc670062,0xbcfb1f20,0x00000000}},	// [2ef0] riat_, лъжн, _trém,
  { {0x3ea91f21,0xe1ff1f22,0x7ae21f23,0x00000000}},	//   siat_, lcó_, emot,
  { {0x75eb000f,0xef670062,0x3ea91f24,0x00000000}},	//   _közü, _съпо, piat_,
  { {0x628f006f,0xe1ff006d,0xeaae0086,0x00000000}},	//   nkco, ncó_, ій_,
  { {0x224900f3,0x3eb9006f,0xfe360047,0x00000000}},	//   _mbak_, _ijst_, _דארך_,
  { {0xd7050062,0xf77100f2,0x7ae21f25,0x00000000}},	//   азки, قاب_, amot,
  { {0xdd0e0058,0x10380041,0x66f1008f,0x00000000}},	//   _kışl, אטום_, _nākt,
  { {0x31690045,0xa3de0080,0x22b6001c,0x00000000}},	//   _oraz_, _běží_, vāko_,
  { {0x98750086,0xef190022,0x60c71f26,0x00000000}},	//   _клац, ąży_, kojm,
  { {0x66f1003d,0xbcfb0003,0x2613008b,0x00000000}},	//   _sāku, _préj, ảo_,
  { {0x21200117,0xe3b10021,0x798b001f,0x00000000}},	//   _svih_, ترة_, lygw,
  { {0x91e61527,0x61fa004c,0x22b6008f,0x00000000}},	//   ионе, ětlo, rāko_,
  { {0x6f050025,0x661b00fe,0x51ba082d,0x00000000}},	//   _athc, mauk, тыня_,
  { {0x7ae214ba,0x859a0063,0x661b1f27,0x00000000}},	//   zmot, _בשנו, lauk,
  { {0x44fb021f,0x2376007e,0xa067005e,0x00000000}},	//   _hê_, _نمود_, јаса_,
  { {0x44fb001b,0x75eb005b,0x7bce002b,0x00000000}},	//   _kê_, _gözü, _rybu,
  { {0xdd0e005b,0x6e361f28,0x7eba0078,0x00000000}},	// [2f00] _dışl, rgyb, gįpa,
  { {0x6e36001f,0x44fb1f29,0x6d56002b,0x00000000}},	//   sgyb, _mê_, rwya,
  { {0x907b0063,0x66f1001c,0x44fb1f2a,0x00000000}},	//   _סטטי, _māks, _lê_,
  { {0x6b8300c7,0x7bce0240,0x661b1f2b,0x00000000}},	//   änga, _vybu, jauk,
  { {0x7bce0051,0x88e6047e,0x09b00053,0x00000000}},	//   _wybu, ажде, जपेय,
  { {0x99150088,0x66f1008f,0x7ae21f2c,0x00000000}},	//   сьці, _nāks, smot,
  { {0x7c47013d,0x78aa1f2d,0x7ae2059f,0x00000000}},	//   ésrő, rifv, pmot,
  { {0x62840290,0x44fb1f2e,0x661b05b5,0x00000000}},	//   _noio, _bê_, gauk,
  { {0x66f1001c,0x245b0006,0xa5070002,0x00000000}},	//   _sākt, kšmė_, аења_,
  { {0x44fb1f2f,0x07a61f30,0x75eb0058,0x00000000}},	//   _dê_, _казн, _sözü,
  { {0x2bf70063,0x57fb0149,0x8c1b0063,0x00000000}},	//   ימין_, _סלאו, כויי,
  { {0x661b0150,0x44fb017d,0x15460054,0x00000000}},	//   cauk, _fê_, _ведм,
  { {0x628f006f,0xe1ff0118,0xddd60022,0x00000000}},	//   rkco, rcó_, ndyń,
  { {0xe1ff1f31,0x160e0042,0xd59b009a,0x00000000}},	//   scó_, सरकर_, _שֹׁכ,
  { {0x60c70024,0x31690051,0x4ea71cb9,0x00000000}},	//   rojm, _wraz_, араа,
  { {0x3169017d,0xf1a70f8d,0xf2390094,0x00000000}},	//   _traz_, _врон, _спиш_,
  { {0x44fb0013,0x7c070044,0xd657009a,0x00000000}},	// [2f10] _xê_, لباك, סימת_,
  { {0xcc740138,0x7055006a,0xb035005e,0x00000000}},	//   огућ, _اندا, _унош,
  { {0x07f20047,0x9f58004c,0x7a41013d,0x00000000}},	//   _װאָס_, obrý_, játó,
  { {0x99d90021,0x66020023,0xdfd10043,0x00000000}},	//   هواء_, _nfok, _ويک_,
  { {0x661b0ab6,0x644a0022,0xe9460043,0x00000000}},	//   vauk, _obfi, مروی,
  { {0x88c8019d,0xfc67005a,0x31580047,0x00000000}},	//   алів_, _тъмн, יידן_,
  { {0x44fb00e8,0x661b00fe,0xbb850021,0x00000000}},	//   _sê_, tauk, _الزي,
  { {0x66f1001c,0xbcfb0003,0xd7f10013,0x00000000}},	//   _sāks, _préh, _mãi_,
  { {0x05680079,0xa3e4024c,0x6aa90035,0x00000000}},	//   ајќи_, पेस_, _imef,
  { {0x661b003d,0x44fb1f32,0xbcfb00cd,0x00000000}},	//   sauk, _vê_, _créi,
  { {0x661b00fe,0x97a7000d,0x44fb001f,0x00000000}},	//   pauk, _трал, _wê_,
  { {0xc7b20063,0x44fb1f33,0x6d5d1f34,0x00000000}},	//   _צבא_, _tê_, _ossa,
  { {0xd6c6006a,0xe3b1007e,0x7522007d,0x00000000}},	//   _امنی, ترک_, _gvoz,
  { {0xbcfb0025,0xa06a0001,0xb97a0063,0x00000000}},	//   _gréi, ћава_, אנשי,
  { {0xf8520066,0xb21b01e1,0xdfd2013a,0x00000000}},	//   ážiť_, rkær, سير_,
  { {0xb21b0146,0xee370782,0xed5a137c,0x00000000}},	//   skær, йнс_, лоб_,
  { {0x6cd60021,0x44270089,0xf1a9007e,0x00000000}},	// [2f20] مقرا, _kdn_, _پايه_,
  { {0x8db50086,0x4c83019c,0xcc290021,0x00000000}},	//   істі, плув, لأمم_,
  { {0x6d5d1f35,0x0b461518,0xeb2a0131,0x00000000}},	//   _essa, снен, ужел_,
  { {0x8aa50054,0x98b9008f,0xfe94005d,0x00000000}},	//   орід, _īsā_, _بیرج,
  { {0x823b0047,0xda650067,0x44270130,0x00000000}},	//   רענצ, تالي, _odn_,
  { {0x3cf10024,0x6c860021,0x7e64004e,0x00000000}},	//   ľovú_, _الآم, ldip,
  { {0x9f58006d,0x6d441f36,0xeb9a0854,0x00000000}},	//   mbró_, ltia, _сив_,
  { {0xddcd005b,0x7e641f37,0x4427146d,0x00000000}},	//   ndaş, ndip, _adn_,
  { {0x6d441d23,0x7a4100ea,0x661d0014,0x00000000}},	//   ntia, sátó, ðska,
  { {0x6d440025,0x00000000,0x00000000,0x00000000}},	//   itia,   ,   ,
  { {0x6d441169,0x6c7b0041,0x0ec80042,0x00000000}},	//   htia, אריד, लवाड,
  { {0x6d441f38,0x51870002,0xa6e6030b,0x00000000}},	//   ktia, буга, _ужел,
  { {0xe2980088,0xbcfb0025,0xd7f10013,0x00000000}},	//   саў_, _tréi, _rãi_,
  { {0x201a0150,0x1394030b,0x7ff40044,0x00000000}},	//   _cepi_, _милю, كسفا,
  { {0x6d440397,0x7ce9005f,0x5f940299,0x00000000}},	//   etia, _užri, пирт,
  { {0xb3b7009a,0xbd450044,0xda0a0082,0x00000000}},	//   _לפוג_, ينزي, हुमत_,
  { {0x98ba0042,0x5ed400de,0x00000000,0x00000000}},	// [2f30] ेवाए, ستفز,   ,
  { {0x9f550699,0xd0110044,0x5478009d,0x00000000}},	//   _двоч, _تلد_, סְּנ,
  { {0xd9f90fec,0x6d441f39,0x9b590854,0x00000000}},	//   анец_, atia, риет_,
  { {0x4ee4000d,0x6d4400a4,0x7055007e,0x00000000}},	//   _ніяз, btia, _انگا,
  { {0xa9240086,0x27330013,0x20040022,0x00000000}},	//   зділ, ọng_, śmie_,
  { {0x1869000a,0x20030045,0x9f580290,0x00000000}},	//   раки_, ncji_, mbrò_,
  { {0x7d0d04b1,0x9b090063,0xcb340062,0x00000000}},	//   lpas, _כִּ֥, _неръ,
  { {0x44271f3a,0x6aa90035,0xdd090066,0x00000000}},	//   _sdn_, _umef, _môžt,
  { {0x20030045,0x7d0d1f3b,0x94790690,0x00000000}},	//   kcji_, npas, асну_,
  { {0x8d5c0063,0x395f1f3c,0x22b6008f,0x00000000}},	//   רכזי, _isus_, māki_,
  { {0x22b6008f,0xdb1f0137,0xbcfb006c,0x00000000}},	//   lāki_, _övär, _grév,
  { {0x7d0d0150,0x68fb0213,0x201a1f3d,0x00000000}},	//   kpas, _kuud, _sepi_,
  { {0xa193000d,0x7649002b,0x68fb0bda,0x00000000}},	//   даўч, mfey, _juud,
  { {0x68fb0004,0xa06a0088,0x7649002b,0x00000000}},	//   _muud, шага_, lfey,
  { {0x6b830502,0x7d0d1f3e,0x6d44002b,0x00000000}},	//   ängl, epas, wtia,
  { {0x61f60307,0x2733008b,0x6d441f3f,0x00000000}},	//   _ugyl, ạng_, ttia,
  { {0x7d0d00bb,0x201a0397,0x6496000c,0x00000000}},	// [2f40] gpas, _tepi_, _mâin,
  { {0xd00a0001,0x6d441f40,0x7649002b,0x00000000}},	//   _њене_, rtia, hfey,
  { {0x7d0d1f41,0x395f004b,0x6d441f42,0x00000000}},	//   apas, _asus_, stia,
  { {0x7d0d00be,0x298a137a,0x5aca05ac,0x00000000}},	//   bpas, исло_, шлем_,
  { {0xc9830076,0x18740726,0x7649001f,0x00000000}},	//   дущи, згля, dfey,
  { {0xf72a0076,0xbcfb1db1,0x96f80062,0x00000000}},	//   аций_, _prév, бект_,
  { {0x7bdc001c,0xab271f43,0xdce40078,0x00000000}},	//   _uzru, _мора_, nvič,
  { {0x6496003b,0x7649001f,0x22b6008f,0x00000000}},	//   _câin, gfey, bāki_,
  { {0x20030051,0x26d8008f,0x7e9b0149,0x00000000}},	//   ycji_, ēro_, יסקו,
  { {0x60c20027,0xbcfb1f44,0x3946143b,0x00000000}},	//   _íomh, _trév, mtos_,
  { {0xc6060088,0xa3e40161,0x39461f45,0x00000000}},	//   _дзей, पें_, ltos_,
  { {0x92940088,0x69c600d1,0xdce400a8,0x00000000}},	//   даюц, _økes, dvič,
  { {0x39461f46,0x506706be,0x7d020025,0x00000000}},	//   ntos_, отва, íosl,
  { {0x39461f47,0x2733008b,0x2a641f48,0x00000000}},	//   itos_, ụng_, _lamb_,
  { {0xa295000d,0xeeab0d62,0x20030022,0x00000000}},	//   _накі, атак_, rcji_,
  { {0xc3330063,0x539b0063,0x9df9065b,0x00000000}},	//   _חוק_, _כיוו, снат_,
  { {0x3ebe0026,0x20030051,0x7d0d1f49,0x00000000}},	// [2f50] étta_, pcji_, upas,
  { {0xc0580086,0x68fb0659,0x22590b1b,0x00000000}},	//   _дію_, _ruud, lesk_,
  { {0x68fb1f4a,0x7afc02ed,0x7d0d1f4b,0x00000000}},	//   _suud, _curt, spas,
  { {0x68fb0004,0x6738007d,0x7d0d1f4c,0x00000000}},	//   _puud, duvj, ppas,
  { {0xa9691f4d,0xbcfb0153,0x39460a10,0x00000000}},	//   сила_, _crét, gtos_,
  { {0xe9d80088,0x7afc1729,0x22b6001c,0x00000000}},	//   цкі_, _furt, rāki_,
  { {0x661d0026,0x6496003b,0x7afc0e16,0x00000000}},	//   ðsko, _pâin, _gurt,
  { {0xbcfb007a,0xba770067,0x629d0078,0x00000000}},	//   _frét, _باست, ūroj,
  { {0x39461f4e,0x395f08a4,0x7649002b,0x00000000}},	//   ctos_, _usus_, rfey,
  { {0x7afc0058,0x7649002b,0x656908f3,0x00000000}},	//   _yurt, sfey, rveh,
  { {0x69c600d1,0x35f501ce,0x69b10082,0x00000000}},	//   _øker, _епер, _आइडी,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x6b830137,0x21391f4f,0x1016046e,0x00000000}},	//   ängj, gush_, зьбя,
  { {0xd0070076,0x648d0139,0x38670137,0x00000000}},	//   зере_, _cúit, ndnr_,
  { {0x394600ea,0xc059000d,0xdee61f50,0x00000000}},	//   ztos_, ціў_, зови,
  { {0x39460006,0x21391f51,0x531a0041,0x00000000}},	//   ytos_, bush_, _פופצ,
  { {0xf5390024,0x3946141f,0x7afc00e9,0x00000000}},	// [2f60] nuť_, xtos_, _surt,
  { {0xe1ff006d,0x7afc1f52,0xc173069a,0x00000000}},	//   ndón_, _purt, _נחת_,
  { {0xbcfb0164,0x6ffb009a,0xef94005d,0x00000000}},	//   _brés, _להיפ, _غیرد,
  { {0xbcfb0164,0xdb23004c,0x8a030062,0x00000000}},	//   _prét, írán, езце,
  { {0x64960003,0x7afc1dba,0x39461f53,0x00000000}},	//   _bâil, _wurt, utos_,
  { {0x7afc0498,0x39461f54,0x7e660137,0x00000000}},	//   _turt, rtos_, _hakp,
  { {0x22b6001c,0x39461f55,0x76aa0062,0x00000000}},	//   lāku_, stos_, йтив_,
  { {0xbddb0813,0xdb1c0051,0x39461f56,0x00000000}},	//   _ibèr, _wyró, ptos_,
  { {0x22b6008f,0xc9860021,0xf7f614d7,0x00000000}},	//   nāku_, _عشري, _فساد,
  { {0x7c3e1f57,0x00000000,0x00000000,0x00000000}},	//   ngpr,   ,   ,
  { {0x2ee9002b,0x62350f55,0x00000000,0x00000000}},	//   ymaf_, мену,   ,
  { {0x22b6001c,0x7e6600a4,0x648d0014,0x00000000}},	//   kāku_, _nakp, _búis,
  { {0x648d0025,0x5bb90053,0xa6e20046,0x00000000}},	//   _cúis, _आश्व, æðuh,
  { {0x212d02f4,0xa3b40086,0x22b6008f,0x00000000}},	//   šeho_, _облі, dāku_,
  { {0xa9230078,0x645a1f58,0x4fc4013f,0x00000000}},	//   ėžia, meti, еста,
  { {0x443e10eb,0x645a1f59,0x7c3e00ea,0x00000000}},	//   lgt_, leti, egpr,
  { {0x443e006f,0x648d0025,0x22b6008f,0x00000000}},	// [2f70] ogt_, _gúis, gāku_,
  { {0x67280117,0x3ea0002c,0x443e1f5a,0x00000000}},	//   _ovdj, ahit_, ngt_,
  { {0xbcfb03b2,0x9e150086,0x645a1f5b,0x00000000}},	//   _prés, _одні, ieti,
  { {0x7c3e00a4,0x22b6001c,0xd366007e,0x00000000}},	//   agpr, bāku_, _یه_,
  { {0xd914000d,0xbd6b0002,0x645a1f5c,0x00000000}},	//   едчы, _урне_, keti,
  { {0x443e0122,0x645a1f5d,0xddcd0022,0x00000000}},	//   jgt_, jeti, reań,
  { {0xbcfb0164,0xe8480044,0x67d20896,0x00000000}},	//   _trés, سجون_, кољу,
  { {0x22b6001c,0x443e1f5e,0xf5090456,0x00000000}},	//   nākt_, egt_, онил_,
  { {0xdddd0045,0x69c600d1,0xc8ab0062,0x00000000}},	//   _hasł, _økep, _лъже_,
  { {0x648d0025,0x443e0626,0x645a1f5f,0x00000000}},	//   _rúis, ggt_, geti,
  { {0x9c870080,0xe1ff006d,0x22b6001c,0x00000000}},	//   _začá, rdón_, zāku_,
  { {0x443e19c3,0xd5ae007e,0x648d0139,0x00000000}},	//   agt_, افی_, _cúir,
  { {0x9293000d,0x648d0025,0xf42901d5,0x00000000}},	//   таўц, _dúir, _долл_,
  { {0x645a1f60,0x7e6604aa,0x22b6008f,0x00000000}},	//   ceti, _sakp, vāku_,
  { {0x7e66002c,0xdddd0022,0x9e76005d,0x00000000}},	//   _pakp, _nasł, وهست,
  { {0x648d0025,0x22b6001c,0xdee30091,0x00000000}},	//   _túis, tāku_, воси,
  { {0x7e6600ac,0x3ea00104,0x6fe70003,0x00000000}},	// [2f80] _vakp, rhit_, técé,
  { {0xb21b00b9,0x61fa0080,0x22b6001c,0x00000000}},	//   hjæl, ětlu, rāku_,
  { {0x307b0063,0x7e6600a4,0x6fe70003,0x00000000}},	//   _ואינ, _takp, récé,
  { {0x22b6001c,0xeb970121,0x62861f61,0x00000000}},	//   māks_, ьих_, njko,
  { {0xbcfb0164,0x645a005b,0x22b6001c,0x00000000}},	//   _fréq, yeti, lāks_,
  { {0xb7bc008f,0x96f80f0a,0xddc6005f,0x00000000}},	//   _leģe, пект_, _lakū,
  { {0x22b6001c,0x645a1f62,0x36d40f34,0x00000000}},	//   nāks_, veti, нокр,
  { {0x7bc10078,0x98a60022,0xebe31f63,0x00000000}},	//   _žlug, kroć_, _росп,
  { {0xdddd0051,0xe4c60121,0x645a1f64,0x00000000}},	//   _zasł, дённ, teti,
  { {0x98af003b,0x443e030c,0x7d7b0aeb,0x00000000}},	//   rugă_, ugt_, קריג,
  { {0xb21b0146,0x6e24002c,0x443e1f65,0x00000000}},	//   bjæl, kaib, rgt_,
  { {0x6b830b64,0xdddd0066,0x645a0869,0x00000000}},	//   ängi, _hosť, seti,
  { {0x7c2e017f,0x65960242,0x22b6001c,0x00000000}},	//   _odbr, _تجار, vākt_,
  { {0xe3af04de,0x61f80088,0x69c5004d,0x00000000}},	//   اری_, ьняў_, ßhei,
  { {0xdfd8005a,0xdfd4000d,0x6e240003,0x00000000}},	//   дът_, воры, faib,
  { {0x656d0734,0xd5e20042,0x98a6056c,0x00000000}},	//   _šahi, _पराज, broć_,
  { {0xbcfb0003,0x6aa2004d,0x7c870121,0x00000000}},	// [2f90] _crép, dhof, муже,
  { {0x22b6183d,0x61e0005b,0xfc300044,0x00000000}},	//   sākt_, ümle, لحم_,
  { {0x290d003b,0x9f450072,0x5a350794,0x00000000}},	//   _stea_, älä_, енет,
  { {0x6aa2001f,0x6e241f66,0x9dab0062,0x00000000}},	//   ghof, caib, _дъга_,
  { {0x49b8006a,0xd5a60044,0x5a44014b,0x00000000}},	//   واهد_, _إف_, тэха,
  { {0xf09f01a8,0xd62202fe,0x2bbe0042,0x00000000}},	//   mpàs_, _цiка, ्थशा,
  { {0xe7390376,0x46f50071,0xcb440094,0x00000000}},	//   чей_, нчит, _ихти,
  { {0x05650138,0x6aa20035,0x7c251f67,0x00000000}},	//   евин, chof, lahr,
  { {0x5a44000d,0x22b6001c,0x04b502e4,0x00000000}},	//   _шэра, zāks_, есня,
  { {0xb21b00b9,0x7c251f68,0x6e24013d,0x00000000}},	//   sjæl, nahr, zaib,
  { {0x889a0063,0x5435005d,0x9f600075,0x00000000}},	//   _צבעי, ورگر, örür_,
  { {0x753b0035,0x22b6008f,0xc0490063,0x00000000}},	//   puuz, vāks_, _לז_,
  { {0x34950088,0xbddb0164,0xb7bc008f,0x00000000}},	//   _падр, _scèn, _veģe,
  { {0x7c25004d,0x22b6001c,0x09b6009a,0x00000000}},	//   jahr, tāks_, תפשט_,
  { {0xdfd20049,0x6609008f,0x6e24013d,0x00000000}},	//   ايز_, ocek, taib,
  { {0xbcfb0164,0x66091f69,0x64411f6a,0x00000000}},	//   _prép, ncek, lgli,
  { {0xed570079,0x7c250199,0xee370088,0x00000000}},	// [2fa0] нот_, fahr, энт_,
  { {0x64411f6b,0x6e24013d,0x44251f6c,0x00000000}},	//   ngli, saib, nal_,
  { {0x64411d60,0x20181f6d,0x44251f6e,0x00000000}},	//   igli, mbri_, ial_,
  { {0xca75000d,0xbcfb0003,0x44251f6f,0x00000000}},	//   кучы, _trép, hal_,
  { {0x44251f70,0x6aa21f71,0xe9800085,0x00000000}},	//   kal_, rhof, ралi_,
  { {0x7c2e0146,0x44251f72,0x6cd60021,0x00000000}},	//   _udbr, jal_, _أقسا,
  { {0x20180290,0x59dc0053,0xf0930063,0x00000000}},	//   ibri_, _बरकर, רנו_,
  { {0x7b06001c,0x76400014,0x61e41f73,0x00000000}},	//   ēstā, ugmy, _ozil,
  { {0x44251f74,0x442e1f75,0xfaa31849,0x00000000}},	//   fal_, _pdf_, _сато,
  { {0x1828006a,0x64411f76,0x44251c45,0x00000000}},	//   _آقای_, ggli, gal_,
  { {0x61e41f77,0x5c370047,0x3d170042,0x00000000}},	//   _azil, ערטן_, _पढ़ने_,
  { {0x64411f78,0x44251f79,0x752900a8,0x00000000}},	//   agli, aal_, bsez,
  { {0x44251121,0x7ebb0050,0x644e004e,0x00000000}},	//   bal_, häpä, õbis,
  { {0x32c4005b,0x44251f7a,0x656601e1,0x00000000}},	//   rıya_, cal_, ækhu,
  { {0x7ea30004,0xd4670001,0xdfd5026c,0x00000000}},	//   _lõpe, _чије_, товы,
  { {0x2ebd0161,0x7c2500bd,0x32c40058,0x00000000}},	//   ्केत, wahr, pıya_,
  { {0x661d0ac6,0x2d580055,0x20180290,0x00000000}},	// [2fb0] ðski, нить_, bbri_,
  { {0x6ac90053,0x2d87007d,0x212b00ca,0x00000000}},	//   िक्र, ćne_, msch_,
  { {0xf09f00cd,0x212b050c,0xc0520041,0x00000000}},	//   spàs_, lsch_, _דזי_,
  { {0x44251f7b,0xc5fe001c,0xc3330063,0x00000000}},	//   zal_, šējo_, רוף_,
  { {0x212b1f7c,0x44251f7d,0x7e7d1f7e,0x00000000}},	//   nsch_, yal_, _insp,
  { {0x6d4d002c,0x212b0221,0xf8ae007e,0x00000000}},	//   mtaa, isch_, يکل_,
  { {0xf892000a,0x6d4d1f7f,0x68fa01b0,0x00000000}},	//   рајќ, ltaa, _ditd,
  { {0x7e6d0e53,0x442511c4,0x6b831255,0x00000000}},	//   ndap, wal_, ängu,
  { {0x64410199,0x6d4d1f80,0x66091f81,0x00000000}},	//   tgli, ntaa, rcek,
  { {0xd90d006a,0x13090be6,0x64411f82,0x00000000}},	//   _هیچ_, мной_, ugli,
  { {0x6d4d00fe,0x75291f83,0x212b06aa,0x00000000}},	//   htaa, ssez, esch_,
  { {0xddc40529,0x6441001f,0x6d4d166f,0x00000000}},	//   ndiţ, sgli, ktaa,
  { {0x7afb000f,0x44250e57,0x06380044,0x00000000}},	//   _miut, pal_, _أسمع_,
  { {0x016300d7,0x7e7d1bf6,0x442500ac,0x00000000}},	//   јкро, _ansp, qal_,
  { {0x03a20086,0x6d4d1986,0x212b0244,0x00000000}},	//   _вищо, etaa, asch_,
  { {0x41b60021,0x6d4d00ac,0x7ae900d1,0x00000000}},	//   _لمعر, ftaa, _nhet,
  { {0x6d4d002c,0x6cd60032,0xf1aa0042,0x00000000}},	// [2fc0] gtaa, نقرا, _चेचन,
  { {0x7afb02f6,0xdd8f01fb,0x7e6d1f84,0x00000000}},	//   _aiut, غول_, adap,
  { {0x0a4a0088,0x6d4d1f85,0xcb090054,0x00000000}},	//   дзей_, ataa, ехід_,
  { {0x7afb0994,0x78a11f86,0x7ae91f87,0x00000000}},	//   _ciut, _allv, _chet,
  { {0xd9540032,0x7afb0397,0x7ceb00bd,0x00000000}},	//   انتخ, _diut, dürf,
  { {0x7ae3006f,0xf772002a,0xe8f70054,0x00000000}},	//   ïntr, لاع_, вніч_,
  { {0x6b830502,0x8a061f88,0xd7ef1f89,0x00000000}},	//   ängt, _азбе, ру_,
  { {0xe6cc0053,0x3ce60042,0x7ae90a04,0x00000000}},	//   ावेज, _जीते_, _ghet,
  { {0xceb3014e,0x27e51f8a,0x7bdc1f8b,0x00000000}},	//   ייה_, _ezln_, _hyru,
  { {0xb865006a,0x68fa0162,0xb4cc0053,0x00000000}},	//   _مامو, _uitd, लवे_,
  { {0xa2950097,0x83fc017f,0x387e000c,0x00000000}},	//   гані, jeđe, _intr_,
  { {0x26c00006,0x212b1f8c,0x98a600a8,0x00000000}},	//   čios_, tsch_, isoč_,
  { {0xe2980088,0x29040035,0x212b004d,0x00000000}},	//   таў_, _juma_, usch_,
  { {0x2ebd0053,0x212b1f8d,0x64a302d8,0x00000000}},	//   ्क्त, rsch_, _ваља,
  { {0x2904002c,0xff0403d6,0x9f050021,0x00000000}},	//   _luma_, иятн, اورو,
  { {0x6d4d024a,0x7e6d1f8e,0xde580054,0x00000000}},	//   ttaa, udap, касі_,
  { {0x29040016,0x7e6d0397,0x7afb07a0,0x00000000}},	// [2fd0] _numa_, rdap, _riut,
  { {0x6d4d1f8f,0x629d10da,0x63a50244,0x00000000}},	//   rtaa, lkso, _ühnc,
  { {0x7afb1f90,0x3f790047,0x6d4d1f91,0x00000000}},	//   _piut, _װאָס, staa,
  { {0x629d1f92,0x4ae4000d,0x6d4d1f93,0x00000000}},	//   nkso, аўча, ptaa,
  { {0x3a241f94,0x29041f95,0xb5fd0c6d,0x00000000}},	//   _demp_, _cuma_, neše,
  { {0x7ae90034,0xe8f80086,0x98e50021,0x00000000}},	//   _whet, влі_, دكتو,
  { {0x2249005b,0x00580063,0x7bdc1f96,0x00000000}},	//   _ocak_, דשות_, _gyru,
  { {0xdb24018d,0xd756006a,0x629d006f,0x00000000}},	//   _úsái, اليت_, jkso,
  { {0xb5fd007d,0xddc402f7,0x3ebe0014,0x00000000}},	//   ješe, odiš, étti_,
  { {0x2001008b,0xb5fd0253,0x8236007e,0x00000000}},	//   _nghi_, deše, گردا,
  { {0x9475006a,0x98af003b,0x29041f97,0x00000000}},	//   ندگا, argă_, _zuma_,
  { {0x7ceb004d,0xcad50063,0xaad30042,0x00000000}},	//   bürg, רוֹת_, तविक,
  { {0x661b076b,0xc5fe008f,0xe1ff013d,0x00000000}},	//   mbuk, ģēto_, deód_,
  { {0x55ba0063,0xddc400c2,0x3f98002b,0x00000000}},	//   _אמנו, jdiš, tyru_,
  { {0xf8b20063,0x2d8f0502,0x3f9e108f,0x00000000}},	//   משך_, ägen_, átu_,
  { {0x629d1f98,0x7ee30044,0xc7b2009d,0x00000000}},	//   ckso, مكّن, צבן_,
  { {0x83fc0117,0x3f9e1f99,0xc692069a,0x00000000}},	// [2fe0] ređe, štu_, זאן_,
  { {0xf06609e1,0x7bdc04ec,0x0c230330,0x00000000}},	//   _скоп, _pyru, ймун,
  { {0xa25b017d,0xddd40051,0x7ceb0058,0x00000000}},	//   inôn, _łańc, dürd,
  { {0x7524005b,0x094a0448,0xba450054,0x00000000}},	//   _çizg, ечки_, ихій,
  { {0x38a2007a,0x82d700b5,0x6b830137,0x00000000}},	//   _aðra_, נונג_, ängr,
  { {0x753b12bf,0x4b26002a,0x2ee00196,0x00000000}},	//   druz, _معرف, llif_,
  { {0x3a24055b,0xd6d0007e,0x69c5004d,0x00000000}},	//   _temp_, يقت_, ßher,
  { {0x29040009,0x6b8300c7,0x661b1f9a,0x00000000}},	//   _tuma_, ånge, gbuk,
  { {0xc0b3001b,0x7d061f9b,0x753b1f9c,0x00000000}},	//   gười_, _juks, gruz,
  { {0xd563011c,0x661b00a4,0x635419b6,0x00000000}},	//   стъп, abuk, авоу,
  { {0x2ee0005b,0x7d061be2,0x37e6030b,0x00000000}},	//   klif_, _luks, _сожг,
  { {0x52a70021,0x7ceb08af,0x66e31f9d,0x00000000}},	//   اصدق, pürg, _лоха,
  { {0xc05b019d,0x629d0307,0xe1ff0022,0x00000000}},	//   нів_, rkso, zdów_,
  { {0xef670062,0xdced0130,0x2ee00058,0x00000000}},	//   лъбо, tvač, elif_,
  { {0x9423005e,0x28970047,0xb5fd1f9e,0x00000000}},	//   _умје, נדלן_, reše,
  { {0x7d061f9f,0x6e20004b,0x8d8715ce,0x00000000}},	//   _buks, _õmbl, лузд,
  { {0xb5fd00c2,0x40351fa0,0x9df9019c,0x00000000}},	// [2ff0] peše, _кепс, тнат_,
  { {0x2a6d1fa1,0xadf41fa2,0x7ceb0075,0x00000000}},	//   _saeb_, спуш, küre,
  { {0x60fa0063,0x7ae3003b,0x70fa0063,0x00000000}},	//   _שהתק, înto, _שהתח,
  { {0x660200e8,0x19b90088,0x7ceb1fa3,0x00000000}},	//   _ngok, куль_, würd,
  { {0x3ea90d17,0xe1ff0051,0x64580513,0x00000000}},	//   mhat_, rdów_, _obvi,
  { {0x3ea900ea,0x7c871fa4,0xd9160044,0x00000000}},	//   lhat_, _суме, جيوش_,
  { {0x07a51fa5,0xc7a50062,0x2bc8007b,0x00000000}},	//   райн, рийк, _буто_,
  { {0x753b1fa6,0x661b002c,0x3ea91fa7,0x00000000}},	//   truz, ubuk, nhat_,
  { {0x661b08f0,0x3ea90150,0xca48007e,0x00000000}},	//   rbuk, ihat_, _حلقه_,
  { {0x753b097c,0xb4c10053,0xb9940021,0x00000000}},	//   rruz, ्के_, _الْب,
  { {0xa3ea016a,0xe2860793,0x7c27007d,0x00000000}},	//   _मरण_, ални, _mejr,
  { {0x25b6007e,0x7c2700b9,0x6d5d1fa8,0x00000000}},	//   اهید_, _lejr, _opsa,
  { {0x3ea900ea,0xcad60063,0x2d8f0989,0x00000000}},	//   dhat_, שורת_, ägel_,
  { {0x3ea900f3,0x7c270080,0xa06a0001,0x00000000}},	//   ehat_, _nejr, њава_,
  { {0x7d061fa9,0x6d5d13d0,0x44271faa,0x00000000}},	//   _suks, _apsa, _ien_,
  { {0xed5a0856,0x44271fab,0x7d06004b,0x00000000}},	//   коб_, _hen_, _puks,

  { {0x1d07005a,0x44271fac,0x25ad1fad,0x00000000}},	// [3000] иети_, _ken_, nzel_,
  { {0x44270080,0x3ea9002c,0x4c83000a,0x00000000}},	//   _jen_, ahat_, олув,
  { {0x3ea91fae,0x9f4c0072,0x44271aaf,0x00000000}},	//   bhat_, ädä_, _men_,
  { {0x44270024,0x3ea91faf,0x7d061fb0,0x00000000}},	//   _len_, chat_, _tuks,
  { {0x2d8f00b9,0x7c2700b9,0x3ebe0014,0x00000000}},	//   øget_, _fejr, éttu_,
  { {0xd7f1001b,0xddcd000c,0x44271fb1,0x00000000}},	//   _hãy_, leaş, _nen_,
  { {0x6d44003b,0xf727000d,0x07a302d8,0x00000000}},	//   luia, ацый_, жајн,
  { {0x3ea001b2,0x2733008b,0x442700ca,0x00000000}},	//   nkit_, ịnh_, _aen_,
  { {0x74c6005a,0x35f30062,0x6d441fb2,0x00000000}},	//   ищож, опър, nuia,
  { {0x3ea900ea,0x7ae21fb3,0x661d0014,0x00000000}},	//   zhat_, llot, ðskr,
  { {0x44271ea3,0x5c790047,0x7ae21fb4,0x00000000}},	//   _den_, אָרױ, olot,
  { {0x44271fb5,0x96070076,0x7ae2013d,0x00000000}},	//   _een_, _кэша_, nlot,
  { {0x3ea9013d,0x44271fb6,0x7cf00244,0x00000000}},	//   vhat_, _fen_, märf,
  { {0x3ea90034,0x3be60053,0x7cf00137,0x00000000}},	//   what_, _करूँ_, lärf,
  { {0x442c0029,0x3ea900ea,0x4343018e,0x00000000}},	//   mad_, that_, _дејв,
  { {0x7c2700b9,0x27e300b9,0x93fb0047,0x00000000}},	//   _sejr, _øjne_, _בלוי,
  { {0x27330013,0x6d441fb7,0x44271fb8,0x00000000}},	// [3010] ạnh_, guia, _yen_,
  { {0x442c1fb9,0x7ae21fba,0xb5fd00cc,0x00000000}},	//   nad_, elot, neša,
  { {0x7c270146,0xcb550001,0x644800a4,0x00000000}},	//   _vejr, свећ, igdi,
  { {0x2d8f00b9,0x7ceb00bd,0xbad80086,0x00000000}},	//   øges_, fürc, афії_,
  { {0x6d44003b,0x98dd000d,0x442c1fbb,0x00000000}},	//   cuia, нскi, kad_,
  { {0x442c0004,0x25ad00c3,0xb5fd017f,0x00000000}},	//   jad_, vzel_, ješa,
  { {0x442c1fbc,0xb5fd017f,0xccf20063,0x00000000}},	//   dad_, deša, _מכך_,
  { {0x4427024a,0x6e2d1fbd,0x442c1fbe,0x00000000}},	//   _sen_, naab, ead_,
  { {0xddc60198,0x442c1fbf,0x44271fc0,0x00000000}},	//   _kakš, fad_, _pen_,
  { {0x395f00cd,0xd469005e,0x442c1fc1,0x00000000}},	//   _ipus_, ћине_, gad_,
  { {0xa22a0076,0x6e2d1a61,0x44271fc2,0x00000000}},	//   лжна_, kaab, _ven_,
  { {0xddc61fc3,0x6448006f,0x442c1fc4,0x00000000}},	//   _lakš, agdi, aad_,
  { {0x44271fc5,0x83fc007d,0x6e2d004b,0x00000000}},	//   _ten_, ređa, daab,
  { {0x7cf00019,0x7649005b,0x7e200042,0x00000000}},	//   märg, lgey, बर्ग_,
  { {0x13a7005d,0x34920699,0x8fa31fc6,0x00000000}},	//   _خنثی_, _хајр, паре,
  { {0x6e2d00a4,0x539a0063,0x4226047e,0x00000000}},	//   gaab, _תיקו, _удив,
  { {0x3ea000fe,0x7e640006,0x51850002,0x00000000}},	// [3020] rkit_, reip, _дуќа,
  { {0x6e2d00a4,0x6d44003b,0x62960331,0x00000000}},	//   aaab, ruia, _hoyo,
  { {0x2d8f0146,0xe1ff0268,0xd24f007e,0x00000000}},	//   øger_, bdós_, _غنی_,
  { {0x6b8300c7,0x442c1fc7,0x1a2a0062,0x00000000}},	//   ånga, zad_, ужди_,
  { {0x442c00bb,0xb9560138,0x7cf00019,0x00000000}},	//   yad_, стећ, järg,
  { {0x7ae21fc8,0x307a00b5,0x7ea30019,0x00000000}},	//   slot, ראַנ, _lõpl,
  { {0x442c1fc9,0x628400e5,0x7ae21fca,0x00000000}},	//   vad_, _onio, plot,
  { {0x7cf00137,0x6296006c,0x442c1fcb,0x00000000}},	//   färg, _noyo, wad_,
  { {0xb21b069f,0x442c1fcc,0x142a0054,0x00000000}},	//   kjær, tad_, ліно_,
  { {0x442c0d4b,0x628419e7,0x3946005f,0x00000000}},	//   uad_, _anio, muos_,
  { {0x38ab0205,0x442c1fcd,0x62960150,0x00000000}},	//   _sørg_, rad_, _boyo,
  { {0xd62705fb,0x62840025,0x6569004d,0x00000000}},	//   _гоце_, _cnio, bweh,
  { {0x442c1fce,0x914b000d,0xb5fd0be1,0x00000000}},	//   pad_, ычна_, lešn,
  { {0x224d0051,0x39460006,0xb21b04aa,0x00000000}},	//   żek_, iuos_, gjær,
  { {0xdbf10080,0xe4570047,0x66110072,0x00000000}},	//   _přím, _ליגט_, _ähkö,
  { {0x39460078,0x7cf000a5,0xf8140022,0x00000000}},	//   kuos_, härd, ężyć_,
  { {0x6e940817,0x38ab01f2,0x5cb9000d,0x00000000}},	// [3030] читу, _høre_, алаў_,
  { {0x38ab0146,0x394604a6,0xa3cc0053,0x00000000}},	//   _køre_, duos_, _रखा_,
  { {0x62960009,0xce95011c,0x395f000c,0x00000000}},	//   _yoyo, _данъ, _spus_,
  { {0xdb0800ea,0x38ab05e7,0xc17f0078,0x00000000}},	//   álás, _møre_, _įėjo_,
  { {0xc7b8017f,0x394602dd,0xddc600c3,0x00000000}},	//   _među_, guos_, _takš,
  { {0x7cf01fcf,0x644e00cd,0x58d40363,0x00000000}},	//   gärd, òbil, почт,
  { {0x7ea3004b,0x76490046,0xa09c009a,0x00000000}},	//   _lõpm, tgey, ריוט,
  { {0x66f2018e,0x060905a1,0x78a80014,0x00000000}},	//   мпју, шник_, _eldv,
  { {0xf9930032,0x62960089,0x5fdb0053,0x00000000}},	//   _عبر_, _royo, _मुसल,
  { {0x6296066d,0x6569004d,0x7cf0004d,0x00000000}},	//   _soyo, rweh, rärg,
  { {0x61ed0792,0x62661527,0x65691fd0,0x00000000}},	//   _azal, овна, sweh,
  { {0x7cf0004d,0xe7300021,0xc7d60041,0x00000000}},	//   märe, _أصل_, _וועי_,
  { {0x62960164,0x7cf01fd1,0xe4c80043,0x00000000}},	//   _voyo, läre, شبین_,
  { {0x38ab0831,0x6aa9001f,0x62840051,0x00000000}},	//   _føre_, _llef, _wnio,
  { {0x62961fd2,0x38ab010a,0x9e960001,0x00000000}},	//   _toyo, _gøre_, ошаљ,
  { {0x62840305,0xf77207e9,0xb5fd1fd3,0x00000000}},	//   _unio, וקל_, nešo,
  { {0xe1ff006d,0xe5f60047,0xf8c80013,0x00000000}},	// [3040] león_, ַזער_, hứa_,
  { {0x61e4005b,0x39460078,0x9046005d,0x00000000}},	//   _iyil, vuos_, _بنده,
  { {0xbcfb03b2,0x7cf010b5,0x643a0047,0x00000000}},	//   _spéc, värd, שעענ,
  { {0x60dc185a,0xae5a0054,0x39461fd4,0x00000000}},	//   lorm, _троє_, tuos_,
  { {0x6aa21fd5,0x7cf00e77,0xbcfb013d,0x00000000}},	//   rkof, tärd, _csés,
  { {0x7cf00cbf,0x2d540019,0x98a303d6,0x00000000}},	//   färe, mäe_, миче,
  { {0xf09300b7,0xfaa6000d,0x291d00a4,0x00000000}},	//   ונג_, _даво, apwa_,
  { {0x60dc08f8,0xc6f8005e,0x38ab01e1,0x00000000}},	//   horm, љних_, _røre_,
  { {0xb7bc008f,0xe60f0044,0x0ae90044,0x00000000}},	//   _meģi, خشى_, _طرفي_,
  { {0x7cf00d88,0xd49a0076,0xddcd000c,0x00000000}},	//   lärb, рри_, ldaţ,
  { {0x64a30002,0x60dc1fd6,0x61ed1504,0x00000000}},	//   фаќа, dorm, _szal,
  { {0xddcd000c,0x5187005e,0x2bbd0053,0x00000000}},	//   ndaţ, оуга, ्पता,
  { {0x8afb0041,0x60dc1fd7,0xad9b013d,0x00000000}},	//   יפטק, form, _egúj,
  { {0x6ab70235,0x61ed01c8,0xf8bc0042,0x00000000}},	//   _आग्र, _vzal, ्चिय,
  { {0xcebb0001,0x09b70053,0x78800066,0x00000000}},	//   аља_, _अध्य, _závä,
  { {0x9d151fd8,0x645a1fd9,0x02940044,0x00000000}},	//   здач, lfti, _يؤيد,
  { {0x5fdb0042,0x60dc017c,0xf8bc0042,0x00000000}},	// [3050] _मुरल, borm, ्चाय,
  { {0x645a00bd,0xb5fd004c,0xe5710063,0x00000000}},	//   nfti, dešl, עַן_,
  { {0x7cf0004d,0xc052009a,0xf1c8011b,0x00000000}},	//   färb, _אזי_, rbář_,
  { {0x7cf001e9,0x8f880063,0x59750085,0x00000000}},	//   väre, _וְשֵ, зыку,
  { {0x0dc8000a,0xa924019d,0xddeb005d,0x00000000}},	//   _дури_, дділ, _خرده_,
  { {0x645a0122,0x61e0004d,0x27950cdf,0x00000000}},	//   jfti, ümli, зшир,
  { {0x24890013,0x4ac500de,0x00000000,0x00000000}},	//   _đam_, _فيسق,   ,
  { {0x3209001b,0x7cf0004d,0x645a1fda,0x00000000}},	//   _ngay_, räre, efti,
  { {0x645a0333,0x7cf01fdb,0x47d5005d,0x00000000}},	//   ffti, säre, _کيار,
  { {0xe719007e,0x7ceb0244,0x870702fa,0x00000000}},	//   _هيئت_, zürn, _дяде,
  { {0x3a2d04ff,0x6498005a,0x61e41fdc,0x00000000}},	//   _keep_, ютър_, _syil,
  { {0x216a0062,0x60dc0c5f,0x6d41008f,0x00000000}},	//   бими_, worm, _ālan,
  { {0x29050009,0xb7bc003d,0x6aaa0229,0x00000000}},	//   _kila_, _reģi, ëffi,
  { {0x2d540019,0x60dc0072,0xf9920063,0x00000000}},	//   väe_, uorm, תרך_,
  { {0x29051fdd,0x657b0014,0xa3de004c,0x00000000}},	//   _mila_, lvuh, _těší_,
  { {0x539a014e,0x60dc0164,0xf7720047,0x00000000}},	//   _ליצו, sorm, עקן_,
  { {0x60dc0273,0xdb0d0066,0xa1130044,0x00000000}},	// [3060] porm, ľkým, _كويت,
  { {0x2905002c,0x6d5600e5,0xf8a5007e,0x00000000}},	//   _nila_, rtya, _شک_,
  { {0x309b0063,0xda0a0021,0xa09b07e9,0x00000000}},	//   _השימ, مياه_, _הייט,
  { {0x7ceb1fde,0xed5a0782,0xaae60044,0x00000000}},	//   büro, _лом_, أسطو,
  { {0x3a2d0034,0xddcd003b,0x29051fdf,0x00000000}},	//   _deep_, rdaţ, _bila_,
  { {0x7ceb005b,0x63a10137,0x6e241fe0,0x00000000}},	//   nürl, kyln, lbib,
  { {0x29050da5,0x38cb007e,0x7c2e008f,0x00000000}},	//   _dila_, حانی_, _iebr,
  { {0x6e240396,0x7c2e1fe1,0x6d441fe2,0x00000000}},	//   nbib, _hebr, oria,
  { {0x29051fe3,0x9c8300c3,0x7ceb004d,0x00000000}},	//   _fila_, ščet, kürl,
  { {0x6d441142,0x29051496,0xa9230240,0x00000000}},	//   iria, _gila_, ážen,
  { {0x9956001c,0xe2f90086,0x7ceb0058,0x00000000}},	//   kļūt_, жені_, dürl,
  { {0x6d440006,0xa3bd0042,0x2905008f,0x00000000}},	//   kria, _इधर_, _zila_,
  { {0xc50a0032,0x51870138,0x867b014e,0x00000000}},	//   _اتصل_, чуна, _לראו,
  { {0x6d441fe4,0x7ceb005b,0x6e24006f,0x00000000}},	//   dria, gürl, ebib,
  { {0x6d441fe5,0x7127007e,0x4477009a,0x00000000}},	//   eria, _کربل, _מעגל_,
  { {0x6e2400bb,0xdce4017f,0x442e1fe6,0x00000000}},	//   gbib, dviđ, _hef_,
  { {0xcc990001,0x6d441fe7,0x1df80895,0x00000000}},	// [3070] овац_, gria, зеты_,
  { {0x6e2400a4,0x442e00ca,0x7c2e18fb,0x00000000}},	//   abib, _jef_, _cebr,
  { {0xdced017f,0x7c2e1fe8,0xf0920063,0x00000000}},	//   hvać, _debr, _סנט_,
  { {0x29051fe9,0xddcd007d,0x6d441fea,0x00000000}},	//   _sila_, adaš, bria,
  { {0x6d4412aa,0x2905185d,0x2ee9002b,0x00000000}},	//   cria, _pila_, mlaf_,
  { {0x7c2e1feb,0xe9d8000d,0x21780063,0x00000000}},	//   _gebr, чкі_, פתור_,
  { {0x6b830146,0x3f570003,0x29051fec,0x00000000}},	//   ængd, nçu_, _vila_,
  { {0xaa580138,0x7c250139,0x7c2e1fed,0x00000000}},	//   _нису_, lbhr, _zebr,
  { {0x29051fee,0x7cf0086f,0xa8550a74,0x00000000}},	//   _tila_, lära, _окач,
  { {0xb5fd027c,0x2ee9004d,0x03a50363,0x00000000}},	//   lešk, hlaf_, диоо,
  { {0xa91d0be1,0x657b078c,0x442e1fef,0x00000000}},	//   _drže, svuh, _def_,
  { {0x7d0702b0,0x442e006f,0x7c250025,0x00000000}},	//   _lijs, _eef_, hbhr,
  { {0x27e001f7,0x7ceb1fa3,0x3f570003,0x00000000}},	//   ğine_, türl, eçu_,
  { {0x1dd80161,0x6d4415b7,0x442e0014,0x00000000}},	//   _भुगत, vria, _gef_,
  { {0x7c2e0994,0x91030c09,0x6d44001f,0x00000000}},	//   _rebr, тпре, wria,
  { {0xb5fd007d,0x26cd1ff0,0x6d441ff1,0x00000000}},	//   ješk, nneo_, tria,
  { {0xed570079,0x7d070122,0x4425001f,0x00000000}},	// [3080] мот_, _bijs, obl_,
  { {0x1c39000d,0x6d441ff2,0x6f061ff3,0x00000000}},	//   зяць_, rria, _wikc,
  { {0x7cf001e3,0x660b00d1,0xbb8600de,0x00000000}},	//   gära, _oggk, بلاي,
  { {0x7c250139,0x7c2e1ff4,0x6d441ff5,0x00000000}},	//   abhr, _webr, pria,
  { {0x2d8f0137,0x7c2e005b,0xe7c30053,0x00000000}},	//   äget_, _tebr, _वेबप,
  { {0xab2a005a,0x61eb05b9,0x7cf00137,0x00000000}},	//   _мога_, _øgle, bära,
  { {0xb5fd00c2,0x8c4302d8,0xd83800a8,0x00000000}},	//   bešk, _јесе, _noče_,
  { {0x6b83010a,0x20070024,0x26cd0290,0x00000000}},	//   ænge, _únie_, gneo_,
  { {0xa91d0130,0xfcaa009a,0xb4460085,0x00000000}},	//   _prže, ַיֹּ, мэнк,
  { {0x83fc007d,0x75240058,0xa99b009a,0x00000000}},	//   leđi, _çizm, _ובמר,
  { {0x7eb10031,0xf7720021,0x442e0026,0x00000000}},	//   _håpe, _جاء_, _vef_,
  { {0xe5c61dd1,0x39461ff6,0x87b70041,0x00000000}},	//   _осло, oros_, _קלאס_,
  { {0xa91d0ae1,0x26c41488,0x7ceb004d,0x00000000}},	//   _trže, mimo_, würm,
  { {0x394603d9,0x26c40add,0x7ceb1b89,0x00000000}},	//   iros_, limo_, türm,
  { {0x7d07006f,0x7d0f01e1,0xe8ee0085,0x00000000}},	//   _rijs, _sucs, ылi_,
  { {0x3f570164,0x3f8102e2,0x26c41ff7,0x00000000}},	//   rçu_, _vrhu_, nimo_,
  { {0x2fdf0051,0xb5fd1253,0xf1a70086,0x00000000}},	// [3090] ług_, vešk, _ірин,
  { {0x26c41882,0x3f810240,0x2ee90474,0x00000000}},	//   himo_, _trhu_, slaf_,
  { {0x26c400eb,0x38ab0146,0x7c250025,0x00000000}},	//   kimo_, _børn_, rbhr,
  { {0x26c400eb,0x7d070122,0xdd9505ac,0x00000000}},	//   jimo_, _wijs, _замы,
  { {0xb5fd1ff8,0xe9ce1ff9,0x39461ffa,0x00000000}},	//   rešk, ук_, gros_,
  { {0x7b67005a,0x7cf01ffb,0x99d4007e,0x00000000}},	//   _отбе, pära, ختما,
  { {0xb5fd00c2,0xddcf003b,0xc8780058,0x00000000}},	//   pešk, _facţ, _dağ_,
  { {0x39461ffc,0x26c40006,0x4425001f,0x00000000}},	//   bros_, gimo_, wbl_,
  { {0x2f1502eb,0x26cd1ffd,0x39461ffe,0x00000000}},	//   _låg_, rneo_, cros_,
  { {0xb5fd00eb,0x7e6d0025,0xd838007d,0x00000000}},	//   neši, heap, _poče_,
  { {0xc2c60021,0x13e90076,0x3ea9005b,0x00000000}},	//   فيدي, ямой_, kkat_,
  { {0x7cf000c7,0xc5d501dd,0xeb920041,0x00000000}},	//   järn, _піль, אָש_,
  { {0x7e6d000c,0x9136000d,0xc8780058,0x00000000}},	//   deap, эхні, _yağ_,
  { {0xb5fd017f,0x6d4d0019,0x0ef80053,0x00000000}},	//   ješi, duaa, ंग्स_,
  { {0x7ea30004,0x645c0268,0xb5fd16fe,0x00000000}},	//   _lõpu, òrie, deši,
  { {0x3ea91fff,0x7eaa004a,0x7cf00137,0x00000000}},	//   gkat_, _výpo, gärn,
  { {0xac861a02,0xfd4a0085,0x4d4a0085,0x00000000}},	// [30a0] нгал, язак_, япан_,
  { {0x39460016,0x26c408ed,0x3ea92000,0x00000000}},	//   vros_, zimo_, akat_,
  { {0x291f017d,0x9057009a,0x2d8f0832,0x00000000}},	//   _atua_, _אביו_, äger_,
  { {0x39460747,0x3ea900c7,0x26c40fac,0x00000000}},	//   tros_, ckat_, ximo_,
  { {0xf5390024,0x83fc017f,0x9c8300c2,0x00000000}},	//   jsť_, ređi, ščat,
  { {0x20070268,0x7eb10031,0x39462001,0x00000000}},	//   _únic_, _våpe, rros_,
  { {0xf5390024,0x26c40aca,0x2d802002,0x00000000}},	//   esť_, timo_, lvie_,
  { {0x2b470080,0x39462003,0x2d802004,0x00000000}},	//   ánce_, pros_, ovie_,
  { {0x2d800016,0xceb30063,0x26c40aa6,0x00000000}},	//   nvie_, טיה_, rimo_,
  { {0x26c42005,0x2240053b,0xed570063,0x00000000}},	//   simo_, _adik_, עביר_,
  { {0x26c42006,0xf5390066,0xd6cf2007,0x00000000}},	//   pimo_, asť_, _бт_,
  { {0x7ae212f9,0x7ceb2008,0x5fdb0042,0x00000000}},	//   noot, türk, _मुगल,
  { {0x2f1502eb,0x7cf00137,0x64a62009,0x00000000}},	//   _såg_, värn, _пада,
  { {0x251b009f,0x7ae21b13,0x7ceb0075,0x00000000}},	//   _צווא, hoot, rürk,
  { {0x30a4005a,0x7e6d000c,0xdfd4000d,0x00000000}},	//   уряв, teap, горы,
  { {0x3ea9200a,0x2f150137,0x9f47004c,0x00000000}},	//   ukat_, _våg_, _ání_,
  { {0x628d0035,0x6c550076,0xdce40051,0x00000000}},	// [30b0] _inao, ккау, zwią,
  { {0x2f150137,0x8c44005e,0x3ea9200b,0x00000000}},	//   _tåg_, леђе, skat_,
  { {0x6e3600bb,0x6d4d021e,0xb5fd02f7,0x00000000}},	//   bayb, suaa, reši,
  { {0x9f960063,0x7ae20050,0xf8a90042,0x00000000}},	//   _סדרה_, goot, कस्प,
  { {0xa3de0080,0xf2d40047,0xe895030b,0x00000000}},	//   _věří_, װעס_, кадь,
  { {0xf745060e,0xf7710049,0x1866030b,0x00000000}},	//   веко, لاب_, ваши_,
  { {0xa91d06bb,0x6a15200c,0x7ae205be,0x00000000}},	//   _drža, _амбу, boot,
  { {0x67230130,0x05650121,0xddc4005f,0x00000000}},	//   rpnj, ввин, leiš,
  { {0x6827000d,0x7cf000a5,0xa92b014b,0x00000000}},	//   _зьез, kärl, _хібе_,
  { {0x27e0003b,0x9476007e,0xb4bd0053,0x00000000}},	//   şina_, ندپا, ीचे_,
  { {0x68e3200d,0x2d800066,0x21200130,0x00000000}},	//   mond, zvie_, _stih_,
  { {0x83fc007d,0x9f5e0066,0x68e3200e,0x00000000}},	//   jeđu, ätí_, lond,
  { {0x645c0268,0x6a3a0063,0x7cf00137,0x00000000}},	//   òric, וגרפ, färl,
  { {0x68e3200f,0x64a22010,0x753b0058,0x00000000}},	//   nond, _ваша, msuz,
  { {0xafe60065,0x753b0058,0x661b0058,0x00000000}},	//   товл, lsuz, ocuk,
  { {0x661b0397,0xee3a0002,0xd007005e,0x00000000}},	//   ncuk, ќна_, ђете_,
  { {0xe0da0259,0x68e32011,0x753b0058,0x00000000}},	// [30c0] _ови_, kond, nsuz,
  { {0x3137014e,0x2d802012,0x6e3608f2,0x00000000}},	//   _שנים_, rvie_, sayb,
  { {0xda7a0062,0x83fc007d,0x68e32013,0x00000000}},	//   дял_, beđu, dond,
  { {0xbb430076,0x0a6700e1,0x20070066,0x00000000}},	//   рецк, врши_, _únia_,
  { {0x7ae212bc,0xfaa30002,0x68e32014,0x00000000}},	//   root, јачо, fond,
  { {0x91bb0063,0x75240058,0xb5fd008f,0x00000000}},	//   ומני, _çizi, nešu,
  { {0x98a30001,0xb8ea0053,0x394f0023,0x00000000}},	//   рије, _लग_, augs_,
  { {0x7ceb004d,0x4420004c,0xfaa32015,0x00000000}},	//   fürw, _ři_, _касо,
  { {0xa91d00c2,0x68e32016,0x09062017,0x00000000}},	//   _trža, bond, _апан,
  { {0x7cf00137,0x68e304ca,0xb5fd0130,0x00000000}},	//   kärm, cond, ješu,
  { {0xb8f6016a,0x7cf00137,0xc4c6005d,0x00000000}},	//   ाच_, värl, فتگو,
  { {0xa91d007d,0xc6a30259,0x6aa006a5,0x00000000}},	//   _mržn, _врши, _jomf,
  { {0x61f60051,0xc05b0086,0x7ceb004b,0x00000000}},	//   _czyl, мів_, süri,
  { {0x38d4009a,0x00000000,0x00000000,0x00000000}},	//   אֵֽל_,   ,   ,
  { {0x290c2018,0x4034093e,0xcfa4018e,0x00000000}},	//   _mida_, ресс, ашти,
  { {0x68e30122,0x628d0009,0x290c2019,0x00000000}},	//   zond, _unao, _lida_,
  { {0x83fc017f,0xbdf5005e,0x68e3107b,0x00000000}},	// [30d0] ređu, упај, yond,
  { {0x6adb0161,0xb5fd017f,0x2075000d,0x00000000}},	//   यक्र, mešt, _слоў,
  { {0x68e302b0,0xddc40006,0xfbd00021,0x00000000}},	//   vond, reiš, يتم_,
  { {0x6aa0201a,0x68e30983,0x19f9000d,0x00000000}},	//   _comf, wond, нэль_,
  { {0xb5fd0006,0x4a440086,0x68e3201b,0x00000000}},	//   nešt, рнів, tond,
  { {0x63a800b9,0x68e30035,0x61ed0474,0x00000000}},	//   kydn, uond, _myal,
  { {0x57a40001,0xdce40051,0x68e3201c,0x00000000}},	//   ишћа, jwię, rond,
  { {0x7cf00d9e,0x68e3201d,0xf77001fb,0x00000000}},	//   järj, sond, تاه_,
  { {0xb5fd017f,0x68e309ed,0x61ed0150,0x00000000}},	//   ješt, pond, _nyal,
  { {0x38ab0093,0x7e7d0104,0x68e300ac,0x00000000}},	//   _mørk_, _lasp, qond,
  { {0x645c00cd,0x7e7d003b,0x61ed201e,0x00000000}},	//   òria, _oasp, _ayal,
  { {0x7e7d03f5,0x290c007d,0x85b9005e,0x00000000}},	//   _nasp, _zida_, _плес_,
  { {0x7cf0004d,0x15450699,0x45450021,0x00000000}},	//   wärm, _селм, _إنتق,
  { {0xdddd0045,0xf0d5000d,0x7c35201f,0x00000000}},	//   _obsł, аўсю, _nezr,
  { {0x644600eb,0x7afb0019,0x61ed005b,0x00000000}},	//   ėkit, _ohut, _eyal,
  { {0x7ea30019,0x7e7d2020,0x2eb50085,0x00000000}},	//   _sõpr, _casp, асус,
  { {0xde35000d,0x6aa02021,0x7c352022,0x00000000}},	// [30e0] рэсь, _romf, _bezr,
  { {0x7cf02023,0x7e7d0025,0xddc60114,0x00000000}},	//   märk, _easp, _takž,
  { {0x290c1a8a,0x0b460086,0x5f760049,0x00000000}},	//   _rida_, унен, _صادر,
  { {0x290c02eb,0xbae5019d,0xbddb00cd,0x00000000}},	//   _sida_, ацій, _idèn,
  { {0x9e63000d,0x5a330086,0x79c6000d,0x00000000}},	//   _увяд, сніт, ыйдз,
  { {0xa91d2024,0xf7720593,0x7e7d1c76,0x00000000}},	//   _tržn, ماع_, _zasp,
  { {0x69dc0045,0x290c2025,0xf6e6026b,0x00000000}},	//   _śred, _vida_, лцин,
  { {0x7afb0027,0x644300ea,0x1ab80042,0x00000000}},	//   _ghut, _adni, _आतिथ,
  { {0x45d40fe2,0x290c2026,0xbcfb0025,0x00000000}},	//   ропс, _tida_, _spéi,
  { {0xb5fd0117,0x7ea30004,0x63a80205,0x00000000}},	//   vešt, _lõpp, tydn,
  { {0x87260121,0x44f714d7,0x00000000,0x00000000}},	//   _смеж, دريج_,   ,
  { {0x64430384,0x63a8061f,0x171b009a,0x00000000}},	//   _edni, rydn, _נודע,
  { {0x7e7d2027,0xf4861915,0x63ba013d,0x00000000}},	//   _rasp, _буйн, sztn,
  { {0xe1ff013d,0xb5fd2028,0x7e7d008f,0x00000000}},	//   deót_, rešt, _sasp,
  { {0x7e7d0812,0x9f350054,0x7c352029,0x00000000}},	//   _pasp, ребі, _rezr,
  { {0x4ea40138,0x61ed00ac,0x9f5e0066,0x00000000}},	//   бруа, _tyal, ätá_,
  { {0xdd940076,0x7afb001f,0x7e7d202a,0x00000000}},	// [30f0] баты, _rhut, _vasp,
  { {0x7afb1568,0x7e7d202b,0x27e0004c,0x00000000}},	//   _shut, _wasp, řiny_,
  { {0xda15000a,0x7afb008d,0x7f95005e,0x00000000}},	//   адењ, _phut, _танх,
  { {0xa3c30080,0x78a1202c,0x8f9a0149,0x00000000}},	//   náší_, _solv, _סירי,
  { {0x6e2d202d,0x78a1202e,0xd90f005d,0x00000000}},	//   mbab, _polv, سیا_,
  { {0x07a5011c,0x6b8300c7,0x6e2d0370,0x00000000}},	//   иалн, ångs, lbab,
  { {0x78a1048e,0xdcef003b,0x6447006d,0x00000000}},	//   _volv, _escă, ójim,
  { {0x46a50612,0x78a119dd,0x7545202f,0x00000000}},	//   раив, _wolv, аниз,
  { {0x6d4d119d,0x6f0f2030,0x78a12031,0x00000000}},	//   nraa, _micc, _tolv,
  { {0x98f70021,0x629d0080,0xa5f60001,0x00000000}},	//   _إثرا, ejso, шењу_,
  { {0xf799005d,0xd3b90054,0x7ceb0058,0x00000000}},	//   _جناب_, тупі_, lürs,
  { {0x6f0f2032,0x8b080080,0x7cf00832,0x00000000}},	//   _nicc, mořá, tärk,
  { {0x7ceb0058,0x6d4d2033,0xa4d50054,0x00000000}},	//   nürs, jraa, _коді,
  { {0x6e2d0089,0x6d4d2034,0x75292035,0x00000000}},	//   ebab, draa, mpez,
  { {0x6f0f0290,0x2d8f0137,0x6d4d1986,0x00000000}},	//   _bicc, ågen_, eraa,
  { {0x6e2d00bb,0xddc60045,0x6f0f0a02,0x00000000}},	//   gbab, _takż, _cicc,
  { {0x3da7005a,0x6f0f2036,0x6281008f,0x00000000}},	// [3100] акто_, _dicc, ēlot,
  { {0x6e2d002c,0x8c4617f2,0x913b009a,0x00000000}},	//   abab, реже, _שעיק,
  { {0x6f0f2037,0x6ecc0058,0x7cf02038,0x00000000}},	//   _ficc, aşba, näri,
  { {0x8b230086,0x79892039,0x6d4d056f,0x00000000}},	//   ідче, _brew, braa,
  { {0x7cf0004d,0x3940203a,0x6d4d00ca,0x00000000}},	//   häri, éis_, craa,
  { {0x798912cc,0x7cf00072,0x4b260044,0x00000000}},	//   _drew, käri, _نعرف,
  { {0xd90d006a,0x6a960054,0xd6da1e7f,0x00000000}},	//   ریم_, _крає, кти_,
  { {0x2f1c00ea,0xa5340086,0xa9260156,0x00000000}},	//   _míg_, бнич, _вдал,
  { {0x6f04203b,0x9f600003,0x7989203c,0x00000000}},	//   imic, érêt_, _grew,
  { {0xd4060ac5,0xf8aa0042,0xc977009a,0x00000000}},	//   ияни, _कविय, _דגמי_,
  { {0x6f04074f,0xdddd001c,0xbddb12f7,0x00000000}},	//   kmic, _pasū, _adèl,
  { {0x20cd00eb,0x26c600a4,0xd62a05f4,0x00000000}},	//   džia_, _umoo_, _роде_,
  { {0x6f0f12c9,0x6f040ecf,0xd1380002,0x00000000}},	//   _ricc, dmic, ихр_,
  { {0x6d4d04c6,0x6f0f203d,0x14f3000d,0x00000000}},	//   vraa, _sicc, _дзіў,
  { {0x6f0f203e,0x3ec7000d,0x13a9007e,0x00000000}},	//   _picc, асаб, _منوی_,
  { {0x5eb40245,0xceb8005e,0x6d4d0d47,0x00000000}},	//   ойст, аљу_, traa,
  { {0x6e2d203f,0xe7ed0053,0xf1a4000d,0x00000000}},	// [3110] rbab, _चुना_, _дрэн,
  { {0x9f410072,0x6f0f2040,0x6d4d12f9,0x00000000}},	//   _pyhä_, _wicc, rraa,
  { {0x6d4d2041,0xdfd10044,0xbb1800de,0x00000000}},	//   sraa, _ريح_, لزنا_,
  { {0x38b90164,0x6e950754,0x6d4d0162,0x00000000}},	//   _mère_, _الحا, praa,
  { {0xa9c7000a,0xd838007d,0x200c004c,0x00000000}},	//   јсек, _beč_, ždit_,
  { {0x7ceb005b,0x1d160063,0xa3b60042,0x00000000}},	//   rürs, _לקשר_, छना_,
  { {0x4738000d,0x6e46013d,0xe0b8009a,0x00000000}},	//   ачыў_, _átbö, שלוט_,
  { {0x24890058,0x7cf02042,0x06820062,0x00000000}},	//   _şam_, väri, згън,
  { {0xe5710021,0xdb12013d,0xe6c400de,0x00000000}},	//   سطة_, ögöt, تتوي,
  { {0x8b080080,0x7cf01555,0x6f0408b7,0x00000000}},	//   pořá, täri, zmic,
  { {0x130a0076,0x7529051f,0xc209009a,0x00000000}},	//   лной_, spez, _נה_,
  { {0xfbd20063,0x7cf0004e,0x8704012c,0x00000000}},	//   לתי_, räri, _дяче,
  { {0xd4690fe2,0x2d8f0137,0x86c40049,0x00000000}},	//   _биле_, ågel_, _بينن,
  { {0xd7f1008b,0x7cf02043,0x60230867,0x00000000}},	//   _kỹ_, lärv, здра,
  { {0xf4120063,0x38b90003,0x2d8b0331,0x00000000}},	//   _צפה_, _gère_, _arce_,
  { {0xd7f1008b,0x16040053,0x20cd0066,0x00000000}},	//   _mỹ_, शेवर_, ržia_,
  { {0xddea006a,0xd2570063,0x6f040aca,0x00000000}},	// [3120] ارزه_, _השפה_, rmic,
  { {0xc5f20149,0xeb9a2044,0xed570f50,0x00000000}},	//   לדן_, лиз_, соф_,
  { {0x7f860032,0x9f5e00fe,0xd8380ecf,0x00000000}},	//   _الجن, ätä_, _reč_,
  { {0xd8380080,0x93bc000c,0x7cf02045,0x00000000}},	//   _seč_, mbăt, järv,
  { {0xe8380054,0x2fd7005d,0x00000000,0x00000000}},	//   аплі_, _نوید_,   ,
  { {0x3ea70529,0x48e3005a,0x4973000d,0x00000000}},	//   _într_, почв, яліс,
  { {0xd8380fbf,0xf1bf000f,0x6d561362,0x00000000}},	//   _več_, zzá_, luya,
  { {0xc6f80001,0xa6aa009e,0x7c3e1561,0x00000000}},	//   јних_, طابق_, lapr,
  { {0x54b80330,0xe9da2046,0xe8fa2047,0x00000000}},	//   игия_, _ска_, _бла_,
  { {0x38b903b2,0x443810c3,0xb5fd0066,0x00000000}},	//   _père_, úr_, rešp,
  { {0xd251006a,0x7e760026,0x25bf003b,0x00000000}},	//   وند_, keyp, azul_,
  { {0x6d5600bb,0xddcd003b,0x3f850026,0x00000000}},	//   kuya, neaţ, ælum_,
  { {0x9c830198,0x68ea0122,0x7cf000bd,0x00000000}},	//   ščit, oofd, läru,
  { {0x9a290013,0x661d0066,0xdb0d0066,0x00000000}},	//   _mươi_, ľske, ľkém,
  { {0xbcfb03b2,0x443e1f1f,0xaab80053,0x00000000}},	//   _opér, mat_, _आतंक,
  { {0x38ab06a5,0x443e2048,0xff072049,0x00000000}},	//   _hørt_, lat_, сягн,
  { {0x38ab00b9,0xf2d40047,0x9c39005e,0x00000000}},	// [3130] _kørt_, _מעק_, ипат_,
  { {0x6ef3005b,0x443e204a,0x645a204b,0x00000000}},	//   içbi, nat_, ngti,
  { {0x443e000c,0x645a00b9,0xea19204c,0x00000000}},	//   iat_, igti, ажеш_,
  { {0x443e204d,0xda650054,0x6008009a,0x00000000}},	//   hat_, івли, _לִרְ,
  { {0xd9450076,0x443e204e,0x7cf0204f,0x00000000}},	//   цели, kat_, värv,
  { {0xdcb10013,0xa7a92050,0x443e2051,0x00000000}},	//   _ổ_, икла_, jat_,
  { {0x3eb90026,0x443e2052,0x22492053,0x00000000}},	//   _klst_, dat_, _odak_,
  { {0x22490150,0x443e0770,0x85490a8f,0x00000000}},	//   _ndak_, eat_, азив_,
  { {0x443e1df0,0x93bc003b,0x39400014,0x00000000}},	//   fat_, zbăt, áist_,
  { {0xe4c5019d,0x20cd00eb,0x645a00d1,0x00000000}},	//   ійни, džio_, ggti,
  { {0x7cf000fe,0x7aeb006f,0x25bf013d,0x00000000}},	//   märt, oogt, szul_,
  { {0x645a2054,0xae090053,0x443e2055,0x00000000}},	//   agti, वधान_, aat_,
  { {0x443e2056,0x38ab06a5,0x672d007d,0x00000000}},	//   bat_, _ført_, ćaju,
  { {0x443e2057,0xbf020053,0x6b6c001c,0x00000000}},	//   cat_, लग्न_, lēgš,
  { {0x6d4b0025,0xa91d0648,0x3f8c0195,0x00000000}},	//   ágan, _drži, ídu_,
  { {0x93bc000c,0x7c3e0150,0xa91d0078,0x00000000}},	//   rbăt, wapr, _erži,
  { {0x62960273,0x27e001f7,0x7c3e2058,0x00000000}},	// [3140] _inyo, ğini_, tapr,
  { {0x93bc0529,0x62860004,0x62840035,0x00000000}},	//   mbăr, ldko, _haio,
  { {0x7c3e1605,0x6d56006c,0x7aeb013d,0x00000000}},	//   rapr, suya, fogt,
  { {0xd83800c2,0x6d560003,0x7c3e2059,0x00000000}},	//   _točk_, puya, sapr,
  { {0x628403d9,0x62960009,0x443e03f9,0x00000000}},	//   _maio, _mnyo, yat_,
  { {0x443e1f1c,0xc8660086,0xed4301dd,0x00000000}},	//   xat_, ітли, _інсп,
  { {0x6d44205a,0x501b014e,0x99490051,0x00000000}},	//   lsia, בוצו, góły_,
  { {0x356a0088,0x7c3c205b,0xd83800c3,0x00000000}},	//   арон_, _herr, _moči_,
  { {0x443e205c,0xd83800c2,0x7c3c205d,0x00000000}},	//   tat_, _loči_, _kerr,
  { {0x62960465,0xc9d5007e,0x6d44205e,0x00000000}},	//   _anyo, _عملک, isia,
  { {0x6d4400e3,0x69c2006f,0xd83800c2,0x00000000}},	//   hsia, lzoe, _noči_,
  { {0x6b830146,0x672d017f,0x443e2056,0x00000000}},	//   ængi, ćajt, sat_,
  { {0xf1c5016a,0x56d90047,0x443e035d,0x00000000}},	//   _लेखन, _פֿעד, pat_,
  { {0x6e24205f,0x84380021,0x443e0222,0x00000000}},	//   ecib, _اكثر_, qat_,
  { {0x6d460c4a,0x22560080,0x78a801e1,0x00000000}},	//   _avka, ácké_, _modv,
  { {0x443c2060,0x3f45001c,0x628400be,0x00000000}},	//   _hev_, rķu_, _gaio,
  { {0xa91d2061,0x7d550062,0x54fe0053,0x00000000}},	// [3150] _trži, явах, _उठाए_,
  { {0x7c3c2062,0xf1a4000d,0x69c2006f,0x00000000}},	//   _cerr, _ірын, dzoe,
  { {0x69c20122,0x7aeb00e8,0x7c3c100f,0x00000000}},	//   ezoe, togt, _derr,
  { {0x0f7a00b5,0x7cf02063,0x7055007e,0x00000000}},	//   _פארב, färs, _بنگا,
  { {0x7c3c2064,0x99d4007e,0x7aeb01e1,0x00000000}},	//   _ferr, وتها, rogt,
  { {0x88c80086,0x017c0063,0x3afc0014,0x00000000}},	//   олів_, שָׁל, rípa_,
  { {0xe7390055,0xdb23007e,0x7d1d2065,0x00000000}},	//   щей_, _آوری, _huss,
  { {0x7c3c0378,0x66de008f,0x69c200ca,0x00000000}},	//   _zerr, tīka, bzoe,
  { {0x7cf000fe,0x62842066,0x765b0058,0x00000000}},	//   märr, _raio, rguy,
  { {0x6aa90122,0x7d1d2067,0x7c3c01a8,0x00000000}},	//   _hoef, _muss, _xerr,
  { {0x6e3d00f5,0x7d1d2068,0x62842069,0x00000000}},	//   _oesb, _luss, _paio,
  { {0x6d44206a,0xe0c90047,0x7c250139,0x00000000}},	//   ysia, _גײ_, hchr,
  { {0x443c1560,0xa5f8005e,0x6286206b,0x00000000}},	//   _fev_, _децу_, rdko,
  { {0xa06a0001,0x5468000d,0x93bc003b,0x00000000}},	//   љава_, _маім_, rbăr,
  { {0xdfd20032,0x7d1d206c,0x6abb00ac,0x00000000}},	//   رير_, _auss, _oluf,
  { {0x6d440004,0x7d15003d,0x7b030019,0x00000000}},	//   tsia, _aizs, nõud,
  { {0x6d44206d,0x6e24206e,0xee37000d,0x00000000}},	// [3160] usia, rcib, янт_,
  { {0x6e24206f,0x64412070,0x22422071,0x00000000}},	//   scib, nali, lakk_,
  { {0x7d1d0164,0x64410035,0x7c3c13aa,0x00000000}},	//   _euss, iali, _verr,
  { {0x7b030019,0x69c2006f,0x64412072,0x00000000}},	//   jõud, tzoe, hali,
  { {0x64412073,0x4427001f,0x7d1d0206,0x00000000}},	//   kali, _ofn_, _guss,
  { {0x69c202b0,0x6f1e1c6b,0x64412074,0x00000000}},	//   rzoe, _kupc, jali,
  { {0x69c20122,0xf093014e,0x6aa900ac,0x00000000}},	//   szoe, תנו_, _foef,
  { {0x7d1d2075,0x44270014,0x443c008f,0x00000000}},	//   _yuss, _afn_, _sev_,
  { {0x64410739,0x7ae319ad,0x7eb8004c,0x00000000}},	//   fali, énte, _lípo,
  { {0x39462076,0x64412077,0xd49a0239,0x00000000}},	//   msos_, gali, сри_,
  { {0x99840006,0x38ab00d1,0xa279167b,0x00000000}},	//   _temų_, _tørr_, обну_,
  { {0x32670076,0x64412078,0xdbc7004b,0x00000000}},	//   чтов, aali, pöör,
  { {0x6441170b,0x6e3d18a7,0x443c001c,0x00000000}},	//   bali, _resb, _tev_,
  { {0x64a30088,0x644118f5,0x20cd004c,0x00000000}},	//   _пача, cali, mžik_,
  { {0x224200d1,0x7d1d1eec,0x2d8206a5,0x00000000}},	//   bakk_, _suss, _aske_,
  { {0x7c25002b,0x6727013d,0x7d150058,0x00000000}},	//   wchr, _éjje, _sizs,
  { {0x7b030019,0x6e3d00a8,0x7cf000a5,0x00000000}},	// [3170] nõue, _vesb, värr,
  { {0xad9b006d,0x91bc0063,0xc1bc0063,0x00000000}},	//   _azúc, _למחי, _למחש,
  { {0x7d1500ea,0x7d1d004d,0x7c252079,0x00000000}},	//   _vizs, _wuss, rchr,
  { {0x7c251a91,0x7d1d0102,0xc3330063,0x00000000}},	//   schr, _tuss, תוף_,
  { {0x6441207a,0x7b03004b,0x9c830445,0x00000000}},	//   yali, jõue, áčst,
  { {0xec290021,0x7c8401ce,0xb79501ce,0x00000000}},	//   _ذكرى_, _пусе, дрић,
  { {0x238c0080,0x6441207b,0x7cf00137,0x00000000}},	//   _něj_, vali, pärr,
  { {0xa562007e,0x20070066,0x6441207c,0x00000000}},	//   چگون, _úniu_, wali,
  { {0x26c30006,0xc6480021,0xa562007e,0x00000000}},	//   ėjo_, سجيل_, نگون,
  { {0x6441207d,0x3a3f00ca,0xf3490cb2,0x00000000}},	//   uali, _heup_, опол_,
  { {0x61f60072,0x96eb0121,0x6441207e,0x00000000}},	//   _syyl, _льда_, rali,
  { {0x216a0076,0xc0490ee1,0x6441207f,0x00000000}},	//   оими_, _כז_, sali,
  { {0x21a30076,0xf6520063,0x64412080,0x00000000}},	//   виям, _יצא_, pali,
  { {0x3cf90053,0x6ada0082,0x00000000,0x00000000}},	//   ्गों_, _भद्र,   ,
  { {0x291f0019,0x93bc003b,0x65691561,0x00000000}},	//   _luua_, ncăl, lteh,
  { {0x61f600fe,0x00000000,0x00000000,0x00000000}},	//   _tyyl,   ,   ,
  { {0xf1bf02fc,0x65692081,0x8d66000d,0x00000000}},	// [3180] lcán_, nteh, ьвае,
  { {0x315700b5,0xec770894,0x718b009d,0x00000000}},	//   _קיין_, мпу_, _וְטַ,
  { {0x309b0063,0xa09b0063,0x9a860091,0x00000000}},	//   _ושימ, _וייט, дулл,
  { {0x21200089,0x2b4700dd,0xa3d40082,0x00000000}},	//   _kuih_, ânca_, _सेफ_,
  { {0x39460006,0x397a04f6,0x5937000d,0x00000000}},	//   usos_, تصاد_, дзіў_,
  { {0x394605ca,0x7f5c0003,0x21200089,0x00000000}},	//   rsos_, ourq, _muih_,
  { {0x39460f76,0xdce4027c,0xd7ef0b3f,0x00000000}},	//   ssos_, ntič, ту_,
  { {0x38c8007e,0x6d5600a4,0x2d802082,0x00000000}},	//   _کاری_, orya, owie_,
  { {0xe5c60076,0xe4e60086,0x78660ac5,0x00000000}},	//   ьско, дінн, _оказ,
  { {0xdce42061,0x80d00042,0x00000000,0x00000000}},	//   ktič, डोमे,   ,
  { {0x2ca7004b,0xe2f90603,0x65692083,0x00000000}},	//   öndi_, зені_, ateh,
  { {0x92940088,0xe6930021,0x7b03004b,0x00000000}},	//   ваюц, _للمد, põue,
  { {0xf5b6006a,0xf1b90240,0xf1bf2084,0x00000000}},	//   _تصاد, áš_, acán_,
  { {0xfd4f008b,0x2d800051,0xb75a0013,0x00000000}},	//   _triế, dwie_, _ngừơ,
  { {0xc588001b,0x46b20042,0xf2030042,0x00000000}},	//   _hồ_, _जवाह, रेज़_,
  { {0x3869007d,0xe5020042,0xe731009a,0x00000000}},	//   đari_, _रीति_, רֵם_,
  { {0x7cf00e77,0x2d802085,0x00000000,0x00000000}},	// [3190] tärp, gwie_,   ,
  { {0xc5880013,0x387c0130,0x00000000,0x00000000}},	//   _mồ_, jevr_,   ,
  { {0xf42900fe,0x66de001c,0xc588008b,0x00000000}},	//   lkää_, tīkl, _lồ_,
  { {0x527c0047,0x60d52086,0x0dcb0f63,0x00000000}},	//   ַנוא, lizm, _дуги_,
  { {0x39490d2f,0x5e560149,0x6f0d2087,0x00000000}},	//   éas_, _אירע_, mmac,
  { {0x6b8300b9,0xb0660072,0x80a20053,0x00000000}},	//   ængs, _ikää, खाये,
  { {0x6602000f,0x7ceb00bd,0x20cd0130,0x00000000}},	//   _azok, kürz, ržih_,
  { {0x291f0019,0xc588008b,0x661d0066,0x00000000}},	//   _tuua_, _bồ_, ľsko,
  { {0x93bc003b,0xe5760121,0x98752088,0x00000000}},	//   scăl, езы_, _плац,
  { {0x6f0d00bd,0xdce70078,0x79580e82,0x00000000}},	//   hmac, ėmėt, _цифр_,
  { {0x6f0d2089,0x6569208a,0x2d800051,0x00000000}},	//   kmac, steh, zwie_,
  { {0x87b60047,0x60d50249,0xe7b60041,0x00000000}},	//   _אלעס_, eizm, _אהער_,
  { {0x463a00b5,0x30760086,0xf1bf0139,0x00000000}},	//   _זענע, нувс, scán_,
  { {0x73e5011c,0x30750076,0x672100fe,0x00000000}},	//   _полз, кусс, _kulj,
  { {0xf8520024,0xf8ad008b,0x91031410,0x00000000}},	//   ížiť_, _đợi_, упре,
  { {0x2d800051,0x38650150,0x67210ba5,0x00000000}},	//   twie_, _lclr_, _mulj,
  { {0x82770047,0xdce4208b,0xf3890013,0x00000000}},	// [31a0] _טעקע_, stič, _hả_,
  { {0x6c860021,0x9f860304,0xef860330,0x00000000}},	//   علام, _згод, _злоп,
  { {0x395d006f,0x6e461137,0x26df007d,0x00000000}},	//   euws_, _пенз, knuo_,
  { {0x7eb104aa,0xf3890013,0x6da60bd8,0x00000000}},	//   _dåps, _mả_, _зима,
  { {0x7ae3006d,0xd6d0007e,0x2d8f0b2a,0x00000000}},	//   énta, یقت_, åget_,
  { {0x98a30f34,0xc5880013,0x67210130,0x00000000}},	//   личе, _rồ_, _bulj,
  { {0x660200ea,0xfce3208c,0x7c3f013d,0x00000000}},	//   _szok, _соро, özrő,
  { {0x6721017f,0x26df007d,0x60d5208d,0x00000000}},	//   _dulj, gnuo_, zizm,
  { {0xfcaa009d,0x00000000,0x00000000,0x00000000}},	//   ִיֹּ,   ,   ,
  { {0x07a60088,0x6d4b00ea,0x7ceb004d,0x00000000}},	//   _пазн, ágai, würz,
  { {0xf389001b,0x6f0d0731,0x7ceb004d,0x00000000}},	//   _cả_, ymac, türz,
  { {0xf7730063,0x9f5e0066,0xf4290072,0x00000000}},	//   _תקף_, ätý_, tkää_,
  { {0xc1b81224,0x60d5208e,0x7b03004e,0x00000000}},	//   елях_, tizm, nõua,
  { {0x13f4005a,0x645c017d,0xddc6056c,0x00000000}},	//   _изля, órid, _odkł,
  { {0xcebb005e,0xf389008d,0x60d50de1,0x00000000}},	//   пља_, _gả_, rizm,
  { {0x79820022,0x60d5208f,0x9f48011b,0x00000000}},	//   kwow, sizm, íhán_,
  { {0x98830024,0x75220006,0x6f0d2090,0x00000000}},	// [31b0] víľu_, _juoz, rmac,
  { {0x9c8200c2,0x658f013d,0x7e66004d,0x00000000}},	//   ščne, lőhö, _eckp,
  { {0xc4d300b5,0xf3890013,0x1cb80044,0x00000000}},	//   נגע_, _xả_, راكب_,
  { {0x2d8f00b9,0x76420331,0x59d20042,0x00000000}},	//   åges_, _neoy, _देहर,
  { {0x672100fe,0x3ea9008f,0xd91b0121,0x00000000}},	//   _sulj, mjat_, чье_,
  { {0xdb23007e,0x9dd60063,0x67212091,0x00000000}},	//   _موسی, _יורק_, _pulj,
  { {0x26df007d,0x2ca70014,0xc7a50062,0x00000000}},	//   tnuo_, öndu_, тийк,
  { {0x3ea92092,0xf3890013,0x59d20082,0x00000000}},	//   njat_, _rả_, _देवर,
  { {0xceb40e2a,0x3ea90072,0xf5090363,0x00000000}},	//   טיק_, ijat_, мнил_,
  { {0x26df007d,0x3ea901cf,0x66e8004c,0x00000000}},	//   snuo_, hjat_, věke,
  { {0xa3cb0053,0xed60004c,0x00000000,0x00000000}},	//   _रेख_, ěžit_,   ,
  { {0x6d5f00ac,0xf3890013,0xe2970446,0x00000000}},	//   kuqa, _vả_, ваю_,
  { {0x20d6019d,0xcb1200b5,0x3ea914c8,0x00000000}},	//   вівс, ילט_, djat_,
  { {0xf389001b,0x3e7c0013,0x09b6009a,0x00000000}},	//   _tả_, _ật_, דפשט_,
  { {0xddca0051,0x10a3150a,0x64432093,0x00000000}},	//   łoży, ширн, _ieni,
  { {0x20cd0006,0x79820051,0x64432094,0x00000000}},	//   džiu_, ywow, _heni,
  { {0xe0d2007e,0x64432095,0xfc320021,0x00000000}},	// [31c0] _نزد_, _keni, لحا_,
  { {0x64432096,0x3ea900fe,0xccc30085,0x00000000}},	//   _jeni, ajat_, абуй,
  { {0x2d8f0146,0xd83e00c2,0x64432097,0x00000000}},	//   åger_, ščka_, _meni,
  { {0x64432098,0x79820051,0xdb21013d,0x00000000}},	//   _leni, twow, átás,
  { {0x3eab0240,0x644307fc,0x6b95004d,0x00000000}},	//   žitá_, _oeni, _erzg,
  { {0x79820051,0x658f013d,0xfce61cce,0x00000000}},	//   rwow, zőhö, _рого,
  { {0xf6e61567,0x36d42099,0xc8b50085,0x00000000}},	//   кцин, локр, ысцы,
  { {0xd6d70475,0x7b03004b,0x96330062,0x00000000}},	//   кты_, lõun, анъц,
  { {0xb5a3000d,0x752201f4,0x7ae2209a,0x00000000}},	//   арэй, _quoz, mnot,
  { {0x7ae20051,0xe7ed0053,0x6443209b,0x00000000}},	//   lnot, _चुका_, _ceni,
  { {0x645c00cd,0x9f4f005b,0x644316d6,0x00000000}},	//   òriq, ünüz_, _deni,
  { {0x64430179,0xa159000d,0x41e7013c,0x00000000}},	//   _eeni, наму_, віга,
  { {0xb356006a,0x6443209c,0x7ae2209d,0x00000000}},	//   ریکا_, _feni, inot,
  { {0x6443209e,0x7ae20139,0x658f013d,0x00000000}},	//   _geni, hnot, sőhö,
  { {0x3ea90bba,0x644807f4,0xdfd80062,0x00000000}},	//   tjat_, madi, вът_,
  { {0xaf34007e,0xff070086,0x6e220066,0x00000000}},	//   شرفت, тягн, žobn,
  { {0x644301f7,0x7d1c0026,0x7ae20114,0x00000000}},	// [31d0] _yeni, _birs, dnot,
  { {0x3e53001b,0xdcf90021,0x64481e3e,0x00000000}},	//   ệt_, رفات_, nadi,
  { {0xaa950086,0x64480066,0x7d1c209f,0x00000000}},	//   лижч, iadi, _dirs,
  { {0x628f20a0,0x644820a1,0x7ae220a2,0x00000000}},	//   ndco, hadi, gnot,
  { {0x7d1c0034,0x69cd016a,0x79a7005a,0x00000000}},	//   _firs, _देखी, ърже,
  { {0x7ae2024a,0x961d001c,0x644820a3,0x00000000}},	//   anot, ieņe, jadi,
  { {0xccf20063,0x644820a4,0x98480054,0x00000000}},	//   _לכך_, dadi, тяча_,
  { {0x6e2d18ff,0xb5fd001c,0x645d0006,0x00000000}},	//   ncab, egša, ėsim,
  { {0x6d4d015d,0x644320a5,0x6f1d20a6,0x00000000}},	//   nsaa, _peni, _misc,
  { {0x6f1d20a7,0xf770007e,0x628f20a8,0x00000000}},	//   _lisc, _ژان_, edco,
  { {0x628f006f,0x644320a9,0x69cb004d,0x00000000}},	//   fdco, _veni, lzge,
  { {0x64430199,0x68ed0025,0x6d4d20aa,0x00000000}},	//   _weni, éadf, ksaa,
  { {0x64480009,0x64431961,0x645c04a6,0x00000000}},	//   badi, _teni, óric,
  { {0x6f1d0027,0x6d4d00e8,0xd6d90051,0x00000000}},	//   _aisc, dsaa, lił_,
  { {0xd36e0021,0x6f1d20ab,0x68e30f49,0x00000000}},	//   _فهو_, _bisc, innd,
  { {0x6d4d00e8,0xdfcf0021,0xd6d90051,0x00000000}},	//   fsaa, سيق_, nił_,
  { {0xed570079,0x6d4d20ac,0xd83e0078,0x00000000}},	// [31e0] лот_, gsaa, ščia_,
  { {0x20cd0080,0x6f1d20ad,0x621b009a,0x00000000}},	//   užit_, _eisc, _אופק,
  { {0xad9b006d,0x7d1c20ae,0x6d4d20af,0x00000000}},	//   _ayúd, _virs, asaa,
  { {0x7d1c004d,0x7ae220b0,0xeafa01fb,0x00000000}},	//   _wirs, unot, ررات_,
  { {0x99dd0024,0x2d840003,0x7ae220b1,0x00000000}},	//   _peňa, _ème_, rnot,
  { {0x2cb100c2,0x7ae220b2,0x2b5a20b3,0x00000000}},	//   _gozd_, snot, prpc_,
  { {0x644820b4,0xb21b0831,0xf1c200c2,0x00000000}},	//   vadi, ndær, lišč_,
  { {0x65aa0001,0xb60500c2,0x64480011,0x00000000}},	//   етог_, _oišč, wadi,
  { {0x644820b5,0x7b06008f,0x35b30062,0x00000000}},	//   tadi, ārtē, йбър,
  { {0x297b0041,0x3a09005d,0x2418007f,0x00000000}},	//   _אטמא, _شکنی_, копы_,
  { {0xd6d90051,0x442e004d,0x644820b6,0x00000000}},	//   bił_, _vff_, radi,
  { {0xd6d90051,0xe2150121,0xb60500c2,0x00000000}},	//   cił_, имны, _bišč,
  { {0x291e014f,0x6f1d20b7,0x59c40053,0x00000000}},	//   _kita_, _risc, वनिर,
  { {0xf1c200c2,0x43940601,0x442e20b8,0x00000000}},	//   dišč_, _вакс, _uff_,
  { {0x14d720b9,0x291e20ba,0x226a0072,0x00000000}},	//   _גוגל_, _mita_, ätkö_,
  { {0x1e350088,0x63b50066,0x291e20bb,0x00000000}},	//   рнаў, äzne, _lita_,
  { {0xe905001b,0x63ba00b9,0x2d580b3f,0x00000000}},	// [31f0] _lượ, lytn, лить_,
  { {0x0f35007e,0x6d4d20bc,0x6e2d20bd,0x00000000}},	//   _نکرد, rsaa, scab,
  { {0x63ba0831,0x6f1d0221,0xbc0703d6,0x00000000}},	//   nytn, _tisc, учай,
  { {0x6f1d0025,0x69cb20be,0xdb120026,0x00000000}},	//   _uisc, tzge, ægðu,
  { {0x291e20bf,0x186920c0,0x00000000,0x00000000}},	//   _bita_, вали_,   ,
  { {0xd6d90051,0x2d99006d,0x63ba0240,0x00000000}},	//   wił_, _irse_, kytn,
  { {0x291e20c1,0x7cf00072,0xa3d40042,0x00000000}},	//   _dita_, järy, _सेल_,
  { {0xe9050013,0x2b5c004c,0x291e2071,0x00000000}},	//   _dượ, ávce_, _eita_,
  { {0x7afb0397,0x291e20c2,0x7649002b,0x00000000}},	//   _ikut, _fita_, raey,
  { {0xa5090001,0xd6d90051,0x67d50782,0x00000000}},	//   ђена_, sił_, _козу,
  { {0x645c20c3,0xd6d90051,0x7ae900d1,0x00000000}},	//   ória, pił_, _kjet,
  { {0x95d90076,0x291e20c4,0x2d8b20c5,0x00000000}},	//   _идет_, _zita_, _osce_,
  { {0x26110053,0x7afb05b3,0x64a520c6,0x00000000}},	//   देशी_, _mkut, _вала,
  { {0x7ae9017f,0x65750024,0x7eb800cd,0x00000000}},	//   _ljet, ľahč, _lípt,
  { {0x61ed15ae,0x2d9900dd,0x224b20c7,0x00000000}},	//   _exal, _arse_, back_,
  { {0xf1c200c3,0x5de6026b,0xb21b01e1,0x00000000}},	//   tišč_, ажба, rdær,
  { {0xf8c50053,0xcd270062,0xfe430054,0x00000000}},	// [3200] वसाय, ижте_, інфо,
  { {0x3b960001,0xc19b0063,0xf1c200a8,0x00000000}},	//   ијет, _ישפי, rišč_,
  { {0x60dc002c,0x2d8b0290,0x7ae90331,0x00000000}},	//   mirm, _esce_, _bjet,
  { {0x291e20c8,0x60dc0058,0x7eb80046,0x00000000}},	//   _sita_, lirm, _pípu,
  { {0xed57005a,0x7ae9007d,0x60dc0139,0x00000000}},	//   _коя_, _djet, oirm,
  { {0xd8f7019d,0x60dc20c9,0xf7540021,0x00000000}},	//   анії_, nirm, منتج,
  { {0x291e20ca,0x60dc004b,0x69d60082,0x00000000}},	//   _vita_, iirm, _मेरी,
  { {0x7eb8000f,0x60dc00bd,0x7ae900d1,0x00000000}},	//   _típu, hirm, _gjet,
  { {0x96b70001,0x7c29005b,0xe4a620cb,0x00000000}},	//   рују_, _şeri, арно,
  { {0x291e003b,0xe905008b,0xd49a0806,0x00000000}},	//   _uita_, _tượ, три_,
  { {0x224b0034,0x929520cc,0xc6a6005e,0x00000000}},	//   tack_, банц, _врли,
  { {0x81c3001c,0x56930086,0x2b47003b,0x00000000}},	//   ņēmi, _маєт, ânci_,
  { {0xd534007e,0xddcd003b,0x60dc20cd,0x00000000}},	//   _افتخ, ifaţ, firm,
  { {0x672801a8,0x224b20ce,0x66e1008f,0x00000000}},	//   _kudj, sack_, vēki,
  { {0x232720cf,0xd43700b5,0x61140086,0x00000000}},	//   _који_, _דרוק_, ідсу,
  { {0x443e004d,0x877b009d,0x33fb009d,0x00000000}},	//   lbt_, כאלי, _שההנ,
  { {0x5d99000d,0x32090058,0xfd470085,0x00000000}},	// [3210] ыкаў_, _uzay_, рэбн,
  { {0x60dc0331,0x7ae920d0,0x7afb20d1,0x00000000}},	//   cirm, _sjet, _skut,
  { {0x443e0199,0x68f80130,0x3b670094,0x00000000}},	//   ibt_, dovd, ръзв,
  { {0x21290089,0x7c3e008f,0x66e8004c,0x00000000}},	//   _kuah_, abpr, děko,
  { {0xe9f80086,0x7ae920d2,0x9f5e0072,0x00000000}},	//   анці_, _vjet, ätö_,
  { {0x6728024a,0xe8f80304,0x224900e5,0x00000000}},	//   _budj, алі_, _leak_,
  { {0x7b030019,0x21290089,0xe7680021,0x00000000}},	//   nõuk, _luah_, لحين_,
  { {0x443e20d3,0x7ae900c2,0x7afb02ae,0x00000000}},	//   ebt_, _ujet, _ukut,
  { {0xb9340635,0x2eaa0047,0x25a90044,0x00000000}},	//   _метј, רשפּ, ادعي_,
  { {0x442300b9,0x7b2c0058,0xc8b40044,0x00000000}},	//   øj_, _oğul, _وإلغ,
  { {0x60dc005b,0x83a80021,0x224900e5,0x00000000}},	//   virm, لاَّ_, _beak_,
  { {0x2129053b,0x63bc00d1,0x1b7a0047,0x00000000}},	//   _buah_, ørna, נטרע,
  { {0x443e00c7,0xd36e007e,0x60dc20d4,0x00000000}},	//   bbt_, وهی_, tirm,
  { {0x25c90058,0x2d9e004c,0xf5560044,0x00000000}},	//   ıtlı_, _čte_, _الوب_,
  { {0xbea606b4,0x60dc0014,0x93bc003b,0x00000000}},	//   бавк, rirm, ucăt,
  { {0x93bc003b,0xc24607b3,0x42560044,0x00000000}},	//   rcăt, _уник, _انظر,
  { {0x60dc20d5,0x628620d6,0x93bc003b,0x00000000}},	// [3220] pirm, meko, scăt,
  { {0x30860032,0x628620d7,0xf06601ce,0x00000000}},	//   _الدف, leko, _укоп,
  { {0x20290024,0x62860173,0x93bc003b,0x00000000}},	//   átiť_, oeko, lcăr,
  { {0x628620d8,0x24851eca,0x66e8011b,0x00000000}},	//   neko, helm_, věko,
  { {0x38cb006a,0x6f0400bd,0x6728017f,0x00000000}},	//   گانی_, mlic, _sudj,
  { {0x6f0420d9,0x62860ff2,0x7c2900dd,0x00000000}},	//   llic, heko, _şerv,
  { {0x6286057e,0x38cb007e,0x35d00053,0x00000000}},	//   keko, دانی_, _तेज़,
  { {0x6f040199,0x628620da,0x257000cd,0x00000000}},	//   nlic, jeko, tàl_,
  { {0x799b006f,0x645c20db,0xd9430782,0x00000000}},	//   _gruw, ório, _нети,
  { {0x6728000f,0x6f0420dc,0x443e00bd,0x00000000}},	//   _tudj, hlic, ubt_,
  { {0x22490034,0x443e00bd,0x6f0420dd,0x00000000}},	//   _peak_, rbt_, klic,
  { {0xd5a4007e,0xe2f90086,0x66de001c,0x00000000}},	//   _ولای, ремі_, rīks,
  { {0xc05b019d,0x6f0420de,0x7ae3006d,0x00000000}},	//   лів_, dlic, énti,
  { {0x22490034,0xf6170063,0x65c10014,0x00000000}},	//   _weak_, _החדש_, sáhö,
  { {0x6f0420df,0xcfa40d34,0xc1040021,0x00000000}},	//   flic, пшти, سوفي,
  { {0x212900e3,0x6f0420e0,0x644a20e1,0x00000000}},	//   _tuah_, glic, _hefi,
  { {0x644a20e2,0x6b9c20e3,0x5274005d,0x00000000}},	// [3230] _kefi, _arrg, _رايز,
  { {0xddd0003b,0x6f1616bb,0x0ba70121,0x00000000}},	//   ţeşt, amyc, йшем,
  { {0xebd90002,0xbab50121,0x9be4000d,0x00000000}},	//   јдеш_, жёлы, піцк,
  { {0x6f0420e4,0x999920e5,0x2b5c0066,0x00000000}},	//   clic, икет_, ávca_,
  { {0x6458082a,0x7e6f0150,0xd82520e6,0x00000000}},	//   _odvi, _iccp, одли,
  { {0x4759011c,0x98a2026b,0x62860051,0x00000000}},	//   ария_, дише, zeko,
  { {0xe7390055,0x7af90051,0x16a91580,0x00000000}},	//   шей_, powt, ивки_,
  { {0x8579000a,0x2ee9001f,0xb9e70086,0x00000000}},	//   асот_, nnaf_, _лізи,
  { {0xb8830024,0x644a20e7,0x628620e8,0x00000000}},	//   _príč, _befi, veko,
  { {0x644a002b,0xd877009e,0x6f0420e9,0x00000000}},	//   _cefi, _دارب, zlic,
  { {0xdce4017f,0xc2090063,0xc7c70699,0x00000000}},	//   stić, _סה_, _усаи,
  { {0x7e7d20ea,0x248520eb,0xd491008d,0x00000000}},	//   _nbsp, selm_, còn_,
  { {0x412a20ec,0x3495032d,0x961d008f,0x00000000}},	//   рого_, _мадр, meņo,
  { {0x6ab6016a,0x93bc000c,0xa06a00e1,0x00000000}},	//   _अक्र, rcăr, јава_,
  { {0x68e40027,0x6f0420ed,0x93bc000c,0x00000000}},	//   éidi, tlic, scăr,
  { {0x75230199,0x64411ab2,0x32d20078,0x00000000}},	//   _hinz, lbli, ršys_,
  { {0x6f04051d,0x644120ee,0x5d6a0065,0x00000000}},	// [3240] rlic, obli, ризм_,
  { {0x2ee90162,0xdb9a0001,0x44270150,0x00000000}},	//   anaf_, итељ_, _jgn_,
  { {0xda6f0895,0x6f040641,0xeb970201,0x00000000}},	//   мя_, plic, жих_,
  { {0x63ae004d,0xbae50054,0x764b20ef,0x00000000}},	//   äbni, пцій, _negy,
  { {0x2d8f00b9,0x672220f0,0x442701f4,0x00000000}},	//   æget_, _rioj, _ogn_,
  { {0x7659002b,0xd7940062,0x58d70054,0x00000000}},	//   _adwy, зикъ, одія_,
  { {0x764b02ab,0x68ed0025,0x644105b9,0x00000000}},	//   _begy, éada, dbli,
  { {0x35b417f4,0x3860005b,0x6441004d,0x00000000}},	//   збир, şir_, ebli,
  { {0x2cb80004,0x7659001f,0x2db70047,0x00000000}},	//   _kord_, _ddwy, ַלטן_,
  { {0x752313ba,0x2cb80e6c,0x442720f1,0x00000000}},	//   _cinz, _jord_, _cgn_,
  { {0x4427028d,0x644a0026,0xa2950454,0x00000000}},	//   _dgn_, _vefi, пані,
  { {0x75230199,0x2cb81e3e,0x442705a5,0x00000000}},	//   _einz, _lord_, _egn_,
  { {0x644102f6,0x66de001c,0x752301f4,0x00000000}},	//   bbli, lūko, _finz,
  { {0x6458010a,0x2cb820f2,0x75230168,0x00000000}},	//   _udvi, _nord_, _ginz,
  { {0x645d0006,0x7659002b,0x0f1b0044,0x00000000}},	//   ėsit, _ydwy, لغرب_,
  { {0x4427006f,0xd3570063,0x1d351dfd,0x00000000}},	//   _zgn_, _ויהי_, зная,
  { {0x2cb820f3,0x61550021,0x00000000,0x00000000}},	// [3250] _bord_, _عندئ,   ,
  { {0x2cb800e5,0xd53b009a,0x00000000,0x00000000}},	//   _cord_, יתמט,   ,
  { {0xd0f80042,0xfbab0085,0x23ca0042,0x00000000}},	//   ंकरण_, штай_, ानिद,
  { {0x6ffa0063,0xbad80054,0x99d704a0,0x00000000}},	//   _להתפ, офії_, يتشا,
  { {0x6441001f,0xe8ee184b,0xd9451741,0x00000000}},	//   ybli, ел_, чели,
  { {0x3eb912d4,0x7e6d004b,0x798b002b,0x00000000}},	//   _host_, lgap, rwgw,
  { {0x8ae70086,0x18660062,0xad9b013d,0x00000000}},	//   _діал, чащи_, _ezút,
  { {0x7e6d20f4,0xc98705ef,0xa7fc0075,0x00000000}},	//   ngap, _музи, _acıs,
  { {0x3eb920f5,0x95550032,0x26df00eb,0x00000000}},	//   _most_, أخبا, riuo_,
  { {0x3eb90034,0xd469005e,0x644120f6,0x00000000}},	//   _lost_, љине_, ubli,
  { {0x3eb90122,0xf7700021,0x7aeb20f7,0x00000000}},	//   _oost_, _لان_, ongt,
  { {0x64411f5f,0x29070b68,0xddc4003b,0x00000000}},	//   sbli, llna_, ngiţ,
  { {0x2731008b,0x59bd0053,0x6456013d,0x00000000}},	//   _hán_, ्निर, égió,
  { {0x859a014e,0x9742017f,0x659a0e2a,0x00000000}},	//   _לשנו, šćen, _לינק,
  { {0x3eb9001f,0x656900fe,0x27311994,0x00000000}},	//   _bost_, lueh, _ján_,
  { {0xa3d40053,0x7e6d20f8,0x3eb920f9,0x00000000}},	//   _सेट_, ggap, _cost_,
  { {0x27310025,0x6296002c,0x4d660603,0x00000000}},	// [3260] _lán_, _iayo, якав,
  { {0x7e6d002c,0x62961362,0xdd8f0021,0x00000000}},	//   agap, _hayo, طوم_,
  { {0x3eb90469,0x629600bb,0x2d8f00b9,0x00000000}},	//   _fost_, _kayo, æger_,
  { {0x2fc50205,0x2cb8015e,0x656900fe,0x00000000}},	//   ølge_, _word_, kueh,
  { {0x7e9b0063,0x629620fa,0xe89420fb,0x00000000}},	//   _הסכו, _mayo, даль,
  { {0x273120fc,0x7aeb00a4,0x29070026,0x00000000}},	//   _bán_, angt, glna_,
  { {0xd6da0619,0x2731008b,0xaa4620fd,0x00000000}},	//   йти_, _cán_, _невл,
  { {0x987800c3,0x2d840003,0x6d56005b,0x00000000}},	//   _išči_, _âmes_, osya,
  { {0x6d5620fe,0x7ae220ff,0xa4d4071f,0x00000000}},	//   nsya, miot, допі,
  { {0x6296002c,0x27310025,0xa4d80086,0x00000000}},	//   _aayo, _fán_, ідну_,
  { {0x78a81c23,0x6d56017e,0xd91b0149,0x00000000}},	//   _indv, hsya, _פובל,
  { {0xddc4003d,0xf6d6005d,0x7ae22100,0x00000000}},	//   maiņ, _عزاد, niot,
  { {0x64a62101,0x3eb92102,0x63bc00a5,0x00000000}},	//   _нада, _rost_, ärnb,
  { {0x760b00b5,0x65930002,0xe1ff013d,0x00000000}},	//   _פּאַ, _чашу, ngói_,
  { {0x78ba00cf,0x3eb913bb,0x20050014,0x00000000}},	//   _motv, _post_, æli_,
  { {0x62962103,0x660f00bd,0x7b03004b,0x00000000}},	//   _gayo, ückg, nõut,
  { {0xa2aa0053,0x5cb90085,0x7ae22104,0x00000000}},	// [3270] टार्, олаў_, diot,
  { {0xb03501a4,0xddc40023,0x78ba2105,0x00000000}},	//   _юнош, kaiņ, _notv,
  { {0x62960035,0x6d561324,0x316c0051,0x00000000}},	//   _yayo, asya, ądze_,
  { {0x5a34000d,0x7aeb2106,0x27312107,0x00000000}},	//   енцт, ungt, _rán_,
  { {0x78ba01e1,0x27310013,0x98f50085,0x00000000}},	//   _botv, _sán_, мякч,
  { {0x48790086,0x2731027d,0xf77104a0,0x00000000}},	//   ісля_, _pán_, ناب_,
  { {0x7ae22108,0x261a0053,0x97a70085,0x00000000}},	//   biot, मेसी_, ярдл,
  { {0xe5590001,0x7ae20387,0x78a82109,0x00000000}},	//   ојој_, ciot, _endv,
  { {0x78270242,0x6296210a,0xfaff008f,0x00000000}},	//   _فعال, _rayo, ļūda_,
  { {0x61e20026,0x2731008b,0x6abb011b,0x00000000}},	//   _þoli, _tán_, _houf,
  { {0x6296210b,0xc747007e,0x68e3210c,0x00000000}},	//   _payo, _رضاي, mind,
  { {0x91e606b4,0x6abb006c,0x36d4210d,0x00000000}},	//   доме, _jouf, _похр,
  { {0x68e3210e,0xdc0a0042,0x9557005d,0x00000000}},	//   oind, _वर्ड_, _رخشا,
  { {0x7ae2210f,0xf9920063,0x68e32110,0x00000000}},	//   ziot, דרך_, nind,
  { {0x629600a4,0x7b030019,0xdff50121,0x00000000}},	//   _tayo, nõus, еять,
  { {0x68e32111,0x7c29095a,0x8236043e,0x00000000}},	//   hind, _şerp, _غربا,
  { {0x68e31a4f,0x7ae22112,0xad9b013d,0x00000000}},	// [3280] kind, viot, _szúr,
  { {0x3cfa0161,0x69c20035,0xdd8f0021,0x00000000}},	//   ्तें_, vyoe, ؤول_,
  { {0xb4fa0047,0x6abb11f5,0x68e32113,0x00000000}},	//   קלער, _bouf, dind,
  { {0xc3320063,0x68e32114,0x78ba01c8,0x00000000}},	//   דוא_, eind, _sotv,
  { {0x6abb0080,0x68e32115,0x6d560089,0x00000000}},	//   _douf, find, qsya,
  { {0x68e32116,0x7ae30331,0x98a302b6,0x00000000}},	//   gind, éntr, киче,
  { {0x7ae20072,0x98a3005e,0x0b46012c,0x00000000}},	//   piot, тије, _інан,
  { {0x6abb1a05,0x656d0066,0xddc4008f,0x00000000}},	//   _gouf, _ťaha, raiņ,
  { {0x68e32117,0x048a005e,0x84660062,0x00000000}},	//   bind, ољни_, мъне,
  { {0x78a82118,0x442a00b9,0x68e32119,0x00000000}},	//   _undv, øb_, cind,
  { {0x6d4b013d,0x97c60044,0xe7a80082,0x00000000}},	//   ágaz, _تقاو, _कपटप,
  { {0x65870137,0xeb910063,0xe56f0058,0x00000000}},	//   örhå, נָי_, ağış,
  { {0xf493007e,0xb90b008d,0xf2040085,0x00000000}},	//   رشید, _điạ_, вяро,
  { {0x660f00bd,0x3cfa0161,0xe1ff056c,0x00000000}},	//   ücke, ्तों_, zgów_,
  { {0xcebb0001,0x34fb089e,0x8503005d,0x00000000}},	//   оља_, _והגד, _جوون,
  { {0x68e3211a,0xa2d50044,0x33830094,0x00000000}},	//   zind, _سيخت, _рушв,
  { {0x68e3005b,0x33180044,0x9d15211b,0x00000000}},	// [3290] yind, _تزود_, едач,
  { {0x6abb0164,0xee3f0024,0x6aa9211c,0x00000000}},	//   _souf, _iným_, _snef,
  { {0x68e3211d,0xa2d60053,0x6abb0022,0x00000000}},	//   vind, मोक्, _pouf,
  { {0x68e3211e,0x00000000,0x00000000,0x00000000}},	//   wind,   ,   ,
  { {0x1958000d,0x66e8004c,0x68e3211f,0x00000000}},	//   дачы_, něku, tind,
  { {0x68e32120,0x7b030019,0x3f8700be,0x00000000}},	//   uind, tõus, _ânus_,
  { {0x98a4000c,0x68e32121,0x6abb0003,0x00000000}},	//   _sumă_, rind, _touf,
  { {0x68e32122,0xf1ca0066,0xf5b50e82,0x00000000}},	//   sind, _hráš_, есою,
  { {0x68e303d7,0xa7fc0058,0x35d90082,0x00000000}},	//   pind, _adıd, _बेख़,
  { {0x9742017f,0x39142123,0x38d5009d,0x00000000}},	//   šćan, _амур, _אֵ֣ל_,
  { {0x28ac0053,0xf8680021,0xb8d30053,0x00000000}},	//   चारि, _زمني_, टा_,
  { {0xdce401f7,0x63bc0137,0xe9df0046,0x00000000}},	//   ktiğ, ärna, _þús_,
  { {0x26cf0078,0x7bc500a3,0xa2d60042,0x00000000}},	//   _ilgo_, hyhu, मोग्,
  { {0xb5fd001c,0x657b0014,0xb5c801f3,0x00000000}},	//   ugšu, mtuh, _توهم_,
  { {0x3f16000a,0x60c10014,0x99dd011b,0x00000000}},	//   еќат, ölma, _keňs,
  { {0x1168007e,0x394d00e5,0x23760044,0x00000000}},	//   _قلبی_, _owes_, _أميد_,
  { {0x657b16b0,0x7c3b0058,0x00000000,0x00000000}},	// [32a0] ntuh, _şura,   ,
  { {0xe0da005e,0xe189005d,0x8c96014b,0x00000000}},	//   _хво_, _آئين_, эрбі,
  { {0xa0370041,0x0b462124,0x7bc5002b,0x00000000}},	//   _ראטה_, хнен, gyhu,
  { {0x657b002c,0x68e1002b,0x29050058,0x00000000}},	//   ktuh, _amld, _akla_,
  { {0x62840139,0x19942125,0x28ac0042,0x00000000}},	//   _mbio, таля, चालि,
  { {0x26cf06b2,0x6d442126,0xd90d007e,0x00000000}},	//   _algo_, mpia, قیق_,
  { {0x56942127,0x66de2128,0x67630044,0x00000000}},	//   вайт, lūki, هُول,
  { {0xd6d70055,0x20d40019,0x4733005d,0x00000000}},	//   еть_, _häid_, دروز,
  { {0xa9672129,0x20d4004b,0x888608b0,0x00000000}},	//   _пита_, _käid_, _плаж,
  { {0x6d440006,0x20d4004b,0x6284212a,0x00000000}},	//   ipia, _jäid_, _abio,
  { {0xe2f90086,0x02cc0053,0xa7b501ce,0x00000000}},	//   дені_, ासंभ, _исцј,
  { {0x9294000d,0x660f0244,0x7b03004e,0x00000000}},	//   гаюц, ückc, nõup,
  { {0xe298000d,0x6eba0042,0xdcf6005f,0x00000000}},	//   хаў_, _एकजु, etyč,
  { {0x2ec90161,0xd7e60021,0xe58b0063,0x00000000}},	//   रस्त, لك_, _זָהָ,
  { {0x316c0022,0x4394212b,0x649b009d,0x00000000}},	//   ądza_, _райс, _מסגד,
  { {0xdce4005b,0xdb0d0058,0x3e890044,0x00000000}},	//   ttiğ, üküm, بَرَ_,
  { {0x60f90062,0x6c75005e,0x629d0137,0x00000000}},	// [32b0] _ония_, клађ, mdso,
  { {0x62840051,0x629d212c,0x628f212d,0x00000000}},	//   _zbio, ldso, leco,
  { {0xdce40058,0x6d44002b,0x00000000,0x00000000}},	//   stiğ, apia,   ,
  { {0x7b2c005b,0x629d212e,0xe04b007e,0x00000000}},	//   _ağus, ndso, _بشکه_,
  { {0x629d0438,0x8027007e,0x7bc51472,0x00000000}},	//   idso, _ترکم, syhu,
  { {0x6f0d212f,0x01380063,0x31380063,0x00000000}},	//   llac, ערות_, ערוך_,
  { {0x628f0089,0x6f0d2130,0x2d4f0022,0x00000000}},	//   keco, olac, lże_,
  { {0x257900cd,0x2d4f0051,0x95850062,0x00000000}},	//   tèl_, oże_, влие,
  { {0x98a40006,0x629d001f,0x628f2131,0x00000000}},	//   _sumą_, ddso, deco,
  { {0x6f0d2132,0x657b2133,0xe8df0013,0x00000000}},	//   hlac, rtuh, _meịo_,
  { {0x657b00bb,0x6f0d2134,0x69d9004d,0x00000000}},	//   stuh, klac, lzwe,
  { {0x2d4f0045,0x628f2135,0x64482136,0x00000000}},	//   kże_, geco, abdi,
  { {0x2d4f0022,0x69d9030c,0x4a5a009a,0x00000000}},	//   jże_, nzwe, ודרו,
  { {0x442e004d,0x6f0d12c7,0x00860062,0x00000000}},	//   _ggf_, elac, ълго,
  { {0x6d440185,0x6d5d02f0,0xb4bf0053,0x00000000}},	//   wpia, _avsa, ीसी_,
  { {0x4374018e,0x6f0d2137,0x673c013d,0x00000000}},	//   _сушт, glac, _érje,
  { {0xed570079,0xf6520047,0x7159000d,0x00000000}},	// [32c0] кот_, יצן_, _прэс_,
  { {0x6f0d0025,0x6606004b,0x66de0078,0x00000000}},	//   alac, ükki, rūki,
  { {0x6f0d2138,0xd838007d,0x78ae01a8,0x00000000}},	//   blac, _jače_, _òbvi,
  { {0x6d442139,0xd94619b1,0x298a1259,0x00000000}},	//   ppia, веди, дско_,
  { {0xda650021,0x394000ac,0xd910005d,0x00000000}},	//   طاني, ëis_, میر_,
  { {0x7b2c000c,0x656900bd,0x8c4317f2,0x00000000}},	//   _eşua, dreh, _вере,
  { {0x20d40019,0xfce3182e,0xba6a0044,0x00000000}},	//   _käib_, _торо, _يحرك_,
  { {0x2ef2002b,0x6f04213a,0x25a90130,0x00000000}},	//   nnyf_, noic, _šala_,
  { {0x656900ea,0x628f001c,0x35b30062,0x00000000}},	//   greh, veco, ибър,
  { {0x3946213b,0x63bc0137,0xdce4213c,0x00000000}},	//   mpos_, ärno, krič,
  { {0xd49708a6,0x65690380,0x628f213d,0x00000000}},	//   тры_, areh, teco,
  { {0x290e001f,0x629d006f,0x20d4004b,0x00000000}},	//   llfa_, udso, _näib_,
  { {0x394600e8,0x629d213e,0x628f213f,0x00000000}},	//   npos_, rdso, reco,
  { {0x394602dd,0x6f0d04a1,0xa2c70042,0x00000000}},	//   ipos_, wlac, ासङ्,
  { {0x628f087d,0x2738013d,0x4fc40d2a,0x00000000}},	//   peco, _jén_, аста,
  { {0xb2750076,0xc275005e,0x479b016e,0x00000000}},	//   _слиш, _слиј, וילס,
  { {0x27382140,0x1e34000d,0x9df90062,0x00000000}},	// [32d0] _lén_, рнуў, хнат_,
  { {0x6f0d2141,0x26050042,0xbbeb00de,0x00000000}},	//   slac, _हँसी_, ورام_,
  { {0x39462142,0x6f0d0399,0x27380013,0x00000000}},	//   epos_, plac, _nén_,
  { {0x69d90199,0x25a60066,0xbcfb013d,0x00000000}},	//   tzwe, _orol_, _svéd,
  { {0xaa58005e,0xa8890330,0xff160063,0x00000000}},	//   тичу_, ейла_, _תקרת_,
  { {0xa2aa024c,0xd9140088,0x69d900bd,0x00000000}},	//   _जोन्, адчы, rzwe,
  { {0x27380027,0x39462143,0x69d9004d,0x00000000}},	//   _cén_, apos_, szwe,
  { {0x6569000f,0x394600e8,0x27380139,0x00000000}},	//   treh, bpos_, _dén_,
  { {0x27380122,0x79890051,0x656900ac,0x00000000}},	//   _eén_, _upew, ureh,
  { {0xdced0024,0xd838007d,0x7b2c0075,0x00000000}},	//   hvaľ, _pače_, _uğur,
  { {0xd7940062,0x42ea014a,0x25a60075,0x00000000}},	//   _вихъ, емно_, _erol_,
  { {0x216a019d,0x6d4106bb,0x16350062,0x00000000}},	//   ними_, _član, _седя,
  { {0x6f042144,0x20d60054,0x09b50041,0x00000000}},	//   voic, гівс, נפֿט_,
  { {0x19b60063,0x6f040051,0x2d87003b,0x00000000}},	//   אפשר_, woic, ănel_,
  { {0x2d99051e,0x70530021,0x2ee9002b,0x00000000}},	//   _asse_, إنفا, fiaf_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x6f042145,0x290e002b,0xdb1e013d,0x00000000}},	// [32e0] roic, ylfa_, _évéb,
  { {0xdce41312,0xec770121,0xc173009a,0x00000000}},	//   prič, лпу_, _פחת_,
  { {0x2d992146,0xe7e3016a,0xa09b0047,0x00000000}},	//   _esse_, _केला_, _װיכט,
  { {0x39460455,0xdd12001c,0x2d86017d,0x00000000}},	//   tpos_, _kļūs, çoes_,
  { {0xaa570593,0xb7bb008d,0x82770041,0x00000000}},	//   الها_, ệna, רענע_,
  { {0x307a0047,0xfce60002,0x39462147,0x00000000}},	//   גאַנ, _сого, rpos_,
  { {0x39462148,0xada30066,0xf72a0363,0x00000000}},	//   spos_, ajúč, нций_,
  { {0xe29f0026,0x96340ae8,0x3ea02149,0x00000000}},	//   koða_, шниц, ndit_,
  { {0x2d8002b0,0xb5fd008f,0xb5a30085,0x00000000}},	//   ntie_, ugšp, брэй,
  { {0xd454005e,0x3ea00868,0x7d7b0149,0x00000000}},	//   шкоћ, hdit_, עריג,
  { {0xd25100b3,0xa9230114,0xb8f80053,0x00000000}},	//   يند_, ížen, ास_,
  { {0x57fb0063,0x2d80214a,0x25a6214b,0x00000000}},	//   _אלבו, ktie_, _trol_,
  { {0x22590078,0x31350e82,0x98a40022,0x00000000}},	//   rask_, регр, _sumę_,
  { {0x63bc0093,0x3ea0214c,0x659b009a,0x00000000}},	//   ørns, edit_, _ניוק,
  { {0xdfd80062,0xde590054,0x645a214d,0x00000000}},	//   гът_, каві_, mati,
  { {0x3ea00186,0xe29f0014,0xf3f10013,0x00000000}},	//   gdit_, boða_, oạn_,
  { {0xdc5502a9,0x7d250021,0x2d80008f,0x00000000}},	// [32f0] ивањ, لفرن, gtie_,
  { {0x645a214e,0x28a40053,0x3ea0004c,0x00000000}},	//   nati, _गोलि, adit_,
  { {0x5a351d7c,0x2d80214f,0x443e0003,0x00000000}},	//   анет, atie_, ict_,
  { {0x645a2150,0xf991043e,0x00000000,0x00000000}},	//   hati, قبت_,   ,
  { {0x2d8002b0,0x9e5a0063,0x50b8007e,0x00000000}},	//   ctie_, _בכרט, _شدید_,
  { {0x20d40019,0x645a2151,0x395d00a3,0x00000000}},	//   _käia_, jati, rsws_,
  { {0x98540086,0x57e70085,0x645a2152,0x00000000}},	//   стіш, ыўдз, dati,
  { {0x16a90055,0x443e000c,0x645a2153,0x00000000}},	//   твии_, ect_, eati,
  { {0x6341003d,0x05760032,0xba190021,0x00000000}},	//   _mēne, لمية_, _شيئا_,
  { {0x7aeb2154,0xc48208a6,0x2ed20053,0x00000000}},	//   ligt, ольк, _सत्त,
  { {0x86c5006a,0x23160086,0x69cb2155,0x00000000}},	//   _پيشن, иємс, lyge,
  { {0x29072156,0x7aeb1855,0x645a10f0,0x00000000}},	//   lona_, nigt, aati,
  { {0x645a2157,0x98a5008f,0xa91d005f,0x00000000}},	//   bati, _zilā_, _apži,
  { {0x03a5019d,0x04450002,0x645a2158,0x00000000}},	//   _вико, _текн, cati,
  { {0xb21b010a,0xd838007d,0xd00a005e,0x00000000}},	//   lfæl, _jača_, теве_,
  { {0xe5190053,0x2d80055b,0xd8380130,0x00000000}},	//   _नीति_, ttie_, _mača_,
  { {0xee372159,0x2907059d,0x7aeb215a,0x00000000}},	// [3300] рну_, kona_, digt,
  { {0x2d801380,0x7aeb004d,0x2907215b,0x00000000}},	//   rtie_, eigt, jona_,
  { {0xa7fc01f7,0xda7a0062,0x2d80215c,0x00000000}},	//   _adın, вял_, stie_,
  { {0x645a0037,0x2d80215d,0x0a670062,0x00000000}},	//   zati, ptie_, арши_,
  { {0x645a215e,0x660f00bd,0xbebb00ac,0x00000000}},	//   yati, ückl, _viët,
  { {0x2907215f,0x645a2160,0x7aeb0078,0x00000000}},	//   gona_, xati, aigt,
  { {0xe0b70047,0x68ea002b,0x645a2161,0x00000000}},	//   ילסט_, rifd, vati,
  { {0x645a18ab,0x69cb00b9,0xbebb0983,0x00000000}},	//   wati, byge, _hiër,
  { {0x29072162,0x645a2163,0x7bde0244,0x00000000}},	//   bona_, tati, lzpu,
  { {0xe7ff0042,0x29072164,0x961d0023,0x00000000}},	//   _ऊँचा_, cona_, teņr,
  { {0x9f45005b,0x7ae300ac,0xa5070002,0x00000000}},	//   çlü_, ëntg, реќа_,
  { {0x6d46017f,0xf5ea0076,0x79820022,0x00000000}},	//   _otka, _имел_, otow,
  { {0xc05b019d,0x79820045,0x645a077d,0x00000000}},	//   ків_, ntow, pati,
  { {0x41e80062,0x7aeb005f,0x00000000,0x00000000}},	//   рфюм_, zigt,   ,
  { {0x6458003d,0x6d46003d,0x251b0047,0x00000000}},	//   _ievi, _atka, _שווא,
  { {0x79820045,0x64581c40,0x290719b4,0x00000000}},	//   ktow, _hevi, zona_,
  { {0x29072165,0x79820ac3,0x64582166,0x00000000}},	// [3310] yona_, jtow, _kevi,
  { {0x40950032,0x2ba70001,0x29072167,0x00000000}},	//   _الدر, ијев, xona_,
  { {0xd0080079,0x7aeb00bd,0xbca40021,0x00000000}},	//   _веќе_, tigt, تملي,
  { {0x69cb01e3,0x290c002c,0x68e8001f,0x00000000}},	//   tyge, _akda_, _amdd,
  { {0x7aeb00e8,0x99d4007e,0x29070e94,0x00000000}},	//   rigt, يتها, tona_,
  { {0x7aeb2168,0x64582169,0x2907216a,0x00000000}},	//   sigt, _nevi, uona_,
  { {0x79820051,0x4758000d,0x69cb216b,0x00000000}},	//   atow, арыя_, syge,
  { {0x20d4024a,0x799b00a4,0x2907216c,0x00000000}},	//   _näin_, _tsuw, sona_,
  { {0x2738008b,0x6458216d,0x799b0051,0x00000000}},	//   _lĩnh_, _bevi, _usuw,
  { {0xa91d0006,0x04b50076,0x6aa0003b,0x00000000}},	//   _apžv, ссия, _zamf,
  { {0xd4c40032,0xd6db0001,0x7ae908ea,0x00000000}},	//   تغيي, _итд_, _kmet,
  { {0x98a5003b,0x9595005e,0x78a1216e,0x00000000}},	//   _filă_, _гркљ, _halv,
  { {0x68e80185,0x454504f6,0x7ae90290,0x00000000}},	//   _ymdd, _انتق, _mmet,
  { {0x6458021f,0x05b8007e,0xdddd0051,0x00000000}},	//   _gevi, _خدمت_, _odsł,
  { {0x66d50512,0x765900a4,0x78a108c9,0x00000000}},	//   _záka, _kewy, _malv,
  { {0x79820051,0x644109fe,0x7afb216f,0x00000000}},	//   ytow, lcli, _njut,
  { {0x6441003b,0x3c660085,0xeef5014b,0x00000000}},	// [3320] ocli, йкаг, цярэ,
  { {0x7afb2170,0x7ae90dfd,0x64410314,0x00000000}},	//   _ajut, _amet, ncli,
  { {0x2fd0000c,0x61200026,0x6aa02171,0x00000000}},	//   ângă_, tölf, _pamf,
  { {0x76590c70,0xdbd00114,0x63bc0137,0x00000000}},	//   _newy, _užív, ärni,
  { {0x6d462172,0xc2cd0041,0x6aa2005f,0x00000000}},	//   _utka, כמאָ, rdof,
  { {0x79820045,0x66d500ea,0x398000cd,0x00000000}},	//   rtow, _ráka, ròs_,
  { {0x765900e8,0xf0930063,0x64580951,0x00000000}},	//   _bewy, פנה_, _revi,
  { {0x79820045,0xe81e0161,0x64412173,0x00000000}},	//   ptow, येगा_, ecli,
  { {0x3ea202f0,0x7ae30162,0x78a1013d,0x00000000}},	//   _makt_, ënte, _falv,
  { {0x78a12174,0x7afb00c2,0xc34a0062,0x00000000}},	//   _galv, _zjut, ляме_,
  { {0x60c52175,0x20d40072,0xa6860794,0x00000000}},	//   _rohm, _päin_, _глед,
  { {0x765900e8,0x64430026,0x60dc0244,0x00000000}},	//   _gewy, _efni, ehrm,
  { {0x64412176,0x61200137,0xeab12177,0x00000000}},	//   bcli, köld, וֹם_,
  { {0x2738001b,0x6120007a,0x64a32178,0x00000000}},	//   _cũng_, jöld, _нача,
  { {0x673a00cd,0x2738008b,0xddc60022,0x00000000}},	//   _jutj, _dũng_, _tekś,
  { {0xbdd50076,0x5d55005a,0x2738008b,0x00000000}},	//   ообщ, жкат, _vĩnh_,
  { {0x60c50089,0xe167007e,0x3f8300a8,0x00000000}},	// [3330] _tohm, _ادبي, stju_,
  { {0xa7fc01f7,0x7ae90606,0x2738008b,0x00000000}},	//   _adım, _smet, _tĩnh_,
  { {0x69c4004b,0x7d0e01e1,0x8cbf0042,0x00000000}},	//   äien, _dkbs, लॉगो,
  { {0x5a150002,0x32122179,0x78a1169b,0x00000000}},	//   омеѓ, _yyyy_, _salv,
  { {0x78a1024a,0x5d7900b5,0xe29c0047,0x00000000}},	//   _palv, _דאָק, טשאר,
  { {0x17c90184,0xd90f007e,0x6d4d217a,0x00000000}},	//   игли_, ریا_, mpaa,
  { {0x6d4d217b,0x6e2001a8,0x78a10a18,0x00000000}},	//   lpaa, _úmbr, _valv,
  { {0x57a4000d,0x7ae9217c,0x7afb18d7,0x00000000}},	//   яшча, _umet, _ujut,
  { {0x78a1217d,0x27210013,0x6d4d217e,0x00000000}},	//   _talv, hóng_, npaa,
  { {0x33650928,0x83890121,0xd469005e,0x00000000}},	//   овог, абов_, јине_,
  { {0x2ca3000f,0x6441217f,0xf1a9009a,0x00000000}},	//   _majd_, rcli, _שס_,
  { {0x6b850185,0xc0490ee1,0xc5d52049,0x00000000}},	//   ithg, _יז_, _міль,
  { {0x3ea20137,0xd250005d,0x021a0054,0x00000000}},	//   _rakt_, وچک_, рінь_,
  { {0x628d004b,0x70560044,0xd6260131,0x00000000}},	//   _ebao, تنسا, _ќоше_,
  { {0x27380013,0x6d4d2180,0xae5a0054,0x00000000}},	//   _vũng_, epaa, ирає_,
  { {0x63ae00b9,0xee3f0014,0xa3e20042,0x00000000}},	//   æbne, _snýr_, _नेट_,
  { {0x6d4d00a4,0x63bc0137,0x3ea216af,0x00000000}},	// [3340] gpaa, ärnv, _vakt_,
  { {0xdced0058,0xabd600de,0x6bd600de,0x00000000}},	//   rtağ, يزات, يتار,
  { {0xeb9a17db,0x3ea22181,0x6d4d1450,0x00000000}},	//   рие_, _takt_, apaa,
  { {0x094a0f55,0xc9aa0b69,0xb4d60042,0x00000000}},	//   ачки_, ивее_, _सत्_,
  { {0x673a14b5,0x6b850139,0x0d75030b,0x00000000}},	//   _sutj, athg, _ныря,
  { {0x765d0026,0x83fc007d,0xed5705cf,0x00000000}},	//   ðsyn, lađe, _фор_,
  { {0xd6da2182,0xdb8314b4,0xcb671238,0x00000000}},	//   ити_, _огри, _маре_,
  { {0x83fc017f,0x758a0429,0xd5662183,0x00000000}},	//   nađe, асов_, отоп,
  { {0xc6f70088,0x66d50026,0x7c3900ea,0x00000000}},	//   ўных_, _tákn, _ábrá,
  { {0x39490331,0x6f160066,0x2db7069a,0x00000000}},	//   íase_, hlyc, קלין_,
  { {0xdc8b0aeb,0x80be0042,0x00000000,0x00000000}},	//   בְכָ, शाने,   ,
  { {0x66dc013d,0x62350121,0xddc40023,0x00000000}},	//   _béke, яему, mbiņ,
  { {0xe2980088,0x66d50114,0x64a62184,0x00000000}},	//   цаў_, _záko, _мада,
  { {0xdd3d0022,0xb606005f,0x7ce00244,0x00000000}},	//   rąży, rašę, _hörf,
  { {0x3ec7000d,0x403400fb,0x7ce02185,0x00000000}},	//   осаб, дерс, _körf,
  { {0x66d50a63,0xceb80001,0x6d4d083f,0x00000000}},	//   _nákl, ољу_, tpaa,
  { {0x3f9e0026,0xdce6005b,0x69c4004b,0x00000000}},	// [3350] ætur_, _askı, äiel,
  { {0x6d4d2186,0x7b180046,0xbc4b0085,0x00000000}},	//   rpaa, síul, рчае_,
  { {0x309a014e,0x6d400164,0x6d4d2187,0x00000000}},	//   _השתמ, _éman, spaa,
  { {0xb5fd0198,0x6d4d00fe,0x13bb0047,0x00000000}},	//   laše, ppaa, יזבע,
  { {0xdce7005b,0xbf6d004c,0x31792188,0x00000000}},	//   şlıc, říči, nusz_,
  { {0x9d18005a,0x4759005a,0x08c40454,0x00000000}},	//   _моят_, брия_, мбін,
  { {0xd378007d,0x7b6401a4,0x6b60013d,0x00000000}},	//   juć_, _отте, _vágá,
  { {0x6f0d2189,0x3179101d,0xe7080021,0x00000000}},	//   noac, kusz_, يتين_,
  { {0xe5710021,0x7ce0004d,0x31790022,0x00000000}},	//   رطة_, _dörf, jusz_,
  { {0xdced0512,0x66d5016b,0x6f0d0168,0x00000000}},	//   krač, _zákl, hoac,
  { {0x7ce001e3,0xd378007d,0xf3f10013,0x00000000}},	//   _förf, guć_, oại_,
  { {0x27210066,0xdced007d,0x6120013d,0x00000000}},	//   fóne_, drač, kölc,
  { {0x171a0047,0xe297014c,0xb5a7218a,0x00000000}},	//   _פונע, чая_, _фрей,
  { {0x6120004d,0xdced0445,0x64a501ea,0x00000000}},	//   wölb, frač, _хака,
  { {0x246700ea,0x320c0022,0x60231dd0,0x00000000}},	//   _című_, łdy_, едра,
  { {0x20d4004b,0x660f004d,0xee3a218b,0x00000000}},	//   _käik_, ückw, сна_,
  { {0x83fc017f,0xdced00c3,0x127b0047,0x00000000}},	// [3360] rađe, arač, _האפע,
  { {0x7ce00026,0x6f160137,0xb8860066,0x00000000}},	//   _mörg, slyc, _kríž,
  { {0x205700ff,0xeb97218c,0x316c0022,0x00000000}},	//   _מייל_, зих_, ądzu_,
  { {0xdce4017f,0x672900c2,0x63ae00b9,0x00000000}},	//   krić, jmej, åbni,
  { {0x7ae3006f,0xd3780022,0xa9780054,0x00000000}},	//   ënta, zuć_, ійку_,
  { {0x3f680058,0x67290331,0x98a50078,0x00000000}},	//   oğu_, emej, _kilę_,
  { {0xb8f40053,0x27210066,0x1be70cb2,0x00000000}},	//   _हक_, zóne_, _едри_,
  { {0xb8d30161,0x60270003,0xfaa30dc8,0x00000000}},	//   _जो_, lémé, _пасо,
  { {0x186a04d8,0xdced0392,0xba1701f3,0x00000000}},	//   _гази_, zrač, _فيفا_,
  { {0x443802ab,0x03f80001,0xb4d60053,0x00000000}},	//   ør_, жној_, ससे_,
  { {0x6f0d0035,0xdc8b009d,0x00000000,0x00000000}},	//   yoac, זְכָ,   ,
  { {0xdced00c3,0x7ce0218d,0xd7ef0021,0x00000000}},	//   vrač, _förg, _حكم_,
  { {0xbcfb0080,0xa5960086,0x7ce0218e,0x00000000}},	//   _svém, _хрещ, _körd,
  { {0x63bc0137,0xdced218f,0x317912a6,0x00000000}},	//   ärns, trač, rusz_,
  { {0x0f1b0021,0xf8b8008b,0xb5fd17cf,0x00000000}},	//   مغرب_, _nhĩm_, raše,
  { {0x7ce00137,0x59be0042,0xf413009a,0x00000000}},	//   _lörd, ्हार, _אפצ_,
  { {0x98a50078,0xdd94000d,0x290e00a8,0x00000000}},	// [3370] _eilę_, наты, kofa_,
  { {0x7ce02190,0xa1150021,0x672900a8,0x00000000}},	//   _nörd, _زوجت, zmej,
  { {0x6ce40086,0x67290072,0x6d4b0014,0x00000000}},	//   хіте, ymej, ígab,
  { {0x2ee0001f,0x64440058,0x917a0013,0x00000000}},	//   chif_, _şiil, _hất_,
  { {0x3ea9006f,0x7ce001bb,0xa969005e,0x00000000}},	//   mdat_, _börd, цила_,
  { {0x008a00b5,0x7ff4007e,0x3ea92191,0x00000000}},	//   ַרפֿ, _آسیا, ldat_,
  { {0x917a008b,0x3ea92192,0x7ce00058,0x00000000}},	//   _mất_, odat_, _dörd,
  { {0xd5490062,0xe29f0014,0x3ea92193,0x00000000}},	//   опие_, boði_, ndat_,
  { {0x7ce02063,0x67290659,0x2d892194,0x00000000}},	//   _förd, rmej, ntae_,
  { {0x3ea900fe,0x7ce00779,0x394d2195,0x00000000}},	//   hdat_, _görd, _ites_,
  { {0xdced0061,0xe29a02f9,0xf77004a0,0x00000000}},	//   hraď, оан_, _مان_,
  { {0x25a90130,0xa284005d,0x00000000,0x00000000}},	//   _šalu_, ریخو,   ,
  { {0x917a001b,0x3ea90137,0x7ce00c38,0x00000000}},	//   _bất_, ddat_, _höre,
  { {0x21670002,0x9f980014,0x661d2196,0x00000000}},	//   ќири_, _báða_, ýsku,
  { {0x25ad004b,0x248b005f,0x00000000,0x00000000}},	//   lvel_, ėkmę_,   ,
  { {0xf4120063,0xef1a0454,0x394d2197,0x00000000}},	//   _שפה_, іма_, _otes_,
  { {0xacca0086,0x25ad2198,0x394d0516,0x00000000}},	// [3380] огаз_, nvel_, _ntes_,
  { {0x3ea6001c,0x3ea92199,0x25ad00ea,0x00000000}},	//   žot_, adat_, ivel_,
  { {0x66dc0080,0x7ce00137,0x25ad004b,0x00000000}},	//   _léka, _rörd, hvel_,
  { {0x657b0072,0x1efa009a,0xbaba00de,0x00000000}},	//   kuuh, _וּ֝מ, غداء_,
  { {0xd00f006a,0xe8940065,0x7e64219a,0x00000000}},	//   _ملی_, еаль, maip,
  { {0x83fc007d,0x7e640078,0x274a005e,0x00000000}},	//   hađa, laip, очио_,
  { {0xd838007d,0x628400f8,0x7ce000a5,0x00000000}},	//   _jači_, _ocio, _vörd,
  { {0x7e640027,0x356a015a,0xf56a0c59,0x00000000}},	//   naip, орон_, ошок_,
  { {0x2a16000d,0xa5340071,0xd49a219b,0x00000000}},	//   _цьвё, ннич, орн_,
  { {0x7ce0219c,0x62840016,0x291800ea,0x00000000}},	//   _före, _acio, _óra_,
  { {0x7ce0219d,0x7e64002c,0x917a008b,0x00000000}},	//   _göre, kaip, _rất_,
  { {0x83fc0117,0xeb9100b5,0x9f980014,0x00000000}},	//   gađa, אָך_, _ráða_,
  { {0x660f004d,0x3ea900a5,0x41e715ce,0x00000000}},	//   ückt, vdat_, фіна,
  { {0x7ce0005b,0x61200072,0x65930085,0x00000000}},	//   _yöre, töla, _рашу,
  { {0x3ea90179,0x7ed70032,0x83fc007d,0x00000000}},	//   tdat_, وزرا, bađa,
  { {0xb5fd0117,0x2d89006f,0x2249005b,0x00000000}},	//   laša, ttae_, _ufak_,
  { {0x78ba0102,0x917a001b,0x3ea9219e,0x00000000}},	// [3390] _ontv, _tất_, rdat_,
  { {0xb5fd219f,0x78a804c8,0x6120013d,0x00000000}},	//   naša, _nadv, löln,
  { {0x394d00be,0x90540085,0x3a751135,0x00000000}},	//   _stes_, _швэц, елер,
  { {0x7ce000c7,0xaa580001,0xdbdc0026,0x00000000}},	//   _röre, дицу_, ráða,
  { {0x27210026,0x644a2158,0x991502fe,0x00000000}},	//   jóna_, _offi, нькі,
  { {0x8d5a00b5,0xf7710021,0x443c0089,0x00000000}},	//   _מכשי, هاب_, _ngv_,
  { {0x7ce001e3,0x7ae221a0,0x629d21a1,0x00000000}},	//   _förb, bhot, keso,
  { {0xbcfb0080,0x644a21a2,0x7ae221a3,0x00000000}},	//   _svéh, _affi, chot,
  { {0xe7080021,0x6f030331,0x6a17005d,0x00000000}},	//   بتون_, _íncu, _آبزر,
  { {0x628421a4,0x7ce021a5,0x98ac003b,0x00000000}},	//   _scio, _töre, _vidă_,
  { {0xa349000d,0x9475007e,0x398901a8,0x00000000}},	//   язна_, ودگا, lús_,
  { {0x660f00bd,0x629d21a6,0x644a1130,0x00000000}},	//   ücks, geso, _effi,
  { {0xa4d5019d,0x83fc007d,0xb21b00b9,0x00000000}},	//   _поді, rađa, dfæs,
  { {0x628b00c7,0xf992009f,0x64a221a7,0x00000000}},	//   _ögon, ארך_, _баша,
  { {0x7a36005b,0x7e6421a8,0x39890026,0x00000000}},	//   _kütü, taip, hús_,
  { {0xbea321a9,0x629d21aa,0x7649005b,0x00000000}},	//   ласк, ceso, ncey,
  { {0x7e6400eb,0x656921ab,0x12fb009a,0x00000000}},	// [33a0] raip, nseh, _מהקב,
  { {0xb53a0041,0x3157069a,0x853a009a,0x00000000}},	//   פגעש, _ריין_, פגעי,
  { {0xda6f21ac,0x78a82106,0x305b0063,0x00000000}},	//   ля_, _radv, _מדיד,
  { {0xb21b21ad,0x398901a8,0x7b2c0058,0x00000000}},	//   mfær, fús_, _aşur,
  { {0xb21b00b9,0x7ae21882,0x78a821ae,0x00000000}},	//   lfær, rhot, _padv,
  { {0x7ae20035,0xf8b8008d,0xd6d90022,0x00000000}},	//   shot, _khĩi_, ekł_,
  { {0x7a3601f7,0x5a960088,0x65690370,0x00000000}},	//   _bütü, _праф, eseh,
  { {0x6569004d,0x398921af,0xf7270085,0x00000000}},	//   fseh, bús_, нцый_,
  { {0xd627005e,0x7ae0004b,0x1a9b0041,0x00000000}},	//   ноће_, _ilmt, _צימע,
  { {0xdce40734,0xb21b0014,0xe8f70a3a,0x00000000}},	//   ksič, kfær, _злу_,
  { {0xb5fd21b0,0x656900a4,0x6ee3004b,0x00000000}},	//   raša, aseh, _hõbe,
  { {0x92580076,0xb21b00b9,0xb5fd0c61,0x00000000}},	//   нают_, dfær, mašn,
  { {0x612000ea,0x443c21b1,0xb5fd21b2,0x00000000}},	//   röln, _tgv_, paša,
  { {0x644a051e,0x2705001c,0x629d21b3,0x00000000}},	//   _uffi, mēna_, seso,
  { {0xb5fd01b3,0xb21b0026,0x2f270002,0x00000000}},	//   našn, gfær, еќав,
  { {0x539b014e,0x612000fe,0x3989006d,0x00000000}},	//   _זיהו, löll, yús_,
  { {0xb2740076,0x9d150054,0x201e0046,0x00000000}},	// [33b0] _слыш, вдач, ýtir_,
  { {0x612000fe,0x6abb21b4,0x6aa90150,0x00000000}},	//   nöll, _snuf, _saef,
  { {0xb5fd074f,0x9f4b0072,0xf0920063,0x00000000}},	//   jašn, ömät_, _דני_,
  { {0xb5fd017f,0xf4130047,0xfbd00021,0x00000000}},	//   dašn, אפע_, حتك_,
  { {0x6d4f013d,0x612021b5,0xbea40085,0x00000000}},	//   _utca, köll, _саўк,
  { {0x2be10161,0x66d50026,0x61200014,0x00000000}},	//   पनदा, _jákv, jöll,
  { {0x3989094a,0x3f47004b,0xddcd21b6,0x00000000}},	//   sús_, _jõu_, ngaž,
  { {0x65690019,0x291c21b7,0x00000000,0x00000000}},	//   tseh, alva_,   ,
  { {0x7ce00137,0xd3780051,0xd6ce0021,0x00000000}},	//   _höra, erć_, تقي_,
  { {0x66d5007a,0x7ce000c7,0x656900bd,0x00000000}},	//   _nákv, _köra, rseh,
  { {0x3f470019,0x656921b8,0x7a360058,0x00000000}},	//   _nõu_, sseh, _tütü,
  { {0x65690019,0x645e0019,0x7c3a0014,0x00000000}},	//   pseh, _õpin, _útre,
  { {0xe73001fb,0x8cc40042,0xe4d50044,0x00000000}},	//   _اصل_, रामो, _لتثب,
  { {0xfd660013,0x20d4004b,0x6d400003,0x00000000}},	//   _thuầ, _näit_, _émai,
  { {0x6f630002,0x26cf0022,0x2d990168,0x00000000}},	//   иврз, _kogo_, _apse_,
  { {0xf77200b5,0x26cf0016,0xe3b0007e,0x00000000}},	//   יקל_, _jogo_, _دره_,
  { {0xb21b1458,0x6e43005e,0x8c4621b9,0x00000000}},	// [33c0] lgæn, реуз, везе,
  { {0x26cf21ba,0xb21b007a,0x317b0aeb,0x00000000}},	//   _logo_, pfær, _קאיד,
  { {0x3eab0037,0x5f060088,0x6ee30019,0x00000000}},	//   _fact_, _азна, _sõbe,
  { {0x26cf085a,0x68e121bb,0x612018de,0x00000000}},	//   _nogo_, _alld, zöll,
  { {0x3ea01556,0x61200050,0xe8ea030b,0x00000000}},	//   meit_, yöll, ммдд_,
  { {0x7ce000c7,0x3ea021bc,0xbb560044,0x00000000}},	//   _föra, leit_, _لنسب,
  { {0x7ce000c7,0xf0930ca4,0x08d5000d,0x00000000}},	//   _göra, ינג_, ыцця,
  { {0xaf770047,0x20d4004b,0x6d5621bd,0x00000000}},	//   דעקס_, _käis_, opya,
  { {0xe4e60088,0x66d50240,0x96b7005e,0x00000000}},	//   вінн, _náku, тују_,
  { {0x3ea00199,0x80d10053,0xb5fd001c,0x00000000}},	//   heit_, _सकें, pašn,
  { {0x3ea00199,0x26cf0016,0x83fc007d,0x00000000}},	//   keit_, _fogo_, rađo,
  { {0xc2b80086,0x61200072,0x3ea0013d,0x00000000}},	//   влює_, söll, jeit_,
  { {0x316d03b2,0xdb21000f,0x394421be,0x00000000}},	//   éez_, ítés, _jums_,
  { {0x39441867,0xab6514b1,0x104b0076,0x00000000}},	//   _mums_, ngüí, ьями_,
  { {0xd838003d,0x601803d6,0xdb0e00be,0x00000000}},	//   _taču_, воря_, _arbí,
  { {0x3ea000ea,0x7ce00137,0x7ee40085,0x00000000}},	//   geit_, _röra, ацуе,
  { {0x1df8014c,0xbd68005e,0x9f340054,0x00000000}},	// [33d0] веты_, врхе_, реті,
  { {0x2fd80014,0x3f47004e,0x09be0042,0x00000000}},	//   byrg_, _tõu_, ्हैय,
  { {0x69d600d1,0x644f0051,0x6348004c,0x00000000}},	//   øyen, ścig, _měno,
  { {0x2d800529,0x3ea000e5,0x93fb009a,0x00000000}},	//   buie_, ceit_, ולבי,
  { {0xd84e008b,0x26cf2069,0xddcd0022,0x00000000}},	//   rọng_, _rogo_, ngaż,
  { {0x7ce00354,0x1b770044,0x23c20082,0x00000000}},	//   _hörn, _لدرج, षमाद,
  { {0x612000c7,0x0b880095,0xc7950021,0x00000000}},	//   följ, _исти_, اشتب,
  { {0x05a90086,0xbb840021,0x9585030b,0x00000000}},	//   евий_, _خلفي, глие,
  { {0xb5fd00eb,0x0445151b,0x39440168,0x00000000}},	//   rašo, лепн, _gums_,
  { {0x645e0004,0x3ea000bd,0xf4940054,0x00000000}},	//   _õpil, zeit_, арюю,
  { {0x69d921bf,0xe784000d,0x26cf21c0,0x00000000}},	//   lywe, _вучо, _togo_,
  { {0xb21b00b9,0x73e20071,0xe1ff21c1,0x00000000}},	//   rgæn, союз, raón_,
  { {0x69d900ac,0x645a1310,0x3ea021c2,0x00000000}},	//   nywe, bbti, veit_,
  { {0x3ea01855,0x645c0014,0xf1cb0014,0x00000000}},	//   weit_, ðrit, _spáð_,
  { {0x3ea021c3,0xdee61efa,0x7ce00026,0x00000000}},	//   teit_, гови, _börn,
  { {0x2d8021c4,0x6da6006e,0x7e550794,0x00000000}},	//   tuie_, либа, итуц,
  { {0x5185000a,0xb21b00b9,0x3ea021c5,0x00000000}},	// [33e0] _куќа, ngæl, reit_,
  { {0x3ea0000f,0x612000ea,0x10a61c9b,0x00000000}},	//   seit_, zölj, _сион,
  { {0x7ce000c7,0x78ae017d,0x394400e5,0x00000000}},	//   _förn, _óbvi, _sums_,
  { {0x628621c6,0x20d40019,0x298a08b0,0x00000000}},	//   ngko, _täis_, еско_,
  { {0xf548001b,0x69d9002b,0x2d8021c7,0x00000000}},	//   _mục_, gywe, quie_,
  { {0xf548001b,0x442700c2,0x6f0421c8,0x00000000}},	//   _lục_, _ozn_, lnic,
  { {0xebe60edd,0x6d4621c9,0xc7af0121,0x00000000}},	//   _совп, _huka, щё_,
  { {0x6d4621ca,0x6f0421cb,0x557406da,0x00000000}},	//   _kuka, nnic, агит,
  { {0x612000ea,0x6f0421cc,0x6d4621cd,0x00000000}},	//   rölj, inic, _juka,
  { {0x6d46024a,0x44f40086,0x6f0421ce,0x00000000}},	//   _muka, рпос, hnic,
  { {0x443801e3,0x27ea0146,0x6d4621cf,0x00000000}},	//   är_, _åbn_, _luka,
  { {0xf548008b,0x657b00c2,0x628608a9,0x00000000}},	//   _cục_, bruh, ggko,
  { {0x41e40088,0xf548008b,0xa2f4000d,0x00000000}},	//   біра, _dục_, спяч,
  { {0x672d0066,0x224c004c,0x6f0421d0,0x00000000}},	//   ňajt, ědka_, enic,
  { {0x6d460627,0x4035055d,0xc4f700ff,0x00000000}},	//   _auka, ревс, _תמוז_,
  { {0x6d460397,0xf3c9007e,0x2f180086,0x00000000}},	//   _buka, _جبهه_, гось_,
  { {0x6d460397,0x644f0051,0x8cf5000d,0x00000000}},	// [33f0] _cuka, ście, азац,
  { {0xeb0d0161,0xbcfb0003,0x6f0421d1,0x00000000}},	//   िक्त_, _avér, anic,
  { {0xfff9006a,0x7ce021d2,0xd4970063,0x00000000}},	//   _شکست_, _törn, רכבת_,
  { {0x7ce000c7,0xdced007d,0x6f040aca,0x00000000}},	//   _föro, krać, cnic,
  { {0x3f83017f,0xaa68005d,0xf86521d3,0x00000000}},	//   luju_, امهٔ_, авло,
  { {0x612000bd,0xe9d80088,0x69d921d4,0x00000000}},	//   völk, ыкі_, rywe,
  { {0x3f831e2e,0x6120004d,0x6d460e52,0x00000000}},	//   nuju_, wölk, _zuka,
  { {0x6d4601f7,0x7c3a0114,0x2b4d004c,0x00000000}},	//   _yuka, _útra, _čech_,
  { {0xc98700e1,0xbcfb0080,0x3f83007d,0x00000000}},	//   _љуби, _uvés, huju_,
  { {0x3f8320da,0x6f040e32,0xe9ff0013,0x00000000}},	//   kuju_, znic, _ngẩn_,
  { {0x3f83017f,0x78a310ce,0x98a7003b,0x00000000}},	//   juju_, menv, amnă_,
  { {0xdced017f,0x3f83007d,0x628600a4,0x00000000}},	//   brać, duju_, ugko,
  { {0x6f0421d5,0x628610c8,0xe44e0002,0x00000000}},	//   vnic, rgko, _мж_,
  { {0x6f040045,0x412a0928,0x6d4621d6,0x00000000}},	//   wnic, того_, _ruka,
  { {0xa2e60076,0x6d4621d7,0xf548001b,0x00000000}},	//   _войд, _suka, _tục_,
  { {0xb5fd08ea,0xdee30062,0x6d4621d8,0x00000000}},	//   jašk, ооси, _puka,

  { {0x7ce001e3,0x78a3006f,0xdcf60078,0x00000000}},	// [3400] _förl, kenv, sryč,
  { {0xccc30076,0x6f041aa5,0x6d46007d,0x00000000}},	//   обуй, snic, _vuka,
  { {0x307b0063,0x3f83007d,0x91830013,0x00000000}},	//   _באינ, cuju_, _iết_,
  { {0x9183008b,0x6d4621d9,0x41b3007e,0x00000000}},	//   _hết_, _tuka, _امیر,
  { {0x9183001b,0x6aa221da,0x644321db,0x00000000}},	//   _kết_, reof, _ogni,
  { {0x307a0047,0xdced007d,0x6aa20025,0x00000000}},	//   דאַנ, vrać, seof,
  { {0xe3a704de,0x6120013d,0x98a5008f,0x00000000}},	//   _بر_, rölh, _ailē_,
  { {0xd6d70076,0x3f7b0047,0xab2a0893,0x00000000}},	//   иты_, דאקס, _роба_,
  { {0x3f830117,0x645e0019,0x2d9200ac,0x00000000}},	//   zuju_, _õpik, ntye_,
  { {0x63b80080,0x3eb200fe,0x02af0053,0x00000000}},	//   _prvn, hdyt_, _जोड़न,
  { {0x7ce00137,0x66e605bd,0x2d920050,0x00000000}},	//   _rörl, _кожа, htye_,
  { {0x83fc017f,0x3f83007c,0xdced007d,0x00000000}},	//   nađi, vuju_, prać,
  { {0xbddb0268,0xe4e60086,0xf8da0053,0x00000000}},	//   _agèn, _війн, _बकाय,
  { {0x3f830397,0x3d100053,0xed590078,0x00000000}},	//   tuju_, ़कों_, _įž_,
  { {0x9f050032,0x2ee90185,0x43840032,0x00000000}},	//   موسو, thaf_, _العق,
  { {0x2fcd017f,0x3f83017f,0x643b0063,0x00000000}},	//   ćeg_, ruju_, _בעונ,
  { {0x7ce0000f,0xb5fd00c3,0x3f83017f,0x00000000}},	// [3410] _törl, vašk, suju_,
  { {0x7ce00d88,0x3e65008b,0x2ee9147f,0x00000000}},	//   _förm, ặt_, shaf_,
  { {0x7ce001f7,0x78a321dc,0x01340021,0x00000000}},	//   _görm, venv, _بعيد,
  { {0x83fc0130,0x0b44045b,0xf9910044,0x00000000}},	//   gađi, інін, كبت_,
  { {0x7e6d00a4,0xda09007e,0x91830013,0x00000000}},	//   maap, ديشه_, _yết_,
  { {0x612000fe,0x31580063,0xf74521dd,0x00000000}},	//   töli, סיון_, беко,
  { {0xb5fd21de,0x487801dd,0x78a317d6,0x00000000}},	//   maši, рсія_, renv,
  { {0xb5fd21df,0xfc4a0025,0x78a321e0,0x00000000}},	//   laši, _tríú_, senv,
  { {0x78a321e1,0x26cd00a8,0xdb0e21e2,0x00000000}},	//   penv, rjeo_, _urbá,
  { {0x612000ea,0xb5fd21e3,0x64440058,0x00000000}},	//   lölv, naši, _şiir,
  { {0x7ce001e3,0xc2c60021,0xc1d00053,0x00000000}},	//   _börj, ميدي, सङ्ग,
  { {0x47350138,0xc0490ee1,0x7ce000a5,0x00000000}},	//   _унес, _טז_, _rörm,
  { {0x27210026,0xb5fd21e4,0x290721e5,0x00000000}},	//   jóni_, kaši, onna_,
  { {0x64430078,0x270c004c,0x81d50085,0x00000000}},	//   _ugni, měna_, іцяц,
  { {0x2731008b,0xe8f5008b,0x290721e6,0x00000000}},	//   _cơng_, _đức_, inna_,
  { {0x63bc21e7,0x628d0025,0xe9ff008b,0x00000000}},	//   ærne, _gcao, _ngắn_,
  { {0x270c0080,0xe0da005a,0x91830013,0x00000000}},	// [3420] něna_, _бвп_, _tết_,
  { {0x2d9200e8,0x7e6d00a4,0xdcb10013,0x00000000}},	//   rtye_, aaap, _ửa_,
  { {0x3ea621e8,0x8a460044,0xbea621e9,0x00000000}},	//   _линг, مَان, _ланк,
  { {0x290721ea,0x0c370021,0x8f9b016e,0x00000000}},	//   enna_, حكمة_, _גיטי,
  { {0x83fc017f,0xdce40051,0x064b0047,0x00000000}},	//   rađi, esią, _האָט_,
  { {0x7ce021eb,0x270c004c,0xa9c50044,0x00000000}},	//   _mörk, děna_, تزمو,
  { {0xddd00022,0xace70062,0x7794005d,0x00000000}},	//   żeńs, _умра_, تیضا,
  { {0xf1050235,0x29070027,0x973c017f,0x00000000}},	//   _रद्द_, anna_, _opće,
  { {0xceb30063,0x78b10137,0x3f4e0013,0x00000000}},	//   ליה_, ökvä, _lýu_,
  { {0x628d0025,0xa534000d,0x7ae221ec,0x00000000}},	//   _scao, ўноч, lkot,
  { {0x4c9b0047,0x53350062,0x3cf00053,0x00000000}},	//   נשטע, жент, _इतने_,
  { {0x7ae20006,0x2d800150,0x4422008f,0x00000000}},	//   nkot, krie_, āk_,
  { {0x63480080,0x644f0051,0x656f0025,0x00000000}},	//   _měni, ścia, ácht,
  { {0x2d8000ca,0x7ae221ed,0x0577009a,0x00000000}},	//   drie_, hkot, _פגום_,
  { {0x7ae200fe,0x2b580089,0x2d8021ee,0x00000000}},	//   kkot, _ntrc_, erie_,
  { {0x7ce000c7,0x2d8002ab,0x0dcb0001,0x00000000}},	//   _förk, frie_, лузи_,
  { {0x290706d0,0x3c470021,0x7e6d21ef,0x00000000}},	// [3430] ynna_, مضاف, raap,
  { {0x61150086,0xdce40022,0x9c471afc,0x00000000}},	//   _єдну, ysią, схал,
  { {0xb5fd21f0,0x660f004d,0x2d8021f1,0x00000000}},	//   raši, ückz, arie_,
  { {0x2d80000c,0x291e1832,0xcb340062,0x00000000}},	//   brie_, _akta_, пехъ,
  { {0x6120000f,0xcec00080,0x2d801653,0x00000000}},	//   rölv, ářet_, crie_,
  { {0x6eea0024,0x2779000a,0xe9180054,0x00000000}},	//   _výbe, асиќ_, бочі_,
  { {0x4758000d,0x60dc0149,0xa6c921f2,0x00000000}},	//   брыя_, רקונ, илка_,
  { {0x96b90138,0xba77007e,0xddc4109f,0x00000000}},	//   руку_, _داست, laiš,
  { {0x7ae901f7,0x4ae4000d,0xceb40063,0x00000000}},	//   _ilet, _эўра, פיץ_,
  { {0x03950062,0xdced007d,0x395d002b,0x00000000}},	//   ормя, ksač, mpws_,
  { {0x7ae9021f,0x130a0076,0x33f50086,0x00000000}},	//   _klet, иной_, ючис,
  { {0xdb1c03b2,0x92f6013c,0xd5280013,0x00000000}},	//   _arrê, ічні, rốn,
  { {0x7ce001e3,0x6353000c,0x612000ea,0x00000000}},	//   _förh, _bănc, költ,
  { {0x7ae91216,0xab620058,0xc2430085,0x00000000}},	//   _llet, çükl, ьняк,
  { {0x7ae90d68,0x8ccd0053,0x5efa0ace,0x00000000}},	//   _olet, सानो, ахар_,
  { {0xc7b20063,0x2d802191,0x7ce00072,0x00000000}},	//   ובל_, trie_, _törk,
  { {0x2d8021f3,0xef17046e,0x644e005f,0x00000000}},	// [3440] urie_, іму_, žbie,
  { {0x612021f4,0x7ae921f5,0xdd8f01fb,0x00000000}},	//   tölu, _alet, ئول_,
  { {0xb5fd007d,0xa09b0149,0x27210195,0x00000000}},	//   mašu, _דייט, lónu_,
  { {0x63bc00c7,0xb5fd00c3,0x2d8021f6,0x00000000}},	//   årni, lašu, prie_,
  { {0xdb21000f,0x61200014,0x7ae221f7,0x00000000}},	//   ítás, sölu, rkot,
  { {0x7ae916d3,0xb5fd0006,0xd8f70086,0x00000000}},	//   _elet, našu, онії_,
  { {0xd90d007e,0x99e30066,0x7ae921f8,0x00000000}},	//   دیل_, ĺňan, _flet,
  { {0x7c2e01a6,0x6b7c003b,0xddc4008f,0x00000000}},	//   _izbr, răgă, rciņ,
  { {0x29000016,0xc896005e,0x9f9f0003,0x00000000}},	//   éias_, _мржњ, réée_,
  { {0x07a606be,0x44970121,0xb4e40053,0x00000000}},	//   _мазн, овью_, नसे_,
  { {0xd6da007e,0x291c21f9,0xb6cc0058,0x00000000}},	//   _پوشش_, mova_, çüsü,
  { {0xfc460080,0x27210066,0x79820022,0x00000000}},	//   šího_, fónu_, orow,
  { {0x61200026,0x7982002b,0x2721011b,0x00000000}},	//   jöls, nrow, gónu_,
  { {0x7ce00137,0x691f00ac,0x613200b9,0x00000000}},	//   _föri, lêer, jæld,
  { {0x3e6b000a,0x270c0080,0x386c001f,0x00000000}},	//   ишан_, něno_, _medr_,
  { {0x9f050021,0x291c21fa,0x7d550062,0x00000000}},	//   أورو, hova_, звах,
  { {0x291c055e,0x6120000f,0x61320146,0x00000000}},	// [3450] kova_, tölt, fæld,
  { {0x61320146,0x7ae90dfb,0xb5fd007d,0x00000000}},	//   gæld, _slet, mašt,
  { {0xf0920132,0xb5fd017f,0x79820051,0x00000000}},	//   _אני_, lašt, erow,
  { {0xdcc40053,0x79820022,0xdb15004c,0x00000000}},	//   राउज़, frow, _trzí,
  { {0x386c0fc8,0xb5fd007d,0xc9640054,0x00000000}},	//   _bedr_, našt, двій,
  { {0xf548008b,0x291c027c,0x4dda0063,0x00000000}},	//   _cụm_, gova_, _החשו,
  { {0xf7710021,0x98a20065,0x79820022,0x00000000}},	//   ءات_, хище, arow,
  { {0xdce40051,0x22490150,0x798221fb,0x00000000}},	//   dsię, _ngak_, brow,
  { {0xdce40051,0x644700b2,0x7982133f,0x00000000}},	//   esię, žjim, crow,
  { {0x2249053b,0x291c21fc,0x3ea90168,0x00000000}},	//   _agak_, cova_, heat_,
  { {0x644f0045,0x1425000d,0x3ea90072,0x00000000}},	//   ścio, ядом, keat_,
  { {0x657a0139,0xe29a1406,0x2721017c,0x00000000}},	//   óchú, щам_, tónu_,
  { {0x3392005d,0x394521fd,0xdce4056c,0x00000000}},	//   ولیز, _kils_, asię,
  { {0xd47900b5,0x55ba0063,0xa7fc005b,0x00000000}},	//   _האַל, _למנו, _adıy,
  { {0x3ea90034,0x613221fe,0xb5fd21ff,0x00000000}},	//   feat_, væld, rašu,
  { {0xc7b200b5,0x25ad0d1e,0x27210195,0x00000000}},	//   עבן_, owel_, pónu_,
  { {0x25ad1a50,0x394d00f4,0x6da30962,0x00000000}},	// [3460] nwel_, _nues_, нита,
  { {0x6d230001,0xdb1c0164,0x2705001c,0x00000000}},	//   едуз, _irré, mēnu_,
  { {0x61320146,0x7ac6005a,0x25ad002b,0x00000000}},	//   ræld, зсле, hwel_,
  { {0x25ad0dac,0x7982102e,0xec1301fb,0x00000000}},	//   kwel_, trow, روند,
  { {0x25ad0122,0x291c1b9d,0x79820022,0x00000000}},	//   jwel_, tova_, urow,
  { {0x394d0268,0x79820034,0x291c0290,0x00000000}},	//   _dues_, rrow, uova_,
  { {0x3f980469,0x386c00b9,0x7c2e2200,0x00000000}},	//   ntru_, _vedr_, _uzbr,
  { {0x79820045,0x7d1e2201,0x291c2202,0x00000000}},	//   prow, lops, sova_,
  { {0x39452203,0x291c2204,0x394d01a8,0x00000000}},	//   _fils_, pova_, _gues_,
  { {0x93780239,0xb5fd007d,0x3f982205,0x00000000}},	//   обот_, vašt, ktru_,
  { {0x7ce000c7,0xdb070014,0xddcd0075,0x00000000}},	//   _förv, _grjó, kbaş,
  { {0x52a70021,0xdce40078,0x69c02206,0x00000000}},	//   أصدق, priė, _krme,
  { {0x7d1e00e8,0xe298000d,0x3ea9113c,0x00000000}},	//   kops, чаў_, veat_,
  { {0xa63b014e,0xb5fd00fc,0xe424007e,0x00000000}},	//   _הגדר, rašt, _يکدي,
  { {0x7d1e2207,0xc49b0063,0x6353003b,0x00000000}},	//   dops, _השות, _tăna,
  { {0xf709008b,0x69c016dd,0x9f51013d,0x00000000}},	//   hần_, _orme, nzzé_,
  { {0x3ea91729,0x3f982208,0x6348004c,0x00000000}},	// [3470] reat_, atru_, _věnu,
  { {0x394d0164,0x3f8a0035,0x61ef005b,0x00000000}},	//   _rues_, bubu_, ınlı,
  { {0x3ea92209,0x7b640071,0x9be4000d,0x00000000}},	//   peat_, етче, ніцк,
  { {0x394d02dd,0x628f220a,0x25ad002b,0x00000000}},	//   _pues_, ngco, ywel_,
  { {0x2a6d0019,0x7e7d069f,0x6f0d2082,0x00000000}},	//   _veeb_, _idsp, mnac,
  { {0x475903d6,0x6f0d00bd,0x394d0003,0x00000000}},	//   ория_, lnac, _vues_,
  { {0x2a6d0004,0xe73901d5,0x6f0d220b,0x00000000}},	//   _teeb_, оек_, onac,
  { {0x6458220c,0x6f0d057a,0x657d00ea,0x00000000}},	//   _afvi, nnac, ásho,
  { {0x6d470441,0x6d4f003b,0x394d0019,0x00000000}},	//   _kija, _juca, _uues_,
  { {0x7ce0220d,0x1868005e,0x6f0d220e,0x00000000}},	//   _föru, _нађи_, hnac,
  { {0x6d47220f,0x6d4f2210,0x7e7d2211,0x00000000}},	//   _mija, _luca, _odsp,
  { {0x7ce0004d,0x6d5d021e,0xdced0058,0x00000000}},	//   _hört, _otsa, yrağ,
  { {0x2360017f,0x6d5d00ac,0x7ce001e9,0x00000000}},	//   _čije_, _ntsa, _kört,
  { {0x3f8a0035,0x67292212,0x69b00053,0x00000000}},	//   tubu_, llej, _आईसी,
  { {0x6d5d20b4,0x672913e4,0x7cf201e1,0x00000000}},	//   _atsa, olej, _hærg,
  { {0xbfc3005a,0x2705001c,0x3f8a1a11,0x00000000}},	//   ъбск, mēns_, rubu_,
  { {0x44270c70,0xed4600d7,0xddcd2213,0x00000000}},	// [3480] _hyn_, днап, rbaş,
  { {0x3e6c001b,0x6e2b00bd,0x6d4f1c6c,0x00000000}},	//   ết_, ügba, _duca,
  { {0xdced017f,0x6d472214,0x6d4f02e3,0x00000000}},	//   građ, _dija, _euca,
  { {0x673b0045,0xbae50086,0x44272215,0x00000000}},	//   jmuj, нцій, _myn_,
  { {0x6d472216,0x44272217,0x7ce0013d,0x00000000}},	//   _fija, _lyn_, _bört,
  { {0x765900ac,0x644f0051,0xf7090013,0x00000000}},	//   _afwy, ścij, uần_,
  { {0x672902dd,0x98be001c,0xf7090013,0x00000000}},	//   flej, _citā_, rần_,
  { {0x67290198,0xd6d00032,0x7ce0007a,0x00000000}},	//   glej, اقة_, _vöru,
  { {0x7ce000c7,0x69c0000c,0x7cf2069f,0x00000000}},	//   _fört, _urme, _værf,
  { {0x6f0d0045,0x67290072,0x44272218,0x00000000}},	//   znac, alej, _byn_,
  { {0x44270185,0x6ef10146,0xd4970be6,0x00000000}},	//   _cyn_, _håbe, фры_,
  { {0x44270185,0x92580076,0x672900cd,0x00000000}},	//   _dyn_, мают_, clej,
  { {0x4427004d,0x914b000d,0xdced007d,0x00000000}},	//   _eyn_, ючна_, zrađ,
  { {0x44272219,0x6720013d,0x2ea70042,0x00000000}},	//   _fyn_, lomj, ख़्त,
  { {0x4427001f,0x48f90047,0x6d47221a,0x00000000}},	//   _gyn_, פּשא, _rija,
  { {0x6d47024a,0x2cb80250,0x7cf2221b,0x00000000}},	//   _sija, _aard_, _lærd,
  { {0x5067005a,0x6f0d2025,0x4427006f,0x00000000}},	// [3490] _отна, rnac, _zyn_,
  { {0x2cb809ee,0x6f0d0333,0xf5480013,0x00000000}},	//   _card_, snac, _bụi_,
  { {0xf1bf017d,0x673b0051,0x6720007d,0x00000000}},	//   lvá_, ymuj, komj,
  { {0x7e7d00b9,0x6d470150,0xdbd10019,0x00000000}},	//   _udsp, _wija, müüg,
  { {0x6d5d02f0,0x67201844,0x98dd0085,0x00000000}},	//   _utsa, domj, йскi,
  { {0x798b0438,0x3eb90359,0xa7b50d34,0x00000000}},	//   rugw, _hast_, есиј,
  { {0x67290004,0xddc6001c,0x25a6132b,0x00000000}},	//   tlej, _iekš, _apol_,
  { {0x7ce0221c,0x4427221d,0xe9ff0013,0x00000000}},	//   _förs, _ryn_, _ngần_,
  { {0x7cf20146,0x7ce0221e,0x2cb8221f,0x00000000}},	//   _færd, _tört, _yard_,
  { {0x442700ac,0x3eb92220,0x7cf22221,0x00000000}},	//   _pyn_, _last_, _værg,
  { {0xc2090063,0xf770007e,0x67292222,0x00000000}},	//   _פה_, _نان_, plej,
  { {0x7af9005b,0x44270137,0x660a004c,0x00000000}},	//   _çatı, _vyn_, ámká,
  { {0x7cf202ab,0x44270e7f,0x35a50854,0x00000000}},	//   _hære, _wyn_, _чалг,
  { {0x7cf200b9,0x64550058,0x645e004b,0x00000000}},	//   _kære, ızis, _õpip,
  { {0x6ee3004b,0x8fa3064b,0x70530021,0x00000000}},	//   _lõbu, ларе, انفا,
  { {0x3eb9094f,0x2cb82223,0x6eea004a,0x00000000}},	//   _cast_, _sard_, _výbo,
  { {0x7cf20831,0x290e002b,0x7206005d,0x00000000}},	// [34a0] _lære, ynfa_, _سودم,
  { {0x3eb90034,0xe29f0026,0x61e60078,0x00000000}},	//   _east_, miða_, mykl,
  { {0x3eb92224,0xe29f0026,0xd11d0053,0x00000000}},	//   _fast_, liða_, पकरण_,
  { {0x2fc50146,0x6ef10d02,0x7cf2000e,0x00000000}},	//   ælge_, _påbe, _særd,
  { {0x2cb80bbd,0x7ce00137,0xf709008d,0x00000000}},	//   _tard_, _dörr, gầm_,
  { {0x6ef10146,0x7cf206a5,0x290e0331,0x00000000}},	//   _våbe, _bære, unfa_,
  { {0x7cf2010a,0x7ce000c7,0xe29f0026,0x00000000}},	//   _værd, _förr, yfð_,
  { {0x61e600eb,0xfd4d0013,0x8f9b00ff,0x00000000}},	//   kykl, _nghị, ליצי,
  { {0x60de00e8,0x6720017f,0xd251007e,0x00000000}},	//   _oopm, romj, یند_,
  { {0xdb1500bd,0x61e60006,0x7cf20014,0x00000000}},	//   _erzä, dykl, _fære,
  { {0xccf3014e,0xe29f0014,0x4c9b009d,0x00000000}},	//   רכת_, eiða_, הביו,
  { {0x7c3a0026,0xf1bf01d9,0x27e1004d,0x00000000}},	//   _útru, tvá_, ähne_,
  { {0x61e60078,0x84e605f4,0x3eb92225,0x00000000}},	//   gykl, _подж, _rast_,
  { {0x752100cd,0x31350f0a,0xe9ce0085,0x00000000}},	//   colz, тегр, ркi_,
  { {0x3eb90625,0x3ea02226,0x78ba2227,0x00000000}},	//   _past_, ffit_, _matv,
  { {0x78ba2228,0x7cf204aa,0xdb23013d,0x00000000}},	//   _latv, _nærb, érün,
  { {0x2ee92229,0x3eb9222a,0x61e6100a,0x00000000}},	// [34b0] rkaf_, _vast_, cykl,
  { {0x2ee900ac,0xdbd1004b,0x645a2158,0x00000000}},	//   skaf_, püüg, ncti,
  { {0x7cf202ab,0x3eb9222b,0x645a222c,0x00000000}},	//   _bærb, _tast_, icti,
  { {0x9980005b,0xc01c008b,0x63a5004d,0x00000000}},	//   çiş_, _lược_, _ähne,
  { {0x442b001b,0x7cf201f2,0x99d701f3,0x00000000}},	//   ́c_, _sære, عتصا,
  { {0x31580063,0x09e20054,0xf709008d,0x00000000}},	//   עיון_, рошн, rầm_,
  { {0x8aa70088,0xac180413,0x61e608ae,0x00000000}},	//   _прад, _зору_, zykl,
  { {0x78a40117,0x7cf202ab,0x645a222d,0x00000000}},	//   điva, _være, ecti,
  { {0x7ce00199,0x2360017f,0x05760021,0x00000000}},	//   _körp, _čija_, نمية_,
  { {0x25bf00ac,0x6abb05cc,0x78ba0006,0x00000000}},	//   rvul_, _hauf, _gatv,
  { {0xc6e7019d,0x399b0016,0x6385005a,0x00000000}},	//   _підп, lês_, ъгна,
  { {0x78ba222e,0xe1ff222f,0x91e60e5e,0x00000000}},	//   _zatv, rbón_, воме,
  { {0x399b03d9,0x98be003b,0xfad60047,0x00000000}},	//   nês_, _uită_, דורך_,
  { {0x6abb00bd,0x2d8900e8,0xe1ff013d,0x00000000}},	//   _lauf, drae_, mból_,
  { {0x61e600eb,0x3ea0059f,0xe1ff013d,0x00000000}},	//   sykl, tfit_, lból_,
  { {0x29070273,0x24160063,0xfb82007e,0x00000000}},	//   hina_, _שחקן_, یگزی,
  { {0x657b00e3,0x29072230,0x60de2231,0x00000000}},	// [34c0] nsuh, kina_, _topm,
  { {0x98be00eb,0xee371736,0x29072232,0x00000000}},	//   _kitą_, тну_, jina_,
  { {0x644f0045,0x29072233,0x6abb004d,0x00000000}},	//   ściw, dina_, _bauf,
  { {0xbad5000d,0xe1ff00ea,0x657b021e,0x00000000}},	//   лічы, kból_, ksuh,
  { {0x78ba00eb,0x7ce00137,0x29072234,0x00000000}},	//   _patv, _förp, fina_,
  { {0x29072235,0xe1ff013d,0xab640058,0x00000000}},	//   gina_, dból_, ttüğ,
  { {0x27e700d1,0x9f5c0050,0xddd60022,0x00000000}},	//   gynn_, _ävä_, ybyś,
  { {0x399b017d,0xf5480013,0x29072236,0x00000000}},	//   bês_, _lụt_, aina_,
  { {0x29072237,0x399b0016,0x657b00a4,0x00000000}},	//   bina_, cês_, gsuh,
  { {0x6abb0051,0x69c200f5,0x29072070,0x00000000}},	//   _zauf, mvoe, cina_,
  { {0x2b9c0024,0x69c20229,0xd251007e,0x00000000}},	//   níc_, lvoe, ینگ_,
  { {0x693500dd,0x85ea0131,0x958601ce,0x00000000}},	//   rşeş, _одев_, _алде,
  { {0x69c20173,0x7ae3017d,0x394c2238,0x00000000}},	//   nvoe, ênti, _kids_,
  { {0x2d8900e8,0x55770047,0xc50a0021,0x00000000}},	//   vrae_, _יעדן_, _تتصل_,
  { {0xcebb0001,0x9f45004c,0x2b9c01c8,0x00000000}},	//   мља_, šlí_, jíc_,
  { {0xbd6b0001,0x2d892239,0x200c0066,0x00000000}},	//   држе_, trae_, údia_,
  { {0x69c2006f,0x3f8a223a,0x6abb223b,0x00000000}},	// [34d0] jvoe, arbu_, _rauf,
  { {0x2c7c0080,0x657d00ea,0x6abb223c,0x00000000}},	//   vádí_, áshi, _sauf,
  { {0x69c20250,0x2907223d,0xfd44000d,0x00000000}},	//   evoe, vina_, рэтн,
  { {0xbcfb0025,0x7ae01beb,0x3f91005b,0x00000000}},	//   _dtéa, _comt, muzu_,
  { {0x69c2021f,0x394c0465,0xca840054,0x00000000}},	//   gvoe, _bids_, ргій,
  { {0x399b017d,0x2907223e,0x7c22003b,0x00000000}},	//   rês_, uina_, şora,
  { {0x3f9101f7,0x6abb223f,0x29072240,0x00000000}},	//   nuzu_, _tauf, rina_,
  { {0xe1ff00ea,0x29072241,0xdb15013d,0x00000000}},	//   tból_, sina_, _oszé,
  { {0x613200b9,0x29071625,0xc9870141,0x00000000}},	//   fæll, pina_, _јуби,
  { {0x394c1a20,0x290700ac,0xe1ff00ea,0x00000000}},	//   _gids_, qina_, rból_,
  { {0x657b003a,0xe1ff00ea,0x29050058,0x00000000}},	//   ssuh, sból_, _imla_,
  { {0x68e12242,0xcad50063,0xf5480013,0x00000000}},	//   _hold, אוֹת_, _sụt_,
  { {0x68e12243,0x64a5129d,0x667a009a,0x00000000}},	//   _kold, _бала, _נטסק,
  { {0x3f910035,0x29350041,0x7bc7214c,0x00000000}},	//   fuzu_, טאָן_, _orju,
  { {0x343900b7,0x68e12244,0x4424007e,0x00000000}},	//   _אײַע, _mold, _پروف,
  { {0x6ee30004,0x2b9c0080,0x69c200ac,0x00000000}},	//   _sõbr, víc_, yvoe,
  { {0x62841513,0xf5480013,0x7ae02245,0x00000000}},	// [34e0] _idio, _tụt_, _romt,
  { {0x7ae000f5,0x6120004d,0x01fb009a,0x00000000}},	//   _somt, hölz, _נפיל,
  { {0xdb1c2246,0x409b0047,0xb09b009f,0x00000000}},	//   _arrá, _אביס, _אייר,
  { {0x69c20ac8,0x9b250603,0x29052247,0x00000000}},	//   tvoe, афіл, _amla_,
  { {0xddc4001c,0x2b9c0114,0x187402fe,0x00000000}},	//   laiž, síc_, агля,
  { {0x69c20173,0xdd9f0080,0x26cf0035,0x00000000}},	//   rvoe, ěňte_, _ango_,
  { {0x2d92006d,0x7ae00114,0x69c20104,0x00000000}},	//   luye_, _tomt, svoe,
  { {0x47340002,0x78a30014,0x6d4e2248,0x00000000}},	//   јнис, afnv, _hiba,
  { {0x6d4e0009,0x613200b9,0x2d92006d,0x00000000}},	//   _kiba, tæll, nuye_,
  { {0x68e103a3,0x29ce0014,0xd9460062,0x00000000}},	//   _gold, aðað_, _сези,
  { {0x69ba0042,0xe2f9071f,0xe766005e,0x00000000}},	//   _एनडी, вені_, _свеп,
  { {0x973c017f,0xa159000d,0x68e10f89,0x00000000}},	//   _opći, каму_, _zold,
  { {0x6284001f,0x68e1005b,0x94d40002,0x00000000}},	//   _ddio, _yold, _волц,
  { {0x628400a4,0xe104000d,0xbcfb01d1,0x00000000}},	//   _edio, бясп, _atén,
  { {0xe44f0242,0x24a20078,0x60181501,0x00000000}},	//   _عضو_, ėsmę_, горя_,
  { {0x98a7008f,0x6d4e00be,0xaf3701fb,0x00000000}},	//   ilnā_, _aiba, ارست,
  { {0x6353003b,0x5c751340,0x442e00a3,0x00000000}},	// [34f0] _răni, илат, _hyf_,
  { {0x7c2e00c7,0x2d870648,0x6d4e01f4,0x00000000}},	//   _bybr, čne_, _ciba,
  { {0x6d4e014f,0xaa551225,0xba550002,0x00000000}},	//   _diba, авеш, авеј,
  { {0x2d92006d,0xcb682249,0xab2b0593,0x00000000}},	//   buye_, امنه_, رسال_,
  { {0xe9870001,0x2a980021,0x4e7a0063,0x00000000}},	//   ућен, ائمة_, _בארצ,
  { {0x6d4e224a,0xe0d50041,0x2b4d0022,0x00000000}},	//   _giba, שײַ_, _wiec_,
  { {0x68e1224b,0xf6510021,0x5884000d,0x00000000}},	//   _vold, يئة_, сыча,
  { {0x6d4e0035,0x45850121,0x69e80139,0x00000000}},	//   _ziba, агив, íseá,
  { {0x1959000d,0x29ce0026,0xe576014c,0x00000000}},	//   _разы_, rðað_, азы_,
  { {0xb3a9005b,0x6d4e0331,0x94250caa,0x00000000}},	//   _çıkı, _xiba, импе,
  { {0xb4e5016a,0x442e002b,0x03a5224c,0x00000000}},	//   _नवी_, _cyf_, шино,
  { {0x69c9224d,0xdced0078,0xdce4008f,0x00000000}},	//   _kree, praė, oriģ,
  { {0x7f570164,0x956700a0,0x3eb20058,0x00000000}},	//   _auxq, _съед, veyt_,
  { {0x6724007d,0xbcfb006c,0x044505ce,0x00000000}},	//   čije, _stén, _келн,
  { {0x6d4e224e,0x6ef101e1,0x6aa90137,0x00000000}},	//   _riba, _våbn, _obef,
  { {0xe8df001b,0x2d9202dd,0x6aa901e1,0x00000000}},	//   _muốn_, tuye_, _nbef,
  { {0xed5701aa,0xd1320021,0xad650021,0x00000000}},	// [3500] иот_, _ومع_, ماله,
  { {0x2d92006d,0x717b0063,0xdd8f0044,0x00000000}},	//   ruye_, _שניס, بوك_,
  { {0x1d19019d,0xbea6000d,0xeb9a1369,0x00000000}},	//   ують_, _канк, тие_,
  { {0x298a006e,0x7c2e0114,0x69c90112,0x00000000}},	//   вско_, _vybr, _bree,
  { {0x7c2e0045,0xc333014e,0x2a69006d,0x00000000}},	//   _wybr, קוד_, ñaba_,
  { {0x6f160d10,0x69c9224f,0x5a330054,0x00000000}},	//   lnyc, _dree, цніт,
  { {0xe8df008b,0x69c90104,0x2d802250,0x00000000}},	//   _cuốn_, _eree, lsie_,
  { {0x6b83000c,0x69c91a70,0x6f162251,0x00000000}},	//   ânge, _free, nnyc,
  { {0x2d802252,0x69c92253,0x3f5c0013,0x00000000}},	//   nsie_, _gree, _líu_,
  { {0x2d8017a6,0x44f42254,0xe1ff0014,0x00000000}},	//   isie_, спос, sbók_,
  { {0x443804b1,0x3f5c2255,0xdce40023,0x00000000}},	//   år_, _níu_, stiķ,
  { {0x2d80160c,0x442e00e8,0x6f160045,0x00000000}},	//   ksie_, _vyf_, jnyc,
  { {0x6f161e13,0x442e001f,0xd9f80053,0x00000000}},	//   dnyc, _wyf_, ्छित_,
  { {0xddcf000c,0x15fb0063,0xc10b014b,0x00000000}},	//   _lecţ, _שִׁמ, тэме_,
  { {0x40350002,0x75280051,0x6353003b,0x00000000}},	//   севс, modz, _bănu,
  { {0x30140086,0x27210066,0x75282256,0x00000000}},	//   ідтр, fóny_, lodz,
  { {0x7cf205b9,0x752800ca,0x25ec0042,0x00000000}},	// [3510] _værn, oodz, आईटी_,
  { {0xebc70001,0x6f160051,0xeb1f0053,0x00000000}},	//   иљен, anyc, यक्त_,
  { {0x2d802257,0x6f160051,0xe1ff013d,0x00000000}},	//   asie_, bnyc, lzó_,
  { {0x69c92258,0x75281a03,0x6f162259,0x00000000}},	//   _pree, hodz, cnyc,
  { {0xe1ff02dd,0x7cf20583,0x5df90047,0x00000000}},	//   nzó_, _kærl, _עפֿנ,
  { {0x69c90173,0x6f0d225a,0xed56009a,0x00000000}},	//   _vree, liac, _לבשר_,
  { {0x69c9006f,0x6d45004d,0xd0f80063,0x00000000}},	//   _wree, mmha, שמות_,
  { {0x6d450027,0x660d0026,0x70180063,0x00000000}},	//   lmha, _þakk, יחוד_,
  { {0x6d450025,0x8cdb0042,0x14d500de,0x00000000}},	//   omha, नापो, مزدح,
  { {0x6f0d051e,0x6d450025,0x6f1606ce,0x00000000}},	//   hiac, nmha, znyc,
  { {0x656902f7,0x6d45004d,0xf8b30042,0x00000000}},	//   speh, imha, ंजीप,
  { {0x6d450025,0xdce400c2,0x61320026,0x00000000}},	//   hmha, vpič, mæli,
  { {0xe2970076,0x6f160024,0x3f5c0026,0x00000000}},	//   щая_, vnyc, _síu_,
  { {0xd466019d,0x6f160051,0x6146026b,0x00000000}},	//   _лише_, wnyc, сега,
  { {0x33950021,0xc2ea0021,0x201e005b,0x00000000}},	//   _العز, _معظم_, çti_,
  { {0x3f5c008d,0x6b65005f,0x6f0d225b,0x00000000}},	//   _víu_, _mėgd, giac,
  { {0x7f4400f4,0x82970063,0x6f16225c,0x00000000}},	// [3520] rmiq, _הדפס_, rnyc,
  { {0x2d80225d,0xddcf0529,0x6d450025,0x00000000}},	//   rsie_, _secţ, gmha,
  { {0xb5fd00eb,0xf53600b5,0x2d80225e,0x00000000}},	//   rašy, צטער_, ssie_,
  { {0x2d8000e8,0x6f0d225f,0x639a0047,0x00000000}},	//   psie_, ciac, טסענ,
  { {0x08540086,0x8e070062,0x929b009d,0x00000000}},	//   овлю, _гняв_, רינת,
  { {0x7cf200b9,0x6eea0114,0x2b58151d,0x00000000}},	//   _kærm, _výbu, _turc_,
  { {0x3706042c,0xd7c60121,0x75280066,0x00000000}},	//   йчив, сёло, vodz,
  { {0x75280051,0xe8df008b,0x9c170063,0x00000000}},	//   wodz, _buồn_, _החלק_,
  { {0x75280022,0x186a2260,0x4a5b009d,0x00000000}},	//   todz, _бази_, _תדמו,
  { {0xe29f0026,0x6f0d2261,0x00000000,0x00000000}},	//   miði_, ziac,   ,
  { {0x63a500bd,0x7cf21920,0xe29f0026,0x00000000}},	//   _ähnl, _nærm, liði_,
  { {0x7cf20205,0x290e0c75,0x083b0047,0x00000000}},	//   _særl, lifa_, _געבל,
  { {0x79820051,0x26c3001c,0xbb3b0047,0x00000000}},	//   nsow, ējot_, טעטי,
  { {0x2b460066,0xe1ff19ad,0xb08b0085,0x00000000}},	//   ňoch_, rzó_, ыёме_,
  { {0xe1ff2262,0x6f0d0b6a,0xdfd80062,0x00000000}},	//   szó_, tiac, бът_,
  { {0x79820051,0x290e0035,0x212a0139,0x00000000}},	//   ksow, hifa_, aobh_,
  { {0x28b90053,0x6f0d2263,0x21640085,0x00000000}},	// [3530] _इसलि, riac, _нтэг,
  { {0x6f0d0024,0x40350002,0x2295005d,0x00000000}},	//   siac, _мепс, _الکس,
  { {0x6f0d2264,0x6d452265,0x2d4d0130,0x00000000}},	//   piac, rmha, _užem_,
  { {0xf2d400b5,0x6d450025,0x98a70078,0x00000000}},	//   ּעס_, smha, ilną_,
  { {0xb2bc0047,0xe1ff0022,0xe9a80044,0x00000000}},	//   טמאר, rbów_, مدون_,
  { {0x31690089,0x3ea92266,0x0b7b0044,0x00000000}},	//   _mtaz_, lfat_, _مصرع_,
  { {0xf7451d27,0xa09c0041,0x79820022,0x00000000}},	//   оеко, טיגט, asow,
  { {0x3b64005a,0x05652267,0xc99b0044,0x00000000}},	//   _хърв, овин, _مخطط_,
  { {0x6ef10137,0x3ea92268,0x61320014,0x00000000}},	//   _påbj, ifat_, sæli,
  { {0xa25b017d,0xf5050054,0x67240130,0x00000000}},	//   udôn, ізно, čija,
  { {0x28150021,0x6ef82269,0x59c70053,0x00000000}},	//   _بواس, _líba, लिवर,
  { {0x4acf0053,0x26c3001c,0xe29a226a,0x00000000}},	//   _सोमव, ējos_, шам_,
  { {0x9f4c0080,0x02030603,0x98a70022,0x00000000}},	//   ádí_, дзян, alną_,
  { {0x6eea004c,0x2d4d007d,0x20d60085,0x00000000}},	//   _nýbr, _džek_, цімс,
  { {0xc447007e,0x7ce000ea,0x3ea9134b,0x00000000}},	//   _دیدن_, _törz, ffat_,
  { {0x7cf200d1,0x9f5900ea,0xdb070046,0x00000000}},	//   _værm, ázás_, _msjó,
  { {0x82fa006a,0x2360017f,0xf2df003b,0x00000000}},	// [3540] _مرکز_, _čiji_, omân_,
  { {0x2ef200ac,0xe29f0014,0xe1260054,0x00000000}},	//   skyf_, viði_, _ємни,
  { {0xdee6064b,0xaf0a0044,0x9a6a0044,0x00000000}},	//   _дони, _نقدم_, لمال_,
  { {0x3f98003d,0xa25b0066,0x49ca226b,0x00000000}},	//   muru_, jdôl, илен_,
  { {0x3f980228,0x3a200058,0x290e092a,0x00000000}},	//   luru_, çip_, tifa_,
  { {0x7cf20146,0xe29f0026,0x28f70121,0x00000000}},	//   _mærk, riði_, жешь_,
  { {0x290e226c,0x31a400ea,0x79820ac3,0x00000000}},	//   rifa_, höz_, ssow,
  { {0x78ad007d,0x27e0007d,0x31a400ea,0x00000000}},	//   đava, ćin_, köz_,
  { {0x26c2034d,0x1efb0041,0x23690605,0x00000000}},	//   ľko_, ילקע, _čaja_,
  { {0x69c0000f,0x32020024,0x3f98226d,0x00000000}},	//   _isme, dzky_, kuru_,
  { {0x7e640089,0x4c9b0047,0xb68a007e,0x00000000}},	//   kcip, סשטע, _نپال_,
  { {0x3f9810f5,0x95ca005e,0x68e8226e,0x00000000}},	//   duru_, _вука_, _hodd,
  { {0x31a40058,0x41e70085,0x68e80058,0x00000000}},	//   göz_, ціна, _kodd,
  { {0x3254000d,0x3f910022,0x443c226f,0x00000000}},	//   ьвяр, trzu_, _tzv_,
  { {0x3f850003,0x68e82270,0xbed5005e,0x00000000}},	//   élu_, _modd, повј,
  { {0x926b018e,0x68e82271,0xff07000d,0x00000000}},	//   _трка_, _lodd, цягн,
  { {0x7bce14dd,0xa25b11f5,0xe167005d,0x00000000}},	// [3550] _arbu, ndôm, _بدبي,
  { {0x629d0146,0x68e8035a,0x3f981cc0,0x00000000}},	//   lgso, _nodd, buru_,
  { {0x69c000eb,0xa3cd0161,0xfb84000d,0x00000000}},	//   _asme, रिय_, дычн,
  { {0x629d2272,0x60c500fe,0x6e380014,0x00000000}},	//   ngso, _hahm, ðabæ,
  { {0x7e7d0418,0x68e82273,0x18692274,0x00000000}},	//   _iesp, _bodd, бали_,
  { {0x7cf202ab,0x61e0092e,0xa3cd0042,0x00000000}},	//   _nærh, ämli, रिम_,
  { {0x47580088,0x69c02275,0x6d5d2276,0x00000000}},	//   орыя_, _esme, _husa,
  { {0x1ab40086,0x6b83130c,0x6d5d2277,0x00000000}},	//   _обся, ángu, _kusa,
  { {0xf42900fe,0x68e800f1,0x7afb004b,0x00000000}},	//   keää_, _fodd, _ilut,
  { {0x7afb007a,0xdb2600fe,0x60c500bd,0x00000000}},	//   _hlut, öpöy, _nahm,
  { {0xd91a0063,0x7ae9119d,0x6d552278,0x00000000}},	//   _פועל, _koet, _miza,
  { {0x92b60032,0x6d5d017d,0x883a0165,0x00000000}},	//   أحدا, _ousa, _התעו,
  { {0x7ae902b0,0x6d5d0801,0x37080021,0x00000000}},	//   _moet, _nusa, _بْنُ_,
  { {0x7cf2010a,0x7ae90004,0xa0672279,0x00000000}},	//   _værk, _loet, зара_,
  { {0x68e3006f,0x7e7d227a,0x6d5d227b,0x00000000}},	//   ijnd, _besp, _ausa,
  { {0x7e7d0290,0x6d5d227c,0x8d66000d,0x00000000}},	//   _cesp, _busa, звае,
  { {0x7e64028d,0x60c50150,0x3f98227d,0x00000000}},	// [3560] rcip, _fahm, suru_,
  { {0xdd8f0032,0x38af005b,0x7afb227e,0x00000000}},	//   اول_, nırı_, _alut,
  { {0xdb050164,0x7afb00bd,0x68e8001f,0x00000000}},	//   othè, _blut, _rodd,
  { {0x68e8051e,0x7e7d091a,0xdb050164,0x00000000}},	//   _sodd, _gesp, nthè,
  { {0x7ae200fe,0x638200ea,0x613200b9,0x00000000}},	//   rjot, _kíná, bælt,
  { {0x7e7d0045,0x7afb227f,0x7bce007d,0x00000000}},	//   _zesp, _elut, _trbu,
  { {0x6d5d0199,0x256000cd,0x7cf20220,0x00000000}},	//   _zusa, _sòl_, _næri,
  { {0x7afb2280,0xdb060ef1,0x7ae92079,0x00000000}},	//   _glut, ömän, _goet,
  { {0x69c00008,0x443a007d,0x68e80c4c,0x00000000}},	//   _usme, _šp_, _todd,
  { {0x7ae92281,0x7659001f,0x20030022,0x00000000}},	//   _zoet, _egwy, yzji_,
  { {0x60c51831,0xa2950454,0x92952282,0x00000000}},	//   _rahm, мані, манц,
  { {0x9f450066,0x6b650078,0xb7db0063,0x00000000}},	//   šlú_, _jėga, _לקבי,
  { {0x6b650006,0x2360007d,0x7e7d2283,0x00000000}},	//   _mėga, _čiju_, _resp,
  { {0x6d5d2284,0x7cf22285,0x6ef8013d,0x00000000}},	//   _rusa, _færi, _bíbo,
  { {0x443a001b,0xdfd80062,0x6d552286,0x00000000}},	//   _áp_, път_, _riza,
  { {0x6d5d0397,0x539b014e,0x961d001c,0x00000000}},	//   _pusa, _היהו, saņe,
  { {0x60c501f7,0x7ae90186,0x88c40080,0x00000000}},	// [3570] _tahm, _roet, _změň,
  { {0x7afb2287,0x9df80076,0x7ae92288,0x00000000}},	//   _slut, чнут_, _soet,
  { {0x7e7d005b,0x6d550e92,0x9f430072,0x00000000}},	//   _tesp, _viza, tyjä_,
  { {0xa3cd0053,0xbcfb0003,0x6d552289,0x00000000}},	//   रित_, _suéd, _wiza,
  { {0x6d5d00bb,0x7ae90179,0xdb05228a,0x00000000}},	//   _uusa, _voet, nthé,
  { {0x4dda009a,0x80c30082,0x00000000,0x00000000}},	//   _וחשו, िएटे,   ,
  { {0x7ae9228b,0x00000000,0x00000000,0x00000000}},	//   _toet,   ,   ,
  { {0x628d0025,0x8cdb0053,0xd6ce0021,0x00000000}},	//   _ndao, नावो, لقى_,
  { {0x917a001b,0x38af005b,0xdbd70072,0x00000000}},	//   _mật_, tırı_, sääv,
  { {0x83890065,0x628d003b,0xf8700066,0x00000000}},	//   обов_, _adao, čším_,
  { {0x6ef81ea0,0xccf200ff,0xebd50054,0x00000000}},	//   _bíbl, דכי_, звiл_,
  { {0x395f0019,0xc878005b,0xe29f0026,0x00000000}},	//   _kuus_, _doğu_, ggð_,
  { {0x64a51cb9,0xe60e0330,0xf5480013,0x00000000}},	//   _жала, _рд_, _lụy_,
  { {0x395f0019,0xdb050003,0x7cf201e1,0x00000000}},	//   _muus_, sthè, _hærv,
  { {0x917a008b,0xdb05006c,0x2f56030b,0x00000000}},	//   _bật_, athé, дтас,
  { {0x6ef80516,0x0eaa0085,0x00000000,0x00000000}},	//   _víbo, ўкай_,   ,
  { {0x395f021f,0xe1ff006d,0x312600e1,0x00000000}},	// [3580] _nuus_, lcón_, _одиг,
  { {0x96dc003b,0x00000000,0x00000000,0x00000000}},	//   ăşiţ,   ,   ,
  { {0xe1ff05d5,0x6c4a0021,0x0c79014b,0x00000000}},	//   ncón_, آلاف_, ясты_,
  { {0x7cf2000e,0x200c0066,0xa2d40082,0x00000000}},	//   _nærv, údiu_, _बोम्,
  { {0x31600016,0x7bda14d5,0x387e228c,0x00000000}},	//   _juiz_, _štud, _petr_,
  { {0xd90d0043,0x00000000,0x00000000,0x00000000}},	//   میق_,   ,   ,
  { {0x31601088,0xb9060042,0xdca3228d,0x00000000}},	//   _luiz_, _बच_, _шари,
  { {0x8c43018e,0x758a14cf,0x1efb0047,0x00000000}},	//   _ресе, осов_, ַליע,
  { {0xddcd000c,0x3ea0002c,0x395f228e,0x00000000}},	//   mbaţ, igit_, _guus_,
  { {0x1c220053,0x6ef80014,0xbcfb006c,0x00000000}},	//   _मशाल_, _síbl, _tuée,
  { {0xb902016a,0x38cb007e,0x8c49009a,0x00000000}},	//   धा_, _باقی_, ּׂרִ,
  { {0x7d0b013d,0x0cbb0042,0x82d4012c,0x00000000}},	//   égsz, _उस्म, воює,
  { {0xe707007e,0xe29f0014,0x54e60044,0x00000000}},	//   _تسلی, rgð_, _يستق,
  { {0x672d074f,0xdb051094,0x98a7004c,0x00000000}},	//   čaje, rthé, dlně_,
  { {0xe1f90006,0xd5c8008b,0xdb050003,0x00000000}},	//   šų_, _hề_, sthé,
  { {0xceb80001,0x3ea0228f,0x867b0047,0x00000000}},	//   мљу_, ggit_, ַרבו,
  { {0x6ca70062,0x9f340086,0x917a0013,0x00000000}},	// [3590] дреж, теті, _vật_,
  { {0x3ea000a5,0xe97e0054,0x0c74005d,0x00000000}},	//   agit_, _свiт_, ندمد,
  { {0xd5c80013,0x917a008d,0x98a7008f,0x00000000}},	//   _lề_, _tật_, jonā_,
  { {0xbcfb2290,0x1ae40054,0x3f852291,0x00000000}},	//   _québ, коєм, šlus_,
  { {0x38c40006,0xd5c80013,0x961d008f,0x00000000}},	//   kūrė_, _nề_, kaņa,
  { {0x270c0080,0x7cf200d1,0x98a7001c,0x00000000}},	//   měny_, _bæru, fonā_,
  { {0x6c54000d,0x38c40078,0x66160014,0x00000000}},	//   _акру, dūrė_, _þykj,
  { {0xd5c8008b,0xa3cd0053,0xe4690072,0x00000000}},	//   _bề_, रिस_, kköä_,
  { {0xc8ab005a,0x270c0080,0x67220150,0x00000000}},	//   _мъже_, něny_, _djoj,
  { {0x61320146,0x31601100,0x6b650078,0x00000000}},	//   jælp, _ruiz_, _jėgo,
  { {0x6b65005f,0x36d517b7,0x260f0082,0x00000000}},	//   _mėgo, _пожр, _तेरी_,
  { {0x4439001c,0xe1ff0118,0xdb070003,0x00000000}},	//   ās_, rcón_, élèb,
  { {0x6d47024a,0x3afa0047,0xe1ff0331,0x00000000}},	//   _ohja, פּטע, scón_,
  { {0x64a52292,0x673b2293,0xdbd701a9,0x00000000}},	//   _чака, lluj, _käär,
  { {0x6d4b0078,0x84640062,0xb4fa009a,0x00000000}},	//   įgal, _ръче, _מפסי,
  { {0xdbd70f75,0x7cf201f2,0x1288005d,0x00000000}},	//   _määr, _lært, _کمکی_,
  { {0xdce6003d,0xdced00c2,0x8e0a0002,0x00000000}},	// [35a0] _atkā, apač, чнав_,
  { {0x62862294,0x3e7e008b,0x2f210078,0x00000000}},	//   lako, ắt_, bėgo_,
  { {0xbcfb017d,0xeb970121,0x20560054,0x00000000}},	//   _suéc, еих_, _ятир,
  { {0xfe720021,0xba2608b9,0x62862295,0x00000000}},	//   _حدد_, ндек, nako,
  { {0xddcd003b,0x82770047,0x7125007e,0x00000000}},	//   rbaţ, גענע_, _سریل,
  { {0x673b00c2,0xc7c606f0,0x6f04017d,0x00000000}},	//   eluj, есии, lhic,
  { {0x8c430928,0x629a0006,0x673b006d,0x00000000}},	//   _бере, ėtoj, fluj,
  { {0xa6aa0021,0x62862296,0x66160014,0x00000000}},	//   سابق_, jako, _þykk,
  { {0x64430089,0x62862297,0xbcfb0003,0x00000000}},	//   _azni, dako, _itér,
  { {0xd5c800aa,0x03f80001,0x6aa2001f,0x00000000}},	//   _về_, дној_, lgof,
  { {0x44380220,0x5c970047,0x6f0401a8,0x00000000}},	//   ær_, עכטע_, khic,
  { {0x6aa2001f,0xd5c80013,0x62862298,0x00000000}},	//   ngof, _tề_, gako,
  { {0x961d001c,0x394e01a8,0xdb07006c,0x00000000}},	//   paņa, omfs_, éléb,
  { {0xa3cd0053,0x7cf201e1,0x656f2299,0x00000000}},	//   रिश_, _mærs, íche,
  { {0x40350002,0xa2d80053,0x64a302d8,0x00000000}},	//   тевс, याख्, _саја,
  { {0x643b0063,0x9f6000ea,0x270c004c,0x00000000}},	//   _מעונ, árás_, těny_,
  { {0x3d94047e,0x6ef80139,0xdced007d,0x00000000}},	// [35b0] литр, _míbh, spač,
  { {0xac270f0a,0x75cf013d,0x621c009a,0x00000000}},	//   нфек, lőzö, _מוחק,
  { {0xe47b0047,0x2d89229a,0x3156009d,0x00000000}},	//   פראכ, ssae_, _שיתן_,
  { {0x9e150726,0x8bc4000d,0x6f04229b,0x00000000}},	//   _адмі, ысуд, chic,
  { {0xdb1c00ea,0xdbd70bda,0xab640022,0x00000000}},	//   _arró, _säär, ężar,
  { {0xdbd701cf,0x98a7003b,0x6286229c,0x00000000}},	//   _päär, donă_, zako,
  { {0x7cf2010a,0xdce40022,0x6286229d,0x00000000}},	//   _vært, jpię, yako,
  { {0x7cf2007a,0xdbd7047f,0xe7390076,0x00000000}},	//   _færs, _väär, ьей_,
  { {0xdb1c006d,0xe7f30053,0x6286229e,0x00000000}},	//   _erró, _अथवा_, vako,
  { {0x7cf2007a,0xd955007e,0xf8070002,0x00000000}},	//   _hærr, _شناخ, _пчен,
  { {0x6286229f,0xdbce0058,0xe29a0861,0x00000000}},	//   tako, rıça, ман_,
  { {0x6443004a,0x4612005d,0x7bd50566,0x00000000}},	//   _vzni, اویر, _mrzu,
  { {0x64430051,0xe5e5007e,0x9ae80063,0x00000000}},	//   _wzni, _جزای, תַתִ,
  { {0xa06a0002,0x798b002b,0xf487032d,0x00000000}},	//   ќава_, isgw, _чудн,
  { {0x6443001c,0x25ad22a0,0x6f0422a1,0x00000000}},	//   _uzni, ltel_, thic,
  { {0x7cf20026,0x8fa3018e,0x26cd22a2,0x00000000}},	//   _nærr, јате, ndeo_,
  { {0xed5a0635,0xc2c90021,0x9ea70062,0x00000000}},	// [35c0] доа_, _سبيل_, ъвта_,
  { {0xbcfb0003,0x6724007d,0x25ad22a3,0x00000000}},	//   _stér, čiji, itel_,
  { {0x7cf20d02,0x6f0422a4,0x961d008f,0x00000000}},	//   _særs, phic, kaņo,
  { {0xdb1c00cd,0x4e7a0021,0x7bd50022,0x00000000}},	//   _arrò, _تحدد_, _drzu,
  { {0x628422a5,0xe89422a6,0x26cd099f,0x00000000}},	//   _meio, галь, ddeo_,
  { {0x6609003d,0x66160026,0x69c20983,0x00000000}},	//   dzek, _þyki, rwoe,
  { {0x38cb007e,0x6d5c00a4,0x25ad0159,0x00000000}},	//   بانی_, _iira, etel_,
  { {0xdb1c00cd,0x3e860006,0x98a7003b,0x00000000}},	//   _errò, būtų_, tonă_,
  { {0x6f030529,0x28e20161,0x6d5c22a7,0x00000000}},	//   _înce, पादि, _kira,
  { {0x672d017f,0x7c3c0026,0x6d5c13dc,0x00000000}},	//   čaja, _kyrr, _jira,
  { {0x6d5c22a8,0xdc9b069a,0x03c31dfd,0x00000000}},	//   _mira, וייל, асям,
  { {0x6b83003b,0x65620072,0x6d5c22a9,0x00000000}},	//   ângi, _tuoh, _lira,
  { {0x66090051,0xc5940002,0x7dfa008f,0x00000000}},	//   czek, _силј, _jāsā,
  { {0xe9ce000d,0xa2a50042,0xe8c00082,0x00000000}},	//   скi_, _काव्, _एसोच,
  { {0xa438019d,0x5433007e,0xce950062,0x00000000}},	//   _язку_, _پرور, лавъ,
  { {0x21670076,0xbcfb006d,0x798b001f,0x00000000}},	//   _итог, _cuén, ysgw,
  { {0x6d5c22aa,0x7cd90699,0x5cab005e,0x00000000}},	// [35d0] _bira, нмар_, дњег_,
  { {0x7c940021,0x7e9e003b,0x7c3c002b,0x00000000}},	//   لشما, tăpâ, _byrr,
  { {0x7c3c0185,0x6d5c22ab,0x9f4500ea,0x00000000}},	//   _cyrr, _dira, áló_,
  { {0xbcfb006c,0xd259008f,0x6d5c22ac,0x00000000}},	//   _guén, žņu_, _eira,
  { {0x7e2b0086,0x991515d4,0x7cf2000e,0x00000000}},	//   _ціна_, лькі, _værr,
  { {0x7c3c007a,0xe0d50047,0x2dda0047,0x00000000}},	//   _fyrr, רײַ_, _אַלב,
  { {0x6e3d0185,0x7c3c0185,0x98a70c3b,0x00000000}},	//   _hysb, _gyrr, joną_,
  { {0x7e6d08f0,0x27e9017f,0x85790002,0x00000000}},	//   ncap, ćan_, нсот_,
  { {0x25ad1a20,0x26cd006d,0x7980002b,0x00000000}},	//   utel_, rdeo_, _gwmw,
  { {0x25ad22ad,0x13e90076,0x69c90019,0x00000000}},	//   rtel_, емой_, _isee,
  { {0x25ad22ae,0x660900ea,0x6e3d069f,0x00000000}},	//   stel_, szek, _lysb,
  { {0x98be0078,0x91e60888,0x16140042,0x00000000}},	//   _bitė_, гоме, _तेवर_,
  { {0xa2a50394,0xe4c8005d,0xfad6009a,0x00000000}},	//   _कार्, ربین_, אורך_,
  { {0x361a00b5,0x25690027,0xa2d40053,0x00000000}},	//   _אונד, _iúl_, _बोर्,
  { {0x6026005a,0x443c0078,0x98a70022,0x00000000}},	//   удва, _gyv_, coną_,
  { {0xbcfb1510,0x6d5c22af,0xb4440085,0x00000000}},	//   _quén, _sira, _тэчк,
  { {0xd7f8008b,0x7f5d22b0,0x715a005e,0x00000000}},	// [35e0] _ngăn_, _disq, _прос_,
  { {0x290700c2,0xee3708a2,0x7c3c22b1,0x00000000}},	//   jhna_, уну_, _pyrr,
  { {0x69c9021e,0x6d5c22b2,0x63a1013d,0x00000000}},	//   _asee, _vira, nuln,
  { {0x6d5c00f3,0xab770021,0x7e6d01f4,0x00000000}},	//   _wira, امنا_, ccap,
  { {0x427b0047,0x6d5c22b3,0x98a722b4,0x00000000}},	//   גאנג, _tira, zoną_,
  { {0xd9f70085,0x63a1013d,0x7c3c22b5,0x00000000}},	//   ыніц_, kuln, _tyrr,
  { {0x672d065f,0x7980004e,0xa2a50042,0x00000000}},	//   čajn, _wwmw, _काल्,
  { {0xb6f40fe2,0xe7370141,0xdbd2004b,0x00000000}},	//   рзиј, леј_, _müür,
  { {0xe9da019d,0x3b07000a,0x443c02ab,0x00000000}},	//   _яка_, _сето_, _syv_,
  { {0x38c8007e,0x290722b6,0x78ad0066,0x00000000}},	//   _جاری_, chna_, ľový,
  { {0x4c9b00b5,0x5c9b0041,0x07b70044,0x00000000}},	//   עשטע, עשטײ, _مهلة_,
  { {0x98a70051,0xdb050139,0x395e22b7,0x00000000}},	//   roną_, othá, _hits_,
  { {0x7f5d0164,0x92580076,0x395e22b8,0x00000000}},	//   _risq, лают_, _kits_,
  { {0xbcfb0331,0x98a70078,0x00000000,0x00000000}},	//   _cuél, poną_,   ,
  { {0x395e0179,0x63a10150,0x78b50075,0x00000000}},	//   _mits_, culn, _özve,
  { {0x395e22b9,0x7cf20093,0x939300de,0x00000000}},	//   _lits_, _særp, _اجوا,
  { {0x2d8f00ea,0x7f5d0110,0x7e6d22ba,0x00000000}},	// [35f0] ége_, _visq, rcap,
  { {0x4c950121,0x30a70062,0x395e01a8,0x00000000}},	//   рижс, _срив, _nits_,
  { {0xa3cd0053,0x515a0063,0x1cb800f2,0x00000000}},	//   रिए_, _שכתו, طالب_,
  { {0x04370047,0x4ffa009a,0x00000000,0x00000000}},	//   נטאש_, _סִינ,   ,
  { {0xdd0101f7,0x6b650006,0x7cdb001c,0x00000000}},	//   ştır, _mėgi, _pārē,
  { {0x69c900c3,0x6ce70086,0x395e001c,0x00000000}},	//   _vsee, _сіме, _cits_,
  { {0x80ad0053,0x25690139,0x66e50002,0x00000000}},	//   _जाने, _súl_, иока,
  { {0xb8fc0394,0x6b8312a1,0xfb580021,0x00000000}},	//   _तो_, ângu, _مؤقت_,
  { {0x395e00e5,0xe1ff0051,0x26180042,0x00000000}},	//   _fits_, mców_, _बेदी_,
  { {0x63a122bb,0x332922bc,0xe1ff0022,0x00000000}},	//   tuln, _ajax_, lców_,
  { {0x0326000a,0x04451b79,0xb9090053,0x00000000}},	//   идон, ренн, या_,
  { {0x2569000f,0x63a122bd,0x216a0499,0x00000000}},	//   _túl_, ruln, кими_,
  { {0x614604bb,0xd1c7000d,0x3f860066,0x00000000}},	//   иема, аляе_, _ňou_,
  { {0x8467005a,0x26cf006d,0x63a100ea,0x00000000}},	//   _съде, _hago_, puln,
  { {0x3f16000a,0xbcfb0331,0x351a0063,0x00000000}},	//   аќат, _vuél, _בוסנ,
  { {0x26cf22be,0x52760699,0xe1ff0022,0x00000000}},	//   _jago_, _туку, jców_,
  { {0x433b0063,0x2905037e,0xa3cd0053,0x00000000}},	// [3600] _בעקב, _olla_, रिक_,
  { {0x80ad0161,0x26cf22bf,0x409622c0,0x00000000}},	//   _जाये, _lago_, _трит,
  { {0x309b0063,0x8ca70053,0x4bd90054,0x00000000}},	//   _בשימ, _चारो, льця_,
  { {0x98a70006,0x395e00e5,0xa3d60053,0x00000000}},	//   monę_, _sits_, सित_,
  { {0x6f03000c,0xddc40006,0x395e00e5,0x00000000}},	//   _înca, rbių, _pits_,
  { {0x39130086,0x8937000d,0xdb051a34,0x00000000}},	//   омір, апіс_, rthá,
  { {0x26cf00bb,0xf72a0076,0xb8ce0053,0x00000000}},	//   _bago_, кций_, _का_,
  { {0xd6d722c1,0x290522c2,0xb8820080,0x00000000}},	//   ать_, _ella_, _řídi,
  { {0x26cf09e9,0xa96a093d,0xf5260a72,0x00000000}},	//   _dago_, _риза_, ифон,
  { {0x04660092,0x136a0ace,0xd9460fc3,0x00000000}},	//   штим, кшми_, _тези,
  { {0x9cd90047,0x291c22c3,0xf36602f8,0x00000000}},	//   אַרז, miva_, јтон,
  { {0x291c0606,0xd6cf0021,0xe61a22c4,0x00000000}},	//   liva_, _يقل_, _иде_,
  { {0x5067100b,0x26c4082a,0xa4d40086,0x00000000}},	//   итва, memo_, _голі,
  { {0x291c22c5,0xc307005d,0xa50701ce,0x00000000}},	//   niva_, ابگو, _веља_,
  { {0xef670094,0x5f9422c6,0x8877009a,0x00000000}},	//   ръго, жист, שתלב_,
  { {0x2fcd0051,0x40340076,0x26c4082a,0x00000000}},	//   łego_, цесс, nemo_,
  { {0x224922c7,0x629a0078,0x291c0db3,0x00000000}},	// [3610] _uzak_, ėtot, kiva_,
  { {0xe1ff0045,0xd6570063,0x291c02e2,0x00000000}},	//   wców_, שימת_, jiva_,
  { {0x291c22c8,0x61fd0527,0x7055005d,0x00000000}},	//   diva_, lysl, _دندا,
  { {0x26c406bb,0x6e32004c,0xab640085,0x00000000}},	//   jemo_, _žebř, івіл,
  { {0xe1ff0051,0x291c00a8,0x26c422c9,0x00000000}},	//   rców_, fiva_, demo_,
  { {0x7c28007d,0x3ea922ca,0xa3c60042,0x00000000}},	//   _ždre, lgat_, उबा_,
  { {0x26cf0297,0x3c450021,0xa0980063,0x00000000}},	//   _pago_, _طَرِ, בדוק_,
  { {0x3ea91534,0x06c90086,0x656f0114,0x00000000}},	//   ngat_, угий_, ícho,
  { {0xdb0500b9,0x291c22cb,0x26cf068b,0x00000000}},	//   tthæ, biva_, _vago_,
  { {0xdb1c03b2,0x6aa60137,0x291c22cc,0x00000000}},	//   _aprè, _ökfr, civa_,
  { {0x26cf00a4,0x2bda0053,0x22462206,0x00000000}},	//   _tago_, णिया, _šok_,
  { {0x26c422cd,0xc6d40044,0x85050043,0x00000000}},	//   cemo_, _وتنت, _گوتن,
  { {0xab630051,0x3ea90137,0x71260021,0x00000000}},	//   ężyc, dgat_, مرسل,
  { {0xdb05004b,0x657b0360,0x3ea9003b,0x00000000}},	//   lthä, mpuh, egat_,
  { {0x44760047,0xd00722ce,0xdee622cf,0x00000000}},	//   _פעקל_, бере_, бови,
  { {0x98a70045,0x52aa0001,0x291c074f,0x00000000}},	//   ronę_, _свим_, ziva_,
  { {0x10a60086,0xc27b0063,0x657b0072,0x00000000}},	// [3620] _липн, _גרפי, npuh,
  { {0x26c4007d,0x291c032a,0xdb05004b,0x00000000}},	//   zemo_, xiva_, hthä,
  { {0xcfea04de,0x291c22d0,0x1c39000d,0x00000000}},	//   _صفحه_, viva_, аяць_,
  { {0xfaa622d1,0x69db22d2,0x1ab4012c,0x00000000}},	//   садо, _brue, ібля,
  { {0xda650032,0x26c402f7,0x291c22d3,0x00000000}},	//   زاني, vemo_, tiva_,
  { {0x7f4422d4,0x69db22d5,0x6ef80046,0x00000000}},	//   lliq, _drue, _gíbr,
  { {0x291c22d6,0x26c40077,0x98a7004c,0x00000000}},	//   riva_, temo_, loně_,
  { {0x291c157e,0xc6f808ac,0x7bdc22d7,0x00000000}},	//   siva_, рних_, _irru,
  { {0x26c422d8,0x69db0d7e,0x291c22d9,0x00000000}},	//   remo_, _grue, piva_,
  { {0x26c4007d,0xd3b80054,0x15140054,0x00000000}},	//   semo_, алої_, ідня,
  { {0xdb1c0803,0x201e22da,0x18770063,0x00000000}},	//   _apré, útil_, _העבר_,
  { {0x61fd0bb7,0xa3cd0053,0x7d1e0058,0x00000000}},	//   tysl, रिज_, hips,
  { {0x7d1e22db,0xf2040085,0x66e50042,0x00000000}},	//   kips, пяро, कारक_,
  { {0x2d92021f,0x7bdc0014,0x61fd22dc,0x00000000}},	//   dsye_, _orru, rysl,
  { {0x24b70165,0x251b0aeb,0x00000000,0x00000000}},	//   _להגן_, _גוגא,   ,
  { {0x69c00a53,0x3f910051,0x3ea922dd,0x00000000}},	//   _opme, rszu_, ugat_,
  { {0xd0d5011c,0x7bce0a02,0x644f0051,0x00000000}},	// [3630] _допъ, _asbu, ęcie,
  { {0x628f22de,0x8c671810,0x7d1e056c,0x00000000}},	//   laco, стад, gips,
  { {0x69c0003d,0x6f03000c,0xbc4b026c,0x00000000}},	//   _apme, _înco, учае_,
  { {0x69db048e,0x672d017f,0x628f22df,0x00000000}},	//   _prue, čajk, naco,
  { {0x6f0d0027,0xe1ff00cd,0x628f0a02,0x00000000}},	//   mhac, nyó_, iaco,
  { {0x60c7004c,0x6f0d00be,0xd36601fb,0x00000000}},	//   nejm, lhac, _يه_,
  { {0x3786005a,0xda7b000d,0x907c0047,0x00000000}},	//   общо_, _бяз_, נטהי,
  { {0x8595000a,0x6d4522e0,0x69db22e1,0x00000000}},	//   ошоц, llha, _true,
  { {0x6d4500be,0xdb050244,0x776222e2,0x00000000}},	//   olha, rthä, _diox,
  { {0x26d90024,0x14250076,0x98ae00dd,0x00000000}},	//   ôsob_, ждом, rofă_,
  { {0x02c61087,0x60c70051,0x6aab08a9,0x00000000}},	//   ойно, dejm, oggf,
  { {0x6d45004d,0xcb9a0041,0x657b22e3,0x00000000}},	//   hlha, ױסשט, ppuh,
  { {0x51ba000d,0x3204027d,0x201101f4,0x00000000}},	//   шыня_, ámy_, ezzi_,
  { {0x320c0051,0x67291e9f,0x627e0022,0x00000000}},	//   ądy_, lnej, dłoż,
  { {0x6b650006,0x656300a4,0x656b22e4,0x00000000}},	//   _mėgs, _iinh, _hugh,
  { {0x6d45000f,0x7d1e00e8,0x67290024,0x00000000}},	//   elha, wips, nnej,
  { {0x7f4422e5,0x7d1e22e6,0x60c70022,0x00000000}},	// [3640] rliq, tips, bejm,
  { {0x7f4422e5,0x61fb004d,0xdca302b3,0x00000000}},	//   sliq, äule, дафи,
  { {0x656b10ca,0x656303d9,0x7f440291,0x00000000}},	//   _lugh, _minh, pliq,
  { {0x656303d9,0xe9da131b,0x656b0034,0x00000000}},	//   _linh, ике_, _ough,
  { {0x6d45001f,0x672922e7,0x5db60021,0x00000000}},	//   blha, dnej, _بإجر,
  { {0x6f040051,0x656303cc,0xf806015a,0x00000000}},	//   lkic, _ninh, жчин,
  { {0xe3a7006a,0x656b00e5,0xeb9714e9,0x00000000}},	//   _تر_, _augh, _мир_,
  { {0x672900c2,0x656b00a4,0x9c170063,0x00000000}},	//   gnej, _bugh, _וחלק_,
  { {0x628f0024,0x656300a4,0xbb4322e8,0x00000000}},	//   vaco, _binh, _цетк,
  { {0x2b4622e9,0x32d7008b,0xa3d60053,0x00000000}},	//   lloc_, _ủy_, सिल_,
  { {0x656322ea,0x6729104c,0x628f22eb,0x00000000}},	//   _dinh, bnej, taco,
  { {0x656307cf,0x6443001f,0x61e200c2,0x00000000}},	//   _einh, _dyni, _šola,
  { {0x628f22ec,0x7ae40072,0x6f040022,0x00000000}},	//   raco, öity, dkic,
  { {0x628f1ea0,0x636a005e,0x6f040058,0x00000000}},	//   saco, _криг_, ekic,
  { {0x60c70198,0x6f0d056d,0xf3ef0021,0x00000000}},	//   rejm, thac, _لأي_,
  { {0xe7f20053,0x3eaf00bd,0x63a800c2,0x00000000}},	//   _अपना_, ügt_, mudn,
  { {0x20050648,0x6c6b005e,0x645c0014,0x00000000}},	// [3650] šli_, ашег_, ýrif,
  { {0x67290599,0x61e00026,0x628d0019,0x00000000}},	//   znej, æmle, _heao,
  { {0x63a808ea,0xdbd6004b,0xe53b009a,0x00000000}},	//   nudn, jääg, סתבר,
  { {0x6f040051,0xddcd00c2,0x5457016e,0x00000000}},	//   ckic, mbaž, קסאן_,
  { {0xed5b007e,0xda7801dd,0x672922ed,0x00000000}},	//   _نشست_, цях_, vnej,
  { {0xb17c01f9,0x63a80130,0x8dfa009a,0x00000000}},	//   סטור, kudn, _ההשת,
  { {0x67290dec,0x656b0290,0x63a822ee,0x00000000}},	//   tnej, _sugh, judn,
  { {0x656322ef,0xb6a30013,0x6b510137,0x00000000}},	//   _sinh, _giầ, fåge,
  { {0x6443001f,0x656322f0,0x7eb60047,0x00000000}},	//   _syni, _pinh, פּקע_,
  { {0x672922f1,0x290e002b,0x656b00ca,0x00000000}},	//   snej, chfa_, _vugh,
  { {0x65630016,0x6f1d0122,0x6729017c,0x00000000}},	//   _vinh, _omsc, pnej,
  { {0x6443027d,0x6b510137,0x67ba0063,0x00000000}},	//   _vyni, båge, _למעק,
  { {0x64430045,0x656303d9,0xdce60006,0x00000000}},	//   _wyni, _tinh, _sukč,
  { {0x63a80024,0xaa3a009d,0x85f6009d,0x00000000}},	//   budn, מתרח, _מצנע_,
  { {0x9f5e0080,0x6f040051,0xdee622f2,0x00000000}},	//   ští_, tkic, пови,
  { {0xdce60130,0x3e7c004c,0x8cc10042,0x00000000}},	//   _vukč, kátů_, _रॉबो,
  { {0xdcf0004c,0x6f040534,0xf2d3009a,0x00000000}},	// [3660] řečt, rkic, _טעה_,
  { {0x6f040d45,0x644e004b,0x3e7c004c,0x00000000}},	//   skic, übig, dátů_,
  { {0x7f460184,0xe0fb0063,0x6600161f,0x00000000}},	//   _неож, _הליל, zymk,
  { {0xd4910013,0x05bd0042,0x2055014b,0x00000000}},	//   hà_, ्बाब, _ітэр,
  { {0xd94622f3,0x7cf3013d,0xad26005d,0x00000000}},	//   педи, _sűrű, _فرسو,
  { {0x2d8021d1,0xed571224,0x91bb009d,0x00000000}},	//   mpie_, _ноя_, ממני,
  { {0x2ca7006d,0x798900ac,0xab64004d,0x00000000}},	//   ónde_, _ewew, grüß,
  { {0x6b510137,0x63a80137,0x32020072,0x00000000}},	//   tåge, vudn, kyky_,
  { {0x6720007d,0x96340065,0x7989002b,0x00000000}},	//   rimj, ьниц, _gwew,
  { {0x6b510137,0xddcd003b,0x63a810c9,0x00000000}},	//   råge, lcaţ, tudn,
  { {0x68e800b9,0xddcd003b,0xc8b5000d,0x00000000}},	//   _indd, ocaţ, _юсты,
  { {0xddcd003b,0x63a822f4,0x977300de,0x00000000}},	//   ncaţ, rudn, _أُنش,
  { {0x63a8007d,0xc56a0021,0x644f0022,0x00000000}},	//   sudn, _احصل_, ęcia,
  { {0xe9ce000d,0x2572002b,0xdb05004c,0x00000000}},	//   ткi_, _iâl_, ruhé,
  { {0x94bb0063,0xdb1c0865,0x4fc40ad9,0x00000000}},	//   _המות, _aprí, нста,
  { {0xdb1c0025,0x877b089e,0xdb050046,0x00000000}},	//   _bprí, מאלי, sthú,
  { {0xe3b8005b,0xfe7001fb,0xc0cb0121,0x00000000}},	// [3670] ltı_, ادف_, _луне_,
  { {0x68fa0244,0x4d9822f5,0xa3b00082,0x00000000}},	//   _notd, якую_, टंप_,
  { {0xe3b801f7,0x9f550054,0xddcd00dd,0x00000000}},	//   ntı_, _овоч, fcaţ,
  { {0x6f1d00bd,0x3e7c004c,0x290c22f6,0x00000000}},	//   _umsc, tátů_, _alda_,
  { {0xeab00021,0xd9590085,0xa3d30042,0x00000000}},	//   اعم_, ошкі_, _सैन_,
  { {0x3e7c0080,0xe3b8005b,0xa7790001,0x00000000}},	//   rátů_, ktı_, ољих_,
  { {0x32020240,0xb09c0047,0xf8ae007e,0x00000000}},	//   zyky_, מיגר, شکل_,
  { {0x68e81cb3,0xead4000d,0x290c01a8,0x00000000}},	//   _endd, _пось, _elda_,
  { {0xeaf80044,0xe61922f7,0x671c0042,0x00000000}},	//   _عرفت_, юди_, बोधक_,
  { {0x7afb1a3a,0x2572002b,0x59c40044,0x00000000}},	//   _hout, _dâl_, _سيمك,
  { {0xbcfb006d,0x89340021,0x7afb22f8,0x00000000}},	//   _hués, _أعقا, _kout,
  { {0x6f030529,0x7afb0f38,0x2378013d,0x00000000}},	//   _înch, _jout, írja_,
  { {0x7afb04bc,0xd7060086,0x68e8001f,0x00000000}},	//   _mout, _інше_, _yndd,
  { {0x66060031,0xa5b20053,0x7dd80139,0x00000000}},	//   økke, _आमतौ, húsá,
  { {0x5043000a,0xdb1c0024,0x29070014,0x00000000}},	//   верб, _sprí, ikna_,
  { {0x620700ea,0x6d550089,0x7afb22f9,0x00000000}},	//   örlé, _ahza, _nout,
  { {0x4d66000d,0x8d66000d,0xef170054,0x00000000}},	// [3680] дкав, двае, єму_,
  { {0xef1f0019,0x7e760022,0x644e0022,0x00000000}},	//   _emü_, scyp, żbie,
  { {0x7afb03b2,0x3eb300fe,0x8e8622fa,0x00000000}},	//   _bout, äntö_, _огне,
  { {0x2d80015e,0x7afb22fb,0xfe720021,0x00000000}},	//   ppie_, _cout, _جدد_,
  { {0xddcd0529,0xb17b0146,0x7afb1676,0x00000000}},	//   rcaţ, rvåg, _dout,
  { {0x7ae922fc,0xe3b80075,0x17fa0044,0x00000000}},	//   _enet, ytı_, قرعة_,
  { {0x7afb0173,0x2572002b,0x60c1004b,0x00000000}},	//   _fout, _sâl_, õlmi,
  { {0xd7570032,0x7afb0003,0x290722fd,0x00000000}},	//   وجيا_, _gout, akna_,
  { {0x88c50080,0x68fa22fe,0x88c60021,0x00000000}},	//   _směř, _totd, _يتطل,
  { {0x290700c7,0xbcfb006d,0xe3b8005b,0x00000000}},	//   ckna_, _huér, ttı_,
  { {0x7afb22ff,0x8ca60042,0x4394014b,0x00000000}},	//   _yout, _चयनो, эанс,
  { {0x3863000f,0xe3af006a,0xe3b8005b,0x00000000}},	//   _újra_, گری_, rtı_,
  { {0x672d0198,0x798212a9,0x6f03003b,0x00000000}},	//   čajt, npow, _înci,
  { {0x7dd800ea,0xe3b8005b,0xe3af007e,0x00000000}},	//   zúsá, ptı_, دری_,
  { {0x62860137,0xd0d40062,0x69060046,0x00000000}},	//   bbko, ъоръ, _aðek,
  { {0x63b70066,0xdce6008f,0x539b009a,0x00000000}},	//   žaní, _rukā, _ויהו,
  { {0xa3d60235,0x7afb2158,0x06870041,0x00000000}},	// [3690] सिक_, _rout, _הכּל_,
  { {0x7afb0c36,0x79820051,0x70591a02,0x00000000}},	//   _sout, dpow, _напр_,
  { {0xfd440085,0x7afb22f8,0x00000000,0x00000000}},	//   тэтн, _pout,   ,
  { {0xd6d90051,0x80bb0053,0x7d0e004d,0x00000000}},	//   koła_, श्रे, _elbs,
  { {0x7ae900c2,0xa9a5005e,0x7afb2300,0x00000000}},	//   _vnet, хилд, _vout,
  { {0xe9d80726,0x7afb09fe,0xe8f82049,0x00000000}},	//   ькі_, _wout, млі_,
  { {0x7afb2301,0x62860051,0xf74505a1,0x00000000}},	//   _tout, ybko, неко,
  { {0xbcfb0164,0x7ae92302,0x6b5100a5,0x00000000}},	//   _guér, _unet, båga,
  { {0xf5052303,0xb9c70044,0x99d400de,0x00000000}},	//   езпо, _تتأه, _لتلا,
  { {0xf8070055,0xa3d30042,0x29190043,0x00000000}},	//   _очен, _सईद_, _عقاد_,
  { {0x7bda00ea,0x644f0051,0x6e2900c2,0x00000000}},	//   _átut, ęcio, _žebl,
  { {0x0bb60063,0xd9f30042,0x3f9e2304,0x00000000}},	//   עִיר_, _आपात_, átum_,
  { {0xdfd2007e,0xe196000d,0x13030054,0x00000000}},	//   گيز_, эрнэ, узям,
  { {0x656f0025,0x80bb0053,0x7bd50051,0x00000000}},	//   íchu, श्ले, _oszu,
  { {0x79820051,0xa3d20131,0x6fb60044,0x00000000}},	//   zpow, _бојч, عمرا,
  { {0xdb1c004a,0x64460022,0x79820022,0x00000000}},	//   _oprá, ękit, ypow,
  { {0xc2e90021,0xd2660086,0x25ad2305,0x00000000}},	// [36a0] _زعيم_, _який, nuel_,
  { {0xc50c0047,0x02c10042,0x61e40058,0x00000000}},	//   ֿלאָ, ष्ठभ, _iril,
  { {0xda7a0062,0xbcfb0003,0x7ac6170a,0x00000000}},	//   пял_, _puér, есле,
  { {0x61e4027c,0x2d4f01a8,0xbcfb006c,0x00000000}},	//   _kril, qüen_, _quér,
  { {0x2fe80051,0x61e20130,0x7982056c,0x00000000}},	//   ługę_, _šolj, upow,
  { {0x6b5101e3,0x63ba0137,0x25ad2306,0x00000000}},	//   råga, yttn, duel_,
  { {0xfaa60088,0xb76601a4,0xd6d90022,0x00000000}},	//   _паво, нтий, woła_,
  { {0x61e4006d,0x25ad113c,0xf7430002,0x00000000}},	//   _oril, fuel_, лејо,
  { {0x25ad2307,0xc5260002,0x34bd0042,0x00000000}},	//   guel_, еќни, ौजूद,
  { {0xe9d70086,0x7bd50022,0x3a231f89,0x00000000}},	//   _яку_, _yszu, _смуг,
  { {0xdb1c0080,0x673c00ea,0x22490089,0x00000000}},	//   _zprá, _írjo, _syak_,
  { {0x61e42308,0xd6d9012c,0x69d50042,0x00000000}},	//   _bril, _оті_, _मैडी,
  { {0x6906007a,0x3f570003,0x8cc10042,0x00000000}},	//   _aðei, nçue_, र्डो,
  { {0x61e42309,0xf6290021,0x2eeb230a,0x00000000}},	//   _dril, _تسمى_, _sncf_,
  { {0xb4ac0235,0xe9ff008b,0x61e40d68,0x00000000}},	//   गली_, _khảo_, _eril,
  { {0x6d5e13b8,0x61e40807,0x3f83008f,0x00000000}},	//   empa, _fril, rpju_,
  { {0x6ca7230b,0x67220035,0x7bc70137,0x00000000}},	// [36b0] ереж, _mmoj, _spju,
  { {0x63a8230c,0x98ae004c,0xdca401ce,0x00000000}},	//   ordn, rofě_, лађи,
  { {0xdb1c0512,0x9be4000d,0x30a40121,0x00000000}},	//   _sprá, ліцк, _срыв,
  { {0x644a230d,0x6e2c0014,0x6d5e230e,0x00000000}},	//   _myfi, élbú, ampa,
  { {0x25ad0003,0x12fa0047,0x0dc80601,0x00000000}},	//   xuel_, והײב, _пури_,
  { {0x7bcb003b,0xbb850021,0xe9180054,0x00000000}},	//   ăgub, _للسي, ночі_,
  { {0x644a00a5,0xe73904f2,0xb21b0046,0x00000000}},	//   _nyfi, мек_, fbæk,
  { {0x25ad230f,0xdb05004d,0xf5e90854,0x00000000}},	//   tuel_, nthü, дмил_,
  { {0x6f03000c,0x6b6c005b,0x644f0022,0x00000000}},	//   _încu, _işga, ęcim,
  { {0xdbcc0026,0x58d90086,0x25ad2310,0x00000000}},	//   _kóða, _ідея_, ruel_,
  { {0x644a001f,0x25ad2311,0x3f7800b2,0x00000000}},	//   _cyfi, suel_, _ačun_,
  { {0x61e42312,0x644a002b,0x8cc10042,0x00000000}},	//   _pril, _dyfi, र्तो,
  { {0x25ad2313,0x6d5e0731,0xdb0800ea,0x00000000}},	//   quel_, ympa, élés,
  { {0xb1430b3f,0x7e7d2314,0x64a52315,0x00000000}},	//   инял, _afsp, _рака,
  { {0x644a001f,0x764b002b,0x21670571,0x00000000}},	//   _gyfi, _hygy, тири_,
  { {0x61e42316,0x8464005a,0x69c90983,0x00000000}},	//   _tril, _съче, _opee,
  { {0x61e40529,0x6b9c007d,0xb13a0021,0x00000000}},	// [36c0] _uril, _svrg, _يأخذ_,
  { {0x6d5e0332,0xd2570063,0x4c8309c2,0x00000000}},	//   umpa, _בשפה_, илув,
  { {0xeb972317,0x6b5100c7,0x764b0006,0x00000000}},	//   вих_, rågn, _lygy,
  { {0xfaa62318,0x62070014,0x93fa009a,0x00000000}},	//   тадо, _örlí, ולעי,
  { {0x827700b5,0x6a160021,0xceb3069a,0x00000000}},	//   דענע_, خبار, _דיר_,
  { {0x6b582319,0x3f570003,0xa7b8007f,0x00000000}},	//   díge, rçue_, елку_,
  { {0xdbcc0026,0xc010008b,0xd823005e,0x00000000}},	//   _góða, _đuổi_, идљи,
  { {0xdb1c05b9,0x764b001f,0x5b36000d,0x00000000}},	//   _spræ, _bygy, _рэгу,
  { {0x6603005e,0x89660085,0xaa46231a,0x00000000}},	//   ипћа, _акаж, _реал,
  { {0xb4ac0235,0x03f80001,0x764b002b,0x00000000}},	//   गले_, еној_, _dygy,
  { {0xe9ff001b,0xdb050d92,0xd6cf1134,0x00000000}},	//   _thảo_, luhá, _кт_,
  { {0x67220035,0x644a01d9,0x764b001f,0x00000000}},	//   _umoj, _vyfi, _fygy,
  { {0x92580121,0x63a80dad,0x8334012c,0x00000000}},	//   кают_, srdn, рнях,
  { {0x644a002b,0xdb050003,0x3494231b,0x00000000}},	//   _tyfi, rrhé, _сакр,
  { {0x4035000a,0x6b510137,0x7f940456,0x00000000}},	//   уевс, fågl, иарх,
  { {0x6d470026,0x6b510137,0xb7db009f,0x00000000}},	//   _skja, vågo, וקלי,
  { {0x2d8f0164,0x7e550086,0x64460058,0x00000000}},	// [36d0] ège_, уває, şkid,
  { {0xe9ff0013,0x15f50042,0xac19231c,0x00000000}},	//   _nhạo_, ेहतर_, нозу_,
  { {0xf1bf231d,0x69c90479,0x7a0a008f,0x00000000}},	//   ltá_, _spee, _lētā,
  { {0x6b5101e3,0xee84026c,0x394e0983,0x00000000}},	//   rågo, _выро, elfs_,
  { {0x7b1300be,0xe8ee0054,0x2d540072,0x00000000}},	//   _açuc, бл_, mäen_,
  { {0xf1bf017d,0x387e01a8,0x6f0d231e,0x00000000}},	//   itá_, _cftr_, lkac,
  { {0xf77108aa,0x6f0d231f,0x31580047,0x00000000}},	//   حات_, okac, דיגן_,
  { {0x6f0d2320,0xdb050025,0xcb690021,0x00000000}},	//   nkac, rthó, _أمره_,
  { {0xdb050026,0x645c0026,0x66050076,0x00000000}},	//   sthó, ýrin, уппа,
  { {0x6b582321,0x3f9e0078,0xe6160065,0x00000000}},	//   ríge, štui_, удь_,
  { {0x23d4000d,0xd6d70044,0xc209089e,0x00000000}},	//   ацяр, _لتشغ, _צה_,
  { {0xa77a0047,0x82f60002,0x6d452322,0x00000000}},	//   _טרעפ, учоц, hoha,
  { {0x6d450004,0x6f0d0051,0x67291265,0x00000000}},	//   koha, dkac, miej,
  { {0x6d4500e3,0x67290006,0x1c030053,0x00000000}},	//   joha, liej, लहाल_,
  { {0x232a0086,0x25bf003b,0x6d450052,0x00000000}},	//   _поки_, ltul_, doha,
  { {0x67290045,0x25bf003b,0x26df0078,0x00000000}},	//   niej, otul_, nduo_,
  { {0x25bf0469,0x66092323,0xee3a2324,0x00000000}},	// [36e0] ntul_, nyek, хна_,
  { {0x98a70006,0xdd8f0049,0x25bf2325,0x00000000}},	//   monė_, سوم_, itul_,
  { {0x629600a4,0xb17b0137,0x25bf004b,0x00000000}},	//   _keyo, nvån, htul_,
  { {0xa3e40161,0x67290078,0x41a80042,0x00000000}},	//   नित_, jiej, _कटास,
  { {0xe81c0053,0x6d452326,0x67290078,0x00000000}},	//   _भेजा_, boha, diej,
  { {0x6f03000c,0x6d450089,0xdb1c0354,0x00000000}},	//   _încr, coha, _sprä,
  { {0x6d5c005b,0x25bf2327,0x8bd80063,0x00000000}},	//   _ihra, etul_, _בַּח,
  { {0x2f1500b9,0x75280051,0x758a2328,0x00000000}},	//   _tåge_, widz, нсов_,
  { {0x163400a0,0x87030121,0xe9ff0013,0x00000000}},	//   репя, сяще, _thạo_,
  { {0x88bc0080,0x645c0046,0x6f0d2329,0x00000000}},	//   _změn, ýrio, zkac,
  { {0x62960969,0x6f0d0051,0x25bf003b,0x00000000}},	//   _beyo, ykac, atul_,
  { {0x66760021,0x6b650006,0x66090150,0x00000000}},	//   _إدار, _bėgy, byek,
  { {0x25bf000c,0x6d5c0606,0x2d540072,0x00000000}},	//   ctul_, _ohra, väen_,
  { {0xf1bf1397,0xfebb007e,0x6f0d0051,0x00000000}},	//   rtá_, کاست_, wkac,
  { {0x2d5400fe,0xf1bf0fa9,0xe47b0063,0x00000000}},	//   täen_, stá_, _ארוכ,
  { {0xfe730021,0x212a0025,0x6458232a,0x00000000}},	//   صدر_, aibh_, _izvi,
  { {0x6d5c0027,0x6d45232b,0x6f0d151f,0x00000000}},	// [36f0] _bhra, toha, rkac,
  { {0xb0b20161,0x6729232c,0x6f0d232d,0x00000000}},	//   _जाएग, ziej, skac,
  { {0x62960009,0xa2bc0161,0x8c190021,0x00000000}},	//   _yeyo, ष्क्, خيار_,
  { {0x98a9007d,0x8c64232e,0x8d77043e,0x00000000}},	//   đač_, студ, _ماسا,
  { {0x60de01f7,0x25bf0529,0x6d5c0025,0x00000000}},	//   _yapm, xtul_, _fhra,
  { {0x28f80076,0x6d5c232f,0x67290022,0x00000000}},	//   лечь_, _ghra, wiej,
  { {0xdb1c2330,0x67290006,0x644e004b,0x00000000}},	//   _språ, tiej, übil,
  { {0x88bc0080,0x49900043,0xf99300de,0x00000000}},	//   _uměn, _کیور, _هبط_,
  { {0x67290006,0x98a70022,0x64580077,0x00000000}},	//   riej, enną_, _azvi,
  { {0x25bf0529,0x62960150,0x67291265,0x00000000}},	//   rtul_, _seyo, siej,
  { {0x661b0045,0x25bf2331,0x47d50021,0x00000000}},	//   szuk, stul_, _خيار,
  { {0x25bf0529,0xb17b0137,0x39472332,0x00000000}},	//   ptul_, rvån, lons_,
  { {0xcad6009a,0xfad6009a,0x00000000,0x00000000}},	//   בורת_, בורך_,   ,
  { {0x39472333,0x25ad0066,0x660601cf,0x00000000}},	//   nons_, mrel_, äkke,
  { {0x212a0139,0xdfd2009e,0x5f061cab,0x00000000}},	//   ribh_, غير_, азва,
  { {0x6d5c2334,0x39472335,0x8e860ee5,0x00000000}},	//   _shra, hons_, ргае,
  { {0xa156005a,0x1d2608a2,0x60de004b,0x00000000}},	// [3700] _външ, амам, _tapm,
  { {0xdca60138,0x2fdf0051,0xfe7f2336,0x00000000}},	//   ражи, ługa_, _naïf_,
  { {0x60c300ea,0x443c2337,0x61e60137,0x00000000}},	//   _önma, _xxv_, lvkl,
  { {0x103b009a,0xca0a0131,0xdee62338,0x00000000}},	//   _יגיע, кнеж_, _томи,
  { {0xd90d007e,0x39472339,0xc27b0063,0x00000000}},	//   کیل_, fons_, דרני,
  { {0x3947233a,0xb21b0026,0x61fb004d,0x00000000}},	//   gons_, mbæt, äuli,
  { {0xf0930063,0xf803000d,0x320b0051,0x00000000}},	//   חנו_, жчын, zycy_,
  { {0xa3e40235,0x257b001f,0x394700cd,0x00000000}},	//   निस_, _bêl_, aons_,
  { {0x394701a8,0xc6f70895,0x98be0078,0x00000000}},	//   bons_, рных_, _aktą_,
  { {0x75140002,0x75060002,0x7ae2233b,0x00000000}},	//   смоф, рџие, ldot,
  { {0x2f150137,0x69c2233c,0x7ae0233d,0x00000000}},	//   _låga_, ltoe, _kamt,
  { {0x25ad00ac,0x86460925,0x7ae0233e,0x00000000}},	//   brel_, _кнеж, _jamt,
  { {0x69c2233f,0x7ae22340,0x273a008f,0x00000000}},	//   ntoe, idot, cīna_,
  { {0x7ae200fe,0x29c2008b,0x320b0022,0x00000000}},	//   hdot, _mưa_, rycy_,
  { {0x69c2024a,0x753d000f,0x64582341,0x00000000}},	//   htoe, észe, _uzvi,
  { {0x69c20983,0x88bc004c,0x39472342,0x00000000}},	//   ktoe, _směl, zons_,
  { {0x39470164,0xdcfd001c,0x7bdc0150,0x00000000}},	// [3710] yons_, _atsā, _asru,
  { {0x629d0fbf,0x69c200f5,0x30a70413,0x00000000}},	//   laso, dtoe, _трив,
  { {0x39470164,0x25ad0066,0xbc48000d,0x00000000}},	//   vons_, zrel_, ачце_,
  { {0x629d2343,0x7ae20534,0x28c40042,0x00000000}},	//   naso, gdot, ल्सि,
  { {0xa2bc0161,0x69c2016d,0xf1b40047,0x00000000}},	//   ष्ट्, gtoe, ַסק_,
  { {0x88bc0080,0xa9240086,0x629d2344,0x00000000}},	//   _uměl, оділ, haso,
  { {0x39472345,0xfb84000d,0x257b002b,0x00000000}},	//   rons_, _мытн, _sêl_,
  { {0x257b001f,0x394704bc,0xfc460024,0x00000000}},	//   _pêl_, sons_, číta_,
  { {0x69db2346,0x39472347,0x629d2348,0x00000000}},	//   _usue, pons_, daso,
  { {0x629d0d11,0x25ad2349,0x8cca0082,0x00000000}},	//   easo, rrel_, स्पो,
  { {0xb9360041,0xe29a1dd0,0x76590022,0x00000000}},	//   _פרעג_, лан_, _wzwy,
  { {0x68e1234a,0x2905234b,0x2d85234c,0x00000000}},	//   _hald, _hola_, _člen_,
  { {0x29c2008b,0x673e00ea,0x68e1234d,0x00000000}},	//   _xưa_, épje, _kald,
  { {0xa3e40235,0x61e200c2,0xd4790047,0x00000000}},	//   निश_, _šols, _גאַל,
  { {0xb4b30235,0x09d40053,0x8cca0053,0x00000000}},	//   टली_, _धन्य, स्फो,
  { {0x629d234e,0x6b5100a5,0x93250044,0x00000000}},	//   caso, bågi, _ورين,
  { {0x7ae01036,0x0c7601fb,0x8d760021,0x00000000}},	// [3720] _ramt, مداد, صاءا,
  { {0x7ae019b2,0xb21b0026,0x2f150137,0x00000000}},	//   _samt, rbæt, _våga_,
  { {0x7ae0007d,0x29c2008d,0xd00a234f,0x00000000}},	//   _pamt, _sưa_, _сене_,
  { {0x9b2515d4,0x3f9e0078,0xb21b0014,0x00000000}},	//   офіл, štus_, mbær,
  { {0x59f80612,0xd910007e,0x29052350,0x00000000}},	//   реля_, ویر_, _bola_,
  { {0xdd8f0021,0x69c21103,0xd94308b9,0x00000000}},	//   _سوف_, rtoe, печи,
  { {0x29050035,0x629d0035,0xdb1c00b9,0x00000000}},	//   _dola_, yaso, _oprø,
  { {0xdc370047,0x69c22351,0x98bc0078,0x00000000}},	//   _האלט_, ptoe, dovą_,
  { {0x629d2352,0x68e12353,0x29050139,0x00000000}},	//   vaso, _fald, _fola_,
  { {0x9179008b,0x4ddb0063,0x29052354,0x00000000}},	//   hận_, נחיו, _gola_,
  { {0x629d084e,0x8cca0053,0x60d501c8,0x00000000}},	//   taso, स्यो, vezm,
  { {0x23a90042,0x29052355,0xdb05051c,0x00000000}},	//   _किरद, _zola_, sthö,
  { {0xdcef000c,0x7d030626,0x29050058,0x00000000}},	//   _jucă, önsk, _yola_,
  { {0x463b00b5,0x629d1db0,0x88bc004c,0x00000000}},	//   _געדע, saso, _směj,
  { {0x4ac80161,0x629d2356,0x29370047,0x00000000}},	//   रभाव, paso, צאלן_,
  { {0x6d4e2357,0x9f550054,0x2fdf0022,0x00000000}},	//   _akba, івач, ługo_,
  { {0xcc99005e,0x673c013d,0xe29f0046,0x00000000}},	// [3730] ивац_, _írju, mað_,
  { {0xe29f0026,0x00000000,0x00000000,0x00000000}},	//   lað_,   ,   ,
  { {0x61ed0066,0x8bd90f56,0xab9b0044,0x00000000}},	//   _hral, рмес_, اخطر_,
  { {0xe29f007a,0x527c0047,0x29052358,0x00000000}},	//   nað_, ָנגא, _sola_,
  { {0x68e12359,0x9e67007e,0x76550051,0x00000000}},	//   _pald, _دادن, ęzyk,
  { {0x777a00cd,0x63a1004c,0x88c80054,0x00000000}},	//   _butx, ysln, йлів_,
  { {0x68e112fa,0xe29f007a,0x6b950051,0x00000000}},	//   _vald, kað_, _uwzg,
  { {0xe29f0026,0x61ed235a,0x68e1235b,0x00000000}},	//   jað_, _oral, _wald,
  { {0x6aa900d1,0x68e1235c,0xa5f6005e,0x00000000}},	//   _idef, _tald, жењу_,
  { {0x6284235d,0x8937014d,0x98bc0078,0x00000000}},	//   _sfio, _اعرا, tovą_,
  { {0xe29f0026,0x6446005b,0x61ed235e,0x00000000}},	//   fað_, şkin, _aral,
  { {0xe29f0026,0x61ed235f,0x63a10014,0x00000000}},	//   gað_, _bral, rsln,
  { {0x64a52360,0x20050072,0xdb20009c,0x00000000}},	//   _дала, älin_, étéb,
  { {0xe3b10021,0x3ce300c2,0x7bc50829,0x00000000}},	//   _قرب_, _najv_, kthu,
  { {0x61ed0004,0x90c30121,0xa7a9009a,0x00000000}},	//   _eral, ьбре, יֹּ֥,
  { {0x61ed2361,0x6aa9080d,0x91790013,0x00000000}},	//   _fral, _ndef, uận_,
  { {0x7bc5002b,0xcd2a000d,0x6e29004c,0x00000000}},	// [3740] ethu, ажае_, _žebr,
  { {0x6b58032a,0x4d630054,0xdb0501d1,0x00000000}},	//   tígo, дкув, vrhá,
  { {0x8b26019d,0x1c39000d,0x672b16af,0x00000000}},	//   одже, бяць_, _omgj,
  { {0x7b3c01a6,0xa8020058,0xdb05004c,0x00000000}},	//   ačun, şıkl, trhá,
  { {0x6aa90185,0x2d4f0268,0xd946183f,0x00000000}},	//   _ddef, gües_, оеди,
  { {0xf1bf00ea,0x3ea02362,0x6b5801a8,0x00000000}},	//   szág_, lait_, pígo,
  { {0xfbc32363,0x86c40044,0xbab600de,0x00000000}},	//   _обро, كيغن, _ومسب,
  { {0x3ea00164,0xc6f80193,0xd6d90051,0x00000000}},	//   nait_, сних_, kołu_,
  { {0xb17b0031,0xe29f0026,0x50ca0053,0x00000000}},	//   rvåk, vað_, िभाष,
  { {0x3ea00164,0x38c8007e,0x6aa90051,0x00000000}},	//   hait_, _داری_, _zdef,
  { {0xe29f007a,0x3ea02364,0xe3b80058,0x00000000}},	//   tað_, kait_, azın_,
  { {0x3ea000ea,0x0665007e,0x61ed2365,0x00000000}},	//   jait_, _کامپ, _pral,
  { {0xe29f0026,0x3636007e,0x3ea00003,0x00000000}},	//   rað_, _براس, dait_,
  { {0x7bc5001f,0xe29f0026,0xf44016f2,0x00000000}},	//   ythu, sað_, _полi_,
  { {0x7d0700c3,0xe29f0026,0x3ea00003,0x00000000}},	//   _rojs, pað_, fait_,
  { {0x23280001,0x61e90b19,0x3ea0013d,0x00000000}},	//   _моји_, åels, gait_,
  { {0x61ed2366,0xdcef004c,0x3f570058,0x00000000}},	// [3750] _ural, řeče, lçuk_,
  { {0xed51005d,0x765d0046,0xa1280044,0x00000000}},	//   رپا_, ýsyi, _وكيل_,
  { {0x3ea02367,0x7d07064f,0x79892368,0x00000000}},	//   bait_, _vojs, _stew,
  { {0x7d070045,0x52d800b5,0xfaa70086,0x00000000}},	//   _wojs, ַווע_, ішен,
  { {0x5efa0063,0x7bc52369,0xd358009a,0x00000000}},	//   _הפרד, sthu, קידי_,
  { {0xd6d90022,0xdce70022,0x09040083,0x00000000}},	//   hołt_, _biją, мпін,
  { {0x48090c46,0xa08c009d,0x00000000,0x00000000}},	//   сейн_, בְחִ,   ,
  { {0x6aa901e1,0x97d80021,0x753a0244,0x00000000}},	//   _udef, تظهر_, entz,
  { {0x644601f7,0xd8380c61,0x49b80044,0x00000000}},	//   şkil, _reče_, _واكد_,
  { {0x6e200004,0x58bb0242,0xe576236a,0x00000000}},	//   _ümbe, _خارج_, язь_,
  { {0x6d890024,0x3ea0236b,0xdc3e003b,0x00000000}},	//   _hľad, yait_, mţăm,
  { {0x62810045,0xdc3e000c,0x2d8b004c,0x00000000}},	//   ślon, lţăm, _otce_,
  { {0x2bd20235,0x21a30076,0x3ea0236c,0x00000000}},	//   _सहभा, ниям, vait_,
  { {0x3ea0236d,0xeb180053,0xeb080042,0x00000000}},	//   wait_, _दत्त_, _वक्त_,
  { {0x3ea0236e,0x29360047,0x673b0c22,0x00000000}},	//   tait_, לאשן_, onuj,
  { {0x673b004b,0xdd9200f2,0xd6d90022,0x00000000}},	//   nnuj, فور_, połu_,
  { {0x3ea0236f,0xb2bb0063,0x645c008f,0x00000000}},	// [3760] rait_, _המפר, ļrie,
  { {0x3ea02370,0x40960121,0xad5a06c9,0x00000000}},	//   sait_, _эрит, ёрах_,
  { {0xa3e40161,0x0c26018e,0x3ea02371,0x00000000}},	//   निए_, џмен, pait_,
  { {0x63be0031,0x7076007e,0xc0470013,0x00000000}},	//   _åpne, _واگذ, _lượn_,
  { {0xceb300b7,0x0d83000d,0xd6d90022,0x00000000}},	//   _איר_, _плян, deł_,
  { {0x6f0401b3,0xf8060086,0x673b2372,0x00000000}},	//   ljic, зчин, enuj,
  { {0x6f040066,0x9d1b009a,0xad1b009d,0x00000000}},	//   ojic, _פולט, _פולר,
  { {0x753d013d,0x6f040734,0x1ae32373,0x00000000}},	//   észn, njic, _посм,
  { {0x6e242374,0x3494000d,0xe4e6071f,0x00000000}},	//   nzib, мапр, пінн,
  { {0x6e24003b,0x62862375,0x645d005f,0x00000000}},	//   izib, ecko, ęsin,
  { {0x8cc10053,0xd6d90022,0xa2c10082,0x00000000}},	//   र्टो, beł_, _वाद्,
  { {0xf6e5019d,0x6aa20035,0x1dac0053,0x00000000}},	//   _оцін, naof, _चिंत,
  { {0x7af60072,0x87250044,0xcb13009d,0x00000000}},	//   öyty, _تعلم, גלר_,
  { {0x98bc0006,0x6f040080,0x98a7000c,0x00000000}},	//   tovę_, ejic, mină_,
  { {0x3d000161,0x98a7003b,0xf55b0063,0x00000000}},	//   राने_, lină_, _הדגמ,
  { {0x394e004d,0xdb0500d1,0xb6a30013,0x00000000}},	//   hofs_, orhå, _nhầ,
  { {0xa3e40161,0xa2a20053,0x98a7003b,0x00000000}},	// [3770] निक_, _ख़त्, nină_,
  { {0xf1b20053,0xdb1c0051,0x673b085a,0x00000000}},	//   _जितन, _opró, znuj,
  { {0x63ba06bb,0x4af9005d,0x673b056c,0x00000000}},	//   nutn, يکرد_, ynuj,
  { {0x6f160066,0x5a350cb2,0x6b5100a5,0x00000000}},	//   ckyc, мнет, vågs,
  { {0xf9840086,0x98a7003b,0xf9880021,0x00000000}},	//   егіо, jină_, كنني_,
  { {0x63ba2376,0xdb1c0139,0xe9d80454,0x00000000}},	//   kutn, _bpró, які_,
  { {0x67d2000a,0x1bd40928,0x98bc004c,0x00000000}},	//   воју, _поря, lově_,
  { {0xe6192377,0x7b3c0195,0x2ee9002b,0x00000000}},	//   жди_, hčuj, ndaf_,
  { {0x98a70529,0x98bc004c,0xcec0004c,0x00000000}},	//   gină_, nově_, ířit_,
  { {0x7c25027d,0xd6d90051,0xe6c4007d,0x00000000}},	//   ozhr, seł_, češć,
  { {0x2d540004,0x98bc004c,0x78a30d90,0x00000000}},	//   päev_, hově_, manv,
  { {0x98bc004c,0x78a3086f,0x5727002a,0x00000000}},	//   kově_, lanv, _عراق,
  { {0x98a7000c,0x2ee9001f,0xaefb0013,0x00000000}},	//   cină_, ddaf_, _phùn,
  { {0x657d0025,0x6da2000c,0x63ba2378,0x00000000}},	//   íshu, nţaţ, butn,
  { {0x6f160066,0x93a80044,0x6288004c,0x00000000}},	//   tkyc, _فايف_, ědob,
  { {0xdbd90016,0x9f550001,0x20040022,0x00000000}},	//   nçõe, ењуј, ćmi_,
  { {0xdbd90016,0xee3a13bd,0xaefb008b,0x00000000}},	// [3780] içõe, цна_, _thùn,
  { {0x6f160024,0x78a32379,0x70860062,0x00000000}},	//   skyc, janv, _югоз,
  { {0x6f66000a,0xb6a3001b,0xda7a0612,0x00000000}},	//   _овоз, _phầ, оял_,
  { {0x60dc237a,0xddcb237b,0x7c6504a0,0x00000000}},	//   lerm, žišk, رالل,
  { {0xdb1c0045,0xa2c10053,0xfaa3237c,0x00000000}},	//   _spró, _वास्, тачо,
  { {0x7d0300c7,0x98a7000c,0x478a0612,0x00000000}},	//   önst, vină_, осим_,
  { {0x38cb006a,0xd7f00021,0x60dc237d,0x00000000}},	//   تانی_, اكب_, ierm,
  { {0x8cca0161,0x98a7000c,0x60dc237e,0x00000000}},	//   स्रो, tină_, herm,
  { {0x60dc237f,0x87030121,0x6d400046,0x00000000}},	//   kerm, тяще, _ímas,
  { {0x60dc0031,0x63ba0228,0x2fdf0045,0x00000000}},	//   jerm, tutn, ługi_,
  { {0x61e40009,0x60dc2380,0x291e0072,0x00000000}},	//   _asil, derm, _ilta_,
  { {0x68e82381,0xdbd90016,0x79800035,0x00000000}},	//   _hadd, cçõe, _kumw,
  { {0x61e400ea,0x63ba20d2,0x290c1830,0x00000000}},	//   _csil, sutn, _koda_,
  { {0x660f0d88,0x637e001c,0x7b3c00c2,0x00000000}},	//   äcke, _līni, učuj,
  { {0x68e82382,0x61e42383,0x290c1ea0,0x00000000}},	//   _madd, _esil, _moda_,
  { {0xc3280032,0x68e80924,0x98bc004c,0x00000000}},	//   _يكون_, _ladd, tově_,
  { {0x6458024a,0x68fa0173,0x8d790021,0x00000000}},	// [3790] _hyvi, _ontd, سماء_,
  { {0x60dc2384,0x447b0047,0x290c04b5,0x00000000}},	//   cerm, ַנדע, _noda_,
  { {0x3dc912cc,0x98bc004c,0x78a30072,0x00000000}},	//   staw_, sově_, vanv,
  { {0xab940086,0xdd95000d,0xfbd0007e,0x00000000}},	//   тиці, _памы, شتم_,
  { {0x78a32385,0x290c2386,0xe9ce0085,0x00000000}},	//   tanv, _boda_, ык_,
  { {0x3f810019,0x290c2387,0x41b20053,0x00000000}},	//   _kuhu_, _coda_, _जिसस,
  { {0xa927001c,0x78a301bb,0x645804aa,0x00000000}},	//   _režī, ranv, _nyvi,
  { {0x68fa00bd,0x78a31374,0x291e0026,0x00000000}},	//   _entd, sanv, _elta_,
  { {0xdbd9017d,0x3a540076,0x99840021,0x00000000}},	//   rçõe, _актё, _للقو,
  { {0x7ae900fe,0x442512ca,0x290c2388,0x00000000}},	//   _haet, tzl_, _goda_,
  { {0x5695005a,0xdbd90016,0x7ae90019,0x00000000}},	//   _зает, pçõe, _kaet,
  { {0x7ae900fe,0x290702e2,0x69cb0229,0x00000000}},	//   _jaet, ljna_, otge,
  { {0x78a100fe,0xa2c10161,0x29c9130b,0x00000000}},	//   _kelv, _वार्, núa_,
  { {0x61e400c3,0x69cb05e2,0x7ae92389,0x00000000}},	//   _vsil, itge, _laet,
  { {0x69cb0717,0x29071886,0xdcee0013,0x00000000}},	//   htge, ijna_, _libă,
  { {0xe4560047,0x60dc17c0,0x3f8108ed,0x00000000}},	//   _איצט_, serm, _duhu_,
  { {0xce47005a,0x8d660076,0x69cb006f,0x00000000}},	// [37a0] езте_, евае, jtge,
  { {0x7659001f,0x7afb1fdc,0x69cb004d,0x00000000}},	//   _mywy, _anut, dtge,
  { {0x7659001f,0x309b0063,0x69cb238a,0x00000000}},	//   _lywy, _משימ, etge,
  { {0x61220024,0x2d9200e8,0xbae50086,0x00000000}},	//   _dôle, ppye_, кцій,
  { {0x7ae90185,0x290c238b,0x2bd20053,0x00000000}},	//   _daet, _poda_, _सहवा,
  { {0x07e6005e,0x7afb02d2,0x612200be,0x00000000}},	//   ецим, _enut, _fôle,
  { {0xd7e7000a,0xb9080161,0x9d4308b9,0x00000000}},	//   емје_, _बस_, _серд,
  { {0x8b66006a,0x76590185,0x79800035,0x00000000}},	//   _سازم, _bywy, _tumw,
  { {0x69cb0122,0x78a100ea,0xe4c60076,0x00000000}},	//   ctge, _felv, нённ,
  { {0x98a70006,0x7659001f,0xb17b0137,0x00000000}},	//   tiną_, _dywy, kvår,
  { {0x3320238c,0x2d82238d,0x7d0e00e5,0x00000000}},	//   _blix_, _luke_, _mobs,
  { {0x78a1006f,0x7659001f,0x3f570110,0x00000000}},	//   _zelv, _fywy, nçut_,
  { {0x6e3b0024,0x9403007e,0x3f81238e,0x00000000}},	//   _ľubo, نویه, _suhu_,
  { {0x3f81238f,0x7d0e2390,0xe5340200,0x00000000}},	//   _puhu_, _nobs, _шель,
  { {0xdfd8005a,0xb17b00a5,0x2d82004e,0x00000000}},	//   нът_, gvår, _auke_,
  { {0x61220003,0xa8570063,0xadd5005e,0x00000000}},	//   _rôle, גילה_, кобљ,
  { {0x5d550189,0x238c004c,0x69cb2391,0x00000000}},	// [37b0] вкат, _děje_, xtge,
  { {0x7ae9001f,0xdb1e0019,0x2d822392,0x00000000}},	//   _saet, htpä, _duke_,
  { {0x78a12393,0xe3b80058,0xef1f004b,0x00000000}},	//   _relv, nrı_, _tlü_,
  { {0x29c9006d,0xe3b30047,0x78a12394,0x00000000}},	//   túa_, רױף_, _selv,
  { {0x09e50caa,0x78a12395,0x753d013d,0x00000000}},	//   толн, _pelv, észk,
  { {0x88bc0080,0x69cb2396,0x7ae9001f,0x00000000}},	//   _směr, rtge, _waet,
  { {0x69cb2397,0x2d54004d,0x68450062,0x00000000}},	//   stge, päer_, ънка,
  { {0x7afb2398,0x78a10229,0x69cb004d,0x00000000}},	//   _unut, _welv, ptge,
  { {0x9fb60080,0x9182008b,0x637e008f,0x00000000}},	//   vřít_, iện_, _mīnu,
  { {0x601c0d90,0xe975013a,0xa8020058,0x00000000}},	//   nämö, _شهاد, ğırl,
  { {0x3f570003,0xa91d007c,0x03950062,0x00000000}},	//   nçus_, _tužb, ърпя,
  { {0x76590185,0x6f0f0290,0x6b58017d,0x00000000}},	//   _tywy, _nocc, bígu,
  { {0xf1bf2399,0xe3b80058,0xd24f0044,0x00000000}},	//   guá_, arı_, ْنُ_,
  { {0x2d82239a,0x26df002b,0xf8e10042,0x00000000}},	//   _ruke_, leuo_, फ़िय,
  { {0x6f0f239b,0x10a31b8b,0xdb1e00d1,0x00000000}},	//   _bocc, рисн, ltpå,
  { {0xc7b211b4,0x6f0f239c,0x2216239d,0x00000000}},	//   יבל_, _cocc, _афор,
  { {0x3ea200d1,0x9313007e,0xb17b0137,0x00000000}},	// [37c0] _vekt_, _خويش, rvår,
  { {0xb17b0137,0x3ea200ca,0xf1b9004c,0x00000000}},	//   svår, _wekt_, áše_,
  { {0xa7fc005b,0xd8380066,0xb17b04aa,0x00000000}},	//   _azın, _rečo_, mvåp,
  { {0x98a70006,0x6f0f0290,0xdcb10013,0x00000000}},	//   minę_, _gocc, _ổn_,
  { {0x3f570003,0x98a7232c,0xc3330063,0x00000000}},	//   rçut_, linę_, סוד_,
  { {0x6f0f0290,0xe3b80058,0xb2270014,0x00000000}},	//   _zocc, yrı_, _hræð,
  { {0xb8da0053,0x97a3000d,0x6a861b76,0x00000000}},	//   _आए_, арыл, _алба,
  { {0x6b58239e,0x6d5e13bb,0xe3b80058,0x00000000}},	//   tígu, llpa, vrı_,
  { {0xe6630062,0xd5660094,0xbb77009a,0x00000000}},	//   итьо, ктоп, _יעלו_,
  { {0xe29a001b,0x660f00c7,0xfe7f00cd,0x00000000}},	//   _đưa_, äcka, _raïm_,
  { {0x39490e1a,0x9182008b,0x6d5e239f,0x00000000}},	//   éase_, yện_, ilpa,
  { {0x7b3c007d,0x98a70006,0x63b50114,0x00000000}},	//   ačuv, dinę_, ázna,
  { {0x6f0f23a0,0x2b460024,0x25bf006f,0x00000000}},	//   _rocc, čoch_, cuul_,
  { {0x2f1502eb,0x6d5e006f,0x98a70006,0x00000000}},	//   _lågt_, jlpa, finę_,
  { {0x443a0019,0xb4be0053,0xb2270014,0x00000000}},	//   _äp_, इली_, _bræð,
  { {0x200700cd,0x5eb40ac5,0x6d5e23a1,0x00000000}},	//   _ànim_, ийст, elpa,
  { {0x6ca70612,0x291c0014,0x61f6005f,0x00000000}},	// [37d0] вреж, kkva_, _gryl,
  { {0x01fa009f,0x63ba02fd,0x98a70d07,0x00000000}},	//   _נפתל, ortn, binę_,
  { {0x6f0f0682,0xb2270026,0x98a70006,0x00000000}},	//   _tocc, _fræð, cinę_,
  { {0x3f570003,0xb2270014,0xce950062,0x00000000}},	//   rçus_, _græð, _щамъ,
  { {0x78a50026,0x3ea923a2,0x6eba0063,0x00000000}},	//   ðhvo, maat_, _אזרח,
  { {0xeb93006a,0x3ea923a3,0x672223a4,0x00000000}},	//   _نظر_, laat_, _aloj,
  { {0x98a20076,0x645c004b,0xc7a80044,0x00000000}},	//   щище, üril, نديل_,
  { {0x3ea9126e,0x6b83017d,0xa91d007d,0x00000000}},	//   naat_, íngu, _duža,
  { {0xb17b04aa,0x8cca0042,0x63ba0022,0x00000000}},	//   yvåp, स्को, ertn,
  { {0x20180050,0x97c50044,0x27f70044,0x00000000}},	//   yyri_, _مقطو, _لأصح,
  { {0x69c60137,0x67222386,0xf6d50054,0x00000000}},	//   _äker, _floj, _біля,
  { {0xdb1e00d1,0x644f003b,0x61f60137,0x00000000}},	//   ptpå, şcio, _pryl,
  { {0xba3d0080,0x63ba0ff8,0x20b60121,0x00000000}},	//   _zdůr, artn, лёвс,
  { {0x25ad09fb,0x98a70006,0x61f600ac,0x00000000}},	//   msel_, tinę_, _vryl,
  { {0x25ad23a5,0x3ea908a3,0x201e23a6,0x00000000}},	//   lsel_, faat_, áti_,
  { {0x69db006d,0x6d5e006f,0x543a0047,0x00000000}},	//   _opue, wlpa, _רעקא,
  { {0x25ad23a7,0x98a723a8,0x201e23a9,0x00000000}},	// [37e0] nsel_, sinę_, šti_,
  { {0xdb0a0080,0x527b0047,0xb19b0149,0x00000000}},	//   ěnít, _אנפא, _רייכ,
  { {0xf53600b5,0x69db006d,0x62810080,0x00000000}},	//   נטער_, _apue, ělov,
  { {0x3ea90122,0x0b46000d,0x25ad23aa,0x00000000}},	//   caat_, ынен, ksel_,
  { {0xa91d00fc,0x25ad00ca,0x99d30021,0x00000000}},	//   _suža, jsel_, متوا,
  { {0x25ad23ab,0x67220734,0xda65014d,0x00000000}},	//   dsel_, _sloj, جامي,
  { {0x660f0137,0xdce60078,0xd90d007e,0x00000000}},	//   äckn, _sukė, بیل_,
  { {0x7f440164,0x25ad0104,0xc6f823ac,0x00000000}},	//   nniq, fsel_, тних_,
  { {0x25ad23ad,0x4a460085,0x0f7b0041,0x00000000}},	//   gsel_, _снав, ערפל,
  { {0x2956011c,0x03f80001,0x80d60053,0x00000000}},	//   _събр, вној_, म्मे,
  { {0x69c2001f,0x7b3c00c2,0x86c601fb,0x00000000}},	//   luoe, bčut, _ميان,
  { {0xf1bf00ea,0xa91d064f,0x27e0003b,0x00000000}},	//   szám_, _južn, ăind_,
  { {0xa596011c,0x3ea90186,0x25ad001f,0x00000000}},	//   _срещ, vaat_, csel_,
  { {0x98a70080,0xa2c10053,0x7bdc23ae,0x00000000}},	//   dině_, _वाक्, _opru,
  { {0x753a0994,0x3ea923af,0x4f6b0131,0x00000000}},	//   mitz, taat_, ешам_,
  { {0x753a0c3f,0x3e07005a,0xa91d017f,0x00000000}},	//   litz, лязв, _nužn,
  { {0xdb1e03b2,0x3ea923b0,0x7bdc23b1,0x00000000}},	// [37f0] cupé, raat_, _apru,
  { {0x753a0994,0x3ea923b2,0xd7f8000c,0x00000000}},	//   nitz, saat_, _oră_,
  { {0x3ea923b3,0xbed502d8,0x25ad23b4,0x00000000}},	//   paat_, _конј, zsel_,
  { {0x7f440268,0x4f9a0063,0x8f9a0063,0x00000000}},	//   cniq, _שברצ, _שירי,
  { {0xa91d017f,0x628f0290,0xd7f8003b,0x00000000}},	//   _dužn, icco, _ară_,
  { {0x6f0d007d,0x7a2a013d,0xa7b5007b,0x00000000}},	//   ljac, _söté, асиј,
  { {0xd70503d6,0x25ad002b,0x753a01a8,0x00000000}},	//   изки, wsel_, ditz,
  { {0x47590062,0x660f0137,0x6f0d23b5,0x00000000}},	//   ърля_, äcko, njac,
  { {0xd7060076,0x6d4500fe,0x6e2d23b6,0x00000000}},	//   рные_, onha, nzab,
  { {0x62880080,0x25ad23b7,0x612b004d,0x00000000}},	//   ědom, rsel_, _hülf,
  { {0x6d4523b8,0x612b00ea,0x78fa0149,0x00000000}},	//   inha, _külf, _שלעפ,
  { {0x249801f7,0x45d523b9,0x25ad23ba,0x00000000}},	//   ırma_, _водс, psel_,
  { {0x8afd004c,0x442c0022,0xf5050456,0x00000000}},	//   _chři, azd_, _взло,
  { {0x628f23bb,0x98a70080,0xa91d1994,0x00000000}},	//   acco, vině_, _mužo,
  { {0x2bb10045,0x68fc02dd,0x398b07e6,0x00000000}},	//   jąc_, _órde, _løs_,
  { {0x68e323bc,0x98a70080,0x63bc0066,0x00000000}},	//   hend, tině_, árne,

  { {0x63a3001f,0xed5a0095,0x661b23bd,0x00000000}},	// [3800] _hwnn, воа_, nyuk,
  { {0x4103000d,0xf1bf00ea,0x68e323be,0x00000000}},	//   _дзьв, zzák_, jend,
  { {0x68e323bf,0x65610137,0x661b0150,0x00000000}},	//   dend, illh, hyuk,
  { {0x98a70080,0x6f0d0051,0x2bd70053,0x00000000}},	//   pině_, cjac, _ठहरा,
  { {0x272a008b,0x660f0137,0x82d70047,0x00000000}},	//   _hùng_, äckl, שונג_,
  { {0x68e323c0,0x7ae20bda,0x8b96101a,0x00000000}},	//   gend, seot, _врач,
  { {0x753a090d,0x6d5c23c1,0xa91d007d,0x00000000}},	//   vitz, _ikra, _tužn,
  { {0x6d5c00c3,0x68e323c2,0x272a0013,0x00000000}},	//   _hkra, aend, _mùng_,
  { {0x753a0268,0x272a0013,0xd83800a2,0x00000000}},	//   titz, _lùng_, _meči_,
  { {0x68e30aca,0x628423c3,0x753a00ca,0x00000000}},	//   cend, _agio, uitz,
  { {0x753a23c4,0x6e2d23c5,0x6f0d0051,0x00000000}},	//   ritz, zzab, yjac,
  { {0x753a0199,0x612b0019,0xd6d90051,0x00000000}},	//   sitz, _külg, koły_,
  { {0xf5940032,0x6d450185,0x78a8000f,0x00000000}},	//   _التج, ynha, _kedv,
  { {0x78a8007d,0x272a008b,0x361b0063,0x00000000}},	//   _jedv, _bùng_, _בודד,
  { {0x4ea70079,0x272a001b,0x7467005a,0x00000000}},	//   ираа, _cùng_, _кръв_,
  { {0x272a001b,0x62840290,0xe47b0ee1,0x00000000}},	//   _dùng_, _ggio, _ברוכ,
  { {0x68e302dd,0x8cc20053,0x6f0d1dfa,0x00000000}},	// [3810] yend, _लाखो, rjac,
  { {0x61ed1a61,0x3f8500ea,0x68e3017d,0x00000000}},	//   _isal, ílus_, xend,
  { {0x6d4523c6,0x68e305e5,0x6e2d00ea,0x00000000}},	//   rnha, vend, szab,
  { {0x68e317bc,0xb4790047,0xddd400c2,0x00000000}},	//   wend, אָני, žašk,
  { {0xe9190086,0x3df4000d,0x49cb05ac,0x00000000}},	//   лоді_, _дзяс, туем_,
  { {0x68e323c7,0xf1bf0460,0x98a20ab1,0x00000000}},	//   uend, irá_, пише,
  { {0x60da0019,0xf1bf23c8,0x68e323c9,0x00000000}},	//   õtmi, hrá_, rend,
  { {0x61ed047f,0x7bc5002c,0xf1bf0026,0x00000000}},	//   _osal, muhu, krá_,
  { {0x612b000f,0x673b0006,0x68e31b1c,0x00000000}},	//   _küld, riuj, pend,
  { {0x6aa902b0,0xf1bf23ca,0xa5251743,0x00000000}},	//   _heef, drá_, смод,
  { {0x7bc5002c,0xf1bf0b23,0x76b923cb,0x00000000}},	//   nuhu, erá_, _блер_,
  { {0x98ae0078,0x91e6079f,0x35f902da,0x00000000}},	//   rifą_, боме, _مرتد_,
  { {0xd8380117,0x61ed000f,0x7bc5002c,0x00000000}},	//   _reči_, _csal, huhu,
  { {0x6aa90179,0x7bc50035,0x25b6005d,0x00000000}},	//   _leef, kuhu, _اهود_,
  { {0x394700c7,0x00190088,0xf1bf0297,0x00000000}},	//   inns_, аўты_, ará_,
  { {0x272a001b,0x24160063,0x6d5c23cc,0x00000000}},	//   _vùng_, _לחצן_, _skra,
  { {0x2fdf000c,0x11d70021,0x3f670062,0x00000000}},	// [3820] ăuga_, _هوية_, сито_,
  { {0x6b80005b,0x272a008b,0x25bf1472,0x00000000}},	//   _simg, _tùng_, irul_,
  { {0xb53a00b5,0x25bf0150,0xd83800a8,0x00000000}},	//   נגעש, hrul_, _teči_,
  { {0x7981002b,0x273a0078,0x78a802fd,0x00000000}},	//   _ailw, vūno_, _sedv,
  { {0x3ea023cd,0xdbda0058,0x28c90042,0x00000000}},	//   mbit_, lçüt, _राशि,
  { {0x25bf0492,0xdc3c0066,0xdcfc16fe,0x00000000}},	//   drul_, láča, _kirč,
  { {0x93bc000c,0x25bf000c,0x78a80093,0x00000000}},	//   nzăt, erul_, _vedv,
  { {0x6aa902b0,0x63be0031,0xa3ab0053,0x00000000}},	//   _geef, _åpni, गठन_,
  { {0xe9a30fe2,0x7981001f,0xa91d007d,0x00000000}},	//   _натп, _filw, _mužj,
  { {0xb606007d,0x3f8223ce,0x73d823cf,0x00000000}},	//   vršć, _liku_, адор_,
  { {0x25bf00dd,0x78250044,0x83190044,0x00000000}},	//   arul_, _وعمل, لقدر_,
  { {0xdb1e0024,0x25bf032c,0x61ed23d0,0x00000000}},	//   kupí, brul_, _psal,
  { {0x25bf000c,0xf1bf23d1,0xb7c300dd,0x00000000}},	//   crul_, urá_, ăţen,
  { {0x16770063,0xa2d90042,0xf1bf23d2,0x00000000}},	//   _הגדל_, _फॉर्, rrá_,
  { {0x2ef50f8d,0x3dc0002b,0x7d1523d3,0x00000000}},	//   озвр, eriw_, _rozs,
  { {0x3dc0002b,0xd37100de,0x00000000,0x00000000}},	//   friw_, _تهب_,   ,
  { {0x9f60000f,0x61ed23d4,0xd251007e,0x00000000}},	// [3830] írás_, _usal, _زند_,
  { {0xd131006a,0x30a70817,0x6aa90206,0x00000000}},	//   _آمد_, _урив, _seef,
  { {0x3ea023d5,0xec6b0085,0x7bc50b49,0x00000000}},	//   bbit_, урак_, uuhu,
  { {0x7bc50009,0x798100ac,0xde59000d,0x00000000}},	//   ruhu, _silw, _вамі_,
  { {0xbddb0268,0xdaa80086,0xf3890013,0x00000000}},	//   _exèr, свід_, _nản_,
  { {0x2d9900fe,0x77950001,0x612b00ea,0x00000000}},	//   _itse_, ојиц, _füle,
  { {0x612b0058,0x6344013d,0xd70923d6,0x00000000}},	//   _güle, lőne, инке_,
  { {0xf38900aa,0x25bf000c,0x2d8b007d,0x00000000}},	//   _bản_, trul_, _kuce_,
  { {0xe616093e,0xf389008b,0x2d840003,0x00000000}},	//   жды_, _cản_, _émet_,
  { {0x451900a0,0xc588008b,0x39400139,0x00000000}},	//   рция_, _tồn_, éist_,
  { {0x2d8b0fbc,0xd838007d,0xd4691321,0x00000000}},	//   _luce_, _beču_, рине_,
  { {0x2d990019,0x442b0022,0x25bf00dd,0x00000000}},	//   _otse_, ąc_, prul_,
  { {0x10f60905,0x6d890066,0xfe7f10a1,0x00000000}},	//   оявя, _uľah, _maïs_,
  { {0x2d830117,0x3f820009,0xf9920a7a,0x00000000}},	//   _nije_, _siku_, ורך_,
  { {0x3ea023d7,0xe2080051,0xdc3c0066,0x00000000}},	//   tbit_, wróć_, táča,
  { {0x6d4b0003,0xf3890013,0x1f6602fe,0x00000000}},	//   égan, _hảo_, ікам,
  { {0x3f820026,0x612b1f4a,0xe7e90053,0x00000000}},	// [3840] _viku_, _süle, झौता_,
  { {0x2d8b23d8,0x3ea00075,0x5cc60044,0x00000000}},	//   _duce_, sbit_, تغرق,
  { {0x2d83006d,0x98780066,0x0bb60121,0x00000000}},	//   _dije_, _páči_, ющая,
  { {0x27f80014,0xe28d009a,0x2d9923d9,0x00000000}},	//   _árni_, ְרוֹ, _ftse_,
  { {0x93bc000c,0x2d830331,0xdb0500a5,0x00000000}},	//   nzăr, _fije_, dshä,
  { {0xf3890013,0x89370085,0x00000000,0x00000000}},	//   _nảo_, опіс_,   ,
  { {0xf389001b,0xf72a0076,0x6d4e006f,0x00000000}},	//   _sản_, иций_, _ijba,
  { {0x4b34007e,0xd6d70e82,0xdb050989,0x00000000}},	//   _عکاس, оть_, gshä,
  { {0xf389001b,0x7afd0026,0xfe7f0003,0x00000000}},	//   _bảo_, _ósta, _haïr_,
  { {0x6b9e00d1,0x9987000c,0x61300832,0x00000000}},	//   oppg, şiţi_, _hälf,
  { {0xd7ef0032,0x6344013d,0x4547000d,0x00000000}},	//   _لكل_, zőne, ўчым_,
  { {0x518708d7,0xf3890013,0x9294000d,0x00000000}},	//   жува, _tản_, маюц,
  { {0x69c223da,0xf3890013,0xf1bf009c,0x00000000}},	//   nroe, _uản_, jzát_,
  { {0x2d8b0080,0x98bc0078,0x3eab23db,0x00000000}},	//   _ruce_, rovė_, _sect_,
  { {0x656f0003,0xd0d40062,0x69c223dc,0x00000000}},	//   îche, ьоръ, hroe,
  { {0x634400ea,0x69c223dd,0x2d8300a8,0x00000000}},	//   tőne, kroe, _sije_,
  { {0xa802005b,0xd6d90022,0xdb0500cf,0x00000000}},	// [3850] ğıyl, niła_, nshå,
  { {0x69c223de,0xf3890013,0xa8020058,0x00000000}},	//   droe, _xảo_, şıyl,
  { {0x69c223df,0xfe7f0003,0xd251007e,0x00000000}},	//   eroe, _païs_, _زنگ_,
  { {0xad9b0024,0xf413009f,0x69c2002b,0x00000000}},	//   _prúd, ופע_, froe,
  { {0x69c223e0,0x8cd80053,0x2d990137,0x00000000}},	//   groe, न्हो, _utse_,
  { {0xf1bf00ea,0x5d790047,0xed58000d,0x00000000}},	//   lzás_, _לאָק, _моў_,
  { {0xb8860014,0xdb05051c,0x00000000,0x00000000}},	//   _svíþ, tshä,   ,
  { {0x69c223e1,0xa3bb0053,0x98ab0058,0x00000000}},	//   broe, ेंस_, ılın_,
  { {0xdb050137,0xad9b0066,0xa91d14cb,0x00000000}},	//   rshä, _hrúb, _luži,
  { {0xc588001b,0x799b00a4,0xa91d0061,0x00000000}},	//   _gồm_, _ituw, _ouži,
  { {0xb4650062,0xd8240002,0xa91d0078,0x00000000}},	//   якол, _одѕи, _nuži,
  { {0x91e60095,0xd6d90022,0xcad5009d,0x00000000}},	//   поме, biła_, הוֹת_,
  { {0x61300019,0x6d890024,0x4223005a,0x00000000}},	//   _jälg, _zľav, едяв,
  { {0x867a014e,0x6d4b0003,0x25e00053,0x00000000}},	//   _פרסו, égal, _कहती_,
  { {0xdfd20021,0x645c004b,0xa06a0785,0x00000000}},	//   عير_, ürit, сава_,
  { {0xa91d017f,0x00000000,0x00000000,0x00000000}},	//   _duži,   ,   ,
  { {0x6ead0053,0x6130004b,0xad9b0046,0x00000000}},	// [3860] _ज़रु, _nälg, _arúb,
  { {0x4d630079,0xd7090121,0x2ee9002b,0x00000000}},	//   екув, ́ние_, aeaf_,
  { {0x711b00b5,0x6b9e00c7,0xa7fc005b,0x00000000}},	//   _הויפ, uppg, _ayın,
  { {0x69c223e2,0x3ae8005d,0x6f0623e3,0x00000000}},	//   troe, تبطی_, _unkc,
  { {0x61300137,0xc3330063,0xe8fa0330,0x00000000}},	//   _välf, עוד_, йлд_,
  { {0x612b0004,0x69c223e4,0x672b0014,0x00000000}},	//   _küla, rroe, _algj,
  { {0x61e400a4,0xd6d90051,0x69c223e5,0x00000000}},	//   _lpil, wiła_, sroe,
  { {0x96ea019d,0xf389001b,0x69c20250,0x00000000}},	//   ська_, _cảm_, proe,
  { {0x61e400a4,0x96b70001,0x290f0014,0x00000000}},	//   _npil, чују_, ýjað_,
  { {0x6d5e23e6,0xf8660002,0x63bc23e7,0x00000000}},	//   nopa, _евзо, árno,
  { {0xd6d90051,0x61e423e8,0x256b04aa,0x00000000}},	//   siła_, _apil, møll_,
  { {0xa91d1235,0xd6d90022,0x6d5e23e9,0x00000000}},	//   _ruži, piła_, hopa,
  { {0xa91d23ea,0x637f008f,0x6d5e23eb,0x00000000}},	//   _suži, _jūni, kopa,
  { {0xf67b0063,0x6d5e23ec,0x857a0062,0x00000000}},	//   _האדמ, jopa, _усет_,
  { {0x04db0063,0x2fca00a4,0x68ea00ca,0x00000000}},	//   _הקול, gubg_, iefd,
  { {0x7ae4004b,0x656800a5,0x00000000,0x00000000}},	//   õitl, lldh,   ,
  { {0xbf1d0235,0x788300ea,0x6d5e23ed,0x00000000}},	// [3870] _नवीन_, _kívü, fopa,
  { {0xa91d017f,0x628e001c,0xfc461994,0x00000000}},	//   _tuži, ānoš, čína_,
  { {0xa0220019,0x799b006f,0x7b940054,0x00000000}},	//   ööta, _stuw, ерії,
  { {0x1b19000d,0x201e0066,0xceeb007e,0x00000000}},	//   ўжды_, ätie_, _اردن_,
  { {0xe9ce0062,0xa2c00053,0x4efa0063,0x00000000}},	//   ък_, _वयस्, _והרו,
  { {0x5d85007e,0x61300db3,0x6d5e23ee,0x00000000}},	//   _زلزل, _välg, copa,
  { {0x6e200019,0xe7390b3f,0xdb1e013d,0x00000000}},	//   _ümbr, жей_, supá,
  { {0x656823ef,0x28d20042,0xfbd2009d,0x00000000}},	//   eldh, _साथि, _שתן_,
  { {0x06090086,0x80ce0053,0x273123f0,0x00000000}},	//   інок_, _ताले, _láng_,
  { {0x7aeb00bd,0x05760021,0xa3b90021,0x00000000}},	//   legt, ومية_, ياجر_,
  { {0x69d90e0e,0x61e423f1,0x69cb23f2,0x00000000}},	//   ltwe, _spil, luge,
  { {0x6d5e0035,0x61300019,0x59d10053,0x00000000}},	//   zopa, _mäle, _समार,
  { {0x7bc50199,0x6d5e0009,0x69cb23f3,0x00000000}},	//   hrhu, yopa, nuge,
  { {0x7aeb00e8,0x3860000c,0x27310013,0x00000000}},	//   hegt, şire_, _báng_,
  { {0x61fd0829,0x6d5e23f4,0xd6d90022,0x00000000}},	//   avsl, vopa, niło_,
  { {0xdbc60019,0x2731008b,0x69cb004d,0x00000000}},	//   _köög, _dáng_, kuge,
  { {0x69d9006f,0x7bc523f5,0x6b8e23f6,0x00000000}},	// [3880] jtwe, erhu, _subg,
  { {0x4176007e,0xa06a090f,0x63a10195,0x00000000}},	//   _تابس, _мапа_, opln,
  { {0x69d90625,0x613010b9,0xdbc6004b,0x00000000}},	//   etwe, _väld, _löög,
  { {0x69cb23f7,0x6130004d,0x69d923f8,0x00000000}},	//   fuge, _wäld, ftwe,
  { {0xceb30165,0x6376029c,0x7bc5003b,0x00000000}},	//   _שיש_, mánd, arhu,
  { {0xfbc60086,0xdd870062,0x63760b9b,0x00000000}},	//   _обго, _обяд_, lánd,
  { {0x99920051,0xa91d0078,0x63760331,0x00000000}},	//   ódła_, _nužu, cáng,
  { {0xc588001b,0x6376182a,0x7d1c0513,0x00000000}},	//   _hồi_, nánd, _hors,
  { {0x7d1c23f9,0x69d90051,0xbb430d34,0x00000000}},	//   _kors, ctwe, _ретк,
  { {0x63760331,0x44f40121,0xd6d90022,0x00000000}},	//   hánd, хпос, biło_,
  { {0xd6cf0ae8,0xc5880013,0xd6d90022,0x00000000}},	//   _ит_, _mồi_, ciło_,
  { {0x7d1c03b2,0x3d050053,0x637602fc,0x00000000}},	//   _lors, _होने_, jánd,
  { {0x7d1c04c6,0xa264005a,0x660f00c7,0x00000000}},	//   _oors, върл, äckt,
  { {0x7d1c06a3,0x61fd102d,0x660223fa,0x00000000}},	//   _nors, rvsl, _irok,
  { {0xdfd8005a,0x69cb00bd,0xe5710063,0x00000000}},	//   мът_, zuge, _עַד_,
  { {0x6376006d,0x33180021,0x7bc5004a,0x00000000}},	//   gánd, _يزيد_, vrhu,
  { {0x171b00b5,0x3cf800c2,0x7e2b000d,0x00000000}},	// [3890] קומע, _barv_, ціва_,
  { {0x7d1c23fb,0xc588008b,0x2d87004d,0x00000000}},	//   _cors, _bồi_, öne_,
  { {0xd011006a,0xe3b8005b,0xe1ff006d,0x00000000}},	//   _صلح_, nsı_, lvó_,
  { {0x0f27019d,0x637602dd,0xca75000d,0x00000000}},	//   _цьом, cánd, нулы,
  { {0xdddd0045,0x7aeb135f,0x7d1c23fc,0x00000000}},	//   _wysł, regt, _fors,
  { {0x69cb23fd,0x7aeb00cc,0x63a10114,0x00000000}},	//   ruge, segt, ypln,
  { {0x6d451372,0xdbc6004b,0x637623fe,0x00000000}},	//   miha, _söög, láne,
  { {0x6d45014f,0xf77108aa,0x66021683,0x00000000}},	//   liha, دات_, _brok,
  { {0x2cb1013d,0xf3890013,0x6f1d23ff,0x00000000}},	//   _kezd_, _iải_, _mosc,
  { {0x6d45007a,0xf389001b,0x637602fc,0x00000000}},	//   niha, _hải_, zánd,
  { {0x6b8900ea,0x63760331,0x9346066e,0x00000000}},	//   _kieg, yánd, енне,
  { {0x66021d0d,0xdbc60019,0x6d451aff,0x00000000}},	//   _frok, _töög, hiha,
  { {0x6d452400,0xe5b4000d,0x6b892401,0x00000000}},	//   kiha, _айчы, _mieg,
  { {0x6b892402,0x412a019d,0xe610007e,0x00000000}},	//   _lieg, чого_, _خشم_,
  { {0x637602dd,0x6f1d2403,0x6d4510a5,0x00000000}},	//   tánd, _bosc, diha,
  { {0x3f9e003d,0xc588001b,0x6f1d2404,0x00000000}},	//   ītu_, _rồi_, _cosc,
  { {0x63762405,0x7d1c2406,0x3f9e001c,0x00000000}},	// [38a0] ránd, _pors, ūtu_,
  { {0x98a70006,0x6376006d,0x1016000d,0x00000000}},	//   minė_, sánd, _зьмя,
  { {0x7d1c0995,0x98a70006,0x79880150,0x00000000}},	//   _vors, linė_, _ridw,
  { {0x28d20235,0x7d1c0706,0xb60500c3,0x00000000}},	//   _साहि, _wors, _košč,
  { {0xf38a001b,0x98a70006,0x672900c2,0x00000000}},	//   _cải_, ninė_, dkej,
  { {0xf1b30063,0xf38a008b,0xc5880013,0x00000000}},	//   נסו_, _dải_, _tồi_,
  { {0xfce30086,0x67ce013d,0x6602056c,0x00000000}},	//   _щоро, dőjá, _srok,
  { {0x66022407,0xdb1e004b,0x98a70078,0x00000000}},	//   _prok, uupä, kinė_,
  { {0x98a7005f,0xde7a0054,0x262a0085,0x00000000}},	//   jinė_, орiї_, яцко_,
  { {0x98a70006,0x6561002b,0x273a0078,0x00000000}},	//   dinė_, golh, vūnu_,
  { {0x386100bd,0x290c2408,0x4427000d,0x00000000}},	//   ührt_, _inda_, ецям_,
  { {0x67290066,0x98a70078,0x66022409,0x00000000}},	//   ckej, finė_, _trok,
  { {0x291e014f,0xa5f80001,0x612b00bd,0x00000000}},	//   _kota_, _целу_, _füll,
  { {0x656103d9,0x44250080,0x291e024a,0x00000000}},	//   colh, byl_, _jota_,
  { {0xb4be0235,0x4ea7018e,0xa0220019,0x00000000}},	//   ेली_, ерза, ööpa,
  { {0x98a70006,0x63ba0e04,0x6376240a,0x00000000}},	//   binė_, mstn, táne,
  { {0x6d450357,0x98a70006,0x290c240b,0x00000000}},	// [38b0] tiha, cinė_, _onda_,
  { {0x6376016b,0x6b892224,0x612b0019,0x00000000}},	//   ráne, _sieg, _külm,
  { {0x6b89240c,0x6d45240d,0x6f1d240e,0x00000000}},	//   _pieg, riha, _tosc,
  { {0x6d450c64,0x290c240f,0x61f6001f,0x00000000}},	//   siha, _anda_, _ysyl,
  { {0x6b89001c,0x6d452410,0x291e2411,0x00000000}},	//   _vieg, piha, _bota_,
  { {0x63ba2412,0xf38a0013,0x291e2413,0x00000000}},	//   kstn, _vải_, _cota_,
  { {0x7d540001,0x63ba2414,0x9c65007e,0x00000000}},	//   _сврх, jstn, _شهرو,
  { {0x3d050235,0xf38a001b,0x63ba00b9,0x00000000}},	//   _होते_, _tải_, dstn,
  { {0x63ba034d,0x67290397,0x44252415,0x00000000}},	//   estn, rkej, wyl_,
  { {0x7afb2416,0x3f8b007d,0x67292417,0x00000000}},	//   _haut, _licu_, skej,
  { {0x7afb2418,0x39472419,0x6561013d,0x00000000}},	//   _kaut, mins_, rolh,
  { {0x7afb003d,0x98a700eb,0x656100ea,0x00000000}},	//   _jaut, tinė_, solh,
  { {0x63ba00c3,0x39471db7,0x291e0035,0x00000000}},	//   astn, oins_, _yota_,
  { {0x66060146,0x98a70006,0xb60500c2,0x00000000}},	//   ække, rinė_, _vošč,
  { {0xd0590086,0x98a7091b,0x612b241a,0x00000000}},	//   ерті_, sinė_, _külj,
  { {0xe45600b5,0x394712a9,0x98a70078,0x00000000}},	//   _שיקט_, hins_, pinė_,
  { {0x4d660062,0x3dc91ae7,0x6376013d,0x00000000}},	// [38c0] вкав, graw_, pánb,
  { {0xed570001,0xad9b241b,0x3947241c,0x00000000}},	//   воу_, _trún, jins_,
  { {0x69db241d,0x98bc000c,0x26c200ea,0x00000000}},	//   _aque, hivă_, ókok_,
  { {0x291e241e,0x7afb09ee,0xf1bf0331,0x00000000}},	//   _sota_, _caut, iyán_,
  { {0x7fe20161,0xada60002,0x332001a8,0x00000000}},	//   _पहुँ, _јагл, _moix_,
  { {0x3947241f,0x63ba2420,0x33200003,0x00000000}},	//   gins_, ystn, _loix_,
  { {0x7afb0164,0x9f5801f4,0x291e2421,0x00000000}},	//   _faut, ovrà_, _vota_,
  { {0x7afb00eb,0xb6f400e1,0x26060086,0x00000000}},	//   _gaut, узиј, вчог,
  { {0x291e0268,0xe9d71001,0xc6f70475,0x00000000}},	//   _tota_, _икт_, тных_,
  { {0xb4be0235,0x290c2422,0x7bde007d,0x00000000}},	//   ेले_, _unda_, otpu,
  { {0x3cfa0053,0x7bde2423,0x1cb7009a,0x00000000}},	//   _उसने_, ntpu, כליל_,
  { {0x46a6005a,0x63ba2424,0x637610c9,0x00000000}},	//   _радв, rstn, vánc,
  { {0x63ba04aa,0x3f801ae4,0x7bde21ef,0x00000000}},	//   sstn, dmiu_, htpu,
  { {0x2731013d,0x20040023,0x64a30896,0x00000000}},	//   _tánc_, āmin_, _каља,
  { {0x78b80290,0x33202425,0x55770063,0x00000000}},	//   iavv, _foix_, _שעון_,
  { {0x63760080,0x39470194,0x3ea92426,0x00000000}},	//   ránc, zins_, ubat_,
  { {0x629d00ea,0x27310066,0x7ae208a9,0x00000000}},	// [38d0] mcso, _jána_, dfot,
  { {0x3ea900cd,0x7afb1a85,0x612b005b,0x00000000}},	//   sbat_, _saut, _mülk,
  { {0x637600ea,0x394715f2,0x7afb2427,0x00000000}},	//   lána, vins_, _paut,
  { {0x5a3505fb,0x629d00ea,0xb17b0137,0x00000000}},	//   лнет, ncso, ståd,
  { {0x39472428,0x7afb1ca8,0x333c0063,0x00000000}},	//   tins_, _vaut, ותאמ,
  { {0x39470110,0xe8f802fe,0x9996005d,0x00000000}},	//   uins_, клі_, دپور_,
  { {0x63760139,0x7afb2429,0xf7451122,0x00000000}},	//   hána, _taut, леко,
  { {0x98bc000c,0x3947242a,0x7afb06a5,0x00000000}},	//   tivă_, sins_, _uaut,
  { {0xd4d90088,0x6376000f,0x5a47000d,0x00000000}},	//   ньні_, jána, _рэва,
  { {0x9990000c,0x236900c3,0x6ab900e5,0x00000000}},	//   şaţi_, _akaj_, lawf,
  { {0x6b9502dd,0x98bc000c,0xa34a242b,0x00000000}},	//   _juzg, sivă_, езна_,
  { {0x25790164,0x11d60500,0x63bc00dd,0x00000000}},	//   dèle_, лігр, ârna,
  { {0x33200164,0x93430121,0x63761079,0x00000000}},	//   _voix_, сняе, gána,
  { {0xb6020080,0x2369085a,0x69cb242c,0x00000000}},	//   čátk, _ekaj_, irge,
  { {0x69cb00bd,0xf4840001,0x3d170053,0x00000000}},	//   hrge, _кућн, नाने_,
  { {0xd0070001,0x69c40053,0x6d89242d,0x00000000}},	//   ћете_, _रिली, _džam,
  { {0xc692009f,0x7ae201e1,0xd37b069a,0x00000000}},	// [38e0] מאן_, vfot, _ארקט,
  { {0xc8d20161,0x23b70053,0x6d8900a8,0x00000000}},	//   _साइट, _आबाद, _užal,
  { {0x5aca0071,0xa3bb0053,0x7bde242e,0x00000000}},	//   елем_, ेंट_, utpu,
  { {0x2ca701f7,0xda7a03d1,0x7bde242f,0x00000000}},	//   ında_, нял_, rtpu,
  { {0x82d700b5,0x59f818bf,0xb17b0d7d,0x00000000}},	//   רונג_, теля_, ståe,
  { {0x39990164,0x6d4b0003,0x28df0042,0x00000000}},	//   _dès_, égat, प्लि,
  { {0xe3a7041b,0x78b80290,0x8b950376,0x00000000}},	//   _در_, ravv, _вруч,
  { {0xb8cb0053,0x1706007e,0x48f00042,0x00000000}},	//   _क्_, افظی_, _इसको_,
  { {0x290f0025,0x386c00a3,0xa5340867,0x00000000}},	//   álaí_, _wydr_, инич,
  { {0x59830076,0x637600ea,0x69c00058,0x00000000}},	//   _глуб, vána, _ivme,
  { {0xb8930032,0x2458019d,0xd6c4006a,0x00000000}},	//   _المع, тань_, _نمای,
  { {0x84330086,0x25790003,0x27ec0150,0x00000000}},	//   снює, vèle_, _ipdn_,
  { {0xdc27005b,0x629d013d,0x96b92049,0x00000000}},	//   köğr, rcso, _руху_,
  { {0x629d000f,0x25790164,0x637619ba,0x00000000}},	//   scso, tèle_, rána,
  { {0x629d03e8,0x6376000f,0x612b004d,0x00000000}},	//   pcso, sána, _jüli,
  { {0x63760014,0x61302430,0x23690384,0x00000000}},	//   lánn, _häll, _ukaj_,
  { {0x613001e3,0x612b0019,0x68e3002b,0x00000000}},	// [38f0] _käll, _lüli, yfnd,
  { {0x61ed002c,0x3cff0161,0x627c0063,0x00000000}},	//   _ipal, ईयें_, _אנחנ,
  { {0x69c00031,0x768b005b,0xbc0702dc,0x00000000}},	//   _avme, _köyü, ычай,
  { {0x63760025,0x32092431,0xeeab0054,0x00000000}},	//   hánn, _kray_, _яток_,
  { {0x99d70032,0x69cb2432,0xda650002,0x00000000}},	//   اتصا, urge, јвли,
  { {0x319c0041,0x69cb0244,0xd8251f9d,0x00000000}},	//   עבונ, rrge, идли,
  { {0x47590062,0xd8b8002a,0x5c040085,0x00000000}},	//   крия_, ادها_, _лята,
  { {0x637d0118,0xdb050014,0xd7090121,0x00000000}},	//   nénd, rshó, тние_,
  { {0x8579000a,0x7d1200ea,0x6130004d,0x00000000}},	//   ксот_, _újsá, _bäll,
  { {0x66060026,0x6352008f,0x59670062,0x00000000}},	//   ækka, māni, _съба,
  { {0x61ed028d,0x99840021,0x69c608a9,0x00000000}},	//   _apal, _اللو, _åker,
  { {0x60c50139,0xe28605ef,0xe7870085,0x00000000}},	//   _adhm, илни, _сузо,
  { {0x9980034d,0x85a70001,0x85c80021,0x00000000}},	//   šiť_, _сјед, _مِنْ_,
  { {0x613001e3,0xdb050164,0x763a0047,0x00000000}},	//   _gäll, sphè, _בענג,
  { {0x7ae92433,0xa06a2434,0x6352001c,0x00000000}},	//   _obet, тава_, hāni,
  { {0x6800000f,0x32090b00,0x25bf00dd,0x00000000}},	//   lájá, _fray_, osul_,
  { {0x25bf222d,0x63762435,0x32092436,0x00000000}},	// [3900] nsul_, láno, _gray_,
  { {0x7ae92437,0x127b0047,0x2d8e004d,0x00000000}},	//   _abet, _באפע, öfe_,
  { {0xc5f20053,0xf53600b5,0x75230efd,0x00000000}},	//   _अन्य_, סטער_, _monz,
  { {0x25bf0004,0x7c230072,0x305b0063,0x00000000}},	//   ksul_, änra, _ידיד,
  { {0x6b822438,0x680000ea,0x612b004e,0x00000000}},	//   rmog, kájá, _süli,
  { {0x67220019,0x82770047,0x6b822439,0x00000000}},	//   _sooj, בענע_, smog,
  { {0x637d013d,0x6800013d,0xbad60085,0x00000000}},	//   léne, dájá, _візы,
  { {0x613000c7,0x3ea0165d,0x15d8005e,0x00000000}},	//   _säll, ncit_, гмић_,
  { {0x66e20053,0x99e90049,0xbb3b0041,0x00000000}},	//   क्षक_, _معلق_, _סעמי,
  { {0x612b004b,0x96a60053,0x6800013d,0x00000000}},	//   _tüli, _ट्रॉ, gájá,
  { {0x637d006d,0x6376243a,0x61ed243b,0x00000000}},	//   yénd, ránn, _spal,
  { {0x32090034,0x637d243c,0x61300244,0x00000000}},	//   _pray_, kéne, _wäll,
  { {0x6130024a,0x15a7005a,0x6d400006,0x00000000}},	//   _täll, _къщи_, _įman,
  { {0x3869000c,0xf669007e,0x7523243d,0x00000000}},	//   şare_, _صحنه_, _gonz,
  { {0xdb050003,0x41540002,0xd48f243e,0x00000000}},	//   sphé, цврс, _фр_,
  { {0x3f8f007a,0x61300659,0x3209243f,0x00000000}},	//   ögu_, _jälj, _tray_,
  { {0x442c0185,0x637d19ad,0xe3b8005b,0x00000000}},	// [3910] lyd_, rénd, ayıt_,
  { {0xbc070062,0xeca7007b,0x98b2004c,0x00000000}},	//   ичей, рјан, ěděl_,
  { {0x443e2440,0x656f0003,0x442c002b,0x00000000}},	//   nzt_, îchi, nyd_,
  { {0x637600ea,0x6352001c,0xdcfd008f,0x00000000}},	//   jánl, tāni, _pusē,
  { {0x2cb80031,0x442c001f,0x98a51a5c,0x00000000}},	//   _ferd_, hyd_, биле,
  { {0x63a40240,0x2cb82441,0x3eb92442,0x00000000}},	//   _činn, _gerd_, _hest_,
  { {0x013801f9,0x2d9905b9,0x752301f4,0x00000000}},	//   שרות_, _huse_, _ronz,
  { {0x3eb91112,0x7ae905dd,0x442c001f,0x00000000}},	//   _jest_, _ubet, dyd_,
  { {0xb8820ac6,0xd7060076,0xad9b0025,0x00000000}},	//   _þínu, сные_, _brúi,
  { {0x442c0185,0xd7e7019d,0x25bf000c,0x00000000}},	//   fyd_, _відо, rsul_,
  { {0x3eb90268,0x25bf0089,0x98a70006,0x00000000}},	//   _oest_, ssul_, linį_,
  { {0x63760024,0xe6950021,0x26c200ea,0x00000000}},	//   ráno, _الإد, ókot_,
  { {0x98a70006,0x7f4d006c,0xf556005d,0x00000000}},	//   ninį_, diaq, _گلوب_,
  { {0xa0a306f0,0x62630086,0x753a05e4,0x00000000}},	//   зард, ївра, chtz,
  { {0x251a014e,0x1dda0161,0x3eb91c70,0x00000000}},	//   _תוצא, यूनत, _best_,
  { {0x637d000f,0x98a70006,0x6e930021,0x00000000}},	//   téne, kinį_, كلفا,
  { {0x6130024a,0x2d9101f7,0x0eb9000d,0x00000000}},	// [3920] _jälk, _bize_, русы_,
  { {0x3eb90004,0x98a70006,0x637d00ea,0x00000000}},	//   _eest_, dinį_, réne,
  { {0x4176006a,0x637d000f,0x3eb90e0e,0x00000000}},	//   _پاکس, séne, _fest_,
  { {0x2cb802b0,0x98a70006,0x673b00c2,0x00000000}},	//   _werd_, finį_, jhuj,
  { {0x98a70078,0x660d0078,0xcec4004c,0x00000000}},	//   ginį_, _šakn, atří_,
  { {0x613000c7,0x6f042443,0x3f9a2444,0x00000000}},	//   _sälj, ldic, _kupu_,
  { {0xb9000161,0xa7fc005b,0x6f042445,0x00000000}},	//   _था_, _ayır, odic,
  { {0xcb6a000d,0x6f0403db,0x98a70078,0x00000000}},	//   _сабе_, ndic, binį_,
  { {0x442c0c70,0x61302446,0x612b0779,0x00000000}},	//   wyd_, _välj, _kült,
  { {0x443e0199,0x442c021f,0x69c20757,0x00000000}},	//   tzt_, tyd_, msoe,
  { {0x65680009,0x78ba003d,0x612b005b,0x00000000}},	//   rodh, _ietv, _mült,
  { {0x673b2447,0x443e004d,0x6aa22448,0x00000000}},	//   chuj, rzt_, ncof,
  { {0x69c2021f,0x78ba0006,0x443e1688,0x00000000}},	//   nsoe, _ketv, szt_,
  { {0x3eb90004,0x91790013,0x69c2002b,0x00000000}},	//   _sest_, uần_, isoe,
  { {0xdbf10080,0x4035000a,0x889b00b5,0x00000000}},	//   _příj, цевс, רבלי,
  { {0x69c200e8,0x2d912449,0x78ba244a,0x00000000}},	//   ksoe, _size_, _letv,
  { {0x612b005b,0x7f4d0003,0x3eb9244b,0x00000000}},	// [3930] _bült, riaq, _vest_,
  { {0x78ba010a,0x69c200ac,0x3eb9244c,0x00000000}},	//   _netv, dsoe, _west_,
  { {0x69c200e8,0x2d91244d,0x3eb9244e,0x00000000}},	//   esoe, _vize_, _test_,
  { {0x98a700eb,0x3a75244f,0xa088009a,0x00000000}},	//   tinį_, олер, _לְרִ,
  { {0x7ccb001c,0x4993005d,0xaa5801ce,0x00000000}},	//   tērē, سیار, бицу_,
  { {0x612b00bd,0x98a70006,0x660d0a1c,0x00000000}},	//   _gült, rinį_, _šako,
  { {0xe8090053,0x98a70078,0x98bc004c,0x00000000}},	//   विधा_, sinį_, livě_,
  { {0x69c200e8,0x612b000f,0xdb23086f,0x00000000}},	//   bsoe, _küls, öräl,
  { {0x673b2450,0xe559005e,0x7bd700dd,0x00000000}},	//   rhuj, ијој_, luxu,
  { {0x613000c7,0x6f0402e2,0xa3e90002,0x00000000}},	//   _välk, zdic, адоа_,
  { {0x2634001b,0xc2090063,0xf8b20063,0x00000000}},	//   ào_, _שה_, _חשב_,
  { {0x63ad2451,0x6595212b,0x00000000,0x00000000}},	//   _čand, _даду,   ,
  { {0xbebb00ac,0x4ade0053,0x63762452,0x00000000}},	//   _voël, फ्टव, lánk,
  { {0xb17b00c7,0x25ad2453,0x660900d1,0x00000000}},	//   stån, mpel_, mvek,
  { {0xa2e61fa5,0x61300019,0xc0e30062,0x00000000}},	//   _дойд, _jäli, ьорк,
  { {0x69c2001f,0x9182008b,0x6f042454,0x00000000}},	//   ysoe, iển_, udic,
  { {0xfd4a0abb,0x6f042455,0x66092456,0x00000000}},	// [3940] азак_, rdic, nvek,
  { {0x3f9a05b3,0xbd8301dd,0x3860003b,0x00000000}},	//   _tupu_, дгук, şiri_,
  { {0x637600ea,0x644100bd,0xb53a0047,0x00000000}},	//   vánj, nzli, סגעש,
  { {0xdb1e0026,0x69c2015e,0x6da60044,0x00000000}},	//   vupó, tsoe, _ومجم,
  { {0x394e1db7,0x6aa21ca2,0x6abb002b,0x00000000}},	//   tifs_, rcof, _deuf,
  { {0x69c2021f,0x7981002b,0x660905e7,0x00000000}},	//   rsoe, _chlw, dvek,
  { {0x78ba0066,0x394e1dba,0x17f70021,0x00000000}},	//   _vetv, rifs_, قرية_,
  { {0xf0930063,0x394e0003,0x69c20104,0x00000000}},	//   ונו_, sifs_, psoe,
  { {0x27310013,0x9989085a,0xdb050244,0x00000000}},	//   _mánh_, šaš_, tshö,
  { {0x27310013,0x7c470014,0x2bd10053,0x00000000}},	//   _lánh_, _úrræ, _हिमा,
  { {0x66e62457,0x29ff0051,0xa91d0078,0x00000000}},	//   _можа, ałać_, _nužy,
  { {0x53340121,0xad9b0066,0x6b9c2458,0x00000000}},	//   деют, _krút, _murg,
  { {0x644102e2,0xe4da007e,0xf2040085,0x00000000}},	//   azli, _نوشت_, мяро,
  { {0x72280054,0x3cf60042,0xe8ee045b,0x00000000}},	//   іцяв_, ीयों_, елi_,
  { {0x2f190076,0x6b9c0019,0x2731008b,0x00000000}},	//   бовь_, _nurg, _bánh_,
  { {0x27312459,0x2fcd007d,0x3dd2002b,0x00000000}},	//   _cánh_, čeg_, fryw_,
  { {0x3dd2001f,0xdddd001c,0xd25101fb,0x00000000}},	// [3950] gryw_, _izsū, _سند_,
  { {0xdfdb011c,0x9182001b,0x63a4017f,0x00000000}},	//   _към_, yển_, _činj,
  { {0x612b00ea,0x70fa0063,0xdc980086,0x00000000}},	//   _fülr, _ההתח, івці_,
  { {0xad9b245a,0x27310013,0x98bc004c,0x00000000}},	//   _csúc, _gánh_, pivě_,
  { {0x6d58007d,0x7e7d008f,0xe9d80500,0x00000000}},	//   čvar, _uzsp, жкі_,
  { {0x68f80019,0x6b9c245b,0x3f89245c,0x00000000}},	//   gevd, _furg, lmau_,
  { {0x6abb00bd,0x6b9c245d,0x2d830072,0x00000000}},	//   _teuf, _gurg, _ihje_,
  { {0x6130037e,0xdcfd0006,0x6376027d,0x00000000}},	//   _väli, _pusė, ránk,
  { {0x7bc5094d,0xad9b0046,0xe61605ac,0x00000000}},	//   lshu, _trúu, зды_,
  { {0x64410199,0x6376245e,0xa4450076,0x00000000}},	//   tzli, pánk, знод,
  { {0x29ff0051,0xd4690001,0x61fd245f,0x00000000}},	//   słać_, сине_, ewsl,
  { {0x25ad2187,0x64410d25,0x660900d1,0x00000000}},	//   ppel_, rzli, pvek,
  { {0x2d8300fe,0x29050214,0x69d90229,0x00000000}},	//   _ohje_, _kala_, nuwe,
  { {0x2731008b,0x29fd0066,0x29072460,0x00000000}},	//   _sánh_, _mňa_, ndna_,
  { {0xb4d70235,0x69d9006f,0x29052461,0x00000000}},	//   िली_, huwe, _mala_,
  { {0x69d90009,0x6e960021,0x7bc52462,0x00000000}},	//   kuwe, سلطا, dshu,
  { {0xf7720063,0x733b0041,0x6b9c2463,0x00000000}},	// [3960] תקן_, _לעקס, _surg,
  { {0x6b9c2464,0xa91c0024,0x69d9006f,0x00000000}},	//   _purg, _ohľa, duwe,
  { {0x69d90122,0x309b0063,0x7bc50acd,0x00000000}},	//   euwe, _לשימ, gshu,
  { {0x23a10051,0x6b9c005b,0x63bc003b,0x00000000}},	//   _mój_, _vurg, ârni,
  { {0x63762465,0xcb67000d,0x29052466,0x00000000}},	//   gáni, чаце_, _bala_,
  { {0x29fd0024,0x6f060089,0x69cd0053,0x00000000}},	//   _dňa_, _hakc, _सिरी,
  { {0x6d4e0bbf,0x68f80058,0x69d92467,0x00000000}},	//   _imba, revd, auwe,
  { {0xa6140f92,0xf0930063,0x29050139,0x00000000}},	//   дмич, ענה_, _eala_,
  { {0x6376006d,0xb0dc0053,0x29052468,0x00000000}},	//   cáni, _बांग, _fala_,
  { {0x9a3b0063,0x637d0066,0x2a3b0063,0x00000000}},	//   _התמק, génn, _העממ,
  { {0x3f89001f,0xa4382049,0xd6cf2469,0x00000000}},	//   ymau_, ізму_, _пт_,
  { {0xf743047e,0x6130004b,0x7d0b008f,0x00000000}},	//   _пехо, _mälu, ēgsi,
  { {0xdb050025,0x6d4e246a,0x29050a4a,0x00000000}},	//   nphá, _omba, _yala_,
  { {0xf617014e,0xa91c0066,0x66021229,0x00000000}},	//   _מחדש_, _yhľa, _isok,
  { {0x69d900bd,0x610f0078,0x85030044,0x00000000}},	//   zuwe, vėlė, _سوين,
  { {0x6d4e10ca,0x290700c2,0x637d246b,0x00000000}},	//   _amba, zdna_, méno,
  { {0x3f890185,0xa3d40053,0x637d246c,0x00000000}},	// [3970] rmau_, िंक_, léno,
  { {0x7bc5246d,0x63760195,0x2bd10042,0x00000000}},	//   tshu, váni, _हिदा,
  { {0x629a0080,0xad9b03ea,0xd251007e,0x00000000}},	//   ětov, _prús, _سنگ_,
  { {0x69d90009,0x6d4e0f15,0x6376246e,0x00000000}},	//   tuwe, _emba, táni,
  { {0x637d0003,0x61300137,0x7bc504aa,0x00000000}},	//   héno, _välv, sshu,
  { {0x6376246f,0x2ca5004b,0xd9980cac,0x00000000}},	//   ráni, _üld_, سخها_,
  { {0x69d900a4,0x29052470,0x63760331,0x00000000}},	//   suwe, _vala_, sáni,
  { {0x05a9019d,0x2905053a,0xeab30021,0x00000000}},	//   овий_, _wala_, _سعر_,
  { {0x29052471,0x05b9006a,0x6130004d,0x00000000}},	//   _tala_, زگشت_, _kält,
  { {0xb4d70235,0x53c90e34,0xb9c40044,0x00000000}},	//   िले_, огом_, _أقلي,
  { {0xa3d40161,0x66020089,0x7d072472,0x00000000}},	//   िंग_, _esok, _majs,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xe56e011c,0x127a0021,0xd6d90022,0x00000000}},	//   _аз_, تحدث_, chła_,
  { {0x659400d7,0xe3b90131,0x7d072473,0x00000000}},	//   _зачу, _дбк_, _najs,
  { {0xdff5015a,0xd0070184,0x91030062,0x00000000}},	//   нять, мере_, ъпре,
  { {0x26df0035,0x672b0150,0xf1bf013d,0x00000000}},	//   nguo_, _jogj, gyás_,
  { {0x63a4081a,0x61300137,0x9e66007e,0x00000000}},	// [3980] _čini, _bält, ذارن,
  { {0x1e83000d,0xb6060014,0x6e2b00a5,0x00000000}},	//   тлум, lráð, ägba,
  { {0x711b0047,0x672b00ca,0xdb1e0014,0x00000000}},	//   _וויפ, _oogj, sspí,
  { {0x3cfa0053,0x61300137,0xdbc70014,0x00000000}},	//   _उसके_, _välu, _vöðv,
  { {0x613000c7,0x6368005b,0xd9462474,0x00000000}},	//   _fält, mınd, меди,
  { {0x636801f7,0x6d4e2475,0x3ace0013,0x00000000}},	//   lınd, _umba, ộp_,
  { {0x613000c7,0xb6060026,0x31570047,0x00000000}},	//   _häls, kráð, ויסן_,
  { {0x85a6000a,0x636801f7,0x2d98096c,0x00000000}},	//   мјод, nınd, _hire_,
  { {0x98a6093d,0xd3790130,0x89d70044,0x00000000}},	//   _жизе, nuće_, _يوفر_,
  { {0x6d5e04aa,0x63680075,0x2d4f056c,0x00000000}},	//   nnpa, hınd, yżem_,
  { {0x672b000f,0x6368005b,0x99800006,0x00000000}},	//   _fogj, kınd, šių_,
  { {0x660200a4,0x2d982476,0xd5ba0854,0x00000000}},	//   _tsok, _lire_, _дск_,
  { {0xd379017f,0x636801f7,0x63760026,0x00000000}},	//   juće_, dınd, jánu,
  { {0xd379017f,0xa507005e,0xe44f007e,0x00000000}},	//   duće_, _жеља_, اضی_,
  { {0x636801f7,0xa3cb0053,0xf1940086,0x00000000}},	//   fınd, _लिए_, тирь,
  { {0x2f180086,0x2d982477,0x26c42478,0x00000000}},	//   мось_, _aire_, namo_,
  { {0xd3790117,0x26c40290,0x9d150002,0x00000000}},	// [3990] guće_, iamo_, ндач,
  { {0x6d5e00d1,0x2d980003,0x26c42479,0x00000000}},	//   gnpa, _cire_, hamo_,
  { {0x2d98247a,0x8af9247b,0x6130065c,0x00000000}},	//   _dire_, знес_, _vält,
  { {0xf38a001b,0x6d5e006f,0x6130004d,0x00000000}},	//   _bảy_, anpa, _fäls,
  { {0xad9b0027,0x28e0016a,0x613000fe,0x00000000}},	//   _grúp, _नाशि, _tält,
  { {0x6376247c,0xdb1c0137,0x3ea9003b,0x00000000}},	//   lánt, _avrä, lcat_,
  { {0x2d4f0051,0xe739247d,0x97c404a0,0x00000000}},	//   yżej_, зей_, نتيم,
  { {0x26c400c3,0x3ea9247e,0x66050121,0x00000000}},	//   gamo_, ncat_, епиа,
  { {0x29d508aa,0x317100ea,0x3f99007d,0x00000000}},	//   _سياس, kozz_, _misu_,
  { {0x6368005b,0x1425247f,0x891701fb,0x00000000}},	//   zınd, едом, _تبرئ,
  { {0x6368005b,0x26c4007d,0x973c007d,0x00000000}},	//   yınd, bamo_, _suće,
  { {0x3f990117,0x794d0051,0x26c42480,0x00000000}},	//   _nisu_, dźwi, camo_,
  { {0xdb05007a,0xf38a008b,0xb6060014,0x00000000}},	//   pphæ, _xảy_, rráð,
  { {0x25d600b5,0x6e200268,0x06560063,0x00000000}},	//   _נוצן_, _àmbi, _אינך_,
  { {0x636801f7,0x2d980164,0xe4650019,0x00000000}},	//   tınd, _rire_, ööde_,
  { {0x61300137,0x2d982481,0x645c01a8,0x00000000}},	//   _päls, _sire_, úrie,
  { {0x636801f7,0x36190063,0x2d980003,0x00000000}},	// [39a0] rınd, הוּד, _pire_,
  { {0x636801f7,0x61300137,0x26c42482,0x00000000}},	//   sınd, _väls, zamo_,
  { {0xf53600b7,0x6368005b,0xeb9a0ac5,0x00000000}},	//   עטער_, pınd, чие_,
  { {0x205700b5,0x2d9800f6,0x2bd10053,0x00000000}},	//   _טייל_, _wire_, _हिरा,
  { {0x26c42483,0xd3570063,0x2d982484,0x00000000}},	//   vamo_, עיני_, _tire_,
  { {0xdbc7004b,0x67d40200,0x49370083,0x00000000}},	//   _rööv, воку, нзію_,
  { {0x9182008b,0x26c42485,0x777b2486,0x00000000}},	//   iền_, tamo_, flux,
  { {0xdb0e00c7,0x7bde07fd,0x59c90042,0x00000000}},	//   _avbö, mupu, _रिचर,
  { {0x26c42487,0xcb670121,0x7bde2488,0x00000000}},	//   ramo_, _чате_, lupu,
  { {0x61fb0016,0xa3cb0053,0x26c42489,0x00000000}},	//   çulm, _लिख_, samo_,
  { {0x6284051e,0x799a0035,0x7bde248a,0x00000000}},	//   _azio, _iitw, nupu,
  { {0xdbc70019,0xe5a6005e,0x22590121,0x00000000}},	//   _tööv, _зиди, димы_,
  { {0x7bde00e3,0x799a0035,0x75d300f2,0x00000000}},	//   hupu, _kitw, _مينا,
  { {0xa4d4019d,0x3f990019,0x7bde248b,0x00000000}},	//   _рокі, _sisu_, kupu,
  { {0x62840290,0xdb1e00b9,0x8f87005e,0x00000000}},	//   _ezio, mspæ, ећал,
  { {0x6376006d,0x799a0051,0xf7850058,0x00000000}},	//   uánt, _litw, _üçte_,
  { {0x3f99003d,0x3ea91ea8,0x5d99000d,0x00000000}},	// [39b0] _visu_, rcat_, дкаў_,
  { {0xceeb006a,0x6376248c,0xbd780086,0x00000000}},	//   _کردن_, sánt, ебує_,
  { {0x3f9900e3,0x752800ca,0x9c190044,0x00000000}},	//   _tisu_, ijdz, بياء_,
  { {0x7ae208f0,0x64480078,0x54570047,0x00000000}},	//   ggot, izdi, עסאן_,
  { {0x799a0051,0xd7f8000c,0x7bde248d,0x00000000}},	//   _bitw, _apă_, aupu,
  { {0x7ae200c3,0x61300137,0xdb1e00b9,0x00000000}},	//   agot, _jälp, jspæ,
  { {0x6f0d007d,0x799a00b9,0x63680058,0x00000000}},	//   odac, _ditw, nınc,
  { {0x9182008b,0x6448008f,0x6f0d248e,0x00000000}},	//   iến_, dzdi, ndac,
  { {0xd7060076,0x3b64005a,0x9182001b,0x00000000}},	//   тные_, _сърв, yền_,
  { {0xdb0500bd,0xb8860080,0x4a540002,0x00000000}},	//   sphä, _stíž, _скус,
  { {0x1422000d,0x6f1d0d1e,0xdb05248f,0x00000000}},	//   адэм, _onsc, pphä,
  { {0x62840290,0x637600ea,0x69d92490,0x00000000}},	//   _pzio, váns, orwe,
  { {0x6f0d001f,0x69cb2491,0xdea2005d,0x00000000}},	//   ddac, nsge, ییدی,
  { {0x6f1d0199,0xa6840086,0x6729085a,0x00000000}},	//   _ansc, _слід, ljej,
  { {0x7f440164,0x6f0d006f,0x69d9004d,0x00000000}},	//   thiq, fdac, hrwe,
  { {0x672900e3,0xd36f0032,0x973c007d,0x00000000}},	//   njej, _وهو_, _kuća,
  { {0x63a32492,0x76490058,0x69cb00ca,0x00000000}},	// [39c0] _hunn, nzey, jsge,
  { {0xc50c0047,0x6f1d2493,0x63a32494,0x00000000}},	//   ּלאָ, _ensc, _kunn,
  { {0x40d900b7,0x7f4403b2,0x673b0ff2,0x00000000}},	//   _אַרײ, phiq, kkuj,
  { {0x6b8903d9,0x63a31c75,0x799a002c,0x00000000}},	//   _cheg, _munn, _sitw,
  { {0x7bde2495,0x7ae21237,0x6b9b0089,0x00000000}},	//   supu, rgot, _diug,
  { {0x7bde2496,0x6d4500bd,0x49730651,0x00000000}},	//   pupu, chha, аліс,
  { {0x69cb00e8,0x8b960002,0xd6d90022,0x00000000}},	//   asge, _арач, liły_,
  { {0x6b9b051e,0xbebb00ac,0x60c7007d,0x00000000}},	//   _giug, _hoër, zajm,
  { {0xe9a6011c,0xd379017f,0xd6d90022,0x00000000}},	//   _разп, juća_, niły_,
  { {0x636801f7,0x9182001b,0x799a0179,0x00000000}},	//   yınc, yến_, _uitw,
  { {0x27380014,0x44270054,0x291e086f,0x00000000}},	//   _léni_, вцям_, _inta_,
  { {0xfd61001b,0x5453005a,0x63a32497,0x00000000}},	//   _quyế, рвют, _dunn,
  { {0x290c2498,0xa5f80001,0xd379007d,0x00000000}},	//   _kada_, _челу_, guća_,
  { {0x63a32499,0xe466004b,0x63680058,0x00000000}},	//   _funn, ööst_, tınc,
  { {0x4ea70079,0xfd61001b,0x290e001f,0x00000000}},	//   врза, _tuyế, idfa_,
  { {0x290c249a,0x6368005b,0xe3af007e,0x00000000}},	//   _lada_, rınc, _برو_,
  { {0x6f0d018d,0xc299019d,0x5f940086,0x00000000}},	// [39d0] rdac, _яких_, ритт,
  { {0xbebb00ac,0x290c249b,0x6b8904aa,0x00000000}},	//   _poës, _nada_, _sheg,
  { {0x290e001f,0x63680058,0x673b0022,0x00000000}},	//   ddfa_, lına, ykuj,
  { {0x6f1d20df,0x41c4007e,0x69cb249c,0x00000000}},	//   _unsc, _حقیق, tsge,
  { {0x69cb00bd,0x637d249d,0x69d90657,0x00000000}},	//   usge, géni, urwe,
  { {0x69cb249e,0x290c249f,0xbfc4004c,0x00000000}},	//   rsge, _cada_, řížs,
  { {0xd0f8014e,0x6d55005b,0x69cb004d,0x00000000}},	//   דמות_, _imza, ssge,
  { {0x63a324a0,0x69cb23e1,0x8834000d,0x00000000}},	//   _runn, psge, рэшц,
  { {0x63a324a1,0x290c0025,0x99d90021,0x00000000}},	//   _sunn, _fada_, _سواء_,
  { {0x290c003d,0x60c500bd,0x91820013,0x00000000}},	//   _gada_, _nehm, iễn_,
  { {0xf8b20063,0xd6d90022,0x6566013d,0x00000000}},	//   _השב_, ziły_, ékha,
  { {0x63a302f0,0x3f47004b,0x07090044,0x00000000}},	//   _vunn, _jõud_, _سيتي_,
  { {0x973c007d,0x290c005b,0x20d60086,0x00000000}},	//   _kućn, _yada_, лівс,
  { {0x7544000d,0x06e30053,0x63a324a2,0x00000000}},	//   _кніз, _गाँव_, _tunn,
  { {0xd379017f,0xd6d90051,0xdb1e0137,0x00000000}},	//   suća_, wiły_, lspå,
  { {0x2eb500e1,0x7ae900dd,0xd6d2009d,0x00000000}},	//   исус, _ncet, ֶׂב_,
  { {0x03210042,0xb17b00a5,0x4d660085,0x00000000}},	// [39e0] यारह_, ttåt, гкав,
  { {0x365a0047,0x3d28007e,0x64640078,0x00000000}},	//   ײכענ, ختری_, štiš,
  { {0xdd8f0032,0x9f5e00ea,0xe4a80063,0x00000000}},	//   أول_, ító_, דֹנָ,
  { {0xbae50086,0xb17b02f0,0x290c24a3,0x00000000}},	//   ицій, ståt, _sada_,
  { {0x290c014f,0x8f9b0041,0xda770062,0x00000000}},	//   _pada_, _ריכי, ляш_,
  { {0x3f800268,0x637d24a4,0xd90d007e,0x00000000}},	//   lliu_, réni, ویق_,
  { {0x290c24a5,0x8c4624a6,0x1826005d,0x00000000}},	//   _vada_, _севе, اقعی_,
  { {0x8c1b0063,0xa8170049,0xdb1e0072,0x00000000}},	//   _אולי, اتور_, uspä,
  { {0xe4c6093e,0x290c24a7,0xdb1e051c,0x00000000}},	//   лённ, _tada_, rspä,
  { {0xa976018e,0x291e24a8,0x35f7007e,0x00000000}},	//   _субј, _unta_, اريد_,
  { {0xb9930032,0x49170063,0x3f800006,0x00000000}},	//   _اللب, _תקבל_, kliu_,
  { {0x41e701dd,0xdc3b0047,0x63680058,0x00000000}},	//   ліга, געטר, tına,
  { {0x60c501a9,0x7ae60014,0x3f800078,0x00000000}},	//   _pehm, _öktu, dliu_,
  { {0x973c007d,0x63680058,0xe9ce0085,0x00000000}},	//   _kućo, rına, цкi_,
  { {0xdfd8005a,0x68f50058,0x63c6011b,0x00000000}},	//   лът_, _özde, ásně,
  { {0x1fb40121,0x63680058,0xbdd51406,0x00000000}},	//   ссёр, pına, иобщ,
  { {0x3f470019,0x7d550a74,0xc0cb005e,0x00000000}},	// [39f0] _nõue_, авах, _пуне_,
  { {0x7ae90290,0x3f800078,0x9c4709c8,0x00000000}},	//   _scet, aliu_, лхел,
  { {0x3f800268,0x2d4f0045,0x7e7d0051,0x00000000}},	//   bliu_, dżet_, _wysp,
  { {0xb17b00c7,0xcf270044,0xeafb0044,0x00000000}},	//   fråg, _إردي, عرضت_,
  { {0x3f680058,0x645e005f,0x4aa80085,0x00000000}},	//   oğun_, _žpil, укін_,
  { {0x26c9017f,0x19b80044,0x4dda009a,0x00000000}},	//   _žao_, اطنة_, _בחשו,
  { {0xb17b24a9,0x681c003b,0xab950054,0x00000000}},	//   mråd, _nădă, _виві,
  { {0xdb1e00c7,0xdb0700b9,0xb17b0203,0x00000000}},	//   tspå, _stjæ, lråd,
  { {0x6f0f24aa,0xf505005a,0x75450081,0x00000000}},	//   _macc, азпо, иниз,
  { {0x5a340d62,0x6f0f24ab,0x3940006f,0x00000000}},	//   _унут, _lacc, ëist_,
  { {0xdb1e00c7,0xd4690184,0xc8670062,0x00000000}},	//   sspå, тине_, _стаи,
  { {0x17f80021,0xdb1e01e1,0xf2df00a3,0x00000000}},	//   _حركة_, pspå, shân_,
  { {0xf77001a7,0xe3b80075,0x6d8924ac,0x00000000}},	//   _عام_, apı_, _džaz,
  { {0xa06a24ad,0xd379007d,0x16640054,0x00000000}},	//   вага_, vrće_, _увім,
  { {0xd4790047,0x6f0f24ae,0x9fc706b4,0x00000000}},	//   _באַל, _bacc, игра_,
  { {0x6f0f051e,0x24a70006,0xdfa50021,0x00000000}},	//   _cacc, šumą_, صحفي,
  { {0x6f0f01f4,0x3da70121,0x637d006c,0x00000000}},	// [3a00] _dacc, икто_, génu,
  { {0x8cb606be,0x3f80005f,0x621b009d,0x00000000}},	//   рсач, sliu_, _יופק,
  { {0x6f0f06e2,0x3f8000cd,0x2a7f24af,0x00000000}},	//   _facc, pliu_, _ayub_,
  { {0x394524b0,0x501b009f,0x7c85005e,0x00000000}},	//   _alls_, _סוכו, суђе,
  { {0xbe67000d,0x637d0331,0x7d0e24b1,0x00000000}},	//   _ваяж_, mént, _tabs,
  { {0x6f040199,0x6f0f24b2,0xb9530054,0x00000000}},	//   leic, _zacc, овіщ,
  { {0xe7580086,0xb8070021,0x25a601f4,0x00000000}},	//   ликі_, ليوم_, _suol_,
  { {0x39450268,0x681c000c,0x98a50022,0x00000000}},	//   _ells_, _rădă, _rolą_,
  { {0x48e61804,0x6b8206f1,0x758a16b4,0x00000000}},	//   _возв, mlog, ксов_,
  { {0x25a60290,0x6f0409fd,0x2369007d,0x00000000}},	//   _vuol_, heic, _sjaj_,
  { {0x04580021,0x637d00ea,0xd6c4007e,0x00000000}},	//   الجة_, ként, _همای,
  { {0x27fe0150,0x6b8224b3,0xe73a0121,0x00000000}},	//   _iptn_, nlog, _шее_,
  { {0x6f0f24b4,0x64450004,0xdb0900bd,0x00000000}},	//   _racc, _ühin, _ließ,
  { {0xd5fb0063,0x6f0f24b5,0x31780022,0x00000000}},	//   _ספור, _sacc, gorz_,
  { {0x6f0f051e,0x6f040025,0x6b8224b6,0x00000000}},	//   _pacc, feic, klog,
  { {0xddc40051,0x637d0003,0x63ba24b7,0x00000000}},	//   dził, ténu, mptn,
  { {0x6b8201a6,0x2d4f0051,0x7bde24b8,0x00000000}},	// [3a10] dlog, dżer_, erpu,
  { {0x6b82008f,0xed070092,0x637d009c,0x00000000}},	//   elog, јџан, rénu,
  { {0x6f0f24b9,0x6368005b,0x6b820333,0x00000000}},	//   _tacc, kınl, flog,
  { {0x637d24ba,0x6f0f24bb,0x6b8224bc,0x00000000}},	//   cént, _uacc, glog,
  { {0x6368005b,0xde640062,0x27380014,0x00000000}},	//   dınl, _дърп, _léns_,
  { {0xdb0700c7,0x09480002,0xaa68005d,0x00000000}},	//   _stjä, ичји_, جمهٔ_,
  { {0xdb09004d,0x6d4724bd,0x6b8224be,0x00000000}},	//   _gieß, _ilja, blog,
  { {0x6b820268,0x2ee924bf,0x63680058,0x00000000}},	//   clog, ngaf_, gınl,
  { {0xe57905fb,0x0f58009a,0xd61900de,0x00000000}},	//   лзи_, ייהם_, اتبا_,
  { {0x6f040199,0x39450268,0x27380268,0x00000000}},	//   zeic, _ulls_, _béns_,
  { {0xc209009a,0xe611005d,0x00000000,0x00000000}},	//   _רה_, زشک_,   ,
  { {0xdb070137,0x8704030b,0x672224c0,0x00000000}},	//   _utjä, _мяче, _gnoj,
  { {0xd7740032,0x6f0424c1,0x6d4724c2,0x00000000}},	//   _بالع, veic, _olja,
  { {0x6f0400bd,0x6b8201b3,0x98ac001c,0x00000000}},	//   weic, zlog, _kodā_,
  { {0x637d03ad,0x6f04003d,0x7afb0384,0x00000000}},	//   tént, teic, _obut,
  { {0x27ea0146,0x03d60063,0x6d470392,0x00000000}},	//   _åbne_, _הוקם_, _alja,
  { {0x6f040199,0x637d006d,0x6368005b,0x00000000}},	// [3a20] reic, rént, nınm,
  { {0xdb1e05b9,0x7afb24c3,0x5bc60021,0x00000000}},	//   lspø, _abut, متصف,
  { {0x636801f7,0x61e6005b,0x6f0400bd,0x00000000}},	//   yınl, lukl, peic,
  { {0xf093014e,0x66090983,0xcaca005e,0x00000000}},	//   _מנת_, kwek, угде_,
  { {0xceb300b5,0xb3470016,0x6b8224c4,0x00000000}},	//   _מיר_, luçõ, rlog,
  { {0xa7b8000a,0x6b82128d,0xe918045b,0x00000000}},	//   алку_, slog, рокі_,
  { {0x6c36006a,0x395c00c7,0x6d5e24c5,0x00000000}},	//   _افزا, rivs_, mipa,
  { {0x6d5e24c6,0xcc3b0047,0xa3e60053,0x00000000}},	//   lipa, _געלט, यंस_,
  { {0x3f47004b,0xdb1e00d1,0x7c3e24c7,0x00000000}},	//   _jõua_, dspø, lypr,
  { {0x03f80001,0xdb2300ea,0x61e624c8,0x00000000}},	//   аној_, öröl, dukl,
  { {0x6445004b,0xd49a0121,0xdd7b0aeb,0x00000000}},	//   _ühil, ыри_, רטיל,
  { {0xdc9b00b5,0xb347017d,0x6d5e24c9,0x00000000}},	//   טייל, duçõ, hipa,
  { {0x6d5e24ca,0x613000fe,0x66e3000d,0x00000000}},	//   kipa, _häly, _хоча,
  { {0x067b00b5,0xe3af006a,0x6d5e058c,0x00000000}},	//   _ענגל, بری_, jipa,
  { {0x2099000d,0x6d5e24cb,0xd48f24cc,0x00000000}},	//   рквы_, dipa, _хр_,
  { {0x7eb9005a,0x3ceb0053,0x9f560014,0x00000000}},	//   ргас_, _चाहे_, ægði_,
  { {0x171b00b5,0x61e6005b,0x6d47007d,0x00000000}},	// [3a30] נומע, cukl, _plja,
  { {0x657a24cd,0x2dd4000d,0xddc40022,0x00000000}},	//   noth, яжур, dziń,
  { {0xfbd0006a,0x65680146,0xb347017d,0x00000000}},	//   فتن_, indh, cuçõ,
  { {0x6d5e002c,0x20010150,0x7d05004d,0x00000000}},	//   aipa, _iphi_, sehs,
  { {0x443e00fe,0x6d5e0019,0xf2d40047,0x00000000}},	//   hyt_, bipa, פעס_,
  { {0x7ff4006a,0xa7b5005e,0x27150013,0x00000000}},	//   _بسیا, осиј, _ền_,
  { {0xe7d50054,0x61e6092a,0x69c400dd,0x00000000}},	//   цілю, zukl, âier,
  { {0xe739101a,0x443e24ce,0x656821ef,0x00000000}},	//   реи_, dyt_, endh,
  { {0x05a60076,0x63aa00bd,0xdb1c0026,0x00000000}},	//   овый_, _aufn, _evró,
  { {0x61e624cf,0x6609006f,0x05760021,0x00000000}},	//   vukl, rwek, يمية_,
  { {0xf6d50086,0x290724d0,0xe29f0026,0x00000000}},	//   _діля, mena_, veða_,
  { {0xf770043b,0x6d5e24d1,0x98a50051,0x00000000}},	//   _كان_, zipa, _rolę_,
  { {0x6d4b001c,0xdb1e06a5,0x2b7a0047,0x00000000}},	//   īgaj, rspø, שטרײ,
  { {0x61e6048a,0x8fa61001,0xdb1e069f,0x00000000}},	//   rukl, жаве, sspø,
  { {0x61e60228,0xa0a30d34,0x776924d2,0x00000000}},	//   sukl, дард, onex,
  { {0xb3470016,0x7769155d,0x41aa0699,0x00000000}},	//   ruçõ, nnex, _квин_,
  { {0x9f4b0026,0x290724d3,0x98a50022,0x00000000}},	// [3a40] ðmát_, kena_, _wolę_,
  { {0x6d5e0035,0xf1b901c2,0x2907208b,0x00000000}},	//   uipa, íše_, jena_,
  { {0x6d5e0228,0x63a424d4,0xf81e0051,0x00000000}},	//   ripa, _kiin, ążkę_,
  { {0x6d5e24d5,0x31af005b,0x80ba0053,0x00000000}},	//   sipa, _yüz_, ्रवे,
  { {0xdb0024d6,0x63a4021e,0xad9b013d,0x00000000}},	//   _jimé, _miin, _csús,
  { {0x63a4112c,0x290706d5,0x69db0053,0x00000000}},	//   _liin, gena_, _निरी,
  { {0x98be0529,0x6d5c24d7,0x98a3005e,0x00000000}},	//   _altă_, _imra, миље,
  { {0x44200512,0x973c007d,0xcb6a000d,0x00000000}},	//   _či_, _kući, _табе_,
  { {0x29071e45,0xcf930063,0x657a24d8,0x00000000}},	//   bena_, וטה_, toth,
  { {0x443e024a,0xb6030024,0x63a400a4,0x00000000}},	//   tyt_, úšaj, _aiin,
  { {0xd6cf24d9,0xad1b00b5,0xdb000003,0x00000000}},	//   _от_, בויר, _aimé,
  { {0x63b5027d,0x657a24da,0xea000013,0x00000000}},	//   ízna, soth, huật_,
  { {0x63a4053b,0x443e0072,0xdb9b009f,0x00000000}},	//   _diin, syt_, יסטר,
  { {0x443e24db,0xa50705ce,0x6f160022,0x00000000}},	//   pyt_, _меча_, edyc,
  { {0x63a40529,0x403524dc,0xb4d60053,0x00000000}},	//   _fiin, чевс, िणी_,
  { {0xa3b7007e,0x290724dd,0xd379007d,0x00000000}},	//   _باور_, zena_, kući_,
  { {0xd3790117,0x32540062,0xdb0018fb,0x00000000}},	// [3a50] jući_, _овър, _gimé,
  { {0xd379017f,0x6ac30053,0x4155085e,0x00000000}},	//   dući_, शर्र, _хвос,
  { {0x7640001f,0x290724de,0xdab90085,0x00000000}},	//   hymy, vena_, былі_,
  { {0xddc4003d,0x6d5c0089,0x90e7007e,0x00000000}},	//   dziņ, _emra, _اسکن,
  { {0xd379017f,0xf8a9005d,0x290724df,0x00000000}},	//   gući_, مگاه_, tena_,
  { {0x2907006d,0x07f90021,0xade40085,0x00000000}},	//   uena_, مربع_, _ўцяк,
  { {0x290712fc,0x776924e0,0x98a219b6,0x00000000}},	//   rena_, tnex, нише,
  { {0x27e724e1,0x3ce9003b,0x290724e2,0x00000000}},	//   runn_, şivă_, sena_,
  { {0xc9870001,0x290724e3,0xddc4001c,0x00000000}},	//   _дужи, pena_, aziņ,
  { {0x34390021,0x6445004b,0x98ac003b,0x00000000}},	//   مسجد_, _ühik, _vodă_,
  { {0x6f16001f,0xdb0024e4,0x63a40bda,0x00000000}},	//   ydyc, _simé, _piin,
  { {0xd7fa0063,0x69c90229,0x6d4501a8,0x00000000}},	//   _להעל, _kwee, hkha,
  { {0x63a424e5,0xc2430062,0x170a0043,0x00000000}},	//   _viin, еняк, _دفنی_,
  { {0x55ba0063,0x25bf24e6,0x361a0063,0x00000000}},	//   _המסו, mpul_, _לונד,
  { {0x6754007e,0x65611560,0x3d0f0053,0x00000000}},	//   _رییس_, milh, ड़ने_,
  { {0x0eaa0088,0x661b0130,0xe7e30042,0x00000000}},	//   скай_, ovuk, _गिना_,
  { {0xee3a0d64,0x69c9006f,0xfce60da2,0x00000000}},	// [3a60] щна_, _nwee, зозо,
  { {0x65610016,0x98ac00eb,0xd379017f,0x00000000}},	//   nilh, _kodą_, vući_,
  { {0x315700b7,0x6441001f,0x913b0063,0x00000000}},	//   _זיין_, nyli, _העיק,
  { {0xea64007e,0x2f560454,0x3f47004b,0x00000000}},	//   وپای, _хтос, _jõul_,
  { {0xda65007e,0x644124e7,0xe9d70085,0x00000000}},	//   واهي, hyli, зміч_,
  { {0x637600ea,0x6d5c24e8,0xd379007d,0x00000000}},	//   rány, _umra, rući_,
  { {0x17f70021,0x6561017d,0x7af10072,0x00000000}},	//   كرية_, dilh, ähtö,
  { {0xddc4001c,0x45b80121,0x88bc004c,0x00000000}},	//   rziņ, огию_, _zněl,
  { {0x753824e9,0xbebb006f,0xeb9704f2,0x00000000}},	//   _povz, _poëz, _хит_,
  { {0x03d80062,0xb8820014,0x660200a8,0x00000000}},	//   омощ_, áísk, _vpok,
  { {0x7640024a,0x69c910ce,0x656f0003,0x00000000}},	//   symy, _zwee, écha,
  { {0x6d4b008f,0x4acc0042,0xc7b3089e,0x00000000}},	//   īgai, ारिव, _טבע_,
  { {0x7afd089f,0x660224ea,0x35f7007e,0x00000000}},	//   _öste, _upok, _فرود_,
  { {0x61e0000f,0x656100be,0xf1bf0061,0x00000000}},	//   ámla, cilh, rpá_,
  { {0x34fb014e,0x7d1500c3,0x662f0047,0x00000000}},	//   _ההוד, _razs, _באַװײ,
  { {0xf1bf00ea,0x9f050044,0x64610022,0x00000000}},	//   ppá_, بورو, ówił,
  { {0x394c24eb,0x01650044,0x00000000,0x00000000}},	// [3a70] _olds_, _يُعَ,   ,
  { {0x9d1402d8,0x9f43004c,0xed8b0085,0x00000000}},	//   ндуч, mují_, ёсак_,
  { {0x9f430080,0x69c924ec,0x6d4507b8,0x00000000}},	//   lují_, _swee, rkha,
  { {0x6d4524ed,0x8c4400dd,0x7e2b0083,0x00000000}},	//   skha, _ăşti, _ліга_,
  { {0x9f430080,0xe9d8000d,0xdb1e0051,0x00000000}},	//   nují_, зкі_, espó,
  { {0xada40088,0x3f89001f,0x644100fe,0x00000000}},	//   _паўл, llau_, yyli,
  { {0x9f430080,0x65610016,0x3f89001f,0x00000000}},	//   hují_, vilh, olau_,
  { {0xec340086,0x9f43004c,0x69c90479,0x00000000}},	//   _янсь, kují_, _twee,
  { {0x64410185,0x656124ee,0xdb1e0025,0x00000000}},	//   wyli, tilh, aspó,
  { {0x9f430080,0x25bf001a,0x63b5004c,0x00000000}},	//   dují_, rpul_, ízno,
  { {0xb17b0137,0x65611601,0x661b0bda,0x00000000}},	//   trån, rilh, svuk,
  { {0x888c0047,0x8c1a0063,0xa25b00be,0x00000000}},	//   _פראַ, קורי, rbôn,
  { {0xd379017f,0x3f89001f,0xdcfc00c2,0x00000000}},	//   juću_, dlau_, _skrč,
  { {0x22420031,0xd379007d,0x3f89002b,0x00000000}},	//   rykk_, duću_, elau_,
  { {0xb17b00a5,0xb4e90042,0x30752338,0x00000000}},	//   prån, यली_, еутс,
  { {0x26cf0045,0x60c101f7,0x9f430080,0x00000000}},	//   _jego_, ılma, bují_,
  { {0x88bc0080,0x9f430080,0xd379007d,0x00000000}},	// [3a80] _sněm, cují_, guću_,
  { {0x3eb90026,0x3f89014f,0x26cf24ef,0x00000000}},	//   _efst_, alau_, _lego_,
  { {0x201c013d,0x3f8924f0,0xfb82005d,0x00000000}},	//   _évi_, blau_, نگری,
  { {0x26cf0117,0x09e60086,0x3f8924f1,0x00000000}},	//   _nego_, додн, clau_,
  { {0x62880022,0xef1f0244,0xbdfa01f3,0x00000000}},	//   ędow, _thür_, _برجا_,
  { {0xc983047e,0xe89424f2,0xf84a0054,0x00000000}},	//   кущи, наль, жчий_,
  { {0x9f430080,0x6d4e0831,0x98a70022,0x00000000}},	//   zují_, _ilba, yjną_,
  { {0x27e0065f,0x26cf24f3,0xf0930063,0x00000000}},	//   čin_, _cego_, כנו_,
  { {0xe4e60086,0xa4d40054,0x6a8324f4,0x00000000}},	//   мінн, нопі, _алта,
  { {0x9f430080,0x69c211cf,0x3f80004b,0x00000000}},	//   vují_, mpoe, hoiu_,
  { {0x3f89001f,0xdb0012c7,0x61e624f5,0x00000000}},	//   ylau_, _limí, erkl,
  { {0xf6d6006a,0x798a002b,0x9f43004c,0x00000000}},	//   _آزاد, llfw, tují_,
  { {0x518724f6,0x9294000d,0x25af2341,0x00000000}},	//   дува, каюц, _gugl_,
  { {0x9f430080,0x3f8900a3,0x301524f7,0x00000000}},	//   rují_, wlau_, ндгр,
  { {0x61e6005b,0x9f43004c,0x3f89002b,0x00000000}},	//   arkl, sují_, tlau_,
  { {0x2d8300d1,0x3f890089,0x9f43004c,0x00000000}},	//   _skje_, ulau_, pují_,
  { {0x20050080,0x11d90021,0x25a90139,0x00000000}},	// [3a90] ůli_, _عودة_, _éalt_,
  { {0x301524f8,0x3f8924f9,0xdb000046,0x00000000}},	//   _здор, slau_, _dimí,
  { {0x9949034d,0xd379017f,0x3f89002b,0x00000000}},	//   núť_, suću_, plau_,
  { {0x309a014e,0xceeb007e,0xa3e624fa,0x00000000}},	//   _משתמ, _بردن_, _पिन_,
  { {0x6f0d24fb,0x69c4003b,0x9f5a0014,0x00000000}},	//   meac, ţien, _uppá_,
  { {0x6f0d0025,0x63680058,0xaffb009d,0x00000000}},	//   leac, lınt, ַּ֔י,
  { {0x26cf24fc,0x7c842183,0x8bb40044,0x00000000}},	//   _pego_, _ауте, _لإقا,
  { {0xac940055,0x6f0d0027,0xef120063,0x00000000}},	//   _расш, neac, ָּה_,
  { {0xb17b13e5,0x39890014,0x60d5017c,0x00000000}},	//   trål, húsi_, kazm,
  { {0x6f0d0025,0xe00f0053,0x39890066,0x00000000}},	//   heac, ाबाद_, kúsi_,
  { {0x26cf0045,0x6368005b,0x69d91b3c,0x00000000}},	//   _tego_, kınt, lswe,
  { {0x59c60042,0x91e60867,0x00000000,0x00000000}},	//   रीकर, номе,   ,
  { {0x6f0d0027,0x69d924fd,0x61e6008f,0x00000000}},	//   deac, nswe, urkl,
  { {0x463a0047,0xb607008f,0x69d90518,0x00000000}},	//   _מענע, rošī, iswe,
  { {0x6f0d0025,0x4f9624fe,0x9f58006c,0x00000000}},	//   feac, ерау, ltré_,
  { {0x69d900e8,0x1fa70448,0x6f0d24ff,0x00000000}},	//   kswe, екси_, geac,
  { {0x9f582500,0x20d6000d,0x3f80003b,0x00000000}},	// [3aa0] ntré_, _пінс, roiu_,
  { {0x69d901af,0x60d50516,0x6da60da2,0x00000000}},	//   dswe, cazm, хиза,
  { {0xd910006a,0xc173014e,0x1c39000d,0x00000000}},	//   ییر_, _תחת_, мяць_,
  { {0x6f0d0025,0x3ce6003b,0xc4460041,0x00000000}},	//   ceac, şov_, ערײַ_,
  { {0xdcfc001c,0xda65007e,0x69d92501,0x00000000}},	//   _ekrā, پاني, gswe,
  { {0x6b83003b,0x69c200ca,0x1db50042,0x00000000}},	//   îngr, rpoe, _अंतत,
  { {0x2d980199,0x69d900ac,0xddcd0051,0x00000000}},	//   _ihre_, aswe, czał,
  { {0x3ea6001c,0xa8470021,0x853c005f,0x00000000}},	//   žotu_, عليم_, omėg,
  { {0x7afd2502,0xdb1c0003,0x3cfd0042,0x00000000}},	//   _östa, _ntré, र्वे_,
  { {0x6b822503,0xdb0000cd,0x2d98004d,0x00000000}},	//   loog, _himà, _jhre_,
  { {0xd498019d,0xdb1c006c,0xdb0e006c,0x00000000}},	//   ької_, _atré, _aubé,
  { {0x88bc004c,0x6b822504,0x78c60023,0x00000000}},	//   _sněh, noog, ūrvē,
  { {0xdb050137,0x8afd004c,0xf2042505,0x00000000}},	//   pphö, _umře, ляро,
  { {0x6b822506,0x291c2507,0x2d9800a3,0x00000000}},	//   hoog, ndva_, _nhre_,
  { {0x6f0d018d,0x7467005a,0x60d52508,0x00000000}},	//   teac, _пръв_, razm,
  { {0xa3f70063,0x00000000,0x00000000,0x00000000}},	//   _נמחק_,   ,   ,
  { {0x6f0d018d,0x7bdc01f7,0x636801f7,0x00000000}},	// [3ab0] reac, _avru, rınt,
  { {0x6f0d0025,0x4ea42509,0xad670044,0x00000000}},	//   seac, урса, راءه,
  { {0x69c000eb,0x2fd90021,0x6445004b,0x00000000}},	//   _atme, _توجد_, _ühit,
  { {0xeab0006a,0xddcd0051,0x2d98004d,0x00000000}},	//   معه_, rzał, _ehre_,
  { {0xdb07007a,0x61fd250a,0xdb00017d,0x00000000}},	//   _stjó, ntsl, _simã,
  { {0x61fd0d13,0x69d923ef,0xdcfd0066,0x00000000}},	//   itsl, rswe, _husľ,
  { {0x69c001f7,0xe739250b,0x69d9250c,0x00000000}},	//   _etme, дей_, sswe,
  { {0x6abb0035,0x25b90240,0x69d90821,0x00000000}},	//   _ufuf, íslo_, pswe,
  { {0x57240021,0x48ab0062,0x7bc5140d,0x00000000}},	//   طريق, _етем_, lphu,
  { {0x637d00ea,0xb9c40021,0xdb0e05ab,0x00000000}},	//   mény, _إقلي, _rubé,
  { {0xf3e5005a,0x9f58250d,0xa3cc0053,0x00000000}},	//   ъжно, stré_, शील_,
  { {0x06990021,0xdb00013d,0x61fd092f,0x00000000}},	//   _قناة_, _kimá, ftsl,
  { {0x20d60086,0x61fd01e1,0xe2970500,0x00000000}},	//   ківс, gtsl, каю_,
  { {0x6e2002dd,0x236c013d,0x0656009a,0x00000000}},	//   _ámbi, ődj_, _בינך_,
  { {0x998f0006,0x61fd250e,0x20730085,0x00000000}},	//   lygų_, atsl, алёў,
  { {0x9f5a00d1,0xc3230062,0x4f960002,0x00000000}},	//   _oppå_, _вмък, тргу,
  { {0x2738013d,0x6b821500,0x998f0078,0x00000000}},	// [3ac0] _pénz_, voog, nygų_,
  { {0x64450004,0x63ae0025,0x69db0053,0x00000000}},	//   _ühis, _úiné, _निजी,
  { {0x7983002b,0x6b8200ca,0xdee60121,0x00000000}},	//   donw, toog, _иони,
  { {0xa3e60042,0xb4ae0042,0x9986056c,0x00000000}},	//   यूट_, _कल्_, zwoń_,
  { {0x79830185,0x6b82250f,0x637d013d,0x00000000}},	//   fonw, roog, gény,
  { {0xf8060086,0x3ea6001c,0xaa570044,0x00000000}},	//   вчин, žots_, خلها_,
  { {0x7d1c0025,0x9d1b0149,0x290e2510,0x00000000}},	//   _iars, _קולט, refa_,
  { {0x9c170063,0x97140259,0xb17b0137,0x00000000}},	//   _בחלק_, умиц, tråk,
  { {0x68ed00ea,0x69c00829,0x853c0078,0x00000000}},	//   ándé, _utme, ymėd,
  { {0x7e9b0063,0xf5260854,0x7bc30014,0x00000000}},	//   וספו, тфин, ínug,
  { {0x2955005a,0xe2f90086,0xd6d201fb,0x00000000}},	//   _сътр, нені_, _نقض_,
  { {0xb17b0a2e,0x61fd0ddc,0x7d1c1781,0x00000000}},	//   pråk, ttsl, _lars,
  { {0x52140054,0x61fd0046,0x0737009a,0x00000000}},	//   адят, utsl, _שאדם_,
  { {0x70bf0053,0x7bc5006d,0x25d70047,0x00000000}},	//   ्रेल, yphu, _יודן_,
  { {0xdfd8005a,0x61fd02ea,0xd0d40330,0x00000000}},	//   кът_, stsl, росъ,
  { {0x3eaf0146,0x7d1c1d6c,0x0ccb0053,0x00000000}},	//   øgt_, _aars, िर्म,
  { {0xa3ac0053,0x60c200dd,0x2b8e01c8,0x00000000}},	// [3ad0] _कूट_, _şome, mých_,
  { {0x2d872511,0x7d1c2512,0x2b8e0240,0x00000000}},	//   ône_, _cars, lých_,
  { {0x2ca701e3,0x7d1c2513,0x6ca72514,0x00000000}},	//   änd_, _dars, траж,
  { {0x65680035,0x63b50080,0x2b8e0114,0x00000000}},	//   hidh, ízni, ných_,
  { {0x64480185,0x7d1c2515,0xe1ff2516,0x00000000}},	//   hydi, _fars, ntó_,
  { {0x7d1c0006,0x2b8e027d,0x4dfa0041,0x00000000}},	//   _gars, hých_, _אפשא,
  { {0x2b8e027d,0xccf20063,0x6f1d004d,0x00000000}},	//   kých_, _לכם_, _kasc,
  { {0xe6190ad9,0x63ad2517,0x442902f7,0x00000000}},	//   еди_, _nian, _ča_,
  { {0x645a001c,0x6b9b00a4,0xe1ff00ea,0x00000000}},	//   ezti, _ihug, jtó_,
  { {0x6f1d051e,0x63ad004b,0x28ac0053,0x00000000}},	//   _lasc, _aian, _चलचि,
  { {0x63ad2518,0x6448002b,0x80bf0042,0x00000000}},	//   _bian, gydi, ्रैं,
  { {0x18a40086,0x63ad2519,0x6f1d251a,0x00000000}},	//   _таєм, _cian, _nasc,
  { {0x63ad1aae,0x656805b3,0xd6d90051,0x00000000}},	//   _dian, bidh, mał_,
  { {0x673b01a6,0xd6d90051,0xf8c60053,0x00000000}},	//   ljuj, lał_, रुपय,
  { {0x63ad251b,0x65a8005e,0x6f1d251c,0x00000000}},	//   _fian, _ртцг_, _basc,
  { {0xd6d90051,0x9f550001,0x673b01b3,0x00000000}},	//   nał_, ањуј, njuj,
  { {0xe1ff006d,0x6e930021,0x6f1d251d,0x00000000}},	// [3ae0] ctó_, ملفا, _dasc,
  { {0x63ad251e,0x4427251f,0xdcfc0051,0x00000000}},	//   _zian, _krn_, _okrą,
  { {0xd6d90051,0xcea90063,0x8ae60086,0x00000000}},	//   kał_, פי_, гілл,
  { {0x6b9b0027,0x7afd0c38,0xee3a0002,0x00000000}},	//   _chug, _östl, _знм_,
  { {0xd6d90051,0x673b007d,0x28f80525,0x00000000}},	//   dał_, djuj, вель_,
  { {0xc27b00b5,0xb60500c2,0x6e2b0063,0x00000000}},	//   ערסי, _mašč, _אֵלַ,
  { {0x8b9600e2,0xd6d90051,0xdddd0066,0x00000000}},	//   _брач, fał_, _vysť,
  { {0x7bc300cd,0xd6d90051,0x6f042520,0x00000000}},	//   ínue, gał_, nfic,
  { {0x6448001f,0x2b8e027d,0x7bde030c,0x00000000}},	//   wydi, vých_, lspu,
  { {0x63ad2521,0x64482522,0x645a004d,0x00000000}},	//   _sian, tydi, tzti,
  { {0x63ad055b,0x2b8e016b,0x7bde2523,0x00000000}},	//   _pian, tých_, nspu,
  { {0x291e19f4,0x656800a4,0xe4470021,0x00000000}},	//   _hata_, sidh, الَى_,
  { {0x645a000f,0x291e014f,0x2b8e0512,0x00000000}},	//   szti, _kata_, rých_,
  { {0x7bde00ac,0x628d0035,0xe6930021,0x00000000}},	//   kspu, _vyao, _الهد,
  { {0xe1ff0521,0x291e035e,0xcf9b00e1,0x00000000}},	//   stó_, _mata_, еја_,
  { {0x7bde01bc,0x2f180b0f,0x291e0051,0x00000000}},	//   dspu, лось_, _lata_,
  { {0x7bde2524,0x6f1d06c5,0x6b9b002b,0x00000000}},	// [3af0] espu, _vasc, _rhug,
  { {0x6b9b0035,0xd6d90051,0x291e2525,0x00000000}},	//   _shug, zał_, _nata_,
  { {0xc174014e,0xb6050198,0x656f0164,0x00000000}},	//   _לחץ_, _zašč, échi,
  { {0xfbd0006a,0x4c940076,0xfb840121,0x00000000}},	//   ستم_, щихс, бычн,
  { {0x291e2526,0xf8a9007e,0x7bde2527,0x00000000}},	//   _bata_, چگاه_, aspu,
  { {0xd6d90045,0xf8a9007e,0xda78000d,0x00000000}},	//   wał_, نگاه_, ыях_,
  { {0x6b9b105c,0xd6d90051,0xd0f80063,0x00000000}},	//   _thug, tał_, אמות_,
  { {0x60d72528,0xb17b01e1,0x5ba41ece,0x00000000}},	//   _lexm, nsåb, _груз,
  { {0xd6d90051,0x291e1f09,0x673b06d8,0x00000000}},	//   rał_, _fata_, rjuj,
  { {0xa5090138,0xd6d90051,0x291e2529,0x00000000}},	//   њена_, sał_, _gata_,
  { {0x2815006a,0xd6d90022,0x7bc1006c,0x00000000}},	//   _خواس, pał_, _élud,
  { {0x25ae00a3,0xe81b0082,0x6386252a,0x00000000}},	//   _eifl_, _भैया_, ргма,
  { {0x7ae40025,0x291e0a9f,0xf7840021,0x00000000}},	//   óiti, _yata_, _النَ,
  { {0xb60500c2,0xdcfe008f,0x44270077,0x00000000}},	//   _vašč, kopā, _trn_,
  { {0x3f470019,0xdb0e006d,0xdb1c0014,0x00000000}},	//   _nõus_, _subí, _strí,
  { {0x6d55252b,0x63b5004c,0x6f04252c,0x00000000}},	//   _alza, íznu, ufic,
  { {0xdc3c00c3,0x6f04252d,0x91a0008b,0x00000000}},	// [3b00] ršča, rfic, _trì_,
  { {0x7bde05be,0x7afb252e,0xef1f004e,0x00000000}},	//   tspu, _acut, _eaü_,
  { {0x3dc900a4,0x60dc15f3,0x161c0053,0x00000000}},	//   apaw_, marm, _बैनर_,
  { {0x7bde007a,0xdb1c000c,0x291e10ff,0x00000000}},	//   rspu, _strâ, _sata_,
  { {0x291e0009,0xaa160259,0x7bde252f,0x00000000}},	//   _pata_, рфеј, sspu,
  { {0x60dc0026,0x07e60001,0xf1b90124,0x00000000}},	//   narm, ацим, íši_,
  { {0xa8a3005a,0xebe30121,0x8c462530,0x00000000}},	//   орък, _морп, _теве,
  { {0x36d40001,0xab74006a,0xdb070026,0x00000000}},	//   љопр, _انرژ, _stjö,
  { {0x291e03c6,0x60dc2531,0x8b8b009d,0x00000000}},	//   _tata_, karm, _יָמֶ,
  { {0x95380002,0x60dc0331,0xe4a60fd0,0x00000000}},	//   узот_, jarm, ирно,
  { {0x33200268,0xd49a005a,0x3cfe0053,0x00000000}},	//   _baix_, ъри_, _लाने_,
  { {0x60dc0025,0x3d060053,0x60ce00a5,0x00000000}},	//   earm, स्ते_, ebbm,
  { {0x60c2003b,0x60dc2532,0x35b6030b,0x00000000}},	//   _şoma, farm, _тщес,
  { {0xa1870088,0x224b00c7,0x32d50013,0x00000000}},	//   рымл, ryck_, ấy_,
  { {0x657d00ea,0x656f0003,0x32020124,0x00000000}},	//   éshe, èche, atky_,
  { {0x60dc0122,0x644700fe,0x9f430066,0x00000000}},	//   aarm, äjie, lujú_,
  { {0x60dc1c2a,0x23690058,0x539c009a,0x00000000}},	// [3b10] barm, _imaj_, _ביהו,
  { {0x61440001,0x91a0001b,0x7afb13e6,0x00000000}},	//   _мења, _trí_, _scut,
  { {0x9f4b0026,0x5ba7000d,0x7afd0137,0x00000000}},	//   ðmót_, ардз, _östk,
  { {0x9f430024,0x9a9d0085,0x1a650043,0x00000000}},	//   hujú_, нулi, میزی_,
  { {0x9f430024,0xbf360ca4,0xe9f80054,0x00000000}},	//   kujú_, _הארץ_, инці_,
  { {0xe9870001,0xdcfc0051,0xe8f80086,0x00000000}},	//   шћен, _okrę, илі_,
  { {0x9f430024,0x67d20002,0x31580063,0x00000000}},	//   dujú_, поју, שיון_,
  { {0x27e91ba3,0x60dc24d2,0x32020260,0x00000000}},	//   čan_, zarm, ytky_,
  { {0xd4d90726,0x9f58231d,0x04b50085,0x00000000}},	//   льні_, ntrá_, йсня,
  { {0x45190905,0x9f430066,0x60dc00be,0x00000000}},	//   уция_, gujú_, xarm,
  { {0xb8950032,0x33200164,0x2b9c0114,0x00000000}},	//   _الاع, _paix_, síce_,
  { {0x833a0002,0x69cb006f,0xb17b06a5,0x00000000}},	//   учот_, opge, krås,
  { {0xdb1c0051,0x9f430024,0x6d900072,0x00000000}},	//   _zwró, bujú_, säai,
  { {0x9f430024,0x23b2007e,0x21330013,0x00000000}},	//   cujú_, _کميس, _cnxh_,
  { {0x03a6018e,0x3202004a,0x63c6004c,0x00000000}},	//   _лико, stky_, ěrné,
  { {0xd0070001,0xdb0200ac,0x24981b89,0x00000000}},	//   љете_, rmoë, ürme_,
  { {0x7bc70078,0x60dc2533,0x39452534,0x00000000}},	// [3b20] _atju, parm, _ools_,
  { {0x9f5800cd,0x2369007d,0xc692009f,0x00000000}},	//   strà_, _zmaj_, לאן_,
  { {0x61e402ab,0xdb1c04a6,0xbc6a01fb,0x00000000}},	//   _hvil, _atrá, دمان_,
  { {0x9f43034d,0x7bc30bc6,0xda7a047e,0x00000000}},	//   zujú_, ínua, лял_,
  { {0x29070168,0x00000000,0x00000000,0x00000000}},	//   ffna_,   ,   ,
  { {0x6f1612ca,0x9f430066,0x3945006c,0x00000000}},	//   leyc, xujú_, _cols_,
  { {0x9f430024,0xb17b01f2,0x88bc011b,0x00000000}},	//   vujú_, orår, _dněp,
  { {0xb8ef0053,0xcc770063,0x4432008d,0x00000000}},	//   _व्_, _העלה_, _ăy_,
  { {0xdcfc0051,0x61e4161b,0x9f430066,0x00000000}},	//   _skrę, _nvil, tujú_,
  { {0xb9960032,0x91a9001b,0x394504a5,0x00000000}},	//   _الطب, _trả_, _gols_,
  { {0x9f430024,0xdb1c0080,0x290c0150,0x00000000}},	//   rujú_, _ztrá, _ibda_,
  { {0x04630be6,0x9f430066,0xf7432183,0x00000000}},	//   ятым, sujú_, _нехо,
  { {0x9f430066,0x753c013d,0x926b0789,0x00000000}},	//   pujú_, örzs, урна_,
  { {0x60230080,0xd258000d,0xc0350141,0x00000000}},	//   jímá, сцю_, онгј,
  { {0xf484007e,0x61e42535,0x85030044,0x00000000}},	//   _باشی, _evil, _روين,
  { {0xe7f00235,0x3d060053,0xa492005d,0x00000000}},	//   _घटना_, स्से_, _ویکت,
  { {0x93bc000c,0x7afd00a5,0x7bc70130,0x00000000}},	// [3b30] zvăl, _östi, _stju,
  { {0xf1b90066,0x6ca70ae8,0x56370041,0x00000000}},	//   íšu_, бреж, זאמע_,
  { {0xdb1c2536,0xd251007e,0x9f5800be,0x00000000}},	//   _strá, _رنگ_, strá_,
  { {0x39452537,0x68e800a4,0x6bd40021,0x00000000}},	//   _sols_, _addd, ستمر,
  { {0x39452538,0xf1bf2539,0xd9450c4d,0x00000000}},	//   _pols_, zván_, жели,
  { {0x61dc009a,0x8e36009a,0x00000000,0x00000000}},	//   נקוד, _ונשא_,   ,
  { {0x3945253a,0xddd60051,0x18660062,0x00000000}},	//   _vols_, czył, жащи_,
  { {0x6d4702dd,0x58940021,0x9b58253b,0x00000000}},	//   _hoja, أجهز, _лист_,
  { {0x8579000a,0x59670062,0x9f5e006c,0x00000000}},	//   исот_, _лъжа, îté_,
  { {0x6b8b253c,0xf1bf00ea,0xc13b003b,0x00000000}},	//   logg, tván_, _ţânţ,
  { {0x61e4150d,0x6d47253d,0x69c90072,0x00000000}},	//   _svil, _moja, _htee,
  { {0x9655005a,0x6d47253e,0xd2aa22c4,0x00000000}},	//   _мълч, _loja, икне_,
  { {0x84e5253f,0x0574007e,0x95c8005e,0x00000000}},	//   _долж, _کاند, _луја_,
  { {0x28cf0235,0x412a24f8,0x85a70001,0x00000000}},	//   _स्मि, шого_, _ујед,
  { {0x7ae92540,0x7d172541,0x63e40044,0x00000000}},	//   _odet, dexs, _فسيك,
  { {0x61e403d4,0x75232542,0xef1a0092,0x00000000}},	//   _tvil, _hanz, јма_,
  { {0x92e90242,0x7bc30014,0xee3a0794,0x00000000}},	// [3b40] _طريق_, ínun, шна_,
  { {0x3d140053,0xb17b0137,0x7ae90058,0x00000000}},	//   ड़ें_, lsån, _adet,
  { {0x75232543,0x69c90656,0xe4560041,0x00000000}},	//   _manz, _atee, ֿינט_,
  { {0xeb970055,0x75231166,0xddd60051,0x00000000}},	//   оих_, _lanz, rzył,
  { {0x7ae9001f,0xddd60051,0x49a60699,0x00000000}},	//   _ddet, szył, ојка,
  { {0xed5a0001,0xe7ea2544,0xd910007e,0x00000000}},	//   _тог_, афик_, عیض_,
  { {0xd7f00032,0x69c900fe,0xfc030988,0x00000000}},	//   ركة_, _etee, _опро,
  { {0x75230122,0xdb1c0583,0xfb56007e,0x00000000}},	//   _aanz, _stræ, _بپرد,
  { {0x7791007e,0x3a2d2545,0x8e7a069a,0x00000000}},	//   ریها, _grep_, ינֵה,
  { {0x7523051e,0xce370063,0x03f8005e,0x00000000}},	//   _canz, קאית_, бној_,
  { {0x75232546,0x836b0021,0x4cbb0063,0x00000000}},	//   _danz, لصحف_, יזיו,
  { {0xd3a7000d,0x8c1b009a,0xf62a0054,0x00000000}},	//   ўроп, בוטי, _віки_,
  { {0xc6170054,0x914b0094,0x75232547,0x00000000}},	//   _моїх_, ачва_, _fanz,
  { {0x75230199,0xdb1c01e1,0x3d140053,0x00000000}},	//   _ganz, _utræ, ड़ों_,
  { {0x2099014c,0x6d472548,0x4f6b24fe,0x00000000}},	//   сквы_, _roja, ашам_,
  { {0x75232549,0x98a5001c,0x99920066,0x00000000}},	//   _zanz, _solī_, ždňa_,
  { {0x3eaf00bd,0x201e0026,0x5d55065b,0x00000000}},	// [3b50] ägt_, ætir_, пкат,
  { {0x7bc3017d,0x80f5014c,0xcd28005e,0x00000000}},	//   ínuo, _эпох, ожђе_,
  { {0x200500cd,0x6d4714d5,0x6b150001,0x00000000}},	//   àlid_, _voja, змеђ,
  { {0x3a2d00e5,0x7d0e00a5,0x501a0063,0x00000000}},	//   _prep_, _ebbs, _פורו,
  { {0x7f3a0063,0x7c2e254a,0x6d47254b,0x00000000}},	//   _הערו, _erbr, _toja,
  { {0x6b8b0290,0xf771007e,0x6d5e254c,0x00000000}},	//   sogg, کات_, chpa,
  { {0x6b8b051e,0x63680058,0x7523254d,0x00000000}},	//   pogg, rınz, _ranz,
  { {0x75230a02,0x657a254e,0x907c0063,0x00000000}},	//   _sanz, enth, יטוי,
  { {0x28cf0053,0x29d5007e,0x69c4003b,0x00000000}},	//   _स्थि, _رياس, ţier,
  { {0xb465254f,0xf770005d,0x2eb80042,0x00000000}},	//   зкол, _یان_, _अल्त,
  { {0xb97a0047,0xccf20047,0x75232550,0x00000000}},	//   _פרעז, עכט_, _vanz,
  { {0x889a0063,0x637600c2,0x6b750022,0x00000000}},	//   _הבעי, kšne, rągw,
  { {0x66ba0063,0x75232551,0xb17b00a5,0x00000000}},	//   _המנה, _tanz, rsån,
  { {0xb17b0137,0x442e0003,0x45d201ce,0x00000000}},	//   ssån, _frf_, _џојс,
  { {0x6f0f0be1,0x8fa60820,0x6e2f01a8,0x00000000}},	//   _bbcc, заве, _arcb,
  { {0x03a30062,0x6d900050,0xa3ad0082,0x00000000}},	//   _пищо, jäar, कगण_,
  { {0x63a4002c,0x2ee00025,0x6d5e2552,0x00000000}},	// [3b60] _ihin, raif_, thpa,
  { {0x26dd0051,0xb17b0137,0x28ac0053,0x00000000}},	//   _lewo_, nsål, टेडि,
  { {0xa3de0235,0x63a4055f,0x61e6080f,0x00000000}},	//   दीप_, _khin, lskl,
  { {0xeb9a0055,0x0b46000d,0xcb6a005e,0x00000000}},	//   щие_, янен, љаде_,
  { {0x98be000c,0x61e62553,0x60de0150,0x00000000}},	//   _notă_, nskl, _kepm,
  { {0xdb1c0d88,0x395a0014,0xddd60022,0x00000000}},	//   _strä, óps_, rzyń,
  { {0x6d9000fe,0x2b77007e,0xddd60022,0x00000000}},	//   säas, _کینگ_, szyń,
  { {0x96342514,0x61e62554,0x5c7b0063,0x00000000}},	//   дниц, kskl, _האלה,
  { {0x7e6400bd,0xbb3b0063,0x98be003b,0x00000000}},	//   nzip, _פעמי, _cotă_,
  { {0x63a400a4,0x4a5b0063,0x29180139,0x00000000}},	//   _ahin, _הדמו, _úra_,
  { {0xb4bc0053,0x63a42555,0xe3d20041,0x00000000}},	//   _अली_, _bhin, _פֿילאַ,
  { {0x7ae20035,0x63a422a4,0x7afd0137,0x00000000}},	//   naot, _chin, _östt,
  { {0x61e62556,0xeb910063,0x7f4400be,0x00000000}},	//   gskl, דָם_, djiq,
  { {0x7ae20d17,0x7e640066,0x56370041,0x00000000}},	//   haot, dzip, _מאדע_,
  { {0xd5a5007e,0x63a40139,0x7ae2004b,0x00000000}},	//   _تلوی, _fhin, kaot,
  { {0x63a4203b,0x7ae2078c,0xd4970149,0x00000000}},	//   _ghin, jaot, _מכות_,
  { {0xf1b70082,0xfe730cac,0x00000000,0x00000000}},	// [3b70] _इंटन, ردر_,   ,
  { {0x6ca700a0,0x637600c2,0x00000000,0x00000000}},	//   преж, ršne,   ,
  { {0x8c190067,0x8e2601ce,0xf2d5009a,0x00000000}},	//   تيار_, кoг_, ֵעַ_,
  { {0x98b2004c,0x7ae2004b,0x6d5c013d,0x00000000}},	//   žděn_, gaot, _elra,
  { {0x539c0063,0x692501e2,0xd2b8009a,0x00000000}},	//   זיאו, дмла, פלגת_,
  { {0x6f0d2557,0xceb2016e,0x5c070085,0x00000000}},	//   lfac, _שיך_, _няба,
  { {0x29c20ac6,0xd9420062,0xb8e50053,0x00000000}},	//   _eða_, тещи, _एल_,
  { {0x6f0d0199,0x6e2d00c2,0x80380063,0x00000000}},	//   nfac, ovab, לנוע_,
  { {0x6f0d004d,0x629a0022,0x63a40305,0x00000000}},	//   ifac, ętok, _rhin,
  { {0xe576000d,0x6d450137,0x63a42558,0x00000000}},	//   дзь_, njha, _shin,
  { {0x68e32559,0x63a4255a,0xe8550044,0x00000000}},	//   mand, _phin, _تناد,
  { {0xe29a255b,0x68e3255c,0x29c20014,0x00000000}},	//   жам_, land, _yða_,
  { {0x16340088,0x27e0017f,0x68e30035,0x00000000}},	//   _пеця, ćine_, oand,
  { {0x32dc008b,0xf6520063,0x6729255d,0x00000000}},	//   ậy_, _בצד_, ldej,
  { {0x63a40034,0x68e3255e,0x6609255f,0x00000000}},	//   _thin, iand, ltek,
  { {0x63a40035,0x67292560,0x853c0006,0x00000000}},	//   _uhin, ndej, ymėk,
  { {0x68e32561,0x66092562,0xa19e000d,0x00000000}},	// [3b80] kand, ntek, _вынi,
  { {0x67290080,0x68e32563,0x66092564,0x00000000}},	//   hdej, jand, itek,
  { {0x7ae20019,0x7e6400bd,0x68e32565,0x00000000}},	//   taot, szip, dand,
  { {0x672900c2,0x68e32566,0x25ee0053,0x00000000}},	//   jdej, eand, _इटली_,
  { {0x68e32567,0xfa360049,0xdb1c006c,0x00000000}},	//   fand, براد, _juré,
  { {0x764600fe,0x68e32568,0x66092569,0x00000000}},	//   äkym, gand, dtek,
  { {0xd794005a,0x644700fe,0x2bf5000d,0x00000000}},	//   никъ, äjil, _пятр,
  { {0x2f5b0047,0x68e3256a,0xd6d00021,0x00000000}},	//   ַדינ, aand, دقة_,
  { {0x6609000f,0x8a03005a,0xf8cf0053,0x00000000}},	//   gtek, _изте, _स्वय,
  { {0x7afd0d88,0x67290080,0x68e3256b,0x00000000}},	//   _östr, adej, cand,
  { {0x7ae00089,0xdb1c22e5,0x69c0256c,0x00000000}},	//   _kemt, _auré, _hume,
  { {0x69c00c55,0x291c256d,0x660900ca,0x00000000}},	//   _kume, leva_, btek,
  { {0x394c003d,0x69c0256e,0xdb1c006c,0x00000000}},	//   _kods_, _jume, _curé,
  { {0xdb1c0164,0xf1a4005e,0x291c256f,0x00000000}},	//   _duré, врсн, neva_,
  { {0x69c02570,0x34fb0063,0x6f0d0244,0x00000000}},	//   _lume, _והוד, tfac,
  { {0x68e32571,0xdb1c01a8,0x291c2572,0x00000000}},	//   zand, _etrú, heva_,
  { {0x6e2d0003,0x7bce2573,0xdb002574,0x00000000}},	// [3b90] uvab, _atbu, _limó,
  { {0x291c1181,0x61fd021e,0x201a0014,0x00000000}},	//   jeva_, musl, éfið_,
  { {0x68e32575,0x69c02576,0x291c2577,0x00000000}},	//   vand, _aume, deva_,
  { {0x395e00cd,0x68e32578,0x66092579,0x00000000}},	//   _alts_, wand, ytek,
  { {0x68e3257a,0xe9d8000d,0x7ae0002b,0x00000000}},	//   tand, дкі_, _demt,
  { {0x68e3257b,0x7afe0078,0x291c257c,0x00000000}},	//   uand, ėpta, geva_,
  { {0x68e3257d,0xa7b5257e,0xbb1b007e,0x00000000}},	//   rand, нсиј, _وزرا_,
  { {0xaffa00b5,0x7ae00146,0x69c00191,0x00000000}},	//   פּצי, _gemt, _fume,
  { {0xe616026c,0x69c0257f,0x68e32580,0x00000000}},	//   еды_, _gume, pand,
  { {0x291c051e,0x61fd0004,0x7bc80164,0x00000000}},	//   ceva_, dusl, _éduc,
  { {0x69c000bd,0x9f580003,0xdc3c007d,0x00000000}},	//   _zume, suré_, ršća,
  { {0x68e12581,0xdb0e017d,0x66092582,0x00000000}},	//   _held, _subú, ptek,
  { {0x61fd0004,0x7e7b2583,0x68e12584,0x00000000}},	//   gusl, _župn, _keld,
  { {0x68e100d1,0x2b5f01a8,0xc5680044,0x00000000}},	//   _jeld, _lluc_, _يحول_,
  { {0x03961087,0x68e12585,0xd4790047,0x00000000}},	//   _прия, _meld, _מאַל,
  { {0x20050268,0xdcd80042,0x61fd2586,0x00000000}},	//   àlia_, यर्फ़, busl,
  { {0xdee1000d,0xe5060053,0xc7b200ff,0x00000000}},	// [3ba0] русi_, _शामि_, רבן_,
  { {0x2cbc00d1,0x8d760021,0x69c02587,0x00000000}},	//   øvd_, راءا, _rume,
  { {0x291c051e,0xe1ff0871,0x394c00e5,0x00000000}},	//   veva_, nzón_, _rods_,
  { {0x69c0002b,0x09e61567,0xca86030b,0x00000000}},	//   _pume, еодн, нгей,
  { {0x291c2588,0xdb002589,0x68e1005b,0x00000000}},	//   teva_, _simó, _beld,
  { {0x291c258a,0x68e1258b,0x3d060042,0x00000000}},	//   ueva_, _celd, स्खे_,
  { {0x7bce0137,0x291c258c,0x6d4e00dd,0x00000000}},	//   _utbu, reva_, _ioba,
  { {0x69c00d74,0x68e10019,0x3f800025,0x00000000}},	//   _tume, _eeld, nniu_,
  { {0x291c258d,0x68e1258e,0x6d4e258f,0x00000000}},	//   peva_, _feld, _koba,
  { {0x61fd0019,0x68e12590,0xdb002591,0x00000000}},	//   vusl, _geld, _timó,
  { {0x249800b9,0x2360006f,0x72d5114d,0x00000000}},	//   ærm_, _blij_, конф,
  { {0x68e12592,0x61fd047f,0x6d4e2593,0x00000000}},	//   _zeld, tusl, _loba,
  { {0x3f800051,0xe1ff006d,0x28ac0082,0x00000000}},	//   dniu_, azón_, टेरि,
  { {0x3f802594,0x61fd2595,0x637600a8,0x00000000}},	//   eniu_, rusl, ršna,
  { {0x7d1e0420,0xdfd10021,0x1fa7000d,0x00000000}},	//   deps, شيء_, ераг,
  { {0x2d8708ea,0xcf980001,0xc49b0063,0x00000000}},	//   čnem_, еју_, _משות,
  { {0x2b9c0080,0x6d4e01ae,0x81c3008f,0x00000000}},	// [3bb0] mích_, _boba, ķēsi,
  { {0x2b9c0080,0x6d4e2596,0xf27c0041,0x00000000}},	//   lích_, _coba, _מרחש,
  { {0x6144000a,0x61ed01a6,0x6d4e074f,0x00000000}},	//   _сеќа, _hval, _doba,
  { {0x2b9c02f4,0xaa550002,0x61ed2597,0x00000000}},	//   ních_, квеш, _kval,
  { {0xaa580675,0xe1ff006d,0x68e12598,0x00000000}},	//   ницу_, nuó_, _peld,
  { {0x2b9c008b,0x6d4e2599,0xaa5601ce,0x00000000}},	//   hích_, _goba, ђију_,
  { {0x68e117d3,0x01380063,0x7c84259a,0x00000000}},	//   _veld, תרות_, _буте,
  { {0x6d4e0045,0x2b9c01c2,0x68e11033,0x00000000}},	//   _zoba, jích_, _weld,
  { {0x27e0017f,0x59f80330,0xdcea003b,0x00000000}},	//   ćina_, _петя_, _înău,
  { {0xdb1c02ab,0xe1ff006d,0x3f800022,0x00000000}},	//   _strø, duó_, zniu_,
  { {0x61ed010e,0x84581406,0x55041313,0x00000000}},	//   _aval, ерят_, учња,
  { {0x87d40021,0xe1ff0516,0x7d1e004c,0x00000000}},	//   _إغلا, rzón_, zeps,
  { {0x2d870024,0x42230062,0xcad6009a,0x00000000}},	//   čnej_, адяв, כורת_,
  { {0xf8ce0013,0xf67a0047,0xadc3008d,0x00000000}},	//   hứng_, _קאסמ, _hoặc,
  { {0xdff50071,0x61ed259b,0x6d4e259c,0x00000000}},	//   лять, _eval, _roba,
  { {0x2b9c108f,0x44270034,0x93fa0063,0x00000000}},	//   cích_, _isn_, _חלקי,
  { {0x6d4e259d,0xaec3259e,0x3f920075,0x00000000}},	// [3bc0] _poba, рбул, royu_,
  { {0x3f800006,0x645c04aa,0x321e0022,0x00000000}},	//   sniu_, ørig, łtys_,
  { {0x6faa0138,0xfbc30088,0x63660025,0x00000000}},	//   _овог_, абхо, _cóng,
  { {0xe29f0026,0x7d1e017e,0x44271aba,0x00000000}},	//   afðu_, seps, _msn_,
  { {0x2b9c004a,0x6f040137,0x298a058f,0x00000000}},	//   níci_, mgic, мско_,
  { {0x2b9c0080,0x38c8007e,0x44270114,0x00000000}},	//   zích_, راتی_, _osn_,
  { {0xebe3259f,0x317b0063,0xb8070049,0x00000000}},	//   _восп, ורסמ, نيوم_,
  { {0x59dd0053,0x80aa0042,0x00000000,0x00000000}},	//   _नौकर, _टरने,   ,
  { {0x69260079,0x8f9b014e,0xb5a60076,0x00000000}},	//   _имаа, ויקי, крой,
  { {0x6b82007d,0x201a25a0,0x73d812a5,0x00000000}},	//   lnog, _oppi_, ндор_,
  { {0x2cfb0063,0x442725a1,0x2b9c0114,0x00000000}},	//   וליא, _csn_, tích_,
  { {0xe1ff006d,0x18770063,0x44270089,0x00000000}},	//   tuó_, _בעבר_, _dsn_,
  { {0x4909016a,0xddd60051,0x2b9c25a2,0x00000000}},	//   _सामो_, rzyś, rích_,
  { {0x660025a3,0x6b82162d,0x2b9c004c,0x00000000}},	//   mumk, hnog, sích_,
  { {0xa1840088,0x63660014,0x2f190121,0x00000000}},	//   рыял, _bónd, новь_,
  { {0x6366006d,0x3c2c013d,0x2f180054,0x00000000}},	//   _cónd, zóvá_, кось_,
  { {0xa3de024c,0x636602dd,0xdbca0019,0x00000000}},	// [3bd0] दीर_, _dónd, _mõõt,
  { {0x636602dd,0x7c3a059d,0xdb1c017c,0x00000000}},	//   _póng, _štra, _durí,
  { {0x6b820185,0x6be40021,0xdb1c1795,0x00000000}},	//   fnog, لكلم, _eurí,
  { {0x4ea70088,0x4c940076,0x6366032a,0x00000000}},	//   _арга, шихс, _gónd,
  { {0x3c2c013d,0x4efa25a4,0xfbd3005d,0x00000000}},	//   tóvá_, _אהרו, _چتر_,
  { {0xdb1c000c,0x2ee900ca,0x6b8225a5,0x00000000}},	//   _curâ, laaf_, anog,
  { {0x17b90002,0xe7390121,0x9815005d,0x00000000}},	//   нѓиќ_, еей_, ابتا,
  { {0xab9525a6,0xc7250456,0x56290201,0x00000000}},	//   _сабљ, удий, ежим_,
  { {0x853c0006,0x66000360,0x29160139,0x00000000}},	//   ymėt, gumk, ídaí_,
  { {0x2ee900f5,0x22590022,0x00000000,0x00000000}},	//   haaf_, dysk_,   ,
  { {0xb9070235,0x672b00ea,0xa3e9000d,0x00000000}},	//   पर_, _tagj, эдна_,
  { {0xe611007e,0x9f580139,0x63760130,0x00000000}},	//   _هشت_, turí_, ršno,
  { {0xd5ae005d,0x07a40054,0x3634005d,0x00000000}},	//   تفی_, _таїн, _پرنس,
  { {0x6e20017d,0xa5091dd1,0x442725a7,0x00000000}},	//   _âmbi, _чека_, _tsn_,
  { {0x764600fe,0x2b9c0080,0x7521004d,0x00000000}},	//   äkyv, síci_, melz,
  { {0xdb1c0331,0x80d40053,0x4425002b,0x00000000}},	//   _purí, _ब्रे, mwl_,
  { {0x224601f7,0x3daa005e,0x6b82007d,0x00000000}},	// [3be0] _çok_, екао_, vnog,
  { {0x6e240089,0xf1bf013d,0x8c461527,0x00000000}},	//   rwib, rvát_, лезе,
  { {0x4425001f,0x201a0026,0x6f040137,0x00000000}},	//   nwl_, _uppi_, pgic,
  { {0xe5130053,0x67d1008f,0xdb1c25a8,0x00000000}},	//   त्ति_, _mājd, _surâ,
  { {0x32020024,0xd37b0047,0x6b8225a9,0x00000000}},	//   nuky_, ערנט, rnog,
  { {0x7521000f,0x082a0121,0x6b8213d7,0x00000000}},	//   jelz, еции_, snog,
  { {0x8d6325aa,0x8cda0042,0x22590022,0x00000000}},	//   _увре, _प्यो, zysk_,
  { {0x998d000c,0x1754005a,0x35f425ab,0x00000000}},	//   _preţ_, рвия, апир,
  { {0xe4e60086,0xfaa3000d,0x6d5e25ac,0x00000000}},	//   лінн, _гато, okpa,
  { {0x80d40235,0x7c220051,0x660025ad,0x00000000}},	//   _ब्ले, łoru, rumk,
  { {0x0d97014e,0x9f5802dd,0xcd9703c3,0x00000000}},	//   רכים_, ntró_, רדית_,
  { {0x78a8017f,0xdb1c00cd,0x439525ae,0x00000000}},	//   _izdv, _jurà, рамс,
  { {0xa77b0047,0xd7930021,0x63760734,0x00000000}},	//   _אראפ, _النخ, ošnj,
  { {0x4425001f,0x68ea1244,0x9f5800cd,0x00000000}},	//   bwl_, nafd, eurà_,
  { {0xe3b0006a,0x2ee90186,0x65680025,0x00000000}},	//   تری_, taaf_, mhdh,
  { {0x657a25af,0x82390601,0xaf3701f3,0x00000000}},	//   lith, _азис_, درست,
  { {0xccfb0138,0x7983001f,0xdd750095,0x00000000}},	// [3bf0] еће_, ynnw, агањ,
  { {0x63760198,0x657a0027,0x31c4005a,0x00000000}},	//   jšnj, nith, _усъв,
  { {0x63ad25b0,0x2ca70dca,0x67d1008f,0x00000000}},	//   _khan, ånd_, _kāje,
  { {0x799a002c,0xa2e30053,0x5a3506b4,0x00000000}},	//   _aktw, _ख़ोज_, инет,
  { {0x61ef0d17,0x63ad25b1,0x2003004c,0x00000000}},	//   nscl, _mhan, luji_,
  { {0x645a0006,0x4e7a0047,0xdb1c01a8,0x00000000}},	//   kyti, _יארצ, _eurà,
  { {0x31580063,0x9f5800cd,0x657a24fb,0x00000000}},	//   ריון_, ctró_, dith,
  { {0x63ad25b2,0x657a0123,0x645a00d5,0x00000000}},	//   _nhan, eith, dyti,
  { {0x7bc700e3,0x7aeb1b21,0x9f4c0164,0x00000000}},	//   _huju, magt, édé_,
  { {0x9f580290,0x7bc725b3,0x055500a0,0x00000000}},	//   ntrò_, _kuju, ртия,
  { {0x7bc71e0f,0x69d90104,0xd838007d,0x00000000}},	//   _juju, lpwe, _grč_,
  { {0x7bc70089,0x63ad25b4,0xddc4003b,0x00000000}},	//   _muju, _chan, nziţ,
  { {0xdb1c0331,0x7bc725b5,0x7e6d0130,0x00000000}},	//   _jurá, _luju, jzap,
  { {0x63ad001f,0x65680139,0x4425002b,0x00000000}},	//   _ehan, chdh, pwl_,
  { {0x61fd00d1,0xd4660086,0x6366006d,0x00000000}},	//   arsl, _вище_, _cónc,
  { {0x6b89065f,0x7aeb0146,0xd0070001,0x00000000}},	//   _njeg, jagt, јете_,

  { {0x7aeb00e8,0x539b2177,0xb17b0137,0x00000000}},	// [3c00] dagt, _שיפו, tsåt,
  { {0x6b9b0455,0xee3725b6,0x2003004c,0x00000000}},	//   _akug, шну_, buji_,
  { {0x61e4001f,0x1c39000d,0x6d5e25b7,0x00000000}},	//   _hwil, ляць_, rkpa,
  { {0x7aeb0146,0xb5fd00c3,0x29070026,0x00000000}},	//   gagt, azši, egna_,
  { {0x9f5825b8,0xdb1c0022,0xda34007f,0x00000000}},	//   stró_, _stró, селы,
  { {0x61e40035,0x28f70121,0x26c20066,0x00000000}},	//   _mwil, аешь_, ľkom_,
  { {0x68ea25b9,0x26c225ba,0xdb0000be,0x00000000}},	//   rafd, žkom_, _simõ,
  { {0x61fd0026,0x68ea01af,0x7aeb0025,0x00000000}},	//   yrsl, safd, cagt,
  { {0x63ad0185,0x61e4006f,0x657a19d9,0x00000000}},	//   _rhan, _nwil, tith,
  { {0xa906006a,0x7bc025bb,0x645a0078,0x00000000}},	//   _خبرن, _himu, tyti,
  { {0x657a25bc,0x7bc025bd,0x6931007e,0x00000000}},	//   rith, _kimu, _رکور,
  { {0x68e80185,0x657a25be,0x2003004c,0x00000000}},	//   _hedd, sith, vuji_,
  { {0x645a25bf,0xa5f80001,0x75d4007e,0x00000000}},	//   syti, _селу_, _ايتا,
  { {0x7e6d00c2,0x68e82322,0x2003004c,0x00000000}},	//   vzap, _jedd, tuji_,
  { {0x63ad1898,0xdb1e0080,0x68e825c0,0x00000000}},	//   _than, _švýc, _medd,
  { {0xdcfe003d,0x7bc70397,0x68e825c1,0x00000000}},	//   kopē, _ruju, _ledd,
  { {0x68e80185,0x7a1a001c,0x61e4001f,0x00000000}},	// [3c10] _oedd, nātā, _gwil,
  { {0x7aeb00ac,0x7bc70089,0x6b9b0626,0x00000000}},	//   wagt, _puju, _skug,
  { {0x636600ea,0x5c070062,0x6aa90051,0x00000000}},	//   _hóna, ряза, _szef,
  { {0x9f580290,0xdb5b005a,0x7e99007e,0x00000000}},	//   strò_, ъюз_, _منجر_,
  { {0x7bc0014f,0x7bc70397,0x7ac40086,0x00000000}},	//   _dimu, _wuju, ісце,
  { {0x7bc7014f,0x7a1a001c,0x98ac005b,0x00000000}},	//   _tuju, dātā, _aldı_,
  { {0x7aeb002c,0x68e80322,0x286b0062,0x00000000}},	//   pagt, _dedd, ърдо_,
  { {0xbb850032,0x7bc00078,0x6d5523b4,0x00000000}},	//   _الري, _gimu, _hoza,
  { {0x68e8001f,0xa762005a,0x16390021,0x00000000}},	//   _fedd, якъд, اسبة_,
  { {0x7ae911a1,0xe1ff1795,0x6d550f74,0x00000000}},	//   _heet, dró_, _joza,
  { {0x6d5525c2,0xe3ba0854,0x94750021,0x00000000}},	//   _moza, лбо_, إدخا,
  { {0x78bc0014,0x6d551160,0x6d410014,0x00000000}},	//   _úrva, _loza, _ólaf,
  { {0xe1ff25c3,0x7ae9010e,0x63660025,0x00000000}},	//   gró_, _meet, _cóna,
  { {0x999f0045,0x6d55001c,0x86360149,0x00000000}},	//   _usuń_, _noza, _לאנג_,
  { {0x3fa60021,0xa06724dc,0xb17b00d1,0x00000000}},	//   مصرف, бара_, tsår,
  { {0xe1ff006d,0x63760ed9,0x7ae925c4,0x00000000}},	//   bró_, kšni, _neet,
  { {0x7bc0051e,0x9eaa000a,0xee3a0088,0x00000000}},	// [3c20] _rimu, уваа_, ына_,
  { {0x7bc0243f,0x8066005e,0xa3de0042,0x00000000}},	//   _simu, _гвож, दीक_,
  { {0x3a2d00f3,0x68e825c5,0xd5c8008b,0x00000000}},	//   _asep_, _redd, _nền_,
  { {0x8fc5007e,0x68e825c6,0x69c125c7,0x00000000}},	//   _گزین, _sedd, _aile,
  { {0x69c125c8,0x68e80168,0xa3e70042,0x00000000}},	//   _bile, _pedd, मीत_,
  { {0xdd9204de,0x313a0047,0xb17b00d1,0x00000000}},	//   _روز_, רײַב, nsåp,
  { {0x7bc006a7,0x69c125c9,0xe0d30047,0x00000000}},	//   _timu, _dile, לײג_,
  { {0x2d9a25ca,0x26df002c,0x68e804bf,0x00000000}},	//   lope_, gbuo_, _wedd,
  { {0x69c10e6c,0x68e825cb,0x09e31eaf,0x00000000}},	//   _file, _tedd, _нотн,
  { {0x26df00a4,0x94180002,0x8e570041,0x00000000}},	//   abuo_, ажот_, צייג_,
  { {0xebe6000d,0xe60f007e,0x7a1a008f,0x00000000}},	//   авiк_, وشی_, sātā,
  { {0x69c125cc,0xe1ff0885,0xf367080a,0x00000000}},	//   _zile, tró_, стон,
  { {0x36360021,0xe1ff0331,0x6d410014,0x00000000}},	//   _دراس, uró_, _ólag,
  { {0x69c101a8,0xd0d40094,0xe1ff25cd,0x00000000}},	//   _xile, зоръ, rró_,
  { {0x6d5525ce,0xe3c90013,0x7533004c,0x00000000}},	//   _roza, _hằn_, řezá,
  { {0x2e4b0062,0x6d5800a5,0x442e1806,0x00000000}},	//   лязо_, övan, _isf_,
  { {0x67d1001c,0x42dc0047,0xa2a00053,0x00000000}},	// [3c30] _māja, _עקזע, _गुप्,
  { {0x7ae90019,0x443c04c9,0x6600008f,0x00000000}},	//   _seet, _krv_, irmk,
  { {0x6b75000a,0x7ae90019,0x69c125cf,0x00000000}},	//   олжу, _peet, _rile,
  { {0x69c125d0,0x442e25d1,0xcf27005d,0x00000000}},	//   _sile, _msf_, _اردي,
  { {0x69c90c2e,0x7c2e021a,0x7ae925d2,0x00000000}},	//   _quee, _esbr, _veet,
  { {0x6376085a,0x7ae900ca,0xe1ff0022,0x00000000}},	//   ršni, _weet, szów_,
  { {0x69c125d3,0x7ae925d4,0x68f8004c,0x00000000}},	//   _vile, _teet, _řadá,
  { {0x3f890185,0xf7710067,0x23cf0053,0x00000000}},	//   nnau_, بات_, _संबद,
  { {0x645c0e5a,0x443c1a8a,0xf5050086,0x00000000}},	//   ørin, _arv_, озпо,
  { {0x7c2e001f,0xe57925d5,0x69c100ca,0x00000000}},	//   _ysbr, рзо_, _uile,
  { {0xdce50066,0xa34a0f55,0x2369003b,0x00000000}},	//   kohľ, азна_, _blaj_,
  { {0x96b9005e,0x7c3a017c,0x2bd00042,0x00000000}},	//   _кулу_, _štrk, _तूफा,
  { {0x442e004b,0xe796005d,0xd6e8009a,0x00000000}},	//   _esf_, _بالک, _הַצָ,
  { {0x6f1d0199,0x443c0026,0x3f890333,0x00000000}},	//   _absc, _frv_, enau_,
  { {0x3f89002b,0x659a009f,0x4f7a0121,0x00000000}},	//   fnau_, _דיסק, ащая_,
  { {0x20870086,0x6366017c,0xdee60044,0x00000000}},	//   ійти_, _ióno, تأسي,
  { {0x27e0017f,0xdb1b0139,0x2d9a25d6,0x00000000}},	// [3c40] ćini_, _ciuí, tope_,
  { {0x4c86005a,0x31a400ea,0xa157005e,0x00000000}},	//   олзв, közi_, _мању_,
  { {0x2d9a25d7,0xfc2a0121,0x7ac625d8,0x00000000}},	//   rope_, ржек_, осле,
  { {0x3e700164,0xeb9a0076,0x8cda0161,0x00000000}},	//   _côté_, шие_, _प्रो,
  { {0xbddb0994,0x094a25d9,0xee371b5e,0x00000000}},	//   _crèd, ички_, _дня_,
  { {0xe9770085,0xd7fa04ef,0x422b009a,0x00000000}},	//   обіш_, ауи_, שֵׁ֣,
  { {0xf66a0026,0xd90d007e,0x1867005e,0x00000000}},	//   kvæð_, ایم_, жаји_,
  { {0xc7ba0076,0x8b230856,0x2900003b,0x00000000}},	//   шёл_, _одсе, şia_,
  { {0x5986000a,0x27e9007d,0xc5260002,0x00000000}},	//   _длаб, ćana_, оќни,
  { {0x443c0024,0x7bde25da,0xe3c9008d,0x00000000}},	//   _prv_, oppu, _vằn_,
  { {0x3f890185,0x32020066,0x7ae225db,0x00000000}},	//   ynau_, erky_, obot,
  { {0xd37b25dc,0x67d10023,0x7bde0b49,0x00000000}},	//   рчо_, _kājn, ippu,
  { {0xb5fd0080,0xa773000d,0xd5c80013,0x00000000}},	//   uzšt, _ўліч, _kềm_,
  { {0x9f580290,0xd258000d,0x61f60078,0x00000000}},	//   errà_, іця_, _dvyl,
  { {0x7528034d,0xd5b8003d,0x645c0019,0x00000000}},	//   medz, mmā_, ärid,
  { {0xa8570063,0x75280051,0xa115007e,0x00000000}},	//   חילה_, ledz, _کودت,
  { {0x3f89001f,0x9f4a0046,0xd5b80023,0x00000000}},	// [3c50] rnau_, erbó_, omā_,
  { {0x8c670032,0xeca70001,0x752800ea,0x00000000}},	//   يطان, ојен, nedz,
  { {0x25690066,0x752825dd,0xbc4b000d,0x00000000}},	//   _júla_, iedz, шчае_,
  { {0x3b640062,0xb5fd004c,0x7de70085,0x00000000}},	//   мъчв, lyše, _мігд,
  { {0x7bde001c,0x442c002b,0xd94525de,0x00000000}},	//   appu, hwd_, зели,
  { {0x4bdb007e,0x6f0d25df,0xae5a0063,0x00000000}},	//   _نبرد_, lgac, _הכשר,
  { {0x6d470089,0xa3ae0053,0x6f0d25e0,0x00000000}},	//   _inja, कतम_, ogac,
  { {0x6f0d25e1,0xdb1c25e2,0x7ae201a8,0x00000000}},	//   ngac, _strö, cbot,
  { {0x79a700d7,0x6d471236,0x7afb0078,0x00000000}},	//   _држе, _knja, _idut,
  { {0xa5090001,0x6e200504,0x7c3a16fe,0x00000000}},	//   љена_, _ämbe, _štri,
  { {0x04451b79,0x6e2d2087,0x442c002b,0x00000000}},	//   ченн, hwab, gwd_,
  { {0x69db2181,0xeaa700f2,0xd6b6005d,0x00000000}},	//   _ktue, فع_, _کشمک,
  { {0x6b8b1324,0x442c002b,0xd36f0044,0x00000000}},	//   ingg, awd_, اهُ_,
  { {0xb227007a,0x763a0047,0xe20b0014,0x00000000}},	//   _svæð, _לענג, _stóð_,
  { {0x64a225e3,0x66090072,0x504304c3,0x00000000}},	//   _паша, luek, нерб,
  { {0x672900b9,0x10a30086,0x6d471d4c,0x00000000}},	//   neej, хисн, _anja,
  { {0x6729001c,0x26c200a2,0x644e004b,0x00000000}},	// [3c60] ieej, žkov_, äbiv,
  { {0x6b8b003e,0xdd920021,0x7afb25e4,0x00000000}},	//   engg, روض_, _adut,
  { {0xdd8f0032,0x6e2d25e5,0xe1ff00ea,0x00000000}},	//   دول_, awab, szót_,
  { {0xe3c9008b,0x7f4a0021,0x75280051,0x00000000}},	//   _nằm_, _الحق_, zedz,
  { {0x201825e6,0x7ae225e7,0x200a25e8,0x00000000}},	//   ltri_, rbot, lubi_,
  { {0x6b8b18a5,0xdb1523b6,0x69330086,0x00000000}},	//   angg, _buzó, еншу,
  { {0x201825e9,0x75280024,0xa7b825ea,0x00000000}},	//   ntri_, vedz, олку_,
  { {0x95d80055,0x20180ad5,0x75280051,0x00000000}},	//   одит_, itri_, wedz,
  { {0x7bce0397,0x3a3f25eb,0xe66625ec,0x00000000}},	//   _hubu, _grup_, ятко,
  { {0x7bce0373,0x200a08b3,0x2018078c,0x00000000}},	//   _kubu, kubi_, ktri_,
  { {0x7528003d,0x442c0122,0xd5b8001c,0x00000000}},	//   redz, uwd_, rmā_,
  { {0x98ac003d,0x442c001f,0xd5b8001c,0x00000000}},	//   _gadā_, rwd_, smā_,
  { {0x27e0017f,0x1634047e,0xcb130047,0x00000000}},	//   ćinu_, _целя, עלש_,
  { {0xdb090025,0x35b30454,0x290e25ed,0x00000000}},	//   _mheá, _збір, ngfa_,
  { {0x26c20024,0x443a008b,0x201800a4,0x00000000}},	//   ľkou_, _ép_, gtri_,
  { {0xee3f0080,0x3f5c0026,0x6b8205b3,0x00000000}},	//   _prý_, _síur_, jiog,
  { {0x6e2d00a4,0xc3340047,0xce940062,0x00000000}},	// [3c70] uwab, _נוץ_, еатъ,
  { {0x853c0006,0x7bce1fff,0x77a500ed,0x00000000}},	//   klėm, _bubu, róxi,
  { {0x394b008b,0x2d81005b,0x6b8b00a4,0x00000000}},	//   _đcs_, rihe_, tngg,
  { {0x6b8b017e,0x23cf0053,0xbddb006c,0x00000000}},	//   ungg, _संसद, _crèc,
  { {0xcf560063,0x7bdc25ee,0xf777005e,0x00000000}},	//   _חברת_, _etru, _ниjе_,
  { {0xdb090025,0xbddb01a8,0xdb1c002b,0x00000000}},	//   _dheá, _erèc, _strô,
  { {0xdb020110,0x999f00ea,0x238800ea,0x00000000}},	//   cloï, éről_, lője_,
  { {0xeafb007e,0x853c0006,0xbddb02a5,0x00000000}},	//   _درست_, slėl, _grèc,
  { {0x7bd2001c,0x61fb007d,0x391504ef,0x00000000}},	//   ējuš, šulj, _омар,
  { {0xdce700a8,0xb46525ef,0xe45100de,0x00000000}},	//   _oljč, дкол, نضج_,
  { {0x321900ac,0xe3c9008d,0x9cd6009a,0x00000000}},	//   etsy_, _tằm_, וותה_,
  { {0x798300a4,0x224025f0,0x6609004b,0x00000000}},	//   linw, _prik_, puek,
  { {0xf7700242,0x44230080,0x0caa0053,0x00000000}},	//   _حال_, ůj_, _कर्म,
  { {0xd5bb126b,0x201825f1,0xd4690caa,0x00000000}},	//   _усе_, ttri_, _миле_,
  { {0x7f5a000a,0x853c0078,0x10a3005e,0x00000000}},	//   ојат_, klėj, вирн,
  { {0x03950088,0x224025f2,0x7983004d,0x00000000}},	//   _прыя, _trik_, hinw,
  { {0x7bce1790,0x1da90053,0x7bdc25f3,0x00000000}},	// [3c80] _subu, कतंत, _stru,
  { {0x6b821780,0xfce3007b,0x4e19046e,0x00000000}},	//   wiog, вофо, яюся_,
  { {0xec7714b4,0x00000000,0x00000000,0x00000000}},	//   мпф_,   ,   ,
  { {0x61e90529,0x200501da,0xe46a004b,0x00000000}},	//   ţele, álie_, ltöö_,
  { {0xe46a004b,0x63b6002b,0x6b8225f4,0x00000000}},	//   otöö_, _mhyn, riog,
  { {0x6b8200eb,0x7c3a0024,0x7bce070e,0x00000000}},	//   siog, _štru, _tubu,
  { {0x7bdc25f5,0xa3ae0053,0x63a425f6,0x00000000}},	//   _utru, कता_, _okin,
  { {0xc6f825f7,0x963425f8,0x96ea0454,0x00000000}},	//   чних_, ениц, цька_,
  { {0x6d5c25f9,0x98a7004c,0x00000000,0x00000000}},	//   _kora, odně_,   ,
  { {0x63a400bb,0x6d5c00e3,0x6d580019,0x00000000}},	//   _akin, _jora, övah,
  { {0x7bda03b2,0x6d5c25fa,0x238800ea,0x00000000}},	//   _étud, _mora, zője_,
  { {0x63b6001f,0x69c60053,0x69c814ac,0x00000000}},	//   _chyn, ादकी, _hide,
  { {0x69c825fb,0xe2ab007e,0x5a9b0041,0x00000000}},	//   _kide, تادن_, ַשלא,
  { {0x6d5c25fc,0xe9ff0013,0x644e25fd,0x00000000}},	//   _nora, hiếc_, äbis,
  { {0x69c825fe,0xdcfe00a8,0x853c0078,0x00000000}},	//   _mide, gipč, ylėj,
  { {0x238800ea,0xc3fb0063,0x69c825ff,0x00000000}},	//   tője_, _ולהש, _lide,
  { {0x6d5c2600,0xd0d5005a,0xadb5000a,0x00000000}},	// [3c90] _bora, _попъ, ебаш,
  { {0x25690026,0x6d5c2601,0x2388013d,0x00000000}},	//   _núll_, _cora, rője_,
  { {0x23b200ea,0x2ca700b9,0x753800c2,0x00000000}},	//   lája_, ænd_, _mavz,
  { {0x69c804bc,0x61ed2602,0x6d5c0139,0x00000000}},	//   _aide, _kwal, _eora,
  { {0x6d5c2603,0x7e760051,0xaa580074,0x00000000}},	//   _fora, czyp, мицу_,
  { {0x61ed0009,0x6d5c2604,0x69c82322,0x00000000}},	//   _mwal, _gora, _cide,
  { {0x69c80b89,0x31580047,0x79830616,0x00000000}},	//   _dide, ויגן_, rinw,
  { {0x76420003,0x6d5c2605,0x23b2013d,0x00000000}},	//   _broy, _zora, kája_,
  { {0x63b60185,0x76421db7,0xd9ab0062,0x00000000}},	//   _rhyn, _croy, _дъжд_,
  { {0x69c8005b,0x63a42606,0xddcd0058,0x00000000}},	//   _gide, _skin, zyaş,
  { {0x98ac000c,0x23d5000d,0x61ed03d7,0x00000000}},	//   _vadă_, эцпр, _awal,
  { {0xd7c80021,0x69c80051,0x86750054,0x00000000}},	//   _قوله_, _zide, _плеє,
  { {0x7bc90164,0x998d00c2,0xc7b20063,0x00000000}},	//   _mieu, _mrež_, _עבד_,
  { {0x7bc914ff,0x61ed006f,0x63660331,0x00000000}},	//   _lieu, _dwal, _móni,
  { {0x6d5c2607,0x7f5d2608,0xf992009a,0x00000000}},	//   _rora, _bosq, טרך_,
  { {0xe29a011c,0x7bc92609,0xe46a0019,0x00000000}},	//   _най_, _nieu, stöö_,
  { {0x661b0e53,0x61ed0185,0xdd9204f6,0x00000000}},	// [3ca0] ntuk, _gwal, هور_,
  { {0xd29b014e,0x661b024a,0xa3b40053,0x00000000}},	//   _משפט, ituk, _जीत_,
  { {0x9b06000a,0x6d5c260a,0x2619008b,0x00000000}},	//   езед, _vora, hèo_,
  { {0x673b0045,0x69c8260b,0x7981001f,0x00000000}},	//   jduj, _side, _amlw,
  { {0x6d5c0027,0xd9d70086,0x7bc9260c,0x00000000}},	//   _tora, емії_, _dieu,
  { {0x61fb0460,0x9d460131,0x6443260d,0x00000000}},	//   áuli, _џевд, _orni,
  { {0x7dc90006,0x69c811a3,0xc7c60601,0x00000000}},	//   _užsa, _vide, нсии,
  { {0x7642260e,0x25720003,0xc7a30002,0x00000000}},	//   _proy, _mâle_, лијк,
  { {0x661b00eb,0x69c80666,0xadc3008b,0x00000000}},	//   gtuk, _tide, _hoạc,
  { {0x69c8102d,0x644301f0,0x673b260f,0x00000000}},	//   _uide, _brni, aduj,
  { {0x61ed077d,0x6443007d,0x661b2610,0x00000000}},	//   _swal, _crni, atuk,
  { {0xd497000d,0x67220c61,0x76422611,0x00000000}},	//   эры_, _uboj, _troy,
  { {0x61f80088,0xbddb0003,0x78a40058,0x00000000}},	//   нняў_, _arèn, şivd,
  { {0x25720003,0xe8ee02fe,0x23b2013d,0x00000000}},	//   _bâle_, алi_, rája_,
  { {0x395e0291,0xd3a72612,0x2d8f013d,0x00000000}},	//   _mots_, _прип, égem_,
  { {0x23b2088f,0x395e2613,0x34370044,0x00000000}},	//   pája_, _lots_, _أسود_,
  { {0x7bc90003,0x61ed0022,0xa3ae0042,0x00000000}},	// [3cb0] _rieu, _uwal, कतर_,
  { {0x7bc91276,0x1e340085,0x40950044,0x00000000}},	//   _sieu, ынуў, _للخر,
  { {0x7bc90003,0xb0c70e82,0x661b0022,0x00000000}},	//   _pieu, _ящик, ztuk,
  { {0xead80054,0x9056009a,0x00000000,0x00000000}},	//   емці_, _סברו_,   ,
  { {0x7bc92614,0x2396001c,0xe9d8000d,0x00000000}},	//   _vieu, nāja_, екі_,
  { {0x2d850244,0xb08b009a,0x0a48014b,0x00000000}},	//   _öle_, ּנֵ֖, эзій_,
  { {0xb7950001,0x9835000d,0x01380063,0x00000000}},	//   крић, тэлі, גרות_,
  { {0x394c2615,0xdb1c004c,0x63662616,0x00000000}},	//   _ends_, _kurý, _tóni,
  { {0x661b024a,0x1a5b0021,0x442708b3,0x00000000}},	//   utuk, _عشرة_, _spn_,
  { {0x661b2617,0x395e00cd,0x44270150,0x00000000}},	//   rtuk, _gots_, _ppn_,
  { {0x3d190235,0x661b0d9e,0x33d4000d,0x00000000}},	//   _पाने_, stuk, ліят,
  { {0x644300c3,0x23c50085,0x44272618,0x00000000}},	//   _vrni, лёўв, _vpn_,
  { {0xd2f20042,0x2396008f,0x26f80043,0x00000000}},	//   _अजीब_, gāja_, _سرنخ_,
  { {0x25720003,0x3ceb0053,0xb33b00be,0x00000000}},	//   _pâle_, टरों_, roça,
  { {0x64432619,0x66091a24,0x2b4d00a8,0x00000000}},	//   _urni, lrek, _onec_,
  { {0x2005261a,0x7bd800ea,0xd00f0242,0x00000000}},	//   ália_, ívum, تلف_,
  { {0x64411c40,0x91960092,0x6609261b,0x00000000}},	// [3cc0] lvli, _ајнш, nrek,
  { {0x6d8b003d,0x5bca0053,0x644104aa,0x00000000}},	//   kļau, िद्व, ovli,
  { {0xceea0086,0x395e09fe,0x6db6008f,0x00000000}},	//   _одне_, _rots_, _kņaz,
  { {0x6609261c,0x67d1008f,0x09e6261d,0x00000000}},	//   krek, _gāji, водн,
  { {0x395e0994,0x66090146,0x82d700b5,0x00000000}},	//   _pots_, jrek, דונג_,
  { {0x5e770063,0x39130086,0xc27b0063,0x00000000}},	//   _יתכן_, имір, ורני,
  { {0x395e00cd,0x6609261e,0x6d4e01e1,0x00000000}},	//   _vots_, erek, _inba,
  { {0xf0930132,0x6609261f,0x466a1dd1,0x00000000}},	//   ינו_, frek, дром_,
  { {0x395e0994,0x9a250021,0x63660046,0x00000000}},	//   _tots_, _معلن, _jónu,
  { {0x200a00c2,0xb5fd004c,0x23960023,0x00000000}},	//   krbi_, myšl, vāja_,
  { {0x5975000d,0x66092620,0x64410104,0x00000000}},	//   _сыту, arek, gvli,
  { {0x2396003d,0x66092621,0x9f580139,0x00000000}},	//   tāja_, brek, arrú_,
  { {0x2d8f000f,0x51872622,0x13940054,0x00000000}},	//   égek_, вува, рияю,
  { {0x68f8126f,0xdb1c1ab7,0xd8380260,0x00000000}},	//   navd, _kuró, _ksč_,
  { {0x84380021,0x50f4005a,0x656f0003,0x00000000}},	//   _أكبر_, рзст, êche,
  { {0x8afd0080,0x6ab20053,0x6d4e2623,0x00000000}},	//   _koře, _जरूर, _anba,
  { {0x27e9007d,0x98a7001c,0x28a90053,0x00000000}},	// [3cd0] ćani_, ienā_, _चुनि,
  { {0xdcb1001b,0x9be70086,0x2fc000c2,0x00000000}},	//   _ở_, відк, amig_,
  { {0x9f5802dd,0x3d9412a5,0x6acb0042,0x00000000}},	//   guró_, шифр, िश्र,
  { {0x6d4e00c7,0x66092624,0x3a752625,0x00000000}},	//   _enba, yrek, ллер,
  { {0x3f892626,0x2011017f,0x61fd0014,0x00000000}},	//   miau_, luzi_, nssl,
  { {0xdb1c0199,0x3f891148,0x6d8b001c,0x00000000}},	//   _zurü, liau_, tļau,
  { {0x20110009,0xb8db0053,0x23b2013d,0x00000000}},	//   nuzi_, _घर_, fájl_,
  { {0x3f890185,0x66092627,0x6fd60042,0x00000000}},	//   niau_, trek, _मंसू,
  { {0xdb1c18a8,0x7bd50058,0xd4f5082d,0x00000000}},	//   _euró, _huzu, ляны,
  { {0x20110009,0x7bd50035,0x3f89001f,0x00000000}},	//   kuzi_, _kuzu, hiau_,
  { {0x66092628,0xb17b00d1,0x7bd50089,0x00000000}},	//   srek, rpål, _juzu,
  { {0x36d50079,0x91e6157c,0x2011017d,0x00000000}},	//   _содр, ломе, duzi_,
  { {0x3f89001f,0x6441006f,0x660520fb,0x00000000}},	//   diau_, svli, _спла,
  { {0xe4e70086,0xb33b017d,0xbddb0003,0x00000000}},	//   _рідн, boço, _crèm,
  { {0x5f06011c,0x20110035,0x3f960002,0x00000000}},	//   лзва, guzi_, граѓ,
  { {0x3f892629,0x1eca0002,0x13a8005d,0x00000000}},	//   giau_, елби_, _جنبی_,
  { {0x2fc0262a,0x63a6013d,0x7bd500dd,0x00000000}},	// [3ce0] rmig_, mokn, _auzu,
  { {0xee37000d,0x25a500cd,0x7bd51c8a,0x00000000}},	//   ыну_, noll_, _buzu,
  { {0x711b00b5,0xbb460905,0x3f89262b,0x00000000}},	//   _אויפ, лежк, biau_,
  { {0x3f89001f,0x6366013d,0x25a5262c,0x00000000}},	//   ciau_, _tónu, holl_,
  { {0xc9860002,0x9f580331,0x98a7008f,0x00000000}},	//   луки, suró_, venā_,
  { {0x9f5801f4,0xaa47005e,0x6f16002b,0x00000000}},	//   curò_, упља_, lgyc,
  { {0x63a6262d,0x3d190053,0x3ea6008f,0x00000000}},	//   kokn, _पाते_, ļotu_,
  { {0x61e410b9,0x7c930021,0x61fd0137,0x00000000}},	//   _otil, _الفص, yssl,
  { {0x7bd500bd,0xc58a0062,0x6e36001f,0x00000000}},	//   _zuzu, ещне_, nwyb,
  { {0x20110035,0xbddb00cd,0xecb80053,0x00000000}},	//   yuzi_, _brèj, _अराफ,
  { {0x2d8f00ea,0x6355037c,0x7c29007d,0x00000000}},	//   égei_, авну, _ćerk,
  { {0xb33b017d,0x63a6013d,0x7bc2262e,0x00000000}},	//   roço, gokn, nmou,
  { {0xbddb00cd,0x3f890006,0x25a5262f,0x00000000}},	//   _prèm, viau_, boll_,
  { {0x3f89001f,0x61e9003b,0x7bc22630,0x00000000}},	//   wiau_, ţelo, hmou,
  { {0x3f89001f,0x6366006d,0x61e42631,0x00000000}},	//   tiau_, _cóns, _etil,
  { {0x7bc20080,0xd491008b,0x853c0078,0x00000000}},	//   jmou, oàn_, alėt,
  { {0x7bd514ef,0x3f891142,0x9e15000d,0x00000000}},	// [3cf0] _suzu, riau_, рдзі,
  { {0x3f890185,0x22492632,0x9e0800de,0x00000000}},	//   siau_, _irak_, ايلك_,
  { {0x3f890185,0xe1ff000f,0x7c350121,0x00000000}},	//   piau_, lsó_, реех,
  { {0x6d582633,0x305a0041,0xdb58030b,0x00000000}},	//   övar, _סדרד, люч_,
  { {0xe9ff001b,0xfaa5018e,0xe1ff006d,0x00000000}},	//   _trận_, јало, nsó_,
  { {0x7bc22634,0x63a6013d,0xdce800dd,0x00000000}},	//   amou, zokn, ălăr,
  { {0x25a52635,0xa3b50042,0xe7392636,0x00000000}},	//   voll_, झता_, вей_,
  { {0x2249007d,0x66e50699,0x16390021,0x00000000}},	//   _orak_, јопа, نسخة_,
  { {0x05550085,0x00000000,0x00000000,0x00000000}},	//   атня,   ,   ,
  { {0x2705001b,0x6b8b17d5,0xe6280021,0x00000000}},	//   ồn_, ligg, اثين_,
  { {0x22490089,0xf1c80080,0x61e42637,0x00000000}},	//   _arak_, ntář_, _stil,
  { {0x22492638,0x02c60456,0xd491008d,0x00000000}},	//   _brak_, ийно, bàn_,
  { {0x25a501a8,0x66cb0058,0x1307000d,0x00000000}},	//   poll_, _dökü, шняй_,
  { {0x69c30025,0x6455004d,0xa2c20053,0x00000000}},	//   nmne, äzis, रेष्,
  { {0x853c0006,0xe1ff006d,0x7d0000ea,0x00000000}},	//   alės, asó_, hárí,
  { {0x684019bc,0x3a2d16eb,0xe3b90058,0x00000000}},	//   ládá, _opep_, ltın_,
  { {0x7de50754,0x853c0006,0xdb1b008b,0x00000000}},	// [3d00] مسلم, plėt, _thuê,
  { {0x01fb00b5,0xf4290066,0x63660014,0x00000000}},	//   _שפיל, amäť_, _tóns,
  { {0xc059000d,0x6b8b01f4,0x22490392,0x00000000}},	//   _біў_, figg, _zrak_,
  { {0x69c32639,0xdbdf0026,0xd4910013,0x00000000}},	//   emne, _víðt, hào_,
  { {0x7bc2263a,0x79c6000d,0x3ea6008f,0x00000000}},	//   rmou, айдз, ļots_,
  { {0x99f5013c,0x645c01a9,0x7bc2263b,0x00000000}},	//   сяці, ärik, smou,
  { {0xa9670540,0x798a001f,0x31570047,0x00000000}},	//   рија_, rifw, ייסן_,
  { {0x69c31233,0xab5d0022,0xfb160043,0x00000000}},	//   amne, _biżu, _خورج,
  { {0x6563263c,0xba29013a,0xcb670854,0x00000000}},	//   _bonh, _مسلم_, _тате_,
  { {0x656303d9,0x65c3005e,0x66cb0075,0x00000000}},	//   _conh, обња, _sökü,
  { {0xe2f90086,0x656f006c,0x2cfb009d,0x00000000}},	//   лені_, êcha, כליא,
  { {0xe3b90058,0x22a3004c,0x26360022,0x00000000}},	//   atın_, _léků_, _tło_,
  { {0x52140065,0x363601fb,0xe57a263d,0x00000000}},	//   одят, _خراس, _изд_,
  { {0xd5af0086,0x3d100053,0x7c2e2314,0x00000000}},	//   _єс_, ालों_, _opbr,
  { {0x3f87000a,0x657a0027,0xe1ff032a,0x00000000}},	//   аѓаа, mhth, ssó_,
  { {0x853c00eb,0x442e0089,0x2fcf0014,0x00000000}},	//   plės, _ipf_, ögg_,
  { {0x63ad00a4,0x3eaf263e,0x539c0063,0x00000000}},	// [3d10] _ikan, ægt_, _שיחו,
  { {0x201e0268,0x5d540054,0xdcf9013a,0x00000000}},	//   àtic_, окут, افات_,
  { {0x9f352049,0x0dc81134,0x0ca80094,0x00000000}},	//   _лені, рути_, атци_,
  { {0x91a0001b,0xe4570047,0xe9a8005d,0x00000000}},	//   _trị_, ייבט_, یدون_,
  { {0xf2d400b5,0x98a70006,0xb5fd0006,0x00000000}},	//   קעס_, ieną_, ryšk,
  { {0x69c30529,0x6b8b0917,0x2731008b,0x00000000}},	//   umne, sigg, _ạn_,
  { {0x63ad00e8,0x256900ea,0x443c004b,0x00000000}},	//   _okan, _múlt_, _nsv_,
  { {0x6563263f,0xf7710021,0x69dc0a80,0x00000000}},	//   _sonh, ثات_, _črev,
  { {0x9f5e03b2,0x6563017d,0x443c001c,0x00000000}},	//   été_, _ponh, _asv_,
  { {0x660200b2,0x63ad2640,0xbddb01a8,0x00000000}},	//   _dvok, _akan, _crèi,
  { {0x443c2641,0xe3b90058,0x66022642,0x00000000}},	//   _csv_, rtın_, _evok,
  { {0xc169009a,0xa5f9030b,0xb7cb0044,0x00000000}},	//   _אח_, _беду_, _شباك_,
  { {0xc6a70001,0x657a0025,0x644a2643,0x00000000}},	//   _тржи, bhth, _erfi,
  { {0x657a20d3,0x1ddb0053,0xf6520063,0x00000000}},	//   chth, _बढ़त, _מצד_,
  { {0xe1f2007e,0x660200c2,0xdee60a36,0x00000000}},	//   _کسب_, _zvok, йови,
  { {0x439300e1,0x03a30062,0xaf790054,0x00000000}},	//   _најс, _нищо, асує_,
  { {0x0ef9000d,0xdcee008f,0x6d8b0022,0x00000000}},	// [3d20] рэсы_, _albā, rżan,
  { {0xcf890041,0x32022644,0x8db5012c,0x00000000}},	//   ײט_, msky_, осхі,
  { {0x61f6001f,0xab5d0051,0x6b9b0026,0x00000000}},	//   _hwyl, _niżs, _bjug,
  { {0x8afd0080,0xcb160032,0xeafa08aa,0x00000000}},	//   _pořa, إذاع, ارات_,
  { {0xaa58167b,0x298a0ae8,0x32022645,0x00000000}},	//   рилу_, лско_, nsky_,
  { {0x2d8f000f,0x7f440003,0x2b4000a2,0x00000000}},	//   éget_, ldiq, žic_,
  { {0xdc28001c,0x764b035a,0x7d0b0078,0x00000000}},	//   rķēt, _argy, ėgst,
  { {0x7f4418ce,0xab960021,0x9b960044,0x00000000}},	//   ndiq, _الرغ, _الرت,
  { {0xba56005a,0xda63065b,0x61f6002b,0x00000000}},	//   _утвъ, _евти, _nwyl,
  { {0x443c2646,0x6e2401a8,0x63ad2647,0x00000000}},	//   _psv_, itib, _skan,
  { {0xd7ea1001,0x764b001f,0x4d5b0047,0x00000000}},	//   _смее_, _ergy, אדיצ,
  { {0x6e24002c,0x4c9b2648,0x29f60051,0x00000000}},	//   ktib, רשטע, oła_,
  { {0x386e001f,0x442e0bcb,0xa5f8173e,0x00000000}},	//   lyfr_, _wpf_, _телу_,
  { {0x61f6001f,0x98a70006,0x443c2649,0x00000000}},	//   _dwyl, seną_, _tsv_,
  { {0x7dc900eb,0xc0580086,0x61f6002b,0x00000000}},	//   _užsi, біт_, _ewyl,
  { {0x7e6d005b,0x29f60051,0x4ea70699,0x00000000}},	//   tyap, kła_, брза,
  { {0x61f60185,0x6e2400a4,0x644f008f,0x00000000}},	// [3d30] _gwyl, gtib, ācie,
  { {0x29f60051,0x6b890078,0xd6d90022,0x00000000}},	//   dła_, _smeg, ydło_,
  { {0x29f60051,0x6f1d04d5,0x6abb0022,0x00000000}},	//   eła_, _tcsc, _szuf,
  { {0x291e264a,0xe3b90058,0x7bc00cb6,0x00000000}},	//   _acta_, ktım_, _chmu,
  { {0x2d8f000f,0x29f60051,0x78a4005b,0x00000000}},	//   éges_, gła_, şivl,
  { {0x1869005a,0x98be005b,0xbddb0003,0x00000000}},	//   иали_, _altı_, _brèv,
  { {0x29f60051,0x6d55264b,0x6b9b1310,0x00000000}},	//   ała_, _inza, _tjug,
  { {0x257b0003,0xef110063,0x060922c4,0x00000000}},	//   _mêle_, וּ֙_, аник_,
  { {0x2005007d,0x8c44003b,0x81c3008f,0x00000000}},	//   šlih_, ăşes, ķēji,
  { {0x7afb0199,0xa5090001,0x7c250139,0x00000000}},	//   _heut, јена_, othr,
  { {0x7afb0397,0xbddb0003,0xf9920063,0x00000000}},	//   _keut, _grèv, _קרב_,
  { {0x61f6001f,0x853c0006,0x7c25264c,0x00000000}},	//   _pwyl, slėp, ithr,
  { {0x6729264d,0x3204004a,0x7afb264e,0x00000000}},	//   mfej, émy_, _meut,
  { {0x7afb00bd,0x7c250178,0x32020bf6,0x00000000}},	//   _leut, kthr, rsky_,
  { {0x6d45264f,0x29f60051,0x69db004b,0x00000000}},	//   ddha, zła_, _luue,
  { {0x6d550199,0x29f60051,0x6e242650,0x00000000}},	//   _anza, yła_, ttib,
  { {0x69c10080,0x20d624ad,0x672900ea,0x00000000}},	// [3d40] _ohle, _мінс, ifej,
  { {0x22400004,0x8cb60459,0x6e242651,0x00000000}},	//   _isik_, осеч, rtib,
  { {0x7afb00bd,0xdd8f0021,0xdb0b017d,0x00000000}},	//   _beut, خول_, mogê,
  { {0x6d450035,0x2d8f0003,0x6e242652,0x00000000}},	//   adha, éger_, ptib,
  { {0x7afb0359,0x20182653,0x7c250025,0x00000000}},	//   _deut, luri_, athr,
  { {0xbddb0268,0x29f60051,0x672900ea,0x00000000}},	//   _prèv, rła_, efej,
  { {0x29f60045,0x307a0047,0x68fa00ac,0x00000000}},	//   sła_, יאַנ, _vetd,
  { {0x69c1004d,0x35f40121,0x2018003b,0x00000000}},	//   _ehle, ппир, iuri_,
  { {0x7bdc2654,0x44250051,0x65940be6,0x00000000}},	//   _huru, etl_, запу,
  { {0x20182655,0x7bdc2656,0x7c450014,0x00000000}},	//   kuri_, _kuru, _ótrú,
  { {0x7bdc2657,0x20182658,0x9cdb03c3,0x00000000}},	//   _juru, juri_, יקיפ,
  { {0x9f5100ea,0xd62a0184,0x201100c2,0x00000000}},	//   sszú_, _воде_, vrzi_,
  { {0xe298000d,0x7bdc017e,0x3a260075,0x00000000}},	//   жаў_, _luru, ntop_,
  { {0x7c252659,0x2018003b,0x291c265a,0x00000000}},	//   ythr, furi_, ngva_,
  { {0xe9ff008b,0x2018265b,0xdfdb0062,0x00000000}},	//   _trần_, guri_, ръг_,
  { {0x20030045,0xa2f50121,0x3a26265c,0x00000000}},	//   rsji_, _эпич, ktop_,
  { {0x7e600268,0x3f9e017d,0x0ec50053,0x00000000}},	// [3d50] _àmpl, étua_, लेंड,
  { {0x7bdc265d,0x2018265e,0x8234007e,0x00000000}},	//   _buru, buri_, _آريا,
  { {0x2018265f,0x7bdc2660,0xe7100078,0x00000000}},	//   curi_, _curu, dėžė,
  { {0x7bdc01f7,0x2396003d,0x69db0019,0x00000000}},	//   _duru, tāji_, _puue,
  { {0xbddb006c,0x0e080121,0x69c12661,0x00000000}},	//   _crèt, _мэри_, _phle,
  { {0x2b4600cd,0x4425004c,0x4dda0063,0x00000000}},	//   adoc_, ytl_, _לחשו,
  { {0xf7710021,0xdcfc007d,0x7bdc137d,0x00000000}},	//   فاة_, _smrć, _guru,
  { {0x309c0063,0x16060053,0x69db004b,0x00000000}},	//   ישומ, _शिखर_, _tuue,
  { {0x20182662,0x67292663,0xfb34014b,0x00000000}},	//   zuri_, rfej, _інфэ,
  { {0x672922bd,0x270c0078,0x76492664,0x00000000}},	//   sfej, vėnų_, rvey,
  { {0x2018003b,0x7d0a0014,0x7dc9005f,0x00000000}},	//   xuri_, ófsi, _užsu,
  { {0xddcd007d,0x98a50078,0x20182665,0x00000000}},	//   jzaž, _salė_, vuri_,
  { {0xdb1b008d,0x93bd00dd,0x98a7005f,0x00000000}},	//   _khuâ, ptăn, venę_,
  { {0x20182666,0x200c0827,0xc5f20041,0x00000000}},	//   turi_, ádio_, _טדד_,
  { {0x645c024a,0x39452667,0xdb0b00be,0x00000000}},	//   ärit, _mals_, rogê,
  { {0x2018000c,0xcf59071f,0xe0430121,0x00000000}},	//   ruri_, оруч_, энси,
  { {0x3f670001,0x20182668,0x7bdc06e1,0x00000000}},	// [3d60] чито_, suri_, _suru,
  { {0x20180529,0xf1bf2669,0xdca60f92,0x00000000}},	//   puri_, ltán_, пази,
  { {0xdb0b0146,0x50db0063,0x6bd601fb,0x00000000}},	//   ilgæ, _לחיצ, ستار,
  { {0xf1bf0025,0x8fa6000d,0x7bdc005b,0x00000000}},	//   ntán_, _хаме, _vuru,
  { {0xdb0b266a,0xade30053,0x3945006c,0x00000000}},	//   ulgá, _कूपन_, _bals_,
  { {0x7bdc266b,0x88bc0080,0xdb1b008b,0x00000000}},	//   _turu, _obět, _chuâ,
  { {0x3a26266c,0x07200053,0x58d302d8,0x00000000}},	//   stop_, _यादव_, ношт,
  { {0x4c9b0063,0xe3b9005b,0x780c0053,0x00000000}},	//   _הבלו, rtık_, _सटीक_,
  { {0xf6230138,0xc6f70475,0x59860141,0x00000000}},	//   едњо, чных_, _елаб,
  { {0x270c008b,0x3945266d,0x09690021,0x00000000}},	//   ớn_, _gals_, _وإلى_,
  { {0x201e01a8,0xb603008f,0x69ca0244,0x00000000}},	//   àtil_, ēšam, mmfe,
  { {0xa295000d,0x18770063,0x69ca266e,0x00000000}},	//   дамі, _מעבר_, lmfe,
  { {0xe9ff008b,0x95ca1225,0x6fd60042,0x00000000}},	//   _trấn_, _лука_, _मंजू,
  { {0xd6570063,0x645c266f,0x32190cb6,0x00000000}},	//   _מידת_, äris, rusy_,
  { {0xdb1b0025,0x753a004d,0x6d58008f,0x00000000}},	//   _shuí, metz, ķval,
  { {0xa857014e,0x753a00bd,0x987b0047,0x00000000}},	//   הילה_, letz, זאלט,
  { {0x2fc92670,0x9d55007e,0x63af2671,0x00000000}},	// [3d70] rmag_, وچست, mocn,
  { {0x61ed2672,0xcf27007e,0x753a004d,0x00000000}},	//   _ital, _کردي, netz,
  { {0xdb0b2673,0xd5b80023,0x8d740044,0x00000000}},	//   logé, ilā_, راكا,
  { {0x290c2674,0x394501a8,0x61e9003b,0x00000000}},	//   _adda_, _sals_, ţelu,
  { {0xd5b8003d,0x2bcc0053,0x394513be,0x00000000}},	//   klā_, ़ग़ा, _pals_,
  { {0xbddb0164,0x9967047e,0xeab00021,0x00000000}},	//   _frèr, ятел, دعم_,
  { {0x39452675,0x18660062,0xdb23003b,0x00000000}},	//   _vals_, дащи_, ărâm,
  { {0xe1ff00cd,0x85e90086,0x6d4722af,0x00000000}},	//   nyós_, одив_, _haja,
  { {0x39450268,0x6d472676,0xdb1b008b,0x00000000}},	//   _tals_, _kaja, _thuâ,
  { {0x6d47014f,0x49170053,0xd5b80023,0x00000000}},	//   _jaja, _नाटो_, glā_,
  { {0x6d472677,0x61ed2678,0xf87501fb,0x00000000}},	//   _maja, _atal, _تهاج,
  { {0x98a7004c,0xe705005d,0x189800de,0x00000000}},	//   zeně_, _آسای, _عضلة_,
  { {0x1c1f0053,0xc447007e,0x645c0072,0x00000000}},	//   मंडल_, زیکن_, ärir,
  { {0xdb0b01e3,0xf1bf2679,0x6d47267a,0x00000000}},	//   llgä, stán_, _naja,
  { {0x61ed267b,0xe5a202b3,0x2bd90053,0x00000000}},	//   _etal, _шиши, _बंगा,
  { {0x2396003d,0xe3b7005a,0xe29a267c,0x00000000}},	//   tāju_, _общ_, _май_,
  { {0x6d471a1f,0x2d930655,0x661b0072,0x00000000}},	// [3d80] _baja, fixe_, nuuk,
  { {0x7ae90016,0x6d47267d,0xb17b0137,0x00000000}},	//   _afet, _caja, spår,
  { {0x6d4708ea,0x200501da,0x515b0063,0x00000000}},	//   _daja, álit_, _וכיו,
  { {0x7d07000f,0xeb970541,0x661b0656,0x00000000}},	//   térí, мих_, kuuk,
  { {0x6d47267e,0x09e3267f,0x62862680,0x00000000}},	//   _faja, вочн, nzko,
  { {0x7ae903d9,0x6443017f,0x2738008b,0x00000000}},	//   _efet, _osni, _ẩn_,
  { {0x7ae901f4,0x8c430121,0xf1bf013d,0x00000000}},	//   _ffet, _иере, dtál_,
  { {0xf60a0121,0x8b950454,0x6d470ab3,0x00000000}},	//   охой_, _зруч, _zaja,
  { {0x6d470035,0x661b00a4,0xa9260a29,0x00000000}},	//   _yaja, guuk, _одал,
  { {0x628606ce,0xa5bd0078,0x61ed0058,0x00000000}},	//   dzko, ltųj, _rtal,
  { {0x443e006f,0x661b00a4,0x61ed2681,0x00000000}},	//   uwt_, auuk, _stal,
  { {0x753a0199,0x93bd000c,0xd5b8001c,0x00000000}},	//   setz, ptăm, slā_,
  { {0x6f042682,0x914b0062,0x6676014d,0x00000000}},	//   daic, очва_, _تدار,
  { {0xdb0b2673,0x76bb009a,0xb6bb009a,0x00000000}},	//   rogé, _ומדפ, _וצדי,
  { {0xdb0b01e3,0xd48f0086,0x4f6b0777,0x00000000}},	//   llgå, _рр_, ошам_,
  { {0xbed50002,0x4f94005e,0x6d470ce8,0x00000000}},	//   еобј, врђу, _saja,
  { {0x6d472683,0x5d550189,0x62860051,0x00000000}},	// [3d90] _paja, нкат, czko,
  { {0x2005000f,0x71750021,0xc05b0086,0x00000000}},	//   ális_, _أهدا, _дім_,
  { {0x6d472684,0x5b15071a,0xe5210042,0x00000000}},	//   _vaja, емет, _मासि_,
  { {0x4fc70088,0x6d470397,0x6f042264,0x00000000}},	//   _існа, _waja, caic,
  { {0x6366006d,0x6d47027b,0x3df40330,0x00000000}},	//   _cóny, _taja, _изяс,
  { {0x7d0a0026,0xda780121,0x661b0072,0x00000000}},	//   ófst, ьях_, vuuk,
  { {0x88bc004c,0xb8040044,0x8804043e,0x00000000}},	//   _sběr, نبيه, نظيم,
  { {0x8bc4000d,0x3eb9000e,0x7d050058,0x00000000}},	//   _асуд, _kyst_, lahs,
  { {0x9f51000f,0x673b00cd,0x4a5502fe,0x00000000}},	//   lszó_, reuj, _якас,
  { {0x44650002,0x661b01cf,0x6f042685,0x00000000}},	//   евов, ruuk, zaic,
  { {0x661b00fe,0x5fdb0053,0xf1bf18a8,0x00000000}},	//   suuk, _मंगल, rtál_,
  { {0xf1bf2686,0x62860206,0x644300a5,0x00000000}},	//   stál_, tzko, _vsni,
  { {0xe2920021,0xf1bf013d,0x555914db,0x00000000}},	//   اذج_, ptál_, _надя_,
  { {0x2396003d,0x3d190042,0x6609004e,0x00000000}},	//   tājs_, दलों_, msek,
  { {0xe4e40086,0x98be000c,0xa06a2687,0x00000000}},	//   _річн, _iată_, чава_,
  { {0x22520146,0x3eb92688,0x42260f59,0x00000000}},	//   _tryk_, _byst_, _здив,
  { {0x539b014e,0x2fd9001f,0x66092689,0x00000000}},	// [3da0] _מיקו, _disg_, nsek,
  { {0x3eb9002b,0x6609268a,0x6f04268b,0x00000000}},	//   _dyst_, isek, saic,
  { {0x60260088,0x6b82268c,0x2b58005d,0x00000000}},	//   _ядна, thog, ویسد_,
  { {0xe29f0026,0x60c10058,0xc05300ff,0x00000000}},	//   laða_, ülme, _עזר_,
  { {0x6b820122,0x63a40035,0x7d050089,0x00000000}},	//   rhog, _mjin, bahs,
  { {0xe29f0014,0x6609268d,0xe894268e,0x00000000}},	//   naða_, dsek, каль,
  { {0xdca6005e,0x6d5c0137,0x6da30263,0x00000000}},	//   _чави, _inra, _сира,
  { {0x17540ac5,0x9634268f,0xe6662530,0x00000000}},	//   твия, вниц, етоо,
  { {0x98be003b,0xe29f0014,0x6609081d,0x00000000}},	//   _bată_, kaða_, gsek,
  { {0xa4d4071f,0x5574030b,0x363304a0,0x00000000}},	//   копі, тгот, اريس,
  { {0x98be0529,0x3861004d,0xd49a2303,0x00000000}},	//   _dată_, ährt_, яри_,
  { {0x69da2690,0x66090150,0xc6a60002,0x00000000}},	//   _hite, bsek, _прли,
  { {0x69da1037,0x98be003b,0x2fd9001f,0x00000000}},	//   _kite, _fată_, _risg_,
  { {0xe29f0014,0x6594014b,0x865b009a,0x00000000}},	//   gaða_, _шалу, _מדדי,
  { {0x69da2691,0xf1bf00ea,0x5f950002,0x00000000}},	//   _mite, lták_, вивт,
  { {0xddd60022,0x6d5c0244,0x69da2692,0x00000000}},	//   czyź, _anra, _lite,
  { {0x69da017d,0xf1bf013d,0xa3e40042,0x00000000}},	// [3db0] _oite, nták_, _भूत_,
  { {0x63bd00c7,0x69da2693,0x2fd9002b,0x00000000}},	//   llsn, _nite, _wisg_,
  { {0x7d050089,0x61d60063,0x320b0051,0x00000000}},	//   rahs, _שותף_, lscy_,
  { {0x3f670055,0x3b64005a,0x7d0a0014,0x00000000}},	//   _чтоб, лъчв, ófsr,
  { {0x9f51000f,0xaa450076,0x69da2694,0x00000000}},	//   sszó_, телл, _bite,
  { {0xf1bf00ea,0x6609004b,0x69da2695,0x00000000}},	//   dták_, vsek, _cite,
  { {0xdb0b048e,0x69da2696,0xa966005a,0x00000000}},	//   logí, _dite, тища_,
  { {0x66091b35,0x69da071c,0x257b00be,0x00000000}},	//   tsek, _eite, _pêlo_,
  { {0x6e2d0d6c,0x66090072,0x320b0022,0x00000000}},	//   ntab, usek, jscy_,
  { {0x63a400e8,0x66092697,0x13e90076,0x00000000}},	//   _sjin, rsek, ммой_,
  { {0xe29f0026,0xd6ab007e,0x29072698,0x00000000}},	//   vaða_, _کدام_, mana_,
  { {0x6e2d2699,0xb8f40053,0x69da01f4,0x00000000}},	//   ktab, से_, _zite,
  { {0x69c8024a,0x43930088,0xe29f0026,0x00000000}},	//   _yhde, раўс, taða_,
  { {0x2907077d,0x6e2d1ec5,0x657a269a,0x00000000}},	//   nana_, dtab, ckth,
  { {0x2907269b,0xe29f0014,0x25b60021,0x00000000}},	//   iana_, raða_, _جهود_,
  { {0x7e76024a,0x63a40035,0x7bc9002b,0x00000000}},	//   tyyp, _ujin, _nheu,
  { {0x2907269c,0xdb0b0331,0x7981002b,0x00000000}},	// [3dc0] kana_, gogí, _ollw,
  { {0xed5a0054,0x29071509,0xf0ba005d,0x00000000}},	//   ьоз_, jana_, _يادش_,
  { {0x6e2d269d,0x69da269e,0xcb6a0001,0x00000000}},	//   atab, _rite, маже_,
  { {0x79810185,0xe3b90058,0x69da269f,0x00000000}},	//   _allw, ltır_, _site,
  { {0xdb15000f,0x61e40164,0xdb0b0331,0x00000000}},	//   óbál, _juil, cogí,
  { {0x644f0418,0x9166008b,0x290726a0,0x00000000}},	//   ācij, _bổ_, gana_,
  { {0x26c000eb,0xf803000d,0x98a50006,0x00000000}},	//   _šio_, ачын, _dalį_,
  { {0x78ba0512,0xf1bf000f,0xc7c60092,0x00000000}},	//   _vytv, tták_, њски,
  { {0xe3b901f7,0x09e606bc,0x29071e17,0x00000000}},	//   ktır_, _розн, bana_,
  { {0x69da03a8,0x290726a1,0x63bd00ca,0x00000000}},	//   _uite, cana_, wlsn,
  { {0xf1bf00ea,0x9d1b0149,0x443800c6,0x00000000}},	//   sták_, וויט, ïr_,
  { {0x61e40034,0xc884005b,0xf1bf013d,0x00000000}},	//   _buil, ışı_, pták_,
  { {0x645e0080,0x98be091b,0x61e40153,0x00000000}},	//   _špid, _datą_, _cuil,
  { {0x3f820072,0x320b0022,0xe8ee0083,0x00000000}},	//   _alku_, rscy_, блi_,
  { {0xb33b0016,0x394c000e,0x73e30002,0x00000000}},	//   ança, _mads_, _којз,
  { {0x61e40139,0x290726a2,0xe3b90058,0x00000000}},	//   _fuil, zana_, atır_,
  { {0xdfd8011c,0x7bc926a3,0x61e410c5,0x00000000}},	// [3dd0] тър_, _rheu, _guil,
  { {0xbbcb0053,0xdce7001c,0x6e2d26a4,0x00000000}},	//   िष्क, _bojā, rtab,
  { {0x61e4006f,0x6e2d26a5,0x290726a6,0x00000000}},	//   _zuil, stab, vana_,
  { {0x2613016a,0x90560063,0x99860051,0x00000000}},	//   _दिली_, _עברו_, proś_,
  { {0xee870076,0x9166008b,0x29070ba1,0x00000000}},	//   _рыно, _sổ_, tana_,
  { {0x9aa40021,0xa9240086,0xaa560021,0x00000000}},	//   جمهو, иділ, الوا_,
  { {0x0138014e,0x290726a7,0xdd94000d,0x00000000}},	//   דרות_, rana_, _тары,
  { {0x394c26a8,0x290726a9,0x2249004e,0x00000000}},	//   _eads_, sana_, _osak_,
  { {0x290726aa,0xff5f002b,0x959925a6,0x00000000}},	//   pana_, _nhîm_, етну_,
  { {0x9166008b,0x61e4056f,0x394c001c,0x00000000}},	//   _tổ_, _ruil, _gads_,
  { {0x61e40139,0x29050023,0xa3c20042,0x00000000}},	//   _suil, _iela_, ्गल_,
  { {0x290526ab,0x8c1a0063,0x6386005e,0x00000000}},	//   _hela_, עורי, угма,
  { {0x2249000f,0x61e4196e,0x2d8326ac,0x00000000}},	//   _csak_, _quil, _olje_,
  { {0x869a0047,0x61e426ad,0x9584000d,0x00000000}},	//   _אינז, _vuil, _кліе,
  { {0xa5da0047,0x290526ae,0x7534013d,0x00000000}},	//   _אַהי, _mela_, égző,
  { {0x661b017f,0x61e40d23,0x8afd0080,0x00000000}},	//   oruk, _tuil, _mořs,
  { {0x733b00b5,0x1fa7114d,0xbc6a005d,0x00000000}},	// [3de0] _טעקס, укти_, کمان_,
  { {0x2905017d,0xa3e70042,0x5bdc0042,0x00000000}},	//   _nela_, _बढा_, यद्व,
  { {0x2d8300c3,0x8236005d,0x9f4e013d,0x00000000}},	//   _dlje_, _شرکا, ínók_,
  { {0x501b014e,0x7dc20024,0xa09b0047,0x00000000}},	//   _אוטו, pôso, _טייט,
  { {0x2fc006a3,0x8e760856,0x290526af,0x00000000}},	//   mlig_, _сунч, _bela_,
  { {0x290503b2,0xfce30b0f,0x661b26b0,0x00000000}},	//   _cela_, _горо, druk,
  { {0x17f70032,0x290526b1,0x8cd30042,0x00000000}},	//   هرية_, _dela_, भेदो,
  { {0x6d4e26b2,0x2fc01781,0x2d9a26b3,0x00000000}},	//   _haba, nlig_, lipe_,
  { {0x6d4e18ab,0x29050026,0x2fc026b4,0x00000000}},	//   _kaba, _fela_, ilig_,
  { {0x16370032,0x6d4e014f,0x29050d2e,0x00000000}},	//   اسية_, _jaba, _gela_,
  { {0x6d4e26b5,0xc445007e,0xcdb70063,0x00000000}},	//   _maba, لیون_, רפיה_,
  { {0x2d9a003b,0x661b26b6,0x2fc00838,0x00000000}},	//   hipe_, bruk, jlig_,
  { {0x2fc01781,0x518726b7,0x228426b8,0x00000000}},	//   dlig_, гува, бург,
  { {0x22490198,0x6d4e1fe9,0xa4d401dd,0x00000000}},	//   _vsak_, _naba, _колі,
  { {0x54330021,0x2fc0002b,0xc977009a,0x00000000}},	//   _هرير, flig_, נגלי_,
  { {0xc275000a,0x6d4e002c,0x8d77007e,0x00000000}},	//   _влиј, _aaba, گارا,
  { {0x6d4e26b9,0x443c26ba,0xdbe30139,0x00000000}},	// [3df0] _baba, _hpv_, déán,
  { {0x6d4e26bb,0x443c004b,0x8d770049,0x00000000}},	//   _caba, _kpv_, دارا,
  { {0x6d4e00eb,0x2905014f,0xa2d90042,0x00000000}},	//   _daba, _rela_, _नृत्,
  { {0xdb35005e,0x443c09e9,0x290526bc,0x00000000}},	//   редњ, _mpv_, _sela_,
  { {0x290503d9,0xb4c20053,0xaa58173e,0x00000000}},	//   _pela_, ्धु_, лицу_,
  { {0x2d9a26bd,0x3f8926be,0xc27c0047,0x00000000}},	//   cipe_, lhau_, ערגי,
  { {0xc9840001,0xa3e40053,0x29050419,0x00000000}},	//   ључи, _भूल_, _vela_,
  { {0x3f89001f,0x7f4f26bf,0x6d4e26c0,0x00000000}},	//   nhau_, _jacq, _zaba,
  { {0x64581e29,0x3f89001f,0x290526c1,0x00000000}},	//   _arvi, ihau_, _tela_,
  { {0xe5760121,0x661b26c2,0x7f4f0168,0x00000000}},	//   изы_, rruk, _lacq,
  { {0x2fc02271,0x2fd2002b,0x7d0701ff,0x00000000}},	//   ylig_, ymyg_, _mejs,
  { {0xe72e01aa,0x7f4f051e,0xf6d50085,0x00000000}},	//   _ќе_, _nacq, _кіля,
  { {0x3f89001f,0x2fc00666,0xa5f8005e,0x00000000}},	//   dhau_, vlig_, _бечу_,
  { {0x7d070080,0x644a0072,0x6f0626c3,0x00000000}},	//   _nejs, ämiä, _sekc,
  { {0x6fb601a7,0x2fc01781,0x443c006f,0x00000000}},	//   لمسا, tlig_, _gpv_,
  { {0x6d4e058c,0x2fc0069f,0x439300e1,0x00000000}},	//   _saba, ulig_, _мајс,
  { {0x6d4e26c4,0x93bd000c,0x2fc00386,0x00000000}},	// [3e00] _paba, rtăt, rlig_,
  { {0x4d630086,0x645e1358,0x2fc00807,0x00000000}},	//   окув, _ápic, slig_,
  { {0x6d4e0004,0x7d070008,0x93bd003b,0x00000000}},	//   _vaba, _dejs, ptăt,
  { {0xfbc30c07,0x93bd003b,0x6d4e26c5,0x00000000}},	//   обхо, ltăr, _waba,
  { {0xfce60086,0x7ae4004a,0x93bd003b,0x00000000}},	//   _вого, žito, otăr,
  { {0xf1bf0024,0x93bd000c,0x7d0726c6,0x00000000}},	//   stáv_, ntăr, _gejs,
  { {0x7659001f,0x31570047,0x3f800078,0x00000000}},	//   _arwy, שיצן_, okiu_,
  { {0x7659001f,0x3f800006,0x7dcb004d,0x00000000}},	//   _brwy, nkiu_, rüse,
  { {0xd0fb0161,0x7bc20080,0x7659001f,0x00000000}},	//   ्रमण_, mlou, _crwy,
  { {0x645802e2,0x7659001f,0x96b7005e,0x00000000}},	//   _prvi, _drwy, јућу_,
  { {0x2ec30161,0x765900e8,0x764b002b,0x00000000}},	//   _शर्त, _erwy, _esgy,
  { {0xb8f9016a,0x93bd000c,0x7659001f,0x00000000}},	//   ठे_, etăr, _frwy,
  { {0x7659001f,0xdd21011b,0x7f4f26c7,0x00000000}},	//   _grwy, _růži, _racq,
  { {0x7bc2004c,0x63a626c8,0xa63b009a,0x00000000}},	//   hlou, ankn, _סגור,
  { {0x3f890185,0x7d0726c9,0xb4930001,0x00000000}},	//   thau_, _rejs, _мишљ,
  { {0x93bd15ff,0x764b002b,0x7659002b,0x00000000}},	//   drăg, _ysgy, _yrwy,
  { {0x3f890185,0x3e07005a,0x7bc20080,0x00000000}},	// [3e10] rhau_, рябв, dlou,
  { {0x93bd000c,0x213a0150,0x9e140054,0x00000000}},	//   ctăr, _gbph_, ідхі,
  { {0x7055006a,0x2dd80021,0x7f4f01f4,0x00000000}},	//   _انجا, شبكة_, _tacq,
  { {0x8b940086,0x7bc20003,0x6e241fb2,0x00000000}},	//   оріч, glou, buib,
  { {0x2d8f0164,0x7f3a0047,0x0a6b0062,0x00000000}},	//   èges_, _גערו, ържи_,
  { {0x5d850032,0x7bc226ca,0xecf80085,0x00000000}},	//   _السل, alou, _верш_,
  { {0xf1bf000f,0x7bc226cb,0x6d4526cc,0x00000000}},	//   ltás_, blou, meha,
  { {0x7bc20994,0x6d45157b,0x3f99008d,0x00000000}},	//   clou, leha, _jmsu_,
  { {0xf1bf000f,0x99860249,0x28f90085,0x00000000}},	//   ntás_, stoš_, _безь_,
  { {0x2717001b,0xc9740021,0x6d4526cd,0x00000000}},	//   ển_, _والث, neha,
  { {0x61f626ce,0x04450499,0x321e0022,0x00000000}},	//   _styl, щенн, ątym_,
  { {0x7659001f,0x03a60ac5,0x69c326cf,0x00000000}},	//   _trwy, симо, llne,
  { {0xf668006a,0xd29a0086,0xd2990054,0x00000000}},	//   _نحوه_, утні_, атрі_,
  { {0xdb0b0137,0x67291548,0x7bc2004c,0x00000000}},	//   logä, lgej, zlou,
  { {0x656326d0,0x764900ac,0x6d4526d1,0x00000000}},	//   _innh, lwey, deha,
  { {0x44250529,0x6729053b,0x93bd156e,0x00000000}},	//   mul_, ngej, stăr,
  { {0x44250529,0x93bd003b,0xf1bf013d,0x00000000}},	// [3e20] lul_, ptăr, ttát_,
  { {0x7c2526d2,0x6d4526d3,0x69c3013d,0x00000000}},	//   fuhr, geha, jlne,
  { {0x98a700eb,0x442526d4,0x8c950086,0x00000000}},	//   menė_, nul_, орці,
  { {0x4425000c,0x9166008b,0xf1bf1954,0x00000000}},	//   iul_, _hồ_, stát_,
  { {0x44250004,0x6d4526d5,0x6e241bae,0x00000000}},	//   hul_, beha, quib,
  { {0x44250dbb,0x7bc226d6,0x6d4526d7,0x00000000}},	//   kul_, slou, ceha,
  { {0x6c860032,0xa9670fe2,0x442526d8,0x00000000}},	//   _الأم, сија_, jul_,
  { {0xf1bf1d6b,0x6563001f,0x442526d9,0x00000000}},	//   ntár_, _annh, dul_,
  { {0xceb30063,0x35f7007e,0x44250a2c,0x00000000}},	//   ּית_, یرید_, eul_,
  { {0x442526da,0x454a0a72,0x6729004e,0x00000000}},	//   ful_, учим_, agej,
  { {0x442526db,0x7aed1235,0xb6e60062,0x00000000}},	//   gul_, žate, _люлк,
  { {0x29c9006d,0xe29f0026,0x290e0035,0x00000000}},	//   núan_, laði_, lafa_,
  { {0x91660013,0x10e7005d,0x442526dc,0x00000000}},	//   _bồ_, یژگی_, aul_,
  { {0xe29f007a,0x3d220053,0x442526dd,0x00000000}},	//   naði_, मलों_, bul_,
  { {0x442526de,0x6d4526df,0x93bd003b,0x00000000}},	//   cul_, veha, trăd,
  { {0x53a402a9,0x290e26e0,0x7ae400c2,0x00000000}},	//   _најб, hafa_, žitj,
  { {0x5d99000d,0x6b820019,0xf1ab007e,0x00000000}},	// [3e30] акаў_, dkog, _ماده_,
  { {0x2d870024,0xd7f8003b,0xf1bf00ea,0x00000000}},	//   óne_, _otă_, rtás_,
  { {0x6d4526e1,0xf1bf006d,0x0af90044,0x00000000}},	//   reha, stás_, لفاظ_,
  { {0x6d4526e2,0x53c90053,0x23c90053,0x00000000}},	//   seha, रतिश, रतिद,
  { {0x2bb10045,0x398b02ab,0x442526e3,0x00000000}},	//   jące_, _løse_, zul_,
  { {0x61fd00ac,0xb4e70053,0x2bb10022,0x00000000}},	//   ipsl, _भले_, dące_,
  { {0x4425000c,0xb17c0063,0xa3e40042,0x00000000}},	//   xul_, רטור, _भंग_,
  { {0xcb34005a,0x442526e4,0x63ad02ae,0x00000000}},	//   _несъ, vul_, _njan,
  { {0x69c30024,0x1bd40076,0x85e90002,0x00000000}},	//   plne, _хотя, јдов_,
  { {0x442526e5,0xf1bf26e6,0x63ad26e7,0x00000000}},	//   tul_, ztár_, _ajan,
  { {0x93460121,0x394726e8,0x61fd00ca,0x00000000}},	//   онне, mens_, epsl,
  { {0x44250469,0x394706a3,0xc16907e9,0x00000000}},	//   rul_, lens_, _בח_,
  { {0x5156000a,0x442526e9,0x9965004c,0x00000000}},	//   отву, sul_, _můžu_,
  { {0x44250529,0x6b891e32,0x9166008b,0x00000000}},	//   pul_, _lleg, _bố_,
  { {0xd00a0001,0x9166008b,0x6b8926ea,0x00000000}},	//   ребе_, _cố_, _oleg,
  { {0x82a60086,0xdf4a005e,0x394726eb,0x00000000}},	//   _майж, јзад_, hens_,
  { {0x8fa3000a,0x1dc50053,0x39470112,0x00000000}},	// [3e40] фате, वतंत, kens_,
  { {0x6b8926ec,0x5046005e,0x394710ed,0x00000000}},	//   _aleg, _деоб, jens_,
  { {0x29c9006d,0x39470386,0xf1bf00ea,0x00000000}},	//   túan_, dens_, ptár_,
  { {0x394710da,0xda7a030b,0x00000000,0x00000000}},	//   eens_, иял_,   ,
  { {0xe29f0026,0xd7f8003b,0xc9f30021,0x00000000}},	//   taði_, _stă_, وسوع,
  { {0x394726ed,0x6b892591,0x4a530086,0x00000000}},	//   gens_, _eleg, ькіс,
  { {0x290e007a,0xe29f0026,0x58d30002,0x00000000}},	//   rafa_, raði_, мошт,
  { {0xc6f80054,0xe29f0046,0x645e01d1,0x00000000}},	//   щних_, saði_, _špio,
  { {0x056a018e,0x394726ee,0x853c0078,0x00000000}},	//   ајни_, bens_, snėm,
  { {0x63ad26ef,0x394726f0,0x6e360078,0x00000000}},	//   _sjan, cens_, ityb,
  { {0x69d8004d,0xa3e40042,0x13f40766,0x00000000}},	//   mmve, _भूख_, язня,
  { {0x27f30024,0x661d13ed,0x21ef004b,0x00000000}},	//   žané_, šska, _püh_,
  { {0x9166001b,0x753d000f,0x290c0019,0x00000000}},	//   _số_, ősza, _keda_,
  { {0x8673012c,0x00000000,0x00000000,0x00000000}},	//   _юліє,   ,   ,
  { {0xcf9b257e,0xdfd5093e,0x290c0b57,0x00000000}},	//   аја_, зовы, _meda_,
  { {0x39470706,0x5215018e,0x63ad0089,0x00000000}},	//   zens_, _едит, _ujan,
  { {0x39470164,0x63bd006d,0x645a073a,0x00000000}},	// [3e50] yens_, mosn, lvti,
  { {0x6b8926f1,0x9166008b,0x93bd003b,0x00000000}},	//   _sleg, _tố_, brăc,
  { {0x394726f2,0xc0580086,0x6b8926f3,0x00000000}},	//   vens_, _дія_, _pleg,
  { {0x2d8a26f4,0x394700e8,0x61ed166a,0x00000000}},	//   _elbe_, wens_, _kual,
  { {0x290c00f3,0x61ed0397,0x645e007d,0x00000000}},	//   _beda_, _jual, _špil,
  { {0x61ed14d1,0x3947083f,0xdcee003b,0x00000000}},	//   _mual, uens_, ădăc,
  { {0x764202dd,0x9166001b,0x98a7001c,0x00000000}},	//   _apoy, _hỗ_, menī_,
  { {0x6b890051,0x69d80acd,0x394726f5,0x00000000}},	//   _uleg, amve, sens_,
  { {0xd7060076,0x8f9c0047,0x6d5526f6,0x00000000}},	//   чные_, ייהי, _kaza,
  { {0xb998014c,0xe29f0026,0xdce70051,0x00000000}},	//   _двух_, naðu_, _poję,
  { {0x32090034,0x657c0137,0xa2d90053,0x00000000}},	//   _away_, örha, नेस्,
  { {0x61ed0089,0x6d5526f7,0x61b40042,0x00000000}},	//   _bual, _laza, ंक्ष,
  { {0x61ed048e,0xe29f0026,0x9166008b,0x00000000}},	//   _cual, kaðu_, _nỗ_,
  { {0x6d551c6b,0xa6e10026,0x321e004a,0x00000000}},	//   _naza, öðug, čty_,
  { {0x63bd0035,0xe1ff01a8,0xd0590054,0x00000000}},	//   bosn, apó_, орті_,
  { {0x7ae40024,0x73060076,0x7ae90150,0x00000000}},	//   žiti, _эпиз, _nget,
  { {0xe29f0026,0x69c126f8,0x6d5526f9,0x00000000}},	// [3e60] faðu_, _okle, _baza,
  { {0xe29f007a,0x6d551876,0x6e360078,0x00000000}},	//   gaðu_, _caza, rtyb,
  { {0x717b0063,0x6e360006,0x290c26fa,0x00000000}},	//   _הניס, styb, _reda_,
  { {0x290c0004,0x261c0161,0x7d01003b,0x00000000}},	//   _seda_, _मिली_, _pârâ,
  { {0x6d670027,0x6f041aae,0x8e56000d,0x00000000}},	//   áraí, mbic, _этні,
  { {0x644302b0,0x6d5526fb,0x7c2800a5,0x00000000}},	//   _opni, _gaza, _ådro,
  { {0x8c4326fc,0xd90d007e,0xdb1b0025,0x00000000}},	//   _пере, شین_, _chuó,
  { {0x69c101f7,0x7d0100dd,0x6d5526fd,0x00000000}},	//   _ekle, _târâ, _zaza,
  { {0x6d5501f7,0x290c1aec,0x63bd007d,0x00000000}},	//   _yaza, _teda_, vosn,
  { {0x61eb0164,0x1dbe0053,0x290c26fe,0x00000000}},	//   _égli, ्तित, _ueda_,
  { {0x61ed0025,0x61e50024,0x3633007e,0x00000000}},	//   _sual, _rihl, وریس,
  { {0x60c5024a,0x95820051,0x6e2426ff,0x00000000}},	//   _ryhm, _żąda, krib,
  { {0xe298000d,0x61ed053f,0x7d1c00c2,0x00000000}},	//   заў_, _qual, _odrs,
  { {0xbddb00cd,0x7d0e004d,0xfe7f002b,0x00000000}},	//   _apèn, _nebs, _sgïo_,
  { {0x63bd00c3,0x6d552700,0x6e242701,0x00000000}},	//   posn, _raza, erib,
  { {0xb33b017d,0x61ed2702,0x4fc40bf5,0x00000000}},	//   biça, _tual, есуа,
  { {0xe29f007a,0x2bb10051,0x6d552703,0x00000000}},	// [3e70] taðu_, jąca_, _paza,
  { {0x27e62704,0x7ae9002b,0x2bb10022,0x00000000}},	//   _lion_, _sget, dąca_,
  { {0xe29f0026,0x6e242705,0x645e007d,0x00000000}},	//   raðu_, arib, _špij,
  { {0x60080063,0x8a59001c,0xe29f0014,0x00000000}},	//   _מִשְ, ņēmā, saðu_,
  { {0x6d550009,0x6e242706,0x19950086,0x00000000}},	//   _taza, crib, мадя,
  { {0x992b0121,0xbd450021,0x2fc92707,0x00000000}},	//   сюда_, _تنسي, llag_,
  { {0x2369017f,0x69c100c2,0x8c42004d,0x00000000}},	//   _onaj_, _vkle, ößtm,
  { {0x69c10051,0x27e60139,0x7ae9003b,0x00000000}},	//   _wkle, _cion_, _uget,
  { {0x6f0f2708,0x645c2709,0xa3c30053,0x00000000}},	//   _mecc, ærin, ्तन_,
  { {0x6f0f14c4,0x2fc900bd,0x637f00ac,0x00000000}},	//   _lecc, hlag_, _oëns,
  { {0x7d050139,0xa3e90085,0xe3b90058,0x00000000}},	//   ibhs, юдна_, arım_,
  { {0x78880021,0xb33b00be,0xf2a602f8,0x00000000}},	//   _عَنِ_, tiça, димп,
  { {0x7ae400c3,0xe297026c,0x6f0400a8,0x00000000}},	//   žitv, дая_, vbic,
  { {0x6f1d270a,0x27e6270b,0x9405009b,0x00000000}},	//   _adsc, _zion_, _قوته,
  { {0x6f0f0314,0x7dcb0058,0x7d0e004d,0x00000000}},	//   _becc, rüsl, _rebs,
  { {0x6f0f270c,0x201e007d,0x20040195,0x00000000}},	//   _cecc, štio_, ďmi_,
  { {0x0eaa0088,0x6f04070e,0x6d5a0014,0x00000000}},	// [3e80] цкай_, rbic, _ótak,
  { {0x6f04270d,0x6e242308,0x93f9009a,0x00000000}},	//   sbic, rrib, ַלְי,
  { {0x9265007e,0x6c4a03eb,0x7d0e007d,0x00000000}},	//   _قدیم, تلاف_, _vebs,
  { {0x6e24270e,0x7d050025,0x5aca270f,0x00000000}},	//   prib, abhs, олем_,
  { {0xda770062,0x28f822f5,0xf8a60082,0x00000000}},	//   дящ_, пель_, गप्प,
  { {0x2fc00025,0x6f0f0314,0x61eb0003,0x00000000}},	//   loig_, _zecc, _ègle,
  { {0x19b9000d,0xa3c30053,0x661d0078,0x00000000}},	//   чуць_, ्तम_, šskl,
  { {0x97a306bc,0x442500a8,0xba1a005d,0x00000000}},	//   крыл, drl_, _ويزا_,
  { {0x993a000d,0x9e7b0041,0x7791005d,0x00000000}},	//   _мяжу_, ַנטפ, دینا,
  { {0x44980086,0x271e0013,0x2fc900a8,0x00000000}},	//   звою_, ịn_, zlag_,
  { {0x29c9013d,0x53350201,0x201e1fca,0x00000000}},	//   zúak_, нент, átil_,
  { {0x69ca2710,0x926b11f7,0xc6a61415,0x00000000}},	//   llfe, орга_, _орли,
  { {0x3a2604c7,0x2fc90104,0x43940121,0x00000000}},	//   nrop_, vlag_, таяс,
  { {0x6f0f2711,0x95830062,0x66d7013d,0x00000000}},	//   _secc, _илче, súké,
  { {0x6f0f2712,0x656a0025,0x69ca2713,0x00000000}},	//   _pecc, _infh, ilfe,
  { {0x442c0185,0x93780021,0x9df9202f,0x00000000}},	//   mud_, _يصير_, знат_,
  { {0x6f0f051e,0x442c2714,0x63a800cd,0x00000000}},	// [3e90] _vecc, lud_, èjne,
  { {0x2fc92715,0x3f920150,0x6da40001,0x00000000}},	//   slag_, ahyu_, виђа,
  { {0x442c2716,0x2fc900d1,0xdda40066,0x00000000}},	//   nud_, plag_, _žňú_,
  { {0x61fb000c,0x291e00ea,0xad9b2717,0x00000000}},	//   ţulu, _adta_, _stúd,
  { {0xa9691dd1,0x442c2718,0x6a670044,0x00000000}},	//   зила_, hud_, بطال,
  { {0xdb0b0025,0x442c2719,0x7dd00137,0x00000000}},	//   ingé, kud_, läsn,
  { {0x6e2d0034,0x442c0231,0x645c0014,0x00000000}},	//   luab, jud_, æril,
  { {0x442c0004,0xd7f8008d,0x3f89005f,0x00000000}},	//   dud_, _trăn_, nkau_,
  { {0x6e2d006d,0x645d008f,0x6726013d,0x00000000}},	//   nuab, āsim, ókja,
  { {0xe5710021,0x7bcb271a,0x4425271b,0x00000000}},	//   اطة_, llgu, trl_,
  { {0x290700c3,0xd4691321,0x442c271c,0x00000000}},	//   mbna_, чине_, gud_,
  { {0x6e2d004b,0xb9020053,0x00000000,0x00000000}},	//   kuab, ने_,   ,
  { {0xc6040054,0x2bb70042,0xb38306c9,0x00000000}},	//   _азій, _अदना, улял,
  { {0x442500c2,0x442c0d7d,0x6e2d271d,0x00000000}},	//   prl_, bud_, duab,
  { {0x2bb10051,0xdc32001c,0xa067271e,0x00000000}},	//   jąco_, kļāv, нара_,
  { {0x4906016a,0x3f890397,0x25a5004e,0x00000000}},	//   _स्नो_, gkau_, lill_,
  { {0x4d66000d,0x6e2d271f,0x25a50139,0x00000000}},	// [3ea0] нкав, guab, oill_,
  { {0x25a52720,0x7afb0035,0x7dc6007e,0x00000000}},	//   nill_, _afut, رقان,
  { {0x10a60086,0xf1bf00ea,0x3a26002b,0x00000000}},	//   _чинн, orán_, wrop_,
  { {0x7c230139,0x6e2d2721,0x25a52722,0x00000000}},	//   ánra, buab, hill_,
  { {0x6f630055,0xf1bf006d,0x25a52723,0x00000000}},	//   _связ, irán_, kill_,
  { {0x6f16005b,0xdca62724,0xf1bf2725,0x00000000}},	//   layc, _заги, hrán_,
  { {0xd7f1008b,0x07e60001,0xa37b017d,0x00000000}},	//   _cũ_, нцим, lmõe,
  { {0x442c2726,0xb33b017d,0x93bd003b,0x00000000}},	//   vud_, viço, stăz,
  { {0xf1bf2727,0x25a52728,0x63a62729,0x00000000}},	//   drán_, fill_, dikn,
  { {0x63a6007a,0x6286272a,0xf1bf006d,0x00000000}},	//   eikn, dyko, erán_,
  { {0x46ea0079,0x442c004b,0xf1bf0331,0x00000000}},	//   _еден_, uud_, frán_,
  { {0xf1bf0025,0x63a60089,0x442c272b,0x00000000}},	//   grán_, gikn, rud_,
  { {0x442c2719,0x25a512a9,0x16340e82,0x00000000}},	//   sud_, bill_, _реля,
  { {0xf1bf1e10,0x394e006c,0x66e3272c,0x00000000}},	//   arán_, nefs_, _соча,
  { {0xc4f700b5,0x10480086,0x3f67142a,0x00000000}},	//   _אזוי_, няти_, нтаб,
  { {0x6e2d272d,0x9e95005d,0x3f8f0014,0x00000000}},	//   tuab, پارچ, ógu_,
  { {0x8d870076,0xc5f30047,0x62860137,0x00000000}},	// [3eb0] нужд, ָדע_, cyko,
  { {0x2249017f,0x3f890206,0x00000000,0x00000000}},	//   _ipak_, skau_,   ,
  { {0xeb390085,0x7c950044,0xa074014b,0x00000000}},	//   дзеш_, خلاص, _быўш,
  { {0xa3c30161,0x7bcb272e,0x0b58000d,0x00000000}},	//   ्ति_, ulgu, ершы_,
  { {0x2fd90150,0xdc13005b,0x6e2d006c,0x00000000}},	//   _ihsg_, rşıt, quab,
  { {0x7dcb0019,0x63a60089,0xf2d40047,0x00000000}},	//   küsi, zikn, נעס_,
  { {0xa3c30161,0x63a60150,0x62860b72,0x00000000}},	//   ्ता_, yikn, zyko,
  { {0x7afb0035,0x1bd5000d,0xd7f10013,0x00000000}},	//   _ufut, _робя, _vũ_,
  { {0x25a5272f,0x63a6007d,0x853c0078,0x00000000}},	//   till_, vikn, ynėt,
  { {0x4585005a,0xb4650086,0x62862730,0x00000000}},	//   тгов, вкол, vyko,
  { {0x63a62376,0x25a51b6a,0xf1bf06fe,0x00000000}},	//   tikn, rill_, trán_,
  { {0xb5fd00c2,0x69c32731,0xdb0b0022,0x00000000}},	//   evše, lone, mogó,
  { {0x25a52732,0x63a62733,0x93bd003b,0x00000000}},	//   pill_, rikn, crăm,
  { {0x412a019d,0x63a62734,0xdb000003,0x00000000}},	//   ього_, sikn, _emmè,
  { {0x03aa0021,0x661b0360,0x69c30d17,0x00000000}},	//   _يدعو_, lsuk, ione,
  { {0xe4e40086,0x6266047e,0x69c32659,0x00000000}},	//   _січн, _авиа, hone,
  { {0x63a42735,0x69c30b3d,0xee3a2736,0x00000000}},	// [3ec0] _imin, kone, ьна_,
  { {0x69c3076c,0xdb000164,0x661b0ff2,0x00000000}},	//   jone, _immé, isuk,
  { {0x69c306b8,0xa7fc0058,0xc50c0041,0x00000000}},	//   done, _arın, פלאָ,
  { {0x6a8600e1,0xf1bf0080,0x661b065c,0x00000000}},	//   клеа, hrál_, ksuk,
  { {0x63a4051e,0x69c30f4b,0x3f8c0078,0x00000000}},	//   _mmin, fone, ūdus_,
  { {0x63a400b9,0x69c32737,0x661b0093,0x00000000}},	//   _lmin, gone, dsuk,
  { {0x63a4024a,0xd7f8008b,0xa96700e1,0x00000000}},	//   _omin, _trăm_, тија_,
  { {0x6d5c2738,0x6d5e2739,0x7c3e273a,0x00000000}},	//   _hara, ldpa, mtpr,
  { {0x6d5c273b,0x661b00a4,0x201e007d,0x00000000}},	//   _kara, gsuk, štih_,
  { {0x63a4273c,0x6d5c273d,0x69c3273e,0x00000000}},	//   _amin, _jara, cone,
  { {0x19b9015a,0x6d5c11a0,0x7c3e273f,0x00000000}},	//   _чуть_, _mara, ntpr,
  { {0x6d5c18a5,0x7c3e0760,0xa7fc0058,0x00000000}},	//   _lara, itpr, _yrın,
  { {0x86c3007e,0x63a40246,0x661b013d,0x00000000}},	//   _پيون, _dmin, csuk,
  { {0x7c3e16af,0x6d5c2740,0x660d0075,0x00000000}},	//   ktpr, _nara, _çaka,
  { {0x25ab03b2,0xdb1b008b,0xa5bd0078,0x00000000}},	//   ècle_, _khuô, krųj,
  { {0x6d5c002c,0x63a40051,0x40340001,0x00000000}},	//   _aara, _gmin, јетс,
  { {0x6d5e02b0,0x6d5c2741,0x69c32742,0x00000000}},	// [3ed0] fdpa, _bara, yone,
  { {0x6d5c15dd,0x31550121,0x5c0702e1,0x00000000}},	//   _cara, _своё, вяда,
  { {0x6d5c2743,0x443e2744,0x69c32745,0x00000000}},	//   _dara, ntt_, vone,
  { {0x443e2746,0x69c32747,0x66022748,0x00000000}},	//   itt_, wone, _otok,
  { {0x6d5c2749,0x69c3274a,0xbea4000d,0x00000000}},	//   _fara, tone, _ваўк,
  { {0x644a00b9,0x38590121,0x6458274b,0x00000000}},	//   _opfi, ерию_, _osvi,
  { {0x69c3274c,0xbc95005e,0xc1740063,0x00000000}},	//   rone, _савј, יחס_,
  { {0xdb1b008b,0x6d5c1aea,0x69c3274d,0x00000000}},	//   _chuô, _zara, sone,
  { {0x6d5c01f7,0x7f5d1db7,0x69c3214e,0x00000000}},	//   _yara, _masq, pone,
  { {0x661b1957,0xdb0b274e,0x6d5c01a8,0x00000000}},	//   rsuk, ingí, _xara,
  { {0x661b274f,0xc98401ce,0x7d15009c,0x00000000}},	//   ssuk, _тути, _mezs,
  { {0x7f5d00cd,0xe29a0699,0xa822007e,0x00000000}},	//   _nasq, еам_, _اکون,
  { {0x69da09ff,0x6d47064f,0xea000013,0x00000000}},	//   _yhte, _obja, _đẫm_,
  { {0xf6520063,0x41b505ac,0x7659002b,0x00000000}},	//   _לצד_, асст, _iswy,
  { {0xb1840080,0x7f5d18b9,0x6d5c22d3,0x00000000}},	//   šťov, _basq, _rara,
  { {0x798100ac,0x63a42750,0xd1380051,0x00000000}},	//   _lolw, _umin, żą_,
  { {0xa3c30161,0x0e660088,0x6d5c2751,0x00000000}},	// [3ee0] ्तर_, ыкан, _para,
  { {0x3c3c000f,0x6d5c1bef,0x7c3e2752,0x00000000}},	//   tív_, _qara, ttpr,
  { {0x31570047,0x657c0137,0x6d5c2753,0x00000000}},	//   _גיין_, örhi, _vara,
  { {0x2f56019d,0x93bd000c,0x207b0047,0x00000000}},	//   _стос, luăr, _נאכא,
  { {0x6d5c2754,0x798100ca,0x7c3e2755,0x00000000}},	//   _tara, _bolw, stpr,
  { {0x443e2756,0xada60001,0x7981002b,0x00000000}},	//   ytt_, _сагл, _colw,
  { {0x764b0078,0x66022757,0x7e640050,0x00000000}},	//   _apgy, _stok, lvip,
  { {0x3f8200fe,0xf0930063,0x853c0078,0x00000000}},	//   _joku_, מנו_, riėm,
  { {0xa91c0024,0x853c0078,0x3f8201a8,0x00000000}},	//   _voľb, siėm, _moku_,
  { {0x7981001f,0xaa930021,0x09e62758,0x00000000}},	//   _golw, _الكث, _созн,
  { {0xdb1b008b,0x7e64078c,0x443e2759,0x00000000}},	//   _thuô, hvip, utt_,
  { {0x443e275a,0x395e275b,0xdcee004c,0x00000000}},	//   rtt_, _hats_, _sobě,
  { {0xdcee0080,0x82a70002,0x98f50013,0x00000000}},	//   _pobě, ушне, _mản,
  { {0x365b0063,0x7dcb0058,0x395e00e5,0x00000000}},	//   _נכונ, nüst, _jats_,
  { {0x4395000d,0x7f5d275c,0x2f190121,0x00000000}},	//   _вайс, _pasq, ковь_,
  { {0x998601c2,0x29c90026,0x395e275d,0x00000000}},	//   spoň_, núar_, _lats_,
  { {0x7dcb049c,0x7f5d275e,0x51d902f8,0x00000000}},	// [3ef0] küst, _vasq, _имиџ_,
  { {0x442c275f,0x395e004e,0xa7fc0075,0x00000000}},	//   ord_, _nats_, _arım,
  { {0x7f5d0268,0x98f5008b,0x7dcb005b,0x00000000}},	//   _tasq, _bản, düst,
  { {0x442c20ed,0x98f5008b,0xd7f8003b,0x00000000}},	//   ird_, _cản, _grăi_,
  { {0x6f0d014f,0x853c0078,0x6d43004b,0x00000000}},	//   mbac, riėj, õnas,
  { {0xda620086,0x6f0d2760,0x395e059f,0x00000000}},	//   івщи, lbac, _cats_,
  { {0x79810162,0x6f0d2761,0x395e0c5f,0x00000000}},	//   _volw, obac, _dats_,
  { {0x2d830016,0x6e2d00c3,0x395e00e5,0x00000000}},	//   _hoje_, orab, _eats_,
  { {0x2d830a0d,0x442c0a53,0xbb840032,0x00000000}},	//   _koje_, erd_, _القي,
  { {0x45d5000a,0x6d450025,0x2d830006,0x00000000}},	//   јцит, nfha, _joje_,
  { {0x04450928,0x7dcb00bd,0x29c90014,0x00000000}},	//   шенн, lüss, búar_,
  { {0x6e2d2762,0xc4820083,0x62662763,0x00000000}},	//   krab, іляк, авма,
  { {0x6f0d2764,0x442c0479,0x3f822765,0x00000000}},	//   dbac, ard_, _roku_,
  { {0xd6260079,0x395e0268,0x23af00fe,0x00000000}},	//   _тоше_, _xats_, töjä_,
  { {0xc0e6047e,0x660900d1,0x6e2d2766,0x00000000}},	//   ровк, lpek, erab,
  { {0xb4c10053,0x64412767,0x0c76007e,0x00000000}},	//   ंथी_, mtli, یداد,
  { {0x64412768,0x2d83041f,0x6d452769,0x00000000}},	// [3f00] ltli, _boje_, ffha,
  { {0xe3b9005b,0x6441276a,0x27ef00b9,0x00000000}},	//   brıs_, otli, _lign_,
  { {0xed57000d,0x644116f9,0xd7f8003b,0x00000000}},	//   рох_, ntli, _trăi_,
  { {0xdb0b0016,0x6e2d276b,0xdcf6005b,0x00000000}},	//   ligê, brab, ıcıl,
  { {0x395e276c,0x6441276d,0x3a200139,0x00000000}},	//   _pats_, htli, éip_,
  { {0xa3dd0161,0x644112f5,0x2a15000d,0x00000000}},	//   _तीन_, ktli, сьцё,
  { {0x7dcb0baa,0xf8370044,0xf77200de,0x00000000}},	//   rüst, لسيث_, قاظ_,
  { {0x7dcb0004,0xf1bf1d6b,0x8a060002,0x00000000}},	//   süst, nuár_, _взае,
  { {0xd6d7276e,0x64410051,0x98a50058,0x00000000}},	//   ить_, etli, _dalı_,
  { {0x80f50053,0x6441276f,0x27ef0026,0x00000000}},	//   _आलेख_, ftli, _eign_,
  { {0x442c2770,0x660900a4,0x291c2771,0x00000000}},	//   urd_, apek, mava_,
  { {0x291c2772,0x93a70054,0x00000000,0x00000000}},	//   lava_, ршод,   ,
  { {0x9f4200fe,0xf1bf00ea,0x6d45002b,0x00000000}},	//   _mikä_, nság_, yfha,
  { {0x6f0d096c,0x6e2d2773,0xddcd0022,0x00000000}},	//   wbac, vrab, zwał,
  { {0x64411767,0xddcd0051,0x291c00be,0x00000000}},	//   ctli, ywał, iava_,
  { {0xcf980138,0xa3d20161,0x6e2d2774,0x00000000}},	//   ају_, वतः_, trab,
  { {0x291c2775,0x6e2d2776,0xd7f8003b,0x00000000}},	// [3f10] kava_, urab, _luă_,
  { {0x6e2d1e04,0x2b5f001c,0x93bd003b,0x00000000}},	//   rrab, _sauc_, grăv,
  { {0x201e0080,0xccf8005e,0x9af50021,0x00000000}},	//   átit_, рћу_, مكات,
  { {0xdea1007e,0x2d830022,0xcb690131,0x00000000}},	//   _فیزی, _woje_, ѓале_,
  { {0x2d830006,0xf1bf00ea,0xddcd0022,0x00000000}},	//   _toje_, gság_, rwał,
  { {0x9f42024a,0x27ef0465,0x98a50058,0x00000000}},	//   _eikä_, _sign_, _salı_,
  { {0x7c950032,0x6c850021,0xdb0b0137,0x00000000}},	//   _الأص, _الزم, dogö,
  { {0x9f970268,0x5ba40376,0x291c01cf,0x00000000}},	//   nçà_, _друз, aava_,
  { {0x291c1c53,0xddd6004c,0x00000000,0x00000000}},	//   bava_, evyř,   ,
  { {0xa9280086,0x66091154,0x291c2777,0x00000000}},	//   _віце_, rpek, cava_,
  { {0x8458005a,0xd7fb0002,0x64412778,0x00000000}},	//   арят_, _руз_, utli,
  { {0x7dd01a14,0x64412779,0xad9b0014,0x00000000}},	//   räsi, rtli, _stúl,
  { {0x6605277a,0x7dd00072,0x6441277b,0x00000000}},	//   _упла, säsi, stli,
  { {0x910307da,0x6441004d,0x6146005e,0x00000000}},	//   зпре, ptli, љева,
  { {0xdcfc0418,0xf1bf013d,0xdfd20044,0x00000000}},	//   _norā, zság_, كيس_,
  { {0x4fa3005a,0x291c277c,0xfe7a000d,0x00000000}},	//   писв, zava_, лёзы_,
  { {0x67c1003d,0x32460021,0xea000013,0x00000000}},	// [3f20] mējd, _انخف, _đắm_,
  { {0x201e017d,0x6e2b00ea,0xe3b9005b,0x00000000}},	//   átis_, ágba, nsın_,
  { {0xcb6a0001,0x291c277d,0x1c4625dc,0x00000000}},	//   лаже_, vava_, снем,
  { {0x201e0006,0x5ba50054,0xf1bf013d,0x00000000}},	//   štis_, оріз, tság_,
  { {0x93bd003b,0xe3b90058,0xab270062,0x00000000}},	//   prăv, ksın_, соча_,
  { {0x5d860021,0x7d960021,0xda650021,0x00000000}},	//   _الآل, _السؤ, غاني,
  { {0xf1bf00ea,0xc8660429,0x7d1e06f8,0x00000000}},	//   sság_, стли, maps,
  { {0xbb430055,0xc7c6005e,0x291c277e,0x00000000}},	//   _неск, љски, sava_,
  { {0xd6d00032,0xdb0b0003,0x291c277f,0x00000000}},	//   بقة_, digè, pava_,
  { {0x7d1e1164,0x39990003,0x6f190022,0x00000000}},	//   naps, _pèse_, ówcz,
  { {0x07a6018e,0x4d7b0047,0xa4d8167b,0x00000000}},	//   _лажн, אריע, рдну_,
  { {0xc7f70063,0x7d1e2780,0xe3b90058,0x00000000}},	//   _הזאת_, haps, asın_,
  { {0x7d1e2781,0xd5e20013,0x82a40085,0x00000000}},	//   kaps, _trò, заўж,
  { {0x645c2782,0xc0cb01ce,0xc05b012c,0x00000000}},	//   æris, губе_, ліб_,
  { {0xbddb0003,0x3ea000ca,0x351b009a,0x00000000}},	//   _opèr, ezit_, _גוונ,
  { {0xd5b8001c,0x398b0093,0xa3bd0053,0x00000000}},	//   lnā_, _høst_, _आदि_,
  { {0x88bc0080,0x22590076,0xa91c0066,0x00000000}},	// [3f30] _sděl, _типы_, _roľn,
  { {0xd5b8008f,0x44d7008d,0x23b20078,0x00000000}},	//   nnā_, _ỹ_, ršje_,
  { {0xa91c0024,0xdb0b0003,0x3af50121,0x00000000}},	//   _poľn, ligé, оялс,
  { {0x398b02ab,0x93bd000c,0x63af007d,0x00000000}},	//   _løst_, crăt, nicn,
  { {0xa91c0024,0x7f3a0047,0xd5b8008f,0x00000000}},	//   _voľn, _דערו, knā_,
  { {0x7d1e08c9,0xa96904f2,0x00000000,0x00000000}},	//   caps, рика_,   ,
  { {0x26160161,0x88bc0080,0xab950086,0x00000000}},	//   पीसी_, _uděl, _диві,
  { {0xc8640062,0xd5b8008f,0x6d572783,0x00000000}},	//   ятчи, enā_, lexa,
  { {0x7bcb093a,0x67c10023,0x0555030b,0x00000000}},	//   mogu, vējd, отня,
  { {0x05a90076,0xdb0b2784,0xc9840002,0x00000000}},	//   рвой_, digé, _нухи,
  { {0xe3ba0076,0x7dd01e55,0x320908f2,0x00000000}},	//   ибо_, mäst, _atay_,
  { {0x3ce10053,0x42ea2785,0x7dd00dc9,0x00000000}},	//   _करने_, имно_, läst,
  { {0xdb0b0003,0x645c0014,0x92930085,0x00000000}},	//   rigè, ærir, даўц,
  { {0x673b2786,0x7dd00b75,0x2d870075,0x00000000}},	//   lguj, näst, önel_,
  { {0x7bcb0004,0x43460330,0xea00008b,0x00000000}},	//   kogu, _дейв, _đậm_,
  { {0x20051997,0x7dd02787,0x673b2788,0x00000000}},	//   ília_, häst, nguj,
  { {0x7dd00461,0x10f6000d,0x7d1e2789,0x00000000}},	// [3f40] käst, _мяня, taps,
  { {0x7dd00072,0x5bd20053,0x30760a7d,0x00000000}},	//   jäst, तत्व, _думс,
  { {0x6563278a,0x7d1e278b,0xdca30094,0x00000000}},	//   _manh, raps, мафи,
  { {0x2905278c,0xa91c0066,0x656300f1,0x00000000}},	//   _afla_, _poľo, _lanh,
  { {0x79c6000d,0x7dd00137,0xff570063,0x00000000}},	//   ойдз, fäst, _ובכך_,
  { {0x291a0027,0x082a278d,0xf806278e,0x00000000}},	//   úpa_, ации_, очин,
  { {0x7d1c0983,0x69ca278f,0x23ca0053,0x00000000}},	//   _iers, rofe, रवाद,
  { {0x65631a20,0x7d1c2790,0x6f042791,0x00000000}},	//   _aanh, _hers, ncic,
  { {0x65630016,0x7d1c2792,0xda6601fb,0x00000000}},	//   _banh, _kers, _بازي,
  { {0xe3b9005b,0x7dd01ea9,0x65632793,0x00000000}},	//   asıl_, mäss, _canh,
  { {0x32090034,0x7dd01a14,0x3e4e001c,0x00000000}},	//   _stay_, läss, lētā_,
  { {0xf1bf0080,0x6b8200ea,0x6e242794,0x00000000}},	//   hrát_, njog, ksib,
  { {0x798800ac,0x7d1c2795,0xf1bf0114,0x00000000}},	//   _kodw, _oers, krát_,
  { {0x65630016,0xdb0b0164,0x93bd003b,0x00000000}},	//   _ganh, rigé, grăr,
  { {0x3f87000a,0xf20f0042,0x7dd00d90,0x00000000}},	//   оѓаа, ़ीज़_, häss,
  { {0x23280001,0x6d4e2796,0x6720007d,0x00000000}},	//   _доћи_, _abba, namj,
  { {0x7d1c0397,0xccfb0001,0xdb0b00d1,0x00000000}},	// [3f50] _bers, аће_, nngå,
  { {0x79880185,0x93bd000c,0x7d1c1643,0x00000000}},	//   _nodw, crăr, _cers,
  { {0x7d1c0a70,0x515a0063,0x7bcb0006,0x00000000}},	//   _ders, _הכתו, togu,
  { {0x7d1c0ac8,0x6d4e0137,0x6f0401f4,0x00000000}},	//   _eers, _ebba, ccic,
  { {0x7d1c0185,0xea00001b,0x7dd00d90,0x00000000}},	//   _fers, _đảm_, täst,
  { {0x8dfa014e,0x89a80086,0x4e160063,0x00000000}},	//   _להשת, оків_, _מחשב_,
  { {0x63ad0004,0x319c014e,0x7dd000fe,0x00000000}},	//   _oman, שבונ, räst,
  { {0x6563002c,0x38580032,0x7d1c00bd,0x00000000}},	//   _sanh, تشهد_, _zers,
  { {0x3964024a,0x6f1d2797,0x3e4e008f,0x00000000}},	//   össä_, _mesc, cētā_,
  { {0x79882798,0x63ad2799,0x6f1d1346,0x00000000}},	//   _godw, _aman, _lesc,
  { {0x6563024a,0x8afd0080,0x7d0500bd,0x00000000}},	//   _vanh, _zařa, ichs,
  { {0x6b89006f,0x6563279a,0x25a2008f,0x00000000}},	//   _joeg, _wanh, īkla_,
  { {0x8c49005b,0x93bd000c,0xc7b2009f,0x00000000}},	//   laşı, trăr, _אבא_,
  { {0xf1bf1a0a,0x63ad279b,0x6b89001f,0x00000000}},	//   drás_, _eman, _loeg,
  { {0x6f1d1a91,0xa06a005a,0x3e4e001c,0x00000000}},	//   _besc, щава_, zētā_,
  { {0x7d0500bd,0x7d1c279c,0x6fb60021,0x00000000}},	//   echs, _sers, أمرا,
  { {0x7d1c0e69,0x59cb0053,0xf1bf279d,0x00000000}},	// [3f60] _pers, िवार, grás_,
  { {0x63ad09d3,0x7dd000fe,0x7521279e,0x00000000}},	//   _zman, väss, nalz,
  { {0x7dd000bd,0x6e24279f,0xcea90063,0x00000000}},	//   wäss, ssib, ני_,
  { {0x7d1c0045,0x6f1d27a0,0x8c49005b,0x00000000}},	//   _wers, _gesc, daşı,
  { {0x7d1c1d09,0x79880051,0x98be0006,0x00000000}},	//   _ters, _podw, _patį_,
  { {0x3e4e001c,0xb60500c2,0x7dd00072,0x00000000}},	//   rētā_, _mešč, räss,
  { {0x67200035,0x6b9b27a1,0x3e4e001c,0x00000000}},	//   tamj, _flug, sētā_,
  { {0xa91c0024,0x6b9b0026,0x3ce10053,0x00000000}},	//   _koľk, _glug, _करते_,
  { {0x98b1001c,0xfaa327a2,0x442727a3,0x00000000}},	//   ībām_, _зато, _avn_,
  { {0x63ad017f,0xf64f0754,0x5a9b0063,0x00000000}},	//   _sman, ائي_, _השמא,
  { {0xdcfc0051,0xf1bf0014,0x291e2401,0x00000000}},	//   _gorą, krár_, _ieta_,
  { {0x57fb0063,0x291e0137,0x69d827a4,0x00000000}},	//   _הלאו, _heta_, llve,
  { {0x69d827a5,0x2707008b,0x752101f4,0x00000000}},	//   olve, _ống_, balz,
  { {0x2005017d,0x291e0003,0x67c1001c,0x00000000}},	//   ílio_, _jeta_, mēja,
  { {0x67c1001c,0x6f1d0dd1,0x291e27a6,0x00000000}},	//   lēja, _pesc, _meta_,
  { {0xf1bf0942,0x291e27a7,0xbfd90086,0x00000000}},	//   trás_, _leta_, ідає_,
  { {0x6f1d19b9,0xddd00080,0x67c1008f,0x00000000}},	// [3f70] _vesc, _řeši, nēja,
  { {0xf1bf00ea,0x7d0500bd,0x291e0552,0x00000000}},	//   rrás_, uchs, _neta_,
  { {0x7d0500bd,0x63bd27a8,0x2d8a27a9,0x00000000}},	//   rchs, onsn, _dobe_,
  { {0x7d0500bd,0x8c49005b,0xfc30002a,0x00000000}},	//   schs, vaşı, احل_,
  { {0x6b890122,0x5f94005a,0x957c0006,0x00000000}},	//   _voeg, _чият, rmąj,
  { {0xac19131b,0x67c1001c,0x44250080,0x00000000}},	//   _могу_, dēja, ysl_,
  { {0x6b890ac8,0x7e6d27aa,0x246c0080,0x00000000}},	//   _toeg, lvap, _něm_,
  { {0xefc8008b,0x69d827ab,0x060900e2,0x00000000}},	//   _địch_, alve, оник_,
  { {0x291e27ac,0xb6590086,0x7e6d0527,0x00000000}},	//   _feta_, іших_, nvap,
  { {0x291e007a,0xbebb0104,0x1dbf0053,0x00000000}},	//   _geta_, _geëe, ्वित,
  { {0xb80803eb,0xd5b10013,0xf4940121,0x00000000}},	//   _فيلم_, rí_, еряю,
  { {0x672b00b9,0xb60500b2,0x7e6d0114,0x00000000}},	//   _udgj, _pešč, kvap,
  { {0x644e005b,0x67c1001c,0x21e4004d,0x00000000}},	//   çbir, cēja, höhe_,
  { {0xb60500c2,0x44270331,0x68e4004c,0x00000000}},	//   _vešč, _tvn_, řide,
  { {0xdb0000fe,0x43860021,0x2d8a25d7,0x00000000}},	//   _ymmä, _يلتق, _robe_,
  { {0x7afb0150,0x200c001c,0xe3b20021,0x00000000}},	//   _ngut, īdi_, _جرت_,
  { {0xa1c627ad,0x9f4000cd,0x2bb30042,0x00000000}},	// [3f80] _обид, rmià_, ूचना,
  { {0xee370086,0x2257007e,0x7afb01a8,0x00000000}},	//   ьну_, _کلید_, _agut,
  { {0x013500b5,0x764900fe,0x1d190086,0x00000000}},	//   _אָרט_, htey, яють_,
  { {0xa91c0024,0x7649005b,0x291e27ae,0x00000000}},	//   _toľk, ktey, _seta_,
  { {0x6568001f,0x291e27af,0x2d8a27b0,0x00000000}},	//   yddh, _peta_, _tobe_,
  { {0x67c1008f,0x957c005f,0x00000000,0x00000000}},	//   vēja, rmąk,   ,
  { {0x291e27b1,0xfc0300e1,0x8b260095,0x00000000}},	//   _veta_, _апсо, _одве,
  { {0x332000cd,0x6f16001f,0x67c1001c,0x00000000}},	//   _neix_, nbyc, tēja,
  { {0xf54e00aa,0x291e27b2,0x39460094,0x00000000}},	//   _dụng_, _teta_, _онаг,
  { {0x67c1001c,0x2b440013,0x05ba0044,0x00000000}},	//   rēja, _hcmc_, تدعت_,
  { {0x67c1008f,0x98ac0058,0x6d39009a,0x00000000}},	//   sēja, _tadı_, הֲרו,
  { {0x67c1003d,0x6e360051,0x644827b3,0x00000000}},	//   pēja, kryb, rtdi,
  { {0xe2980088,0x61f70137,0x644827b4,0x00000000}},	//   даў_, _pixl, stdi,
  { {0x246c0080,0xf1bf0139,0x6e36005f,0x00000000}},	//   _těm_, asán_, dryb,
  { {0x10480076,0xd0d4005a,0x44a30021,0x00000000}},	//   мяти_, воръ, _لموق,
  { {0x2d8e004d,0x7e6d0137,0xf1bf013d,0x00000000}},	//   öfen_, tvap, csán_,
  { {0x93bd003b,0x7e6d0072,0xdfd80062,0x00000000}},	// [3f90] nsăm, uvap, фър_,
  { {0xdb0b0e7c,0x7e6d01a9,0xaad20042,0x00000000}},	//   rigí, rvap, _तड़क,
  { {0x6e360078,0x5c040085,0x7e6d165b,0x00000000}},	//   aryb, вяча, svap,
  { {0x7dcb009c,0x8f19009a,0x00000000,0x00000000}},	//   nüsz, _מוֹת,   ,
  { {0xf54e0013,0xdfd1005d,0x89d6005d,0x00000000}},	//   _rụng_, _ليگ_, کوور_,
  { {0xda620b3f,0xddc4003b,0xfd10007e,0x00000000}},	//   увши, rviţ, _نجف_,
  { {0x20010019,0x7dcb013d,0xdb0b00dd,0x00000000}},	//   _juhi_, küsz, rigâ,
  { {0x7afb00e3,0x501c014e,0x166527b5,0x00000000}},	//   _ugut, קוחו, евим,
  { {0xb8d6016a,0xea000013,0xf54e008d,0x00000000}},	//   _चे_, _đầm_, _vụng_,
  { {0x764927b6,0x893827b7,0xc4852099,0x00000000}},	//   rtey, _опус_, елок,
  { {0x332000cd,0xf54e0013,0x6f16004c,0x00000000}},	//   _peix_, _tụng_, ybyc,
  { {0x6e360006,0x67c1008f,0xdcfc0022,0x00000000}},	//   yryb, mējo, _dorę,
  { {0x27ed0105,0x67c1001c,0x659527b8,0x00000000}},	//   mmen_, lējo, _паду,
  { {0x3f8f0014,0x27ed1d13,0x15450094,0x00000000}},	//   ögun_, lmen_, _чекм,
  { {0xddc406bb,0x27ed27b9,0xf1bf004c,0x00000000}},	//   jviš, omen_, psán_,
  { {0x273a005b,0xc2460086,0xa2e60895,0x00000000}},	//   münü_, _зник, _пойд,
  { {0xee3a27ba,0x27ed119d,0x273a005b,0x00000000}},	// [3fa0] яна_, imen_, lünü_,
  { {0x27ed0199,0x5d6706da,0xdca62184,0x00000000}},	//   hmen_, ниум_, нази,
  { {0x88bc0080,0x27ed02cc,0x273a0058,0x00000000}},	//   _jdět, kmen_, nünü_,
  { {0x67c1001c,0xec13007e,0xda660021,0x00000000}},	//   dējo, اوند, فاتي,
  { {0xfeba014d,0xc3330063,0x27ed27bb,0x00000000}},	//   _راحت_, רוד_, dmen_,
  { {0x27ed27bc,0x7db60021,0x2fc000a4,0x00000000}},	//   emen_, _أصحا, lnig_,
  { {0x395c1310,0x6d5e27bd,0xfce327be,0x00000000}},	//   revs_, mepa, _боро,
  { {0x6d5e0029,0x2fc027bf,0x27ed27c0,0x00000000}},	//   lepa, nnig_, gmen_,
  { {0x6d5e0983,0xe60f007e,0x2fc027c1,0x00000000}},	//   oepa, یشی_, inig_,
  { {0x6d5e058c,0x9f4000fe,0x2fc0002b,0x00000000}},	//   nepa, lmiä_, hnig_,
  { {0x67c1008f,0x273a0058,0xd6da007e,0x00000000}},	//   cējo, günü_, _کوشش_,
  { {0x61ee27c2,0x889b0063,0x67e5013d,0x00000000}},	//   embl, _משבצ, tóje,
  { {0x6d5e27c3,0x9f400072,0x7c3e004b,0x00000000}},	//   kepa, imiä_, hupr,
  { {0xc6b500b5,0x660f0024,0x9f4000fe,0x00000000}},	//   _בלױז_, ícke, hmiä_,
  { {0x6d5e27c4,0x273a0058,0x66020072,0x00000000}},	//   depa, cünü_, _huok,
  { {0x987b00b5,0xc275018e,0x2553005b,0x00000000}},	//   האלט, _алиј, ağlı_,
  { {0x67c1001c,0x4ea7005e,0x443e27c5,0x00000000}},	// [3fb0] zējo, хрва, lut_,
  { {0x6602024a,0x6d5e05e1,0x443e27c6,0x00000000}},	//   _muok, gepa, out_,
  { {0x6602024a,0xa3e6016a,0x656a0089,0x00000000}},	//   _luok, _बीड_, _mafh,
  { {0x80480132,0x67c1001c,0xc4d30047,0x00000000}},	//   _אֲשֶ, vējo, אגע_,
  { {0x443e27c7,0x273a0058,0xa96927c8,0x00000000}},	//   hut_, zünü_, дила_,
  { {0x6d5e27c9,0x443e1074,0x645801b0,0x00000000}},	//   cepa, kut_, _opvi,
  { {0x1866005a,0x443e27ca,0x27ed27cb,0x00000000}},	//   ващи_, jut_, tmen_,
  { {0x67c1001c,0x3f89003e,0x443e27cc,0x00000000}},	//   rējo, njau_, dut_,
  { {0x443e0164,0x6458001c,0x27ed2492,0x00000000}},	//   eut_, _apvi, rmen_,
  { {0x68e40080,0x67c1001c,0x66020078,0x00000000}},	//   řida, pējo, _duok,
  { {0x443e27cd,0x2fc0002b,0x69da0042,0x00000000}},	//   gut_, ynig_, _पीटी,
  { {0x273a005b,0x03961415,0x6d5e27ce,0x00000000}},	//   rünü_, троя, zepa,
  { {0xa2d50053,0x273a0058,0x443e27cf,0x00000000}},	//   _युद्, sünü_, aut_,
  { {0x443e27d0,0x3ea9001c,0x67e50022,0x00000000}},	//   but_, dzat_, bójc,
  { {0x61ee120a,0x443e27d1,0xb5fd004a,0x00000000}},	//   rmbl, cut_, avšt,
  { {0xa067000a,0xdee60259,0x3ebf007d,0x00000000}},	//   њата_, воби, _žuta_,
  { {0x2fc0007a,0x6d5e0551,0xa7fc0058,0x00000000}},	// [3fc0] rnig_, tepa, _asıl,
  { {0x2fcd08ea,0xdb0b18a8,0x7c3e27d2,0x00000000}},	//   čega_, vigá, tupr,
  { {0xdd100024,0x752327d3,0x6d5e27d4,0x00000000}},	//   _týžd, _menz, repa,
  { {0x2d9a00ac,0x752327d5,0x6d5e27d6,0x00000000}},	//   skpe_, _lenz, sepa,
  { {0x443e27d7,0x9f4000fe,0x7c3e27d8,0x00000000}},	//   zut_, rmiä_, supr,
  { {0x7f4427d9,0x660200fe,0x443e27da,0x00000000}},	//   lgiq, _ruok, yut_,
  { {0x1c390076,0x7659002b,0xdcee008f,0x00000000}},	//   _пять_, _apwy, _mobī,
  { {0x443e024a,0xf0930063,0x75230035,0x00000000}},	//   vut_, שנה_, _aenz,
  { {0xc966005a,0x752327db,0x7bc2004c,0x00000000}},	//   _ивай, _benz, mnou,
  { {0x660200fe,0xdcee001c,0x48b60121,0x00000000}},	//   _vuok, _nobī, _ищет,
  { {0x443e084e,0x7bc200e5,0x3ea927dc,0x00000000}},	//   uut_, onou, zzat_,
  { {0x443e0397,0x040d001b,0x7523006f,0x00000000}},	//   rut_, _hưởn, _eenz,
  { {0x3f8f0026,0x7e9a001c,0x443e27dd,0x00000000}},	//   ögum_, _jāpā, sut_,
  { {0x7bc20080,0x656a0146,0x6593000d,0x00000000}},	//   hnou, _uafh, _вашу,
  { {0x7bc20080,0x75280051,0x31c40062,0x00000000}},	//   knou, madz, рсяв,
  { {0x3ea90994,0xa8570063,0x442c005f,0x00000000}},	//   tzat_, כילה_, msd_,
  { {0x7c2e0707,0x7bc20080,0x5d550189,0x00000000}},	// [3fd0] _avbr, dnou, лкат,
  { {0x7bc21806,0x752827de,0x91e401ce,0x00000000}},	//   enou, nadz, _коње,
  { {0x442c26ad,0x5b15005e,0x93bd003b,0x00000000}},	//   nsd_, гмет, drăz,
  { {0x442c006f,0x752816bb,0x09cb0053,0x00000000}},	//   isd_, hadz, िव्य,
  { {0x19950062,0x442c002b,0x75282329,0x00000000}},	//   ладя, hsd_, kadz,
  { {0x7528003d,0xca76007e,0x9f5900cd,0x00000000}},	//   jadz, اموش_, _sisè_,
  { {0x75231ee6,0x9f590003,0x6e2d27df,0x00000000}},	//   _renz, _aisé_, lsab,
  { {0x752327e0,0x6e2d1964,0x6f0d27e1,0x00000000}},	//   _senz, osab, ncac,
  { {0xaab70235,0x6d450025,0x6e2d27e2,0x00000000}},	//   _अधिक, ogha, nsab,
  { {0x6d4527e3,0x45852363,0x27210013,0x00000000}},	//   ngha, угов, ẳn_,
  { {0x2d9127e4,0xa91c0066,0x48152254,0x00000000}},	//   _moze_, _voľt, _смес,
  { {0xe72e0138,0xbebb00ac,0xdce7222e,0x00000000}},	//   _ће_, _reën, _najč,
  { {0x69c303b2,0x752327e5,0x7b06004c,0x00000000}},	//   onne, _tenz, _ústř,
  { {0xa06a0088,0x957c0045,0x200c017d,0x00000000}},	//   нага_, gląd, ídio_,
  { {0x65610016,0x6e2d01f7,0x69c327e6,0x00000000}},	//   melh, esab, inne,
  { {0x6d4500ea,0xad9b0066,0xdd110114,0x00000000}},	//   egha, _stúp, výši,
  { {0x6e2d27e7,0x644f000c,0x7f4400f4,0x00000000}},	// [3fe0] gsab, ăciu, rgiq,
  { {0x65610122,0x51662178,0x52b20053,0x00000000}},	//   nelh, _своб, ीपीस,
  { {0x7bc20080,0x64412741,0x224227e8,0x00000000}},	//   tnou, nuli, lukk_,
  { {0x6d4527e9,0x7e6400ac,0xbebb00ac,0x00000000}},	//   agha, pwip, _keël,
  { {0xd00f006a,0x644127ea,0x63a402f7,0x00000000}},	//   _ولی_, huli, _mlin,
  { {0xe8940055,0xdce700c2,0x63a427eb,0x00000000}},	//   иаль, _zajč, _llin,
  { {0x64410009,0x7bc20080,0x63a427ec,0x00000000}},	//   juli, pnou, _olin,
  { {0x75280045,0xa91c0024,0x69c327ed,0x00000000}},	//   wadz, _poľs, anne,
  { {0x2bb10045,0x040d001b,0x9b930021,0x00000000}},	//   jący_, _tưởn, _القت,
  { {0x63a427ee,0x2609006d,0x63b6001f,0x00000000}},	//   _alin, _dúo_, _amyn,
  { {0x69c8006f,0x644127ef,0x75281a03,0x00000000}},	//   _ijde, guli, radz,
  { {0x63a427f0,0x752827f1,0x201800a8,0x00000000}},	//   _clin, sadz, dpri_,
  { {0x877b0047,0x75280022,0x442c004c,0x00000000}},	//   _ראדי, padz, ssd_,
  { {0x9f490027,0x644127f2,0x301b0021,0x00000000}},	//   rmaí_, buli, فترة_,
  { {0xb97b00b5,0xd0840076,0x644127f3,0x00000000}},	//   ענלי, быти, culi,
  { {0x6e2d27f4,0xb4c00042,0x161b0042,0x00000000}},	//   tsab, ंपी_, पीकर_,
  { {0x93fc0063,0x6e2d0035,0xbebb006f,0x00000000}},	// [3ff0] _אלהי, usab, _geël,
  { {0x6e2d05d8,0x6f0d27f5,0x61fe002b,0x00000000}},	//   rsab, scac, _gipl,
  { {0x2dd80032,0x6e2d27f6,0x6d4527f7,0x00000000}},	//   ابقة_, ssab, rgha,
  { {0x6d450025,0x3f6706da,0x65611929,0x00000000}},	//   sgha, _стоб, zelh,
  { {0x3ce10053,0x644127f8,0x15f60042,0x00000000}},	//   _करके_, zuli, ीदार_,
  { {0x67c1001c,0x69c327f9,0xdd870085,0x00000000}},	//   mēji, unne, _сымп,
  { {0x67c1001c,0x2bb10022,0x18a50085,0x00000000}},	//   lēji, zący_, райм,
  { {0x69da0031,0xd8b80021,0x644127fa,0x00000000}},	//   _ekte, ددها_, vuli,
  { {0x2d9c000f,0x67c1008f,0x656127fb,0x00000000}},	//   öveg_, nēji, telh,
  { {0xbebb0438,0xe576000d,0x644127fc,0x00000000}},	//   _reël, азь_, tuli,
  { {0xa3c4016a,0x9f970268,0x656127fd,0x00000000}},	//   ्वल_, nçó_, relh,
  { {0x644127fe,0x9675000d,0x61fe1013,0x00000000}},	//   ruli, _выкі, _sipl,
  { {0x644127ff,0x63a413de,0xc2430062,0x00000000}},	//   suli, _vlin, оняк,
  { {0x67c1001c,0x1a9a0047,0x463a0047,0x00000000}},	//   dēji, דישע, _יענע,
  { {0x39470034,0x5f06037c,0x41270002,0x00000000}},	//   igns_, изва, росо_,
  { {0x201800f3,0x63a405b3,0x1f6601ce,0x00000000}},	//   rpri_, _ulin, јкам,

  { {0x8fa303d6,0x9f400229,0x1d0a0092,0x00000000}},	// [4000] цате, llië_, вези_,
  { {0x67f500eb,0x637b00fe,0xbc1a0086,0x00000000}},	//   _išju, _tänä, віді_,
  { {0xf53600b5,0x315711b4,0xdd8f00f2,0x00000000}},	//   שטער_, _דיין_, بول_,
  { {0xf4560047,0x54560047,0xba2a005d,0x00000000}},	//   ייער_, יסען_, نستم_,
  { {0x67c1001c,0xe9800085,0x00000000,0x00000000}},	//   cēji, залi_,   ,
  { {0x2d9e0003,0x2d8c004b,0xd8760044,0x00000000}},	//   _ôte_, _õde_, لاعب,
  { {0x7c85000a,0x588627b8,0x98a3005e,0x00000000}},	//   _луѓе, рыла, жије,
  { {0x25a00164,0xc7c60095,0x7f98017d,0x00000000}},	//   _œil_, јски, _tíqu,
  { {0xfaa32800,0xd6d00021,0xe8950051,0x00000000}},	//   _дато, ثقة_, gółó,
  { {0xc6f705ac,0x5e570063,0x1659005d,0x00000000}},	//   шных_, סייע_, اسيک_,
  { {0x03f90001,0xddcd000c,0x67c1001c,0x00000000}},	//   лној_, lvaţ, zēji,
  { {0x06560021,0x69d82801,0x7c3e00a3,0x00000000}},	//   _ننصح, love, irpr,
  { {0x8c480058,0x7c3e004d,0xe7b30044,0x00000000}},	//   _yuşç, hrpr, _بمند,
  { {0x67c1001c,0xc1050021,0x7e7601c2,0x00000000}},	//   vēji, صوري, dvyp,
  { {0x0443000a,0x7ae600d1,0x351b0041,0x00000000}},	//   _дејн, _øktf, _יוגנ,
  { {0x67c1001c,0x34fb0063,0x25a2008f,0x00000000}},	//   tēji, _בהוד, īklu_,
  { {0x69d82802,0x41e7000d,0xdc0f004c,0x00000000}},	// [4010] kove, _віна, _věčn,
  { {0x67c1001c,0x20052803,0x63bd2804,0x00000000}},	//   rēji, ílis_, lisn,
  { {0x629d00fe,0x69d82805,0x67c1008f,0x00000000}},	//   lyso, dove, sēji,
  { {0x443e0027,0x67c1003d,0x69d8056f,0x00000000}},	//   irt_, pēji, eove,
  { {0x443e0199,0x7b740021,0x69d800ca,0x00000000}},	//   hrt_, تطلا, fove,
  { {0x69d80008,0x7ae900c2,0xda620054,0x00000000}},	//   gove, _vzet, ївщи,
  { {0x99990006,0x31580047,0x01382177,0x00000000}},	//   _ūsų_, ייגן_, ברות_,
  { {0x1bd40086,0x63bd2806,0xfc3000de,0x00000000}},	//   _дося, jisn, _زحف_,
  { {0x7ae9017f,0x443e2807,0x63bd0247,0x00000000}},	//   _uzet, ert_, disn,
  { {0x69d81e27,0x06540085,0x67c10023,0x00000000}},	//   cove, ітыў, jējv,
  { {0x7e7b007c,0x232a0781,0x290500a8,0x00000000}},	//   _šupl, лони_, _igla_,
  { {0x63bd0150,0x06b8005d,0xc7f501ce,0x00000000}},	//   gisn, انیک_, _узећ,
  { {0x68e10146,0x443e2808,0x113a0085,0x00000000}},	//   _hyld, art_, лявы_,
  { {0x661b13b8,0xf5050121,0x3d210053,0x00000000}},	//   mpuk, _узко, यरों_,
  { {0x3ce60053,0x63bd0150,0xa7fc005b,0x00000000}},	//   _करें_, bisn, _arıy,
  { {0x2a6d00c3,0x2451004a,0xa3ac0053,0x00000000}},	//   _oseb_, mám_, _गति_,
  { {0x32090e1a,0x20050014,0x24770013,0x00000000}},	// [4020] _guay_, ílir_, _hăm_,
  { {0x67c1183d,0x00000000,0x00000000,0x00000000}},	//   mēju,   ,   ,
  { {0x7c3e0179,0x67c1001c,0x7ae00137,0x00000000}},	//   urpr, lēju, _symt,
  { {0x24510013,0x7f860021,0x7f190054,0x00000000}},	//   iám_, _الحن, _віру_,
  { {0xca560079,0x1994005a,0xdb590086,0x00000000}},	//   стењ, жаля, рює_,
  { {0x20020009,0xddcd000c,0xa898019b,0x00000000}},	//   _hiki_, rvaţ, иклу_,
  { {0x247700aa,0x6d5c240f,0xdce7001c,0x00000000}},	//   _năm_, _ibra, _tajā,
  { {0xa61403d6,0x69d82809,0xa7730062,0x00000000}},	//   омич, sove, злъч,
  { {0x5ebb00b5,0x69d8280a,0x63bd0246,0x00000000}},	//   ָזיק, pove, visn,
  { {0xddc4003d,0x68e10d02,0x7afd004a,0x00000000}},	//   stiņ, _fyld, _ústa,
  { {0x68e10dfb,0x629d001f,0x443e280b,0x00000000}},	//   _gyld, wyso, urt_,
  { {0x9f400164,0x629d00fe,0x443e280c,0x00000000}},	//   blié_, tyso, rrt_,
  { {0x63bd0a0d,0x3209008b,0x5187280d,0x00000000}},	//   risn, _quay_, бува,
  { {0x443e280e,0x6114126b,0x63bd1667,0x00000000}},	//   prt_, здру, sisn,
  { {0x6811001c,0xbebb00ac,0x63bd280f,0x00000000}},	//   _kāda, _teëk, pisn,
  { {0x02a724f8,0x6811001c,0x6d5c2810,0x00000000}},	//   _гром, _jāda, _abra,
  { {0x67c1008f,0x7ee712c1,0x877b0aeb,0x00000000}},	// [4030] cēju, сцве, נאמי,
  { {0xdcfc003d,0x76400078,0x2002004b,0x00000000}},	//   _norē, irmy, _eiki_,
  { {0xdb0b0014,0x7bd90022,0x2477008d,0x00000000}},	//   ingö, towu, _xăm_,
  { {0x8f470076,0x6d5c2811,0x7e6e0072,0x00000000}},	//   _уход, _ebra, änpä,
  { {0x245100ea,0x753800c2,0xc3340063,0x00000000}},	//   zám_, _odvz, פוס_,
  { {0x9f4200fe,0x7bd90022,0xdb1900a3,0x00000000}},	//   _ehkä_, sowu, ciwî,
  { {0x319c00b5,0x67c1001c,0x91660013,0x00000000}},	//   רבונ, zēju, _hộ_,
  { {0x2fc9001f,0xd7090076,0x2451004a,0x00000000}},	//   nnag_, шние_, vám_,
  { {0xbebb0179,0x05a90086,0x2fc900a4,0x00000000}},	//   _beëi, ивий_, inag_,
  { {0xdcf5003d,0x67c1001c,0x24510114,0x00000000}},	//   _nozī, vēju, tám_,
  { {0x9166008b,0x84580330,0xd38a09b3,0x00000000}},	//   _lộ_, брят_, айне_,
  { {0xd8d600b5,0x67c1001c,0xe8d60047,0x00000000}},	//   _וועט_, tēju, _ווער_,
  { {0x6b600026,0xddcd0130,0x245101c8,0x00000000}},	//   _hágæ, zvaš, sám_,
  { {0xd3780045,0x7ae600d1,0xbebb0104,0x00000000}},	//   ść_, _økte, _geëi,
  { {0x67c1001c,0x660300ac,0x93bd003b,0x00000000}},	//   sēju, _iink, rsăr,
  { {0xa2d50235,0x9166001b,0x1fa7137a,0x00000000}},	//   _युक्, _bộ_, окси_,
  { {0x672b03e8,0x44270185,0xa226007e,0x00000000}},	// [4040] _megj, _hwn_, _برعه,
  { {0x672b00ea,0x64412812,0x2fc900a4,0x00000000}},	//   _legj, orli, anag_,
  { {0x2fc900a4,0x66032813,0x7e7d004d,0x00000000}},	//   bnag_, _mink, _ersp,
  { {0x533700b5,0x68300025,0x64412814,0x00000000}},	//   ַנצן_, _lódá, irli,
  { {0x644100bd,0x298a00d7,0xadeb0053,0x00000000}},	//   hrli, иско_, _जीवन_,
  { {0x44270037,0x127b0047,0x6d5c2815,0x00000000}},	//   _own_, יאנע, _ubra,
  { {0x672b00d1,0x7afd01c2,0x9939142a,0x00000000}},	//   _begj, _ústn, сячу_,
  { {0x2d982816,0x248002e2,0xaa460086,0x00000000}},	//   _hore_, _čim_, _мебл,
  { {0x2d98079c,0x66032817,0x67d3003b,0x00000000}},	//   _kore_, _bink, dăjd,
  { {0x68300025,0xa2d50053,0x98bf008f,0x00000000}},	//   _códá, _युग्, ūrām_,
  { {0x2d982818,0x6811001c,0x66032819,0x00000000}},	//   _more_, _tāda, _dink,
  { {0x2d98281a,0x660313f3,0x249e0022,0x00000000}},	//   _lore_, _eink, rytm_,
  { {0xdcf5001c,0x69ca281b,0x2bdb0053,0x00000000}},	//   _pozī, onfe, यकता,
  { {0xbf9b0016,0x6603281c,0xa1840895,0x00000000}},	//   _ciên, _gink, мысл,
  { {0x84380021,0x4427002b,0x142a0054,0x00000000}},	//   _اكبر_, _gwn_, _тіло_,
  { {0x6448281d,0x6603281e,0x4fc7000d,0x00000000}},	//   mudi, _zink, ісва,
  { {0xdce70051,0x2d9804bf,0xdefb0076,0x00000000}},	// [4050] _mają, _bore_, рыв_,
  { {0x65680025,0xbf9b008b,0xe1ff0051,0x00000000}},	//   nedh, _giên, zwój_,
  { {0x6448281f,0xbc680044,0x71f800de,0x00000000}},	//   nudi, يمكن_, _بريس_,
  { {0x64480290,0xa0880063,0x69ca2820,0x00000000}},	//   iudi, _וְשִ, enfe,
  { {0x672b0031,0xc5f8001c,0x7e7d089f,0x00000000}},	//   _regj, kmē_, _ursp,
  { {0x672b0026,0x2d982821,0x4efa0063,0x00000000}},	//   _segj, _gore_, _להרו,
  { {0x660300eb,0x7e6d00ac,0x64482822,0x00000000}},	//   _rink, lwap, judi,
  { {0x2d980130,0x66032823,0x600c069a,0x00000000}},	//   _zore_, _sink, בִזְ,
  { {0x66032824,0xba77007e,0x4427002b,0x00000000}},	//   _pink, _بازت, _swn_,
  { {0x44270022,0x3f990cb6,0x6568009c,0x00000000}},	//   _pwn_, _losu_, gedh,
  { {0xbf9b001b,0x64410179,0xbebb0983,0x00000000}},	//   _riên, urli, _geëv,
  { {0x644100bd,0x66032825,0x660b00a4,0x00000000}},	//   rrli, _wink, _tugk,
  { {0x66030812,0x7bcb06d5,0x2452007e,0x00000000}},	//   _tink, ingu, ونیس,
  { {0xdce70051,0x67e5006d,0x6d1b0053,0x00000000}},	//   _zają, dóji, _प्लग_,
  { {0x64482826,0x03a60962,0xbf9b008d,0x00000000}},	//   cudi, _нико, _viên,
  { {0x2d9806b8,0xc0032827,0xf43a0063,0x00000000}},	//   _sore_, епск, _התקש,
  { {0xa3d90042,0x69ca002b,0x2d982828,0x00000000}},	// [4060] ़कर_, ynfe, _pore_,
  { {0xc27b00b5,0x63a600e8,0x3f8f0026,0x00000000}},	//   _פריי, lkkn, ögur_,
  { {0x2d9818eb,0x1d190086,0x319b0063,0x00000000}},	//   _vore_, юють_, _הבינ,
  { {0x2d980034,0xdb002829,0x00000000,0x00000000}},	//   _wore_, _almá,   ,
  { {0x93bd003b,0x2d98282a,0x6a130054,0x00000000}},	//   spăg, _tore_, еміу,
  { {0x7bcb210b,0xceb30041,0xc213009a,0x00000000}},	//   angu, _טיר_, עהו_,
  { {0x68ed0080,0xb4ea0053,0xdce70022,0x00000000}},	//   řadn, _मरे_, _pają,
  { {0xcc570063,0x64481233,0x63af008d,0x00000000}},	//   _מבלי_, vudi, xhcn,
  { {0xb21b01e1,0x35f404f2,0xb7130044,0x00000000}},	//   mvæg, мпир, ربيش,
  { {0xb21b007a,0x7bc20b54,0x6448157e,0x00000000}},	//   lvæg, liou, tudi,
  { {0xe3b9005b,0x6568282b,0xc5f8008f,0x00000000}},	//   msız_, redh, rmē_,
  { {0x6448282c,0xb4cc0053,0x64910078,0x00000000}},	//   rudi, _रखी_, džią,
  { {0xb287000d,0x6448282d,0x51871340,0x00000000}},	//   чынк, sudi, пува,
  { {0x6e3600e8,0xddcd0051,0xe3b9005b,0x00000000}},	//   dsyb, ztał, nsız_,
  { {0x98a7003b,0xf55b0063,0xddcd0022,0x00000000}},	//   mană_, _הדומ, ytał,
  { {0x94730032,0x7e6d006f,0x98a7003b,0x00000000}},	//   _أدوا, twap, lană_,
  { {0x63ad282e,0x79880035,0xdcfc0006,0x00000000}},	// [4070] _ilan, _ondw, _korė,
  { {0x799a0359,0x7e6d0104,0xb21b01e1,0x00000000}},	//   _notw, rwap, evæg,
  { {0x63ad1700,0x515a0063,0x200c004c,0x00000000}},	//   _klan, _וכתו, ídit_,
  { {0x7bc20037,0xff25007e,0x7bcb282f,0x00000000}},	//   giou, _تبدی, ungu,
  { {0x799a0185,0x1ee7007e,0x63ad0035,0x00000000}},	//   _botw, _روسی_, _mlan,
  { {0xdcfc00eb,0xddcd0045,0xf8a9007e,0x00000000}},	//   _norė, stał, يگاه_,
  { {0x7bc200e5,0x63ad2830,0x9f400014,0x00000000}},	//   biou, _olan, omið_,
  { {0x7bc20037,0x63ad00f5,0xbc560061,0x00000000}},	//   ciou, _nlan, žšíc,
  { {0x799a001f,0x6811001c,0x6d4a0e7c,0x00000000}},	//   _fotw, _tādo, ófag,
  { {0x63ad2831,0x224b2832,0x31af0058,0x00000000}},	//   _alan, duck_, _yüze_,
  { {0x69c30bcf,0x63ad2833,0x6b890130,0x00000000}},	//   mine, _blan, _kneg,
  { {0x21e400bd,0x63ad2834,0x224b01a8,0x00000000}},	//   höht_, _clan, fuck_,
  { {0x98a7003b,0x69c32835,0xc7b2009f,0x00000000}},	//   bană_, oine, _בבא_,
  { {0xdcee003d,0x6594000d,0x98a7000c,0x00000000}},	//   _labā, _пачу, cană_,
  { {0x11d70021,0xbf9a005e,0x28b00042,0x00000000}},	//   ذوفة_, ођач_, जनयि,
  { {0x7bc20034,0xa3e60053,0x2fda007e,0x00000000}},	//   xiou, _बीच_, آورد_,
  { {0x7bc21a74,0x6e360006,0x6f16059f,0x00000000}},	// [4080] viou, usyb, rcyc,
  { {0xad6600b3,0xcf890047,0x69c32836,0x00000000}},	//   باره, ױט_, jine,
  { {0x7bc20034,0x6b9b04bc,0xdb0b2837,0x00000000}},	//   tiou, _boug, bigü,
  { {0x799a00a4,0x69c32838,0x6b9b2839,0x00000000}},	//   _sotw, eine, _coug,
  { {0x7bc20037,0x799a0045,0xe3b9005b,0x00000000}},	//   riou, _potw, tsız_,
  { {0x6b8900c3,0x69c30d6a,0xb21b01e1,0x00000000}},	//   _eneg, gine, svæg,
  { {0xec16006a,0x6b9b04bc,0xaf390026,0x00000000}},	//   _آورد, _foug, _óþæg,
  { {0x17f70021,0x69c3283a,0x6b9b283b,0x00000000}},	//   ورية_, aine, _goug,
  { {0x056a018e,0x98a7003b,0x69c3283c,0x00000000}},	//   ојни_, tană_, bine,
  { {0x63ad283d,0xad760085,0xc9860593,0x00000000}},	//   _slan, звiц, _تشري,
  { {0x4438007a,0x9f400026,0x6b9b0003,0x00000000}},	//   ér_, ymið_, _youg,
  { {0xe717007e,0xe3b90058,0x03f8005d,0x00000000}},	//   _قيمت_, apın_, وژيک_,
  { {0xc17b0054,0x68e8283e,0x63ad017c,0x00000000}},	//   оїв_, _hydd, _vlan,
  { {0xa4d4019d,0x224b0359,0x225901e1,0x00000000}},	//   _полі, ruck_, rtsk_,
  { {0xcf9b02a9,0x2eed074f,0xdb0b283f,0x00000000}},	//   оја_, _šef_, tigü,
  { {0x63ad014f,0x08770047,0x6d5e00ca,0x00000000}},	//   _ulan, ועלט_, efpa,
  { {0x6b9b04bc,0x9f400026,0x24582840,0x00000000}},	// [4090] _roug, rmið_, lém_,
  { {0x6b9b0034,0xdce70051,0xd6570063,0x00000000}},	//   _soug, _zaję, וימת_,
  { {0x645a024a,0x24580080,0x61e50397,0x00000000}},	//   ntti, ném_, _ikhl,
  { {0xce95005a,0x645a2841,0xcf27007e,0x00000000}},	//   _замъ, itti, _تردي,
  { {0x645a006f,0x245801da,0x69c32842,0x00000000}},	//   htti, hém_, tine,
  { {0x245802f4,0x68e80185,0x7bc000cd,0x00000000}},	//   kém_, _bydd, _emmu,
  { {0x98be005b,0x6b9b2843,0x853c0006,0x00000000}},	//   _batı_, _toug, rkėl,
  { {0x68e80185,0xa6950635,0x69c32844,0x00000000}},	//   _dydd, ерој, sine,
  { {0x645a2845,0x68e80026,0x98a70022,0x00000000}},	//   etti, _eydd, daną_,
  { {0x68e80185,0xe8950088,0x2458017d,0x00000000}},	//   _fydd, _пазь, fém_,
  { {0x69c109fb,0x853c0006,0xa3ea093d,0x00000000}},	//   _imle, okėj, здна_,
  { {0x61e5053b,0xe3b203eb,0x853c0078,0x00000000}},	//   _akhl, ارد_, nkėj,
  { {0x645a2846,0xda0f0053,0x6d550051,0x00000000}},	//   atti, ादित_, _ocza,
  { {0x24582847,0x765b0014,0x8839009a,0x00000000}},	//   bém_, mtuy, ּתּו,
  { {0xe3b20032,0x2458017d,0xddc40058,0x00000000}},	//   _مرة_, cém_, etiş,
  { {0x201e003d,0xafe32848,0xc1780078,0x00000000}},	//   īti_, госл, žė_,
  { {0x765b00e3,0xc7b20047,0x201e109f,0x00000000}},	// [40a0] ntuy, אבן_, ūti_,
  { {0xe1f200f2,0x680a0022,0xa7fc0075,0x00000000}},	//   _حسب_, _mędr, _apıl,
  { {0x28df0161,0x315700b5,0x0b461254,0x00000000}},	//   _पुलि, _איין_, енен,
  { {0x6d55005b,0x68e81e47,0x69c12849,0x00000000}},	//   _ecza, _rydd, _amle,
  { {0x5b130086,0x2458017d,0x68e801e1,0x00000000}},	//   уміт, zém_, _sydd,
  { {0x63af001c,0x645a284a,0x98a70022,0x00000000}},	//   ībni, ytti, zaną_,
  { {0xd90d007e,0x7ae9284b,0xab2a0336,0x00000000}},	//   زین_, _eyet, _нова_,
  { {0x24580080,0x86260086,0x7ae604aa,0x00000000}},	//   vém_, ньое, _økto,
  { {0x68e8001f,0xdce5008f,0xdd1f0066,0x00000000}},	//   _wydd, mehā, líši,
  { {0x98a70051,0x68e8002b,0x9a3b0063,0x00000000}},	//   waną_, _tydd, _מתמק,
  { {0x62840d5f,0x98a70022,0xa4d42049,0x00000000}},	//   _ario, taną_, тоні,
  { {0x38cb007e,0x645a284c,0x24582840,0x00000000}},	//   _عالی_, rtti, rém_,
  { {0x27e6284d,0x6284203a,0x69c1002b,0x00000000}},	//   _ikon_, _crio, _ymle,
  { {0x65780031,0x04940021,0x2244004a,0x00000000}},	//   _uavh, _للتح, ámka_,
  { {0x9f350088,0x6284175c,0x33990044,0x00000000}},	//   кеві, _erio, _ينتج_,
  { {0x8d77007e,0x6284284e,0xddc40058,0x00000000}},	//   کارا, _frio, ttiş,
  { {0x8afd004c,0x6284284f,0xa3de0042,0x00000000}},	// [40b0] _obřa, _grio, तकर_,
  { {0x201e00cd,0x5d540699,0x64482850,0x00000000}},	//   ític_, лкут, ordi,
  { {0xdb35000a,0x9f5a00cd,0x7c670021,0x00000000}},	//   веењ, _cupó_, عائل,
  { {0xa03a0047,0x6448005b,0xddc4003b,0x00000000}},	//   _קערפ, irdi, ptiş,
  { {0xbf360063,0x7d2400ea,0x853c0006,0x00000000}},	//   _בארץ_, ítsé, rkėj,
  { {0x89a80086,0xdced0058,0x27e62851,0x00000000}},	//   нків_, şkın, _akon_,
  { {0x6811008f,0xa3e10042,0x00000000,0x00000000}},	//   _kādi, थवा_,   ,
  { {0x765b0058,0x7c252852,0x49bb005d,0x00000000}},	//   ttuy, mphr, _کارد_,
  { {0x200b000c,0xba5500e1,0x7bd80003,0x00000000}},	//   _mici_, _швај, évue,
  { {0x3ce60053,0x69c1004d,0x765b2853,0x00000000}},	//   _जुडे_, _umle, rtuy,
  { {0x6f1d006f,0x7c250139,0x478b0131,0x00000000}},	//   _ofsc, nphr, _нсдм_,
  { {0x200b0529,0xe72e0259,0x62842854,0x00000000}},	//   _nici_, _ње_, _prio,
  { {0xe29717ab,0x27ff2855,0x644811c8,0x00000000}},	//   вая_, mmun_, ardi,
  { {0x200b2856,0x6f1d0122,0x27e002e2,0x00000000}},	//   _aici_, _afsc, čine_,
  { {0x200b017f,0xddd6004a,0xcfaa007e,0x00000000}},	//   _bici_, jvyš, وارم_,
  { {0x9f4f0026,0x62842857,0x27ed0674,0x00000000}},	//   ögð_, _trio, nlen_,
  { {0x27ed2858,0x200b01f4,0x76490014,0x00000000}},	// [40c0] ilen_, _dici_, nrey,
  { {0x27ed0199,0x1d190085,0x1d230c03,0x00000000}},	//   hlen_, еюць_, имум,
  { {0x27ed2859,0xed57272c,0x7649285a,0x00000000}},	//   klen_, тох_, hrey,
  { {0x27ed285b,0xe627008b,0xfba90054,0x00000000}},	//   jlen_, _phố_, нтій_,
  { {0xddd60066,0xda770062,0x27ed285c,0x00000000}},	//   avyš, вящ_, dlen_,
  { {0xdb0b0026,0x28f80071,0x200b003b,0x00000000}},	//   rigð, нель_, _zici_,
  { {0x27ed001f,0x660a285d,0x5f190042,0x00000000}},	//   flen_, _rifk, युक्_,
  { {0x27ed285e,0x6448147d,0x7649005b,0x00000000}},	//   glen_, vrdi, frey,
  { {0xb8e90161,0xf623005e,0x442e285f,0x00000000}},	//   _ले_, адњо, _swf_,
  { {0x64480198,0x27ff003e,0x2138007d,0x00000000}},	//   trdi, amun_, jarh_,
  { {0x27ed2860,0x644810a1,0xad370063,0x00000000}},	//   blen_, urdi, כניס_,
  { {0xd5b0006a,0x76490026,0xa73a03eb,0x00000000}},	//   _گفت_, brey, _آثار_,
  { {0xdcf500c2,0x6811001c,0x9f400072,0x00000000}},	//   _razč, _rādi, iliä_,
  { {0x442e002b,0x21382861,0xe5340054,0x00000000}},	//   _twf_, garh_, _секь,
  { {0x99990066,0x64a30092,0x4034019c,0x00000000}},	//   _ísť_, _ваја, иерс,
  { {0xa3470088,0x5f240635,0x645d003b,0x00000000}},	//   _рэкл, ифуз, ăsit,
  { {0x291e01e3,0xfe700021,0xdb0000ea,0x00000000}},	// [40d0] _ofta_, يدك_, _elmú,
  { {0x68ed0080,0x6729007d,0x865b0063,0x00000000}},	//   řadi, zbej, ודמי,
  { {0x6811008f,0x27ed2862,0x27ff2863,0x00000000}},	//   _tādi, ylen_, ymun_,
  { {0x9b440044,0xe4ab009a,0x00000000,0x00000000}},	//   لنمو, וֹדָ,   ,
  { {0x27ed0093,0xeab0002a,0xd9450867,0x00000000}},	//   vlen_, يعه_, гели,
  { {0x27ed1a91,0x487900a0,0x76492864,0x00000000}},	//   wlen_, есия_, vrey,
  { {0x18660062,0x27ed2865,0xddcd01d1,0x00000000}},	//   гащи_, tlen_, ovaž,
  { {0x86990079,0x291e2866,0x27ed1c41,0x00000000}},	//   етот_, _efta_, ulen_,
  { {0x67292867,0x61ee00c7,0x3ea92868,0x00000000}},	//   rbej, ylbl, nyat_,
  { {0x59b70161,0x98c70635,0x27ed2869,0x00000000}},	//   _अतिर, _исел, slen_,
  { {0x58d416e0,0x76490014,0xa87b0044,0x00000000}},	//   _кофт, srey, _تحذر_,
  { {0xc20901d8,0x3ea90397,0xddcd074f,0x00000000}},	//   _זה_, kyat_, jvaž,
  { {0xdcf40130,0x59b70042,0xc447005d,0x00000000}},	//   _čača, _अतार, ریکن_,
  { {0xddcd007d,0x44250fc4,0x67c1008f,0x00000000}},	//   evaž, ppl_, jējz,
  { {0x26c201a8,0x9f400072,0xa06705c7,0x00000000}},	//   úkov_, yliä_, лара_,
  { {0x645c0268,0x2000003b,0x44f30013,0x00000000}},	//   àrie, umii_, _ị_,
  { {0x213800c2,0xdfcf0021,0x4d66286a,0x00000000}},	// [40e0] parh_, سيك_, лкав,
  { {0xa0c6007e,0x127b0041,0xed570f56,0x00000000}},	//   _ميخو, _טאפע, лоу_,
  { {0xf53600b5,0x6811001c,0xacf60d34,0x00000000}},	//   רטער_, _kādu, учај,
  { {0x65ad0024,0xdca3005e,0xb09b0063,0x00000000}},	//   _súhl, љаци, _ניכר,
  { {0x60d6001c,0x8cd00053,0x0a940085,0x00000000}},	//   šamā, _दशको, ралю,
  { {0xf8b0007e,0x82770041,0xfce605ce,0x00000000}},	//   يکا_, טענע_, _бого,
  { {0xcc780063,0x07e6005e,0x3c780063,0x00000000}},	//   _בְּר, лцим, _בָּב,
  { {0x3f80286b,0x7c3e14a7,0x6aad013d,0x00000000}},	//   ndiu_, mspr, önfé,
  { {0x7c3e04d3,0x36d401f8,0x35b4286c,0x00000000}},	//   lspr, ропр, ибир,
  { {0xa5f80001,0x7dcb0022,0xed220085,0x00000000}},	//   ђену_, ożsa, абiў_,
  { {0x6d430025,0xd7ef0525,0x69ca00dd,0x00000000}},	//   ónai, _гу_, mife,
  { {0xdb00017d,0x7c3e286d,0xdb0b00a5,0x00000000}},	//   _romê, ispr, rigö,
  { {0xdcf5003d,0x7c3e004d,0x65940152,0x00000000}},	//   _mazā, hspr, _валу,
  { {0x3f8012a1,0x7c3e286e,0x645d003b,0x00000000}},	//   ediu_, kspr, ăsir,
  { {0xd48f0076,0x10480086,0x351b0149,0x00000000}},	//   _ур_, ляти_, _אוונ,
  { {0x6d4a286f,0x7c3e011d,0x443e2870,0x00000000}},	//   ófan, dspr, mst_,
  { {0x69ca00ea,0x7c3e2871,0x443e2872,0x00000000}},	// [40f0] kife, espr, lst_,
  { {0x443e2873,0x7c3e244c,0xdd910044,0x00000000}},	//   ost_, fspr, غوا_,
  { {0x443e2874,0x9f490025,0xdb000003,0x00000000}},	//   nst_, llaí_, _homè,
  { {0x443e0027,0x753a004d,0x9f490139,0x00000000}},	//   ist_, hatz, olaí_,
  { {0x443e00bd,0x2d8500f8,0x753a004d,0x00000000}},	//   hst_, _óleo_, katz,
  { {0x443e2875,0x80ca0053,0x7c3e2109,0x00000000}},	//   kst_, _हेडे, bspr,
  { {0x443e2876,0xa7b500e1,0x49b8007e,0x00000000}},	//   jst_, исиј, داند_,
  { {0x443e08dc,0x07a52877,0xf771002a,0x00000000}},	//   dst_, раин, زاب_,
  { {0x443e2878,0x7bcb2879,0x86c5005d,0x00000000}},	//   est_, migu, شيدن,
  { {0x273300aa,0x27e001a6,0x753a0268,0x00000000}},	//   ản_, čina_, gatz,
  { {0x443e287a,0x23690089,0x6aab001f,0x00000000}},	//   gst_, _bbaj_, lygf,
  { {0x888a00b5,0xbef50053,0x889a0063,0x00000000}},	//   _שרײַ, _आरंभ_, _בבעי,
  { {0x2d9102b0,0xdb000803,0x443e287b,0x00000000}},	//   _onze_, _comè, ast_,
  { {0xdb000268,0x673b0006,0x443e1917,0x00000000}},	//   _domè, lauj, bst_,
  { {0x98a70080,0x6811001c,0x9f490139,0x00000000}},	//   vaně_, _tādu, alaí_,
  { {0x673b00eb,0x9f490139,0x7880004c,0x00000000}},	//   nauj, blaí_, lává,
  { {0xd007287c,0x7bcb166b,0xed5a0141,0x00000000}},	// [4100] рете_, digu, коа_,
  { {0x7c3e287d,0xf815008b,0x9d4603d6,0x00000000}},	//   tspr, _ước_, режд,
  { {0x98a70080,0x62860019,0x8c7a0062,0x00000000}},	//   raně_, lvko, ъщат_,
  { {0x1a2a0086,0x63a4287e,0x7c3e2790,0x00000000}},	//   вжди_, _join, rspr,
  { {0x63a403b2,0x673b00eb,0x63b60185,0x00000000}},	//   _moin, dauj, _mlyn,
  { {0x3eaf0146,0x63b6001f,0x7c3e287f,0x00000000}},	//   øgte_, _llyn, pspr,
  { {0x788002f4,0x7b96019d,0x3c3c0080,0x00000000}},	//   dává, _краї, _dává_,
  { {0x9634019d,0x2ca7089f,0x63a42003,0x00000000}},	//   бниц, ände_, _noin,
  { {0x443e001f,0x6b82002b,0x3b070b0e,0x00000000}},	//   wst_, mdog, _вето_,
  { {0xdb000994,0x443e0122,0x63a40025,0x00000000}},	//   _nomé, tst_, _aoin,
  { {0x63b60185,0x7afd0061,0x63a42880,0x00000000}},	//   _blyn, _ústr, _boin,
  { {0x753a00bd,0x6b8204ad,0x63a42881,0x00000000}},	//   satz, ndog, _coin,
  { {0x443e1c3f,0x63a41729,0x6d5c0139,0x00000000}},	//   sst_, _doin, _ocra,
  { {0x463b00b5,0xdb000732,0x6b8000ac,0x00000000}},	//   _יעדע, _comé, _lamg,
  { {0xa1840088,0x63a40025,0x63b6001f,0x00000000}},	//   цыял, _foin, _flyn,
  { {0x63a42882,0x63b6035a,0x200f004b,0x00000000}},	//   _goin, _glyn, ögi_,
  { {0x6b82002b,0x69c82883,0x7bcb2884,0x00000000}},	// [4110] ddog, _omde, vigu,
  { {0x71750049,0x71790456,0x673b0061,0x00000000}},	//   _اهدا, _сбор_, zauj,
  { {0x2ca70529,0xe2ab007e,0x6fb5007e,0x00000000}},	//   ând_, _ساکن_, _همدا,
  { {0x6d5c000c,0x6b80001f,0x6f950021,0x00000000}},	//   _ecra, _camg, _الحض,
  { {0xb21b007a,0x673b0006,0x60db005b,0x00000000}},	//   kvæm, vauj, ğumu,
  { {0x7bcb2885,0x6d5c0139,0x9da80062,0x00000000}},	//   sigu, _gcra, _къса_,
  { {0x7bcb0268,0x78800080,0x673b2886,0x00000000}},	//   pigu, vává, tauj,
  { {0xb21b0014,0x6b801566,0x76400014,0x00000000}},	//   tvæl, _gamg, fsmy,
  { {0x63a40027,0x673b109f,0x7880004c,0x00000000}},	//   _roin, rauj, tává,
  { {0x63a42226,0xb5790b3f,0xb21b00b9,0x00000000}},	//   _soin, ущих_, rvæl,
  { {0x63a404bc,0x98ab008f,0x7880004c,0x00000000}},	//   _poin, ēlēm_, rává,
  { {0x645c00cd,0x79812887,0xf1a9009a,0x00000000}},	//   ària, _halw, _אס_,
  { {0x6d472888,0x63a40be3,0x1b7a0047,0x00000000}},	//   _odja, _voin, נטשע,
  { {0xc6920063,0x41b50121,0x853c0078,0x00000000}},	//   _מאד_, осст, ukėt,
  { {0x63a4024a,0x79812889,0xdce70023,0x00000000}},	//   _toin, _malw, _majē,
  { {0x64410f8c,0x6d47288a,0x24430058,0x00000000}},	//   msli, _adja, mım_,
  { {0x2443005b,0x8fa3288b,0x6b801233,0x00000000}},	// [4120] lım_, чате, _ramg,
  { {0x1d0a005e,0x6b80288c,0x7bc9006c,0x00000000}},	//   гези_, _samg, _ameu,
  { {0x2443005b,0xb53a0047,0x7afb00ea,0x00000000}},	//   nım_, רגעש, _azut,
  { {0x7e7d158f,0x6441288d,0x9992004c,0x00000000}},	//   _fssp, isli, údža_,
  { {0xab65001c,0x6b82288e,0x79811542,0x00000000}},	//   daļā, rdog, _balw,
  { {0x644100eb,0x3f82024a,0x2443005b,0x00000000}},	//   ksli, _haku_, kım_,
  { {0x6441010a,0x7afb00ea,0x3f820150,0x00000000}},	//   jsli, _ezut, _kaku_,
  { {0x27e000c3,0xf0930063,0x2443005b,0x00000000}},	//   čino_, לנו_, dım_,
  { {0x7e64288f,0x201a2890,0x79812891,0x00000000}},	//   ntip, _lupi_, _falw,
  { {0x798119c5,0xb865006a,0x3f822892,0x00000000}},	//   _galw, _ژانو, _laku_,
  { {0x53990086,0xe3750121,0x64410e6d,0x00000000}},	//   авня_, олны, gsli,
  { {0x69d8003d,0xb8de0161,0x61e10053,0x00000000}},	//   lnve, ुछ_, पक्ष,
  { {0x64411522,0x7e64008f,0xb6380002,0x00000000}},	//   asli, jtip, _тплф_,
  { {0x2443005b,0xbddb0003,0xa159005e,0x00000000}},	//   bım_, _avèn, јаву_,
  { {0x3f822893,0xdc3c0006,0x24430058,0x00000000}},	//   _baku_, _išėj, cım_,
  { {0x69d8004d,0x1fa404f2,0xc7b1009a,0x00000000}},	//   hnve, пруг, ֵ֑ן_,
  { {0x680a0045,0x3f870080,0xde590086,0x00000000}},	// [4130] _będz, ěnu_, разі_,
  { {0x201a0035,0x998d085a,0x7afb0022,0x00000000}},	//   _fupi_, _svež_, _rzut,
  { {0xccfb0001,0x7e6400a8,0x6ad10082,0x00000000}},	//   ућа_, atip, तप्र,
  { {0x395e0034,0x2d9c00c7,0x69d8015d,0x00000000}},	//   _acts_, över_, enve,
  { {0x69d80026,0x2443005b,0x6fb5007e,0x00000000}},	//   fnve, zım_, _همگا,
  { {0x6e2d051e,0x2443005b,0xd23c0063,0x00000000}},	//   mpab, yım_, נגול,
  { {0x6e2d1e04,0x29fd0066,0xab65008f,0x00000000}},	//   lpab, _kňaz_, taļā,
  { {0xa4cd00a8,0xf62519b6,0x680a056c,0x00000000}},	//   _ščoč, одио, _kędy,
  { {0x959927b5,0x79812894,0xa93d000d,0x00000000}},	//   атну_, _talw, _адзi,
  { {0x2443005b,0xec350047,0x644700c2,0x00000000}},	//   tım_, ֿאָר_, šjim,
  { {0xd4690184,0x87e70928,0x628d0139,0x00000000}},	//   шине_, _люде, _arao,
  { {0x244301f7,0x64412895,0xe6950049,0x00000000}},	//   rım_, rsli, _ولاد,
  { {0xbebb0122,0x2443005b,0x628d177f,0x00000000}},	//   _geëx, sım_, _crao,
  { {0xe692007e,0x24430058,0x644e00be,0x00000000}},	//   _آلود, pım_, ábic,
  { {0x64430080,0x03a60bf5,0x3f820b45,0x00000000}},	//   _uvni, _мико, _paku_,
  { {0xa3be016a,0xd5e2008b,0x680a0051,0x00000000}},	//   _इति_, _trọ, _sędz,
  { {0x3e87005a,0x6e2d002c,0x628d0025,0x00000000}},	// [4140] ойто_, gpab, _grao,
  { {0xdd92006a,0x7e642896,0x201a12aa,0x00000000}},	//   بوط_, rtip, _tupi_,
  { {0x7e6415d7,0x2a7f0019,0xdcfc00c2,0x00000000}},	//   stip, _asub_, _tarč,
  { {0x2ca700c7,0xcb6a1a2f,0x6d430014,0x00000000}},	//   ända_, раде_, ónar,
  { {0x09e60131,0x19940085,0xfaa30085,0x00000000}},	//   оодн, заля, мацо,
  { {0x8d76007e,0x7646005f,0x31780244,0x00000000}},	//   _باحا, škyk, nerz_,
  { {0x93bd00dd,0x69d82897,0xbb560044,0x00000000}},	//   spăi, rnve, _ونسب,
  { {0xffb70047,0xca760475,0x0c23013c,0x00000000}},	//   ַליש_, _музы, _імун,
  { {0x69d9013d,0x39460085,0xdb00011b,0x00000000}},	//   óbeá, _мнаг, _komí,
  { {0x28960001,0xb21b01e1,0xda7b0063,0x00000000}},	//   _мјес, svæk, _דנמר,
  { {0x628d0139,0xd5b70636,0x4917009a,0x00000000}},	//   _srao, ісь_, _וקבל_,
  { {0xf1bf013d,0xdb000061,0x28c30042,0x00000000}},	//   ppák_, _lomí, _वेटि,
  { {0x9f490994,0x51872898,0x00000000,0x00000000}},	//   llaç_, оува,   ,
  { {0x65ad0066,0x27e902f7,0xc1eb0121,0x00000000}},	//   _súhv, čane_, рьме_,
  { {0x2d8300c2,0xddc40078,0xd6d90022,0x00000000}},	//   _raje_, atiū, mała_,
  { {0xcf980138,0x6e2d0019,0x09b70053,0x00000000}},	//   оју_, tpab, _अत्य,
  { {0x2d830331,0xcd2b0044,0x82370044,0x00000000}},	// [4150] _paje_, لسان_, _برعا,
  { {0xdc8b00d7,0xdb0000f8,0xd6d90022,0x00000000}},	//   исел_, _comí, nała_,
  { {0xdb0003d9,0xd6d90022,0x68270058,0x00000000}},	//   _domí, iała_, _kıde,
  { {0x207a00b5,0x307a0047,0x907a0063,0x00000000}},	//   _פארא, _פארנ, _פטרי,
  { {0x2009001c,0x7af60051,0xd6d90051,0x00000000}},	//   mmai_, żytn, kała_,
  { {0x20092899,0xc984005e,0xd6d90022,0x00000000}},	//   lmai_, дући, jała_,
  { {0xcb35005a,0x01380063,0xd6d90051,0x00000000}},	//   _невъ, חרות_, dała_,
  { {0xe7620062,0x31780022,0x06550085,0x00000000}},	//   евъп, zerz_, птоў,
  { {0xe81b0053,0x23790850,0x2a7f004b,0x00000000}},	//   _पूरा_, desj_, _usub_,
  { {0xd6d90022,0xc7b8007d,0xc5650074,0x00000000}},	//   gała_, _ruđe_, чкок,
  { {0x317800b2,0x2009013d,0xb9c40593,0x00000000}},	//   verz_, kmai_, _تقلي,
  { {0x78fa0063,0x69080063,0x00000000,0x00000000}},	//   _הפעו, _וּנְ,   ,
  { {0x27ed26df,0x471a0063,0xb184004c,0x00000000}},	//   moen_, _הונג, íťov,
  { {0x91b1008b,0x7c29054e,0x216a005e,0x00000000}},	//   _đạt_, _čern, љиви_,
  { {0x10a6005a,0x7531001c,0x92a90022,0x00000000}},	//   чивн, īdzē, _połó,
  { {0xc7b8007d,0x27ed06f8,0xef1a202f,0x00000000}},	//   _tuđe_, noen_, сма_,
  { {0xdee3289a,0x31780534,0xdb00004c,0x00000000}},	// [4160] еоти, perz_, _pomí,
  { {0x2009289b,0x27ed09fe,0xfce6005e,0x00000000}},	//   amai_, hoen_, позо,
  { {0xe1ff006d,0x61ee2223,0x711b0047,0x00000000}},	//   otón_, mobl, _לויפ,
  { {0xdb000529,0xe1ff006d,0x2009000c,0x00000000}},	//   _româ, ntón_, cmai_,
  { {0x27ed0250,0x61ee00c2,0xdcfc008f,0x00000000}},	//   doen_, oobl, _darā,
  { {0x61ee289c,0x8c4622e8,0x4efb009a,0x00000000}},	//   nobl, _неге, _להכו,
  { {0x2d980137,0x38c8007e,0x31570041,0x00000000}},	//   _inre_, غاتی_, ליסן_,
  { {0x27ed0031,0xd6d90045,0xf8030088,0x00000000}},	//   goen_, wała_, нчын,
  { {0x61ee0855,0xd6d90051,0x9f4000ea,0x00000000}},	//   kobl, tała_, llió_,
  { {0x273a008b,0x6d5e289d,0x61ee004c,0x00000000}},	//   ẫn_, ngpa, jobl,
  { {0x20090006,0x61ee08ea,0x27ed00ac,0x00000000}},	//   ymai_, dobl, boen_,
  { {0xd6d90022,0x61ee0023,0x9cd7009a,0x00000000}},	//   sała_, eobl, לויה_,
  { {0xa3be016a,0x59b00042,0xd6d90022,0x00000000}},	//   _इतर_, _जकार, pała_,
  { {0xd49a0086,0xbf9b289e,0xa91c0066,0x00000000}},	//   _гри_, _chên, _maľo,
  { {0x657a244c,0x7c2900a8,0x62800046,0x00000000}},	//   meth, _čero, æmor,
  { {0x2009289f,0x30140062,0x645a28a0,0x00000000}},	//   umai_, едср, muti,
  { {0x645a0238,0x394c28a1,0x61ee28a2,0x00000000}},	// [4170] luti, _odds_, bobl,
  { {0xd90404de,0x27ed0122,0xadf40141,0x00000000}},	//   _می_, zoen_, епуш,
  { {0xdcfc003d,0x645a28a3,0x69c00053,0x00000000}},	//   _parā, nuti, वसनी,
  { {0x6d5e00bb,0x394c0034,0x8af91bdd,0x00000000}},	//   agpa, _adds_, онес_,
  { {0xc5f8001c,0xdb00017d,0x645a004b,0x00000000}},	//   klē_, _romã, huti,
  { {0x645a28a4,0xe9d8000d,0xc895005e,0x00000000}},	//   kuti, пкі_, дрињ,
  { {0xb7b500aa,0xe7390055,0x27ed0831,0x00000000}},	//   _dụn, оей_, toen_,
  { {0x645a28a5,0x3f8928a6,0x22490a1e,0x00000000}},	//   duti, ndau_, _ovak_,
  { {0xdce70006,0x386700b9,0x27ed28a7,0x00000000}},	//   _pajė, stnr_, roen_,
  { {0x657a0037,0x645a0009,0x27ed28a8,0x00000000}},	//   geth, futi, soen_,
  { {0x645a28a9,0xdcfc003b,0xdb000025,0x00000000}},	//   guti, _iară, _iomá,
  { {0xd6ce006a,0x657a001f,0x7c29005f,0x00000000}},	//   اقی_, aeth, _čerl,
  { {0x3f890185,0x2b4d0089,0xe1ff006d,0x00000000}},	//   ddau_, _mdec_, rtón_,
  { {0xe1ff006d,0x661d0014,0xd6d90022,0x00000000}},	//   stón_, ísku, lało_,
  { {0x7afd01f2,0xe1ff00ea,0x30750121,0x00000000}},	//   _østf, mtól_, нутс,
  { {0x3e660164,0x61ee0c61,0xee3a28aa,0x00000000}},	//   tôt_, sobl, жна_,
  { {0x7dc01b58,0x42c7005a,0x61ee270a,0x00000000}},	// [4180] _löse, _огън_, pobl,
  { {0x3f890c70,0xdb0028ab,0xfd1200b3,0x00000000}},	//   adau_, _romà, نجا_,
  { {0x93bd000c,0xdb0001a8,0x6d5e28ac,0x00000000}},	//   mpăr, _somà, rgpa,
  { {0x3e660164,0x657a00ea,0xd6d90022,0x00000000}},	//   pôt_, zeth, jało_,
  { {0xe1ff00ea,0xd6d90022,0xab770044,0x00000000}},	//   któl_, dało_, ظمها_,
  { {0xfaa30856,0x7dc0004d,0x3eaf004d,0x00000000}},	//   таљо, _böse, ägte_,
  { {0xdb000114,0x93bd003b,0x657a013d,0x00000000}},	//   _domá, ipăr, veth,
  { {0x657a0185,0xdb0000cd,0x7c2e006f,0x00000000}},	//   weth, _tomà, _itbr,
  { {0x6e220027,0x8966042c,0xe9da0062,0x00000000}},	//   íobh, _окаж, _дка_,
  { {0x65ad0024,0xb8b60001,0x645a28ad,0x00000000}},	//   _súhr, _осећ, tuti,
  { {0x628400fe,0x3f89001f,0x657a28ae,0x00000000}},	//   _asio, ydau_, reth,
  { {0x7bc20173,0xb21b0026,0x645a28af,0x00000000}},	//   nhou, kvæt, ruti,
  { {0x6d4e0743,0x7d1c00c2,0xe5c6015a,0x00000000}},	//   _odba, _ogrs, _оско,
  { {0x79881041,0x3f89001f,0x6d4e00b9,0x00000000}},	//   _jadw, wdau_, _ndba,
  { {0x69c60006,0x29180066,0x7bc215f1,0x00000000}},	//   _įkel, _úrad_, khou,
  { {0x7bc20122,0x80a00053,0xd5b8008f,0x00000000}},	//   jhou, _ऑपरे, lkā_,
  { {0x799a0102,0x6e2400ac,0x7c2e001c,0x00000000}},	// [4190] _ontw, gqib, _atbr,
  { {0x7bc228b0,0x63ad28b1,0xd6d90051,0x00000000}},	//   ehou, _hoan, zało_,
  { {0x2d870024,0x3a2d28b2,0x798a002b,0x00000000}},	//   ľne_, _step_, ddfw,
  { {0x7bc20706,0x799a28b3,0x442e0089,0x00000000}},	//   ghou, _antw, _mtf_,
  { {0xdb000114,0xda640021,0x798828b4,0x00000000}},	//   _pomá, ناوي, _badw,
  { {0x7988001f,0xd6d90051,0x9f400026,0x00000000}},	//   _cadw, wało_, llið_,
  { {0x6d4528b5,0x7988001f,0xd6d90051,0x00000000}},	//   maha, _dadw, tało_,
  { {0x799a0199,0x644828b6,0x6d45035d,0x00000000}},	//   _entw, dsdi, laha,
  { {0x201928b7,0x442e28b8,0xe1ff013d,0x00000000}},	//   _misi_, _atf_, ttól_,
  { {0x77b50747,0x6d4528b9,0x443c1c4f,0x00000000}},	//   _máxi, naha, _bwv_,
  { {0x69c30025,0xe1ff28ba,0x66180249,0x00000000}},	//   mhne, rtól_, _divk,
  { {0xdb00010a,0x6d4500bb,0xe1ff00ea,0x00000000}},	//   _domæ, haha, stól_,
  { {0x63ad001b,0x6d45204d,0xb21b04aa,0x00000000}},	//   _doan, kaha, dvæs,
  { {0x6d4528bb,0x7bc228bc,0x76490058,0x00000000}},	//   jaha, zhou, msey,
  { {0x6d45014f,0x7dc000bd,0x11d70021,0x00000000}},	//   daha, _lösc, روفة_,
  { {0x67290118,0x93bd000c,0x6d430014,0x00000000}},	//   ncej, spăr, ðnan,
  { {0x62840035,0x7649005b,0x6d4528bd,0x00000000}},	// [41a0] _usio, nsey, faha,
  { {0x6b9b0228,0x7af60051,0x6d450bbf,0x00000000}},	//   _anug, żytk, gaha,
  { {0x7bc20706,0x79881417,0xf1bf28be,0x00000000}},	//   thou, _radw, rpát_,
  { {0x7988001f,0x2e240026,0xddcd0051,0x00000000}},	//   _sadw, _töf_, grał,
  { {0xb21b0d02,0x7bc212bc,0x6d45035d,0x00000000}},	//   lvær, rhou, baha,
  { {0x6d4e00b9,0x672b05b9,0x6d45003e,0x00000000}},	//   _udba, _afgj, caha,
  { {0xb21b07e6,0x7c2e0a2e,0x307a0047,0x00000000}},	//   nvær, _utbr, לאַנ,
  { {0x2d8a00bd,0x3ec50006,0x76490014,0x00000000}},	//   _habe_, ųstų_, fsey,
  { {0x7bc00551,0x69c30025,0x63ad28bf,0x00000000}},	//   _ilmu, bhne, _roan,
  { {0x69c3162b,0xb21b00b9,0xceb30063,0x00000000}},	//   chne, kvær, טיח_,
  { {0x644800eb,0xf8bf0002,0xd5b8008f,0x00000000}},	//   usdi, _сé_, rkā_,
  { {0xd5b8003d,0xb21b00b9,0x64481c41,0x00000000}},	//   skā_, dvær, rsdi,
  { {0x6d4528c0,0x63ad0877,0xdb0b004d,0x00000000}},	//   yaha, _voan, ckgä,
  { {0x7afd02ab,0x201914f1,0x27e01ba3,0x00000000}},	//   _øste, _sisi_, činu_,
  { {0x7bc0005b,0xb21b00b9,0x6d4500fe,0x00000000}},	//   _olmu, gvær, vaha,
  { {0x6d4528c1,0xe1ff013d,0x70e10042,0x00000000}},	//   waha, otók_, _नशील,
  { {0x9f400026,0x201928c2,0x201e0014,0x00000000}},	// [41b0] rlið_, _visi_, ítir_,
  { {0x9f400026,0x7bc028c3,0x9ce70b4a,0x00000000}},	//   slið_, _almu, нцел,
  { {0xf99f0013,0xdce70051,0x6d450859,0x00000000}},	//   _đè_, _obją, raha,
  { {0x6d45076b,0x77b500be,0x225905e7,0x00000000}},	//   saha, _táxi, orsk_,
  { {0x6d4518ab,0x69c319d9,0xe1ff013d,0x00000000}},	//   paha, thne, jtók_,
  { {0x2d8a03a7,0xb23c0041,0xfa34005d,0x00000000}},	//   _gabe_, לעדז, ارند,
  { {0x7e6d28c4,0x69c30124,0x18a5014b,0x00000000}},	//   ltap, rhne, тайм,
  { {0x27e902f7,0x69c328c5,0x6b9b002b,0x00000000}},	//   čano_, shne, _unug,
  { {0x9be40054,0xaa580141,0x7e6d28c6,0x00000000}},	//   _сірк, _питу_, ntap,
  { {0xdb0001e3,0x6827000d,0x7e6d005b,0x00000000}},	//   _domä, _зьдз, itap,
  { {0x3947089c,0x69c128c7,0xf5020062,0x00000000}},	//   mans_, _ille, изьо,
  { {0x394728c8,0xddc4003b,0x7d1a0014,0x00000000}},	//   lans_, otiţ, _útse,
  { {0xddc4000c,0xd2990086,0x7dc00137,0x00000000}},	//   ntiţ, нтрі_, _lösa,
  { {0xdb1b00cd,0xddc4003b,0xe5790086,0x00000000}},	//   _lluï, itiţ, _цзк_,
  { {0xb21b010a,0x7e6d23f3,0x2d8a28c9,0x00000000}},	//   tvær, etap, _rabe_,
  { {0x2d8a04a6,0xb21b00b9,0xc2c60021,0x00000000}},	//   _sabe_, uvær, _ليبي,
  { {0xb21b0146,0x7e6d1f9a,0x321a0240,0x00000000}},	// [41c0] rvær, gtap, _tipy_,
  { {0xb21b010a,0x1ea90021,0x7dc0004d,0x00000000}},	//   svær, راقي_, _bösa,
  { {0x0b460086,0x7e6d002c,0x9f40006f,0x00000000}},	//   внен, atap, nnië_,
  { {0x248702dd,0xacf528ca,0xdca30095,0x00000000}},	//   _msnm_, учуј, јаци,
  { {0x394728cb,0xda6306da,0x4ad20042,0x00000000}},	//   fans_, ивци, _देशव,
  { {0x394728cc,0x26060042,0x5eeb009a,0x00000000}},	//   gans_, _सीढी_, _חַלְ,
  { {0xdb1b00cd,0x83fd007d,0xdca31f1d,0x00000000}},	//   _fluï, luđe, _кари,
  { {0x39470104,0x69c10d7d,0xd90d007e,0x00000000}},	//   aans_, _elle, سین_,
  { {0x83fd017f,0x394728cd,0x3ffb0041,0x00000000}},	//   nuđe, bans_, ופקע,
  { {0x394728ce,0x3d200053,0xe1ff28cf,0x00000000}},	//   cans_, _बलों_, rtók_,
  { {0xa7660002,0x69d828d0,0x3a240168,0x00000000}},	//   _акед, mive, _hump_,
  { {0xccf30063,0xe737005a,0x22590076,0x00000000}},	//   יכת_, _аец_, нимы_,
  { {0xe2980088,0x3a2428d1,0x645d28d2,0x00000000}},	//   ваў_, _jump_, ąsia,
  { {0xca48008b,0x69d828d3,0x629628d4,0x00000000}},	//   iờ_, nive, _dryo,
  { {0x3f8b0089,0xca480013,0x3a2412a9,0x00000000}},	//   _pacu_, hờ_, _lump_,
  { {0x7e6d28d5,0x645a14b3,0x394728d6,0x00000000}},	//   ttap, mrti, zans_,
  { {0x5d99000d,0xdf44000d,0x69d828d7,0x00000000}},	// [41d0] нкаў_, рэсп, kive,
  { {0x7e6d28d8,0x69d800c2,0x645a28d9,0x00000000}},	//   rtap, jive, orti,
  { {0x7e6d28da,0x63bd0006,0x7afb0150,0x00000000}},	//   stap, oksn, _syut,
  { {0x645a0026,0x83fd007d,0xa5150047,0x00000000}},	//   irti, buđe, אַנג_,
  { {0x2b4400e3,0x8aa7005a,0x63bd28db,0x00000000}},	//   _demc_, ържд, iksn,
  { {0x69d80a59,0xddc4003b,0x1a68007e,0x00000000}},	//   give, rtiţ, ئیلی_,
  { {0xddc4000c,0x2d810019,0x5964005a,0x00000000}},	//   stiţ, mehe_, ръча,
  { {0x2cbc0031,0x2d810019,0x178514cf,0x00000000}},	//   øvde_, lehe_, угим,
  { {0x3a2418c3,0x645a1c86,0x69d81a1b,0x00000000}},	//   _gump_, erti, bive,
  { {0x7dc000c7,0x69d80290,0xddcd0051,0x00000000}},	//   _lösn, cive, jważ,
  { {0x59b80053,0x2d8100bd,0x98bc00dd,0x00000000}},	//   _अवतर, iehe_, ravă_,
  { {0xdb1b0268,0x9f400250,0x2d81149a,0x00000000}},	//   _lluí, rnië_, hehe_,
  { {0xe1ff0045,0x63bd00e8,0x9f40006f,0x00000000}},	//   ntów_, êrna, snië_,
  { {0xa594005a,0xf1ce0053,0xddc40006,0x00000000}},	//   _връщ, होंन, ktiš,
  { {0x20b50121,0x957c0022,0xb5fd007d,0x00000000}},	//   аётс, snąc, guše,
  { {0xe1ff0051,0x200b0080,0x394500cd,0x00000000}},	//   któw_, _chci_, _lels_,
  { {0x27ff00fe,0x76550051,0xe81b0053,0x00000000}},	// [41e0] ilun_, ązyw, _पूछा_,
  { {0xdca60001,0x531b0063,0xbd46007e,0x00000000}},	//   лази, _אופצ, اناي,
  { {0x69d81172,0x27e90b59,0x83fd007d,0x00000000}},	//   vive, čanj_, suđe,
  { {0xab2a0160,0x3a24085c,0x394501f4,0x00000000}},	//   хода_, _pump_, _aels_,
  { {0x673b00c3,0x69d813bb,0x11f6009a,0x00000000}},	//   dbuj, tive, ְזֶל_,
  { {0x7c29108f,0x7d0300bd,0x20000072,0x00000000}},	//   _červ, ünsc, llii_,
  { {0x39450c3f,0x6e2600a4,0xdce70051,0x00000000}},	//   _dels_, _hukb, _obję,
  { {0x76aa183f,0xddcd0051,0xfc1a0021,0x00000000}},	//   етов_, zważ, _أقرب_,
  { {0xdcee0078,0x3945004d,0xd5b00044,0x00000000}},	//   _pabė, _fels_, قفة_,
  { {0x645a00c2,0x27ff004b,0x7afd000e,0x00000000}},	//   trti, alun_, _østa,
  { {0xdb090026,0x8d5b0047,0x35f3000d,0x00000000}},	//   _hleð, עכטי, спэр,
  { {0x6b820025,0xd2510021,0x57ea0062,0x00000000}},	//   neog, ينج_, _ядем_,
  { {0xdb19004d,0x63bd2401,0x59b80042,0x00000000}},	//   chwä, rksn, _अवार,
  { {0x645a00c2,0x171b009a,0xda4b009a,0x00000000}},	//   prti, _נוגע, עֲכָ,
  { {0xdb0002dd,0x860708aa,0xe1ff0022,0x00000000}},	//   _comú, _حقوق_, ztów_,
  { {0xb5fd0114,0x200003a4,0xe1ff0022,0x00000000}},	//   ruše, glii_, ytów_,
  { {0x6b8228dc,0xde580054,0x2d81004d,0x00000000}},	// [41f0] deog, латі_, tehe_,
  { {0x2000003b,0xbddb0003,0x21671f1d,0x00000000}},	//   alii_, _avèr, _стиг,
  { {0x2d810009,0xcd07065b,0x672200c2,0x00000000}},	//   rehe_, учаи, _ogoj,
  { {0xccf8005e,0xddc40078,0x39450003,0x00000000}},	//   ућу_, rtiš, _sels_,
  { {0x39450994,0x2d8100b2,0xa96928dd,0x00000000}},	//   _pels_, pehe_, вила_,
  { {0xa8550fe2,0x9f520164,0xe1ff0051,0x00000000}},	//   атиј, voyé_, rtów_,
  { {0xe1ff0045,0x27ff0026,0xdb020026,0x00000000}},	//   stów_, tlun_, skoð,
  { {0x5a35000a,0x765b02dd,0x98a5000c,0x00000000}},	//   _внат, truy, _află_,
  { {0x6d470e53,0x39450164,0x6b840019,0x00000000}},	//   _keja, _tels_, õige,
  { {0x6d470397,0x27ff28de,0x6d430014,0x00000000}},	//   _jeja, slun_, ðnah,
  { {0x79830122,0xa3ea0053,0x6d4728df,0x00000000}},	//   menw, _मदद_, _meja,
  { {0xb6010080,0x79830185,0x7e7d28e0,0x00000000}},	//   _řáde, lenw, _opsp,
  { {0x75d5007e,0xd24f0021,0x628600ca,0x00000000}},	//   _پيغا, ونَ_, uwko,
  { {0x6d4728e1,0x2c510022,0x865a0063,0x00000000}},	//   _neja, kąd_, _ידני,
  { {0xa9880063,0xe3c20058,0x1c150042,0x00000000}},	//   נָשִ, _akış_, तगाल_,
  { {0xa0670079,0xd259008f,0x798303a7,0x00000000}},	//   јата_, šņa_, henw,
  { {0x442728e2,0x3e6f005b,0x79831a62,0x00000000}},	// [4200] _hun_, güt_, kenw,
  { {0x442010ca,0x442728e3,0x6d470331,0x00000000}},	//   _hii_, _kun_, _ceja,
  { {0x6d4728e4,0x660101bb,0x442728e5,0x00000000}},	//   _deja, illk, _jun_,
  { {0x4427007a,0xfc0300e1,0xda660021,0x00000000}},	//   _mun_, опхо, لاتي,
  { {0x0a940088,0x4420000c,0x442728e6,0x00000000}},	//   салю, _mii_, _lun_,
  { {0x798328e7,0xe9f7000d,0xd6d90051,0x00000000}},	//   genw, аніі_, nału_,
  { {0xfce30928,0x442728e8,0xc7c60601,0x00000000}},	//   _доро, _nun_, исии,
  { {0x44200004,0xe1ff013d,0xf7f30044,0x00000000}},	//   _nii_, ltót_, يسيد,
  { {0x4427048e,0x7983004d,0x8c1b0063,0x00000000}},	//   _aun_, benw, _יולי,
  { {0x77bc0297,0x442728e9,0x7c2028ea,0x00000000}},	//   _méxi, _bun_, _himr,
  { {0x2fc00438,0x7786026b,0x43951137,0x00000000}},	//   kkig_, _влез, банс,
  { {0x442700e3,0xe73a1b41,0x07a32124,0x00000000}},	//   _dun_, _ред_, _махн,
  { {0x65941c15,0xd378000d,0x91f70021,0x00000000}},	//   _галу, шчэ_, لأسا,
  { {0x442728eb,0x2fc0006f,0x7c20002b,0x00000000}},	//   _fun_, ekig_, _limr,
  { {0x44271d83,0x4420000c,0x5214013c,0x00000000}},	//   _gun_, _fii_, ідст,
  { {0x6d471aae,0xee1f0053,0xff07000d,0x00000000}},	//   _seja, बद्ध_, аязн,
  { {0x6d470974,0xd2510032,0x5d550878,0x00000000}},	// [4210] _peja, _عند_, йкат,
  { {0x27e908ea,0x2c510051,0x8d74007e,0x00000000}},	//   čani_, tąd_, قاما,
  { {0x40950021,0x6c750001,0x6d4728ec,0x00000000}},	//   _الجر, слеђ, _veja,
  { {0x2fc0051c,0x7c2028ed,0x442028ee,0x00000000}},	//   ckig_, _cimr, _xii_,
  { {0x6d471558,0x2d870003,0xdb230014,0x00000000}},	//   _teja, ônes_, _þríh,
  { {0x2ca700c7,0xb5fd28ef,0x69ca0025,0x00000000}},	//   änds_, kuša, ghfe,
  { {0x3b67005a,0xb5fd001c,0x008a0041,0x00000000}},	//   _възв, juša, ָרפֿ,
  { {0x442728f0,0x7afd00d1,0x656800ca,0x00000000}},	//   _run_, _østo, egdh,
  { {0x26cd007d,0x6443001f,0x442724ec,0x00000000}},	//   uzeo_, _swni, _sun_,
  { {0x4427014f,0x69ca00bd,0x7ae40139,0x00000000}},	//   _pun_, chfe, úite,
  { {0xb5fd001c,0x69fa0047,0xdddd008f,0x00000000}},	//   guša, _עלעק, _apsū,
  { {0x4815151b,0x4427008d,0x671b0042,0x00000000}},	//   _умес, _vun_, _पृथक_,
  { {0x6d580014,0x2d910130,0xd6d90022,0x00000000}},	//   óvak, _oaze_, tału_,
  { {0xd83e00c3,0x442728f1,0xa06a28f2,0x00000000}},	//   ščen_, _tun_, лага_,
  { {0x8fa60818,0xd435002a,0xd6d9056c,0x00000000}},	//   баве, _اعتب, rału_,
  { {0x29c20026,0xc006014b,0xf456009a,0x00000000}},	//   _aðal_, ёпак, _היקר_,
  { {0x2d9128f3,0x63a428f4,0xdcfe00a8,0x00000000}},	// [4220] _baze_, _inin, repč,
  { {0x7e6400e8,0xef170001,0x31860044,0x00000000}},	//   ruip, сму_, _الدِ,
  { {0x63a40c7e,0xe1ff0014,0x00000000,0x00000000}},	//   _knin, fróf_,   ,
  { {0xdee6173e,0xb4fa0041,0xc7b80130,0x00000000}},	//   _гоми, אפעי, _tuđi_,
  { {0x7e640994,0x7afd02ab,0xcaf60021,0x00000000}},	//   quip, _østl, حساب,
  { {0x9f490026,0x2244004a,0xcaa50021,0x00000000}},	//   llað_, ámky_, تصمي,
  { {0xc0f2008b,0xa37b017d,0x7c200137,0x00000000}},	//   _rượu_, liõe, _timr,
  { {0x96340169,0x2ca700a5,0xb5fd0023,0x00000000}},	//   ониц, ånde_, vuša,
  { {0xa37b017d,0xcf930063,0x76b70062,0x00000000}},	//   niõe, לטה_, йлър_,
  { {0xc58a0076,0x95d80002,0x54541e15,0x00000000}},	//   ущие_, рдот_, овот,
  { {0x293700b5,0xc7af0055,0x26c228f5,0x00000000}},	//   _האבן_, _её_, ško_,
  { {0x290c00b2,0xb5fd28f6,0x7bc20050,0x00000000}},	//   _izda_, ruša, nkou,
  { {0xadfa0053,0xd706005e,0x98bc0078,0x00000000}},	//   ्तान_, _узди, vavę_,
  { {0x236d0045,0x63a400fe,0xb5fd0a63,0x00000000}},	//   żej_, _enin, lušn,
  { {0x61150086,0x2d9113cb,0x7bc20072,0x00000000}},	//   ідбу, _raze_, kkou,
  { {0x543b00b5,0x628d0025,0x61fe00a4,0x00000000}},	//   _געהא, _tsao, _ekpl,
  { {0x69c80034,0xa37b0016,0xbdb50095,0x00000000}},	// [4230] _olde, giõe, обај,
  { {0xe1ff013d,0x5d5516f2,0x00000000,0x00000000}},	//   rtós_, ікет,   ,
  { {0xb5fd00c3,0xe1ff00cd,0x9f490026,0x00000000}},	//   kušn, stós_, blað_,
  { {0xf8a9007e,0xfd100021,0x69c828f7,0x00000000}},	//   یگاه_, رجل_, _alde,
  { {0x957c0045,0x2d910058,0x290c017c,0x00000000}},	//   ciąg, _taze_, _azda_,
  { {0x957c0051,0xdb1b01a8,0x38590121,0x00000000}},	//   niąd, _lluç, арию_,
  { {0xdb1b017d,0xf9900049,0xe1ff0014,0x00000000}},	//   _oluç, عبه_, próf_,
  { {0x69c828f8,0x7bc228f9,0xb5fd00a8,0x00000000}},	//   _elde, ckou, irše,
  { {0x07b60044,0x56260085,0x77c60054,0x00000000}},	//   تهية_, ожым_, ільг_,
  { {0xb5fd00b2,0x61e90003,0xe6280021,0x00000000}},	//   krše, éell, حثين_,
  { {0x7bc903a8,0x6d580025,0x13a8007e,0x00000000}},	//   _kleu, óvai, مندی_,
  { {0x645c0016,0x65bf008d,0xb8df0042,0x00000000}},	//   ária, _mêhi, ुन_,
  { {0x63b6006c,0x9c08009a,0x98bc004c,0x00000000}},	//   _voyn, מִשִ, kavě_,
  { {0x38a00529,0x7bc91216,0x83fd017f,0x00000000}},	//   _fără_, _lleu, vrđe,
  { {0x9f490026,0x7bc9002b,0x7fda0a71,0x00000000}},	//   tlað_, _oleu, афат_,
  { {0x6fda004c,0x63a428fa,0x0fb30042,0x00000000}},	//   můck, _unin, ीसगढ,
  { {0xfd4a005e,0xee3708ac,0x0eaa0085,0x00000000}},	// [4240] изак_, жну_, шкай_,
  { {0xad660049,0xe1ff0022,0x7bc928fb,0x00000000}},	//   تاره, gród_, _aleu,
  { {0x7bc90164,0xa37b017d,0xcc360021,0x00000000}},	//   _bleu, siõe, زراع,
  { {0xcb67000d,0x61fc044e,0xa37b00be,0x00000000}},	//   жаце_, lorl, piõe,
  { {0xf38d00b5,0x61fc0d1e,0x7bc228fc,0x00000000}},	//   טראָ, oorl, rkou,
  { {0x3e7400fe,0x61fc0504,0x7bc2084e,0x00000000}},	//   mät_, norl, skou,
  { {0xa96728fd,0x91a9001b,0x7bc91344,0x00000000}},	//   ција_, _quả_, _fleu,
  { {0xdb00005b,0x78a50093,0x7bc928fe,0x00000000}},	//   _komü, åhva, _gleu,
  { {0x7c3e0122,0x3e740c16,0xa976005e,0x00000000}},	//   lppr, nät_, _мужј,
  { {0x7c3e05c8,0xd5ba28ff,0x69c32900,0x00000000}},	//   oppr, рси_, ckne,
  { {0x44380438,0xddcd000c,0x3e740072,0x00000000}},	//   ër_, ltaţ, hät_,
  { {0xb5fd1181,0x47c3005a,0x7c3e00ac,0x00000000}},	//   vrše, _обхв, ippr,
  { {0x3e74024a,0xddcd000c,0x61fc06a5,0x00000000}},	//   jät_, ntaţ, forl,
  { {0x35f7006a,0x3e7400fe,0xdb000e7c,0x00000000}},	//   _ورود_, dät_, _homó,
  { {0xdb000051,0xc1050021,0x7e761343,0x00000000}},	//   _komó, سوري, etyp,
  { {0x1e35000d,0x443e2901,0xe1ff0139,0x00000000}},	//   знаў, mpt_, atóp_,
  { {0x443e2902,0x98bc0080,0x00000000,0x00000000}},	// [4250] lpt_, tavě_,   ,
  { {0x7bc91a20,0x443e0122,0xb5fd0080,0x00000000}},	//   _sleu, opt_, prše,
  { {0x0cab000a,0x7bc92903,0x98bc0080,0x00000000}},	//   штаи_, _pleu, ravě_,
  { {0x70fa014e,0x60fa014e,0x7afd0093,0x00000000}},	//   _להתח, _להתק, _østk,
  { {0x7bc9006f,0x7c3e2068,0xbf360e2a,0x00000000}},	//   _vleu, appr, _מארץ_,
  { {0x3e7b003b,0x3f892012,0xdeba0063,0x00000000}},	//   râtă_, leau_, _המשל,
  { {0x443e006f,0x225e0051,0xdcf5005f,0x00000000}},	//   jpt_, ątki_, _razė,
  { {0x2cbc00c7,0x7bdb00a4,0xdb000139,0x00000000}},	//   ävde_, _umuu, _comó,
  { {0xddcd0529,0x61fc005b,0xab660019,0x00000000}},	//   ctaţ, yorl, stüü,
  { {0x6e3b005b,0xb5fd2904,0x88950062,0x00000000}},	//   _çubu, rušo, _низх,
  { {0x64a5000d,0x22491472,0x61fc2905,0x00000000}},	//   чана, _awak_, vorl,
  { {0x7e7604aa,0x61fc2906,0x14160054,0x00000000}},	//   ytyp, worl, яєпр,
  { {0xdb0000cd,0x66a60047,0xb6a50121,0x00000000}},	//   _homò, _באַשט, _хилл,
  { {0x3e74024a,0x29052907,0xc692009a,0x00000000}},	//   vät_, _kyla_, _נאו_,
  { {0x8fa60088,0x87850066,0x55020053,0x00000000}},	//   паве, ahŕň, _रुपए_,
  { {0x3e742908,0x7e762909,0x3f891653,0x00000000}},	//   tät_, ttyp, geau_,
  { {0x61fc01f7,0xc2c60044,0x216a290a,0x00000000}},	// [4260] porl, _ريدي, _липи_,
  { {0x7d1a0026,0x3e740461,0x9f4000cd,0x00000000}},	//   _útsk, rät_, snià_,
  { {0x3b86000a,0xdcfe000c,0x2249006f,0x00000000}},	//   злег, depă, _zwak_,
  { {0xcb6a290b,0x3f89290c,0x7c3e00ca,0x00000000}},	//   саде_, ceau_, rppr,
  { {0xf1b00161,0x7f44290d,0x957c0022,0x00000000}},	//   ञापन, mbiq, niąc,
  { {0xddcd000c,0x2905290e,0x443e290f,0x00000000}},	//   rtaţ, _byla_, ypt_,
  { {0xddcd000c,0x7dcb0051,0xdb000051,0x00000000}},	//   staţ, yższ, _pomó,
  { {0xddcd0529,0xf0930063,0x6d4e2910,0x00000000}},	//   ptaţ, תנה_, _heba,
  { {0x6d4e0e53,0x45d416fc,0x7c2e0206,0x00000000}},	//   _keba, допс, _hubr,
  { {0x645c03d9,0xddd60051,0xdcfe003b,0x00000000}},	//   ário, jwyż, cepă,
  { {0x224900e8,0x443e00bd,0x493b0063,0x00000000}},	//   _swak_, upt_, _הגבו,
  { {0x6d4e0ff0,0x7e642911,0x443e14f6,0x00000000}},	//   _leba, krip, rpt_,
  { {0x3f892912,0x6d5c06b9,0x46a3000d,0x00000000}},	//   veau_, _odra, _пацв,
  { {0x171b0132,0x6d4e2913,0x6d5c01f4,0x00000000}},	//   _הודע, _neba, _ndra,
  { {0x3f892914,0x61140054,0x757b0063,0x00000000}},	//   teau_, едру, _הטופ,
  { {0x6d5c2915,0x6b84004b,0x443c2916,0x00000000}},	//   _adra, õigl, _itv_,
  { {0x6d4e0397,0x7dc000bd,0x443c017f,0x00000000}},	// [4270] _beba, _lösu, _htv_,
  { {0x20020ac6,0x3f8903b2,0x6d4e2917,0x00000000}},	//   _ekki_, seau_, _ceba,
  { {0x7e640228,0x7c2e2918,0x6d5c001f,0x00000000}},	//   arip, _cubr, _ddra,
  { {0x7c2e2919,0x443c291a,0x2c750e6c,0x00000000}},	//   _dubr, _mtv_, råd_,
  { {0x7e64291b,0x6d430058,0x2458008d,0x00000000}},	//   crip, ınab, hĩm_,
  { {0x20090185,0x6458051e,0xb5fd007d,0x00000000}},	//   llai_, _ovvi, krša,
  { {0xfc64005a,0xa37b0019,0x7c2e0089,0x00000000}},	//   _пътн, lnõu, _gubr,
  { {0x6d450025,0x6d5c1582,0x9b940074,0x00000000}},	//   lbha, _zdra, _писц,
  { {0x442e0cd4,0x2009014f,0x6458291c,0x00000000}},	//   _auf_, ilai_, _avvi,
  { {0xe4590062,0x6b8b291d,0x83fd0130,0x00000000}},	//   ожо_, legg, vrđa,
  { {0x20090006,0x957c0051,0x442e01bb,0x00000000}},	//   klai_, wiąc, _cuf_,
  { {0xe72e20cf,0xf770006a,0x6b8b291e,0x00000000}},	//   _је_, _ماه_, negg,
  { {0xe56e291f,0x27ed00c7,0xd3780045,0x00000000}},	//   _из_, mnen_, ęć_,
  { {0x27ed00bd,0x6b8b17c2,0x60350078,0x00000000}},	//   lnen_, hegg, _sąma,
  { {0x9f8b0026,0x957c0051,0x6d450139,0x00000000}},	//   töðu_, siąc, dbha,
  { {0x6d4e2920,0x6b8b0190,0x27ed2492,0x00000000}},	//   _seba, jegg, nnen_,
  { {0x6e270122,0x27ed2921,0x6b8b2922,0x00000000}},	// [4280] _bijb, inen_, degg,
  { {0x27ed00bd,0x3f4c001b,0x3f5e0013,0x00000000}},	//   hnen_, ếu_, ữu_,
  { {0x225e0051,0x27ff0150,0xeb9a0612,0x00000000}},	//   ątku_, koun_, жие_,
  { {0x27ed02b0,0x6d4e2923,0x6d450025,0x00000000}},	//   jnen_, _weba, abha,
  { {0x6d4e027b,0xddcd0c61,0x61ee006f,0x00000000}},	//   _teba, staš, onbl,
  { {0xe2a70026,0x27ed2924,0x6d43005b,0x00000000}},	//   æðis_, enen_, ınac,
  { {0xdcfc003d,0x27ed00bd,0x7c2e00a4,0x00000000}},	//   _varē, fnen_, _uubr,
  { {0x6e270122,0xb5fd007d,0x442e2743,0x00000000}},	//   _zijb, vrša, _ruf_,
  { {0x7dc00026,0x7b300078,0x2d982925,0x00000000}},	//   _föst, gėuž, _kare_,
  { {0x7dc004ab,0x2d9800e8,0x27ed2926,0x00000000}},	//   _göst, _jare_, anen_,
  { {0x2009001f,0x2d982927,0xad180054,0x00000000}},	//   ylai_, _mare_, овiр,
  { {0x443c0013,0x661d0078,0x690b009a,0x00000000}},	//   _vtv_, įska, _וּדְ,
  { {0xdcf5001c,0x2d98003b,0xdb19004d,0x00000000}},	//   _pazī, _oare_, ckwä,
  { {0xb5fd0024,0x6b8b2928,0xf5770021,0x00000000}},	//   prša, zegg, _يمنع_,
  { {0x26c40078,0x6e2700ca,0x00000000,0x00000000}},	//   lymo_, _rijb,   ,
  { {0x2009014f,0x2d981013,0xf483071f,0x00000000}},	//   ulai_, _aare_, _рушн,
  { {0x2d9803b1,0xd904007e,0x8e150085,0x00000000}},	// [4290] _bare_, _چی_, едац,
  { {0x2d9809ee,0xcce7007e,0x2bc70053,0x00000000}},	//   _care_, وساي, लस्थ,
  { {0x7dc000c7,0xb5fd00c3,0x6b8b2929,0x00000000}},	//   _röst, kršn, tegg,
  { {0x26c400eb,0x8b050022,0xb5fd01c8,0x00000000}},	//   kymo_, hnęł, tušk,
  { {0x4429292a,0x27ed02ab,0x2d98055b,0x00000000}},	//   _mia_, vnen_, _fare_,
  { {0xba3d0080,0x26c40006,0x2d98292b,0x00000000}},	//   _průb, dymo_, _gare_,
  { {0x3f990019,0x6b8b292c,0x6ab604aa,0x00000000}},	//   _kasu_, pegg, øyfr,
  { {0x27ed0d13,0xe7390002,0x4429292d,0x00000000}},	//   unen_, џеп_, _nia_,
  { {0x27ed292e,0x2d980137,0x27ff292f,0x00000000}},	//   rnen_, _yare_, roun_,
  { {0x7c292930,0xe938007e,0xe616014c,0x00000000}},	//   _hier, _قسمت_, нды_,
  { {0x7c292931,0x64412932,0x3e83008f,0x00000000}},	//   _kier, upli, lītā_,
  { {0x98360047,0x3f99007d,0x64412494,0x00000000}},	//   _טרעף_, _nasu_, rpli,
  { {0x44292933,0x2d83017f,0x7c292934,0x00000000}},	//   _dia_, _obje_, _mier,
  { {0x645500ea,0x44292935,0x64412936,0x00000000}},	//   ázis, _eia_, ppli,
  { {0xf505019d,0xb5fd001c,0x64a20062,0x00000000}},	//   _язко, juši, _баща,
  { {0x4429001b,0x2d98003b,0x7c292937,0x00000000}},	//   _gia_, _sare_, _nier,
  { {0x7dd20146,0x2d982938,0xdb002939,0x00000000}},	// [42a0] _læse, _pare_, _homö,
  { {0x3e83001c,0x629600a4,0x2b5f000c,0x00000000}},	//   dītā_, _isyo, _aduc_,
  { {0x7dd200b9,0x2d980611,0xab66293a,0x00000000}},	//   _næse, _vare_, евел,
  { {0x7c29293b,0xf43a0047,0xf8b0007e,0x00000000}},	//   _cier, לגעמ, یکا_,
  { {0x32d80051,0xb5fd027c,0x2d980038,0x00000000}},	//   _użyć_, vršn, _tare_,
  { {0x98a5005b,0x7c292585,0xab270085,0x00000000}},	//   _adlı_, _eier, хоча_,
  { {0xb5fd0006,0x3ea0293c,0x7c29169b,0x00000000}},	//   eršo, lvit_, _fier,
  { {0xdb2100bd,0x26c40006,0xddc4003b,0x00000000}},	//   _äuße, tymo_, buiţ,
  { {0xc6f8019d,0xddc4000c,0xadf40053,0x00000000}},	//   ьних_, cuiţ, _आदान_,
  { {0x4429293d,0x7c29087d,0x26c40078,0x00000000}},	//   _sia_, _zier, rymo_,
  { {0x44290009,0x2240293e,0x26c40078,0x00000000}},	//   _pia_, _atik_, symo_,
  { {0x60350078,0x87da013a,0x8b050022,0x00000000}},	//   _sąmo, _عباس_, snęł,
  { {0x430b0086,0x5187293f,0x7afd05b9,0x00000000}},	//   яхом_, нува, _østt,
  { {0x7dd200b9,0x91a90013,0xcb130063,0x00000000}},	//   _læsb, _quà_, טלר_,
  { {0xddc4000c,0x3f992940,0x44292941,0x00000000}},	//   zuiţ, _pasu_, _tia_,
  { {0x799a00ac,0x44292942,0x645a2943,0x00000000}},	//   _latw, _uia_, msti,
  { {0x3f99017f,0x52151321,0x7c290857,0x00000000}},	// [42b0] _vasu_, _идит, _rier,
  { {0xf41f024a,0xb21b0146,0x7c292944,0x00000000}},	//   lmä_, dtæg, _sier,
  { {0x3f990019,0x7c290ce9,0x645a290f,0x00000000}},	//   _tasu_, _pier, nsti,
  { {0xddc4003b,0x3e83008f,0xb5fd2904,0x00000000}},	//   tuiţ, tītā_, ruši,
  { {0x2bb80021,0x7c292945,0x9f492946,0x00000000}},	//   عامة_, _vier, nnaí_,
  { {0x7c292947,0xf41f00fe,0xdb1b0003,0x00000000}},	//   _wier, hmä_, _joué,
  { {0x66010173,0x7c292948,0x645a2949,0x00000000}},	//   volk, _tier, jsti,
  { {0x645a010a,0xf41f0024,0x7dd20146,0x00000000}},	//   dsti, jmä_, _væse,
  { {0x799a014f,0x6601294a,0x645a24df,0x00000000}},	//   _fatw, tolk, esti,
  { {0x6b9b294b,0x645a1660,0x63ad294c,0x00000000}},	//   _haug, fsti, _anan,
  { {0x22400198,0x6b9b1eb1,0xe1ff294d,0x00000000}},	//   _stik_, _kaug, trón_,
  { {0x799a0051,0xd5b8001c,0x629600a4,0x00000000}},	//   _zatw, ajā_, _psyo,
  { {0x660100fe,0xe1ff1919,0x645a294e,0x00000000}},	//   polk, rrón_, asti,
  { {0x6b9b294f,0x63ad2950,0x645a2951,0x00000000}},	//   _laug, _enan, bsti,
  { {0x91a9001b,0x9f400025,0xe1ff00ea,0x00000000}},	//   _quá_, mniú_, mról_,
  { {0xe1ff00ea,0xdfd200f2,0x6b9b2952,0x00000000}},	//   lról_, جير_, _naug,
  { {0xf1c2001c,0x61e7006f,0xd0072953,0x00000000}},	// [42c0] _pašā_, bijl, тете_,
  { {0xdca60259,0x63ad1e2d,0x9f400139,0x00000000}},	//   кази, _znan, nniú_,
  { {0xb5fd00c2,0x3ea00072,0x9f400139,0x00000000}},	//   vršl, svit_, iniú_,
  { {0x799a00f3,0x6b9b0034,0x9f400025,0x00000000}},	//   _satw, _caug, hniú_,
  { {0xe1ff000f,0x6b9b0498,0xdaba007e,0x00000000}},	//   król_, _daug, بهشت_,
  { {0x645a1258,0xe9f80088,0xddcd008f,0x00000000}},	//   ysti, энлі_, esaņ,
  { {0x38c8007e,0x8b96018e,0xf41f00fe,0x00000000}},	//   عاتی_, _ирач, ymä_,
  { {0xb0ba016a,0x2c7c0025,0x2ca705b9,0x00000000}},	//   _उपनग, míd_, ænde_,
  { {0x765b00a4,0x60c70051,0x4b7b0047,0x00000000}},	//   gsuy, zyjm, _קאמו,
  { {0x6b8200ea,0xd6d90051,0x36870062,0x00000000}},	//   lfog, nały_, тсън_,
  { {0xc8ca006a,0x7afd02ab,0xdcfc0078,0x00000000}},	//   _توان_, _østr, _varė,
  { {0x645a2954,0x6b822955,0x3d1a0053,0x00000000}},	//   rsti, nfog, _भरने_,
  { {0xe7372956,0x61e7006f,0x6b822957,0x00000000}},	//   _реч_, tijl, ifog,
  { {0x7bc000a4,0x645a2958,0x9f490139,0x00000000}},	//   _lomu, psti, rnaí_,
  { {0xcf9b000a,0xdfd5093e,0x29c20014,0x00000000}},	//   мја_, говы, _yðar_,
  { {0x63ad2959,0x938b05bd,0x889b03c3,0x00000000}},	//   _unan, _цска_, ובלי,
  { {0x290c0137,0x6b9b295a,0x914b01ce,0x00000000}},	// [42d0] _lyda_, _raug, _очна_,
  { {0xab5d0045,0x6b9b00eb,0x9d550021,0x00000000}},	//   _może, _saug, انات,
  { {0x83fd007d,0x6d5700a5,0xb5fd0078,0x00000000}},	//   suđu, raxa, mušt,
  { {0x3af50121,0x7bc00419,0xb21b05a5,0x00000000}},	//   лялс, _comu, stæd,
  { {0x290c005b,0x7bc0295b,0x6b9b295c,0x00000000}},	//   _ayda_, _domu, _vaug,
  { {0x6b9b00e5,0xd6d90022,0x00000000,0x00000000}},	//   _waug, cały_,   ,
  { {0xdb0000c7,0x6b9b0780,0xe739295d,0x00000000}},	//   _anmä, _taug, ней_,
  { {0xdb000024,0x7c3a0164,0xab5d0051,0x00000000}},	//   _pomô, _étra, _boże,
  { {0x6d5500e3,0xe1ff00ea,0x5a340928,0x00000000}},	//   _keza, tról_, _внут,
  { {0x957c0078,0xa87b0044,0xfbdf0042,0x00000000}},	//   liąj, _يحضر_, पोरम,
  { {0x290c0c70,0x6d55005b,0xa3ea295e,0x00000000}},	//   _gyda_, _meza, една_,
  { {0xe1ff00ea,0x61e50025,0xd6d90051,0x00000000}},	//   sról_, _amhl, zały_,
  { {0xe1ff00ea,0xdce70066,0xe60e295f,0x00000000}},	//   pról_, _najľ, _гд_,
  { {0xc6920047,0x6d55114b,0xb5fd00c2,0x00000000}},	//   _לאד_, _neza, gušt,
  { {0xdb19004d,0x69c12960,0x6d430075,0x00000000}},	//   chwö, _mole, ınal,
  { {0xd6d90045,0x602600d7,0xb5fd0dd8,0x00000000}},	//   wały_, удба, kršk,
  { {0x7bc02961,0xd6d90051,0x8fa300a0,0x00000000}},	// [42e0] _romu, tały_, щате,
  { {0x02b7014e,0xb5fd017f,0xd83e00c2,0x00000000}},	//   _עליך_, dršk, ščin_,
  { {0x6d552962,0x7dd201f2,0x317b1469,0x00000000}},	//   _deza, _cæsa, _ארימ,
  { {0x2c7c0025,0x75160047,0x9f060242,0x00000000}},	//   ríd_, אַדע_, _موجو,
  { {0x16030161,0x6fca0024,0x69c12963,0x00000000}},	//   रकार_, _rých, _bole,
  { {0x6d5510ce,0x69c10cde,0xba3d004c,0x00000000}},	//   _geza, _cole, _trůn,
  { {0x58d40612,0x7dd20026,0x7bc0004a,0x00000000}},	//   ройт, _gæsa, _tomu,
  { {0x69c10139,0x38a30058,0x98a3005e,0x00000000}},	//   _eole, _dır_, сиће,
  { {0x6b840004,0x6fca016b,0x57180062,0x00000000}},	//   õigu, _vých, ъжия_,
  { {0x290c0137,0x69c12964,0x6e2e0046,0x00000000}},	//   _tyda_, _gole, _jibb,
  { {0x6fca0024,0x2db7069a,0x69d80046,0x00000000}},	//   _tých, אלין_, mhve,
  { {0x7c222965,0x75d4005d,0x6e2e2966,0x00000000}},	//   nmor, ايگا, _libb,
  { {0xe298000d,0x64432967,0xdcfc008f,0x00000000}},	//   гаў_, _etni, _barī,
  { {0x69d807e2,0x25ba004b,0x26db009a,0x00000000}},	//   nhve, _õpl_, _אקדמ,
  { {0xdcfc001c,0xd0d4005a,0x69cc0053,0x00000000}},	//   _darī, боръ, _तकनी,
  { {0x6d43005b,0x6d580014,0x937b0044,0x00000000}},	//   ınam, ðvan, _أصغر_,
  { {0x6e2e0a02,0xb5fd0755,0x7c222968,0x00000000}},	// [42f0] _bibb, pušt, dmor,
  { {0x7c222969,0x2d870066,0xdcfc008f,0x00000000}},	//   emor, ýne_, _garī,
  { {0x6d55027c,0xa115007e,0x4c9506da,0x00000000}},	//   _veza, _خودت, риес,
  { {0x69c10b6f,0x20840021,0x44770aeb,0x00000000}},	//   _sole, _الَّ, רעאל_,
  { {0xbd6b0001,0x6d55296a,0x69c1296b,0x00000000}},	//   _прве_, _teza, _pole,
  { {0x1869167b,0x7e6d06f1,0x6845296c,0x00000000}},	//   ваки_, mrap, анка,
  { {0x8c250021,0x69c1296d,0xe1ff296e,0x00000000}},	//   _نفسه, _vole, luós_,
  { {0x57460062,0x16650f55,0x2d93296f,0x00000000}},	//   азъм_, авим, lexe_,
  { {0x78a80006,0x69c12970,0x7e6d2971,0x00000000}},	//   _erdv, _tole, nrap,
  { {0x69d800bd,0x7dd200b9,0xf5050062,0x00000000}},	//   chve, _læsn, изпо,
  { {0xe522000d,0x7e6d2972,0x98bc0078,0x00000000}},	//   ждэп, hrap, davė_,
  { {0xcc760063,0xddc4000c,0x6aa92973,0x00000000}},	//   סגרת_, oriţ, _kref,
  { {0x6b890035,0xdcfc008f,0x7e6d013d,0x00000000}},	//   _mbeg, _parī, jrap,
  { {0xa06a0088,0x200b0080,0x6aa90035,0x00000000}},	//   кага_, _akci_, _mref,
  { {0x6b890137,0x7c22085c,0x2d932974,0x00000000}},	//   _obeg, ymor, dexe_,
  { {0x6aa901f4,0x6e2e01e1,0xba3d004c,0x00000000}},	//   _oref, _sibb, _průl,
  { {0x7c2208a9,0x7e6d2975,0xee0a0002,0x00000000}},	// [4300] vmor, grap, веал_,
  { {0x83fd007d,0x27e901da,0x998c008f,0x00000000}},	//   vrđi, čany_, _vidū_,
  { {0x7e6d2976,0x6aa90046,0xd8380130,0x00000000}},	//   arap, _aref, _trči_,
  { {0xc101008b,0x7ac62977,0x69c5004d,0x00000000}},	//   _lượt_, исле, öhen,
  { {0x6aa9001f,0xb5fd007d,0x6fd800be,0x00000000}},	//   _cref, arši, _cíce,
  { {0x6aa9001f,0x7c3a0164,0xa37b0019,0x00000000}},	//   _dref, _étro, riõi,
  { {0xa3c60053,0x69d80220,0x6b84004e,0x00000000}},	//   _एवं_, rhve, õigs,
  { {0x57a6000a,0x7bd900bd,0x4c9b0063,0x00000000}},	//   ршка, chwu, _בבלו,
  { {0x19960001,0xab270062,0x76b70062,0x00000000}},	//   _вјер, _вота_, илър_,
  { {0x14ca0076,0x76a70062,0x99e31406,0x00000000}},	//   выми_, ртъв_, _джуд,
  { {0xd5b7066e,0xc1010013,0xd4970257,0x00000000}},	//   рсы_, _dượt_, аря_,
  { {0xc7c70076,0xd5b8001c,0x46ea0002,0x00000000}},	//   _выше_, mmām_, _иден_,
  { {0x926b005a,0xd5b8008f,0x41c70085,0x00000000}},	//   ърна_, lmām_, аёва,
  { {0x7e6d0290,0xf2070156,0x645c2978,0x00000000}},	//   vrap, рямо, áris,
  { {0x30a40085,0x55bb009a,0xa1582979,0x00000000}},	//   ортв, _במגו, расу_,
  { {0xb5fd055e,0x316d003b,0x7e6d22d3,0x00000000}},	//   vrši, şez_, trap,
  { {0xba3d0080,0x9df9026b,0xd838085a,0x00000000}},	// [4310] _prům, гнат_, _luč_,
  { {0xeca70138,0x2705001b,0x7e6d297a,0x00000000}},	//   ијен, ồng_, rrap,
  { {0x31740024,0x6fd80139,0x7e6d297b,0x00000000}},	//   ňazí_, _síce, srap,
  { {0x2d8a297c,0x66081e45,0xddc4003b,0x00000000}},	//   _ebbe_, hodk, triţ,
  { {0x66080089,0xc3340063,0x501a016e,0x00000000}},	//   kodk, קוס_, _תורו,
  { {0xceb200b7,0x6fd80080,0x395c0137,0x00000000}},	//   _זיך_, _více, gavs_,
  { {0xf0940047,0x48580085,0x6fca01d1,0x00000000}},	//   ַנץ_, арыў_, _výcv,
  { {0xd0f80132,0x3869074f,0x6b8906a5,0x00000000}},	//   ימות_, čar_, _ubeg,
  { {0x6aa90035,0x06090ab1,0xba740044,0x00000000}},	//   _uref, лник_, _واكت,
  { {0x588706bc,0xddc4007d,0x6608297d,0x00000000}},	//   _выда, oriš, godk,
  { {0xddcd00eb,0xc101008b,0xa9540054,0x00000000}},	//   ktaž, _vượt_, _єкці,
  { {0xbddb0003,0xe1ff0022,0x2b5d002b,0x00000000}},	//   _stèl, orów_, nawc_,
  { {0x87070076,0x27ed297e,0xddc40130,0x00000000}},	//   _тяже, mien_, hriš,
  { {0xd5b10067,0xddc4297f,0xba3d004c,0x00000000}},	//   _رفع_, kriš, _průj,
  { {0x27ed0122,0x7dd20146,0xddd60051,0x00000000}},	//   oien_, _sæso, ysył,
  { {0x543a0047,0x6ab70042,0x743a0041,0x00000000}},	//   _געקא, _आपूर, _געקװ,
  { {0xdd3c0006,0x754600ea,0xdfcf0021,0x00000000}},	// [4320] rąži, _érzé, ريك_,
  { {0xeef50088,0x27ed2980,0xdd3c0078,0x00000000}},	//   іятэ, hien_, sąži,
  { {0x442000aa,0x7dc0000f,0x27ed2981,0x00000000}},	//   _khi_, _kösz, kien_,
  { {0x27ed024a,0xab5d0051,0x6f210058,0x00000000}},	//   jien_, _poża, özcü,
  { {0x27ed28b3,0x395c001c,0xc27b0041,0x00000000}},	//   dien_, tavs_, ָרצי,
  { {0x27ed10ce,0x61ee2982,0xddc402e2,0x00000000}},	//   eien_, nibl, briš,
  { {0x6d5e2983,0xa3ca0053,0x44200072,0x00000000}},	//   mapa, ोसा_, _ohi_,
  { {0x6d5e2984,0xb5fd0006,0x2fc000c2,0x00000000}},	//   lapa, iršu, njig_,
  { {0x95d80121,0x320a2985,0x95ca076a,0x00000000}},	//   идит_, koby_, гуна_,
  { {0x6d5e03d5,0x27ed006f,0xceb30063,0x00000000}},	//   napa, aien_, פית_,
  { {0xab5d0045,0xddcd000c,0x1836007e,0x00000000}},	//   _możn, luaţ, _طراح,
  { {0x27ed2986,0x6d5e2987,0x44202988,0x00000000}},	//   cien_, hapa, _chi_,
  { {0x44321140,0xddcd000c,0x6d5e2989,0x00000000}},	//   _diy_, nuaţ, kapa,
  { {0x41e40088,0x22440024,0x6d5e298a,0x00000000}},	//   піса, ímka_, japa,
  { {0x6d5e0974,0x84460242,0xd0d40062,0x00000000}},	//   dapa, _اختل, поръ,
  { {0x4420001b,0xc5f8001c,0x61ee0003,0x00000000}},	//   _ghi_, lnē_, aibl,
  { {0xe3b00021,0x61ee0f8c,0xddcd0734,0x00000000}},	// [4330] _أرى_, bibl, rtaž,
  { {0x657a0034,0x27ed0194,0x6d5e298b,0x00000000}},	//   ngth, zien_, gapa,
  { {0xddcd00eb,0x69c5024a,0x236900c3,0x00000000}},	//   ptaž, öhem, _kdaj_,
  { {0xe1ff0051,0x27ed298c,0x6d5e01a9,0x00000000}},	//   trów_, xien_, aapa,
  { {0x7e7900b5,0x4ea70002,0x27ed298d,0x00000000}},	//   _דאָז, _урна, vien_,
  { {0x3ea9298e,0x27ed08ae,0xddc41536,0x00000000}},	//   mvat_, wien_, priš,
  { {0x3ea91411,0x6013005b,0x27ed298f,0x00000000}},	//   lvat_, eçmi, tien_,
  { {0x2249014f,0x27ed006d,0x17c90f9f,0x00000000}},	//   _otak_, uien_, ргии_,
  { {0x95950088,0x27ed2990,0xb5fd007d,0x00000000}},	//   ошні, rien_, kršt,
  { {0x3ea900fe,0x8698005a,0x27ed2991,0x00000000}},	//   ivat_, стът_, sien_,
  { {0xd7c9007e,0x44202992,0x3ea90883,0x00000000}},	//   _پوشه_, _phi_, hvat_,
  { {0x6d5e2993,0x232a0f55,0xba3d004c,0x00000000}},	//   zapa, иони_, _průh,
  { {0x61ee2994,0x6d5e0380,0xb21b00b9,0x00000000}},	//   tibl, yapa, rtæn,
  { {0xb21b0146,0x317e004d,0x3ea9004b,0x00000000}},	//   stæn, ütz_, dvat_,
  { {0x3ea90162,0x44202995,0x7f5a00d7,0x00000000}},	//   evat_, _thi_, ијат_,
  { {0x6d5e00e3,0x61ee2996,0x9f860085,0x00000000}},	//   wapa, sibl, ўгад,
  { {0x6e46006a,0xfe720021,0x3ea91f94,0x00000000}},	// [4340] زنام, بدأ_, gvat_,
  { {0x23690198,0x44d5001b,0x63a42997,0x00000000}},	//   _zdaj_, ó_, _hain,
  { {0x3ea9024a,0x63a42998,0x6d5e03f7,0x00000000}},	//   avat_, _kain, rapa,
  { {0xddcd000c,0x63a60186,0xa4fa0047,0x00000000}},	//   tuaţ, ndkn, בלעט,
  { {0x6d5e00bb,0x3ea90729,0x201e00cd,0x00000000}},	//   papa, cvat_, ïtiu_,
  { {0x63a42999,0x629a0051,0xfce600fb,0x00000000}},	//   _lain, łtow, _дого,
  { {0x6d5c003d,0xa37b03d9,0x62860019,0x00000000}},	//   _iera, lhõe, htko,
  { {0x6d5c299a,0xd90d007e,0x6286299b,0x00000000}},	//   _hera, دیم_, ktko,
  { {0x6d5c0228,0xab5d0045,0xc5f8001c,0x00000000}},	//   _kera, _możl, tnē_,
  { {0xdb000003,0x6d5c299c,0x7e64299d,0x00000000}},	//   _ramè, _jera, isip,
  { {0x7766005a,0x7ae2000f,0x63a4299e,0x00000000}},	//   _дълж, lzot, _bain,
  { {0x69c810bc,0x7bc212ee,0x63a40d2f,0x00000000}},	//   _hode, njou, _cain,
  { {0x69c81c2d,0x68350006,0x44d50013,0x00000000}},	//   _kode, _išda, á_,
  { {0x69c80122,0xdb0011f5,0x6d5c299f,0x00000000}},	//   _jode, _camé, _nera,
  { {0xa3bb006a,0xe5e7007e,0x63a429a0,0x00000000}},	//   _ناظر_, _بزنی, _fain,
  { {0x69c82747,0x63a4031d,0x6fd8006d,0x00000000}},	//   _lode, _gain, _píca,
  { {0x6d5c08f0,0xee84000d,0x22492143,0x00000000}},	// [4350] _bera, дыхо, _utak_,
  { {0x63a429a1,0x6d5c29a2,0x69c829a3,0x00000000}},	//   _zain, _cera, _node,
  { {0x7c3c0034,0x6d5c29a4,0xfc640062,0x00000000}},	//   _curr, _dera, дъчн,
  { {0x69da29a5,0x7c3c29a6,0xf2d5009a,0x00000000}},	//   _alte, _durr, ּעַ_,
  { {0x29f60045,0x69c829a7,0x6d5c29a8,0x00000000}},	//   kład_, _bode, _fera,
  { {0x44d5008b,0x69c80c2e,0xdb1b017d,0x00000000}},	//   ý_, _code, _louç,
  { {0x6e3d0034,0x2284000f,0xcf27007e,0x00000000}},	//   _husb, zök_, _درگي,
  { {0x62860045,0x9f400026,0x61c80053,0x00000000}},	//   ytko, nnið_, _रक्ष,
  { {0x63a429a9,0x9af90047,0x7f5d1452,0x00000000}},	//   _rain, _הפּח, _mesq,
  { {0x7f5d0164,0x69c829aa,0x63a426a4,0x00000000}},	//   _lesq, _gode, _sain,
  { {0xb21b0146,0x63a40bcf,0x6d4529ab,0x00000000}},	//   rtæl, _pain, icha,
  { {0x62860e3f,0x69c300c3,0x228428ba,0x00000000}},	//   ttko, ljne, tök_,
  { {0x98a7005b,0x7dd3005b,0x63a61a81,0x00000000}},	//   manı_, _kısı, rdkn,
  { {0x7dd21d0d,0x63a4075a,0x98a7005b,0x00000000}},	//   _væsk, _wain, lanı_,
  { {0x228429ac,0x6e3d00bd,0x9f400026,0x00000000}},	//   sök_, _ausb, fnið_,
  { {0x6d5c29ad,0xe1ff0051,0x63a40139,0x00000000}},	//   _sera, wrót_, _uain,
  { {0x6d5c0e53,0x22160086,0x7c3c1926,0x00000000}},	// [4360] _pera, _нфор, _surr,
  { {0xa37b004b,0x656129ae,0x398f0058,0x00000000}},	//   liõp, nalh, nısı_,
  { {0x6d5c22ad,0x98a7005b,0x69c81100,0x00000000}},	//   _vera, kanı_, _rode,
  { {0x69c80198,0x6d450025,0x7bc20003,0x00000000}},	//   _sode, acha, ujou,
  { {0x7bc200fe,0x69c8198b,0x6d5c29af,0x00000000}},	//   rjou, _pode, _tera,
  { {0x7bc20f3b,0x98c60a36,0xed52007e,0x00000000}},	//   sjou, зсил, _سپر_,
  { {0xec770001,0x656129b0,0xa96700d7,0x00000000}},	//   _нпр_, dalh, чија_,
  { {0x2d9a29b1,0xf0930063,0x6561004b,0x00000000}},	//   lepe_, גנה_, ealh,
  { {0x69c82691,0xa3c60042,0x443c29b2,0x00000000}},	//   _tode, _एवज_, _suv_,
  { {0x69da0015,0xba3d0080,0x6561017d,0x00000000}},	//   _ulte, _prův, galh,
  { {0x53990076,0x395e0162,0xb4c80053,0x00000000}},	//   овня_, _iets_, ोने_,
  { {0x65610019,0x883b0063,0xf483005d,0x00000000}},	//   aalh, _התאו, راپی,
  { {0x656103d9,0x2d9a00ac,0xdb00006d,0x00000000}},	//   balh, kepe_, _inmó,
  { {0xa4100080,0x398f005b,0x6d4529b3,0x00000000}},	//   ětší_, cısı_, xcha,
  { {0x7f5d03d9,0xddc40006,0xb21b0026,0x00000000}},	//   _pesq, asiū, ltæk,
  { {0x34fb0063,0x395e29b4,0x69c300a5,0x00000000}},	//   _להוד, _lets_, zjne,
  { {0x6d4529b5,0x69c30051,0x9f400014,0x00000000}},	// [4370] tcha, yjne, rnið_,
  { {0x4df40086,0x9f400026,0x6d4529b6,0x00000000}},	//   няєт, snið_, ucha,
  { {0x24410013,0x6d4529b7,0x98a70058,0x00000000}},	//   _xóm_, rcha, yanı_,
  { {0xbddb0003,0x6d4502ce,0x398f0058,0x00000000}},	//   _suèd, scha, zısı_,
  { {0x398f01f7,0x98a7005b,0xe8100053,0x00000000}},	//   yısı_, vanı_, ावना_,
  { {0x2d9a0529,0xf9c70376,0x6d430058,0x00000000}},	//   cepe_, ящен, ınas,
  { {0xf8920079,0x6561017d,0x395e29b8,0x00000000}},	//   вајќ, valh, _dets_,
  { {0x2a6600a4,0xb21b0014,0x9b5902b6,0x00000000}},	//   bsob_, ftæk, _фиат_,
  { {0xaa580079,0x656129b9,0x395e0268,0x00000000}},	//   _ниту_, talh, _fets_,
  { {0x395e0034,0xa4450002,0x853c0078,0x00000000}},	//   _gets_, мнод, bdėm,
  { {0x398f005b,0x656129ba,0x3e83008f,0x00000000}},	//   rısı_, ralh, lūtā_,
  { {0xc1690ee1,0x656129ba,0x6fd81bae,0x00000000}},	//   _כח_, salh, _cícl,
  { {0x65610016,0xe60e2292,0xa37b0019,0x00000000}},	//   palh, _ад_, riõp,
  { {0xc58e008b,0x244129bb,0x61460002,0x00000000}},	//   _hồng_, _tóm_, ќева,
  { {0x386701e1,0xe8ee01ce,0x1c0d0042,0x00000000}},	//   nsnr_, ллy_, िकाल_,
  { {0x442b0089,0x00000000,0x00000000,0x00000000}},	//   cmc_,   ,   ,
  { {0x2fcb01f4,0xc58e0013,0x6fec00dd,0x00000000}},	// [4380] _docg_, _mồng_, nşci,
  { {0x270c001b,0xc58e0013,0xce1a014b,0x00000000}},	//   ớng_, _lồng_, іцаі_,
  { {0x412a0002,0x2d9a29bc,0x600a005e,0x00000000}},	//   _фоно_, repe_, _мном_,
  { {0x395e29bd,0x2d9a01f4,0xc58e0013,0x00000000}},	//   _sets_, sepe_, _nồng_,
  { {0xa3e30053,0x6d430058,0x200529be,0x00000000}},	//   फोट_, ınar, élie_,
  { {0xee370062,0x7c2b004b,0x3f800078,0x00000000}},	//   _оня_, amgr, lgiu_,
  { {0x224029bf,0x3ea0006f,0xd90f0054,0x00000000}},	//   _luik_, lwit_, ть_,
  { {0x3f8029c0,0x6bda007e,0x98a3005e,0x00000000}},	//   ngiu_, _بورس_, тиће,
  { {0xc6f80086,0x9f9c0139,0x96340d82,0x00000000}},	//   яних_, _níí_, нниц,
  { {0xb21b007a,0xba230088,0xc6f703e6,0x00000000}},	//   rtæk, _адук, ьных_,
  { {0xb21b0014,0xdb001bae,0xd838004c,0x00000000}},	//   stæk, _mamí, _ksčm_,
  { {0x2240006f,0x7c3a0003,0x2ca70014,0x00000000}},	//   _buik_, _étru, ændi_,
  { {0xf7430086,0x5187280d,0xfd65008b,0x00000000}},	//   _речо, мува, _chuỗ,
  { {0x224000f5,0xdb0029c1,0x56930141,0x00000000}},	//   _duik_, _namí, _рашт,
  { {0x9f40006f,0x3cfa0053,0xe8df0013,0x00000000}},	//   chië_, ्थों_, _kiềm_,
  { {0x14cb0053,0x5f9429c2,0x00000000,0x00000000}},	//   ाहरण, кист,   ,
  { {0x69d800d1,0xee3f008b,0x7e760474,0x00000000}},	// [4390] kkve, _quý_, gryp,
  { {0xdce50024,0xd5b8001c,0xddcd003b,0x00000000}},	//   rehľ, mmās_, draţ,
  { {0x61f5005b,0x3ea00089,0xf3900013,0x00000000}},	//   mizl, awit_, _mảng_,
  { {0xe8df008b,0x69d81f92,0x61f50058,0x00000000}},	//   _niềm_, ekve, lizl,
  { {0xdb0013a3,0x9f8a0019,0xddcd000c,0x00000000}},	//   _famí, tööd_, graţ,
  { {0x61f501f7,0x8afd004c,0x92a90022,0x00000000}},	//   nizl, _neře, _załó,
  { {0x2b4029c3,0x5fd30053,0x853c0078,0x00000000}},	//   žica_, _सवाल, adėk,
  { {0xdb000080,0x01380132,0x2a720078,0x00000000}},	//   _zamí, ורות_, šyba_,
  { {0xddcd000c,0xf390001b,0x98c4001c,0x00000000}},	//   craţ, _bảng_, ētām_,
  { {0xab620019,0x2d8129c4,0x69d80c38,0x00000000}},	//   _üüri, nghe_, ckve,
  { {0xd5e80021,0x2d810290,0xf770005d,0x00000000}},	//   بعين_, ighe_, _چاه_,
  { {0x7dd20026,0x224000ac,0x61f5008f,0x00000000}},	//   _hæst, _puik_, eizl,
  { {0x27ff29c5,0x42ba000d,0x2bc70053,0x00000000}},	//   mnun_, чыню_, _रचना,
  { {0x7a2400cd,0xdfd2007e,0x75d50044,0x00000000}},	//   pòte, گير_, _سيعا,
  { {0xdb0005d5,0x9f9d0026,0x660600ea,0x00000000}},	//   _ramí, tæðu_, ékke,
  { {0x8fa31001,0x7dd20583,0x27ff29c6,0x00000000}},	//   ласе, _læst, nnun_,
  { {0x27ff00fe,0xdb0029c7,0x3ea000a4,0x00000000}},	// [43a0] inun_, _mamã, uwit_,
  { {0x7dd229c8,0xdcee005b,0xddcd003b,0x00000000}},	//   _næst, _sabı, vraţ,
  { {0xa2a4016a,0x7c96000d,0x515b0063,0x00000000}},	//   _चैत्, эрац, _מכיו,
  { {0xddcd000c,0xdb00003b,0x20260022,0x00000000}},	//   traţ, _ramâ, ówić_,
  { {0x2000003b,0xddcd003b,0x6808004c,0x00000000}},	//   mnii_, uraţ, něde,
  { {0x2000003b,0xdb0000dd,0xa8a601e4,0x00000000}},	//   lnii_, _pamâ, ерик,
  { {0xde0329c9,0x27ff0026,0x8b96000d,0x00000000}},	//   _спри, fnun_, _прач,
  { {0x6c360021,0x27ff0014,0x69d829ca,0x00000000}},	//   _أفرا, gnun_, skve,
  { {0xd5b00032,0x7dd229cb,0x8f9b0132,0x00000000}},	//   لفة_, _fæst, ליקי,
  { {0x7dd20146,0xa96a0062,0x6b8229cc,0x00000000}},	//   _gæst, _хижа_, lgog,
  { {0x8afd0080,0xf3ff017d,0xe8df008b,0x00000000}},	//   _veře, tnã_, _tiềm_,
  { {0x32110022,0x9cd7009a,0xd8db009d,0x00000000}},	//   wozy_, גוטה_, _מקבר,
  { {0xf390008b,0xf6d30044,0x61f50075,0x00000000}},	//   _tảng_, _مزود, tizl,
  { {0xddcd0006,0xf3900013,0xd5b8001c,0x00000000}},	//   kraš, _uảng_, rmās_,
  { {0x3d1f0053,0x7dd201e1,0x64a302f8,0x00000000}},	//   _भरें_, _læss, _баја,
  { {0xddcd0006,0xe8df008b,0x64850047,0x00000000}},	//   draš, _hiểm_, _סעפּ_,
  { {0xe8df001b,0x6fd80dcc,0x60180085,0x00000000}},	// [43b0] _kiểm_, _mích, хцёр_,
  { {0xddcd0066,0x02fc0a7a,0x44dc0013,0x00000000}},	//   fraš, _מלחמ, ỏ_,
  { {0x6fd80025,0x7055007e,0xc5f30047,0x00000000}},	//   _oích, _جنجا, נדע_,
  { {0x6d580026,0x6825013d,0x0056009a,0x00000000}},	//   ðvar, zódb, _ששרת_,
  { {0xddcd0078,0xe9ce142a,0xf9910021,0x00000000}},	//   araš, ак_, لبث_,
  { {0xe9d80088,0x442929cd,0xbef6009a,0x00000000}},	//   нкі_, _lha_, _יצרו_,
  { {0x27ff0014,0xd262008f,0x961d0023,0x00000000}},	//   tnun_, _ziņā_, luņg,
  { {0x4429008b,0x764200e5,0x27ff29ce,0x00000000}},	//   _nha_, _buoy, unun_,
  { {0x27ff0026,0x6fd80025,0x7c2923d7,0x00000000}},	//   rnun_, _dích, _iher,
  { {0x442929cf,0x6808004c,0xad850085,0x00000000}},	//   _aha_, věde, евiч,
  { {0x7c3b0035,0x09b60047,0xd7950044,0x00000000}},	//   _kiur, _שפעט_, _للاخ,
  { {0x442910ca,0xc2090063,0x9f400003,0x00000000}},	//   _cha_, _וה_, phié_,
  { {0x44dc008b,0x7c29002b,0xd24f0021,0x00000000}},	//   ả_, _mher, ينَ_,
  { {0xdb0002dd,0x4429004b,0x412a0200,0x00000000}},	//   _jamá, _eha_, дого_,
  { {0x7c290185,0x703a000d,0x8624000d,0x00000000}},	//   _oher, дчас_, _сьце,
  { {0x2000000c,0x656302ab,0x6443000c,0x00000000}},	//   unii_, _henh, _iuni,
  { {0x200522e5,0x644329d0,0xfe431968,0x00000000}},	// [43c0] élia_, _huni, инто,
  { {0xc3330063,0xddcd29d1,0x7c3b00dd,0x00000000}},	//   _דוח_, traš, _aiur,
  { {0xa3c90235,0x656329d2,0xb33b021a,0x00000000}},	//   लॉक_, _menh, reçe,
  { {0x7c2929d3,0x656303cc,0xddcd0006,0x00000000}},	//   _cher, _lenh, rraš,
  { {0x2b4000c2,0x644329d4,0x7c3b0aa8,0x00000000}},	//   žico_, _luni, _diur,
  { {0x656303d9,0xddcd29d5,0xed580066,0x00000000}},	//   _nenh, praš, _ýľ_,
  { {0x98c3005a,0x2ca705b9,0x67fe008f,0x00000000}},	//   исъл, ændt_, līji,
  { {0x7c3b08c8,0xd6da0499,0x2900003b,0x00000000}},	//   _giur, дто_, ăia_,
  { {0x68250051,0x99a400ea,0x67fe008f,0x00000000}},	//   wódc, őtől_, nīji,
  { {0xdb0c0019,0x6563001f,0xe8df008b,0x00000000}},	//   öhõi, _cenh, huộc_,
  { {0xddc400b2,0x44dc0013,0x442929d6,0x00000000}},	//   križ, ủ_, _pha_,
  { {0x65630173,0x6443076b,0xa7850049,0x00000000}},	//   _eenh, _duni, _مشهو,
  { {0x44290146,0xc594000a,0xa3c90053,0x00000000}},	//   _vha_, _билј, लॉग_,
  { {0x67fe001c,0x6563001f,0x644329d7,0x00000000}},	//   dīji, _genh, _funi,
  { {0x656800f3,0x629a0529,0x69ca006f,0x00000000}},	//   madh, ătoa, ijfe,
  { {0x6e3c29d8,0x6d4e29d9,0x44290130,0x00000000}},	//   _airb, _afba, _uha_,
  { {0x40340940,0x6e3c005b,0x3d9500a0,0x00000000}},	// [43d0] ретс, _birb, лиар,
  { {0xf41f09ff,0x7c2929da,0x3f73001b,0x00000000}},	//   llä_, _sher, ệu_,
  { {0x6e3c0006,0x7c29001f,0x7d1c001f,0x00000000}},	//   _dirb, _pher, _cyrs,
  { {0x63ad0004,0x2d870045,0x65680035,0x00000000}},	//   _jaan, żne_, hadh,
  { {0x7c3b0268,0x600801f9,0x9a87018e,0x00000000}},	//   _viur, _יִשְ, туел,
  { {0x7c290037,0x7d1c0627,0x68350078,0x00000000}},	//   _wher, _fyrs, _išdi,
  { {0x3da4011c,0x7c290be9,0x28a60053,0x00000000}},	//   _тряб, _ther, _कैदि,
  { {0x656303d9,0x7c2901da,0x63ad29db,0x00000000}},	//   _senh, _uher, _naan,
  { {0x656810ca,0x656329dc,0x644329dd,0x00000000}},	//   fadh, _penh, _suni,
  { {0x656800ea,0x6fd8017d,0xb5fd0078,0x00000000}},	//   gadh, _víci, osši,
  { {0x6563017d,0xe3660076,0x63ad29de,0x00000000}},	//   _venh, лкни, _baan,
  { {0x65680035,0xf1a90063,0xa93a0047,0x00000000}},	//   aadh, _מס_, _װײני,
  { {0x656303d9,0x65680035,0x63ad1d7b,0x00000000}},	//   _tenh, badh, _daan,
  { {0x201927cb,0x644318b9,0xb2f50121,0x00000000}},	//   _aksi_, _tuni, ряющ,
  { {0xb21b010a,0xe0d5019d,0xdb0000bd,0x00000000}},	//   kræf, ають, _unmö,
  { {0x63ad00bb,0xdce70080,0x67fe001c,0x00000000}},	//   _gaan, ůměr, tīji,
  { {0xd0070076,0x7e6d00a4,0x7d1c29df,0x00000000}},	// [43e0] уете_, gsap, _syrs,
  { {0xcf250032,0xe058007e,0x67fe001c,0x00000000}},	//   شرقي, _لیست_, rīji,
  { {0xb33b03d9,0x63ad0035,0x7e6d1846,0x00000000}},	//   meça, _yaan, asap,
  { {0x6e3c00bd,0xb21b00b9,0x8afd004c,0x00000000}},	//   _wirb, stæt, _seřa,
  { {0x7e6d00ea,0x853c0078,0xfb87005d,0x00000000}},	//   csap, ldėt, ادمی,
  { {0xb33b017d,0x9f520014,0x9d431a5d,0x00000000}},	//   neça, ábær_, _герд,
  { {0x2019024a,0x853c0006,0xf41f0f00,0x00000000}},	//   _yksi_, ndėt, ylä_,
  { {0x61d10053,0x9f490026,0x27e20026,0x00000000}},	//   _सक्ष, nnað_, ókn_,
  { {0x7bc003b9,0xeef70047,0x98ae0058,0x00000000}},	//   _inmu, ָמיר_, rafı_,
  { {0x1a9b0047,0x63ad0cca,0x68250139,0x00000000}},	//   _אימע, _saan, róda,
  { {0x63ad00bb,0x4d7b00b5,0x7d7b0047,0x00000000}},	//   _paan, ערטע, ענטו,
  { {0xd6d90051,0x682500ea,0x533505d2,0x00000000}},	//   był_, lódn, иент,
  { {0x2d9814b1,0x63ad29e0,0x926b0085,0x00000000}},	//   _obre_, _vaan, эрна_,
  { {0x63ad0009,0xe7370062,0xe4a60a29,0x00000000}},	//   _waan, _сеч_, _брио,
  { {0x6fd80268,0x9f49007a,0x628f29e1,0x00000000}},	//   _lícu, fnað_, stco,
  { {0x60180076,0x9f490026,0x2d9800f8,0x00000000}},	//   гося_, gnað_, _abre_,
  { {0xb33b0016,0x8c43005b,0x853c0006,0x00000000}},	// [43f0] beça, ışma, adėt,
  { {0x6b8902f6,0x7bc0004d,0x853c0078,0x00000000}},	//   _sceg, _anmu, bdėt,
  { {0x67fe003d,0xd6d90051,0x8d740021,0x00000000}},	//   līju, zył_, صالا,
  { {0x2d980813,0x7851001c,0x9f4b0072,0x00000000}},	//   _ebre_, _jāve, ämät_,
  { {0xb5fd0006,0xe8df008b,0x67fe008f,0x00000000}},	//   aršy, _kiệm_, nīju,
  { {0x291e00c7,0x42dc0047,0xcd37007e,0x00000000}},	//   _byta_, עקגע, _مرزب,
  { {0xb21b00b9,0x5dc80063,0x31580063,0x00000000}},	//   præf, _עֶשְ, ניהן_,
  { {0xccf20063,0x7df40051,0xddc4003b,0x00000000}},	//   _וכל_, yńsk, psiţ,
  { {0x6aa90034,0xda78005a,0x060904c3,0x00000000}},	//   _usef, _бях_, кник_,
  { {0x67fe003d,0xdcf501f7,0xe8df008b,0x00000000}},	//   dīju, _hazı, _niệm_,
  { {0x69c1200b,0xdcf50058,0x7843013d,0x00000000}},	//   _inle, _kazı, _bőve,
  { {0x672e000f,0xddc40078,0x7a2d0014,0x00000000}},	//   önjü, isiš, fútg,
  { {0xe9ff001b,0x52a70062,0x6825013d,0x00000000}},	//   _luận_, авям_, lódo,
  { {0xd9e50053,0x3f8b2494,0xdcf50058,0x00000000}},	//   कसित_, _accu_, _lazı,
  { {0xb33b14b1,0x9f490026,0x853c0006,0x00000000}},	//   reça, tnað_, udėt,
  { {0x853c0078,0x682500ea,0xe1ff0022,0x00000000}},	//   rdėt, zódn, ksów_,

  { {0x8d660055,0x67fe001c,0x9f490026,0x00000000}},	// [4400] ивае, cīju, rnað_,
  { {0x957c0045,0xb21b21ad,0x68350078,0x00000000}},	//   wiąz, græd, _išdu,
  { {0x3eb90199,0xdcf5005b,0x7b6603d6,0x00000000}},	//   _erst_, _bazı, атле,
  { {0x61fc01f7,0xcdc900b5,0x9f06007e,0x00000000}},	//   lirl, וך_, _نوجو,
  { {0x61fc0139,0x853c0078,0x6825013d,0x00000000}},	//   oirl, ndėr, tódn,
  { {0x61fc29e2,0x42db0047,0x291e0022,0x00000000}},	//   nirl, כקנע, _pyta_,
  { {0x07e60001,0x99650086,0x67fe008f,0x00000000}},	//   ицим, стіл, zīju,
  { {0xd90d006a,0xdb000024,0xb21b00b9,0x00000000}},	//   رین_, _pamä, præg,
  { {0x61fc005b,0x26060086,0x28a60042,0x00000000}},	//   kirl, ичог, _कैरि,
  { {0x7c2229e3,0x4422006f,0xf8b80013,0x00000000}},	//   llor, elk_, _trĩ_,
  { {0xdcf501f7,0x47d6007e,0x07a6000d,0x00000000}},	//   _yazı, _پيشر, _ваен,
  { {0x67fe003d,0xa2b30042,0xe78322f5,0x00000000}},	//   tīju, इटल्, _душо,
  { {0x61fc19ce,0x7c2200d1,0x4425001c,0x00000000}},	//   firl, ilor, ēl_,
  { {0x61fc29e4,0x67fe001c,0x321829e5,0x00000000}},	//   girl, rīju, gory_,
  { {0x67fe003d,0x7c2229e6,0x8c430058,0x00000000}},	//   sīju, klor, ışka,
  { {0x645a29e7,0x6d5e29e8,0xe53b0063,0x00000000}},	//   mpti, ebpa, _בתור,
  { {0xb33b0016,0xb21b0146,0x3218027d,0x00000000}},	// [4410] meço, træd, bory_,
  { {0x3eb900c3,0x61fc29e9,0x645a29ea,0x00000000}},	//   _vrst_, cirl, opti,
  { {0x68080080,0x72340032,0xe9ff008b,0x00000000}},	//   vědn, _بريط, _quận_,
  { {0x645a0006,0x628000ea,0x3eb900b2,0x00000000}},	//   ipti, ámog, _trst_,
  { {0x6fd81c50,0xd5b1008b,0x22490089,0x00000000}},	//   _víct, hóa_, _juak_,
  { {0x22490089,0x27e60a9f,0xbf360063,0x00000000}},	//   _muak_, _alon_, _לארץ_,
  { {0xfb870088,0x6ce40086,0x3ea929eb,0x00000000}},	//   _вызн, _діте, lwat_,
  { {0x3ea900ac,0x3f89001f,0x1a68007e,0x00000000}},	//   owat_, ngau_, _چینی_,
  { {0x1959026c,0x645a0331,0xe619197b,0x00000000}},	//   _базы_, epti, лди_,
  { {0x69c10034,0xa2c60053,0xc48529ec,0x00000000}},	//   _unle, ामस्, блок,
  { {0x3ea9017e,0x61fc29ed,0x3218092b,0x00000000}},	//   hwat_, virl, vory_,
  { {0x3ea900e3,0x5c9a0047,0x32180051,0x00000000}},	//   kwat_, נשרײ, wory_,
  { {0xddcd0418,0x13a8007e,0x321829ee,0x00000000}},	//   mpaņ, هنگی_, tory_,
  { {0x2588011b,0x64a5014b,0x75830043,0x00000000}},	//   _vůlí_, _гака, _بیدم,
  { {0x3ea90150,0xb33b00be,0x50b50133,0x00000000}},	//   ewat_, beço, осту,
  { {0x037a007e,0x2b4029ef,0x61fc0058,0x00000000}},	//   _صحبت_, žici_, sirl,
  { {0x3ea900a4,0xf4130063,0x6280013d,0x00000000}},	// [4420] gwat_, _מפה_, ámod,
  { {0xb21b00b9,0x628629f0,0x63a629f1,0x00000000}},	//   træe, muko, lekn,
  { {0xec7a0138,0x1d190088,0x3ea9002c,0x00000000}},	//   упе_, аюць_, awat_,
  { {0x68080080,0x62860072,0xb09b0063,0x00000000}},	//   vědo, ouko, _גיטר,
  { {0x628629f2,0xeafa002a,0x3d180042,0x00000000}},	//   nuko, درات_, _बुरे_,
  { {0x25a500d1,0x645a29f3,0xf9c4005d,0x00000000}},	//   jell_, ypti, تحصی,
  { {0x6abb0035,0x63a629f4,0x7c2229f5,0x00000000}},	//   _eruf, kekn, plor,
  { {0x62860d9e,0x56780330,0x6825013d,0x00000000}},	//   kuko, абия_, lódj,
  { {0xe9ff001b,0x63a600d1,0xf2df003b,0x00000000}},	//   _quản_, dekn, ncât_,
  { {0x78bc0016,0x5498000d,0x25a529f6,0x00000000}},	//   _árvo, авоў_, gell_,
  { {0xd4970076,0xd5b70076,0x1dc90053,0x00000000}},	//   бря_, ссы_, रातत,
  { {0x22490360,0x63a629f7,0x7a2d017c,0x00000000}},	//   _puak_, gekn, rúte,
  { {0xb33b0016,0x22410150,0x62860019,0x00000000}},	//   reço, _pihk_, guko,
  { {0x07370063,0xe6770063,0x645a0829,0x00000000}},	//   _האדם_, _פתוח_, ppti,
  { {0xba3d0080,0xcf9b000a,0xf2df000c,0x00000000}},	//   _průz, лја_, ecât_,
  { {0x628629f8,0x63a9004b,0x3ea90229,0x00000000}},	//   buko, õend, twat_,
  { {0x200c29f9,0x9df929fa,0x3f891c2a,0x00000000}},	// [4430] édia_, анат_, rgau_,
  { {0xdce70045,0x644a0035,0x3ea90051,0x00000000}},	//   _zdję, _kufi, rwat_,
  { {0x2127008b,0x7c840363,0x660829fb,0x00000000}},	//   _ánh_, зуче, indk,
  { {0x60da0019,0x6abb0026,0x661a0734,0x00000000}},	//   ätme, _pruf, hotk,
  { {0xa9691168,0x661a29fc,0xf42a0072,0x00000000}},	//   аила_, kotk, lvää_,
  { {0x25a5078d,0x200900cc,0x48790363,0x00000000}},	//   xell_, lnai_, асия_,
  { {0x25a529fd,0x20090078,0x6286004d,0x00000000}},	//   vell_, onai_, zuko,
  { {0x8699000a,0x6abb29fe,0xab94005e,0x00000000}},	//   атот_, _truf, _насљ,
  { {0x7bcd001c,0xf5e90002,0x25a529ff,0x00000000}},	//   ķaud, имил_, tell_,
  { {0x661a007d,0xb33b0058,0x286b0092,0x00000000}},	//   gotk, reçl, _брдо_,
  { {0x20090150,0x25a52a00,0xf9900044,0x00000000}},	//   knai_, rell_, _سبل_,
  { {0x62862a01,0x6b8b11b8,0x25a52a02,0x00000000}},	//   tuko, nggg, sell_,
  { {0x8c1a014e,0x25a52833,0x27ed002b,0x00000000}},	//   שורי, pell_, mhen_,
  { {0x27ff00f3,0x82360032,0x63a600ea,0x00000000}},	//   liun_, ترجا, sekn,
  { {0x62862a03,0x27ed004d,0xa06a1a5d,0x00000000}},	//   suko, ohen_, раба_,
  { {0x2475001c,0x62862a04,0x99dd004c,0x00000000}},	//   mām_, puko, _buňk,
  { {0x76430035,0x44202a05,0x2475001c,0x00000000}},	// [4440] _kiny, _iki_, lām_,
  { {0x787000ea,0xe8df0013,0x8d5a04a9,0x00000000}},	//   _jóvá, huốc_, ршат_,
  { {0x2475003d,0x76432a06,0x44202071,0x00000000}},	//   nām_, _miny, _kki_,
  { {0xeb9a0079,0x764300bb,0x27ed00c2,0x00000000}},	//   рид_, _liny, jhen_,
  { {0xa9230080,0x05a90053,0x539b0063,0x00000000}},	//   ížno, क़ाब, שינו,
  { {0x76430273,0x2475003d,0x27ed1a14,0x00000000}},	//   _niny, kām_, ehen_,
  { {0x2475003d,0x442001ec,0xe7860f55,0x00000000}},	//   jām_, _oki_, оупо,
  { {0x2475003d,0x7df40051,0x27ed2a07,0x00000000}},	//   dām_, ańst, ghen_,
  { {0xa3ce0053,0x644a2a08,0x661a2a09,0x00000000}},	//   रान_, _sufi, totk,
  { {0x44f40086,0xf42a00fe,0x44320150,0x00000000}},	//   зпос, yvää_, _ahy_,
  { {0x656a007a,0x7643003e,0x2475001c,0x00000000}},	//   _vefh, _diny, gām_,
  { {0x27ed0cd4,0x27ff000c,0x2b400130,0x00000000}},	//   chen_, ciun_, žicu_,
  { {0x442000f3,0x53440062,0xa3440085,0x00000000}},	//   _dki_, дхра, дэрл,
  { {0x2475003d,0x0665007e,0x44202a0a,0x00000000}},	//   bām_, _راهپ, _eki_,
  { {0x64580e3f,0x29f60051,0x7a2400cd,0x00000000}},	//   _utvi, sław_, gòti,
  { {0x4432006f,0x187b0047,0x35e00053,0x00000000}},	//   _ghy_, יטלב, _पकड़,
  { {0x5434006a,0x200922ab,0x6e940699,0x00000000}},	// [4450] _ترور, rnai_, миту,
  { {0xdcbb07a3,0x61ee004d,0x443922a1,0x00000000}},	//   ище_, chbl, lms_,
  { {0x44392a0b,0xe2140044,0x4f6700de,0x00000000}},	//   oms_, _تبيع, _واحف,
  { {0xf5370047,0x64442a0c,0x3eaf01e1,0x00000000}},	//   קטאר_, _xiii, ægts_,
  { {0x44392a0d,0xeab30021,0xd5b8001c,0x00000000}},	//   ims_, بعض_, glāk_,
  { {0x7f3a0165,0xa966019c,0x75ed0066,0x00000000}},	//   _לערו, пиша_, _kúze,
  { {0xa3ce0053,0x682511ba,0x27ed2a0e,0x00000000}},	//   राम_, lódi, then_,
  { {0x4439017f,0x2475001c,0x75ed18a8,0x00000000}},	//   jms_, vām_, _múze,
  { {0x4432001f,0x27ed2a0f,0x76432a10,0x00000000}},	//   _rhy_, rhen_, _piny,
  { {0x27ff00f3,0x443900eb,0x2475003d,0x00000000}},	//   siun_, ems_, tām_,
  { {0x44200509,0x76432a11,0xec350041,0x00000000}},	//   _pki_, _viny, ּאָר_,
  { {0xdce70080,0x2475001c,0x3835014c,0x00000000}},	//   _nejč, rām_, _энер,
  { {0x2475003d,0xa3ce0053,0x61ee002b,0x00000000}},	//   sām_, राब_, thbl,
  { {0x44320034,0x2475003d,0x66ba0063,0x00000000}},	//   _why_, pām_, _למנה,
  { {0x442000f3,0x44320034,0x200c0016,0x00000000}},	//   _tki_, _thy_, édio_,
  { {0xddcd0078,0x8ca60042,0xe0432184,0x00000000}},	//   graž, _टैगो, енси,
  { {0xd5b1008b,0x6813003b,0xdb0b0014,0x00000000}},	// [4460] hóm_, căde, ldgæ,
  { {0x42fb0063,0x645c0139,0x63b62a12,0x00000000}},	//   _להפס, írig, _hayn,
  { {0x63b601f7,0xddcd00c3,0x2000003b,0x00000000}},	//   _kayn, braž, piii_,
  { {0x20570047,0x63b61d24,0x9057009d,0x00000000}},	//   _מיטל_, _jayn, _מבטו_,
  { {0x682502dd,0x63b62a13,0x66012a14,0x00000000}},	//   códi, _mayn, kilk,
  { {0x2d8c06a5,0x89d80021,0x82770041,0x00000000}},	//   _øde_, توتر_, לענע_,
  { {0xb21b0146,0xe838000d,0xa8a3000d,0x00000000}},	//   kræn, опкі_, ерык,
  { {0x7ceb0063,0x660104aa,0x3c2e0066,0x00000000}},	//   _הַמֶ, eilk, býva_,
  { {0x61fe0268,0x8626000d,0x66010093,0x00000000}},	//   _ompl, зьне, filk,
  { {0xf9c4007e,0x7a2d0066,0xddcd02f7,0x00000000}},	//   _تحری, lútn, zraž,
  { {0xdcfc005b,0x69c82a15,0xb21b0014,0x00000000}},	//   _karı, _inde, fræn,
  { {0xb21b010a,0x7ae20035,0x44391867,0x00000000}},	//   græn, oyot, ums_,
  { {0xddcd2a16,0xe9ff008b,0x44392a17,0x00000000}},	//   nsaţ, _quần_, rms_,
  { {0x69da00fe,0x22450137,0x66010360,0x00000000}},	//   _jote, ölk_, cilk,
  { {0xddcd0117,0x3c2e0024,0xb21b00b9,0x00000000}},	//   traž, zýva_, bræn,
  { {0xe9ff001b,0x61fe2308,0x229601e1,0x00000000}},	//   _tuần_, _empl, bæk_,
  { {0x69c82a18,0xadb500d7,0xe9ff008b,0x00000000}},	// [4470] _onde, мбаш, _huấn_,
  { {0xd5b8001c,0x9f490025,0x69da2a19,0x00000000}},	//   ndā_, mhaí_, _note,
  { {0x68250016,0xdcfc005b,0x26c00006,0x00000000}},	//   sódi, _barı, _šiol_,
  { {0x3eb200fe,0x69c82790,0xf1b9008f,0x00000000}},	//   äntä_, _ande, ēšu_,
  { {0xa3ce0235,0x89d50086,0x8aa7000d,0x00000000}},	//   रात_, дійш, яржд,
  { {0xceb2014e,0xa8590001,0x38590076,0x00000000}},	//   _שים_, ојих_, орию_,
  { {0x66012a1a,0x7c840175,0xa9c4000d,0x00000000}},	//   vilk, _путе, эсцк,
  { {0x69c82a1b,0xab66004b,0x2d8c092a,0x00000000}},	//   _ende, rsüü, _öder_,
  { {0x69da2a1c,0x66012a1d,0x63b61950,0x00000000}},	//   _fote, tilk, _rayn,
  { {0xd7060055,0xa37b0004,0x69da2a1e,0x00000000}},	//   ьные_, skõl, _gote,
  { {0xdcfc005b,0xb21b00b9,0x660100a5,0x00000000}},	//   _yarı, træn, rilk,
  { {0xd91a00b7,0x66012a1f,0x68e32a20,0x00000000}},	//   _וועל, silk, mynd,
  { {0x7a2d0066,0x69c805a5,0x29f60022,0x00000000}},	//   núto, _ynde, płat_,
  { {0x229600b9,0x32530121,0x35d40121,0x00000000}},	//   ræk_, твёр, _почё,
  { {0x3cf90053,0x3243015b,0xf1c30042,0x00000000}},	//   ्पों_, терг, शाजन,
  { {0xc7b900ea,0xdfd2013a,0x8fa32a21,0x00000000}},	//   ndő_, خير_, касе,
  { {0xdb00007a,0x9f490025,0x24530013,0x00000000}},	// [4480] _samþ, chaí_, _hãm_,
  { {0x7ae20009,0xee3714c6,0xdcfc005b,0x00000000}},	//   vyot, дну_, _sarı,
  { {0x200500cd,0x9f9c0195,0x69da2a22,0x00000000}},	//   èlic_, _zíý_, _rote,
  { {0x69da2a23,0x14d60041,0x62862a24,0x00000000}},	//   _sote, וועל_, orko,
  { {0xbb430088,0xdcb1008b,0x68e30026,0x00000000}},	//   вецк, _ẩn_, eynd,
  { {0xddcd0529,0x6286021e,0x98c60a36,0x00000000}},	//   rsaţ, irko, дсил,
  { {0x68e3010a,0x98a30001,0xdcfc005b,0x00000000}},	//   gynd, вије, _tarı,
  { {0xc6e60086,0xb9060053,0x7a2d0451,0x00000000}},	//   діоп, _पथ_, búto,
  { {0x69da2a25,0x628601e1,0x6d430077,0x00000000}},	//   _tote, jrko, žnat,
  { {0x752f0051,0x7bc9004a,0x69c82a26,0x00000000}},	//   ęczn, _zneu, _unde,
  { {0x35f70032,0xd5b8001c,0xe9ff0013,0x00000000}},	//   بريد_, rdā_, _quấn_,
  { {0x9f490027,0xab5d0022,0xa6e6012c,0x00000000}},	//   thaí_, _boży, _ожел,
  { {0xa2c60053,0x96960002,0xddcd0022,0x00000000}},	//   ामग्, _цреш, traż,
  { {0xe9ff008b,0x9f490139,0xab5d0022,0x00000000}},	//   _tuấn_, rhaí_, _doży,
  { {0x3015000a,0x9f400139,0x62862a27,0x00000000}},	//   едвр, chiú_, arko,
  { {0xb21b007a,0xdb002a28,0x747b009d,0x00000000}},	//   mræm, _jamó, _ונהג,
  { {0xf044014b,0x343800de,0x00000000,0x00000000}},	// [4490] тэро, _تسود_,   ,
  { {0xc7b900ea,0x25ac001f,0xdb0b102d,0x00000000}},	//   zdő_, nedl_, ndgå,
  { {0xdcfc008f,0xc5342177,0x7bc92a29,0x00000000}},	//   _marķ, תָּה_, _pneu,
  { {0xdab9000d,0x7a2d0066,0x69de0ef1,0x00000000}},	//   зыкі_, túto, öpen,
  { {0x7eb80025,0x442b0139,0x68e300a3,0x00000000}},	//   rúpá, ilc_, wynd,
  { {0x7bc90185,0x48b5005a,0xe9d8000d,0x00000000}},	//   _wneu, ещит, мкі_,
  { {0xadab005e,0xf8920002,0xdcee0022,0x00000000}},	//   удeн, гајќ, _odbę,
  { {0xbddb0164,0xdb000025,0x62860137,0x00000000}},	//   _guèr, _camó, yrko,
  { {0x3c350147,0xd70903d6,0x68e32a2a,0x00000000}},	//   gåve_, яние_, synd,
  { {0xb33b00cd,0xd8e70121,0x7c2b092f,0x00000000}},	//   neçu, _оцеп, llgr,
  { {0xdb0000cd,0x752f0022,0xdc39009a,0x00000000}},	//   _famó, ęczo, ּעָר,
  { {0xab5d0051,0x44240013,0x62862a2b,0x00000000}},	//   _poży, ôm_, trko,
  { {0x62862a2c,0x7c2b08bf,0xe60e085e,0x00000000}},	//   urko, ilgr, _бд_,
  { {0xdb000051,0xe2a70014,0x7c2b2a2d,0x00000000}},	//   _zamó, óðar_, hlgr,
  { {0x1c1f0053,0xf8a70044,0x307512a5,0x00000000}},	//   यकाल_, دة_, кутс,
  { {0x6286007d,0xa3ba005d,0xb4fa009a,0x00000000}},	//   prko, _رابر_, _מפצי,
  { {0x63a4002c,0x44222a2e,0x8d6605fb,0x00000000}},	// [44a0] _ibin, mok_, евзе,
  { {0xad65006a,0x271e0013,0xa3ce0053,0x00000000}},	//   نامه, ịng_, राव_,
  { {0x44220592,0x8d930021,0xfce31b08,0x00000000}},	//   ook_, المش, лофо,
  { {0x44222a2f,0x80d90082,0x00000000,0x00000000}},	//   nok_, _नॅटे,   ,
  { {0x63a40035,0xdb0009aa,0x7a3618e6,0x00000000}},	//   _mbin, _ramó, hâte,
  { {0x44221362,0x7c2b2a30,0xdb000014,0x00000000}},	//   hok_, algr, _samó,
  { {0x25ac0080,0x44222a31,0x22440061,0x00000000}},	//   vedl_, kok_, ímky_,
  { {0x25ac002b,0x6813003b,0x8c432254,0x00000000}},	//   wedl_, tăda, _бесе,
  { {0xa6140001,0x628000ea,0xd5b8001c,0x00000000}},	//   кмич, ámol, klāt_,
  { {0x5b350088,0x63a40b34,0x7c222a32,0x00000000}},	//   _рэсу, _abin, loor,
  { {0xa37b0019,0x7c4700b9,0xf993009f,0x00000000}},	//   lkõi, _årræ, _תרע_,
  { {0x44222a33,0x7c222a34,0x2bc60053,0x00000000}},	//   gok_, noor, _रोमा,
  { {0xa2be0053,0x55e62a35,0xb21b0014,0x00000000}},	//   शिष्, _подб, sræm,
  { {0x7c220162,0x6d5c004d,0xf7430054,0x00000000}},	//   hoor, _nfra, _сечо,
  { {0x7c222a36,0x44222a37,0xb21b01e1,0x00000000}},	//   koor, bok_, lræk,
  { {0x629a000c,0x4422262d,0x6d4e00a4,0x00000000}},	//   ător, cok_, _agba,
  { {0xa3b8006a,0x7e64002c,0x7c2228b0,0x00000000}},	// [44b0] _ساير_, gpip, door,
  { {0x63bd2a38,0x7c221860,0xddc4005f,0x00000000}},	//   ldsn, eoor, asiž,
  { {0x55770047,0x7c220180,0x628f2a39,0x00000000}},	//   געבן_, foor, luco,
  { {0x7c220019,0x63bd2a3a,0x539c0047,0x00000000}},	//   goor, ndsn, ּיגו,
  { {0x629d03e8,0x6d5c001f,0x63bd00f5,0x00000000}},	//   ntso, _ffra, idsn,
  { {0x442218a8,0xc984005e,0xb21b01e1,0x00000000}},	//   zok_, гући, dræk,
  { {0x7c220162,0x7c2c0003,0xdb0b00ea,0x00000000}},	//   boor, éorè, iegé,
  { {0x69d8082a,0x46a50121,0x629d16af,0x00000000}},	//   ajve, ваив, ktso,
  { {0xdcee0080,0x44220e03,0x63bd0137,0x00000000}},	//   _odbě, vok_, ddsn,
  { {0x628f0290,0x44220509,0x55e52a3b,0x00000000}},	//   duco, wok_, тооб,
  { {0x442218a8,0xd7e70086,0x764a001f,0x00000000}},	//   tok_, _підо, _dify,
  { {0x629d2a3c,0x45180085,0x645c009c,0x00000000}},	//   ftso, эцыя_, íria,
  { {0x629d00b9,0x21f40019,0x644e0046,0x00000000}},	//   gtso, _lähe_, íbir,
  { {0x44222a3d,0x21ef004b,0x6d5b0058,0x00000000}},	//   sok_, _püha_, _şuan,
  { {0x44222a3e,0x21f400bd,0x7e7d02fb,0x00000000}},	//   pok_, _nähe_, _avsp,
  { {0x63a40009,0xc0e3000a,0xe3b2002a,0x00000000}},	//   _ubin, шоск, _ضرب_,
  { {0x539b01d8,0xf77200b5,0x7c220102,0x00000000}},	// [44c0] _חיפו, יקן_, voor,
  { {0x4d63071a,0x7c220102,0xb33b0058,0x00000000}},	//   икув, woor, reçt,
  { {0x7c222a3f,0xc2c9005d,0x8c460c4d,0x00000000}},	//   toor, _قبیل_, веже,
  { {0xe7270032,0x31780051,0xcb0a01fb,0x00000000}},	//   _نص_, larz_, ويان_,
  { {0x7c220162,0x7f1a0086,0xd357009a,0x00000000}},	//   roor, _ціну_, דיני_,
  { {0x7c22166f,0x645e0153,0x6d5c04aa,0x00000000}},	//   soor, _épig, _ufra,
  { {0x63bd0146,0xa37b0019,0x7c222a40,0x00000000}},	//   ydsn, skõi, poor,
  { {0x67f50024,0xb21b0146,0xda08008d,0x00000000}},	//   _nájd, træk, iỏi_,
  { {0xda080013,0xdb0c0072,0xfaa60002,0x00000000}},	//   hỏi_, öhäi, _јазо,
  { {0xb21b00b9,0xca97009a,0x00000000,0x00000000}},	//   rræk, _בדמי_,   ,
  { {0xdb0b00ea,0xb21b00b9,0x9633000d,0x00000000}},	//   vegé, sræk, рнэц,
  { {0xd5be001c,0x78fb0047,0x629d0d14,0x00000000}},	//   _šāda_, _קלאפ, ttso,
  { {0x61e10137,0x63af00c2,0x63bd2a41,0x00000000}},	//   öllo, recn, rdsn,
  { {0x9f490058,0x3494210d,0x63af0130,0x00000000}},	//   lhaç_, _бакр, secn,
  { {0x67f5013d,0xdb0b013d,0x7851008f,0x00000000}},	//   _fájd, regé, _pāvi,
  { {0x58bb0063,0x2d982a42,0x7feb0054,0x00000000}},	//   ומלצ, _acre_, єєва_,
  { {0x2caa00f3,0x44292a43,0xdd9b0086,0x00000000}},	// [44d0] _apbd_, _ika_, дше_,
  { {0x21f4004b,0x644d002b,0xfc670062,0x00000000}},	//   _pähe_, _hiai, въдн,
  { {0x644d0035,0x645e0003,0xdb510021,0x00000000}},	//   _kiai, _épid, مَا_,
  { {0x21f40019,0xddcd0066,0x8b940054,0x00000000}},	//   _vähe_, dsať, иріч,
  { {0x3c3502eb,0xaa580071,0x20092a44,0x00000000}},	//   gåva_, вичу_, miai_,
  { {0x200900eb,0x644d1cac,0x443b008b,0x00000000}},	//   liai_, _liai, _lhq_,
  { {0x07a50086,0x7a2d0066,0x6925000d,0x00000000}},	//   гайн, núti, ымка,
  { {0x200900eb,0x628000ea,0x6801001c,0x00000000}},	//   niai_, ámok, lēdz,
  { {0x5b150001,0xa3d70053,0xaca30013,0x00000000}},	//   _смат, सान_, _khỏa,
  { {0xf99300b3,0xb21b00b9,0x7ae4112c,0x00000000}},	//   _خبر_, bræi, äite,
  { {0x240a005a,0x20090006,0x644d2986,0x00000000}},	//   енни_, kiai_, _biai,
  { {0xb8f70235,0x67f5004c,0x317812dc,0x00000000}},	//   ाम_, _báje, warz_,
  { {0x31780051,0x20092a45,0x92930085,0x00000000}},	//   tarz_, diai_, баўц,
  { {0x27ed06a3,0x44292a46,0xb21b01e1,0x00000000}},	//   lken_, _eka_, jsæd,
  { {0xb21b00b9,0x644d013d,0x2009013d,0x00000000}},	//   dsæd, _fiai, fiai_,
  { {0x20092a47,0x31780051,0x27ed2a48,0x00000000}},	//   giai_, sarz_, nken_,
  { {0x27ed02b0,0x8f7502fe,0x21ef004d,0x00000000}},	// [44e0] iken_, русі, _kühl_,
  { {0x7a2d0026,0x7c292a49,0xdd92002a,0x00000000}},	//   búti, _aker, صوص_,
  { {0x67f50080,0x27ed2a4a,0xa91c0024,0x00000000}},	//   _záje, kken_, _odľa,
  { {0x27ed02b0,0x7c3b1a74,0xddc40006,0x00000000}},	//   jken_, _chur, tsių,
  { {0xddc40078,0xd4910013,0xab77002a,0x00000000}},	//   usių, hù_, امها_,
  { {0x27ed02b0,0x2d830117,0xddc40006,0x00000000}},	//   eken_, _gdje_, rsių,
  { {0x2fc0006f,0xf9690086,0x00000000,0x00000000}},	//   odig_, трій_,   ,
  { {0xd6da2a4b,0x3834018e,0x2fc02a4c,0x00000000}},	//   ето_, јнир, ndig_,
  { {0x644d0d23,0x2fc02a4d,0xdd25008f,0x00000000}},	//   _riai, idig_, _cīņa,
  { {0x442901e3,0x27ed2a4e,0xa96a0021,0x00000000}},	//   _ska_, aken_, _أمام_,
  { {0x2ed10053,0xf866005e,0xb4be0042,0x00000000}},	//   _सप्त, _свео, ँटे_,
  { {0x2fc00122,0x764100ac,0x07b70021,0x00000000}},	//   jdig_, amly, _مهمة_,
  { {0x51872a4f,0x20090006,0x92580062,0x00000000}},	//   лува, viai_, лаят_,
  { {0xe1ff006d,0x54e60021,0x2fc02a50,0x00000000}},	//   apón_, _مسبق, edig_,
  { {0xb21b0146,0x2ee9001f,0x44292410,0x00000000}},	//   kræv, wyaf_, _tka_,
  { {0x087700b5,0x2fc0002c,0x9f4000fe,0x00000000}},	//   טעלט_, gdig_, kkiä_,
  { {0x33a8011c,0x200900eb,0xce950062,0x00000000}},	// [44f0] _също_, riai_, разъ,
  { {0x78ba017f,0x20092a51,0x7c292a52,0x00000000}},	//   _ostv, siai_, _sker,
  { {0x200900eb,0x515a014e,0x27ed005b,0x00000000}},	//   piai_, _בכתו, yken_,
  { {0x200c0164,0x657a2a53,0xce95005a,0x00000000}},	//   édit_, hath, _камъ,
  { {0x657a2a54,0x3ea000cd,0x0f7a0aeb,0x00000000}},	//   kath, ctit_, _בארב,
  { {0x53380047,0x88c50021,0x7bc60014,0x00000000}},	//   אנדן_, لتعل, _ókun,
  { {0x645c0066,0x657a2a55,0x7c3b1217,0x00000000}},	//   íril, dath, _thur,
  { {0x657a0027,0x7c3b0035,0x27ed1c41,0x00000000}},	//   eath, _uhur, uken_,
  { {0x27ed2a56,0x657a2a57,0xab2b0044,0x00000000}},	//   rken_, fath, _أسأل_,
  { {0x7555005e,0xdb0000be,0x86980062,0x00000000}},	//   шњиц, _camõ, утът_,
  { {0x21f40019,0xa8a7005a,0x64a52017,0x00000000}},	//   _näha_, _щрак, шана,
  { {0x3ea02a58,0x93460121,0x787a009a,0x00000000}},	//   ytit_, инне, _יָדו,
  { {0x66670076,0xb7bd003b,0x657a2a59,0x00000000}},	//   _съез, ulţu, bath,
  { {0x657a2a5a,0xd5a3005d,0x66130043,0x00000000}},	//   cath, _طلبی, _دژبا,
  { {0xab5d0045,0xc2430088,0x61ee2a5b,0x00000000}},	//   _każd, інск, rkbl,
  { {0x2fc00173,0x2fda007e,0x3ea02a5c,0x00000000}},	//   udig_, خورد_, ttit_,
  { {0x2fc02a5d,0xed5a20cc,0x3ea02a5e,0x00000000}},	// [4500] rdig_, воз_, utit_,
  { {0xc27b00b5,0x7aeb00b9,0x3ea02a5f,0x00000000}},	//   _שריי, dygt, rtit_,
  { {0x7a2d0026,0x3ea00b3d,0x8fa61915,0x00000000}},	//   nútu, stit_, _кане,
  { {0xc50c0047,0x9f400072,0xa7fc0058,0x00000000}},	//   עלאָ, tkiä_, _atın,
  { {0x62880051,0xab27005e,0x7c66007e,0x00000000}},	//   ądow, аоца_, _چارل,
  { {0x2886005e,0x9f400072,0x4df50094,0x00000000}},	//   аћив, rkiä_, _ляст,
  { {0x44c5001c,0xe466005b,0x9f400072,0x00000000}},	//   _nē_, önüş, skiä_,
  { {0x21ef004b,0xc7c61410,0x68ea002b,0x00000000}},	//   _rühm_, рски, ryfd,
  { {0x8f9b00b5,0x657a2a60,0x48130085,0x00000000}},	//   דיפי, tath, ўмыс,
  { {0x26c000eb,0x95d8000a,0x657a0025,0x00000000}},	//   _šios_, удот_, uath,
  { {0x78ba0198,0x7d7b0063,0x7bc02a61,0x00000000}},	//   _ustv, כניו, _kamu,
  { {0x2618016a,0xb6a6000a,0x7bc004f8,0x00000000}},	//   _पदवी_, _видл, _jamu,
  { {0x7bc02a62,0x6aa22a63,0xf2e40121,0x00000000}},	//   _mamu, ntof, оюро,
  { {0x657a00ac,0x7bc01c6f,0x7a2d10a7,0x00000000}},	//   qath, _lamu, sútv,
  { {0xe63b0063,0x16b60053,0xdfd502dc,0x00000000}},	//   _שתוכ, _अनुब, бовы,
  { {0x7bc0014f,0x7415006a,0xd25b0062,0x00000000}},	//   _namu, _دوبا, _ицо_,
  { {0x64580004,0x200c0268,0xdb23005b,0x00000000}},	// [4510] _huvi, èdia_, ürül,
  { {0x645800fe,0x9df80121,0x7bc00072,0x00000000}},	//   _kuvi, анут_, _aamu,
  { {0xdcbb005a,0xdbd10014,0x628001d1,0x00000000}},	//   ъща_, _býðs, ámov,
  { {0x61e5004d,0x7bc02a64,0xab950054,0x00000000}},	//   _hohl, _camu, сиді,
  { {0x7bc00268,0x61e500bd,0x201e0003,0x00000000}},	//   _damu, _kohl, étie_,
  { {0x64580016,0x65780240,0x7ae40019,0x00000000}},	//   _ouvi, _nevh, äita,
  { {0x61e50114,0xb868005e,0x681300dd,0x00000000}},	//   _mohl, ајње_, lădi,
  { {0xe7392a65,0x3c3c0066,0x96951e3b,0x00000000}},	//   лей_, tíve_, брош,
  { {0x6abb2a66,0xdb0b004d,0x56290062,0x00000000}},	//   _usuf, ndgü, лжим_,
  { {0x7bc00473,0x64580078,0xa5b9005e,0x00000000}},	//   _zamu, _buvi, ућих_,
  { {0x64580529,0xf494015a,0x628f2a67,0x00000000}},	//   _cuvi, оряю, erco,
  { {0x6458017d,0x69c12a68,0x9cd60063,0x00000000}},	//   _duvi, _hale, צורה_,
  { {0x97560063,0x69c12a69,0xb7c700dd,0x00000000}},	//   _הינו_, _kale, _elţî,
  { {0xeb3a0047,0xbb3a00ff,0x69c32a6a,0x00000000}},	//   טערש, טערי, ndne,
  { {0x61e501c8,0x64580023,0x69c12a6b,0x00000000}},	//   _dohl, _guvi, _male,
  { {0xa37b0019,0x69c12a6c,0x00000000,0x00000000}},	//   skõr, _lale,   ,
  { {0x38a10025,0xb21b2a6d,0x7bc02a6e,0x00000000}},	// [4520] hór_, græs, _ramu,
  { {0x7bc00551,0xab8c005b,0x38a10026,0x00000000}},	//   _samu, _çözü, kór_,
  { {0x8b6a065b,0x7bc02a6f,0x69c31780,0x00000000}},	//   гиев_, _pamu, ddne,
  { {0x6aa22a70,0x75ed017d,0x7bc2004c,0x00000000}},	//   ttof, _dúzi, udou,
  { {0x64460078,0x69c1277f,0x6aa22a71,0x00000000}},	//   imki, _bale, utof,
  { {0xe2a70026,0x7bc005b3,0x69c1169b,0x00000000}},	//   óðir_, _wamu, _cale,
  { {0xf1b3014e,0xf8060062,0x69c10a9b,0x00000000}},	//   פסה_, йчин, _dale,
  { {0x67f5006d,0x69c1004e,0x69c32a72,0x00000000}},	//   _pája, _eale, adne,
  { {0x69c12a73,0xa3d70042,0x64582a74,0x00000000}},	//   _fale, सास_, _suvi,
  { {0x38a10051,0x69c12a75,0xceb32177,0x00000000}},	//   bór_, _gale, ליח_,
  { {0xddc60078,0x7a2d0014,0xa3b50085,0x00000000}},	//   _atkū, rútt, обні,
  { {0x69c10045,0x61e5004d,0x7a2d2717,0x00000000}},	//   _zale, _sohl, sútt,
  { {0x69c10035,0xe298000d,0x628f2a76,0x00000000}},	//   _yale, баў_, urco,
  { {0x6458116c,0x7afd0058,0x27e62a77,0x00000000}},	//   _tuvi, _üste, _hoon_,
  { {0x27e62a78,0x54670131,0x00000000,0x00000000}},	//   _koon_, _лајм_,   ,
  { {0x61e500bd,0x7a2d0066,0x69c31efc,0x00000000}},	//   _wohl, nútr, zdne,
  { {0x63ad00bb,0x6d48016b,0x61e50080,0x00000000}},	// [4530] _iban, _údaj, _tohl,
  { {0x442b11fb,0xb21b0014,0x2d870003,0x00000000}},	//   loc_, rræs, ûne_,
  { {0x69c12a79,0x5e440044,0x00000000,0x00000000}},	//   _rale, أَلْ,   ,
  { {0xb21b0146,0x27e62a7a,0x6fb50021,0x00000000}},	//   præs, _noon_, _بمحا,
  { {0x63ad0139,0x69c12a7b,0x69c300c2,0x00000000}},	//   _mban, _pale, tdne,
  { {0x7e6d2a7c,0xe7a60053,0xf1ba0013,0x00000000}},	//   mpap, क्सप, _ươi_,
  { {0x69c12a7d,0x63ad2a7e,0x41fa0047,0x00000000}},	//   _vale, _oban, יִקײ,
  { {0x442b00cd,0x16651736,0x3f9b18e4,0x00000000}},	//   joc_, овим, ngqu_,
  { {0x27e6002c,0x6b8900ea,0x79a702b3,0x00000000}},	//   _doon_, _ideg, _грее,
  { {0x63ad2a7f,0x7c2b2a80,0x7a2d0014,0x00000000}},	//   _aban, logr, rúts,
  { {0x27e6021f,0x04460928,0xca480067,0x00000000}},	//   _foon_, женн, _الله_,
  { {0x3885003d,0xc1690ee1,0x5c9a0047,0x00000000}},	//   mēr_, _יח_, סשרײ,
  { {0xe72e019d,0x645e0003,0x7c2b1e30,0x00000000}},	//   _це_, _épin, iogr,
  { {0x27e60122,0x7c2b2a81,0x63ad2a82,0x00000000}},	//   _zoon_, hogr, _eban,
  { {0x7c2b2a83,0xdfd201fb,0x6b890022,0x00000000}},	//   kogr, ويس_, _odeg,
  { {0x6b890035,0x442b00be,0x67f50124,0x00000000}},	//   _ndeg, coc_, _májo,
  { {0x7e6d0273,0xa3d70235,0x7c2b2a84,0x00000000}},	// [4540] gpap, सार_, dogr,
  { {0x6b892a85,0x0d86013c,0x681300dd,0x00000000}},	//   _adeg, ілен, mădu,
  { {0x7e6d002c,0xb607001c,0xd5fa0047,0x00000000}},	//   apap, mašī, ספער,
  { {0xb21b00b9,0xcdc90063,0x5aca0e82,0x00000000}},	//   nsæn, כך_, илем_,
  { {0x27e600a4,0xda770062,0x6b89002b,0x00000000}},	//   _roon_, оящ_, _ddeg,
  { {0x27e60037,0xc86606da,0x20100022,0x00000000}},	//   _soon_, отии, śnić_,
  { {0x2e2f00bd,0xdb0b19c7,0x67fc013d,0x00000000}},	//   rüft_, regá, _léje,
  { {0x76aa047e,0x76740002,0x7a3f0003,0x00000000}},	//   атов_, плиф, vête,
  { {0xb21b01e1,0x7a2d0014,0x6a831dd0,0x00000000}},	//   dsæn, rútr, _олта,
  { {0x27e600e8,0x63ad0290,0x74a60002,0x00000000}},	//   _woon_, _sban, ојме,
  { {0x957c0051,0x27e62a86,0xa3d70053,0x00000000}},	//   ejąc, _toon_, साल_,
  { {0x7a3f0164,0xd37b0002,0x7e6d2a87,0x00000000}},	//   rête, шчо_, ypap,
  { {0x6813003b,0x442b2a88,0xe737005e,0x00000000}},	//   gădu, roc_, _дец_,
  { {0x67fc0b6c,0x442b2a89,0x0737009a,0x00000000}},	//   _déje, soc_, _ואדם_,
  { {0xba3d0080,0x7c2b215e,0x957c0051,0x00000000}},	//   _způs, yogr, ając,
  { {0x68250051,0x6d580006,0x63ad0c55,0x00000000}},	//   wódz, žval, _uban,
  { {0x7ae4004b,0xa7fc0075,0x9df9066f,0x00000000}},	// [4550] äitl, _atık, бнат_,
  { {0xf2d200b5,0x6b890290,0xe2a70026,0x00000000}},	//   _װעט_, _sdeg, óður_,
  { {0x6ce40088,0x91ba0063,0x61e10026,0x00000000}},	//   міце, _המתי, öllu,
  { {0xf3ff0016,0x32110051,0x3c3c0066,0x00000000}},	//   nhã_, lizy_, tíva_,
  { {0xda35000d,0x7c2b278f,0xa9690781,0x00000000}},	//   педы, rogr, била_,
  { {0xb7bd000c,0x997e003b,0xeab00044,0x00000000}},	//   moţi, răşi_, ضعه_,
  { {0x67f5000f,0x7c2b2a8a,0x2d8100a4,0x00000000}},	//   _fájl, pogr, mahe_,
  { {0x997e003b,0x69de2a8b,0x661a05a5,0x00000000}},	//   păşi_, öper, entk,
  { {0x06091415,0xf771005d,0x0593005d,0x00000000}},	//   йник_, واک_, وادگ,
  { {0x2d81004d,0x245a001c,0xd7060121,0x00000000}},	//   nahe_, _zīmi_, яные_,
  { {0x645e0003,0x27f70044,0xab5d0022,0x00000000}},	//   _épil, _وأصح, _zaża,
  { {0x98170044,0x7d02009c,0x96b9014b,0x00000000}},	//   _ببطا, _híré, _гуку_,
  { {0xc5f5005a,0xb21b00b9,0x11d60054,0x00000000}},	//   _някъ, rsæn, півр,
  { {0x6813000c,0x21670002,0xc7b9013d,0x00000000}},	//   rădu, зири_, leő_,
  { {0xe3c20058,0x00000000,0x00000000,0x00000000}},	//   _alış_,   ,   ,
  { {0x6d480025,0x99870080,0xddc400c2,0x00000000}},	//   _údai, konů_, dpiš,
  { {0x3f80017d,0x35d00053,0xd83e01d9,0x00000000}},	// [4560] raiu_, _थोड़, íčin_,
  { {0x7ae40019,0xb21b0026,0x6286147d,0x00000000}},	//   äitm, nsæl, msko,
  { {0xc173014e,0x3b66005a,0xe7bd0161,0x00000000}},	//   _אחת_, пълв, ्याप,
  { {0xb7bd003b,0x60db0063,0x9987004c,0x00000000}},	//   boţi, _הקטנ, fonů_,
  { {0x44200009,0x6456005b,0x62862a8c,0x00000000}},	//   _mji_, _miyi, nsko,
  { {0x62862a8d,0x433b0041,0x20120058,0x00000000}},	//   isko, זענב, liyi_,
  { {0x7af20080,0x6f0400c2,0x44202a8e,0x00000000}},	//   _řetě, lzic, _oji_,
  { {0x62862a8f,0xab662a90,0xc6f81578,0x00000000}},	//   ksko, _хвал, жних_,
  { {0x62862a91,0x95ca2a92,0x6f042a93,0x00000000}},	//   jsko, буна_, nzic,
  { {0x27ff003e,0x44200150,0x62862a94,0x00000000}},	//   ahun_, _aji_, dsko,
  { {0x67f50080,0x26cf2a95,0x20120075,0x00000000}},	//   _zájm, _ergo_, kiyi_,
  { {0x6286017f,0xdb0b0137,0x64441ea2,0x00000000}},	//   fsko, begä, _chii,
  { {0x2d8100a4,0x628602ad,0xe298000d,0x00000000}},	//   yahe_, gsko, паў_,
  { {0x6f040051,0x26c3008f,0xeab10063,0x00000000}},	//   dzic, ājot_, כֹל_,
  { {0x64a30635,0x6f041236,0x403506da,0x00000000}},	//   _заја, ezic, девс,
  { {0x999e00eb,0x2d81002c,0x75370063,0x00000000}},	//   _kitų_, wahe_, _מאוד_,
  { {0xdb080164,0x6147013d,0x2586004c,0x00000000}},	// [4570] _élèv, félé, cílí_,
  { {0xddc4007d,0x44392a96,0xe1750021,0x00000000}},	//   tpiš, lls_, _تُدخ,
  { {0x645702dd,0x271e008b,0xb7bd003b,0x00000000}},	//   _éxit, ịnh_, soţi,
  { {0x44cc0080,0x2d81002c,0xa3d30053,0x00000000}},	//   _mě_, sahe_, _होम_,
  { {0x44391e92,0xddc4007d,0xb5fd21e4,0x00000000}},	//   ils_, spiš, opšt,
  { {0x443914e6,0x3ea92a97,0x61470003,0x00000000}},	//   hls_, mtat_, célé,
  { {0x44cc0080,0x4439001c,0x27ff2894,0x00000000}},	//   _ně_, kls_, thun_,
  { {0x2fc92a98,0x44392a99,0x9987004c,0x00000000}},	//   ndag_, jls_, ponů_,
  { {0x3c440088,0x3ea92a9a,0x44390550,0x00000000}},	//   _чэрв, ntat_, dls_,
  { {0x44322a9b,0x7af600d1,0x3ea92a9c,0x00000000}},	//   _sky_, øyte, itat_,
  { {0x6f042a9d,0x79832a9e,0x44390046,0x00000000}},	//   zzic, manw, fls_,
  { {0x2fc9006f,0x62862a9f,0x7983001f,0x00000000}},	//   jdag_, tsko, lanw,
  { {0xe5a500a0,0x1307000d,0x62862aa0,0x00000000}},	//   _жили, дняй_, usko,
  { {0x42552aa1,0x44392aa2,0x62862aa3,0x00000000}},	//   етст, als_, rsko,
  { {0x2012005b,0xa0a32aa4,0x628614a7,0x00000000}},	//   tiyi_, кард, ssko,
  { {0x2fc900bb,0xa067000a,0x4420014f,0x00000000}},	//   gdag_, ќата_, _uji_,
  { {0xb226000a,0x2012005b,0x2000003b,0x00000000}},	// [4580] _омил, riyi_, rhii_,
  { {0x6f042aa5,0xdb080003,0x20120058,0x00000000}},	//   rzic, _élév, siyi_,
  { {0x2a6d0185,0x6147013d,0x3ea900dd,0x00000000}},	//   _ateb_, rélé, atat_,
  { {0xab5d0051,0x3ea901a8,0x6f0400ca,0x00000000}},	//   _ważn, btat_, pzic,
  { {0x3ea92aa6,0xbaba0021,0x7983002b,0x00000000}},	//   ctat_, تداء_, fanw,
  { {0x7c39002b,0x286a19b6,0xe876005d,0x00000000}},	//   alwr, орио_, واعظ,
  { {0x6d5c01b3,0x6da3263d,0x26cd004e,0x00000000}},	//   _igra, _шира, eveo_,
  { {0xab2a2aa7,0x7a3f0003,0x9b930044,0x00000000}},	//   _доба_, rêta, _للفت,
  { {0x9f49005b,0x3ae8005d,0xdb0b1778,0x00000000}},	//   rkaç_, _عبری_, tegå,
  { {0x67fc03a1,0x63a42aa8,0x7983002b,0x00000000}},	//   _déja, _acin, canw,
  { {0x0d970ee1,0xdb0b0666,0xe4150086,0x00000000}},	//   וכים_, regå, еднь,
  { {0x8c43005b,0xa2952049,0x44391806,0x00000000}},	//   _üşte, намі, uls_,
  { {0x6d5c2aa9,0x44392aaa,0x65940c0b,0x00000000}},	//   _ogra, rls_, _залу,
  { {0xb21b007a,0x4439001c,0x44cc0080,0x00000000}},	//   msæk, sls_, _tě_,
  { {0x69c82305,0x2fc92aab,0x2465008f,0x00000000}},	//   _made, tdag_, _tēma_,
  { {0x76580009,0x3ea90f70,0x6d5c2aac,0x00000000}},	//   _hivy, ttat_, _agra,
  { {0x76580035,0x3ea901b2,0x63bd003f,0x00000000}},	// [4590] _kivy, utat_, mesn,
  { {0xa3d3016a,0x2fc92aad,0x69da00d1,0x00000000}},	//   _होत_, sdag_, _nnte,
  { {0x69ca001f,0x629d2aae,0x2fc92aaf,0x00000000}},	//   ddfe, luso, pdag_,
  { {0xf41f00fe,0x63bd0006,0xde59000d,0x00000000}},	//   nnä_, nesn, _намі_,
  { {0xf41f0072,0x6b80004d,0x63bd0066,0x00000000}},	//   inä_, _demg, iesn,
  { {0xe29c0063,0xa9690a1f,0x69c82ab0,0x00000000}},	//   קשור, чика_, _cade,
  { {0x69c82ab1,0xa8550259,0x67f5004c,0x00000000}},	//   _dade, нтиј, _háji,
  { {0xb8d70053,0x6d5c2888,0x7983004d,0x00000000}},	//   _छह_, _zgra, sanw,
  { {0x7bdb00a4,0x63bd00fc,0x69c82ab2,0x00000000}},	//   _inuu, desn, _fade,
  { {0xdcee0080,0xf41f00fe,0x629d078c,0x00000000}},	//   _nebě, enä_, duso,
  { {0x629d00ac,0x45190121,0x67d5005e,0x00000000}},	//   euso, яция_, _пожу,
  { {0x9f4b13a8,0x69c808c4,0x629d2ab3,0x00000000}},	//   _você_, _zade, fuso,
  { {0xe784013c,0x69da002b,0x629d2ab4,0x00000000}},	//   _рухо, _ynte, guso,
  { {0x63bd001f,0x7c22008f,0x6d580078,0x00000000}},	//   aesn, čori, žvai,
  { {0x60262ab5,0x63bd2ab6,0x6d5c002b,0x00000000}},	//   едва, besn, _rgra,
  { {0x6d5c2ab7,0x03a60699,0x63a40f74,0x00000000}},	//   _sgra, _џипо, _ucin,
  { {0x629d017d,0x69ca001f,0x6d5c2ab8,0x00000000}},	// [45a0] cuso, ydfe, _pgra,
  { {0xee3711e6,0x20c60086,0xab5d0051,0x00000000}},	//   ену_, _зйом, _inży,
  { {0x6d5c00c3,0x69c82ab9,0x27210013,0x00000000}},	//   _vgra, _rade, ỳnh_,
  { {0x69c801f7,0x7bcf039f,0x7981001f,0x00000000}},	//   _sade, _ócul, _aelw,
  { {0x69c82aba,0x7afd005b,0xd7f10013,0x00000000}},	//   _pade, _üstl, _gũi_,
  { {0x63bd0051,0xead7000d,0xca75000d,0x00000000}},	//   zesn, эміі_, туцы,
  { {0x79810185,0xf41f00fe,0x69da004d,0x00000000}},	//   _delw, ynä_, _vnte,
  { {0xf0930063,0x3f820130,0xab690044,0x00000000}},	//   אנה_, _jeku_, _يحقق_,
  { {0xdb0600fe,0x601b00fe,0x98c00058,0x00000000}},	//   ämän, lämä, ırız_,
  { {0x69da0cd4,0x48e62abb,0x79811150,0x00000000}},	//   _unte, _позв, _gelw,
  { {0x29180004,0x63bd00eb,0x29070045,0x00000000}},	//   _ära_, tesn, czna_,
  { {0x3f82017f,0x388c0080,0xdcf5008f,0x00000000}},	//   _neku_, měr_, _zdzē,
  { {0xfbd30063,0x1dd10053,0x63bd0aae,0x00000000}},	//   אתר_, _सफलत, resn,
  { {0x63bd2abc,0x629d2abd,0xf41f0072,0x00000000}},	//   sesn, ruso, snä_,
  { {0xadc30013,0x3f820360,0x601b0072,0x00000000}},	//   _ngạc, _beku_, jämä,
  { {0x629d00ea,0x653b0063,0x35a60042,0x00000000}},	//   puso, _מעוד, _खाड़,
  { {0xf4580047,0xdb0b0331,0x6003004b,0x00000000}},	// [45b0] _איהר_, segú, _nõme,
  { {0x4df40086,0x3f82004b,0x29070022,0x00000000}},	//   ляєт, _eeku_, yzna_,
  { {0xe29f0026,0xe9df0013,0x41de0042,0x00000000}},	//   luð_, _đú_, मारस,
  { {0x2cb800f3,0x9be40085,0xdab90085,0x00000000}},	//   _dprd_, лічк, дыкі_,
  { {0xe29f0026,0xead4012c,0x81440043,0x00000000}},	//   nuð_, лоць, _لنین,
  { {0x127c0047,0xb7bd003b,0xf993005d,0x00000000}},	//   לאדע, inţe, ابش_,
  { {0x9f400014,0x99830078,0xaa560044,0x00000000}},	//   lkið_, _ųjų_, خلوا_,
  { {0x7981001f,0xe29f0026,0x9f400014,0x00000000}},	//   _welw, kuð_, okið_,
  { {0x6d480025,0xe29f0014,0xa3e50042,0x00000000}},	//   _údar, juð_, नान_,
  { {0x388c0080,0xe29f0026,0x9f400014,0x00000000}},	//   běr_, duð_, ikið_,
  { {0x2d8300c3,0xb7bd003b,0xd6a8005d,0x00000000}},	//   _meje_, enţe, ودیم_,
  { {0xe29f0026,0x2d832abe,0x9f400014,0x00000000}},	//   fuð_, _leje_, kkið_,
  { {0x72c30088,0x7c3a0164,0x65c5000d,0x00000000}},	//   абяз, _être, _абла,
  { {0x7a360003,0x72c30002,0xdb082abf,0x00000000}},	//   lâtr, јбрз, élér,
  { {0xb7bd003b,0x9f400014,0x32010066,0x00000000}},	//   anţe, ekið_, _dlhy_,
  { {0x601b024a,0xe4c80021,0x7a36006c,0x00000000}},	//   vämä, _أبون_, nâtr,
  { {0x225a00c2,0x3f8204d9,0xdcfc0078,0x00000000}},	// [45c0] _tipk_, _veku_, _verč,
  { {0x601b024a,0x7a36006c,0x25f70042,0x00000000}},	//   tämä, hâtr, एसटी_,
  { {0x60260088,0x3f8208ea,0x2d832ac0,0x00000000}},	//   _адна, _teku_, _deje_,
  { {0x67fc0003,0x388c004c,0x44222ac1,0x00000000}},	//   _réjo, věr_, nnk_,
  { {0x67fc0164,0x09e60454,0x20020058,0x00000000}},	//   _séjo, кодн, _ilki_,
  { {0xc33301f9,0x67f500ea,0x5a3301dd,0x00000000}},	//   בוד_, _máju, аніт,
  { {0x3ea02ac2,0xfce32ac3,0xa3e50053,0x00000000}},	//   luit_, _коро, नाम_,
  { {0x8c462ac4,0x2fc02ac5,0x7794005d,0x00000000}},	//   _ребе, neig_, ایشا,
  { {0xf6e3000d,0x3ea02ac6,0x96340794,0x00000000}},	//   ацэн, nuit_, лниц,
  { {0xe29f0026,0x7ae4004b,0x44222ac7,0x00000000}},	//   vuð_, äitu, enk_,
  { {0x7c222ac8,0xddcd003b,0x15141862,0x00000000}},	//   onor, lpaţ, удня,
  { {0xe29f0026,0xd7ef0021,0x2a641013,0x00000000}},	//   tuð_, _وكل_, _kumb_,
  { {0xa2d00053,0x7c222ac9,0x51872aca,0x00000000}},	//   दिष्, inor, кува,
  { {0x3ea02acb,0xe29f0014,0x5224000d,0x00000000}},	//   duit_, ruð_, афса,
  { {0xc05b0086,0xd7f8003b,0x22580121,0x00000000}},	//   діа_, _luăm_, тиры_,
  { {0x23aa0235,0xf047000d,0xe29f0026,0x00000000}},	//   _कायद, тэго, puð_,
  { {0x3ea02acc,0x5314007e,0x4ea7005a,0x00000000}},	// [45d0] guit_, _پذير, ърва,
  { {0x7c220185,0x9f400026,0x925b0044,0x00000000}},	//   enor, rkið_, _تشعر_,
  { {0x7af600d1,0x2d832acd,0x7c220014,0x00000000}},	//   øytn, _veje_, fnor,
  { {0x200c0994,0x3ea0000c,0x7c222ace,0x00000000}},	//   èdit_, buit_, gnor,
  { {0xee8408a6,0x60030019,0x3ea013cb,0x00000000}},	//   _высо, _tõmb, cuit_,
  { {0x27ef18ec,0x7c222acf,0x26d9102d,0x00000000}},	//   _sogn_, anor, åsom_,
  { {0x628000ea,0x20020150,0x89d60021,0x00000000}},	//   ámoz, _ylki_, طوير_,
  { {0x6d4701b3,0xf7710021,0x657a004d,0x00000000}},	//   _izja, حاث_, ebth,
  { {0x2a6401a6,0xdcfc008f,0x27ef05e7,0x00000000}},	//   _gumb_, _ierā, _vogn_,
  { {0xdb09017d,0x67f500ea,0x7a36006c,0x00000000}},	//   _abeç, _ráju, sâtr,
  { {0x3ea0000c,0x98750002,0x7a36006c,0x00000000}},	//   zuit_, _слец, pâtr,
  { {0x987a0047,0x3c3c0066,0xe29a2ad0,0x00000000}},	//   _נאנט, tívi_, нам_,
  { {0x8bd6009a,0xeab5009a,0x00000000,0x00000000}},	//   אורו_, נִ֨י_,   ,
  { {0xfb1600b7,0x471a0047,0x3ea00059,0x00000000}},	//   אַלט_, _אונג, vuit_,
  { {0x44220089,0x7c22002b,0x2fc02ad1,0x00000000}},	//   pnk_, ynor, teig_,
  { {0xdcfc001c,0xd9c00053,0x3ea02ad2,0x00000000}},	//   _nerā, _एस्ट, tuit_,
  { {0xdee30794,0xe8890013,0x32180b3c,0x00000000}},	// [45e0] боти, hẻ_, piry_,
  { {0x3ea02ad3,0xfce60d34,0x2a6401a8,0x00000000}},	//   ruit_, лозо, _rumb_,
  { {0x645e2abf,0xd5fa0047,0x660f0066,0x00000000}},	//   _épit, עפער, écky,
  { {0x7e7600ac,0xdde3008f,0xf5360047,0x00000000}},	//   ppyp, āršo, אטער_,
  { {0xa3e50053,0x3ea02ad4,0x752f0022,0x00000000}},	//   नात_, quit_, ęczy,
  { {0x7c222ad5,0xddcd003b,0xfa880013,0x00000000}},	//   snor, rpaţ, rừ_,
  { {0x67f50024,0xb21b2ad6,0x6e2b00ea,0x00000000}},	//   _nájs, msæt, égbe,
  { {0xa3d30161,0xb21b0146,0xf8030085,0x00000000}},	//   _हों_, lsæt, йчын,
  { {0x7bc22ad7,0xdce70078,0x69962ad8,0x00000000}},	//   meou, _bejė, _брех,
  { {0x88c60021,0xb21b00b9,0x44b40af0,0x00000000}},	//   _متصل, nsæt, абос,
  { {0xce370063,0xd5b7066e,0x8e370041,0x00000000}},	//   ראית_, усы_, רניא_,
  { {0x7bc20034,0x6355183f,0xd4970121,0x00000000}},	//   neou, ивну, ырь_,
  { {0xb21b0146,0xa837069a,0xa3d60042,0x00000000}},	//   ksæt, _גראד_, _सफर_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xb21b010a,0xe450007e,0x7bc217e4,0x00000000}},	//   dsæt, تضی_, keou,
  { {0x12e70086,0x661a216c,0xa2c50053,0x00000000}},	//   _біог, litk, िबद्,
  { {0x1de00053,0xdd9b0794,0x66d300ea,0x00000000}},	// [45f0] नांत, еше_, műkö,
  { {0x2733001b,0x2721001b,0xb7bd000c,0x00000000}},	//   ợng_, ẳng_, inţa,
  { {0x644d0228,0x645f0164,0x628f0025,0x00000000}},	//   _khai, _épis, lsco,
  { {0x7bc200e5,0x628f2ad9,0x907a0aeb,0x00000000}},	//   geou, osco, _שטרי,
  { {0x644d0027,0x661a0397,0xe9ce2ada,0x00000000}},	//   _mhai, kitk, ок_,
  { {0xe9d80088,0x628f2adb,0x7de70054,0x00000000}},	//   лкі_, isco, _сімд,
  { {0xa3d60053,0xb7bd003b,0x661a2adc,0x00000000}},	//   _सफल_, enţa, ditk,
  { {0x66030024,0xe8890013,0x7bc200e5,0x00000000}},	//   _slnk, rẻ_, ceou,
  { {0x628f0051,0x8a940021,0x6f0d2add,0x00000000}},	//   jsco, _هؤلا, nzac,
  { {0x44290551,0x7af600fe,0x628f006f,0x00000000}},	//   _aja_, äyte, dsco,
  { {0x644d0027,0x7c292ade,0x69c32adf,0x00000000}},	//   _bhai, _kjer, mene,
  { {0x6b8b2ae0,0x644d057a,0x69c32ae1,0x00000000}},	//   nagg, _chai, lene,
  { {0x7c29017f,0x661a2ae2,0x7c3b0035,0x00000000}},	//   _mjer, bitk, _mkur,
  { {0x412a1b79,0x44292ae3,0x661a0451,0x00000000}},	//   вого_, _eja_, citk,
  { {0x644d0025,0x628f2ae4,0x6f0d003b,0x00000000}},	//   _fhai, asco, ezac,
  { {0xc0030dd5,0x644d2ae5,0x27ed2ae6,0x00000000}},	//   опск, _ghai, njen_,
  { {0xd00f0032,0xb21b00b9,0x6b8b203d,0x00000000}},	// [4600] ذلك_, tsæt, dagg,
  { {0xdcfc000c,0x20090089,0x69c32ae7,0x00000000}},	//   _neră, ahai_, jene,
  { {0x27ed00f3,0xb21b1c23,0x7bc20034,0x00000000}},	//   kjen_, rsæt, teou,
  { {0xb21b0146,0x661a00c3,0x6b8b1bd6,0x00000000}},	//   ssæt, zitk, gagg,
  { {0xb21b00b9,0x62400072,0x6f0d0298,0x00000000}},	//   psæt, töoh, czac,
  { {0x7c292ae8,0xc9a70001,0x69c32ae9,0x00000000}},	//   _ejer, авље_, gene,
  { {0x7c2902ab,0xa96700d7,0x661a007c,0x00000000}},	//   _fjer, шија_, vitk,
  { {0x7c291609,0x27ed2aea,0xd6da2aeb,0x00000000}},	//   _gjer, gjen_, вто_,
  { {0x644d0185,0x69c32aec,0x66d2005b,0x00000000}},	//   _rhai, bene, dıkç,
  { {0xe8390080,0xceb30063,0x644d2aed,0x00000000}},	//   ější, קית_, _shai,
  { {0x2dd900b7,0x644d09fd,0x35db0053,0x00000000}},	//   אַרב, _phai, बाज़,
  { {0x628f09fe,0x661a00fe,0x78fb0047,0x00000000}},	//   tsco, sitk, _שלאפ,
  { {0x628f051e,0xd7ef0021,0x2fd2001f,0x00000000}},	//   usco, _تكن_, ddyg_,
  { {0x628f2aee,0x54660001,0x79882aef,0x00000000}},	//   rsco, _књиз, _jedw,
  { {0x04940032,0x46390047,0x56390047,0x00000000}},	//   _البح, _געװע, _געװײ,
  { {0x6f0d0994,0x628f2af0,0x853c0078,0x00000000}},	//   tzac, psco, ngėm,
  { {0x60d300eb,0x6b8b2af1,0x645f0003,0x00000000}},	// [4610] _žemė, vagg, _épiq,
  { {0xa3e50161,0x7c2900f5,0xdb0b0051,0x00000000}},	//   नाव_, _sjer, zegó,
  { {0x27ed024a,0x201e0268,0x44392af2,0x00000000}},	//   yjen_, ètic_, oos_,
  { {0x44391c43,0x69c32af3,0x2d870022,0x00000000}},	//   nos_, wene, źne_,
  { {0x7c290117,0x6b8b033f,0xe7e50053,0x00000000}},	//   _vjer, ragg, कासा_,
  { {0x6b8b02f6,0x89a8019d,0x6240024a,0x00000000}},	//   sagg, иків_, töoi,
  { {0x27ff007a,0x49980086,0x27ed0150,0x00000000}},	//   tkun_, ртія_, tjen_,
  { {0x7c3b10ca,0x44392af4,0x7c290035,0x00000000}},	//   _ukur, jos_, _ujer,
  { {0xa9c7011c,0x44392af5,0x27ed2af6,0x00000000}},	//   _всек, dos_, rjen_,
  { {0x27ed0821,0x27ff2af7,0x3eda0047,0x00000000}},	//   sjen_, skun_, אַטא,
  { {0x6b890019,0x27ed000f,0xddc60006,0x00000000}},	//   _keeg, pjen_, _sukū,
  { {0x44392af8,0x3eb20072,0xb8dd0053,0x00000000}},	//   gos_, ytyt_, ेब_,
  { {0x6b89016d,0xdb0f0003,0x16350121,0x00000000}},	//   _meeg, édèr, _ледя,
  { {0x6b892af9,0x3dd10051,0x853c0078,0x00000000}},	//   _leeg, _nazw_, igėj,
  { {0x44392afa,0x20000072,0xe29f0014,0x00000000}},	//   bos_, tkii_, arð_,
  { {0x44390fca,0x6e3c08ea,0xb4fa0063,0x00000000}},	//   cos_, _skrb, _תפקי,
  { {0x62920024,0x20000072,0xd5b1008d,0x00000000}},	// [4620] ýkoľ, rkii_, hím_,
  { {0xbd8a006a,0xe058005d,0x6da60044,0x00000000}},	//   انان_, _چیست_, إمام,
  { {0xe058006a,0x3eb200fe,0xf8a5007e,0x00000000}},	//   _نیست_, styt_, _تک_,
  { {0x44d70529,0x248301d1,0xb81c01ce,0x00000000}},	//   _mă_, ájmy_, _плyм,
  { {0xa91c0024,0x7988001f,0x6b8900f5,0x00000000}},	//   _veľm, _pedw, _deeg,
  { {0x44392afb,0x2b98008b,0x3f800078,0x00000000}},	//   zos_, ức_, lbiu_,
  { {0x44392afc,0xdca32377,0x44d70013,0x00000000}},	//   yos_, _нари, _nă_,
  { {0xc7c60b3f,0x44392afd,0xe69805bd,0x00000000}},	//   сски, xos_, авиш_,
  { {0x44392afe,0x3f8012a1,0xa3ac0042,0x00000000}},	//   vos_, ibiu_, खलन_,
  { {0x6b89006f,0x63ad0890,0xad760085,0x00000000}},	//   _zeeg, _scan, авiц,
  { {0x44d70469,0xd7ef0dd5,0x443903e1,0x00000000}},	//   _că_, _еу_, tos_,
  { {0x44d7000c,0x44390006,0x2d9800d1,0x00000000}},	//   _dă_, uos_, _ldre_,
  { {0x44392afe,0x6594000d,0xa2d00053,0x00000000}},	//   ros_, _далу, दिग्,
  { {0x55580088,0xdb0f2986,0x2d9c017d,0x00000000}},	//   _каля_, édér, óvel_,
  { {0xb5b70063,0x61fa00c7,0x60250006,0x00000000}},	//   _הלוח_, ötla, lėmi,
  { {0x40350088,0x3ea02aff,0x98a90051,0x00000000}},	//   цебс, frit_, łać_,
  { {0x6b890019,0xf41f00fe,0xbe190086,0x00000000}},	// [4630] _reeg, miä_, ажає_,
  { {0x6b890004,0xf41f024a,0xf2d40047,0x00000000}},	//   _seeg, liä_, _זעץ_,
  { {0x2d8a2b00,0x6b890019,0x8d74014d,0x00000000}},	//   _debe_, _peeg, سالا,
  { {0xab940086,0xf41f00fe,0x60250078,0x00000000}},	//   зиці, niä_, kėmi,
  { {0x7867000f,0x3ea02b01,0xdefb014c,0x00000000}},	//   _műve, crit_, _сын_,
  { {0x600a0066,0x60250078,0xf41f0072,0x00000000}},	//   _výme, dėmi, hiä_,
  { {0xf41f024a,0xe7e50053,0x6b892b02,0x00000000}},	//   kiä_, काला_, _teeg,
  { {0xdd0e005b,0xf41f00fe,0x44d7003b,0x00000000}},	//   lışa, jiä_, _ră_,
  { {0x44d70469,0x2d9800b9,0x6003004b,0x00000000}},	//   _să_, _ydre_, _nõmm,
  { {0xdd0e0058,0xe61904f2,0xe9db0044,0x00000000}},	//   nışa, рдо_, _حذرت_,
  { {0xd7c8006a,0xf773007e,0xf5050054,0x00000000}},	//   _گونه_, _فاش_, ізмо,
  { {0x44d70469,0x60250006,0xb8860014,0x00000000}},	//   _vă_, bėmi, smíð,
  { {0x42ba000d,0x26c9007e,0xdd0e0058,0x00000000}},	//   шыню_, _خطای_, kışa,
  { {0x200c001c,0x3ea02b03,0x7af604aa,0x00000000}},	//   īdim_, vrit_, øyti,
  { {0xdb20013d,0xf41f0050,0xe3b20044,0x00000000}},	//   _ötöd, biä_, _قرة_,
  { {0x1dac0053,0x3ea02b04,0xe7ec0053,0x00000000}},	//   _चाहत, trit_, झाया_,
  { {0xd0070189,0x3f8b007d,0x3f800078,0x00000000}},	// [4640] цете_, _decu_, rbiu_,
  { {0x64460019,0x3ea0000b,0x31a60044,0x00000000}},	//   llki, rrit_, _بمدف,
  { {0xa91c0024,0x2465001c,0x60250078,0x00000000}},	//   _veľk, _tēmu_, zėmi,
  { {0x3ea003b2,0x2d8a0024,0xdee62b05,0x00000000}},	//   prit_, _webe_, _доми,
  { {0x2d8a1b9d,0xb4c60042,0xf413009a,0x00000000}},	//   _tebe_, _उन्_, ופא_,
  { {0x317a0047,0x20230051,0xddd5001c,0x00000000}},	//   באַד, ąpił_, _aizņ,
  { {0xf1b20053,0x26d901e1,0x8b9611db,0x00000000}},	//   _जानन, æson_, _мрач,
  { {0x6d4e20d2,0x60250006,0x9f490014,0x00000000}},	//   _izba, tėmi, okað_,
  { {0xf41f00fe,0x3b07005a,0x6b822b06,0x00000000}},	//   viä_, _дето_, mbog,
  { {0xc5fa000a,0x60250078,0xf426004b,0x00000000}},	//   рѓи_, rėmi, ääne_,
  { {0xf41f024a,0x60250078,0x64742049,0x00000000}},	//   tiä_, sėmi, ягну,
  { {0x9f490026,0x60250006,0x6b822b07,0x00000000}},	//   kkað_, pėmi, nbog,
  { {0x93470032,0xf41f00fe,0xc34b0905,0x00000000}},	//   تخدم, riä_, ряне_,
  { {0xf41f024a,0x4425013d,0x64462b08,0x00000000}},	//   siä_, ől_, alki,
  { {0xf41f00fe,0x6b8200b9,0x6aa22b09,0x00000000}},	//   piä_, kbog, hrof,
  { {0x7a3f0164,0x60030019,0x753c004d,0x00000000}},	//   nêtr, _tõmm, ürzu,
  { {0x8556006a,0xd167005a,0x6b821c1d,0x00000000}},	// [4650] _دیگر_, _мъни, dbog,
  { {0xddcf004c,0x2b4d0022,0x6aa22b0a,0x00000000}},	//   řeže, _rzec_, drof,
  { {0x442b0164,0xdd0e0058,0x671f0041,0x00000000}},	//   onc_, rışa, _גאַנצ,
  { {0x645800cd,0x27e60290,0x6b8200b9,0x00000000}},	//   _èxit, _nnon_, gbog,
  { {0xb7bd003b,0x7f7600ff,0x442b2b0b,0x00000000}},	//   niţe, _מערב_, inc_,
  { {0x3ea900f3,0xdcee0006,0x245201c2,0x00000000}},	//   muat_, _nebė, máme_,
  { {0x3ea92b0c,0xb7bd003b,0x24520114,0x00000000}},	//   luat_, hiţe, láme_,
  { {0x97c50032,0x08d4000d,0xf813007e,0x00000000}},	//   ستعم, ьція, بستگ,
  { {0x6b9b00a4,0xdb2500fe,0xa3e50053,0x00000000}},	//   _idug, öpäi, नाई_,
  { {0x9732007e,0x386c00a3,0x656f011b,0x00000000}},	//   رکنا, _fudr_, ěcho,
  { {0x2452004c,0x04462049,0x7c2b2b0d,0x00000000}},	//   háme_, зенн, ongr,
  { {0x38970529,0x7a3f0003,0x644600fe,0x00000000}},	//   măr_, cêtr, ulki,
  { {0xe72e0017,0x7c2b2b0e,0x66e50571,0x00000000}},	//   _че_, ingr, _хола,
  { {0xbb3a0047,0x3ea900cd,0xeb3a0047,0x00000000}},	//   מערי, duat_, מערש,
  { {0x3897003b,0x753c004d,0xaf9a142a,0x00000000}},	//   năr_, ürzt, йтах_,
  { {0x6b9b0035,0x2fc900ac,0x24520080,0x00000000}},	//   _ndug, geag_, fáme_,
  { {0xdfcf0032,0x3897003b,0xbe66005d,0x00000000}},	// [4660] ديق_, hăr_, سهاي,
  { {0x273a001b,0x9f490026,0xdb09017d,0x00000000}},	//   ừng_, rkað_, _oceâ,
  { {0x50462b0f,0x01fb0063,0x9f490014,0x00000000}},	//   _необ, _הפיל, skað_,
  { {0x3ea90974,0x5bb80086,0x6aa22b10,0x00000000}},	//   buat_, ілля_, trof,
  { {0x3f920150,0x4422004b,0x6b822b11,0x00000000}},	//   mayu_, iik_, rbog,
  { {0x3f9200e3,0x6b821c1d,0x6aa200cd,0x00000000}},	//   layu_, sbog, rrof,
  { {0x5886000d,0x3897003b,0x44222b12,0x00000000}},	//   чыла, găr_, kik_,
  { {0x6aa22b13,0x4c9b0063,0x44222b14,0x00000000}},	//   prof, _לבלו, jik_,
  { {0xfaa32b15,0x78a30137,0x7a3f0003,0x00000000}},	//   _пато, arnv, rêtr,
  { {0x44980086,0x6e3e00b9,0x7c222b16,0x00000000}},	//   овою_, nopb, lior,
  { {0x44222b17,0x3f920150,0x24590603,0x00000000}},	//   fik_, kayu_, жань_,
  { {0x44222b18,0x69ca2b19,0xb7bd003b,0x00000000}},	//   gik_, lefe, tiţe,
  { {0xa3be0053,0x51870002,0x69ca0229,0x00000000}},	//   ीज़_, зуба, oefe,
  { {0x24520080,0x4422003e,0x69ca2b1a,0x00000000}},	//   váme_, aik_, nefe,
  { {0x7c2b0185,0x69ca004d,0x644f006f,0x00000000}},	//   yngr, iefe, ïbis,
  { {0x3ea911fb,0x24520080,0x987b0047,0x00000000}},	//   tuat_, táme_, מאלט,
  { {0xdb1b0026,0x2fc90025,0x69ca2b1b,0x00000000}},	// [4670] _nauð, reag_, kefe,
  { {0xdb070003,0x69ca04c8,0x92b40021,0x00000000}},	//   _élég, jefe, _أحيا,
  { {0x69ca2b1c,0x7c222b1d,0x7ae00139,0x00000000}},	//   defe, fior, _armt,
  { {0x7c2202f6,0x3897000c,0x38660139,0x00000000}},	//   gior, văr_, _nior_,
  { {0xf42a024a,0x3ea90268,0x69d8006f,0x00000000}},	//   ltää_, quat_, fdve,
  { {0x44222b1e,0x7c222b1f,0x69ca2b20,0x00000000}},	//   zik_, aior, gefe,
  { {0xf42a00fe,0x7c220051,0x38660139,0x00000000}},	//   ntää_, bior, _bior_,
  { {0x63bd0122,0x8699000a,0xb7bd000c,0x00000000}},	//   jfsn, отот_, onţi,
  { {0x69ca004d,0xf42a0072,0x7bcb2b21,0x00000000}},	//   befe, htää_, megu,
  { {0x49bb006a,0xb7bd000c,0x7bcb13f3,0x00000000}},	//   _دارد_, inţi, legu,
  { {0x3866235d,0xd5b8001c,0x44222b22,0x00000000}},	//   _fior_, enās_, tik_,
  { {0x7bcb2b23,0xc2090063,0x76480006,0x00000000}},	//   negu, _דה_, aldy,
  { {0x2480017f,0x44222b24,0x15f50021,0x00000000}},	//   _čime_, rik_, _يستح,
  { {0x35fb006a,0x7c220051,0x44222b25,0x00000000}},	//   _درصد_, zior, sik_,
  { {0xb7bd0529,0x21672b26,0x7e7d2b27,0x00000000}},	//   enţi, дири_, _atsp,
  { {0xd4360021,0xdb0901a8,0xdee605ef,0x00000000}},	//   _تعتب, _oceà, моби,
  { {0x3f920089,0x7bcb2b28,0x6e3e0717,0x00000000}},	// [4680] rayu_, degu, topb,
  { {0x9f590290,0xdb1b0026,0x44200509,0x00000000}},	//   _mosè_, _rauð, _hmi_,
  { {0x69ca01f2,0x442007b7,0x7c222b29,0x00000000}},	//   vefe, _kmi_, tior,
  { {0xf767043b,0x69c100bd,0x6e3e0104,0x00000000}},	//   _لا_, _able, sopb,
  { {0x7c222358,0x99870006,0xbd8a0021,0x00000000}},	//   rior, jonų_, _ونحن_,
  { {0xe607007e,0x99870006,0x7c222b2a,0x00000000}},	//   _شش_, donų_, sior,
  { {0x38660016,0x853c0006,0x7c221ca6,0x00000000}},	//   _pior_, ngėt, pior,
  { {0xd7f00032,0x7e67006f,0x99870006,0x00000000}},	//   اكة_, _zijp, fonų_,
  { {0x8b260088,0x99870078,0x00000000,0x00000000}},	//   _ўдзе, gonų_,   ,
  { {0xf42a00fe,0x4420236e,0xbafb0063,0x00000000}},	//   ytää_, _ami_, _והמש,
  { {0x3dd8001f,0xd7f10013,0x980a00de,0x00000000}},	//   _marw_, _lũy_, _وتصف_,
  { {0x69c10a1e,0x47d4009b,0x00000000,0x00000000}},	//   _zble, _سيتر,   ,
  { {0x236d00c3,0x27f70240,0x60c50089,0x00000000}},	//   žejo_, žená_, _sphm,
  { {0xf42a024a,0x34942b2b,0x44202b2c,0x00000000}},	//   ttää_, _закр, _emi_,
  { {0x7e67006f,0xd258000d,0x44202b2d,0x00000000}},	//   _rijp, ьцю_, _fmi_,
  { {0xf42a00fe,0x44200089,0xe3f80021,0x00000000}},	//   rtää_, _gmi_, _يعيش_,
  { {0xf42a024a,0x7e67006f,0xcddb0001,0x00000000}},	// [4690] stää_, _pijp, жње_,
  { {0x7bcb00bd,0x9f592b2e,0x3dd800a3,0x00000000}},	//   wegu, _josé_, _carw_,
  { {0x7bcb2b2f,0xb7bd003b,0x9973004c,0x00000000}},	//   tegu, hiţa, těži_,
  { {0x6d47027d,0xdb510021,0x515a0063,0x00000000}},	//   _vyja, هَا_, _מכתו,
  { {0x3dd8001f,0x6f160051,0x6d470051,0x00000000}},	//   _farw_, czyc, _wyja,
  { {0x7bcb2b30,0x3dd8001f,0x20090078,0x00000000}},	//   segu, _garw_, lkai_,
  { {0xda620121,0x7af604aa,0xd9420131,0x00000000}},	//   ывши, øytr, леши,
  { {0x2009143b,0x3ea60006,0x99870078,0x00000000}},	//   nkai_, šote_, tonų_,
  { {0x2009001c,0x2d91013d,0x5a352b31,0x00000000}},	//   ikai_, _keze_, _знат,
  { {0xe6160076,0x78ae0025,0x99870078,0x00000000}},	//   едь_, óivé, ronų_,
  { {0xdddd001c,0x44202b32,0x13a8007e,0x00000000}},	//   _atsū, _pmi_, وندی_,
  { {0xafdb0146,0x246c0080,0x99870006,0x00000000}},	//   _skøn, _němu_, ponų_,
  { {0xe29703e6,0x8c1a0063,0xa802005b,0x00000000}},	//   ная_, פושי, ğıtm,
  { {0xd252006a,0xddcd0078,0xb1462b33,0x00000000}},	//   انس_, epaž, енгл,
  { {0x2fd9002b,0x76411d24,0x2056224c,0x00000000}},	//   _basg_, moly, етар,
  { {0x68e50072,0x76410137,0x251a0063,0x00000000}},	//   ähdy, loly, _מוצא,
  { {0xddc600eb,0xee0a0002,0x0eaa000d,0x00000000}},	// [46a0] _aukš, пеал_, якай_,
  { {0x6e460242,0x6f160051,0x8d85007e,0x00000000}},	//   رنام, rzyc, نشمن,
  { {0x2d910b7d,0x6f160045,0xb0af0042,0x00000000}},	//   _deze_, szyc, जूदग,
  { {0x601100d1,0xdca30002,0x207b0047,0x00000000}},	//   _påme, ѓачи, _מאטא,
  { {0xd12f006a,0xdb830062,0x3dd8002b,0x00000000}},	//   _نمی_, угчи, _tarw_,
  { {0x61fe2b34,0x4a530054,0x00000000,0x00000000}},	//   _jopl, гкіс,   ,
  { {0x7641001f,0x245200ea,0x645d0046,0x00000000}},	//   doly, záma_, ymsi,
  { {0x2fc02b35,0x7d120058,0xd6d00044,0x00000000}},	//   nfig_, ıksı, لقب_,
  { {0x87e30055,0x27fd2b36,0x9f590003,0x00000000}},	//   ующе, _down_, _posé_,
  { {0x7641001f,0x4b550062,0x5a9b009a,0x00000000}},	//   goly, _ръст, _משמא,
  { {0x5455065b,0xe4e3000d,0x3e760014,0x00000000}},	//   квот, гіян, _læt_,
  { {0x89370063,0x27fd00e5,0x69da2b37,0x00000000}},	//   _ארבע_, _gown_, _hate,
  { {0x69da2b38,0x8c1b0063,0x41c7000d,0x00000000}},	//   _kate, לוטי, нёва,
  { {0x38ba00ac,0x69da2b39,0x24522b3a,0x00000000}},	//   oër_, _jate, ráma_,
  { {0x2fc0001f,0xddcd0006,0x2fd9001f,0x00000000}},	//   ffig_, tpaž, _pasg_,
  { {0x628d0035,0x69da0112,0x20092b3b,0x00000000}},	//   _twao, _late, ukai_,
  { {0x40340055,0xf207000d,0x6e25005b,0x00000000}},	// [46b0] уетс, _зяно, tihb,
  { {0x2fd9001f,0xe45f25ac,0x20092401,0x00000000}},	//   _wasg_, lmö_, skai_,
  { {0x2d91017f,0xddd0000c,0x463b0047,0x00000000}},	//   _veze_, şeşt, לעמע,
  { {0x69da0656,0xeab10044,0x853b009a,0x00000000}},	//   _aate, لعت_, הגבי,
  { {0x38ba00e8,0x3f892b3c,0x27fd002b,0x00000000}},	//   eër_, mbau_, _rown_,
  { {0xddc6001c,0x69da2b3d,0x3ea92b3e,0x00000000}},	//   _tukš, _cate, mrat_,
  { {0x76410137,0x69da2b3f,0x61fa0137,0x00000000}},	//   voly, _date, ötli,
  { {0x69da0034,0x3f8900bd,0x6d552b40,0x00000000}},	//   _eate, nbau_, _izza,
  { {0x41b20053,0x69da2b41,0x06550085,0x00000000}},	//   _जालस, _fate, ктоў,
  { {0xe475000d,0x69da2b42,0x49d90054,0x00000000}},	//   кумэ, _gate, _ідею_,
  { {0x27fd0037,0x3ea9266a,0xa8020058,0x00000000}},	//   _town_, hrat_, ğırm,
  { {0x3ea92b43,0x657a0025,0x69da2b44,0x00000000}},	//   krat_, acth, _zate,
  { {0x7bdb00a4,0x61fe041a,0x13a8007e,0x00000000}},	//   _mauu, _popl, ونگی_,
  { {0xb21b00b9,0x3ea92b45,0x7af60050,0x00000000}},	//   spæn, drat_, äyti,
  { {0x3e760146,0x3f8900bd,0x3ea92b46,0x00000000}},	//   _sæt_, fbau_, erat_,
  { {0x7bdb002c,0x93c3003b,0x3ea92b47,0x00000000}},	//   _nauu, şări, frat_,
  { {0x3ea92b48,0x61fe26f6,0x6d551873,0x00000000}},	// [46c0] grat_, _topl, _azza,
  { {0x9f5900ea,0xee370193,0x60db0022,0x00000000}},	//   _alsó_, вну_, łuma,
  { {0x69da0708,0x225a0150,0x3f89004d,0x00000000}},	//   _rate, _ihpk_, bbau_,
  { {0x3e760146,0x3ea901da,0x69da2b49,0x00000000}},	//   _tæt_, brat_, _sate,
  { {0x3ea92b4a,0x69da2b4b,0x29070014,0x00000000}},	//   crat_, _pate, eyna_,
  { {0x1958026c,0xf2d3009a,0x0136009d,0x00000000}},	//   налы_, יעד_, ֣רֶת_,
  { {0x69da00bd,0xc2130063,0x692301ce,0x00000000}},	//   _vate, שהו_, имља,
  { {0x7d0300c7,0xf0930063,0xa967005e,0x00000000}},	//   änse, בנה_, њића_,
  { {0x15aa0062,0x69da1417,0xbb460861,0x00000000}},	//   мъни_, _tate, _реак,
  { {0x7bc2191d,0x35f41006,0x00000000,0x00000000}},	//   lfou, упор,   ,
  { {0x26180161,0x29182b4c,0x29070051,0x00000000}},	//   योगी_, _åra_, cyna_,
  { {0x657a0027,0x3c3c0024,0x4c9b0047,0x00000000}},	//   scth, tívy_, ושטע,
  { {0x9f5902f6,0x6d58004a,0x7ae20014,0x00000000}},	//   _così_, ývaj, nvot,
  { {0x6594019b,0x3ea92b4d,0x7ae22b4e,0x00000000}},	//   _саку, vrat_, ivot,
  { {0xa1942b4f,0xf1940054,0x35a301ce,0x00000000}},	//   расч, рись, _тајг,
  { {0x7ae214a3,0x3ea92b50,0xed59005f,0x00000000}},	//   kvot, trat_, _ąž_,
  { {0x9f552b51,0x3f89049d,0x3ea90e4f,0x00000000}},	// [46d0] увач, rbau_, urat_,
  { {0x7bc2006f,0x3f89004d,0x3ea92b52,0x00000000}},	//   efou, sbau_, rrat_,
  { {0x3ea92b53,0x7bdb00a4,0x629d2b54,0x00000000}},	//   srat_, _pauu, lsso,
  { {0x3ea90813,0x629d2b55,0xab5d0022,0x00000000}},	//   prat_, osso, _zaży,
  { {0x625200b9,0x41c00053,0x629d2b56,0x00000000}},	//   kæol, श्वस, nsso,
  { {0x201e001c,0x2b910013,0x79a7005e,0x00000000}},	//   ītie_, ạc_, трде,
  { {0x9f400014,0xac190074,0x7ae20078,0x00000000}},	//   ljið_, _зову_, avot,
  { {0xafdb01e1,0x29070022,0x629d2b57,0x00000000}},	//   _skøj, ryna_, ksso,
  { {0x98be005f,0x29070022,0xf99301f3,0x00000000}},	//   _rytą_, syna_, _نبض_,
  { {0x629d2b58,0xba550021,0x320101d1,0x00000000}},	//   dsso, _صناع, _nohy_,
  { {0x629d2b59,0xdb0000cd,0x49470085,0x00000000}},	//   esso, _admè, _рэаб,
  { {0x629d2b5a,0x00000000,0x00000000,0x00000000}},	//   fsso,   ,   ,
  { {0x6286033b,0x8c1a0063,0xb6a50121,0x00000000}},	//   upko, תורי, _силл,
  { {0x9f5900cd,0x4256007e,0x644f2b5b,0x00000000}},	//   _cosí_, انسر, alci,
  { {0x8fa60088,0xf652014e,0x629d2b5c,0x00000000}},	//   лаве, _הצג_, asso,
  { {0xab5d0022,0x62862b5d,0x7f1a014b,0x00000000}},	//   _waży, ppko, нізу_,
  { {0x63a4002c,0x8236007e,0x543b0047,0x00000000}},	// [46e0] _idin, _مردا, _רעפא,
  { {0x64462b5e,0x62840331,0xa37b00be,0x00000000}},	//   loki, _itio, rdõe,
  { {0xeafa007e,0x61fa004b,0xed5a0121,0x00000000}},	//   کرات_, ötlu, хож_,
  { {0x644600eb,0xdb190051,0x0ecf0053,0x00000000}},	//   noki, jewó, _सैकड,
  { {0x7bc200a1,0x69c307eb,0x7ae20050,0x00000000}},	//   rfou, ffne, uvot,
  { {0x7bc2006f,0x20020089,0xcebf0080,0x00000000}},	//   sfou, _hoki_, ěřte_,
  { {0x7bc20186,0x64462b5f,0x7ae20014,0x00000000}},	//   pfou, koki, svot,
  { {0xc8c70754,0x62842229,0x8c46226b,0x00000000}},	//   اوين_, _otio, _себе,
  { {0x644600eb,0x09e6130d,0x49ca1dd0,0x00000000}},	//   doki, _йоан, _план_,
  { {0xf4860635,0x20022b60,0x63a42b61,0x00000000}},	//   лумн, _loki_, _adin,
  { {0x88860076,0x6446004b,0xfdf70aeb,0x00000000}},	//   _слеж, foki, אמיש_,
  { {0xe3bf006d,0x64460006,0xe8d70063,0x00000000}},	//   riño_, goki, _תואר_,
  { {0x63a4001f,0xe60f007e,0x2d9a0850,0x00000000}},	//   _ddin, زشی_, kape_,
  { {0xd5760076,0x62840025,0x60180026,0x00000000}},	//   _судь, _dtio, _límd,
  { {0x656f0080,0x64462b62,0x998e0078,0x00000000}},	//   ěcht, boki, lofų_,
  { {0xc2750138,0xaffc000d,0x24830066,0x00000000}},	//   _клиј, носi, íjme_,
  { {0x69c80198,0x442b2b63,0x69c3002b,0x00000000}},	// [46f0] _obde, mic_, yfne,
  { {0x442b2b64,0x629b0006,0xdb190022,0x00000000}},	//   lic_, šuos, zewó,
  { {0xdcf5001c,0x63a400fe,0x5c070304,0x00000000}},	//   _iezī, _ydin, ляда,
  { {0x442b2b65,0x24b70041,0x69c82b66,0x00000000}},	//   nic_, רהאן_, _abde,
  { {0x68e80185,0x3ec40080,0x60180014,0x00000000}},	//   _ardd, ěstí_, _símg,
  { {0xa2ad0053,0x627c0047,0x2d9a0b02,0x00000000}},	//   _जिन्, ענונ, cape_,
  { {0x6ce40086,0x5ce40088,0xab950086,0x00000000}},	//   _літе, _люта, _вибі,
  { {0x442b2b67,0x06c90054,0x00000000,0x00000000}},	//   jic_, вгий_,   ,
  { {0x7af6024a,0x63a40290,0x68e80616,0x00000000}},	//   äytt, _rdin, _erdd,
  { {0x7c2b2b68,0x7ae92b69,0xe5a5005e,0x00000000}},	//   ligr, _iret, јини,
  { {0xa8a40fe2,0x62842b6a,0x64462b6b,0x00000000}},	//   _грчк, _stio, toki,
  { {0xe366131b,0x600a0024,0x04461225,0x00000000}},	//   икни, _tými, ремн,
  { {0x20021efc,0xe356000d,0xe708005d,0x00000000}},	//   _roki_, ртнэ, _متون_,
  { {0x64462b6c,0x7c2b004e,0x471a009d,0x00000000}},	//   soki, higr, _בונג,
  { {0x442b2b6d,0x660300ca,0xdfd201fb,0x00000000}},	//   bic_, _ionk, ييس_,
  { {0x63a42b6e,0x2eed007d,0x7ae9053d,0x00000000}},	//   _udin, _šefa_, _oret,
  { {0x5ea60032,0xa0670afc,0x2d9a2b6f,0x00000000}},	// [4700] شمال, рата_, tape_,
  { {0x6603024a,0x929b0063,0x6da62b70,0x00000000}},	//   _jonk, _שיית, рижа,
  { {0x66032b71,0x8f760086,0x2d9a04d5,0x00000000}},	//   _monk, _вугі, rape_,
  { {0x7d0301e3,0x7ae92b72,0x6d4e0114,0x00000000}},	//   änsa, _bret, _vyba,
  { {0x6018000f,0x24590164,0xeab70121,0x00000000}},	//   _címe, néma_, ийц_,
  { {0x7ae92b73,0x7bc9006f,0xc3330063,0x00000000}},	//   _dret, _ebeu, חוד_,
  { {0x7ae92b74,0x8ccd0053,0xd90f000d,0x00000000}},	//   _eret, _सहयो, ць_,
  { {0x3f800024,0x2d9822a4,0x442b2b75,0x00000000}},	//   nciu_, _here_, xic_,
  { {0x442b2b76,0x2d982b77,0x7ae92b78,0x00000000}},	//   vic_, _kere_, _gret,
  { {0x9a6a0242,0x3ea02b79,0x442b0022,0x00000000}},	//   _شمال_, isit_, wic_,
  { {0x2d982b7a,0x3f800024,0x66032b7b,0x00000000}},	//   _mere_, kciu_, _donk,
  { {0x2d982b7c,0x3ea02b7d,0xe3b000de,0x00000000}},	//   _lere_, ksit_, ورُ_,
  { {0x66032b7e,0x442b2b7f,0xc5f8008f,0x00000000}},	//   _fonk, ric_, lmēm_,
  { {0x2d982b80,0x442b2b81,0x2508007e,0x00000000}},	//   _nere_, sic_, _مربی_,
  { {0x3ea00104,0xe4530067,0xf0270002,0x00000000}},	//   esit_, _وضع_, аќан,
  { {0x34fb0132,0x9f5900cd,0x660300ac,0x00000000}},	//   _יהוד, _posà_, _zonk,
  { {0x78750006,0x44292b82,0xd5b8008f,0x00000000}},	// [4710] _išve, _ima_, ogā_,
  { {0x273300aa,0x2d98000c,0x2ca702dd,0x00000000}},	//   ảng_, _cere_, ándo_,
  { {0x7ae9017f,0x2d982b83,0x7c2b103a,0x00000000}},	//   _sret, _dere_, tigr,
  { {0x7ae92b84,0x2d9800ca,0x547b016e,0x00000000}},	//   _pret, _eere_, דטאו,
  { {0x7c2b2b85,0xf1ec0053,0x3f99002b,0x00000000}},	//   rigr, _छोड़_, _iesu_,
  { {0x2ba7008b,0x2d982b86,0xb7bd003b,0x00000000}},	//   ốc_, _gere_, miţi,
  { {0x44292b87,0xb7bd000c,0x9f4b006d,0x00000000}},	//   _oma_, liţi, _tocó_,
  { {0x2d811302,0x01380132,0x21380063,0x00000000}},	//   lche_, ירות_, יטול_,
  { {0xb7bd000c,0x2d812b88,0x2d982b89,0x00000000}},	//   niţi, oche_, _yere_,
  { {0x44292b8a,0x644d0072,0x2d812b8b,0x00000000}},	//   _ama_, _akai, nche_,
  { {0xae1a014e,0x3f800051,0x66032b8c,0x00000000}},	//   רותכ, yciu_, _vonk,
  { {0x3f990078,0x3ea00072,0x69c700a5,0x00000000}},	//   _nesu_, ysit_, _öjeb,
  { {0xa3b90161,0x9f4000ca,0x24521416,0x00000000}},	//   _चार_, rdië_, námi_,
  { {0xb7bd000c,0xdb0e0003,0x661a0c84,0x00000000}},	//   diţi, édéc, chtk,
  { {0x459a0047,0x2d9800cd,0x7c292b8d,0x00000000}},	//   _עסקע, _rere_, _omer,
  { {0x44291bb8,0x3ea010f0,0x6018073d,0x00000000}},	//   _gma_, tsit_, _símb,
  { {0x7d0300c7,0x2d982b8e,0x3f802b8f,0x00000000}},	// [4720] änsn, _pere_, rciu_,
  { {0x8236006a,0xc3330149,0x2176005e,0x00000000}},	//   _دربا, _מוח_, _ћупр,
  { {0x44290c70,0x2d982b90,0x27ff0014,0x00000000}},	//   _yma_, _vere_, kjun_,
  { {0x2d9803e9,0x6f0d006d,0xb7bd003b,0x00000000}},	//   _were_, byac, biţi,
  { {0x7c3b00c7,0x2d980019,0xcc88007e,0x00000000}},	//   _djur, _tere_, انچه_,
  { {0x2d81051e,0x7c290951,0x527b0047,0x00000000}},	//   cche_, _emer, אנסא,
  { {0x3f9905b3,0x1d070141,0xa3b90042,0x00000000}},	//   _yesu_, _лери_, _चाल_,
  { {0x6c3603eb,0xc7b900ea,0x6d5c2b91,0x00000000}},	//   _افرا, ggő_, _izra,
  { {0x6296002b,0xa3cb0053,0xc5f80023,0x00000000}},	//   _nwyo, र्फ_, smēm_,
  { {0x442900f3,0x7c2900c3,0x644d1867,0x00000000}},	//   _sma_, _zmer, _skai,
  { {0x76480812,0xb7bd0529,0xd5b8001c,0x00000000}},	//   rody, ziţi, rgā_,
  { {0xdd1c0066,0xd7f70062,0x799a00ca,0x00000000}},	//   káža, _гуш_, _hetw,
  { {0xdb000080,0x60de01db,0x44290130,0x00000000}},	//   _odmí, _aspm, _vma_,
  { {0x6d5c2b92,0x7792005d,0xb7bd00dd,0x00000000}},	//   _ozra, _بیکا, viţi,
  { {0x95830045,0x44292b93,0x44f40054,0x00000000}},	//   łącz, _tma_, _єпис,
  { {0x442913a8,0xb7bd000c,0x644d0035,0x00000000}},	//   _uma_, tiţi, _ukai,
  { {0x44392b94,0x2d812b95,0x6d5c1bef,0x00000000}},	// [4730] mns_, tche_, _azra,
  { {0xb7bd000c,0x2d812b96,0x7c292b97,0x00000000}},	//   riţi, uche_, _smer,
  { {0x2d812b98,0x7c290122,0x22640080,0x00000000}},	//   rche_, _pmer, řské_,
  { {0x44392b99,0x2d812b9a,0xafdb00d1,0x00000000}},	//   nns_, sche_, _sjøf,
  { {0x799a0037,0xa3cb0161,0x44392b9b,0x00000000}},	//   _betw, र्य_, ins_,
  { {0xe29c00b5,0x9f40004d,0x44392b9c,0x00000000}},	//   נשור, leiß_, hns_,
  { {0x600a0024,0xf8a9006a,0x98ac0006,0x00000000}},	//   _týmt, شگاه_, _dydį_,
  { {0x6b82051e,0x44391df9,0xa3cb0053,0x00000000}},	//   ccog, jns_, र्म_,
  { {0xd7060076,0x290e005b,0x27ff2b9d,0x00000000}},	//   жные_, ayfa_, rjun_,
  { {0xf625019d,0x44392b9e,0x9f40004d,0x00000000}},	//   ідно, ens_, heiß_,
  { {0xdb1900bd,0x44390026,0xbf9b0003,0x00000000}},	//   gewö, fns_, _poêl,
  { {0x6b9b016d,0x44392b9f,0xe39a005e,0x00000000}},	//   _jeug, gns_, шњој_,
  { {0x35a50085,0x93461cdf,0x00000000,0x00000000}},	//   _далг, інге,   ,
  { {0x44392ba0,0xdcfc0078,0xdd1c0066,0x00000000}},	//   ans_, _gerė, váža,
  { {0x7d0300c7,0x216a2ba1,0x98a9009a,0x00000000}},	//   änsl, риви_, יֹּ֤,
  { {0x6fb60021,0xdddc0058,0x6b9b2ba2,0x00000000}},	//   تمرا, _birş, _neug,
  { {0x3e7f003b,0x6018013d,0x4e062ba3,0x00000000}},	// [4740] _cît_, _címa, озаб,
  { {0x237f0024,0xdd1c0066,0x7e560454,0x00000000}},	//   ľuje_, ráža, ітац,
  { {0x237f114b,0x6b9b1093,0xba2a005d,0x00000000}},	//   žuje_, _beug, یستم_,
  { {0x3e7f0003,0x6aa22ba4,0x27430078,0x00000000}},	//   _fît_, tsof, _kūną_,
  { {0xdddc013d,0x6d5c0022,0x3e7f006c,0x00000000}},	//   őzől, _wzra, _gît_,
  { {0xf1ca0053,0x6b822ba5,0x48aa2ba6,0x00000000}},	//   िभिन, scog, атим_,
  { {0xa3cb0161,0x6d5c001c,0x7d0302ab,0x00000000}},	//   र्ड_, _uzra, ønst,
  { {0x32c40058,0xafdb04aa,0x660101e1,0x00000000}},	//   köy_, _gjød, ejlk,
  { {0x443905b9,0xdcfc0006,0x2d9e006c,0x00000000}},	//   vns_, _perė, _ôtes_,
  { {0x6b9b00bd,0x443904bf,0xd6260021,0x00000000}},	//   _zeug, wns_, تعبي,
  { {0x7d7b014e,0x69d82ba7,0xd7fa0454,0x00000000}},	//   יניו, meve, _вул_,
  { {0xd7ef0032,0x69ca004d,0x69d82494,0x00000000}},	//   _لكم_, lffe, leve,
  { {0x78750006,0xc2b80086,0x69d81031,0x00000000}},	//   _išva, оляє_, oeve,
  { {0x69d80d11,0x69ca2ba8,0x9f40004d,0x00000000}},	//   neve, nffe, weiß_,
  { {0xcf9b2ba9,0x60180026,0xb546007e,0x00000000}},	//   ија_, _síma, _بخشه,
  { {0x69d82baa,0x351b089e,0xcff40062,0x00000000}},	//   heve, _כוונ, мпсъ,
  { {0xa3cb0235,0x69d82bab,0xf3ff017d,0x00000000}},	// [4750] र्ण_, keve, lmão_,
  { {0x2fc904aa,0x69d82b91,0x9df8030b,0x00000000}},	//   sfag_, jeve, онут_,
  { {0x69d82bac,0xa25b0003,0xa3cb0053,0x00000000}},	//   deve, ntôm, र्थ_,
  { {0x60182bad,0x3eb20c4a,0x69ca2bae,0x00000000}},	//   _tíma, bryt_, effe,
  { {0x7ccc001c,0x3ffa0063,0x7c39002b,0x00000000}},	//   vērš, _הפרע, rnwr,
  { {0x69d82baf,0xf2dc0063,0xd2b8009a,0x00000000}},	//   geve, שַׁל, קלות_,
  { {0xa969015a,0x5ba7080b,0x61e52bb0,0x00000000}},	//   щика_, _мраз, _mahl,
  { {0x97d90086,0x2d9e0003,0x69ca2bb1,0x00000000}},	//   ську_, _ôter_, affe,
  { {0xafdb000e,0xb6a30013,0x69d82bb2,0x00000000}},	//   _kjøb, _giấ, beve,
  { {0x69d8175f,0x61e50240,0x7e7d2bb3,0x00000000}},	//   ceve, _nahl, _musp,
  { {0x46380085,0xe7080043,0x5dc8009a,0x00000000}},	//   ўчыя_, متین_, חֶרְ,
  { {0x43460062,0x683e0023,0x45180085,0x00000000}},	//   земв, līdn, юцыя_,
  { {0x7e7d00eb,0xa7c6007e,0x61e52bb4,0x00000000}},	//   _nusp, _رژيم_, _bahl,
  { {0xa1870854,0x6018013d,0x867a009a,0x00000000}},	//   збра_, _címn, _פרצו,
  { {0xe3b20021,0x61e50bab,0x7e7d2bb5,0x00000000}},	//   _كرة_, _dahl, _ausp,
  { {0x7e75001c,0xa3cb0053,0x1e861d48,0x00000000}},	//   _aizp, र्द_, злам,
  { {0x7e7d2bb6,0x441b009f,0xd00707b3,0x00000000}},	// [4760] _cusp, _לוקס, чете_,
  { {0x0ea70088,0x9f420080,0x3eb200fe,0x00000000}},	//   якуй_, _jaké_, rryt_,
  { {0xafdb00d1,0xdcfc001c,0x69d80821,0x00000000}},	//   _sjøe, _ierī, veve,
  { {0x69d80037,0x61e50199,0xb33b2bb7,0x00000000}},	//   weve, _zahl, laça,
  { {0x69d81865,0x1e832bb8,0x7f77009a,0x00000000}},	//   teve, _плям, _מעכב_,
  { {0x69d8006d,0xb33b0005,0x69ca2bb9,0x00000000}},	//   ueve, naça, uffe,
  { {0x69ca0185,0x9f490026,0xdb02006d,0x00000000}},	//   rffe, ljað_, rgoñ,
  { {0x69c10530,0x60110f2d,0x69ca002b,0x00000000}},	//   _ecle, _påmi, sffe,
  { {0x8c43005a,0xba3d0080,0x69ca004d,0x00000000}},	//   _чете, _kvůl, pffe,
  { {0xdbd60072,0x601a004c,0x1dcf0042,0x00000000}},	//   sääd, růmy, स्पत,
  { {0x9f470080,0x61e5085a,0xb33b017d,0x00000000}},	//   ěné_, _rahl, daça,
  { {0xf3ff017d,0x53350062,0x61e52bba,0x00000000}},	//   rmão_, демт, _sahl,
  { {0x61e5227c,0xf3ff017d,0xc34b0062,0x00000000}},	//   _pahl, smão_, сяне_,
  { {0x27e60025,0x7d030137,0x7e7d01f4,0x00000000}},	//   _haon_, änsk, _rusp,
  { {0xdcfc003d,0x2b520051,0x7e7d2bbb,0x00000000}},	//   _derī, żych_, _susp,
  { {0x61e500bd,0x6d550301,0x7e7d2bbc,0x00000000}},	//   _wahl, _ryza, _pusp,
  { {0x02a40088,0x23280001,0x27e60ddd,0x00000000}},	// [4770] _прэм, _ноћи_, _maon_,
  { {0x644f2bbd,0x628d0035,0x27e6006c,0x00000000}},	//   loci, _itao, _laon_,
  { {0xdb0900ea,0xf1b2009a,0x23cb009a,0x00000000}},	//   _ideé, _בסי_, ֶצַּ,
  { {0x644f2bbe,0x7988006f,0x6d55004c,0x00000000}},	//   noci, _afdw, _vyza,
  { {0x7e7d01cf,0x09e50131,0x1f740094,0x00000000}},	//   _uusp, долн, _плюя,
  { {0x2d850004,0x200b10c1,0x644f2bbf,0x00000000}},	//   _üle_, _hoci_, hoci,
  { {0x08d40088,0xa3dd0161,0x63ad2211,0x00000000}},	//   ецыя, ड़ा_, _odan,
  { {0x63ad0009,0xd0f80063,0x200b00dd,0x00000000}},	//   _ndan, למות_, _joci_,
  { {0x200b2bc0,0x27e60139,0x644f2bc1,0x00000000}},	//   _moci_, _daon_, doci,
  { {0x63ad2bc2,0xa3cb0053,0xe6110021,0x00000000}},	//   _adan, र्स_, ئشة_,
  { {0xd46a290b,0x04460928,0x1dcf0053,0x00000000}},	//   жине_, денн, स्यत,
  { {0xa7150001,0x644f0530,0xc2c60021,0x00000000}},	//   _одељ, goci, ويجي,
  { {0x63ad0185,0x0cba0161,0x9f4201c2,0x00000000}},	//   _ddan, _उम्म, _také_,
  { {0x628d0025,0x0478007e,0x63ad00ca,0x00000000}},	//   _dtao, _کليک_, _edan,
  { {0xb33b2bc3,0x3cf90053,0x27e600a4,0x00000000}},	//   raça, ूहों_, _yaon_,
  { {0x644f2bc4,0xdb1b006d,0x3055005e,0x00000000}},	//   coci, _acuí, еђут,
  { {0x6da60259,0xb33b2bc5,0x93430121,0x00000000}},	// [4780] диза, paça, _инъе,
  { {0x6b890bd1,0x9f490026,0x60182bc6,0x00000000}},	//   _afeg, rjað_, _tímo,
  { {0xa3cb0235,0x61462bc7,0x9be60054,0x00000000}},	//   र्व_, _цена, ділк,
  { {0xcdc900b5,0xad65005d,0x00000000,0x00000000}},	//   יך_, راله,   ,
  { {0x27e60025,0x0a6a137a,0xda660021,0x00000000}},	//   _raon_, орки_, واتي,
  { {0x09e30001,0x2bae001b,0xbea302d8,0x00000000}},	//   вољн, ộc_, _јарк,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x2fc02bc8,0xb8d60042,0x76aa0f9f,0x00000000}},	//   ngig_, _जि_, отов_,
  { {0xc8ca006a,0xd6da0086,0xc5f8001c,0x00000000}},	//   _ژوئن_, іти_, kmēt_,
  { {0x7c2203d9,0xda650021,0x60180046,0x00000000}},	//   lhor, _كالي, _síml,
  { {0x27e6002c,0xf9c7007e,0x2db70063,0x00000000}},	//   _taon_, _تحقی, ולין_,
  { {0x7c221a87,0x321800ac,0x7d030527,0x00000000}},	//   nhor, ekry_, änsi,
  { {0x43940001,0x44250006,0x601800ea,0x00000000}},	//   ђарс, ėl_, _címm,
  { {0x9f590025,0x200b2bc9,0x644f10c5,0x00000000}},	//   _tosú_, _soci_, soci,
  { {0xdb0000b9,0xdfd5026c,0x7c220c5f,0x00000000}},	//   _udmæ, новы, khor,
  { {0xa3cb0235,0x212a007e,0xe3d0008b,0x00000000}},	//   र्श_, سيقی_, _hằng_,
  { {0x200b02f6,0x628d0035,0x7c222bca,0x00000000}},	// [4790] _voci_, _utao, dhor,
  { {0xb33b0268,0x78650016,0xa7fd013d,0x00000000}},	//   laço, móve, tműk,
  { {0x8234006a,0x7c222bcb,0x765a0a3f,0x00000000}},	//   _جريا, fhor, ilty,
  { {0xe0d20047,0xfbab0086,0x7c22206a,0x00000000}},	//   _גײט_, ітей_, ghor,
  { {0x2444005b,0x1dc70053,0xdbd1004e,0x00000000}},	//   nıma_, _लापत, müüd,
  { {0x3ea92bcc,0x765a01e1,0xba77007e,0x00000000}},	//   msat_, jlty, ذاشت,
  { {0x3ea92bcd,0x8bc70b3f,0xbd4500de,0x00000000}},	//   lsat_, _осад, _أنزي,
  { {0x765a00e8,0xc5f8001c,0x386626b4,0x00000000}},	//   elty, kmēs_, _chor_,
  { {0xe3d0001b,0xf77101a7,0xb33b0555,0x00000000}},	//   _bằng_, داث_, daço,
  { {0xe3b2007e,0x24440058,0x3ea92bce,0x00000000}},	//   گرد_, dıma_, isat_,
  { {0xb33b006c,0x3ea92bcf,0xa81b0044,0x00000000}},	//   faço, hsat_, _وتصر_,
  { {0xccf200b5,0x9d1a0063,0x3ea92bd0,0x00000000}},	//   אכט_, פורט, ksat_,
  { {0x386d0e6c,0x00000000,0x00000000,0x00000000}},	//   mmer_,   ,   ,
  { {0x3ea90425,0x386d2bd1,0xb33b0058,0x00000000}},	//   dsat_, lmer_, maçl,
  { {0x3218021f,0xb5fe008b,0x3ea92bd2,0x00000000}},	//   rkry_, _khơn, esat_,
  { {0x44e10006,0xd007032d,0xb33b01a8,0x00000000}},	//   _ių_, несе_, caço,
  { {0x44202bd3,0x63a62bd4,0x568c0047,0x00000000}},	// [47a0] _ili_, makn, ַטאַ,
  { {0x386d00bd,0xa3c00053,0x9f4001a8,0x00000000}},	//   hmer_, ुभव_, rdià_,
  { {0x7c220034,0x3ea900e3,0x44e100eb,0x00000000}},	//   thor, asat_, _jų_,
  { {0xc5f8003d,0xf7672bd5,0x25a52bd6,0x00000000}},	//   nmēr_, _ما_, hall_,
  { {0xafdb0031,0xa3b80161,0xddcf0080,0x00000000}},	//   _kjøn, _चयन_, řeše,
  { {0x63a6003e,0x25a50026,0xc3330047,0x00000000}},	//   hakn, jall_, נוג_,
  { {0xeb9a0079,0xe3d0001b,0x4420037e,0x00000000}},	//   _нив_, _rằng_, _oli_,
  { {0x63a60488,0xc6f823ac,0x25a5002b,0x00000000}},	//   jakn, дних_, eall_,
  { {0x63a6014f,0xec370063,0x25a52bd7,0x00000000}},	//   dakn, _נאמר_, fall_,
  { {0x442016ea,0xceb30132,0x44322bd8,0x00000000}},	//   _ali_, נית_, _amy_,
  { {0x99de0088,0x442002f0,0x6018000f,0x00000000}},	//   _нiва_, _bli_, _címk,
  { {0x7ae216ae,0x63a6017e,0x7bc22bd9,0x00000000}},	//   owot, gakn, ngou,
  { {0xe2980088,0xee3f0080,0x25a52bda,0x00000000}},	//   наў_, _svým_, ball_,
  { {0x171b00b5,0x7af600fe,0x44320150,0x00000000}},	//   _צוגע, äyty, _emy_,
  { {0x9f470080,0x5067000a,0xb33b0367,0x00000000}},	//   ění_, етаа, paço,
  { {0x442002f6,0x7ae200e8,0x3ea92bdb,0x00000000}},	//   _gli_, kwot, tsat_,
  { {0x3ea91472,0x3f89003b,0x50642bdc,0x00000000}},	// [47b0] usat_, rcau_, утра,
  { {0x6ca715d4,0x3ea92bdd,0x44200734,0x00000000}},	//   ердж, rsat_, _zli_,
  { {0x442000fe,0x3ea92bde,0xdcbb005a,0x00000000}},	//   _yli_, ssat_, яща_,
  { {0x3ea90080,0xdb1b006d,0xb33b005b,0x00000000}},	//   psat_, _acuá, yaçl,
  { {0x645d2bdf,0x2009013d,0xde95005e,0x00000000}},	//   ilsi, mjai_, _јагњ,
  { {0xf2d400b5,0xdc13005b,0x645d004d,0x00000000}},	//   רעס_, rşıs, hlsi,
  { {0x63a6014f,0x25a52be0,0x6d42000c,0x00000000}},	//   yakn, vall_, şoar,
  { {0x645d00b9,0xfc3f006d,0x25a52be1,0x00000000}},	//   jlsi, _ñí_, wall_,
  { {0x25a52be2,0x386d2be3,0x3c44000d,0x00000000}},	//   tall_, rmer_, _сэрв,
  { {0x6444006f,0x45850062,0xb33b005b,0x00000000}},	//   _sjii, ъгов, raçl,
  { {0xcec00080,0xb5fe008b,0x63a60447,0x00000000}},	//   ěřit_, _thơn, takn,
  { {0x2459004a,0x69c3004b,0xd6b50062,0x00000000}},	//   kému_, lgne, _айдъ,
  { {0xe3b8005b,0x2e24004d,0x25a52be4,0x00000000}},	//   ğı_, _höfe_, pall_,
  { {0x44e10006,0x27ed244c,0xe3b8005b,0x00000000}},	//   _tų_, lden_, şı_,
  { {0xa0a30076,0x20560d64,0x27ed2be5,0x00000000}},	//   иард, втар, oden_,
  { {0x44201040,0x27ed2be6,0x78480080,0x00000000}},	//   _uli_, nden_, pěve,
  { {0x63a4001c,0x59e10053,0x27ed2be7,0x00000000}},	// [47c0] _iein, फ़ार, iden_,
  { {0x27ed024a,0x7e23005e,0x764100df,0x00000000}},	//   hden_, адуж, nnly,
  { {0x60182be8,0xafdb00d1,0x63a42be9,0x00000000}},	//   _lími, _kjøl, _kein,
  { {0x27ed2bea,0x69c32beb,0x63a4013d,0x00000000}},	//   jden_, egne, _jein,
  { {0xa3d40235,0x63a407c7,0xb06600fe,0x00000000}},	//   स्य_, _mein, _erää,
  { {0xda6311ec,0x7ae20051,0x61ee2bec,0x00000000}},	//   авчи, rwot, ndbl,
  { {0x7d0301e3,0x27ed0122,0xadd70063,0x00000000}},	//   änst, fden_, _שולח_,
  { {0x6b850021,0x27ed2bed,0x63a42bee,0x00000000}},	//   _مشكل, gden_, _nein,
  { {0x09e60076,0x68e3002b,0x7e7c2bef,0x00000000}},	//   _иоан, awnd, _kirp,
  { {0x4b55011c,0xdb002bf0,0x27ed2bf1,0x00000000}},	//   _съст, _remè, aden_,
  { {0x24e30088,0x63a4294f,0x27ed2bf2,0x00000000}},	//   ацяг, _bein, bden_,
  { {0x76410e7f,0x47d3007e,0x63a42bf3,0x00000000}},	//   anly, _نيمر, _cein,
  { {0x63a42bf4,0x6d5c2bf5,0xa3470085,0x00000000}},	//   _dein, _lyra, тэнл,
  { {0x752d0080,0x2459004a,0x6284003b,0x00000000}},	//   _řaze, vému_, _duio,
  { {0x2fd2001f,0xdb000e1f,0x7865013d,0x00000000}},	//   ffyg_, _demé, lóva,
  { {0x7e7c0706,0x63a41905,0x2009005f,0x00000000}},	//   _airp, _gein, ujai_,
  { {0x62842bf6,0x6d5c0058,0x44392bf7,0x00000000}},	// [47d0] _guio, _ayra, mis_,
  { {0x27ed01f7,0x24590114,0x44392bf8,0x00000000}},	//   zden_, rému_, lis_,
  { {0x27ed2bf9,0xf1a4000d,0x7e7c002b,0x00000000}},	//   yden_, _трын, _dirp,
  { {0xc4d300b5,0x44392bfa,0x6d5c081c,0x00000000}},	//   יגע_, nis_, _dyra,
  { {0x44390019,0x27ed005b,0x8f9a0063,0x00000000}},	//   iis_, vden_, _רישי,
  { {0x7d0300c7,0x44392bfb,0xdd94000d,0x00000000}},	//   änss, his_, _вары,
  { {0x44392bfc,0x69c32bfd,0x6b8400c2,0x00000000}},	//   kis_, rgne, žiga,
  { {0x8699000a,0x44392bfe,0x26cd0314,0x00000000}},	//   нтот_, jis_, tteo_,
  { {0x27ed2bff,0x9f42039f,0x63a403e1,0x00000000}},	//   rden_, _kaká_, _rein,
  { {0x63a407c7,0xafdb1262,0x44392c00,0x00000000}},	//   _sein, _sjøl, eis_,
  { {0x63a42c01,0x62840025,0x44392c02,0x00000000}},	//   _pein, _suio, fis_,
  { {0x289a0047,0x44392c03,0xdb000003,0x00000000}},	//   _נינא, gis_, _semé,
  { {0x8c1a014e,0x63bb0026,0x63a42c04,0x00000000}},	//   גורי, óuna, _vein,
  { {0x44392c05,0xe6c20014,0xe5a5005e,0x00000000}},	//   ais_, _óháð, _сики,
  { {0x3d1d0161,0x63a42c06,0x44392c07,0x00000000}},	//   पनों_, _tein, bis_,
  { {0x44392c08,0x7ae92c09,0x24830061,0x00000000}},	//   cis_, _oset, íjmu_,
  { {0x7c39002b,0x7848004c,0x6d5c2c0a,0x00000000}},	// [47e0] diwr, něva, _syra,
  { {0x683e001c,0xee372c0b,0x61fe1f51,0x00000000}},	//   rīdi, гну_, _unpl,
  { {0xa3cb0235,0x7ae90d9e,0x786500ea,0x00000000}},	//   र्क_, _aset, zóva,
  { {0xc1780006,0x201e008f,0x6d5c2c0c,0x00000000}},	//   žės_, ītis_, _vyra,
  { {0x6d5c0045,0x28c60042,0x7e7c2c0d,0x00000000}},	//   _wyra, रंभि, _tirp,
  { {0xa3d40161,0xb8850066,0xf2d30063,0x00000000}},	//   स्त_, zlíš, צעו_,
  { {0x7ae9000f,0x98a30001,0x0d750121,0x00000000}},	//   _eset, бије, _вытя,
  { {0x7981001f,0xb8140d34,0x44392c0e,0x00000000}},	//   _eglw, рдиј, xis_,
  { {0x44392c0f,0x57f30766,0x17f700de,0x00000000}},	//   vis_, спыт, طرية_,
  { {0x68ed0051,0x5a56005a,0x44392c10,0x00000000}},	//   łada, _събу, wis_,
  { {0x44392c11,0xafdb00d1,0x291821ad,0x00000000}},	//   tis_, _sjøm, _æra_,
  { {0x44392c12,0xb6a6012c,0x4407014b,0x00000000}},	//   uis_, _бидл, учоб,
  { {0xa3cb0053,0xe693007e,0x443922dc,0x00000000}},	//   र्ग_, _هلند, ris_,
  { {0x44392c13,0x6594066e,0xc693069a,0x00000000}},	//   sis_, _таку, _האס_,
  { {0x6671007e,0xa15908a2,0x44392c14,0x00000000}},	//   _بگير, таву_, pis_,
  { {0xafdb00d1,0x443900e5,0xff071a78,0x00000000}},	//   _tjøm, qis_, лязн,
  { {0x1e35000d,0x447c0041,0x0e350085,0x00000000}},	// [47f0] анаў, _אנהע, анаю,
  { {0xafdb00d1,0x3d270766,0xf41f0ef1,0x00000000}},	//   _kjøk, льев, lkä_,
  { {0xa807005b,0x9b950044,0x627a009a,0x00000000}},	//   ngıç, للات, _שנתנ,
  { {0xf41f00fe,0xac74007e,0x2c7e004c,0x00000000}},	//   nkä_, مانش, _půda_,
  { {0xf41f00fe,0x9f420066,0xf1d20042,0x00000000}},	//   ikä_, _taká_, द्वन,
  { {0x387d0185,0xa3cc0053,0xf41f0072,0x00000000}},	//   _siwr_, _लाभ_, hkä_,
  { {0x6d430025,0xafdb00d1,0xa8020058,0x00000000}},	//   únad, _skøy, ğınm,
  { {0xc8880032,0xb8cd0053,0x01380063,0x00000000}},	//   دخول_, _कब_, טרות_,
  { {0x78a4017f,0xe739005e,0x3cef004c,0x00000000}},	//   ćiva, ђео_, ťově_,
  { {0xf41f00fe,0xe6160076,0x3669005e,0x00000000}},	//   ekä_, иды_, ђано_,
  { {0x9984043b,0x236900c3,0xe7b5005d,0x00000000}},	//   _المو, _azaj_, _نماد,
  { {0x7bc60014,0x44242c15,0xf770005d,0x00000000}},	//   _ökut, óm_, _کام_,
  { {0x72c3026c,0x59da0042,0xfbd2009a,0x00000000}},	//   обяз, _मॉडर, קתך_,
  { {0xe2972c16,0x6587014b,0x00000000,0x00000000}},	//   рар_, _сыдз,   ,
  { {0x505a0076,0x463a0047,0xafdb04aa,0x00000000}},	//   вшая_, _בעסע, _gjøk,
  { {0xdb0b0026,0xd3ba000d,0x630602da,0x00000000}},	//   yggð, _рукі_, _نوبل,

  { {0x27ef0595,0xe5a3001b,0x84450021,0x00000000}},	// [4800] _magn_, _điệ, _دخول,
  { {0xbda50032,0xfd9605ac,0x2d960121,0x00000000}},	//   محمو, ршаю, ррас,
  { {0xdddd000c,0x64462c17,0x60180046,0x00000000}},	//   _susţ, onki, _símu,
  { {0x27ef00a4,0x601800ea,0x6a6401a8,0x00000000}},	//   _nagn_, _címt, tòfo,
  { {0xa3cb0053,0xf1aa0053,0x6e20003b,0x00000000}},	//   र्ट_, _क़ान, _îmbo,
  { {0xca560001,0x3ceb00fe,0x7c960062,0x00000000}},	//   штењ, äivä_, _врац,
  { {0x68ed0051,0x2c67004b,0x1d07049f,0x00000000}},	//   ładn, sõda_, _кери_,
  { {0x60180026,0xf0930063,0x237f004c,0x00000000}},	//   _tímu, חנה_, žuji_,
  { {0x96342c18,0xffb70047,0xdb000046,0x00000000}},	//   йниц, ױליש_, _kemí,
  { {0x60de076c,0x64460b4e,0x2258007d,0x00000000}},	//   _oppm, enki, jork_,
  { {0xf41f00fe,0x32132c19,0x77ca000d,0x00000000}},	//   tkä_, _roxy_, _алег_,
  { {0x2ca7003b,0x38600139,0x35ca0053,0x00000000}},	//   ândi_, _óir_, ़्ज़,
  { {0xe6940021,0x63b6001f,0x24520124,0x00000000}},	//   _التد, _ddyn, námy_,
  { {0xa3cb0235,0x26c40006,0x64462c1a,0x00000000}},	//   र्ज_, mumo_, anki,
  { {0x9f490025,0x26c40078,0x61142c1b,0x00000000}},	//   rdaí_, lumo_, одру,
  { {0xcf9820cf,0x02a70055,0x80040002,0x00000000}},	//   ију_, _кром, очуе,
  { {0x69da2c1c,0x22582c1d,0x26c40078,0x00000000}},	// [4810] _obte, bork_, numo_,
  { {0x60180026,0x6e20003b,0x320c0072,0x00000000}},	//   _símt, _îmbl, ödyt_,
  { {0x601800ea,0x63b6001f,0xa3d40042,0x00000000}},	//   _címs, _ydyn, स्व_,
  { {0xa3cb0235,0xc57900b5,0xccf80001,0x00000000}},	//   र्च_, אָנט, шћу_,
  { {0x2ef40088,0x78480080,0xa3d90053,0x00000000}},	//   _дзяр, těvn, ठ्य_,
  { {0xa802005b,0x26c40078,0x27ef05e7,0x00000000}},	//   şılm, dumo_, _sagn_,
  { {0x601801c2,0x7cf0013d,0xef1f008f,0x00000000}},	//   _tímt, rórá, āļus_,
  { {0x9f950004,0xdb000080,0x68ed0051,0x00000000}},	//   _nüüd_, _zemí, łado,
  { {0x26c40006,0x27ef2c1e,0x0675011b,0x00000000}},	//   gumo_, _vagn_, římé_,
  { {0x2480004b,0x06090156,0xa3cb0042,0x00000000}},	//   _siim_, унок_, र्घ_,
  { {0x2496007e,0x2480004b,0x85790121,0x00000000}},	//   ینید_, _piim_, ысит_,
  { {0x2e240026,0x2258201a,0x26c40078,0x00000000}},	//   _nöfn_, work_, bumo_,
  { {0xf745005e,0xe60e182e,0x7349030b,0x00000000}},	//   _ћело, _ед_, ачёв_,
  { {0xf59500de,0xa36300de,0x00000000,0x00000000}},	//   _الغج, سُّو,   ,
  { {0x6603290f,0x661c00a5,0xdb00017c,0x00000000}},	//   _innk, örke, _remí,
  { {0x60180024,0x351a0149,0xdfd2013a,0x00000000}},	//   _ríms, _תוקנ, ثير_,
  { {0xa067226b,0x25ee0042,0xc4480043,0x00000000}},	// [4820] сата_, _असमी_, _میگن_,
  { {0x6018000f,0x7bdb00a4,0xdcfc001c,0x00000000}},	//   _címr, _abuu, _agrā,
  { {0x60de00c7,0x7afb0f52,0xa63a00b5,0x00000000}},	//   _uppm, _arut, נגער,
  { {0x7afb2c1f,0xd00a1dd0,0x32da009d,0x00000000}},	//   _brut, _семе_, ָחַנ,
  { {0x7afb0027,0x44220224,0xcf930063,0x00000000}},	//   _crut, ikk_, _מטר_,
  { {0x6d430025,0xee3a0121,0x291c0078,0x00000000}},	//   únac, _снг_, tyva_,
  { {0x98a3005e,0x7afb2c20,0x6da30320,0x00000000}},	//   пије, _erut, _хиса,
  { {0x26c400eb,0x7afb2c21,0x98a3005e,0x00000000}},	//   tumo_, _frut, чиће,
  { {0xaac50032,0x8b260076,0xdb0e00fe,0x00000000}},	//   _وتكن, _удае, äjäl,
  { {0xba2300d7,0x26c40078,0x7c222c22,0x00000000}},	//   _едук, rumo_, lkor,
  { {0x26c422ea,0x8afd0080,0xba3d0080,0x00000000}},	//   sumo_, _vyře, _tvůr,
  { {0x7c222c23,0x3eb200fe,0x397b0047,0x00000000}},	//   nkor, ksyt_, _עטאנ,
  { {0xcc3b00b5,0xb8570021,0x25ac004c,0x00000000}},	//   רעכט, _النص_, padl_,
  { {0x44222c24,0x290d0051,0x7d1e0050,0x00000000}},	//   akk_, ślał_, kyps,
  { {0x463b00b5,0xa3d514db,0x7c222c25,0x00000000}},	//   _געגע, _дойч, kkor,
  { {0x7c222c26,0x765a2c27,0xef99218c,0x00000000}},	//   jkor, loty, ркаш_,
  { {0x644d0072,0x7c222c28,0xdd9b0054,0x00000000}},	// [4830] _ijai, dkor, гше_,
  { {0x629d2c29,0x7c222c2a,0x3e6f004b,0x00000000}},	//   mpso, ekor, küte_,
  { {0x443b0290,0xdb000022,0x7c222c2b,0x00000000}},	//   _kmq_, _odmó, fkor,
  { {0x237f017f,0x69ca00ea,0x61e72c2c,0x00000000}},	//   žuju_, egfe, lejl,
  { {0x5ba80088,0x765a2c2d,0x63af0066,0x00000000}},	//   скім_, koty, iacn,
  { {0xe9d8000d,0xdb0b0003,0x7c2200a8,0x00000000}},	//   йкі_, nagé, akor,
  { {0x442217d3,0x38ca005d,0x44292c2e,0x00000000}},	//   ykk_, لايی_, _ola_,
  { {0xe7390055,0x7afb2c2f,0x2ca7000c,0x00000000}},	//   ией_, _trut, ându_,
  { {0x7c29005b,0x56290062,0x7afb0360,0x00000000}},	//   _iler, ижим_, _urut,
  { {0xc8ab011c,0x765a2c30,0x644d1472,0x00000000}},	//   _бъде_, goty, _ajai,
  { {0x67d5019d,0x44292c31,0x240a0905,0x00000000}},	//   _можу, _bla_, анни_,
  { {0xc209014e,0x7bcb2c32,0x442200d1,0x00000000}},	//   _בה_, nggu, ukk_,
  { {0x44291112,0x61e72c33,0x7bcb0014,0x00000000}},	//   _dla_, fejl, iggu,
  { {0x442903d9,0x64a5000d,0x7d1800b9,0x00000000}},	//   _ela_, _дака, øvsk,
  { {0x7c222c34,0x7c3b107b,0xd1750085,0x00000000}},	//   ykor, _omur, зыты,
  { {0xdfa60021,0xf1db0053,0x3eb20072,0x00000000}},	//   تحسي, म्बन, tsyt_,
  { {0x69d800ac,0xf99f008b,0xfe050053,0x00000000}},	// [4840] yfve, _đèn_, रांस_,
  { {0x26c2017f,0x7c292c35,0x7d1e0137,0x00000000}},	//   škog_, _aler, typs,
  { {0x55ba0063,0x5ce60021,0x7c291236,0x00000000}},	//   שמעו, تكال, _bler,
  { {0x7c2910c5,0x228f0058,0x99870078,0x00000000}},	//   _cler, _yük_, kinų_,
  { {0x3ce60024,0x7c222c36,0xdb00013d,0x00000000}},	//   ňov_, rkor, _bemá,
  { {0xdb09006f,0x7c222c37,0xdca605ef,0x00000000}},	//   _zeeë, skor, _маги,
  { {0xdb0002dd,0x7c291781,0xc27b0063,0x00000000}},	//   _demá, _fler, ברסי,
  { {0xdb000268,0xd6da13e1,0x7c292c38,0x00000000}},	//   _temà, ато_, _gler,
  { {0x6996005a,0xaad10042,0x75e60085,0x00000000}},	//   _дрех, _समयक, оўне,
  { {0x44290122,0xd6d7000d,0x19c30086,0x00000000}},	//   _sla_, іты_, _обум,
  { {0x61e70146,0x65630185,0x44292c39,0x00000000}},	//   vejl, _cynh, _pla_,
  { {0x98a30142,0x656300a3,0x1e170082,0x00000000}},	//   _цице, _dynh, _दक्ष_,
  { {0x53340456,0x765a2c3a,0xc21b0054,0x00000000}},	//   деят, poty, аєв_,
  { {0x601800cd,0x8ccb0053,0xe5340475,0x00000000}},	//   _símp, _हमलो, _нель,
  { {0x6563001f,0x307b0021,0xd5b8008f,0x00000000}},	//   _gynh, لحرة_, nkām_,
  { {0x3634007e,0x61e700b9,0x44290ca7,0x00000000}},	//   _برچس, sejl, _ula_,
  { {0x23280001,0x2d8700c2,0x61e700b9,0x00000000}},	// [4850] _моћи_, žnem_, pejl,
  { {0x645d0529,0xccfb0001,0x2d8700d1,0x00000000}},	//   losi, иће_, øne_,
  { {0x12780021,0x63ad227c,0x7c290509,0x00000000}},	//   _بحيث_, _kean, _pler,
  { {0x515a014e,0xdb00006d,0xe5710047,0x00000000}},	//   _לכתו, _semá, ײַב_,
  { {0x63ad1a74,0x645d0035,0xfaa52c3b,0x00000000}},	//   _mean, iosi, чало,
  { {0x786502dd,0x7e7900b5,0x62850080,0x00000000}},	//   móvi, _לאָז, _jiho,
  { {0xa3cc0053,0x645d2c3c,0x20191982,0x00000000}},	//   _लाल_, kosi, _kosi_,
  { {0x1bb800b3,0x8bc41137,0x63ad1f82,0x00000000}},	//   _واقع_, _осуд, _nean,
  { {0xd7060076,0xafdb00b9,0x20190035,0x00000000}},	//   зные_, _imød, _mosi_,
  { {0xdb00010a,0x79a70239,0x58870085,0x00000000}},	//   _bemæ, _фрае, _дыда,
  { {0x1ddd0053,0xf2c90149,0x2556004c,0x00000000}},	//   न्यत, _תע_, vělé_,
  { {0x63ad0027,0x645d2c3d,0x20192c3e,0x00000000}},	//   _cean, gosi, _nosi_,
  { {0x2d870024,0x63ad2c3f,0x59d20042,0x00000000}},	//   ľnej_, _dean, _सामर,
  { {0x2d870024,0xf67500b5,0x877a0047,0x00000000}},	//   žnej_, _צײַט_, _פאסי,
  { {0x62850397,0x76412c40,0x6e20003b,0x00000000}},	//   _diho, mily, _îmbi,
  { {0x63ad0173,0x764100fe,0x997e003b,0x00000000}},	//   _gean, lily, lăţi_,
  { {0x6fad0161,0x6a6400cd,0x2019099f,0x00000000}},	// [4860] _ज़रू, sòfi, _dosi_,
  { {0x7641001f,0xafdb04aa,0xf3f8008f,0x00000000}},	//   nily, _sjøt, ēģu_,
  { {0xd5b1008b,0x59d20042,0xcea9009a,0x00000000}},	//   iá_, _साबर, רי_,
  { {0xd5b1008d,0xae050042,0x9a8601d5,0x00000000}},	//   há_, राउन_, пукл,
  { {0x76410026,0xab830183,0x8b23030b,0x00000000}},	//   kily, нушк, ндце,
  { {0x69d501f7,0x78480080,0x3ea022ab,0x00000000}},	//   _özel, pěvk, mpit_,
  { {0x8afd0080,0x7641002b,0xfce30e81,0x00000000}},	//   _vyřa, dily, _поро,
  { {0xafdb05dd,0x44fa001c,0x7792007e,0x00000000}},	//   _hjør, _rī_, ریتا,
  { {0xafdb076c,0x6aa90185,0x63ad2c41,0x00000000}},	//   _kjør, _gwef, _rean,
  { {0x0f370063,0x984e005b,0x63ad2c42,0x00000000}},	//   פריט_, rşın_, _sean,
  { {0x645d2c43,0xa96a013a,0x2c510022,0x00000000}},	//   tosi, _امام_, ląda_,
  { {0x9f4002dd,0xb8650242,0x645d0c97,0x00000000}},	//   ndió_, _قانو, uosi,
  { {0xe8090161,0x29180268,0x2d980093,0x00000000}},	//   वारा_, _àrab_, _ofre_,
  { {0x645d2c44,0x997e003b,0x7853003b,0x00000000}},	//   sosi, căţi_, răve,
  { {0x63ad0027,0x2019078d,0xd49a005e,0x00000000}},	//   _tean, _posi_, _урл_,
  { {0xc5f8008f,0x206401ce,0x2d9c009c,0x00000000}},	//   ldē_, еђув, űvel_,
  { {0xb6a3001b,0x3ea0002c,0xafdb2c45,0x00000000}},	// [4870] _nhấ, gpit_, _bjør,
  { {0xc5f8008f,0x26c42c46,0xe8030042,0x00000000}},	//   ndē_, irmo_, _शोना_,
  { {0xa3d40053,0x40352c47,0xa37b004b,0x00000000}},	//   स्क_, _женс, deõi,
  { {0x22430b7d,0x7a2f0031,0x9203001c,0x00000000}},	//   lijk_, _møte, žādi,
  { {0xb6a3001b,0xda350085,0x20d70058,0x00000000}},	//   _chấ, меды, lçi_,
  { {0xafdb0031,0x9b040088,0x28990131,0x00000000}},	//   _gjør, эзід, отиќ_,
  { {0x23bf0053,0x61f72c48,0xe8090042,0x00000000}},	//   ्लाद, _maxl, वाला_,
  { {0xccf2014e,0x7641001f,0xdb000ae2,0x00000000}},	//   _בכל_, wily, _bemä,
  { {0x997e0529,0x22430122,0xd6ce0044,0x00000000}},	//   tăţi_, kijk_, لقي_,
  { {0x20d7005b,0xd5b10013,0x7a2f04aa,0x00000000}},	//   kçi_, uá_, _bøte,
  { {0xa25b0016,0x2243006f,0x76411cec,0x00000000}},	//   trôn, dijk_, rily,
  { {0x3e740024,0xdd1c0024,0x3ea000fe,0x00000000}},	//   mäte_, náša, ypit_,
  { {0xdb0000bd,0xfbb6009a,0xa5f91135,0x00000000}},	//   _gemä, ופרת_, _меду_,
  { {0x05290002,0xa5f6005e,0x14c50053,0x00000000}},	//   _молк_, _жељу_, _विपण,
  { {0x24590066,0x7a2f04aa,0xdddc2c46,0x00000000}},	//   hémy_, _gøte, _nirš,
  { {0x98a70045,0xafdb00d1,0xdbcc0014,0x00000000}},	//   czną_, _sjør, jóðk,
  { {0x3ea00080,0x44770041,0x93130044,0x00000000}},	// [4880] upit_, _קעפל_, _لويش,
  { {0xae0e0053,0xed030041,0x82860044,0x00000000}},	//   साधन_, גיטאַ, _تجعل,
  { {0x3ea0005b,0x7c660021,0x40950363,0x00000000}},	//   spit_, واصل, _прят,
  { {0x5fb20053,0x6fb20053,0xdca30336,0x00000000}},	//   _ज़िल, _ज़िं, таци,
  { {0x8db6019d,0x9f4002dd,0x5f06000d,0x00000000}},	//   _осві, rdió_, _ўзга,
  { {0xef830363,0x9e76005d,0x2cb80130,0x00000000}},	//   _шляп, _آهست, _tvrd_,
  { {0xafdb076c,0x26110161,0x6e2300ea,0x00000000}},	//   _kjøp, तानी_, önbe,
  { {0x7d03010a,0xb6a3001b,0xb6f40d34,0x00000000}},	//   ænse, _thấ, езиј,
  { {0x78ad017f,0x661c0137,0xc6f70895,0x00000000}},	//   ćava, örko, дных_,
  { {0xc5f8008f,0x3ead0075,0x0ae90044,0x00000000}},	//   udē_, _çete_, _عرقي_,
  { {0x6e200529,0xc9850044,0x2508005d,0x00000000}},	//   _îmbu, _كشمي, سردی_,
  { {0x22430122,0x69da0053,0x260c0082,0x00000000}},	//   wijk_, प्री, ़ाही_,
  { {0xe2980088,0x98a70022,0xdb0000a5,0x00000000}},	//   маў_, rzną_, _femå,
  { {0x2c7500b9,0x20d7005b,0x88c70080,0x00000000}},	//   måde_, tçi_, spěš,
  { {0x224302b0,0x30850021,0x2b5a0022,0x00000000}},	//   rijk_, فلسف, ępcy_,
  { {0x4ea7041d,0x6d430139,0x1eab0021,0x00000000}},	//   држа, únam, قائي_,
  { {0x9f550121,0x799a1f57,0x40841f89,0x00000000}},	// [4890] хвач, _oftw, турб,
  { {0x7c3a00eb,0xff040076,0xbd6b0076,0x00000000}},	//   _įtra, ъясн, орее_,
  { {0x92580021,0x644f2c49,0xdcbb04d6,0x00000000}},	//   _تشير_, onci, юща_,
  { {0xdfa70032,0xdddc00eb,0x447c00b5,0x00000000}},	//   _تحدي, _virš, ַנגע,
  { {0xa3d40235,0x644f2c4a,0xd6c60242,0x00000000}},	//   स्ट_, inci, _حق_,
  { {0x9f420080,0x661c01e9,0x24892c4b,0x00000000}},	//   _jaký_, örkl, _liam_,
  { {0x9f40007a,0x24890089,0xd9960044,0x00000000}},	//   ldið_, _oiam_, رنيت_,
  { {0xf42a00fe,0x3e7400bd,0xb0660072,0x00000000}},	//   isää_, räte_, _isää,
  { {0x9f40007a,0xf6252ab5,0x4758000d,0x00000000}},	//   ndið_, едпо, дрэя_,
  { {0xa3e20053,0x69de0019,0x644f2319,0x00000000}},	//   न्न_, õpet, enci,
  { {0x6c790041,0xd46a173e,0x2c7500a5,0x00000000}},	//   ּאָפ, зине_, pådd_,
  { {0x26d8003b,0x78fa009a,0x00000000,0x00000000}},	//   ăror_, _מפעו,   ,
  { {0x2489003e,0xe72e0793,0x42d5000d,0x00000000}},	//   _diam_, _се_, кіру,
  { {0x27ed2c4c,0x644f2c4d,0xbb3a0047,0x00000000}},	//   leen_, anci, לערי,
  { {0xafe60b62,0xc0760001,0x9f470080,0x00000000}},	//   новл, ећањ, ěný_,
  { {0x27ed02bb,0x2489008b,0xdfd20021,0x00000000}},	//   neen_, _giam_, طيط_,
  { {0x64460357,0x27e0004b,0x50590054,0x00000000}},	// [48a0] miki, _öine_, єшся_,
  { {0xe0da0259,0x27ed2c4e,0xbe66007e,0x00000000}},	//   _ево_, heen_, رهاي,
  { {0x61d700b5,0x27ed015d,0x62490066,0x00000000}},	//   _אויף_, keen_, tľov,
  { {0xdb1b006d,0x64462c4f,0xc4d20047,0x00000000}},	//   _acuñ, niki, רגא_,
  { {0xa3e20235,0x59f800a0,0x24840240,0x00000000}},	//   न्य_, деля_, íjmy_,
  { {0x61ee0d19,0x64462c50,0x62490066,0x00000000}},	//   nebl, hiki, sľov,
  { {0x6446053a,0x644f001f,0x6b9b001f,0x00000000}},	//   kiki, ynci, _ffug,
  { {0x683e003d,0x27ed0438,0x61ee00bd,0x00000000}},	//   līdz, geen_, hebl,
  { {0xc5f8003d,0x644614eb,0xd6da0054,0x00000000}},	//   klēt_, diki, їти_,
  { {0x2c7518eb,0x601800ea,0x24892c51,0x00000000}},	//   råde_, _címz, _siam_,
  { {0x6446282c,0x24590086,0xa3cc0053,0x00000000}},	//   fiki, дань_, _लाख_,
  { {0x27ed119d,0x644f153e,0x7848004c,0x00000000}},	//   ceen_, unci, těvu,
  { {0x2489017d,0x3866013d,0x2819005d,0x00000000}},	//   _viam_, _ikor_, _تفنگ_,
  { {0x61ee2c52,0x64460ab6,0x51870002,0x00000000}},	//   gebl, aiki, еуба,
  { {0x2bd10161,0x64462c53,0x28c60042,0x00000000}},	//   _हाला, biki, रंटि,
  { {0x248900e3,0xd468005e,0x68fc00be,0x00000000}},	//   _uiam_, _пије_, _árdu,
  { {0x9f420024,0xc275007b,0x9df91567,0x00000000}},	// [48b0] _taký_, _илиј, мнат_,
  { {0x6b9b0290,0x00000000,0x00000000,0x00000000}},	//   _sfug,   ,   ,
  { {0x61e1004b,0x2374005d,0x27ed1e3d,0x00000000}},	//   õllu, _لایح, yeen_,
  { {0x683e0006,0xbca40044,0xdea1005d,0x00000000}},	//   būdi, امني, _نیری,
  { {0x27ed2c54,0x501a009d,0x00000000,0x00000000}},	//   veen_, _חורו,   ,
  { {0x27ed2c55,0x64462c56,0x7db40021,0x00000000}},	//   ween_, ziki, _مصفا,
  { {0x27ed2c57,0x64462c58,0xa3e20042,0x00000000}},	//   teen_, yiki, न्ड_,
  { {0x6e20000c,0xc5f8001c,0xd7090121,0x00000000}},	//   _îmbr, klēs_, дние_,
  { {0x61ee2c59,0x27ed2c5a,0x64462c5b,0x00000000}},	//   yebl, reen_, viki,
  { {0x27ed024a,0x26c30198,0x3866014f,0x00000000}},	//   seen_, čjo_, _ekor_,
  { {0x644627f2,0x61ee006f,0x853c0078,0x00000000}},	//   tiki, vebl, lbėj,
  { {0x7c2b006f,0x61aa0042,0x04462c5c,0x00000000}},	//   nkgr, कर्ष, темн,
  { {0x61ee00e8,0x26cd2c5d,0x64462c5e,0x00000000}},	//   tebl, queo_, riki,
  { {0x61ee006d,0x7ae60137,0x64462c5f,0x00000000}},	//   uebl, _äkte, siki,
  { {0x4f96000a,0x64462c60,0x386d2c61,0x00000000}},	//   врзу, piki, oler_,
  { {0x61ee021f,0x386d01f7,0x7ae900fe,0x00000000}},	//   sebl, nler_, _opet,
  { {0xc7b200b5,0x60ce0034,0xa0672c62,0x00000000}},	// [48c0] יבן_, subm, тата_,
  { {0x386d2c63,0x69c10618,0x7e7e0072,0x00000000}},	//   hler_, _ndle, umpp,
  { {0x44202c64,0x387f0360,0x853c0078,0x00000000}},	//   _koi_, kmur_, ybėm,
  { {0x386d2c65,0x351a0047,0x44202c66,0x00000000}},	//   jler_, ווענ, _joi_,
  { {0x44202c67,0x80e20053,0x764300ac,0x00000000}},	//   _moi_, _पहुं, _omny,
  { {0x6da30086,0x44202226,0x78750006,0x00000000}},	//   _вира, _loi_, _išvy,
  { {0x61e3005b,0x442000ac,0xac9a007e,0x00000000}},	//   _önle, _ooi_, _آنرا_,
  { {0x44200c88,0x76430089,0x386d1781,0x00000000}},	//   _noi_, _amny, gler_,
  { {0xca48008b,0xf76f0021,0x7c200139,0x00000000}},	//   hời_, ياً_, _iomr,
  { {0x35e30086,0xceb30063,0x44200d12,0x00000000}},	//   ацюв, סית_, _aoi_,
  { {0x2c7501e3,0x443200e8,0x386d0f4b,0x00000000}},	//   låda_, _bly_, bler_,
  { {0x6d430027,0x07a6018b,0x44202c68,0x00000000}},	//   únai, _радн, _coi_,
  { {0x27e600a4,0x44202b4a,0xa3e20053,0x00000000}},	//   _ibon_, _doi_, न्ध_,
  { {0xd0d50062,0x64440072,0xa4d40054,0x00000000}},	//   логъ, _emii, _бокі,
  { {0x442013a8,0x442b0089,0x44320cc8,0x00000000}},	//   _foi_, pkc_, _fly_,
  { {0x443200ac,0xa3e20053,0x44202c69,0x00000000}},	//   _gly_, न्द_, _goi_,
  { {0xcddb0001,0xce940062,0xb0880121,0x00000000}},	// [48d0] дње_, иатъ, тёре_,
  { {0xe7e20161,0x386d005b,0x645d0003,0x00000000}},	//   क्ता_, zler_, érif,
  { {0xee8401e8,0x2d87181d,0x386d2c6a,0x00000000}},	//   рыто, äne_, yler_,
  { {0x7c2000e5,0xb7e20042,0xdd0d0022,0x00000000}},	//   _comr, _कॉलम_, _półp,
  { {0xdd1c0024,0x5ba8000d,0xd5b8008f,0x00000000}},	//   _vášm, ткім_, nkās_,
  { {0x386d2c6b,0x853c0006,0x7ae900a8,0x00000000}},	//   wler_, rbėj, _vpet,
  { {0x386d2c6c,0x18690f85,0x0593005d,0x00000000}},	//   tler_, наки_, یادگ,
  { {0xb8db0161,0x386d1dba,0x387f0046,0x00000000}},	//   _अब_, uler_, umur_,
  { {0x386d2c6d,0x44202c6e,0x9f590003,0x00000000}},	//   rler_, _roi_, _basé_,
  { {0x69c100b9,0x7c200024,0x386d2c6f,0x00000000}},	//   _udle, _zomr, sler_,
  { {0xc32900b7,0x442002f6,0xb7d50242,0x00000000}},	//   _צו_, _poi_, _مقاب,
  { {0x389a0047,0x263d0066,0xb794005e,0x00000000}},	//   _װיסנ, vňou_, _кршћ,
  { {0x27fd0185,0x44202c70,0xe2972c71,0x00000000}},	//   _iawn_, _voi_, лая_,
  { {0xbb3a0047,0x27ff18d5,0x42550713,0x00000000}},	//   געשי, ldun_, атст,
  { {0x463a00b5,0x44202c72,0x44f30078,0x00000000}},	//   _רעצע, _toi_, _uţ_,
  { {0x6444002c,0x44200290,0x69cd0053,0x00000000}},	//   _umii, _uoi_, _साझी,
  { {0x67290009,0x7d030146,0x06960047,0x00000000}},	// [48e0] nyej, ænsn, ָדעם_,
  { {0x7c202c73,0xc3330132,0x27fd04bf,0x00000000}},	//   _somr, _לוח_, _lawn_,
  { {0x661c0026,0xa37b004b,0x645d2c74,0x00000000}},	//   örki, leõp, érig,
  { {0x27fd002b,0xeaba1415,0x61fe2c75,0x00000000}},	//   _nawn_, ейд_, _hapl,
  { {0x75280051,0x61fe2c76,0x4af808b9,0x00000000}},	//   zydz, _kapl, телю_,
  { {0x673b0024,0x2ee00150,0x63b60026,0x00000000}},	//   dzuj, mtif_, _leyn,
  { {0xa8a3000d,0x6f040e1f,0x7d030137,0x00000000}},	//   брык, lvic, ånst,
  { {0x76aa253f,0x61fe24aa,0x26c207b4,0x00000000}},	//   нтов_, _lapl, škom_,
  { {0x2ee009df,0x6f041e3e,0xdb0e0072,0x00000000}},	//   ntif_, nvic, öjäm,
  { {0x14ca0055,0xa3e20235,0x61fe2c77,0x00000000}},	//   ными_, न्स_, _napl,
  { {0xb9930032,0xd7e60086,0x18a6000a,0x00000000}},	//   _المب, _біло, _саем,
  { {0x2ee0265d,0x61fe00a4,0xd7f72c78,0x00000000}},	//   ktif_, _aapl, _буш_,
  { {0xfe040161,0x629602dd,0x04640088,0x00000000}},	//   रयास_, _cuyo, стэм,
  { {0x69d501f7,0x9f4b0025,0x6f042c79,0x00000000}},	//   _özet, _tacú_, dvic,
  { {0xd5b8003d,0xa3e20053,0xc0c8005e,0x00000000}},	//   skās_, न्ह_, луте_,
  { {0x645d0153,0x50672c7a,0xd346005d,0x00000000}},	//   érid, утга, اییه_,
  { {0x2dcb0001,0x62962c7b,0x69da2c7c,0x00000000}},	// [48f0] ећен_, _guyo, _octe,
  { {0x68fa004d,0x61fe00a3,0xee84014b,0x00000000}},	//   _ostd, _gapl, быхо,
  { {0x8234006a,0x2ee0003e,0x6f042c7d,0x00000000}},	//   _دريا, atif_, avic,
  { {0x69da02a0,0x61fe0ad6,0xbed50141,0x00000000}},	//   _acte, _zapl, _комј,
  { {0x2ee0260c,0x26c2007d,0x3d950086,0x00000000}},	//   ctif_, škoj_, _вигр,
  { {0x3ea908f0,0xdd94000d,0x329c0063,0x00000000}},	//   mpat_, _гары, עבוד,
  { {0x27fd00e5,0x3ea9003b,0x44392c7e,0x00000000}},	//   _pawn_, lpat_, khs_,
  { {0x27ff0072,0xdcee008f,0x2bd9005d,0x00000000}},	//   udun_, _uzbā, _جاسک_,
  { {0x63b6007a,0xa3d90053,0x44392c7f,0x00000000}},	//   _reyn, ालन_, dhs_,
  { {0xdb0b00c7,0x673b0080,0x63b62c80,0x00000000}},	//   gagå, rzuj, _seyn,
  { {0x6296006d,0x245b0006,0x61fe004b,0x00000000}},	//   _suyo, kšmę_, _rapl,
  { {0x61fe2c81,0x63862bc7,0x44392c82,0x00000000}},	//   _sapl, игна, ghs_,
  { {0x63bb007a,0x61fe0df9,0x4376013c,0x00000000}},	//   ðuna, _papl, рунт,
  { {0x6f040290,0x09b50047,0x5436007e,0x00000000}},	//   vvic, יפֿט_, ارگر,
  { {0x3ea9017e,0xa37b004b,0x602602e1,0x00000000}},	//   epat_, seõp, адва,
  { {0x32040045,0x7afb0004,0xf55a0063,0x00000000}},	//   śmy_, _osut, _בדצמ,
  { {0x645d236b,0x5f030054,0x20000cb6,0x00000000}},	// [4900] érie, озта, rdii_,
  { {0xb2bb0063,0xa2bb009f,0x2ee02c83,0x00000000}},	//   _שמיר, _שמיט, rtif_,
  { {0x7afb2c84,0x3ea91193,0xf41f004b,0x00000000}},	//   _asut, apat_, smäe_,
  { {0xa3d90053,0x2ee02c85,0x115b00ff,0x00000000}},	//   ालय_, ptif_, _ידיע,
  { {0x2c7c0014,0x539b089e,0x6a86014b,0x00000000}},	//   vídd_, דינו, алда,
  { {0x26c20078,0xf38d0041,0x49d70054,0x00000000}},	//   škok_, ׂראָ, идію_,
  { {0x7a3400cd,0x6a6d0046,0xf1b3009a,0x00000000}},	//   _càta, júfu, חסו_,
  { {0xa5d80053,0xbcdf004c,0x58860085,0x00000000}},	//   _माहौ, žšíh, шыла,
  { {0xe7e20053,0x36d40062,0xdb0b0137,0x00000000}},	//   क्षा_, щопр, tagå,
  { {0xf6e30085,0x75061313,0x79b8009d,0x00000000}},	//   іцын, аџме, _תֶּה,
  { {0x0d970063,0x443929d8,0xcd970063,0x00000000}},	//   יכים_, ths_, ידית_,
  { {0x26cd006d,0x6298007d,0x69d50058,0x00000000}},	//   breo_, _čvor, _özer,
  { {0xc5940002,0x7ae22c86,0xc4580121,0x00000000}},	//   _лилј, ntot, риях_,
  { {0x69d82c87,0xb7e20053,0xe7f90053,0x00000000}},	//   ngve, क्रम_, ्यथा_,
  { {0x661c007a,0x7ae20ff2,0xd2580086,0x00000000}},	//   örku, htot, рця_,
  { {0xdb0000bd,0x351b0063,0x93b5005e,0x00000000}},	//   _bemü, _יוונ, _убиц,
  { {0xdb002c88,0x7ae200ea,0x41e70500,0x00000000}},	// [4910] _memó, jtot, _кіна,
  { {0xf41f00fe,0x63bd2c89,0x31351d7c,0x00000000}},	//   ljä_, lasn, _геор,
  { {0x8d68000a,0x7ae2001c,0x61f5005b,0x00000000}},	//   ајца_, etot, mezl,
  { {0x69d82c8a,0x3ea90137,0x98710066,0x00000000}},	//   egve, ppat_, _pšč_,
  { {0xee87026c,0xdb00004d,0x7ae200a4,0x00000000}},	//   _выво, _gemü, gtot,
  { {0x69d81262,0xf41f00fe,0x6d59004d,0x00000000}},	//   ggve, hjä_, ßwas,
  { {0x7ae2082a,0x63bd2c8b,0x261a0042,0x00000000}},	//   atot, kasn, बानी_,
  { {0x26cd02dd,0xf1c00066,0x7ae22c8c,0x00000000}},	//   treo_, ľšiu_, btot,
  { {0xf1c00024,0x7afb004b,0xfbd20063,0x00000000}},	//   žšiu_, _usut, _מתן_,
  { {0x26cd048e,0x63bb007a,0xa2ce0053,0x00000000}},	//   rreo_, ðunn, _तिब्,
  { {0xd5491736,0x63bd002b,0x26cd0130,0x00000000}},	//   упне_, fasn, sreo_,
  { {0xd7950021,0x60d5007d,0x63bd2c8d,0x00000000}},	//   _الإخ, duzm, gasn,
  { {0xb8860014,0xf7850021,0xd348005d,0x00000000}},	//   sníð, _الشَ, شیده_,
  { {0x63bd004b,0xe29701f6,0xb3830085,0x00000000}},	//   aasn, сар_, ялял,
  { {0x645d2c8e,0x32430086,0x6587000d,0x00000000}},	//   éric, черг, _тыдз,
  { {0xdb000268,0x7f1a0083,0x00000000,0x00000000}},	//   _memò, лізу_,   ,
  { {0xd0071406,0xdb020058,0xdd960044,0x00000000}},	// [4920] щете_, mboç, مجاع,
  { {0x60c9001c,0xf772009a,0xddde056c,0x00000000}},	//   ņema, לקן_, wopł,
  { {0xfc460080,0xdd8f0044,0x1da70042,0x00000000}},	//   římo_, فوك_, गड़त,
  { {0x7ae2044a,0xfcb50121,0x785300dd,0x00000000}},	//   ttot, ющую, băvi,
  { {0x853c0006,0xa3d90053,0x290704d0,0x00000000}},	//   lbėt, ालत_, evna_,
  { {0x20020009,0xbea3019d,0x7ae22c8f,0x00000000}},	//   _haki_, _харк, rtot,
  { {0xf41f00fe,0x2002053b,0x28cf0161,0x00000000}},	//   yjä_, _kaki_, संगि,
  { {0x6d5700b5,0x20020051,0xdb0000cd,0x00000000}},	//   _הילף_, _jaki_, _demò,
  { {0x63bd00ea,0x501b0063,0x200218d5,0x00000000}},	//   vasn, רופו, _maki_,
  { {0x20022c90,0x26ca00c2,0x63a42c91,0x00000000}},	//   _laki_, čbo_, _afin,
  { {0x63bd00f3,0xe853006a,0xb8960021,0x00000000}},	//   tasn, _کنند, _الصع,
  { {0x4917014e,0xd6da005a,0x2480008b,0x00000000}},	//   _לקבל_, _бтк_, _chim_,
  { {0xb8650021,0x63bd2c92,0x00000000,0x00000000}},	//   _بالو, rasn,   ,
  { {0x7d030026,0x63a42c93,0x63bd2136,0x00000000}},	//   ænsk, _efin, sasn,
  { {0x63a4001f,0x61f5005b,0xdddc143b,0x00000000}},	//   _ffin, rezl, _birž,
  { {0xa0750054,0x85570063,0x6557009a,0x00000000}},	//   ігач, _לשוב_, _לבוא_,
  { {0x200201f7,0x61f50024,0x20070080,0x00000000}},	// [4930] _daki_, pezl, ěni_,
  { {0x290c2c94,0x20070051,0x644f09c7,0x00000000}},	//   _orda_, śni_, lici,
  { {0x6d480078,0x44fa008f,0x2c510022,0x00000000}},	//   _ždar, _jū_, ządu_,
  { {0xfbd004de,0x69c82c95,0x644f03db,0x00000000}},	//   فته_, _adde, nici,
  { {0xcb69005e,0x44fa008f,0x290c2c96,0x00000000}},	//   јале_, _lū_, _arda_,
  { {0x20020089,0x290c007d,0x8cd60053,0x00000000}},	//   _zaki_, _brda_, मूहो,
  { {0xdbf20080,0xa3d90053,0x6f09004c,0x00000000}},	//   _zříz, ाला_, _šech,
  { {0xd8250086,0x2907115b,0x69c80807,0x00000000}},	//   ідпи, rvna_, _edde,
  { {0xba55000a,0x644f1292,0x35d40042,0x00000000}},	//   _двај, dici, _दाख़,
  { {0x0a6b0095,0x63a42c97,0x644f2c98,0x00000000}},	//   _срби_, _sfin, eici,
  { {0x2480001b,0xe5710021,0x63a4220e,0x00000000}},	//   _phim_, بطة_, _pfin,
  { {0x546a0076,0x644f1cac,0xd46a2c99,0x00000000}},	//   рамм_, gici, риме_,
  { {0x3869007d,0x645d2c9a,0xd335000d,0x00000000}},	//   čard_, éria, пэры,
  { {0xdb02017d,0xa5092c9b,0xe611005d,0x00000000}},	//   sboç, _века_, _زشت_,
  { {0x200200bb,0xf41f024a,0x7bc90003,0x00000000}},	//   _paki_, mmän_, _odeu,
  { {0xdbf20080,0xf41f2c9c,0x3e740066,0x00000000}},	//   _příz, lmän_, mäti_,
  { {0x26c200c3,0x9f590268,0x1ea90021,0x00000000}},	// [4940] škov_, _casà_, مالي_,
  { {0x62920024,0x7bc9039f,0x442200c2,0x00000000}},	//   úkoľ, _adeu, ljk_,
  { {0x8236007e,0x66032c9d,0x6835024b,0x00000000}},	//   _هرگا, _mank, _nádo,
  { {0x717b014e,0xf41f00fe,0xd00a2c9e,0x00000000}},	//   _כניס, hmän_, _теме_,
  { {0xda662c9f,0x7bc9001f,0x4422006f,0x00000000}},	//   овди, _ddeu, ijk_,
  { {0x683c0164,0x316d000c,0x644f2ca0,0x00000000}},	//   _méde, şeze_, zici,
  { {0x644f005b,0x2d9802e2,0x2c7c00ed,0x00000000}},	//   yici, _igre_, aída_,
  { {0x66030173,0x2fc000a4,0x644f2ca1,0x00000000}},	//   _aank, naig_, xici,
  { {0x7c220137,0x644f2ca2,0x853c0078,0x00000000}},	//   mjor, vici, ybės,
  { {0x644f0051,0x66032ca3,0x69c82ca4,0x00000000}},	//   wici, _cank, _udde,
  { {0x66032ca5,0x35b3000d,0x853c0078,0x00000000}},	//   _dank, ьбэр, ebėr,
  { {0xd6d90051,0x644f2744,0x7c222ca6,0x00000000}},	//   szła_, uici, njor,
  { {0x683c0003,0x675601fb,0x644f2ca7,0x00000000}},	//   _céde, _بخار, rici,
  { {0x7e040161,0x644f2ca8,0x3869007d,0x00000000}},	//   रयोग_, sici, čare_,
  { {0x644f06d5,0xa1942017,0xe4530044,0x00000000}},	//   pici, дарч, _يضع_,
  { {0x2d980031,0x26c400e3,0x20c5001c,0x00000000}},	//   _agre_, osmo_, rķi_,
  { {0x765a2ca9,0xdd9b05f9,0xc3b80063,0x00000000}},	// [4950] onty, аше_, _ולחץ_,
  { {0x4429001b,0x9f4b006d,0xbe180086,0x00000000}},	//   _hoa_, _sacó_, ожує_,
  { {0x2016034d,0x765a1039,0x7c222caa,0x00000000}},	//   ácií_, inty, fjor,
  { {0x26c40006,0x2c7c0066,0x7c220611,0x00000000}},	//   ksmo_, tída_, gjor,
  { {0xf41f00fe,0xe47c0047,0x7d0e004d,0x00000000}},	//   ymän_, בראכ, _erbs,
  { {0xceb20ca4,0x44292cab,0x7c222cac,0x00000000}},	//   _איך_, _loa_, ajor,
  { {0x26c40016,0x38ca007e,0x66032cad,0x00000000}},	//   esmo_, مايی_, _rank,
  { {0x66032cae,0x9f4000be,0x765a23a8,0x00000000}},	//   _sank, ceió_, enty,
  { {0x66030d68,0x6aa900a5,0x36350044,0x00000000}},	//   _pank, _utef, كردس,
  { {0x645d0003,0x644d2caf,0x7c2924f5,0x00000000}},	//   érin, _amai, _hoer,
  { {0x44290016,0xe9380021,0x7c291f79,0x00000000}},	//   _boa_, _وسمت_, _koer,
  { {0x7c2900e8,0x765a0078,0xf41f01e9,0x00000000}},	//   _joer, anty, smän_,
  { {0x4429053b,0x7c2917df,0x386d2cb0,0x00000000}},	//   _doa_, _moer, moer_,
  { {0x644d2cb1,0x2496006a,0x412a0076,0x00000000}},	//   _emai, _کنيد_, бого_,
  { {0x2175000a,0x3eb9001f,0x7c3b005b,0x00000000}},	//   дутр, _awst_, _olur,
  { {0x44292cb2,0x386d2cb3,0x644d2cb4,0x00000000}},	//   _goa_, noer_, _gmai,
  { {0x2fc009ac,0xe7e30042,0xfd9a0044,0x00000000}},	// [4960] raig_, _गाना_, مئات_,
  { {0x9f4b00ea,0x2fc000cd,0x68ed0022,0x00000000}},	//   ámát_, saig_, łady,
  { {0x6e9303eb,0x7c2200cd,0x7c291999,0x00000000}},	//   رلما, tjor, _boer,
  { {0xd6d90045,0x83360047,0x44290013,0x00000000}},	//   kuł_, ּאַס_, _xoa_,
  { {0x386d2cb5,0x7c2929b3,0x765a2c17,0x00000000}},	//   doer_, _doer, ynty,
  { {0x7c3b0019,0x38a3005b,0x7c222cb6,0x00000000}},	//   _elur, _sıra_, sjor,
  { {0x60c80139,0x7c3b27bb,0x8289009a,0x00000000}},	//   ádmh, _flur, קְנֶ,
  { {0x8d5b014e,0xd6da0086,0x97141939,0x00000000}},	//   _הכלי, бто_, дмиц,
  { {0xafdb00d1,0xf6e30085,0xd6d90022,0x00000000}},	//   _imøt, нцэн, guł_,
  { {0xba290032,0xa5340086,0xdce70051,0x00000000}},	//   _وسلم_, дноч, _wyją,
  { {0x44290035,0x386d2caa,0x645d2cb7,0x00000000}},	//   _poa_, boer_, ério,
  { {0x897b00b5,0x889b0ee1,0x2c7e004c,0x00000000}},	//   _פראצ, _הבאי, _půdy_,
  { {0x288b006a,0x613700ea,0x69dc0137,0x00000000}},	//   _اصلی_, külö, _öres,
  { {0x26c200eb,0x30a7075f,0x60c2056c,0x00000000}},	//   škos_, зрав, _łoma,
  { {0x44292cb8,0xfa770063,0x61141a6b,0x00000000}},	//   _toa_, פעלת_, ндру,
  { {0x656f004d,0x64970023,0x5577009a,0x00000000}},	//   ßche, _eģis, _מעון_,
  { {0x7c292cb9,0xdef10021,0x2c7c0331,0x00000000}},	// [4970] _roer, ضًا_, eído_,
  { {0xb2bc0063,0xd3580063,0x1cd9000d,0x00000000}},	//   _המזר, _משחק_, жджы_,
  { {0x7a2f00d1,0x7c3b1bf7,0x645d2cba,0x00000000}},	//   _møtt, _plur, onsi,
  { {0x98c40080,0x317e004d,0x645d2cbb,0x00000000}},	//   štěn_, ütze_, nnsi,
  { {0x25dd0235,0x386d1a20,0xa3e20161,0x00000000}},	//   _खाली_, voer_, न्ट_,
  { {0x645d004d,0x7a2f00d1,0x7c2910da,0x00000000}},	//   hnsi, _nøtt, _woer,
  { {0xbca5006a,0x2ee90026,0x7c290162,0x00000000}},	//   _آمري, ltaf_, _toer,
  { {0x20092cbc,0x77f90161,0xd6d90051,0x00000000}},	//   ndai_, ्येक_, tuł_,
  { {0x2ee90185,0xd7060076,0xfaf00067,0x00000000}},	//   ntaf_, дные_, _مثل_,
  { {0xd6d90051,0x645d2cbd,0x2009002b,0x00000000}},	//   szło_, ensi, hdai_,
  { {0x69c32cbe,0xb9250021,0x645d0014,0x00000000}},	//   mane, _تفضي, fnsi,
  { {0x628500ea,0x9f400014,0x629701a8,0x00000000}},	//   _ahho, keið_, _aixo,
  { {0x20090185,0x7a2f00d1,0x69c3003b,0x00000000}},	//   ddai_, _føtt, oane,
  { {0xd2950086,0x27ed2cbf,0x200913f5,0x00000000}},	//   ерсь, lfen_, edai_,
  { {0xafe6019d,0x261a0053,0xd00a0062,0x00000000}},	//   мовл, बारी_, оеве_,
  { {0x629703ea,0x69c32cc0,0x6b96005f,0x00000000}},	//   _eixo, hane, žygi,
  { {0x27ed00bd,0xd1380006,0x62972cc1,0x00000000}},	// [4980] ifen_, šą_, _fixo,
  { {0x683c0164,0x568a0047,0x7c2d0137,0x00000000}},	//   _méda, ַטײַ, öarn,
  { {0x61fc0974,0x1115000d,0xafdb06a5,0x00000000}},	//   merl, _зьяў, _blød,
  { {0x61fc2cc2,0xeb9a19f7,0xa3e20042,0x00000000}},	//   lerl, цид_, न्च_,
  { {0xdb000024,0xaa460076,0xfaa30817,0x00000000}},	//   _nemô, медл, вачо,
  { {0x69c32cc3,0x60dc20f7,0x27ed2cc4,0x00000000}},	//   gane, ourm, efen_,
  { {0x99850080,0x61ee00ac,0x7a2f00d1,0x00000000}},	//   _dolů_, ifbl, _røtt,
  { {0x27ed001f,0x683e001c,0xafdb05a5,0x00000000}},	//   gfen_, lūdz, _glød,
  { {0x61fc2cc5,0x69c32cc6,0x683c0003,0x00000000}},	//   kerl, bane, _céda,
  { {0x3869017f,0xdb00017d,0x683c0153,0x00000000}},	//   čara_, _demô, _déda,
  { {0x7bc02cc7,0x61fc2cc8,0x454a0d3b,0x00000000}},	//   _kemu, derl, ючим_,
  { {0xb8650021,0x25b1005b,0x7bc00808,0x00000000}},	//   _كانو, ızla_, _jemu,
  { {0x7bc0014f,0xc2b80086,0x7bdf00cd,0x00000000}},	//   _memu, мляє_, òqui,
  { {0x61fc2cc9,0x7bc02cca,0x764117fa,0x00000000}},	//   gerl, _lemu, chly,
  { {0xe5f70063,0xa2940086,0xf7080013,0x00000000}},	//   _חזור_, тарі, _hủ_,
  { {0x60180086,0x69c32ccb,0x7bc00574,0x00000000}},	//   мося_, zane, _nemu,
  { {0x6aa00150,0x61fc2ccc,0x20092ccd,0x00000000}},	// [4990] _numf, berl, rdai_,
  { {0xab5d0045,0x61fc02dd,0x44392cce,0x00000000}},	//   _jeże, cerl, lks_,
  { {0x7bc000ea,0xbc19000d,0x44392ccf,0x00000000}},	//   _bemu, зілі_, oks_,
  { {0x7bc00089,0x69c32cd0,0xdb0b00cd,0x00000000}},	//   _cemu, wane, dagò,
  { {0xa3e7016a,0x7bc02cd1,0xfb35000d,0x00000000}},	//   _पान_, _demu, эндэ,
  { {0x683c0164,0xdeba0063,0xa2d70053,0x00000000}},	//   _réda, _ממשל, _बिन्,
  { {0x27ed04ab,0xdb0b0027,0x3e7400c7,0x00000000}},	//   tfen_, tagó, rätt_,
  { {0x44390122,0x3e7400c7,0x27ed00bd,0x00000000}},	//   jks_, sätt_, ufen_,
  { {0x27ed050c,0x69c32cd2,0xf7080013,0x00000000}},	//   rfen_, pane, _củ_,
  { {0xe525047e,0x44392cd3,0x7bc02cd4,0x00000000}},	//   едоп, eks_, _zemu,
  { {0x27ed00bd,0xc8c9007e,0xa01b004d,0x00000000}},	//   pfen_, _روشن_, _diöz,
  { {0x29052cd5,0x61e5001f,0x69c12cd6,0x00000000}},	//   _isla_, _achl, _hele,
  { {0x7641002b,0x61fc255c,0x7a3401a8,0x00000000}},	//   phly, terl, _sàti,
  { {0x69c103e8,0x9756014e,0x3ae9008b,0x00000000}},	//   _jele, _אינו_, iúp_,
  { {0x69c12cd7,0x463a0047,0x61fc2cd8,0x00000000}},	//   _mele, _מעסע, rerl,
  { {0x44391dc0,0x61fc2cd9,0x2ff8007e,0x00000000}},	//   cks_, serl, بورگ_,
  { {0x2e360026,0x68352cda,0x69c100ca,0x00000000}},	// [49a0] _hæfi_, _cádi, _oele,
  { {0x7bc00e53,0x9f40016d,0x2d9c0831,0x00000000}},	//   _semu, lgië_, øve_,
  { {0x7bc00974,0x163600b5,0x71bb0063,0x00000000}},	//   _pemu, ענער_, _מציג,
  { {0x69c12cdb,0x3a3e0150,0x8ac60330,0x00000000}},	//   _aele, _sltp_, ейдж,
  { {0x2905005b,0x69c12cdc,0x4dd60054,0x00000000}},	//   _asla_, _bele, _півф,
  { {0x5eeb0063,0x3e74004d,0xfce6046a,0x00000000}},	//   _מַלְ, räts_, _пого,
  { {0x7bc0014f,0x69c12cdd,0x44392cde,0x00000000}},	//   _temu, _dele, yks_,
  { {0xc7c60121,0x57181406,0x17fa0044,0x00000000}},	//   хски, джия_, سرعة_,
  { {0x69c12cdf,0x8c430076,0x78a100ac,0x00000000}},	//   _fele, _сете, _eulv,
  { {0x6e2e1e5c,0x60c9001c,0x78a10d2e,0x00000000}},	//   _jobb, ņemi, _fulv,
  { {0x3ea22ce0,0x78a101f2,0xdb0b0014,0x00000000}},	//   _lukt_, _gulv, lagð,
  { {0x61e50199,0x628e2ce1,0xf7080013,0x00000000}},	//   _schl, embo, _tủ_,
  { {0xa3e70161,0x27e60127,0x44392ce2,0x00000000}},	//   _पाठ_, _icon_, rks_,
  { {0x171b01d8,0x96060021,0xf204000d,0x00000000}},	//   _מודע, _سبتم, лясо,
  { {0x31680141,0x54e600de,0x00000000,0x00000000}},	//   ешто_, _أستق,   ,
  { {0x4ea70928,0xaf34006a,0x628e2ce3,0x00000000}},	//   ержа, گرفت, ambo,
  { {0x63ad0e1c,0x63bb0026,0x6e2e1014,0x00000000}},	// [49b0] _ifan, ðunu, _bobb,
  { {0x6e2e08d2,0xa3d90053,0x92952c0b,0x00000000}},	//   _cobb, ालक_, _шапц,
  { {0xf65300b5,0xad670021,0x6e2e2ce4,0x00000000}},	//   נצע_, رائه, _dobb,
  { {0x44ea051e,0x69c12ce5,0x3ae90066,0x00000000}},	//   iù_, _sele, túp_,
  { {0x63ad0009,0x09e505fb,0x44ea0013,0x00000000}},	//   _mfan, волн, hù_,
  { {0x533800b5,0x660a0360,0x6e2e0d2e,0x00000000}},	//   ענגן_, _nafk, _gobb,
  { {0x63ad2ce6,0xecf82049,0x02180063,0x00000000}},	//   _ofan, _перш_, תחום_,
  { {0x683c0003,0x2489008d,0x69c12ce7,0x00000000}},	//   _dédo, _nham_, _wele,
  { {0xdcfc001c,0x26cb0003,0xfae0004c,0x00000000}},	//   _izrā, éco_, íště_,
  { {0x63ad2ce8,0x69c10035,0x9985003b,0x00000000}},	//   _afan, _uele, _colţ_,
  { {0xd46a0138,0x04460055,0x9f490025,0x00000000}},	//   дине_, венн, dfaí_,
  { {0x200b007d,0x24892ce9,0x387a005d,0x00000000}},	//   _naci_, _cham_, _قشنگ_,
  { {0x9f400229,0x6605237c,0x44630062,0x00000000}},	//   rgië_, _апла, рвяв,
  { {0x2d9c034d,0x7a3d0994,0x44ea0290,0x00000000}},	//   ľvek_, _mèto, bù_,
  { {0x63ad001f,0x90c30121,0x200b2cea,0x00000000}},	//   _ffan, ибре, _baci_,
  { {0xdfd20021,0x200b0950,0x6389005f,0x00000000}},	//   شيط_, _caci_, _sūnū,
  { {0xaf060062,0x200b00dd,0x6da62ceb,0x00000000}},	// [49c0] ъпал, _daci_, виза,
  { {0x4f950054,0x6d960044,0x00000000,0x00000000}},	//   урсу, نشائ,   ,
  { {0x200b11fb,0x515a0085,0x61462338,0x00000000}},	//   _faci_, _ішоў_, _рена,
  { {0x69c50026,0x7f860044,0x6e2e1dfa,0x00000000}},	//   ðhen, _للجن, _wobb,
  { {0x2000003b,0x63a90078,0x7c65002a,0x00000000}},	//   meii_, ženg, دالل,
  { {0x683c0003,0x9cb60021,0xd91a0121,0x00000000}},	//   _pédo, _لمست, дьи_,
  { {0x98c30088,0x63a10051,0x1866005e,0x00000000}},	//   асыл, ślni, књиг,
  { {0x200000dd,0x8d4b009a,0xfc1a00de,0x00000000}},	//   neii_, _חֲמֵ, _تقرب_,
  { {0x6d67000c,0xc0530063,0x6f042493,0x00000000}},	//   ăraţ, יזה_, nwic,
  { {0x14ca0076,0x44ea0290,0x2489113c,0x00000000}},	//   мыми_, tù_, _sham_,
  { {0x7bcd0026,0xd5b8001c,0xde150047,0x00000000}},	//   ðaug, rbā_, אַרץ_,
  { {0x2ee000e8,0x97a30131,0x5fe10042,0x00000000}},	//   kuif_, _кршл, _फाइल,
  { {0x86460062,0x200000dd,0xa30d0042,0x00000000}},	//   _индж, deii_, िटेज_,
  { {0x7df30080,0x22840137,0x6f042cec,0x00000000}},	//   _měsí, töka_, dwic,
  { {0x2489001b,0xdfd5026c,0x6f042ced,0x00000000}},	//   _tham_, ловы, ewic,
  { {0x44ce0045,0x63ad2cee,0xab5d0022,0x00000000}},	//   mę_, _ufan, _leża,
  { {0x228400c7,0x0f15000d,0x44ce232c,0x00000000}},	// [49d0] söka_, ымаю, lę_,
  { {0xf1b70053,0x9f040021,0x7a3d00cd,0x00000000}},	//   _अभिन, ؤولو, _rèto,
  { {0x44ce0c48,0x3cd5042c,0x72340021,0x00000000}},	//   nę_, ужес, _خريط,
  { {0x44ce0045,0x2919004c,0xfbd00021,0x00000000}},	//   ię_, _čsa_, قته_,
  { {0x38a30075,0x2d0c0082,0x9aa400de,0x00000000}},	//   _zırh_, सटॉल_, لمنو,
  { {0x2fc9016d,0x44ce1748,0x3e6f1093,0x00000000}},	//   laag_, kę_, hütz_,
  { {0x27ff021f,0xe8f50021,0xdcf6003b,0x00000000}},	//   teun_, استخ, ăcăn,
  { {0xdcfc001c,0xd7092cef,0x2258004d,0x00000000}},	//   _uzrā, ение_, zirk_,
  { {0xab940054,0x27ff003b,0xe5a5079b,0x00000000}},	//   _виті, reun_, липи,
  { {0x9a872125,0x200000dd,0x98a70022,0x00000000}},	//   _рубл, zeii_, zynę_,
  { {0x22580026,0x44ce1748,0x6f040c57,0x00000000}},	//   virk_, gę_, zwic,
  { {0xc209014e,0xb8090021,0x683500be,0x00000000}},	//   _מה_, _سيتم_, _pádu,
  { {0xe355000d,0x2fc905e9,0x387f0014,0x00000000}},	//   атрэ, daag_, mlur_,
  { {0x387f0026,0x8644000d,0x44ce0051,0x00000000}},	//   llur_, _кніж, bę_,
  { {0x660114f2,0x44ce0051,0x213e0025,0x00000000}},	//   melk, cę_, áth_,
  { {0x6f040199,0x0495000d,0x320c0114,0x00000000}},	//   twic, _крыў, ždy_,
  { {0x4420014f,0x644400a4,0x26cd0025,0x00000000}},	// [49e0] _ini_, _ilii, nseo_,
  { {0x443202dd,0x69c50026,0x7e7e006f,0x00000000}},	//   _hoy_, ðhel, ulpp,
  { {0x6d410019,0x63a903f5,0x3f860024,0x00000000}},	//   _ülal, žene, ťou_,
  { {0xf76704de,0x44322cf0,0x0b460432,0x00000000}},	//   _ها_, _joy_, лнен,
  { {0x60c9003d,0xa09b00b5,0xa3e70053,0x00000000}},	//   ņemt, _ריכט, _पास_,
  { {0xf41f00fe,0x387f0026,0xe2a70014,0x00000000}},	//   lmät_, elur_, ýðir_,
  { {0x66012cf1,0x44202cf2,0x387f0014,0x00000000}},	//   delk, _oni_, flur_,
  { {0x387f007a,0xc6f825f7,0x6601006f,0x00000000}},	//   glur_, вних_, eelk,
  { {0x44ce0051,0xab6602e4,0xcb670854,0x00000000}},	//   wę_, _свал, _бате_,
  { {0xf41f00fe,0x26f70754,0x629e2cf3,0x00000000}},	//   hmät_, اريخ_, _nipo,
  { {0x44202cf4,0x44322cf5,0x69ca2cf6,0x00000000}},	//   _bni_, _boy_, mafe,
  { {0x4395042c,0xc94b0063,0x07a60002,0x00000000}},	//   ианс, _אֲדֹ, _садн,
  { {0x7ae20006,0x4432006d,0x44ce232c,0x00000000}},	//   nuot, _doy_, sę_,
  { {0xe2980088,0x44ce0c48,0x44202cf7,0x00000000}},	//   лаў_, pę_, _eni_,
  { {0x629e0e4f,0x44321932,0x765a2cf8,0x00000000}},	//   _dipo, _foy_, mity,
  { {0x7ae200eb,0x44200290,0x765a2931,0x00000000}},	//   kuot, _gni_, lity,
  { {0x7ae20006,0xcddb041d,0x2fc90162,0x00000000}},	// [49f0] juot, ење_, raag_,
  { {0x7ae20006,0x59e00053,0x7055007e,0x00000000}},	//   duot, _नागर, _چندا,
  { {0x44320150,0x7afb2cf9,0x2d870a3f,0x00000000}},	//   _yoy_, _sput, åne_,
  { {0x60c9003d,0x765a00fe,0x66010051,0x00000000}},	//   ņems, hity, zelk,
  { {0x7ae200eb,0x34c10161,0x998c0080,0x00000000}},	//   guot, _शब्द, _bodů_,
  { {0x08d52ab5,0x50b8006a,0x7a3400cd,0x00000000}},	//   ация, _جدید_, _sàtr,
  { {0x7a3400cd,0x38ca007e,0x66012cfa,0x00000000}},	//   _pàtr, نايی_, velk,
  { {0x66010717,0x7ae20078,0x76480072,0x00000000}},	//   welk, buot, ehdy,
  { {0x7afb017f,0x442000c2,0x26cd2cfb,0x00000000}},	//   _uput, _rni_, useo_,
  { {0x387f007a,0xe6160076,0x44322cfc,0x00000000}},	//   slur_, адь_, _soy_,
  { {0xdb02007a,0x629e2cfd,0xf41f00fe,0x00000000}},	//   lboð, _ripo, ymät_,
  { {0x2aab0146,0xd756006a,0x7bcb2cfe,0x00000000}},	//   _køb_, الیت_, nagu,
  { {0x44322cff,0xa3e70053,0x68e32d00,0x00000000}},	//   _voy_, _पार_, lund,
  { {0x7bcb0009,0x44200150,0xf6b20021,0x00000000}},	//   hagu, _wni_, _بموج,
  { {0x442000f3,0x7ae200eb,0x645d0268,0x00000000}},	//   _tni_, zuot, èric,
  { {0x7bcb0009,0x645d1db1,0x44202d01,0x00000000}},	//   jagu, érit, _uni_,
  { {0x68e3069e,0x7bcb2d02,0x63a4002c,0x00000000}},	// [4a00] hund, dagu, _igin,
  { {0x68e32d03,0x7e230001,0x7ae213d0,0x00000000}},	//   kund, одуж, vuot,
  { {0x68e30019,0x7bcb2d04,0x8c960086,0x00000000}},	//   jund, fagu, арді,
  { {0xf09f2d05,0x7ae213d0,0xdee605f1,0x00000000}},	//   _già_, tuot, _коми,
  { {0x6b890051,0x69ca2d06,0x76480072,0x00000000}},	//   _czeg, tafe, yhdy,
  { {0x7ae200eb,0xc5f8001c,0xaa530500,0x00000000}},	//   ruot, tnēm_, овіш,
  { {0x765a024a,0x7ae20006,0x7bcb2a43,0x00000000}},	//   vity, suot, bagu,
  { {0xd7fa0905,0x7ae20006,0xa2d70053,0x00000000}},	//   тук_, puot, _बिल्,
  { {0x68350025,0x765a0bb7,0x09e62d07,0x00000000}},	//   _pádr, tity, _возн,
  { {0x683c2d08,0x7e620003,0xd838007d,0x00000000}},	//   _médi, éoph, _muči_,
  { {0x2442048e,0x69c81918,0x765a2d09,0x00000000}},	//   _cómo_, _iede, rity,
  { {0x765a024a,0x69c82d0a,0x290c08f2,0x00000000}},	//   sity, _hede, _isda_,
  { {0x69c8014f,0x5c970047,0xa5f8005e,0x00000000}},	//   _kede, יכטע_, _белу_,
  { {0x22450026,0x63a42d0b,0x69c82d0c,0x00000000}},	//   ólk_, _egin, _jede,
  { {0x645d0164,0x7bcb00ae,0xd838007d,0x00000000}},	//   éris, yagu, _auči_,
  { {0x69c82d0d,0x39110041,0x759b0063,0x00000000}},	//   _lede, נטאַר, _בסוג,
  { {0x9df906da,0xfda7005e,0x645d2d0e,0x00000000}},	// [4a10] лнат_, ајем, misi,
  { {0x3869017f,0x74bd0161,0x683c0164,0x00000000}},	//   čari_, वीकृ, _dédi,
  { {0x7bcb2d0f,0x6b892d10,0x645d2d11,0x00000000}},	//   tagu, _szeg, oisi,
  { {0x68e32d12,0x645d2d13,0x69c82d14,0x00000000}},	//   vund, nisi, _aede,
  { {0x68e300bd,0x69c82d15,0x645d078c,0x00000000}},	//   wund, _bede, iisi,
  { {0x7bcb002c,0x645d1668,0x69c82d16,0x00000000}},	//   sagu, hisi, _cede,
  { {0x9915000d,0x7bcb2d17,0x69c82d18,0x00000000}},	//   сьлі, pagu, _dede,
  { {0xccf20063,0x645d005b,0x69c8056f,0x00000000}},	//   _מכל_, jisi, _eede,
  { {0x68e32d19,0x86990002,0x645d1744,0x00000000}},	//   sund, лтот_, disi,
  { {0x69c82d1a,0x68e32d1b,0x645d2d1c,0x00000000}},	//   _gede, pund, eisi,
  { {0x3915007e,0xda7a0047,0x645d2d1d,0x00000000}},	//   _دواز, _ענער, fisi,
  { {0x6aa10199,0x69c80103,0x8c3d1c8a,0x00000000}},	//   _hilf, _zede, _fişe,
  { {0xd8740032,0x69e4000c,0x69c8005b,0x00000000}},	//   _بالب, şteţ, _yede,
  { {0xe5a5011c,0x683c0164,0xdb02017d,0x00000000}},	//   _уики, _rédi, scoç,
  { {0x645d1a61,0x683c0003,0x64b3003b,0x00000000}},	//   bisi, _sédi, _băie,
  { {0x683c0003,0x6f160066,0x63a42d1e,0x00000000}},	//   _pédi, tvyc, _ugin,
  { {0xef1a000d,0x44f12d1f,0x76412d20,0x00000000}},	// [4a20] ыма_, lá_, okly,
  { {0x2d960121,0x44f10013,0xee372d21,0x00000000}},	//   брес, oá_, бну_,
  { {0x44f12d22,0x9f59006d,0x69c82d23,0x00000000}},	//   ná_, _basó_, _rede,
  { {0x9f59006d,0x44f1008b,0x6aa1002b,0x00000000}},	//   _casó_, iá_, _ailf,
  { {0x7ff7007e,0x69c82d24,0xda340121,0x00000000}},	//   _اسپا, _pede, желы,
  { {0x645d2531,0x6e35007d,0x2918013d,0x00000000}},	//   zisi, _gozb, _árak_,
  { {0x44f10026,0x61ea0026,0x69c82d25,0x00000000}},	//   já_, _öflu, _vede,
  { {0x768f00d1,0x764100ac,0xc879003b,0x00000000}},	//   høyd, ekly, goş_,
  { {0x2ee0001f,0x69c82d26,0x2fc000a4,0x00000000}},	//   nrif_, _tede, ibig_,
  { {0x645d0185,0x7bc92d27,0x69c8006d,0x00000000}},	//   wisi, _zeeu, _uede,
  { {0x99860032,0x44f1017d,0xd7fa0a3d,0x00000000}},	//   _الاو, gá_, _бул_,
  { {0x3d000053,0x2ee02d28,0x66e62d29,0x00000000}},	//   _रहने_, krif_, _года,
  { {0x645d2d2a,0xd7960032,0xde6d008b,0x00000000}},	//   ériq, _الشخ, hươn,
  { {0x2fc0004d,0x645d2d2b,0x2ee00046,0x00000000}},	//   ebig_, sisi, drif_,
  { {0x365b014e,0x44f1039f,0xd25801dd,0x00000000}},	//   _תכונ, cá_, сця_,
  { {0x2ee00185,0xdbf10080,0x8c3d000c,0x00000000}},	//   frif_, _přík, _mişc,
  { {0xbda70021,0x2ee0001f,0x40340121,0x00000000}},	// [4a30] محاو, grif_, четс,
  { {0xe45f0072,0x78a2006c,0xdd040042,0x00000000}},	//   liö_, _liov, रबंध_,
  { {0x9f5902dd,0x11f8007e,0x2ee00cc6,0x00000000}},	//   _pasó_, _اوپک_, arif_,
  { {0xa01b0137,0x91a60013,0x7cdc003b,0x00000000}},	//   _ehör, _đỏ_, dără,
  { {0x79810185,0x44f10e7c,0xa3e70053,0x00000000}},	//   _sylw, zá_, _पाई_,
  { {0x6ca72ab5,0x656f003b,0x683c0b6c,0x00000000}},	//   _граж, şchi, _médu,
  { {0x44f1017d,0x768f00d1,0xc879003b,0x00000000}},	//   xá_, nøye, toş_,
  { {0x44f10512,0xeaf8006a,0x26df006d,0x00000000}},	//   vá_, _گرفت_, truo_,
  { {0x6aa12d2c,0xf3ff00be,0x7981002b,0x00000000}},	//   _tilf, enão_, _wylw,
  { {0x8f9c0047,0x959927b5,0x44f12d2d,0x00000000}},	//   ניזי, итну_, tá_,
  { {0x44f1008b,0xdddc008f,0xad27012c,0x00000000}},	//   uá_, _skrū, ивiс,
  { {0x78a22d2e,0x6f1d10bd,0xd4560054,0x00000000}},	//   _giov, _orsc, ітнь,
  { {0x68420088,0x683c2d2f,0xd6292d30,0x00000000}},	//   _інша, _cédu, _воле_,
  { {0x683c0003,0x15ab0062,0x3869007d,0x00000000}},	//   _dédu, _съди_, čaru_,
  { {0x768f00d1,0xc05a005e,0x2284013d,0x00000000}},	//   gøye, арац_, nöki_,
  { {0x44d5003d,0xa3e70053,0xe3b20242,0x00000000}},	//   mā_, _पाए_, _غرب_,
  { {0x44d5001c,0x44c700ea,0xceea000d,0x00000000}},	// [4a40] lā_, lő_, рдзе_,
  { {0x9f4000cd,0x3eab00e5,0x7bcd0046,0x00000000}},	//   rgià_, _duct_, ðaun,
  { {0x6f1d0199,0x44d5003d,0xb60500c2,0x00000000}},	//   _ersc, nā_, _iršč,
  { {0x984c0080,0xb4fa0047,0xde6d0013,0x00000000}},	//   věď_, ילער, rươn,
  { {0xb60500c3,0x3f820058,0x00000000,0x00000000}},	//   _kršč, _uyku_,   ,
  { {0x44d5003d,0x5b130088,0x7cdc003b,0x00000000}},	//   kā_, ьміт, tără,
  { {0x44d5003d,0xbea3000d,0x78a20290,0x00000000}},	//   jā_, _царк, _piov,
  { {0x44d5003d,0x4734018e,0x44c700ea,0x00000000}},	//   dā_, знис, dő_,
  { {0xf0932d31,0x7bc22d32,0x466a21d3,0x00000000}},	//   ונה_, mbou, иром_,
  { {0x683c0164,0x7cdc000c,0x7bc22166,0x00000000}},	//   _rédu, pără, lbou,
  { {0x44d5001c,0x683c0003,0xe45f00fe,0x00000000}},	//   gā_, _sédu, tiö_,
  { {0xf3ff017d,0x7ae22d33,0x7bc22d34,0x00000000}},	//   rnão_, orot, nbou,
  { {0xfbd3014e,0x63a9147d,0xe60f007e,0x00000000}},	//   ותר_, ženo, رشی_,
  { {0x768f0031,0x2480005b,0x44d5001c,0x00000000}},	//   tøye, _ekim_, bā_,
  { {0x63b6001f,0xa2d70053,0x7ae22d35,0x00000000}},	//   _ffyn, _बिक्, hrot,
  { {0x768f00d1,0x7ae22d36,0x66081089,0x00000000}},	//   røye, krot, ledk,
  { {0xddab026b,0x768f00d1,0x6608006f,0x00000000}},	// [4a50] ател_, søye, oedk,
  { {0x9e150088,0x291e005b,0xb60500c2,0x00000000}},	//   ядзі, _orta_, _gršč,
  { {0x6287017f,0x7ae22789,0x9fbf0445,0x00000000}},	//   mljo, erot, lčík_,
  { {0x7bc2006f,0x69da01a8,0xd251005d,0x00000000}},	//   gbou, _adte, _آنگ_,
  { {0x44c7000f,0x7ae22d37,0x291e2d38,0x00000000}},	//   ző_, grot, _arta_,
  { {0x3ea3006f,0xfc7d004c,0x7f3a0063,0x00000000}},	//   _uijt_, _žádá_, _העשו,
  { {0x9f400026,0xa3eb0053,0x291e007d,0x00000000}},	//   lfið_, मला_, _crta_,
  { {0x7ae22d39,0x3d000053,0x44c700ea,0x00000000}},	//   brot, _रहते_, vő_,
  { {0x78ba0031,0x6f0d030c,0xa91c0066,0x00000000}},	//   _ettv, nwac, _vyľa,
  { {0x248000e3,0x44c7000f,0x44d5003d,0x00000000}},	//   _skim_, tő_, tā_,
  { {0x69c300c3,0x6f0d00bd,0x64b3003b,0x00000000}},	//   mbne, hwac, _băia,
  { {0x44d5003d,0x78fa0063,0x764a002b,0x00000000}},	//   rā_, _לפעו, _elfy,
  { {0x934303d6,0x44d5001c,0x38b10014,0x00000000}},	//   еняе, sā_, _hár_,
  { {0x44d5001c,0x76ba0063,0x201e003b,0x00000000}},	//   pā_, _המספ, _şti_,
  { {0x27ed15a4,0xdb0c0014,0x38b1013d,0x00000000}},	//   ogen_, _áhöl, _jár_,
  { {0x2167000a,0x38b119af,0x644f0051,0x00000000}},	//   чиси_, _már_, chci,
  { {0x38b10027,0x2bcf0053,0x27ed05df,0x00000000}},	// [4a60] _lár_, _हज़ा, igen_,
  { {0x644600fe,0xf8ab0013,0xee370a8f,0x00000000}},	//   lkki, _ưới_, пну_,
  { {0x38b10027,0x7ae20051,0x6f0d0035,0x00000000}},	//   _nár_, wrot, awac,
  { {0x6446024a,0x27ed0122,0xeb9a1a5c,0x00000000}},	//   nkki, jgen_, бие_,
  { {0x7bc20c2e,0x64462d3a,0x68e300a6,0x00000000}},	//   rbou, ikki, ernd,
  { {0x61ee00e8,0x82d70047,0x27ed05df,0x00000000}},	//   ngbl, לונג_, egen_,
  { {0x7e7e00d1,0x7bc2006f,0x66082d3b,0x00000000}},	//   mopp, pbou, vedk,
  { {0x98a30001,0x38b10025,0x7e7e2d3c,0x00000000}},	//   није, _dár_, lopp,
  { {0x660800b9,0x69c3013d,0xab5d0022,0x00000000}},	//   tedk, bbne, _odży,
  { {0x7e7e2d3d,0x0f570063,0xf4d80002,0x00000000}},	//   nopp, פיים_, омош_,
  { {0x66081c0d,0x320a102b,0x64b300dd,0x00000000}},	//   redk, deby_, _păia,
  { {0x6f0d0022,0x7e7e2d3e,0xd6d90022,0x00000000}},	//   ywac, hopp, syła_,
  { {0x7e7e029a,0xafdb05e7,0x22b8011b,0x00000000}},	//   kopp, _kløv, věký_,
  { {0x64462d3f,0x56b700ff,0x22840014,0x00000000}},	//   akki, _צפון_, köku_,
  { {0x7e7e2d40,0x64b3003b,0xc5fb0063,0x00000000}},	//   dopp, _tăia, _הפוט,
  { {0xd4680138,0x11f7007e,0x30340121,0x00000000}},	//   _није_, _کودک_, несё,
  { {0x4429299e,0x7a3d02a5,0xc0580054,0x00000000}},	// [4a70] _ina_, _mètr, чір_,
  { {0x9f400026,0x7e7e00d1,0x6f0d2d41,0x00000000}},	//   rfið_, gopp, rwac,
  { {0x644d1d56,0x6abb0359,0x317e004d,0x00000000}},	//   _klai, _stuf, ützt_,
  { {0x26d9000f,0x4429007d,0x60d60063,0x00000000}},	//   ások_, _jna_, _קורא_,
  { {0xe46a00fe,0x7e7e00d1,0xc9a90121,0x00000000}},	//   ltöä_, bopp, овле_,
  { {0x644d001f,0x7e7e0290,0x443b0089,0x00000000}},	//   _llai, copp, _loq_,
  { {0x6446007a,0x27ed2d42,0xdbc70026,0x00000000}},	//   ykki, tgen_, _föðu,
  { {0x63a90add,0x320a0051,0xccf20063,0x00000000}},	//   ženj, zeby_, _שכן_,
  { {0x6abb0035,0x27ed2d43,0x5fc00053,0x00000000}},	//   _utuf, rgen_, ौरतल,
  { {0x7c3b0034,0x06960021,0x44292d44,0x00000000}},	//   _hour, ونية_, _ana_,
  { {0x240a0905,0xe5a50002,0x7de8013d,0x00000000}},	//   онни_, ќини, lésü,
  { {0x7c3b04bc,0x7ae42d45,0x33201672,0x00000000}},	//   _jour, šite, _prix_,
  { {0x6446024a,0xf1060161,0x386d1de0,0x00000000}},	//   rkki, शब्द_, mner_,
  { {0x387f0c69,0x64460019,0x44292d46,0x00000000}},	//   lour_, skki, _ena_,
  { {0x320a2d47,0x386d2d48,0x703a0086,0x00000000}},	//   reby_, oner_, очас_,
  { {0x387f0034,0x7c3b2d49,0x33202d4a,0x00000000}},	//   nour_, _nour, _trix_,
  { {0xdbc70026,0x7e7e2d4b,0x386d1152,0x00000000}},	// [4a80] _röðu, topp, iner_,
  { {0x7aeb002c,0x6e93007e,0x22840026,0x00000000}},	//   dugt, پلما, töku_,
  { {0x44290185,0x7c3b2d4c,0x7e7e2d4d,0x00000000}},	//   _yna_, _bour, ropp,
  { {0x7e7e2d4e,0x7c3b04bc,0x387f0003,0x00000000}},	//   sopp, _cour, jour_,
  { {0x7c3b12aa,0x6e4900ea,0x387f2002,0x00000000}},	//   _dour, ásbó, dour_,
  { {0x386d2d4f,0xf6470021,0xaa570044,0x00000000}},	//   ener_, _شئ_, ولنا_,
  { {0x7c3b04bc,0x386d2357,0x387f2d50,0x00000000}},	//   _four, fner_, four_,
  { {0xd6da2a4b,0x386d16a2,0xd7e60086,0x00000000}},	//   ото_, gner_, фіко,
  { {0x6e3c262d,0x63a92d51,0x44292d52,0x00000000}},	//   _korb, ženk, _rna_,
  { {0x44290027,0x386d2d53,0xa5340121,0x00000000}},	//   _sna_, aner_, еноч,
  { {0x387f2d54,0x6e3c24ae,0x24190121,0x00000000}},	//   bour_, _morb, поны_,
  { {0xc5f8001c,0x97c3000d,0x387f2d55,0x00000000}},	//   tnēs_, _айце, cour_,
  { {0x1b7b00b5,0x6e3c0162,0x5b7b0047,0x00000000}},	//   ַטלע, _oorb, ַרלא,
  { {0x4429001f,0xe46a0072,0x6e3c05fe,0x00000000}},	//   _wna_, ttöä_, _norb,
  { {0x7de8013d,0x6aa82d56,0x30a72d57,0x00000000}},	//   zésü, _midf, драв,
  { {0x44292d58,0x44f82d59,0x3cf20053,0x00000000}},	//   _una_, mé_, ँढने_,
  { {0x7c3b2d5a,0x6e3c2d5b,0xe46a0072,0x00000000}},	// [4a90] _rour, _borb, stöä_,
  { {0xb6a500aa,0x7c3b04bc,0xed8b0095,0x00000000}},	//   _nhậ, _sour, осек_,
  { {0x2d870146,0x7c3b04bc,0xafdb00d1,0x00000000}},	//   æne_, _pour, _bløt,
  { {0x7c94006a,0x22840137,0x7de800ea,0x00000000}},	//   نشنا, sökt_, tésü,
  { {0xfbd0006a,0x6e3c2d5c,0x386d01f2,0x00000000}},	//   شتن_, _forb, vner_,
  { {0xb6a5008b,0x661800c2,0x44f82d5d,0x00000000}},	//   _chậ, _navk, ké_,
  { {0x387f03b2,0x7c3b04bc,0x7988001f,0x00000000}},	//   tour_, _tour, _cydw,
  { {0x67220117,0xbca50032,0x7c2900bd,0x00000000}},	//   _broj, _أمري, _uner,
  { {0xd7060121,0x6d450f67,0xb6a50121,0x00000000}},	//   еные_, lyha, ниил,
  { {0x20192d5e,0x386d2d5f,0x7af4056c,0x00000000}},	//   _lasi_, sner_, żetó,
  { {0x661800c3,0x44f80164,0x7988001f,0x00000000}},	//   _davk, gé_, _gydw,
  { {0xa01b2d60,0x20192d61,0xdd0c0022,0x00000000}},	//   _skön, _nasi_, _róża,
  { {0x63ad00b9,0x67220078,0xadf00042,0x00000000}},	//   _dgan, _groj, _चालन_,
  { {0xe60500fe,0x27ff0014,0x44f82d62,0x00000000}},	//   ärää, lfun_, bé_,
  { {0x50960001,0x7d020045,0x44f827d9,0x00000000}},	//   ерађ, łosz, cé_,
  { {0x20191151,0x9873001c,0x6e3c2d63,0x00000000}},	//   _casi_, mžēl_, _sorb,
  { {0x64960025,0xceea000d,0x2cbf007d,0x00000000}},	// [4aa0] ráid, ядае_, _čuda_,
  { {0x64960025,0x2019004b,0x66e20082,0x00000000}},	//   sáid, _easi_, _खिसक_,
  { {0x2019051e,0x6e3c2d64,0x228400a5,0x00000000}},	//   _fasi_, _vorb, söks_,
  { {0xeb9a06be,0x6aa80137,0x2019001a,0x00000000}},	//   пие_, _sidf, _gasi_,
  { {0x205700b5,0x76480006,0xb6a5008b,0x00000000}},	//   _טיטל_, ykdy, _phậ,
  { {0x44f80164,0xf2d32648,0xb866007e,0x00000000}},	//   yé_, רעג_, کاتو,
  { {0x768f00d1,0xa9340363,0x7ea90078,0x00000000}},	//   tøyn, тейш, _užpa,
  { {0x44f82d65,0xb601006d,0x63a90648,0x00000000}},	//   vé_, ñánd, ženi,
  { {0xd5bd0161,0xb6a5008b,0xe6662d66,0x00000000}},	//   ोरंज, _thậ, етно,
  { {0x44f82d67,0x63ad2d68,0x7988002b,0x00000000}},	//   té_, _sgan, _tydw,
  { {0x44f82d69,0x7865005f,0x4733005d,0x00000000}},	//   ué_, sųva, نریز,
  { {0xe73a0076,0x44f82d65,0xe7ea0042,0x00000000}},	//   _нее_, ré_, _टाटा_,
  { {0x44f80164,0x91a6001b,0x0614000d,0x00000000}},	//   sé_, _đó_, _адлю,
  { {0x661804aa,0x44f82d6a,0xc7a30062,0x00000000}},	//   _uavk, pé_, _сичк,
  { {0xdfd508a6,0x361b0063,0x9f490025,0x00000000}},	//   ковы, _מוגד, rgaí_,
  { {0x63ad2d6b,0x8c3d0058,0x44ce0078,0x00000000}},	//   _ugan, _pişm, mř_,
  { {0x20192d6c,0xa022004b,0xafdb04aa,0x00000000}},	// [4ab0] _vasi_, ööan, _sløs,
  { {0x443900c7,0xdd9b1138,0x7ee400de,0x00000000}},	//   ljs_, пше_, اكلن,
  { {0x2476001c,0x24420014,0xbc19071f,0x00000000}},	//   lāma_, _tómt_, ділі_,
  { {0x44390137,0x2d8a05b9,0xd6d90022,0x00000000}},	//   njs_, _dybe_, ysł_,
  { {0x7de70086,0x2fc92d6d,0xafdb00d1,0x00000000}},	//   _півд, mbag_, _flør,
  { {0x3eaa0199,0xd2b80063,0x09e20002,0x00000000}},	//   _gibt_, עלות_, аошн,
  { {0x6d430137,0xafdb0093,0xdd9402dc,0x00000000}},	//   änad, _uløs, _бары,
  { {0x63a10022,0x38580121,0x24760023,0x00000000}},	//   ślny, ерью_, kāma_,
  { {0x39490418,0x7c24008f,0xc2210042,0x00000000}},	//   ņas_, ķirt, मयाब_,
  { {0xa01b0137,0x9f4001f4,0x77820e82,0x00000000}},	//   _sköl, ggiù_, рльз,
  { {0x57f5286c,0x4d8c009a,0x00000000,0x00000000}},	//   _апет, ּאכַ,   ,
  { {0xb9360047,0x99640503,0x3cf20042,0x00000000}},	//   _ברעג_, _стул, ँढते_,
  { {0xae020053,0xdc360041,0x8c420058,0x00000000}},	//   र्डन_, דארט_, _öğed,
  { {0xdddc007c,0x2ee9002b,0x9756009a,0x00000000}},	//   _okrš, draf_, _בינו_,
  { {0xd1790054,0x0163212b,0x867a009d,0x00000000}},	//   есті_, акро, _קרצו,
  { {0xafdb05b9,0x78bc013d,0xd2590023,0x00000000}},	//   _slør, _érve, īņa_,
  { {0xdfcf002a,0x2ee92d6e,0x0eaa0085,0x00000000}},	// [4ac0] زيل_, graf_, дкай_,
  { {0x645d008f,0x39470014,0xc333089e,0x00000000}},	//   īrie, kyns_, _כוח_,
  { {0x2ee92d6f,0x30860021,0xa3e60042,0x00000000}},	//   araf_, _للدف, _पया_,
  { {0xd6d90051,0x0b460454,0xee3f0013,0x00000000}},	//   szły_, кнен, _suýt_,
  { {0x768f076c,0xafdb04aa,0x210300a8,0x00000000}},	//   tøyl, _iløp, rčiš_,
  { {0xdb0900ca,0x09060054,0x2103005f,0x00000000}},	//   _egeï, вчим, sčiš_,
  { {0x9e630fe2,0x628e0026,0xdd38008f,0x00000000}},	//   _тврд, ilbo, lāža,
  { {0xb8140d34,0xa9270086,0xc1730063,0x00000000}},	//   удиј, тіше_, יחו_,
  { {0xc6f70076,0xae020161,0xdb000026,0x00000000}},	//   вных_, र्थन_, _afmö,
  { {0x9538000a,0x8f9b0047,0x44ce004c,0x00000000}},	//   езот_, ויפי, tř_,
  { {0x69d82070,0x39580f2d,0xa01b0014,0x00000000}},	//   mave, _års_, _sköm,
  { {0xae020161,0x443f007a,0x442d0331,0x00000000}},	//   र्तन_, ðu_, ñe_,
  { {0x38b8007a,0xc4580076,0xd2510044,0x00000000}},	//   _hér_, тиях_, منح_,
  { {0xe2980088,0xdb090003,0x32050066,0x00000000}},	//   каў_, énég, ýly_,
  { {0x443f008b,0x69d8013d,0x2cbf0734,0x00000000}},	//   ưu_, iave, _čudo_,
  { {0x38b8007a,0x69d80e4e,0x628e2d70,0x00000000}},	//   _mér_, have, albo,
  { {0x2d8e00bd,0xf3ff017d,0x6e990699,0x00000000}},	// [4ad0] üfen_, lião_, евар_,
  { {0x8fa40001,0x2ee92d71,0x69d82d72,0x00000000}},	//   рађе, rraf_, jave,
  { {0xf3ff0016,0x3da70088,0x69d82d73,0x00000000}},	//   nião_, траб, dave,
  { {0x8c3d01f7,0x30350121,0x63bd00ea,0x00000000}},	//   _kişi, _семё, ncsn,
  { {0x09e50002,0xf41f0072,0x78ab2d74,0x00000000}},	//   голн, idä_, _rigv,
  { {0xfe71006a,0xf41f024a,0x69d802ab,0x00000000}},	//   _اگر_, hdä_, gave,
  { {0x08d40088,0xdddc007d,0xd90f005d,0x00000000}},	//   ацыя, _ukrš, تیا_,
  { {0x649d0139,0x00000000,0x00000000,0x00000000}},	//   léif,   ,   ,
  { {0xfc64005a,0xe7310021,0x69ca013d,0x00000000}},	//   _търн, صصة_, bbfe,
  { {0x69ca0235,0x7bd900ac,0x394700ac,0x00000000}},	//   _स्पी, lawu, pyns_,
  { {0xf3ff03d9,0xa5040085,0xd46a005e,0x00000000}},	//   gião_, аяўл, еине_,
  { {0x26d900ea,0x7aeb0244,0x36d50081,0x00000000}},	//   ásos_, orgt, _бодр,
  { {0xd838000d,0x6f07008f,0xf74b0021,0x00000000}},	//   _шэф_, nībā, _تجاه_,
  { {0x8c3d0058,0x2cad2d75,0xa5640043,0x00000000}},	//   _dişi, _lied_, ادین,
  { {0xe2970138,0x50b52d76,0xa5940062,0x00000000}},	//   уар_, исту, _кръщ,
  { {0x8c3d0529,0xdd3b0022,0x69d82d77,0x00000000}},	//   _fişi, _dąże, zave,
  { {0x7afd004d,0x6fb30021,0xdfcf0044,0x00000000}},	// [4ae0] _ästh, إمكا, ثيق_,
  { {0x2bcc0053,0x5337009f,0x69d801a8,0x00000000}},	//   ार्थ, _ענין_, xave,
  { {0x2cad021f,0x9be60088,0x69d82d78,0x00000000}},	//   _bied_, гілк, vave,
  { {0x3ce61401,0x7bd900ac,0x69d800e5,0x00000000}},	//   čov_, gawu, wave,
  { {0x2cad0037,0x38b8007a,0x201201f7,0x00000000}},	//   _died_, _sér_, meyi_,
  { {0x7f2b0063,0x20120058,0x98bc0078,0x00000000}},	//   _אֵלֶ, leyi_, hyvą_,
  { {0xdd92006a,0xf41f00fe,0x7c962d79,0x00000000}},	//   _طور_, ydä_, _брац,
  { {0x64560006,0x6f160051,0xf3ff017d,0x00000000}},	//   ūzij, owyc, vião_,
  { {0xc9f60032,0xd5b00032,0x6f07001c,0x00000000}},	//   _مساع, يفة_, cībā,
  { {0x4efb0047,0x38b82d7a,0x248902fd,0x00000000}},	//   עליג, _tér_, _skam_,
  { {0x24590086,0xf76f007e,0x2012005b,0x00000000}},	//   вань_, قای_, keyi_,
  { {0xf3ff00be,0x8c3d0058,0xf99303c3,0x00000000}},	//   rião_, _pişi, _הרע_,
  { {0x41e70088,0xf3ff0016,0x2900003b,0x00000000}},	//   ліва, sião_, ăiau_,
  { {0xd6270001,0xf3ff017d,0x5187019c,0x00000000}},	//   _боље_, pião_, губа,
  { {0x64960025,0xe0d50001,0x41540002,0x00000000}},	//   máin, робњ, бврс,
  { {0x64961077,0x20120058,0x60182049,0x00000000}},	//   láin, geyi_, лося_,
  { {0x2dd52d7b,0x9df9019c,0x6380011b,0x00000000}},	// [4af0] ижар, кнат_, _pánů,
  { {0x63a9004a,0x539c0063,0x877b0063,0x00000000}},	//   žens, _איחו, תאמי,
  { {0x2cad2d7c,0x62872d7d,0x3866003b,0x00000000}},	//   _pied_, mojo, _omor_,
  { {0x6f07001c,0x64960139,0x3d050053,0x00000000}},	//   tībā, háin, _रहीं_,
  { {0x16140161,0x2cad2b21,0x649d0139,0x00000000}},	//   तजार_, _vied_, méid,
  { {0xeab0007e,0x7bd9017e,0x62870df9,0x00000000}},	//   سعه_, sawu, nojo,
  { {0x2cad2d7e,0x6f07001c,0x7bcd0014,0x00000000}},	//   _tied_, sībā, ðaus,
  { {0xaae700b3,0xa6e52aa7,0x649d0139,0x00000000}},	//   _مسئو, ажил, néid,
  { {0x86990079,0x61e5004a,0x62871e57,0x00000000}},	//   ктот_, _odhl, kojo,
  { {0x60c500e3,0x67260026,0x649d0025,0x00000000}},	//   _othm, ækja, héid,
  { {0x48150245,0x6f160051,0x2012005b,0x00000000}},	//   _вмес, zwyc, yeyi_,
  { {0x63ba0080,0x38690137,0xd46a1ba1,0x00000000}},	//   ětno, _öar_, тиме_,
  { {0xb463007e,0xd6c3007e,0x64960025,0x00000000}},	//   تگوه, _امتی, báin,
  { {0x64960025,0x35a5000d,0xca350063,0x00000000}},	//   cáin, _калг, ׁנָה_,
  { {0x76430035,0x2012005b,0x21a60002,0x00000000}},	//   _iony, teyi_, ривм,
  { {0x70560021,0x6724007d,0xdee60131,0x00000000}},	//   جنرا, _šiji, иоби,
  { {0x2012005b,0x9e66000d,0x76432d7f,0x00000000}},	// [4b00] reyi_, авад, _kony,
  { {0x44202d80,0x20120058,0x42db009a,0x00000000}},	//   _hai_, seyi_, _שקיע,
  { {0x442000eb,0x76430089,0x69d90042,0x00000000}},	//   _kai_, _mony, _नज़ी,
  { {0x649d0025,0x44202d70,0x69c12d81,0x00000000}},	//   réig, _jai_, _afle,
  { {0x44202d82,0x2b160076,0x9871005f,0x00000000}},	//   _mai_, рьер, _ašį_,
  { {0x44202d83,0xae020161,0xf41f0137,0x00000000}},	//   _lai_, र्शन_, llät_,
  { {0xfce30065,0x44202d84,0x2d87013d,0x00000000}},	//   _моро, _oai_, ünet_,
  { {0x44202d85,0x9d1b0063,0x672d008f,0x00000000}},	//   _nai_, _בולט, _šaja,
  { {0x76430009,0x64960025,0xa2b20053,0x00000000}},	//   _bony, táin, _इंग्,
  { {0x4432233a,0x442000ac,0xbafb0063,0x00000000}},	//   _any_, _aai_, _בהמש,
  { {0x64960025,0x44202d86,0x7c202d87,0x00000000}},	//   ráin, _bai_, _kamr,
  { {0xe704007e,0x7c202d88,0x44202d89,0x00000000}},	//   _هستی, _jamr, _cai_,
  { {0x44202d8a,0x44320080,0x53440076,0x00000000}},	//   _dai_, _dny_, охра,
  { {0x1779000d,0xb287000d,0x44322d8b,0x00000000}},	//   _ёсць_, рымк, _eny_,
  { {0x44202d8c,0x64560034,0x3d050053,0x00000000}},	//   _fai_, _flyi, _रहें_,
  { {0x7c202d8d,0x44202d8e,0x7f070054,0x00000000}},	//   _namr, _gai_, иїзд,
  { {0x7c220185,0x8c3d003b,0x3f8f0014,0x00000000}},	// [4b10] ddor, _mişt, ægu_,
  { {0x7d0100c7,0x64960025,0xe3b00021,0x00000000}},	//   _älsk, háil, _ترى_,
  { {0x649d0025,0x60c52d8f,0x127c0047,0x00000000}},	//   péid, _uthm, _באזע,
  { {0x4c950076,0x8c3d000c,0x9be70054,0x00000000}},	//   щиес, _nişt, ріжк,
  { {0x69c100bd,0x64960025,0x62800003,0x00000000}},	//   _pfle, dáil, émog,
  { {0xdb0600ea,0x7c220e57,0x7a070054,0x00000000}},	//   ámán, ador, рядж,
  { {0x38ca007e,0x3eb905a5,0x787e008f,0x00000000}},	//   هايی_, _hust_, zīve,
  { {0x64960139,0x3eb92d90,0x26df0c5f,0x00000000}},	//   gáil, _kust_, tsuo_,
  { {0x76430b54,0xf5b50086,0x44202d91,0x00000000}},	//   _pony, йсню, _rai_,
  { {0x3eb90037,0x7c202d92,0x645d00f5,0x00000000}},	//   _must_, _zamr, ërin,
  { {0x44201f2f,0xb9950021,0x671c0053,0x00000000}},	//   _pai_, _الاب, _बैठक_,
  { {0xf09f001b,0x645d0006,0x64960139,0x00000000}},	//   _nhà_, ūrin, cáil,
  { {0x44202d93,0x386d2d94,0xf7940085,0x00000000}},	//   _vai_, mier_, _дацэ,
  { {0x76430035,0x386d2d95,0x425519b6,0x00000000}},	//   _uony, lier_, отст,
  { {0x3eb92d96,0x44202d97,0x200b05b3,0x00000000}},	//   _aust_, _tai_, _bbci_,
  { {0x44e301f7,0x386d2d98,0x44202d99,0x00000000}},	//   mı_, nier_, _uai_,
  { {0x44e301f7,0x2fc000ea,0x8fa31c9d,0x00000000}},	// [4b20] lı_, rcig_, зате,
  { {0x7c20007a,0x3eb90034,0x386d0269,0x00000000}},	//   _samr, _dust_, hier_,
  { {0x44e301f7,0x9f400290,0x2ee012ee,0x00000000}},	//   nı_, ggiò_, ssif_,
  { {0xaae60021,0x7bcd0014,0x3eb91dba,0x00000000}},	//   مستو, ðaup, _fust_,
  { {0x9f40006d,0x6d5e0051,0x386d2d9a,0x00000000}},	//   rgió_, szpa, dier_,
  { {0x4df52d9b,0x7d250026,0x386d2d9c,0x00000000}},	//   _мяст, ðusí, eier_,
  { {0x386d0c6e,0x64960025,0x5e570047,0x00000000}},	//   fier_, táil, _פילע_,
  { {0x44e301f7,0x6f042d9d,0x386d0246,0x00000000}},	//   dı_, otic, gier_,
  { {0x64960139,0x6f0412d4,0x76aa0330,0x00000000}},	//   ráil, ntic, лтов_,
  { {0x386d021f,0x44e3005b,0x14ca0121,0x00000000}},	//   aier_, fı_, лыми_,
  { {0x69da003d,0xa439167b,0x386d2d9e,0x00000000}},	//   _iete, азну_, bier_,
  { {0x69da159d,0x386d2d9f,0x0d970063,0x00000000}},	//   _hete, cier_, מכים_,
  { {0x7ae40027,0x69da014f,0x7ae20072,0x00000000}},	//   áith, _kete, nsot,
  { {0x69da12ee,0x44e3005b,0x3eb90d1e,0x00000000}},	//   _jete, bı_, _rust_,
  { {0x44e301f7,0x915f001b,0x7ea90006,0x00000000}},	//   cı_, _bắt_, _užpi,
  { {0x915f0013,0x3eb904aa,0xd5b8008f,0x00000000}},	//   _cắt_, _pust_, idām_,
  { {0x9f340054,0x00000000,0x00000000,0x00000000}},	// [4b30] петі,   ,   ,
  { {0x69da2da0,0x386d2da1,0x291e2383,0x00000000}},	//   _nete, zier_, _osta_,
  { {0x6f042da2,0xf09f0013,0xdd9b04f2,0x00000000}},	//   atic, _thà_, уша_,
  { {0xa01b0137,0x6295004d,0xfebb007e,0x00000000}},	//   _sjöf, llzo, _ماست_,
  { {0x7055006a,0x291e06c6,0x69da1647,0x00000000}},	//   _هنگا, _asta_, _bete,
  { {0x44e301f7,0x1a290121,0x69da2da3,0x00000000}},	//   yı_, ржки_, _cete,
  { {0xd942005a,0xa8590001,0x386d2da4,0x00000000}},	//   дещи, ијих_, tier_,
  { {0xd6d10032,0x7bc22da5,0x46e90320,0x00000000}},	//   وقع_, ccou, адин_,
  { {0x291e0fca,0x69ca0161,0x9f40007a,0x00000000}},	//   _esta_, _स्वी, ngið_,
  { {0x44e3005b,0xa01b0014,0x386d19d8,0x00000000}},	//   tı_, _fjög, sier_,
  { {0x386d2da6,0x6f04008f,0xa509012d,0x00000000}},	//   pier_, ztic, шена_,
  { {0x44e304ab,0x69da0122,0x6abb0035,0x00000000}},	//   rı_, _zete, _kuuf,
  { {0x44e301f7,0x69da01f7,0x8c1a0063,0x00000000}},	//   sı_, _yete, בורי,
  { {0x59cf024c,0x26cd0290,0x645d02cc,0x00000000}},	//   _स्मर, mpeo_, ahsi,
  { {0x645d0025,0x67292da7,0x2009002b,0x00000000}},	//   bhsi, lvej, ffai_,
  { {0x6f042d2e,0x645d00bd,0x672900c2,0x00000000}},	//   ttic, chsi, ovej,
  { {0x67290146,0xfe460002,0x9f400026,0x00000000}},	// [4b40] nvej, онао, ggið_,
  { {0xa01b00c7,0xee372da8,0xe0da01fc,0x00000000}},	//   _sköt, ону_, _кво_,
  { {0x915f008b,0x649d017d,0x32182da9,0x00000000}},	//   _tắt_, léia, mery_,
  { {0x7bc20164,0x69da1aae,0x7ae200fe,0x00000000}},	//   ucou, _sete, tsot,
  { {0x7bc22daa,0x2ca6001f,0x78ba0006,0x00000000}},	//   rcou, rmod_, _sutv,
  { {0x1ad90088,0x7bc2031b,0x32182dab,0x00000000}},	//   сьць_, scou, nery_,
  { {0xd5b8001c,0x768f04aa,0x69da2dac,0x00000000}},	//   udām_, høys, _vete,
  { {0xe8e0001b,0x69da2dad,0x98a3005e,0x00000000}},	//   hiệp_, _wete, мије,
  { {0x69da1f81,0x32182dae,0x645d005f,0x00000000}},	//   _tete, kery_, ërim,
  { {0x78ba0004,0x649d017d,0xa5f8005e,0x00000000}},	//   _tutv, déia, љену_,
  { {0x645d2daf,0xd7e60086,0x6802004c,0x00000000}},	//   ūrim, _діло, _půjč,
  { {0x2ef200e8,0xafdb00d1,0x2bb10053,0x00000000}},	//   kryf_, _fløy, ुँचा,
  { {0x2fd200b9,0x32182db0,0xf8b3009a,0x00000000}},	//   dbyg_, fery_, _חשף_,
  { {0x2ef200e8,0x2fd2001f,0x321800e5,0x00000000}},	//   dryf_, ebyg_, gery_,
  { {0x306b0259,0x40350002,0x32280054,0x00000000}},	//   ајан_, певс, ціям_,
  { {0x768f04aa,0x2ef2002b,0x91cb0042,0x00000000}},	//   søyt, fryf_, _त्रै,
  { {0xdb19004d,0x62802db1,0x32182db2,0x00000000}},	// [4b50] ubwü, émoc, bery_,
  { {0x551e0053,0x32182db3,0x9e070085,0x00000000}},	//   _बनाए_, cery_, ўчал,
  { {0x8d68000a,0x59de0053,0x78a20066,0x00000000}},	//   ојца_, _नज़र, _ohov,
  { {0x2476008f,0x7d052db4,0x50f40085,0x00000000}},	//   tāmi_, rths, _ўзят,
  { {0x403a0063,0x103a009a,0xaac4043e,0x00000000}},	//   _הגרג, _הגרע, وتون,
  { {0x08d5005a,0xdcfb007e,0x4a440086,0x00000000}},	//   пция, _پرسش_, мнів,
  { {0x76b20051,0xafdb04aa,0x645d008f,0x00000000}},	//   _płyn, _sløy, īrij,
  { {0x787e003d,0x67292db5,0x78a22db6,0x00000000}},	//   tīva, tvej, _chov,
  { {0xab7d000d,0xf77100f2,0xc7b9013d,0x00000000}},	//   _сваi, عاب_, ldők_,
  { {0x67292db7,0x05652db8,0x27290066,0x00000000}},	//   rvej, звон, _vĺn_,
  { {0x32182db9,0x67292b6a,0xab5d0051,0x00000000}},	//   very_, svej, _reży,
  { {0x768f00d1,0xfd560063,0x59cf0053,0x00000000}},	//   tøys, פשרי_, _स्तर,
  { {0x7ae400c3,0x8c1a0063,0x289a0047,0x00000000}},	//   šitv, זורי, _פינא,
  { {0x768f00d1,0x32182dba,0x649d00be,0x00000000}},	//   røys, uery_, réia,
  { {0xc692014e,0x649d0025,0xe3b2007e,0x00000000}},	//   _ראו_, méin, برگ_,
  { {0x649d017d,0x290700a4,0xa01b0b68,0x00000000}},	//   péia, itna_, _skör,
  { {0x33fb009a,0x823604a0,0x32180168,0x00000000}},	// [4b60] _ההפנ, _فردا, pery_,
  { {0x29070734,0xe1fa263d,0x0e6a0044,0x00000000}},	//   ktna_, _уго_, حصري_,
  { {0x628e0e02,0x2bca0054,0xae020042,0x00000000}},	//   mobo, було_, र्गन_,
  { {0xe5720047,0x628e2dbb,0x1c460505,0x00000000}},	//   ײַע_, lobo, янем,
  { {0x2a6c039f,0x78a9004b,0xcfb70063,0x00000000}},	//   _pmdb_, dmev, _מלכי_,
  { {0x26c20024,0x1994066c,0x78a22dbc,0x00000000}},	//   íkom_, маля, _shov,
  { {0x2476003d,0x69230002,0xa3ac0053,0x00000000}},	//   lāmu_, емја, केत_,
  { {0xc8630076,0x248002e2,0x5d7b0063,0x00000000}},	//   етьи, _njim_, _האלק,
  { {0x2476001c,0x628e0562,0x9986005d,0x00000000}},	//   nāmu_, kobo, _کلاو,
  { {0x9f4b00ea,0xab770049,0x9a250044,0x00000000}},	//   ímét_, _عملا_, _يعلن,
  { {0x186a02d8,0xd7ef2124,0x997e0085,0x00000000}},	//   _лажи_, _пу_, _стаi,
  { {0xf8aa0138,0x38a10051,0x493b0063,0x00000000}},	//   _увек_, tóre_, _לגבו,
  { {0xa3be0053,0x93270021,0x628e2dbd,0x00000000}},	//   ेड़_, أرجن, fobo,
  { {0x67220072,0x628e13d7,0x2476008f,0x00000000}},	//   _isoj, gobo, dāmu_,
  { {0x06b10080,0x65930085,0x609b0044,0x00000000}},	//   řící_, _пашу, مخرج_,
  { {0x55970063,0xf0b401dd,0x787e008f,0x00000000}},	//   _מדוע_, ейсь, zīvn,
  { {0x33750054,0xdb090075,0x1eab0044,0x00000000}},	// [4b70] _ігор, ünüd, مائي_,
  { {0x03780063,0x661a2dbe,0x628e2dbf,0x00000000}},	//   _מתחת_, netk, cobo,
  { {0xa25b034d,0x3cf70053,0x8c3d0058,0x00000000}},	//   spôs, ँढें_, _ahşa,
  { {0xfc64005a,0x69c82dc0,0xab75005e,0x00000000}},	//   нъчн, _afde, мгеш,
  { {0x3ce90053,0xcfab007e,0xeb8e2dc1,0x00000000}},	//   _चटके_, _دادم_, ти_,
  { {0x22960026,0x29070137,0x661a2dc2,0x00000000}},	//   tæki_, ttna_, jetk,
  { {0x661a0198,0x649d0025,0x78a9004b,0x00000000}},	//   detk, véin, tmev,
  { {0x06c9015a,0x97d901dd,0x29072dc3,0x00000000}},	//   огий_, цьку_, rtna_,
  { {0x764a0035,0x649d0003,0x29072dc4,0x00000000}},	//   _bofy, téin, stna_,
  { {0x661a0150,0x29070077,0x36690054,0x00000000}},	//   getk, ptna_, іано_,
  { {0x7ae90026,0xa787007e,0x9a840054,0x00000000}},	//   _hvet, _کشاو, _чутл,
  { {0xb8e10235,0x7ae901d9,0x628e0022,0x00000000}},	//   ंद_, _kvet, wobo,
  { {0x4463005a,0x661a2dc5,0x442c004c,0x00000000}},	//   твяв, betk, ěd_,
  { {0x764a0185,0xa01b0026,0x27ff2dc6,0x00000000}},	//   _gofy, _sköp, lgun_,
  { {0x661c0019,0x628e2dc7,0x27ff0046,0x00000000}},	//   õrke, robo, ogun_,
  { {0x27ff06a7,0x10a302a9,0x7ae927ac,0x00000000}},	//   ngun_, висн, _ovet,
  { {0x787e008f,0x6aaa002b,0x61f9013d,0x00000000}},	// [4b80] zīvo, ymff, áblé,
  { {0x649d0025,0xe2920049,0x64460077,0x00000000}},	//   héil, _جذب_, ljki,
  { {0xdbc60019,0x8c460086,0x7ae92dc8,0x00000000}},	//   _mööd, меже, _avet,
  { {0xed570086,0x2bd50053,0x69b30053,0x00000000}},	//   ьох_, दरगा, ेखनी,
  { {0x671c0053,0x7ae9082a,0x6e3900ea,0x00000000}},	//   _बैंक_, _cvet, ábbí,
  { {0xbe16007e,0x787e001c,0x6e2700a8,0x00000000}},	//   _توسع, tīvo, _gajb,
  { {0x661a000f,0x2476001c,0xdd92007e,0x00000000}},	//   vetk, nāms_, _شور_,
  { {0x649d0025,0x27ff0089,0x764a0cc6,0x00000000}},	//   géil, ggun_, _sofy,
  { {0xf0930063,0x59cf0053,0x2d9801e1,0x00000000}},	//   כנה_, _स्वर, _hyre_,
  { {0x7afd0137,0x24760023,0xaa570044,0x00000000}},	//   _åsta, kāms_, _قلقا_,
  { {0x984c0051,0xe01e0053,0x38c8007e,0x00000000}},	//   jść_, _पसंद_, _راضی_,
  { {0x62802dc9,0x84340054,0x7ae91806,0x00000000}},	//   émon, внює, _yvet,
  { {0x984c0051,0xe6660174,0x2d9814a4,0x00000000}},	//   eść_, _отко, _lyre_,
  { {0xe56f007e,0x179b009a,0xab4b009d,0x00000000}},	//   اطی_, _וידב, חֲלֻ,
  { {0x38a100ea,0x649d0139,0xd5fb009a,0x00000000}},	//   lóra_, léim, _ופור,
  { {0x27e400c7,0xa3ea0082,0xd92b009d,0x00000000}},	//   namn_, मणः_, חֵמָ,
  { {0x3eb8007a,0x4429006c,0x3f850022,0x00000000}},	// [4b90] _birt_, _iaa_, _ślub_,
  { {0x27e41310,0x63a0004b,0x42550044,0x00000000}},	//   hamn_, ümne, _أندر,
  { {0x5274007e,0x27ff005b,0x7ae92dca,0x00000000}},	//   _جايز, ygun_, _svet,
  { {0x859b014e,0x44290659,0x2d98011d,0x00000000}},	//   חשבו, _jaa_, _dyre_,
  { {0x38a10026,0x44292dcb,0xdee70021,0x00000000}},	//   jóra_, _maa_, _تأجي,
  { {0xf2d40047,0x4429000e,0x644d008d,0x00000000}},	//   דעס_, _laa_, _loai,
  { {0xd876007e,0x27ff1b0c,0xdbd90014,0x00000000}},	//   کميت_, tgun_, _fæðu,
  { {0x64960025,0x98a20905,0xdbc60019,0x00000000}},	//   náit, лище, _sööd,
  { {0x2b90007e,0x27ff0b9c,0x7c3b0fef,0x00000000}},	//   _پیوس, rgun_, _inur,
  { {0x8a370021,0x984c0051,0x7c292dcc,0x00000000}},	//   _تعرض, yść_, _haer,
  { {0xa907006a,0x62590290,0xb5790071,0x00000000}},	//   _زبان, _vìol, ящих_,
  { {0xc209014e,0x3d070161,0xdcef0078,0x00000000}},	//   _לה_, _हमने_, ūdėt,
  { {0xdbc60019,0x44292dcd,0x7c290c5f,0x00000000}},	//   _tööd, _daa_, _maer,
  { {0x4429024a,0x66f6014e,0x7c292dce,0x00000000}},	//   _eaa_, _נמצא_, _laer,
  { {0x644d000c,0xf9920047,0x2ee9001f,0x00000000}},	//   _foai, ָרן_, esaf_,
  { {0x387f007a,0x7c290019,0x44292dcf,0x00000000}},	//   nnur_, _naer, _gaa_,
  { {0x3f860016,0x7c2b08de,0xdbd90014,0x00000000}},	// [4ba0] çou_, ddgr, _ræðu,
  { {0x645d00ac,0x63a40792,0x387f004d,0x00000000}},	//   ëriv, _izin, hnur_,
  { {0x38a100ea,0x7c292dd0,0x44292dd1,0x00000000}},	//   zóra_, _baer, _yaa_,
  { {0x7c292415,0x3eb8004d,0x7c2b2dd2,0x00000000}},	//   _caer, _wirt_, gdgr,
  { {0x7c29028d,0x64960025,0xd5b8008f,0x00000000}},	//   _daer, láis, ldāt_,
  { {0x63a40035,0x7c2b0c22,0x2d982dd3,0x00000000}},	//   _mzin, adgr, _tyre_,
  { {0x6da31225,0x387f0014,0x8e830330,0x00000000}},	//   _бира, fnur_, _сгре,
  { {0x7c29001f,0x629c004d,0x7b090072,0x00000000}},	//   _gaer, hlro, östö,
  { {0x63a40035,0xcb670054,0x6d43004b,0x00000000}},	//   _nzin, _зате_, änav,
  { {0xb6020080,0x649d0139,0x62800153,0x00000000}},	//   _část, réim, émol,
  { {0x442905dd,0xa3d5014c,0x38a10139,0x00000000}},	//   _paa_, конч, sóra_,
  { {0x4429006c,0xe78604ed,0x7d7b009a,0x00000000}},	//   _qaa_, _пуло, לניו,
  { {0x44292dd4,0xd5b80023,0xa3ac0042,0x00000000}},	//   _vaa_, edāt_, केल_,
  { {0x67260026,0x3885001c,0x63a42dd5,0x00000000}},	//   ækju, mēra_, _dzin,
  { {0x63a42dd6,0x69ca0025,0x6aba0a85,0x00000000}},	//   _ezin, icfe, _mitf,
  { {0x759b0f6d,0x2ee9006f,0x44292dd1,0x00000000}},	//   _מיוח, tsaf_, _uaa_,
  { {0x64960027,0xf41f00fe,0x187b0063,0x00000000}},	// [4bb0] ráit, meä_, פטמב,
  { {0x765a0006,0x38a10026,0x2ee9001f,0x00000000}},	//   nkty, jórn_, rsaf_,
  { {0x64960025,0x63a4001c,0x22960014,0x00000000}},	//   cáis, _zzin, rækt_,
  { {0x64960025,0xafdb00d1,0x8c45005e,0x00000000}},	//   láir, _snøf, ђеле,
  { {0x65640080,0x765a00d1,0x7c292dd7,0x00000000}},	//   _řihl, kkty, _vaer,
  { {0x50d4007e,0xd5b8008f,0x7ac40085,0x00000000}},	//   _جزیر, ndās_, усце,
  { {0xf41f0072,0x7c290139,0x6f0d2dd8,0x00000000}},	//   keä_, _taer, ltac,
  { {0x64960025,0x765a0022,0xf990009e,0x00000000}},	//   háir, ekty, حبه_,
  { {0x387f00f3,0xd7060076,0x6f0d2dd9,0x00000000}},	//   rnur_, вные_, ntac,
  { {0xab740094,0xbab5005d,0x00000000,0x00000000}},	//   _сгуш, _شماب,   ,
  { {0x63a4000f,0xc959006a,0x69ca0053,0x00000000}},	//   _szin, _تلاش_, _स्टी,
  { {0xa01b0137,0x6f0d0051,0x765a1435,0x00000000}},	//   _sjön, ktac, akty,
  { {0x0323019d,0xa3ac0053,0xd7f80062,0x00000000}},	//   адян, कें_, _чух_,
  { {0x998700ea,0x64960025,0x9f4000ac,0x00000000}},	//   lenő_, gáir, waiï_,
  { {0x26c2034d,0x20c70013,0x4096058f,0x00000000}},	//   íkov_, _cõi_, врат,
  { {0x20c7001b,0x7eab00bd,0x3e640137,0x00000000}},	//   _dõi_, nüpf, _möte_,
  { {0x63a42dda,0x6fb3009b,0x00000000,0x00000000}},	// [4bc0] _uzin, لمفا,   ,
  { {0x645d0078,0x3f9c008f,0x02fb069a,0x00000000}},	//   ūrit, āvu_, _קלימ,
  { {0xa01b0014,0xf8b30042,0x6f0d2ddb,0x00000000}},	//   _kjöl, ुदाय, atac,
  { {0xf5360047,0xaae60593,0xfd950054,0x00000000}},	//   כטער_, نستو, ушую,
  { {0x765a00ac,0xa01b0137,0x6f0d2c7c,0x00000000}},	//   ykty, _mjöl, ctac,
  { {0x68f80130,0xf2d3009a,0xbb470044,0x00000000}},	//   trvd, סעו_, ئلون_,
  { {0x9f490014,0xda65013a,0x787e008f,0x00000000}},	//   lgað_, داني, līvi,
  { {0xd943005e,0x7c85005e,0x61e7013d,0x00000000}},	//   рећи, _буђе, zajl,
  { {0x9f490026,0x799a0051,0xec770002,0x00000000}},	//   ngað_, _wytw, _рпт_,
  { {0x9633082d,0x00000000,0x00000000,0x00000000}},	//   аньц,   ,   ,
  { {0x765a2ddc,0x4e350047,0xf41f0072,0x00000000}},	//   rkty, אָרן_, teä_,
  { {0x997900b5,0x897900b5,0x765a0137,0x00000000}},	//   _אָנפ, _אָנה, skty,
  { {0x61e72ddd,0xdcfc0078,0xf41f0072,0x00000000}},	//   tajl, _tyrė, reä_,
  { {0x07a30001,0x63a0004b,0x17570063,0x00000000}},	//   _тачн, ümna, _בסדר_,
  { {0xc69300b7,0xa01b007a,0x60190062,0x00000000}},	//   _דאס_, _fjöl, новя_,
  { {0x20c71fc9,0x260e0161,0x9f9d007a,0x00000000}},	//   _või_, त्री_, _bæði_,
  { {0x53350ad9,0xb2ab0054,0x9f490014,0x00000000}},	// [4bd0] _септ, _отож_, ggað_,
  { {0x20c70019,0x752f0051,0x38690066,0x00000000}},	//   _tõi_, łcze, ďari_,
  { {0x20160024,0x6f0d2dde,0xdd910021,0x00000000}},	//   ícií_, stac, حوا_,
  { {0x645d2ddf,0xda050053,0xbc180086,0x00000000}},	//   nksi, _राहत_, віші_,
  { {0x9f9d0026,0x6d4a00d1,0x61e50a67,0x00000000}},	//   _gæði_, øfar, _kehl,
  { {0x62952de0,0xb7bd003b,0x61e5004c,0x00000000}},	//   nozo, ieţe, _jehl,
  { {0x7e60000c,0x6d430137,0x645d0014,0x00000000}},	//   _împa, ånad, kksi,
  { {0xccf20132,0x7af60006,0x66d9005a,0x00000000}},	//   _לכל_, šyta, ньор_,
  { {0x629500ea,0x00000000,0x00000000,0x00000000}},	//   kozo,   ,   ,
  { {0xb7bd003b,0x85490816,0xa01b00a5,0x00000000}},	//   deţe, езов_, _sjöl,
  { {0x69c102dd,0xf3e61314,0x6295013d,0x00000000}},	//   _igle, лжно, dozo,
  { {0xb7bd003b,0xd6d90022,0xa01b013d,0x00000000}},	//   feţe, zyły_, _eköz,
  { {0xc87901f7,0xe894014b,0xd808009a,0x00000000}},	//   miş_, _таць, _יִסָ,
  { {0x412a0b29,0x629500ea,0x43750071,0x00000000}},	//   ного_, gozo, руют,
  { {0x9f9d0046,0x7ccc0075,0x216a0af0,0x00000000}},	//   _sæði_, _oğra, хиви_,
  { {0xc879005b,0x645d0359,0x787e001c,0x00000000}},	//   niş_, cksi, tīvi,
  { {0x61e50199,0x69c11312,0x44222de1,0x00000000}},	// [4be0] _fehl, _ogle, mek_,
  { {0x5d6a0076,0x9f490026,0x69c12de2,0x00000000}},	//   низм_, rgað_, _ngle,
  { {0x44222ac2,0x2d9c0146,0xdca60189,0x00000000}},	//   oek_, æve_, гажи,
  { {0xcdc9014e,0x44222de3,0x16130053,0x00000000}},	//   לך_, nek_, त्तर_,
  { {0x6d430137,0x44222de4,0xc87918ad,0x00000000}},	//   änar, iek_, diş_,
  { {0xab770032,0x90e5007e,0x44222de5,0x00000000}},	//   دمها_, _حسین, hek_,
  { {0x645d00fe,0x44222de6,0x3f870058,0x00000000}},	//   yksi, kek_, şnut_,
  { {0x44222de7,0xb6f40d34,0x69c106a5,0x00000000}},	//   jek_, азиј, _egle,
  { {0x205700b5,0x7c220035,0x6a660026,0x00000000}},	//   טיקל_, meor, _aðfe,
  { {0x7c222de8,0x91d40042,0xfb1b0041,0x00000000}},	//   leor, _ब्लै, _אוממ,
  { {0x62952de9,0x6e2e0089,0xa01b0137,0x00000000}},	//   vozo, _mabb, _sjöm,
  { {0x4422000f,0x645d024a,0x3d070161,0x00000000}},	//   gek_, uksi, _हमसे_,
  { {0x6295000f,0xb3640062,0xb7bd003b,0x00000000}},	//   tozo, бърк, teţe,
  { {0x442d2dea,0x7c2219cd,0x7d1c00c2,0x00000000}},	//   že_, heor, _oprs,
  { {0x7c22076c,0x62952deb,0xb7bd003b,0x00000000}},	//   keor, rozo, reţe,
  { {0x442201f7,0xafdb00d1,0x4fd52a35,0x00000000}},	//   cek_, _snøb, ржат,
  { {0xf3ff0016,0x61e5005b,0x6276001c,0x00000000}},	// [4bf0] lhão_, _tehl, iņoj,
  { {0xa37b0019,0x6e2e2dec,0x27e617ee,0x00000000}},	//   jaõi, _cabb, _leon_,
  { {0xf3ff0016,0xc8790058,0x6e2e0783,0x00000000}},	//   nhão_, yiş_, _dabb,
  { {0x7c222ded,0x4c950076,0x27e62dee,0x00000000}},	//   geor, шиес, _neon_,
  { {0x6e2e051e,0xab292def,0x7dc70021,0x00000000}},	//   _fabb, тола_, _متأك,
  { {0x2bd50053,0x6e2e1ead,0x27e9007d,0x00000000}},	//   _ड्रा, _gabb, _žan_,
  { {0x3258014e,0xaa560001,0x44222a3e,0x00000000}},	//   רסום_, рију_, yek_,
  { {0x5d840032,0x7ccc005b,0x7c2201e1,0x00000000}},	//   _الفل, _uğra, ceor,
  { {0xc87901f7,0x5746005a,0x7b670086,0x00000000}},	//   riş_, изъм_, _стве,
  { {0x4422102e,0x69c12df0,0x95c80002,0x00000000}},	//   wek_, _ugle, луџа_,
  { {0xd46a0184,0x0446000d,0x44222df1,0x00000000}},	//   вине_, аенн, tek_,
  { {0x6f1d1df9,0x3e640137,0x76b20051,0x00000000}},	//   _opsc, _möta_, _błys,
  { {0x44222df2,0x76b20051,0x29260022,0x00000000}},	//   rek_, _płyt, ętał_,
  { {0x44222df3,0x368b0782,0x787e008f,0x00000000}},	//   sek_, _ясен_, rūve,
  { {0xc0760138,0x6e2e2df4,0x9f4001a8,0x00000000}},	//   аћањ, _rabb, waià_,
  { {0xe7ac0053,0x7cc50006,0x6e2e13f4,0x00000000}},	//   _चरमप, _gėri, _sabb,

  { {0x765c0014,0x8e0a0131,0x34b30044,0x00000000}},	// [4c00] öryg, кнав_, _بميز,
  { {0x6441001c,0x2bde0053,0x9dba005d,0x00000000}},	//   ēlie, मर्थ, نداز_,
  { {0x10a60156,0x7c222df5,0xa0a62088,0x00000000}},	//   _винн, teor, _ванд,
  { {0xb53a0041,0x3d070082,0x33c9009d,0x00000000}},	//   כגעש, _हमरे_, ְהוּ_,
  { {0x7e60000c,0x6e2e2df6,0x7bc40078,0x00000000}},	//   _împo, _tabb, žiuo,
  { {0x6a830076,0x649d0025,0x7c2208e7,0x00000000}},	//   олча, léit, seor,
  { {0x6f040025,0x7c22006d,0x3e640137,0x00000000}},	//   luic, peor, _göta_,
  { {0x649d0d23,0x9cd70063,0x97240044,0x00000000}},	//   néit, _כולה_, مفعو,
  { {0x76aa0076,0xa01b0137,0xdf9a0054,0x00000000}},	//   ктов_, _sjök, нсiї_,
  { {0x1daa0053,0x6996130d,0xfaa62df7,0x00000000}},	//   _करात, _крех, _тазо,
  { {0xe45f00fe,0x44e300ea,0x76b20051,0x00000000}},	//   tkö_, gű_, _słys,
  { {0x7d030268,0x291e00e3,0x787e008f,0x00000000}},	//   ànsi, _ipta_, tīvu,
  { {0x6f042dd0,0x3866003b,0x7eb00244,0x00000000}},	//   juic, _ilor_, mäpf,
  { {0x3d070161,0xe45f0137,0xe9ce014b,0x00000000}},	//   _हमले_, skö_, пкi_,
  { {0x31350062,0x38662df8,0x415402f8,0x00000000}},	//   щевр, _klor_, оврс,
  { {0x4e190042,0xc1040021,0xd91b009a,0x00000000}},	//   न्नई_, توفي, כולל,
  { {0x6f040fb8,0x3e6400a5,0x8f0b0094,0x00000000}},	// [4c10] guic, _söta_, ъхва_,
  { {0x7e60003b,0x644f007d,0x291e0e05,0x00000000}},	//   _împl, ljci, _opta_,
  { {0x38662df9,0x7d790021,0xa1592c0b,0x00000000}},	//   _olor_, دمار_, _сану_,
  { {0x6280004a,0xe0d20041,0xbd440021,0x00000000}},	//   émov, _מײט_, تنمي,
  { {0x291e1795,0x62872dfa,0x6f1d00e5,0x00000000}},	//   _apta_, onjo, _upsc,
  { {0xa3ac0053,0x38660d5c,0x20f3007d,0x00000000}},	//   केट_, _alor_, oći_,
  { {0x649d0025,0xceb20047,0xa3d70042,0x00000000}},	//   néis, _מיך_, िडा_,
  { {0x6c850021,0x38290001,0x20090b89,0x00000000}},	//   _الرم, ужио_, ngai_,
  { {0xf749007e,0x649d0003,0xdd38008f,0x00000000}},	//   اجعه_, héis, māša,
  { {0xd4d90088,0x36180054,0x44e3013d,0x00000000}},	//   льмі_, ацюю_, tű_,
  { {0x6287017f,0x38660955,0xc32907e9,0x00000000}},	//   dnjo, _flor_, _רו_,
  { {0xdd38003d,0x44e300ea,0x62872dfb,0x00000000}},	//   nāša, rű_, enjo,
  { {0x38a10026,0x20f3007d,0x27ed001f,0x00000000}},	//   jóri_, eći_, maen_,
  { {0x27ed0185,0x23ac0078,0x388c004c,0x00000000}},	//   laen_, vųjį_, měra_,
  { {0x76430045,0xa06a011c,0xdd38001c,0x00000000}},	//   _inny, гава_, kāša,
  { {0x320c0051,0x4f960002,0x62872dfc,0x00000000}},	//   żdy_, брзу, anjo,
  { {0x6444002c,0x3fcb006a,0x649d0025,0x00000000}},	// [4c20] _inii, ادفی_, réit,
  { {0x44322dfd,0xf41f00fe,0xc2c6007e,0x00000000}},	//   _hay_, nnän_, _پيگي,
  { {0x27ed0a06,0x61ee236f,0x443215c4,0x00000000}},	//   kaen_, mabl, _kay_,
  { {0xe3bf006d,0x61ee2dfe,0x649d0139,0x00000000}},	//   leña_, labl, léir,
  { {0x44320465,0x6f0416eb,0xa2ce0042,0x00000000}},	//   _may_, quic, _धूम्,
  { {0x523a00b5,0x44322c55,0x19580121,0x00000000}},	//   רײַנ, _lay_, иалы_,
  { {0xdd38001c,0x7aed0014,0x6a13009e,0x00000000}},	//   bāša, áatr, سبور,
  { {0x44321898,0xc6f825f7,0x27ed2dff,0x00000000}},	//   _nay_, аних_, gaen_,
  { {0x61ee2e00,0xe5c60054,0x6d5e2e01,0x00000000}},	//   kabl, йсно, lypa,
  { {0xbb3b0047,0x70b40053,0x61ee2e02,0x00000000}},	//   _געמי, ंगुल, jabl,
  { {0x44321898,0x7e7e0072,0x61ee2e03,0x00000000}},	//   _bay_, iipp, dabl,
  { {0x629e0150,0x7643002b,0xb7bd003b,0x00000000}},	//   _akpo, _enny, seţa,
  { {0x4432172e,0x6287007d,0x4736007e,0x00000000}},	//   _day_, tnjo, _دراز,
  { {0xa6b6005a,0x61ee2e04,0x26b60121,0x00000000}},	//   _усещ, gabl, _ущер,
  { {0xa6170063,0x6287007d,0x4a5b0047,0x00000000}},	//   _הקוד_, rnjo, נדלו,
  { {0x20090006,0x7bc40078,0x44322e05,0x00000000}},	//   ugai_, žiuj, _gay_,
  { {0x200907f4,0x62352e06,0xe3bf0331,0x00000000}},	// [4c30] rgai_, _депу, beña_,
  { {0x649d0025,0x6dc70076,0xf1c70080,0x00000000}},	//   péis, ссаж, část_,
  { {0xdd38008f,0x44320058,0xddab0085,0x00000000}},	//   tāša, _yay_, утал_,
  { {0x6e25004d,0xef1f004b,0x4432008d,0x00000000}},	//   sehb, _tpü_, _xay_,
  { {0xa3ea0042,0x2bcb0082,0xeab100de,0x00000000}},	//   यरत_, िशबा, وعت_,
  { {0x3885183d,0x7a07000d,0x08d51406,0x00000000}},	//   mēri_, сядж, оция,
  { {0x27ed2e07,0x46ce0042,0x08d40085,0x00000000}},	//   taen_, _हूबह, пцыя,
  { {0x9c65007e,0x61ee2e08,0xf8ae005d,0x00000000}},	//   _بهرو, zabl, نکن_,
  { {0x61ee04bc,0x27ed2e09,0x44320af6,0x00000000}},	//   yabl, raen_, _ray_,
  { {0x44320034,0x06960032,0xe6160071,0x00000000}},	//   _say_, ينية_, одь_,
  { {0x61ee2e0a,0x44322e0b,0xdb060046,0x00000000}},	//   vabl, _pay_, ámön,
  { {0xccf20047,0x61ee00e5,0x29072e0c,0x00000000}},	//   וכט_, wabl, muna_,
  { {0x6d5e0045,0xd6db13e1,0x4432008b,0x00000000}},	//   zypa, _сте_, _vay_,
  { {0x386d03d9,0x11da0032,0x44322e0d,0x00000000}},	//   lher_, شورة_, _way_,
  { {0x4432001b,0xe3bf006d,0x61ee2e0e,0x00000000}},	//   _tay_, reña_, rabl,
  { {0xe3bf048e,0x386d004d,0x41b5000d,0x00000000}},	//   seña_, nher_, ясят,
  { {0xe7b600b5,0xa0670431,0x61ee04bc,0x00000000}},	// [4c40] ַהער_, цата_, pabl,
  { {0xa3af016a,0x29072e0f,0x63a42e10,0x00000000}},	//   _करत_, kuna_, _iyin,
  { {0x29072e11,0xae190053,0x8d2a0121,0x00000000}},	//   juna_, न्धन_, роев_,
  { {0x6d5e006f,0x9f4b00be,0xcea92177,0x00000000}},	//   rypa, _mecê_, די_,
  { {0xc0530063,0x386d004b,0x7ff7005d,0x00000000}},	//   _חזר_, dher_, _بسپا,
  { {0x6f162c30,0x29070026,0x20e8003b,0x00000000}},	//   mtyc, funa_, oşi_,
  { {0x63a40034,0xed5a0086,0x29072e12,0x00000000}},	//   _lyin, _тов_, guna_,
  { {0x386d0034,0x6f160051,0x20e8005b,0x00000000}},	//   gher_, otyc, işi_,
  { {0x63a40009,0x29072e13,0x629c2e14,0x00000000}},	//   _nyin, auna_, koro,
  { {0x386d004d,0x29072e15,0x76aa0002,0x00000000}},	//   aher_, buna_, јтив_,
  { {0x29072e16,0x63ad101d,0x629c2e17,0x00000000}},	//   cuna_, _szan, doro,
  { {0x6f160051,0x248d017d,0x386d081b,0x00000000}},	//   ktyc, õem_, cher_,
  { {0x20e8003b,0x629c2e18,0x8c1b009a,0x00000000}},	//   eşi_, foro, בוכי,
  { {0x63a40034,0x6f160137,0x629c2e19,0x00000000}},	//   _dyin, dtyc, goro,
  { {0xaffd0083,0xc0cb2e1a,0xc693009a,0x00000000}},	//   ловi, руге_, _קאצ_,
  { {0x200f0019,0x62800003,0x43950454,0x00000000}},	//   ügi_, émor, _найс,
  { {0x20e8000c,0xe3bf006d,0x2dcb005e,0x00000000}},	// [4c50] aşi_, meño_, аћен_,
  { {0xcddb0001,0xe3bf006d,0x2ca6001f,0x00000000}},	//   рња_, leño_, elod_,
  { {0x20e8003b,0xa01b0046,0x6f162e1b,0x00000000}},	//   cşi_, _sjöu, atyc,
  { {0xa3af0235,0x228d0066,0x69c82e1c,0x00000000}},	//   _करा_, oľko_, _agde,
  { {0xd5b1008b,0x7fd6016e,0xfe7301f3,0x00000000}},	//   hép_, _מורס_, _قدس_,
  { {0x5ba8000d,0x29072e1d,0x7eb00050,0x00000000}},	//   цкім_, tuna_, täpe,
  { {0x386d03ae,0x6b8d003b,0xa01b0046,0x00000000}},	//   ther_, _ţigă, _fjöt,
  { {0x629c108e,0xbd4400f2,0x29072e1e,0x00000000}},	//   zoro, _تنفي, runa_,
  { {0x629c0009,0x386d00bd,0x7eab00ea,0x00000000}},	//   yoro, rher_, nüpo,
  { {0xafdb00d1,0x386d2e1f,0xdb1b00be,0x00000000}},	//   _snøl, sher_, _aguç,
  { {0x386d0305,0x629c0607,0x7eab004b,0x00000000}},	//   pher_, voro, hüpo,
  { {0xdb000003,0x935a0002,0x7ae92e20,0x00000000}},	//   _symé, бргу_, _kwet,
  { {0x629c2e21,0x96b90fce,0x87040593,0x00000000}},	//   toro, _луку_, _قبول,
  { {0xf770006a,0x2f1400c7,0x70b40053,0x00000000}},	//   _جام_, väg_, ंग्ल,
  { {0x7e60000c,0x213e0025,0xe5a214cf,0x00000000}},	//   _împi, íth_, _пиши,
  { {0xefca0121,0x629c2e22,0x63a400e5,0x00000000}},	//   слал_, soro, _tyin,
  { {0x629c2cf1,0xb05b0137,0x44200075,0x00000000}},	// [4c60] poro, _tiän, _ibi_,
  { {0x673b00fe,0x6f160051,0x3885001c,0x00000000}},	//   ivuj, rtyc, mēru_,
  { {0x6f160045,0xa0a61def,0x0c2617e6,0x00000000}},	//   styc, _наод, змен,
  { {0x3d1c0053,0x9b6a2049,0x7eab0058,0x00000000}},	//   _नहीं_, йшла_, lüpl,
  { {0x2ca62e23,0xfaa62e24,0xcf3a0054,0x00000000}},	//   rlod_, падо, _учні_,
  { {0xe994007e,0x60c62e25,0x8d660160,0x00000000}},	//   وهشگ, _hikm, _евге,
  { {0x67222e26,0xe467004b,0x6f042e27,0x00000000}},	//   _spoj, ööks_, lric,
  { {0x7658005b,0x645d0078,0xdca30794,0x00000000}},	//   _sovy, ūriz, _заси,
  { {0x6f04211e,0xa01b0014,0x07f70021,0x00000000}},	//   nric, _kjör, سريع_,
  { {0xe6780086,0x6f040025,0x60c6001c,0x00000000}},	//   ійні_, iric, _likm,
  { {0x6f042e28,0x7bc90058,0x4796005d,0x00000000}},	//   hric, şmuş, _کجاس,
  { {0x2b200053,0x60c60397,0x7eab00ca,0x00000000}},	//   _यहाँ_, _nikm, eüpl,
  { {0xe3bf006d,0xa5f80184,0x4c9b0041,0x00000000}},	//   reño_, _делу_, משטע,
  { {0xe3bf02dd,0xa2c40001,0x44200089,0x00000000}},	//   seño_, ељск, _ebi_,
  { {0xe3bf006d,0x6f042e29,0x38a10139,0x00000000}},	//   peño_, eric, pórt_,
  { {0x30a40472,0x6e3501da,0x64a40002,0x00000000}},	//   ерув, _sazb, _паја,
  { {0xbfab1485,0x6d580137,0xa01b2e2a,0x00000000}},	// [4c70] стве_, ävan, _sjös,
  { {0x442b14d5,0x4439294f,0x629a0066,0x00000000}},	//   lec_, lds_, čtoc,
  { {0x6f042e2b,0x6e350080,0x44392e2c,0x00000000}},	//   aric, _vazb, ods_,
  { {0x6f040955,0x442b189f,0x44392e2d,0x00000000}},	//   bric, nec_, nds_,
  { {0x44392e2e,0x1a65007e,0xa01b0014,0x00000000}},	//   ids_, ویری_, _fjör,
  { {0x442b0164,0xa01b0026,0xbb422e2f,0x00000000}},	//   hec_, _gjör, тешк,
  { {0x63a80051,0x442b00a8,0x09290054,0x00000000}},	//   ędni, kec_, іжий_,
  { {0x44392e30,0xf8920002,0xba77007e,0x00000000}},	//   jds_, кајќ, _کارت,
  { {0x7c2b1bb0,0xe7390002,0x442b2e31,0x00000000}},	//   megr, цеп_, dec_,
  { {0x44392e32,0x44200150,0x7c2b2e33,0x00000000}},	//   eds_, _sbi_, legr,
  { {0xb5790076,0xff5f002b,0x7c390022,0x00000000}},	//   ющих_, _sgîl_, odwr,
  { {0x7c2b2e34,0x6f041098,0x947a0054,0x00000000}},	//   negr, yric, існу_,
  { {0x087600b5,0xe7380086,0x386200ea,0x00000000}},	//   _קענט_, _неї_, ökre_,
  { {0x78a92e35,0xafdb00b9,0x27ef01e1,0x00000000}},	//   llev, _unøj, _hegn_,
  { {0x3d0c0053,0x6f04006f,0x7c2b04aa,0x00000000}},	//   _हमें_, wric, kegr,
  { {0x3885001c,0x26c72e36,0xceea0062,0x00000000}},	//   mērs_, _hino_, ждае_,
  { {0xaec6018e,0x7c2b05e5,0x78a92e37,0x00000000}},	// [4c80] дбал, degr, ilev,
  { {0x6f042e38,0x3e64013d,0x912a0062,0x00000000}},	//   rric, _köti_, _джоб_,
  { {0x6f04050c,0x26cf2e39,0x60c6008f,0x00000000}},	//   sric, _lugo_, _tikm,
  { {0xbb860032,0x32d400fe,0x6f042e3a,0x00000000}},	//   ولاي, _käy_, pric,
  { {0xa01b1914,0x78a92e3b,0x5bba0042,0x00000000}},	//   _tjör, dlev, ेशेव,
  { {0x78a22e3c,0x26c70787,0x442b0f32,0x00000000}},	//   _skov, _nino_, zec_,
  { {0x26cf2e3d,0x44390f5f,0x78a900ca,0x00000000}},	//   _augo_, yds_, flev,
  { {0x8b26000a,0x29002e3e,0x7c2b01e1,0x00000000}},	//   _одбе, čia_, cegr,
  { {0x32d400fe,0x3885001c,0x442b2e3f,0x00000000}},	//   _näy_, vērt_, vec_,
  { {0x26cf1900,0x628e006f,0x7ae22e40,0x00000000}},	//   _dugo_, jnbo, mpot,
  { {0x89160021,0x78a92e41,0x7e60003b,0x00000000}},	//   _زبائ, blev, _împu,
  { {0x27ef0026,0x7af60006,0x628e00ca,0x00000000}},	//   _gegn_, šytu, enbo,
  { {0x26c702f6,0xe29f0026,0x44392e42,0x00000000}},	//   _fino_, erða_, rds_,
  { {0x6d410006,0x78a02e43,0x442b02e2,0x00000000}},	//   _šlam, lomv, sec_,
  { {0x6aaa001f,0x6d582e44,0x442b06d6,0x00000000}},	//   ilff, äval, pec_,
  { {0x26cf0331,0x628e00ca,0x7eb00072,0x00000000}},	//   _yugo_, anbo, väpa,
  { {0x69da2e45,0xeb0d0053,0xceb5005e,0x00000000}},	// [4c90] _ofte, _समेत_, ебаћ,
  { {0x3255005e,0x7ae22e46,0x7eb00072,0x00000000}},	//   _чвор, dpot, täpa,
  { {0x8c3d005b,0x61f5005b,0x7ccc0058,0x00000000}},	//   _akşa, mazl, _oğru,
  { {0x1ddf0394,0x69da03e9,0x6d4105d5,0x00000000}},	//   _प्रत, _afte, _álam,
  { {0x3897003b,0xeb8e06da,0x7c2b2e47,0x00000000}},	//   năre_, уи_, regr,
  { {0xdcfb006a,0x7c2b2e48,0xb062078c,0x00000000}},	//   _ورزش_, segr, ääva,
  { {0x6f0d2e49,0x78a92e4a,0x26c701f4,0x00000000}},	//   luac, tlev, _rino_,
  { {0x69da2e4b,0x26c72e4c,0x78a90213,0x00000000}},	//   _efte, _sino_, ulev,
  { {0x6f0d2e4d,0x26c72e4e,0x78a92e4f,0x00000000}},	//   nuac, _pino_, rlev,
  { {0xb7bd003b,0x5b34007e,0x78a92909,0x00000000}},	//   neţi, _جعفر, slev,
  { {0x27ef02ab,0x78a92e50,0x26c72e51,0x00000000}},	//   _tegn_, plev, _vino_,
  { {0xbc190063,0x9987004c,0x764a002b,0x00000000}},	//   הוֹש, lenů_, _enfy,
  { {0x3ea10004,0x69da0137,0x2f23001c,0x00000000}},	//   koht_, _yfte, nīgā_,
  { {0xd7740242,0x64620051,0x29072e52,0x00000000}},	//   _جامع, _świą, orna_,
  { {0x628e2e53,0x60261dd6,0xd46a005e,0x00000000}},	//   rnbo, ндва, _нике_,
  { {0x7afb0035,0x69d800c2,0x7ae22e54,0x00000000}},	//   _ovut, zcve, ypot,
  { {0x2d87006d,0x6f0d2070,0xb7bd003b,0x00000000}},	// [4ca0] únen_, guac, feţi,
  { {0xb7bd003b,0xef1727b8,0xee3721b9,0x00000000}},	//   geţi, эму_, нну_,
  { {0x9f42024a,0x7afb08c8,0x653a0047,0x00000000}},	//   _sekä_, _avut, ּענד,
  { {0x7ae22e55,0xdee62e56,0x59dd0042,0x00000000}},	//   tpot, _поми, नुसर,
  { {0x6f0d270a,0x7ae20ef0,0xcb340062,0x00000000}},	//   cuac, upot, телъ,
  { {0x7ae22e57,0x7ae4003b,0x00000000,0x00000000}},	//   rpot, ţito,   ,
  { {0x09030088,0xdd9200f2,0x98c601e4,0x00000000}},	//   гчым, _صور_, нсил,
  { {0x98a30001,0x6da3005e,0x7ae22e58,0x00000000}},	//   лије, _сиса, ppot,
  { {0x2f23001c,0x57b40062,0x29072e59,0x00000000}},	//   cīgā_, ъбит, arna_,
  { {0x9b930021,0xff7b0063,0x7f3b0047,0x00000000}},	//   _إلكت, פטימ, לעפו,
  { {0xc58a0076,0xf76f007e,0x65942e5a,0x00000000}},	//   ящие_, لای_, тану,
  { {0x3897003b,0x7ccc0058,0xe8d7009d,0x00000000}},	//   tăre_, _uğru, _נודר_,
  { {0x7eb00137,0x291c00ea,0x93f40085,0x00000000}},	//   väpn, ltva_, ыпяц,
  { {0xc2c50032,0x0737009a,0x46140043,0x00000000}},	//   ئيسي, _נאום_, _شوبر,
  { {0x291c00ea,0xe29f0026,0x6440017d,0x00000000}},	//   ntva_, nuði_, ômic,
  { {0xd4980088,0x6f0d2e5b,0x25b10075,0x00000000}},	//   _пры_, tuac, üzle_,
  { {0x9e07005a,0x644d19d5,0xb7bd00dd,0x00000000}},	// [4cb0] ечел, _inai, teţi,
  { {0x290e05b3,0x6f0d0139,0x9f040021,0x00000000}},	//   kufa_, ruac, اولو,
  { {0x3eaf001c,0xb7bd000c,0x7c870002,0x00000000}},	//   ēgt_, reţi, нуде,
  { {0xfbd00021,0x62872e5c,0xb7bd00dd,0x00000000}},	//   مته_, lijo, seţi,
  { {0x6f0d2040,0xb7bd00dd,0xe9ce04c3,0x00000000}},	//   quac, peţi, ик_,
  { {0x628700eb,0x2f23008f,0xab640085,0x00000000}},	//   nijo, rīgā_, ывіл,
  { {0xdde4004c,0x99320044,0x644d2e5d,0x00000000}},	//   ísťo, لفوت, _onai,
  { {0x7e60000c,0x6bd40021,0x62872e5e,0x00000000}},	//   _împr, _متكر, hijo,
  { {0x7eab005b,0x62870ab6,0x2ba80053,0x00000000}},	//   tüph, kijo, _छुपा,
  { {0x7c3b2e5f,0x7bd2001c,0x644d2e60,0x00000000}},	//   _haur, ājuš, _anai,
  { {0x62870a1c,0x7c3b2e61,0x291c0061,0x00000000}},	//   dijo, _kaur, ctva_,
  { {0x644d0027,0xddce0080,0x4424027d,0x00000000}},	//   _cnai, _dobř, ým_,
  { {0x987a00b5,0xe7390581,0x3e640137,0x00000000}},	//   _קאנט, _цел_, _kött_,
  { {0x412a0376,0x628700fc,0x3e6400ea,0x00000000}},	//   мого_, gijo, _jött_,
  { {0xc6160063,0x21a60141,0x443b2e62,0x00000000}},	//   _יחסי_, тивм, _faq_,
  { {0xc003000a,0x61e200dd,0x7c3b2e63,0x00000000}},	//   ипск, _şold, _naur,
  { {0x9845003d,0xb4ae0053,0x62872e64,0x00000000}},	// [4cc0] dēļ_, कती_, bijo,
  { {0x6aa30031,0x62872e65,0x5d6a0121,0x00000000}},	//   jonf, cijo, мизм_,
  { {0x7c3b2e66,0x7eb00050,0x7e630050,0x00000000}},	//   _baur, säpo, önpa,
  { {0x7c3b2e67,0x6faa0044,0xb5090042,0x00000000}},	//   _caur, _يهدف_, _विनय_,
  { {0x7c3b0813,0x6aa30203,0x6a6f01e1,0x00000000}},	//   _daur, fonf, _søfa,
  { {0x290e25a1,0xcb67005e,0x8ad5000d,0x00000000}},	//   tufa_, ђаје_, уюцц,
  { {0x3e640137,0x6e3c003b,0x7c3b2e68,0x00000000}},	//   _dött_, _iarb, _faur,
  { {0x290e2e69,0xf41f00fe,0x62872e6a,0x00000000}},	//   rufa_, nnät_, zijo,
  { {0x291c2e6b,0xe45f0014,0x3e6400a5,0x00000000}},	//   stva_, lmög_, _fött_,
  { {0x6aa32e6c,0xddce0080,0x09ba0021,0x00000000}},	//   conf, _pobř, _قطاع_,
  { {0xa96a006a,0xb7bd000c,0xca75000d,0x00000000}},	//   _تمام_, deţu, _суты,
  { {0x2cfb00b5,0x649d00cd,0x7c2213bb,0x00000000}},	//   ולטא, néix, nfor,
  { {0x63b60045,0x62871dc1,0x6e3c00dd,0x00000000}},	//   _czyn, tijo, _oarb,
  { {0x86730086,0x644d001f,0x3e640137,0x00000000}},	//   _кліє, _wnai, _möts_,
  { {0x236d034d,0x628709fc,0x9f4b0024,0x00000000}},	//   šej_, rijo, _vecí_,
  { {0x644d075a,0x2d87017d,0x62872e6d,0x00000000}},	//   _unai, únem_, sijo,
  { {0x62870a1c,0xc0c82c9e,0xdef803e6,0x00000000}},	// [4cd0] pijo, туре_, вых_,
  { {0xb0620019,0x63ad00a4,0x765a0137,0x00000000}},	//   äära, _iyan, njty,
  { {0x6e3c2e6e,0x7c3b0290,0x3e640137,0x00000000}},	//   _darb, _paur, _rött_,
  { {0x6e3c004d,0x7d080014,0x7c222e6f,0x00000000}},	//   _earb, _sérð, gfor,
  { {0x6e3c2e70,0x7c3b1962,0x547c009d,0x00000000}},	//   _farb, _vaur, וטאו,
  { {0xddde003b,0x63ad2e71,0x6e3c2e72,0x00000000}},	//   ripţ, _myan, _garb,
  { {0x7c222e73,0x6aa32e74,0x7bd8008f,0x00000000}},	//   bfor, ronf, _šauš,
  { {0x6d4700fe,0xf8a9007e,0x6a7401a8,0x00000000}},	//   _irja, رگاه_, _ràfe,
  { {0x62850122,0x63ad2e75,0xcb340062,0x00000000}},	//   _omho, _nyan, _кетъ,
  { {0xdb0001e1,0xbf5a009d,0x00000000,0x00000000}},	//   _bymæ, ׂ֣ית,   ,
  { {0x63ad0164,0x19940062,0x39452e76,0x00000000}},	//   _ayan, _кафя, _urls_,
  { {0xf2c900b5,0x63ad2e77,0xb4ae0053,0x00000000}},	//   _זע_, _byan, कते_,
  { {0xd7f82049,0x389700dd,0x63ad1645,0x00000000}},	//   _рух_, căra_, _cyan,
  { {0xd295019d,0xe29f0026,0x454501fb,0x00000000}},	//   арсь, kuðu_, _منتق,
  { {0x50960001,0xb7bd003b,0xb882004c,0x00000000}},	//   грађ, reţu, _šíit,
  { {0x388c0080,0x386d1781,0x6e3c2e78,0x00000000}},	//   běru_, nker_, _sarb,
  { {0x386d0ac8,0x63ad2e79,0x7c22169f,0x00000000}},	// [4ce0] iker_, _gyan, vfor,
  { {0x44f1074f,0x9e66007e,0xa01b0014,0x00000000}},	//   oš_, دارن, _umön,
  { {0x386d2e7a,0x85f60047,0x78750024,0x00000000}},	//   kker_, רמעס_, _záve,
  { {0x386d0122,0xbf9b017d,0xeb9a05d2,0x00000000}},	//   jker_, _idên, ние_,
  { {0x6e3c2e7b,0x6285001f,0x7c222e7c,0x00000000}},	//   _tarb, _ymho, rfor,
  { {0x7c222e7d,0x386d2e7e,0x44f12c46,0x00000000}},	//   sfor, eker_, kš_,
  { {0x14cf024c,0x7c222e7f,0x6d430137,0x00000000}},	//   _संगण, pfor, ånat,
  { {0x63a90045,0xa37b017d,0xd943005e,0x00000000}},	//   żeni, lcõe, сећи,
  { {0x44f100eb,0x6a160242,0xeb9701f6,0x00000000}},	//   eš_, _مبار, _бит_,
  { {0x388c0080,0x63ad2e80,0x386d2e81,0x00000000}},	//   věru_, _ryan, aker_,
  { {0x38ba00e8,0xf1a40042,0x48e60094,0x00000000}},	//   eëre_, _खुलन, _соев,
  { {0x2ca62e82,0x386d2e83,0x399b009a,0x00000000}},	//   nood_, cker_, _איבד,
  { {0x657a000f,0x44f101b3,0x6d412e84,0x00000000}},	//   szth, aš_, _álav,
  { {0x2ca60034,0x63ad02ae,0x99850078,0x00000000}},	//   hood_, _vyan, _galų_,
  { {0x2ca60019,0x9f4b00cd,0xf494005d,0x00000000}},	//   kood_, _secà_, _گشود,
  { {0xdd01001c,0xb5a50054,0xd01801ce,0x00000000}},	//   ūtīt, _трій, лфу_,
  { {0x26ce0035,0x2ca609fe,0x4429026a,0x00000000}},	// [4cf0] _kifo_, dood_, _iba_,
  { {0xdd9b0086,0x645d00d1,0xe29f0026,0x00000000}},	//   нше_, ljsi, tuðu_,
  { {0xbc190500,0x261c0042,0x2ca62e85,0x00000000}},	//   вілі_, _मानी_, food_,
  { {0x6dc40121,0xab620058,0x6d4700a8,0x00000000}},	//   ссуж, ğünl, _vrja,
  { {0x44292e86,0x447c0047,0x62950a1e,0x00000000}},	//   _mba_, ענדע, onzo,
  { {0xcb661c7a,0x7dd2013d,0xe29f0014,0x00000000}},	//   раше_, rűsí, puðu_,
  { {0x6295006f,0xe5090053,0x6f0d0139,0x00000000}},	//   inzo, _विधि_, lrac,
  { {0x6f0d0c0c,0xf8650002,0x7c870d34,0x00000000}},	//   orac, рвио, _суге,
  { {0x3775000d,0x386d0f98,0x7c292e87,0x00000000}},	//   рыйс, rker_, _iber,
  { {0x386d02ab,0x44292e88,0xa5250811,0x00000000}},	//   sker_, _aba_, амод,
  { {0x6f0d2e89,0x44f1007d,0xf41f00a5,0x00000000}},	//   hrac, uš_, vnär_,
  { {0x60cf0080,0x44f10c39,0x99640085,0x00000000}},	//   _nicm, rš_, _утул,
  { {0xf41f0137,0x7c260137,0x27ed2e8a,0x00000000}},	//   tnär_, _ökre, mben_,
  { {0x60cf0025,0x27ed2e8b,0x9476007e,0x00000000}},	//   _aicm, lben_, ادگا,
  { {0x7c292e8c,0x6f0d2e8d,0x27ed00a8,0x00000000}},	//   _ober, erac, oben_,
  { {0x629504ad,0x27ed00ea,0x6f0d153e,0x00000000}},	//   anzo, nben_, frac,
  { {0x7eb000fe,0x27ed13ac,0x6f0d2e8e,0x00000000}},	// [4d00] läpi, iben_, grac,
  { {0x7e970021,0x2ca605b6,0x76412e8f,0x00000000}},	//   لنقر_, wood_, ndly,
  { {0x27ed000f,0x2ca60034,0x6be60021,0x00000000}},	//   kben_, tood_, لكام,
  { {0x61fc2e90,0x6f0d2e91,0x4ae60085,0x00000000}},	//   larl, brac, аўка,
  { {0xa01b0137,0x612c00ea,0x6d430137,0x00000000}},	//   _omöj, _fölö, ånar,
  { {0x27ed0199,0x7c292e92,0x60c40ff2,0x00000000}},	//   eben_, _eber, lmim,
  { {0xfa6700d7,0x2ca6004b,0xe2a70014,0x00000000}},	//   рајк_, pood_, úðir_,
  { {0x9179001b,0xec16007e,0x31570047,0x00000000}},	//   _hợp_, _خورد, שיקן_,
  { {0xc6f70088,0x98be000c,0x61fc2e93,0x00000000}},	//   аных_, _artă_, karl,
  { {0x27ed00bd,0xa3bd0053,0x7c2903f5,0x00000000}},	//   aben_, _अरब_, _zber,
  { {0x27ed2d27,0xa9a60086,0x61fc2e94,0x00000000}},	//   bben_, _тижд, darl,
  { {0x61ee2e95,0x6f0d001f,0x3495000d,0x00000000}},	//   ebbl, yrac, самр,
  { {0xec7100b5,0x4736007e,0x443f0066,0x00000000}},	//   פֿט_, _خراز, ľu_,
  { {0x60c40397,0x78750025,0x7d03004a,0x00000000}},	//   emim, _iáva, ánsk,
  { {0x6f0d0051,0xb6bb0063,0x63ba0022,0x00000000}},	//   wrac, _שצוי, ętna,
  { {0x44a40032,0x38a10045,0x61ee0d1e,0x00000000}},	//   _وموق, wórz_, abbl,
  { {0x24892e96,0x61fc2e97,0x6fb902b6,0x00000000}},	// [4d10] _imam_, barl, угар_,
  { {0x27ed000f,0xe45f00c7,0x7e540086,0x00000000}},	//   zben_, ljö_, овує,
  { {0xcdd8005e,0x6f0d2e98,0x7c290023,0x00000000}},	//   рњу_, srac, _pber,
  { {0x3b55000d,0x88bc0080,0xa13600ff,0x00000000}},	//   йкер, _zpěv, _פארק_,
  { {0x7c29004d,0xe29f0014,0x09e50854,0x00000000}},	//   _vber, erði_, болн,
  { {0x533800b5,0x7f3a0047,0x1bb80044,0x00000000}},	//   ינדן_, _געשו, جامع_,
  { {0x27ed000f,0xaa560001,0x6d58004b,0x00000000}},	//   tben_, сију_, ävat,
  { {0x27ed00bd,0x61fc2e99,0x7c292e9a,0x00000000}},	//   uben_, zarl, _uber,
  { {0xbb850032,0x27ed2e9b,0x61fc005b,0x00000000}},	//   _الذي, rben_, yarl,
  { {0xe819016a,0x27ed000f,0x6d4100ea,0x00000000}},	//   _धावा_, sben_, _álas,
  { {0x61fc2e9c,0x04460121,0xb658000d,0x00000000}},	//   varl, бенн, ршых_,
  { {0x2545003d,0x3e760014,0xb4c40042,0x00000000}},	//   _vēl_, _mæta_, ौदे_,
  { {0xd36f0021,0x61fc2e9d,0xb7d20021,0x00000000}},	//   ّهُ_, tarl, _عقوب,
  { {0x61ee2e9e,0xdb06013d,0x91e30cbd,0x00000000}},	//   ubbl, ímén, зоре,
  { {0x95c80001,0x787501c2,0x55f60063,0x00000000}},	//   _кућа_, _záva, _המצב_,
  { {0x349300e1,0x38a10051,0x40790121,0x00000000}},	//   _најр, tóry_, ащую_,
  { {0x63a914b1,0xceea000d,0x200f0451,0x00000000}},	// [4d20] üent, удзе_, ógia_,
  { {0x3e76007a,0x78a92e9f,0xe29f0014,0x00000000}},	//   _bæta_, hoev, yrði_,
  { {0xb5fa0047,0xa0a627b8,0x26c5002b,0x00000000}},	//   רלעכ, _ганд, imlo_,
  { {0xab62005b,0x8c950086,0x628e2ea0,0x00000000}},	//   şüml, орчі, libo,
  { {0x78a92ea1,0x999c009c,0x804b009d,0x00000000}},	//   doev, vevő_, _עֲטֶ,
  { {0x2ce8007e,0x42db0047,0xdee30818,0x00000000}},	//   _نظری_, אקסע, _хори,
  { {0xb5090053,0x88bc0080,0x3e760014,0x00000000}},	//   _विषय_, _opět, _gæta_,
  { {0x7c960021,0xe45f0137,0xf98f0021,0x00000000}},	//   _الرص, xjö_, عبو_,
  { {0x628e0441,0x6b63000d,0xe8190053,0x00000000}},	//   kibo, _екта, _धारा_,
  { {0x8c44000c,0xda650593,0x16d70044,0x00000000}},	//   ăşur, _والي, حذية_,
  { {0x499a005a,0x44990086,0x915f008b,0x00000000}},	//   _стая_, ивою_, _mặt_,
  { {0x7d03006d,0x6aaa05e9,0x7eab004b,0x00000000}},	//   ánsi, loff, hüpp,
  { {0x7eb00072,0x628e00a5,0x938b0f56,0x00000000}},	//   läpu, fibo, усна_,
  { {0x38660104,0x171b0047,0xe45f0137,0x00000000}},	//   _hoor_, _עווע, sjö_,
  { {0x9f5900ac,0x3866056f,0x54e608aa,0x00000000}},	//   _gesê_, _koor_, _استق,
  { {0x76020080,0x6aaa2ea2,0x43952ea3,0x00000000}},	//   bízí, hoff, _майс,
  { {0x9df91a5c,0x2f190085,0x38662ea4,0x00000000}},	// [4d30] инат_, розь_, _moor_,
  { {0x88bc0080,0x394c2ea5,0x3d950121,0x00000000}},	//   _zpět, _ords_, оизр,
  { {0x6aaa002b,0x6d3500f2,0xebd90f56,0x00000000}},	//   doff, تفاض, адеш_,
  { {0x38662ea6,0xf3ff00be,0x351b009a,0x00000000}},	//   _noor_, naã_, רואנ,
  { {0x629a0240,0xbca40021,0x501a009f,0x00000000}},	//   čtov, أمني, _דורו,
  { {0x9962004c,0x6aaa2ea7,0x8de50044,0x00000000}},	//   líře_, goff, _ذكره,
  { {0x48790905,0xbd45007e,0x787501d1,0x00000000}},	//   исия_, _بنزي, _dávn,
  { {0xd7092ea8,0x201b00f5,0x2cbf0150,0x00000000}},	//   ание_, ngqi_, _uhud_,
  { {0x8699000a,0x38660625,0x78a9006f,0x00000000}},	//   итот_, _door_, roev,
  { {0x78a4017f,0x78a9059f,0xddce0066,0x00000000}},	//   čiva, soev, _hlbš,
  { {0xad510054,0x228d00a8,0xa5940094,0x00000000}},	//   здiл, ežko_, зрящ,
  { {0xc3560062,0x9d1a0047,0x61e50046,0x00000000}},	//   оъгъ, סורט, _afhl,
  { {0x628e00bb,0x63ba0051,0xcc3a0047,0x00000000}},	//   tibo, ętno, בערט,
  { {0x7d02001c,0x479a0047,0x7d0000ea,0x00000000}},	//   ņosi, _דינס, _járá,
  { {0x764300e3,0x6e372ea9,0x628e2eaa,0x00000000}},	//   _iany, dexb, ribo,
  { {0x7643014f,0x7ae92eab,0x6031004c,0x00000000}},	//   _hany, _otet, _němč,
  { {0x764300bb,0x9e660086,0x44202eac,0x00000000}},	// [4d40] _kany, овад, _ici_,
  { {0xaec30086,0x27ff00fe,0x644400ac,0x00000000}},	//   дбул, haun_, _haii,
  { {0x27ff0089,0x7875004a,0x76432ead,0x00000000}},	//   kaun_, _návo, _many,
  { {0x61430080,0x6446004e,0x7643255a,0x00000000}},	//   sílá, ndki, _lany,
  { {0x6444002c,0x2b4d00cd,0xe29f0026,0x00000000}},	//   _maii, _crec_, arðu_,
  { {0x76432eae,0x6f042eaf,0xfe790085,0x00000000}},	//   _nany, msic, _лёсы_,
  { {0x386604ff,0x673b0089,0x2714008b,0x00000000}},	//   _poor_, ewuj, òng_,
  { {0x58d3005a,0x64441a61,0x764300a4,0x00000000}},	//   мощт, _naii, _aany,
  { {0x38661fb5,0x7643014f,0x787c00ea,0x00000000}},	//   _voor_, _bany, _néve,
  { {0x0f570063,0xf76f0021,0x64560035,0x00000000}},	//   קיים_, ضاً_, _anyi,
  { {0x2fc700aa,0x386600f5,0x6f04004d,0x00000000}},	//   ̀ng_, _toor_, hsic,
  { {0xb4b50053,0x44201dba,0x6f042eb0,0x00000000}},	//   झते_, _cci_, ksic,
  { {0x76432cdb,0x926b0062,0x78750114,0x00000000}},	//   _fany, арва_, _závo,
  { {0x787c03b2,0x76432eb1,0xe29f0014,0x00000000}},	//   _déve, _gany, yrðu_,
  { {0x20670001,0x44202eb2,0x91480121,0x00000000}},	//   ођав, _fci_, очта_,
  { {0xa2bb0161,0x6f04004d,0x93f5030b,0x00000000}},	//   _शीर्, fsic, _эпиц,
  { {0xcddb2ba9,0x2fcf00c7,0xfe750002,0x00000000}},	// [4d50] ање_, ägg_, плаќ,
  { {0x2714008b,0x2ee60025,0x443914dd,0x00000000}},	//   àng_, íofa_, les_,
  { {0x7ae92eb3,0x44392eb4,0x6b82004d,0x00000000}},	//   _stet, oes_, ezog,
  { {0x2b4d2eb5,0x6f04004d,0x44392eb6,0x00000000}},	//   _prec_, bsic, nes_,
  { {0x09e5253f,0x6d4e2eb7,0x44392eb8,0x00000000}},	//   полн, _erba, ies_,
  { {0x3897000c,0x27e6001f,0x4439081b,0x00000000}},	//   mări_, _afon_, hes_,
  { {0xc27c014e,0x644600ac,0x3897003b,0x00000000}},	//   שרוי, ydki, lări_,
  { {0x44392eb9,0x2b4d2eba,0xdb3b005d,0x00000000}},	//   jes_, _trec_, _پسرش_,
  { {0x76430035,0x3897000c,0x44392ebb,0x00000000}},	//   _pany, nări_, des_,
  { {0x673b1041,0x787500ea,0x4439166f,0x00000000}},	//   rwuj, _távo, ees_,
  { {0x649f0080,0x3a3a0019,0x644400a4,0x00000000}},	//   zšiř, õppe_, _paii,
  { {0x644b007a,0x32cf0051,0x76430035,0x00000000}},	//   _ógil, _użyj_, _wany,
  { {0xe72e0088,0x64960024,0x3897003b,0x00000000}},	//   _яе_, jšie, jări_,
  { {0x11da0021,0xb6cc005b,0x3897003b,0x00000000}},	//   صورة_, şürü, dări_,
  { {0x15fa0063,0x44200150,0x6b82203d,0x00000000}},	//   _ההצע, _tci_, zzog,
  { {0x53a60097,0x2714008b,0x26dd00ac,0x00000000}},	//   _найб, ùng_, _kuwo_,
  { {0x27fd0c70,0x3897000c,0x6f041459,0x00000000}},	// [4d60] _mewn_, gări_, usic,
  { {0x6f042ebc,0x660116b0,0x59cb0053,0x00000000}},	//   rsic, nalk, ाधार,
  { {0x44e100ea,0x6f042ebd,0x61fe001c,0x00000000}},	//   _jó_, ssic, _iepl,
  { {0x44e10027,0x38970529,0x6b82004d,0x00000000}},	//   _mó_, bări_, tzog,
  { {0x38970529,0x66012ebe,0x44e10025,0x00000000}},	//   cări_, kalk, _ló_,
  { {0x63b600fe,0x6b8200bd,0x44392ebf,0x00000000}},	//   _myyn, rzog, zes_,
  { {0x44e12ec0,0xa9670540,0x7c260137,0x00000000}},	//   _nó_, зија_, _ökro,
  { {0x61fe2ec1,0x387f2ec2,0x9f4001a8,0x00000000}},	//   _lepl, ghur_, nciï_,
  { {0x76aa0055,0x44390da1,0x6beb0063,0x00000000}},	//   йтов_, ves_, _הַבַ,
  { {0x44392ec3,0x66012ec4,0x61fe2ec5,0x00000000}},	//   wes_, galk, _nepl,
  { {0x44e100aa,0x27fd0185,0x3897000c,0x00000000}},	//   _có_, _fewn_, zări_,
  { {0x1bf50161,0x44e10025,0x66010019,0x00000000}},	//   आरएल_, _dó_, aalk,
  { {0x61fe0438,0x66010007,0x44390530,0x00000000}},	//   _bepl, balk, res_,
  { {0x44e10139,0x61fe00a8,0x64960066,0x00000000}},	//   _fó_, _cepl, všie,
  { {0x44e10025,0x44392ec6,0x7648002b,0x00000000}},	//   _gó_, pes_, mddy,
  { {0x38970529,0xb97b0047,0x3e640244,0x00000000}},	//   tări_, זנלי, _götz_,
  { {0xe2aa007e,0x44e100ca,0xe81d0042,0x00000000}},	// [4d70] _ژاپن_, _zó_, फलता_,
  { {0xdcfc01f7,0x3897000c,0x1bf50053,0x00000000}},	//   _ayrı, rări_, आरऍल_,
  { {0x3897000c,0x7648002b,0xfd390044,0x00000000}},	//   sări_, iddy, تكاب_,
  { {0x254c0080,0x6a6f04b1,0x69da1b21,0x00000000}},	//   _měl_, _løft, _agte,
  { {0xdb1b008b,0x2e4b0062,0xfebb007e,0x00000000}},	//   _nguô, _ляво_, _هاست_,
  { {0x64960124,0x27fd0168,0x00000000,0x00000000}},	//   ošic, _sewn_,   ,
  { {0x66012ec7,0x3c950121,0x6d34058f,0x00000000}},	//   valk, _живё, _перф,
  { {0x69da021f,0x3158014e,0x44e10025,0x00000000}},	//   _egte, ליון_, _ró_,
  { {0x44e129b9,0x66012ec8,0x46390094,0x00000000}},	//   _só_, talk, очня_,
  { {0x44e12ec9,0xf1c00066,0x6496007d,0x00000000}},	//   _pó_, úšku_, kšic,
  { {0x61fe2eca,0x8ca40053,0x63b60072,0x00000000}},	//   _repl, _कदमो, _syyn,
  { {0x63b6024a,0x69c12ecb,0xc2090ee1,0x00000000}},	//   _pyyn, _izle, _כה_,
  { {0xae1e0235,0x6601024a,0xe5090053,0x00000000}},	//   _पालन_, palk, _विकि_,
  { {0x36c40054,0x67290022,0x44e12ecc,0x00000000}},	//   _збіг, mtej, _tó_,
  { {0x67292ecd,0xd5bb0699,0x629c2541,0x00000000}},	//   ltej, _усд_, rnro,
  { {0x63b600fe,0xa0b5005e,0x7875013d,0x00000000}},	//   _tyyn, ељуј, _sávj,
  { {0xe4c7006a,0xdfcf0754,0x64960240,0x00000000}},	// [4d80] _تصوی, ليف_, ašic,
  { {0xb881004c,0x80be0042,0x29072ece,0x00000000}},	//   _šíle, _वीरे, ksna_,
  { {0xa06a0138,0xf41f0137,0x90c62b4f,0x00000000}},	//   _дана_, miär_, _обое,
  { {0x29070137,0x67292ecf,0x787501c8,0x00000000}},	//   dsna_, ktej, _dávk,
  { {0x7648001f,0x7c650021,0x6d5a2029,0x00000000}},	//   yddy, عامل, _štad,
  { {0x752f0051,0x9f400114,0xaa570699,0x00000000}},	//   łczy, ncií_, дишу_,
  { {0x29070137,0xa01b0137,0x67292ed0,0x00000000}},	//   gsna_, _flöd, etej,
  { {0x6aa100b9,0xb07b0041,0x807b0041,0x00000000}},	//   _ejlf, ַניז, ַניצ,
  { {0x6f16001f,0x9f4001d9,0xba26005e,0x00000000}},	//   nryc, kcií_, _одак,
  { {0x787c0003,0x44320b72,0xb95a0021,0x00000000}},	//   _déva, _aby_, _وجاء_,
  { {0xc58a0076,0x6f16002b,0x6d5a013d,0x00000000}},	//   ющие_, hryc, _átad,
  { {0x7ae00035,0x6f160051,0x291c004b,0x00000000}},	//   _kumt, kryc, muva_,
  { {0x291c2ed1,0xbb3b0047,0x6f160260,0x00000000}},	//   luva_, ֿעלי, jryc,
  { {0xeb910047,0xf7d700ff,0x6f162ed2,0x00000000}},	//   אָל_, _חודש_, dryc,
  { {0x4035050f,0x306b018e,0x3495000d,0x00000000}},	//   невс, ојан_, _пакр,
  { {0xe7480013,0x54a70044,0xdfd5030b,0x00000000}},	//   _kỵ_, _تحتف, еобы,
  { {0x2bd00053,0x93fc009a,0xdd91005d,0x00000000}},	// [4d90] तेमा, _ולחי, گوا_,
  { {0x752f0045,0x645a001c,0x291c0659,0x00000000}},	//   ńcze, ētie, kuva_,
  { {0x7eb000c7,0xdd910021,0xe7480013,0x00000000}},	//   räpp, دوا_, _lỵ_,
  { {0x62952ed3,0x6f160022,0x291c2ed4,0x00000000}},	//   lizo, bryc, duva_,
  { {0x7ae00025,0x60cd2ed5,0x228d00a8,0x00000000}},	//   _cumt, mmam, ežki_,
  { {0x60cd2ed6,0x388c004c,0xdb06004c,0x00000000}},	//   lmam, měry_, ímán,
  { {0x08d500a0,0x63ba0051,0x291c001c,0x00000000}},	//   нция, ętni, guva_,
  { {0x60cd01f7,0x67292ed7,0x69c10ff8,0x00000000}},	//   nmam, ttej, _vzle,
  { {0x62950035,0xb9060053,0x29072ed8,0x00000000}},	//   kizo, _यू_, ssna_,
  { {0x443200f3,0x67292ed9,0x7a540021,0x00000000}},	//   _sby_, rtej, _لضما,
  { {0xc8670062,0x60cd2eda,0x62950331,0x00000000}},	//   _отди, kmam, dizo,
  { {0x4424005b,0x60cd0066,0x629500ca,0x00000000}},	//   üm_, jmam, eizo,
  { {0xafdb00d1,0x78bb004a,0x3945007d,0x00000000}},	//   _unøy, mluv, _hsls_,
  { {0x43750086,0x62952edb,0x60cd2edc,0x00000000}},	//   туют, gizo, emam,
  { {0xe6b4007e,0xa5640021,0x68e10137,0x00000000}},	//   _جلوگ, _لدين, _juld,
  { {0x60cd002c,0x6f162edd,0x2c7e00cd,0x00000000}},	//   gmam, tryc, _oïda_,
  { {0x91e61099,0xaec60d34,0x1fa70713,0x00000000}},	// [4da0] _попе, ебал, екти_,
  { {0x6e46006a,0x7a33005b,0x60cd2ede,0x00000000}},	//   عنام, nıtı, amam,
  { {0xe2a90021,0x6d5a1286,0x7ae02edf,0x00000000}},	//   _تاين_, _štab, _sumt,
  { {0x44222ee0,0x388c004c,0x1be702b6,0x00000000}},	//   ngk_, běry_, едци_,
  { {0x8b660021,0xc4d30041,0x7a330075,0x00000000}},	//   عاصم, אגא_, kıtı,
  { {0x78a200b9,0x68e1005b,0x78bb004b,0x00000000}},	//   _sjov, _buld, eluv,
  { {0x20020150,0x313a0047,0x7875004a,0x00000000}},	//   _keki_, לײַב, _závi,
  { {0x291c0140,0x68e1030c,0xb5090042,0x00000000}},	//   ruva_, _duld, _विजय_,
  { {0x9f402ee1,0x8626000d,0x7d1e2ee2,0x00000000}},	//   ncià_, ньне, lups,
  { {0x68e1010a,0x45d41137,0x3e760014,0x00000000}},	//   _fuld, копс, _bæti_,
  { {0x68e12ee3,0x62952ee4,0x75d4005d,0x00000000}},	//   _guld, vizo, ضيحا,
  { {0x20022ee5,0xe7480013,0x7c222ee6,0x00000000}},	//   _neki_, _tỵ_, ngor,
  { {0x64960078,0x629504a8,0x7def013d,0x00000000}},	//   ušia, tizo, nősü,
  { {0x752b00ea,0x569406da,0x64960078,0x00000000}},	//   élzá, _шалт, ršia,
  { {0x3e76007a,0x60cd005b,0x6d5800a5,0x00000000}},	//   _gæti_, tmam, åval,
  { {0x62950035,0x60cd00a4,0x7c222ee7,0x00000000}},	//   sizo, umam, jgor,
  { {0x2002005b,0x7c221cf2,0x60cd2ee8,0x00000000}},	// [4db0] _deki_, dgor, rmam,
  { {0xa01b004d,0x60cd035c,0x2002004b,0x00000000}},	//   _blöc, smam, _eeki_,
  { {0x98730529,0x60cd005b,0x787c017d,0x00000000}},	//   nţă_, pmam, _névo,
  { {0xf3ff017d,0x7c222ee9,0x6ac90042,0x00000000}},	//   ijão_, ggor, िग्र,
  { {0xbb450189,0x90540085,0xdde3013d,0x00000000}},	//   телк, _свяц, űrőn,
  { {0xff16014e,0xc33400ff,0x20022eea,0x00000000}},	//   _בקשת_, רוס_, _zeki_,
  { {0xaa56005e,0x99800058,0x4993005d,0x00000000}},	//   тију_, ğiş_, دیار,
  { {0x787c0164,0xccf20063,0x9f400290,0x00000000}},	//   _dévo, _ככל_, mbiò_,
  { {0x661500ea,0x3e760014,0x2bd00042,0x00000000}},	//   ózko, _sæti_, तेदा,
  { {0x78bb29c6,0x9f4000be,0xcfca0041,0x00000000}},	//   sluv, nciá_, ומפֿ,
  { {0x764a001f,0xda08005d,0xe5a50152,0x00000000}},	//   _dafy, _سينه_, тини,
  { {0xf770007e,0x64961840,0x7a330058,0x00000000}},	//   _گام_, ašin, sıtı,
  { {0x9873000c,0x9343093e,0x20022eeb,0x00000000}},	//   aţă_, аняе, _reki_,
  { {0x67d40940,0x7c220eb5,0xe7360094,0x00000000}},	//   _сочу, zgor, _реш_,
  { {0x998700eb,0xa0b60001,0x66c60026,0x00000000}},	//   menų_, вљај, uðke,
  { {0x6603024a,0x409502f8,0xa3e80042,0x00000000}},	//   _henk, грут, मुख_,
  { {0x6d470004,0x52aa0001,0x3fe30817,0x00000000}},	// [4dc0] _asja, _овим_, ржув,
  { {0x7d1a0137,0x9f4000cd,0x7c22083f,0x00000000}},	//   _åtsk, rcià_, wgor,
  { {0x66032eec,0x99870006,0x20022eed,0x00000000}},	//   _menk, ienų_, _teki_,
  { {0x7d1e00f3,0x787c0164,0x64860027,0x00000000}},	//   rups, _révo, _dóig,
  { {0x4fa3019d,0x6d552eee,0x7c222eef,0x00000000}},	//   _вияв, _erza, rgor,
  { {0xcb670001,0x290c2ef0,0x7d1e2ef1,0x00000000}},	//   таље_, _pvda_, pups,
  { {0xce370063,0x7c22002b,0xa8a60e82,0x00000000}},	//   _שאלת_, pgor, крик,
  { {0x787c004c,0x00000000,0x00000000,0x00000000}},	//   _vévo,   ,   ,
  { {0x1ae6019d,0x64962ef2,0xf0930132,0x00000000}},	//   _розм, tšin, ינה_,
  { {0x78ad017f,0x64960078,0x99870078,0x00000000}},	//   čava, ušin, genų_,
  { {0xf76f007e,0x660326d3,0x64962a8e,0x00000000}},	//   مای_, _denk, ršin,
  { {0x9873000c,0x7d03017d,0x66030104,0x00000000}},	//   rţă_, ânsi, _eenk,
  { {0x64960078,0xc1eb0121,0x16342ef3,0x00000000}},	//   pšin, дьбе_, _беля,
  { {0x66032ef4,0xfbd3009a,0x92a40896,0x00000000}},	//   _genk, יתר_, ајсл,
  { {0x64961253,0x6720007d,0x66082ef5,0x00000000}},	//   ošil, lumj, madk,
  { {0x66082ef6,0x64960445,0x6603011b,0x00000000}},	//   ladk, nšil, _zenk,
  { {0x44292ef7,0x24992ef8,0x3d050042,0x00000000}},	// [4dd0] _ica_, mism_, हीने_,
  { {0xd904006a,0x644d006f,0x442900b9,0x00000000}},	//   _وی_, _haai, _hca_,
  { {0xf1ab007e,0x644d00f5,0x66080066,0x00000000}},	//   _زاده_, _kaai, iadk,
  { {0x66080089,0x24992ef9,0xa1560063,0x00000000}},	//   hadk, nism_, _עברה_,
  { {0x44291880,0x644d0aba,0xff04000d,0x00000000}},	//   _mca_, _maai, _вясн,
  { {0x2009021f,0x24992d54,0x26dc01b3,0x00000000}},	//   laai_, hism_, _nivo_,
  { {0x44292efa,0xceb20063,0x60dd2efb,0x00000000}},	//   _oca_, _הים_, _kism,
  { {0x66032efc,0xa2bb0053,0x6f0d008f,0x00000000}},	//   _senk, _शीघ्, osac,
  { {0x60dd2efd,0x7c290290,0x66030006,0x00000000}},	//   _mism, _icer, _penk,
  { {0x272b00b9,0x2009006f,0x44292efe,0x00000000}},	//   røn_, haai_, _aca_,
  { {0x3e760026,0x44290d66,0x24992eff,0x00000000}},	//   _gætu_, _bca_, fism_,
  { {0x66030186,0x44e80164,0x3e760026,0x00000000}},	//   _wenk, _dû_, _hætt_,
  { {0xddce0006,0xe7390612,0x66032f00,0x00000000}},	//   _pobū, _чел_, _tenk,
  { {0x479a11b4,0x64860025,0x171a0041,0x00000000}},	//   _אינס, _sóid, _נוצע,
  { {0x60dd2f01,0x6f0d0e1f,0x21750002,0x00000000}},	//   _bism, esac, аутр,
  { {0x24991729,0x27ed2f02,0x9f4b0290,0x00000000}},	//   cism_, ncen_, _recò_,
  { {0xa3d00235,0x27ed0331,0x60dd0725,0x00000000}},	// [4de0] वेश_, icen_, _dism,
  { {0xe1fa0088,0x7c291e1a,0x644d006f,0x00000000}},	//   _яго_, _acer, _zaai,
  { {0x6720007d,0x20090104,0x8db5000d,0x00000000}},	//   zumj, baai_, асці,
  { {0xac250086,0x3b860076,0x764100ea,0x00000000}},	//   ифік, ллег, hely,
  { {0x3e76007a,0x76410006,0x7f760001,0x00000000}},	//   _bætt_, kely, _сунц,
  { {0x7c290150,0x7b06008f,0x67200023,0x00000000}},	//   _ecer, _ērtī, vumj,
  { {0x76412f03,0x64860025,0xdca6019b,0x00000000}},	//   dely, _móib, _бави,
  { {0xe45f0026,0x18740062,0x75210331,0x00000000}},	//   mlög_, ргия, dulz,
  { {0x66080137,0x644d00ac,0x98be003b,0x00000000}},	//   tadk, _raai, _astă_,
  { {0x76412f04,0x27ed006d,0xa5342f05,0x00000000}},	//   gely, acen_, аноч,
  { {0x644d2f06,0x26dc2f07,0xfe9b0063,0x00000000}},	//   _paai, _vivo_, תיימ,
  { {0x69c82f08,0xd3270121,0x66080ff8,0x00000000}},	//   _izde, льги, sadk,
  { {0x66082f09,0xe6c40026,0x60dd0150,0x00000000}},	//   padk, þjóð, _rism,
  { {0x644d006f,0x60dd2f0a,0x1b7b0041,0x00000000}},	//   _waai, _sism, ײטלע,
  { {0x6d5a0024,0x067b014e,0x64860025,0x00000000}},	//   _štan, _אנגל, _dóib,
  { {0x6f0d05e4,0xd5cb089e,0xd51301f3,0x00000000}},	//   tsac, _אֶחָ, _ابوغ,
  { {0x60dd003d,0x20090104,0x2f180121,0x00000000}},	// [4df0] _vism, raai_, лоть_,
  { {0x51870076,0x7c2901f4,0x60dd27c0,0x00000000}},	//   _бума, _scer, _wism,
  { {0x6f0d11eb,0x657a0c4c,0x60dd00dd,0x00000000}},	//   ssac, nyth, _tism,
  { {0x76410058,0x6f0b013d,0x3b550cd6,0x00000000}},	//   zely, ágcs, икер,
  { {0xeab101fb,0xf41f0072,0xefc801ce,0x00000000}},	//   يعت_, yhän_, _бурк_,
  { {0x78750512,0xfaa70076,0xfbd00049,0x00000000}},	//   _návr, ышен, ستن_,
  { {0xf2d40047,0x76412f0b,0xe9690330,0x00000000}},	//   זעס_, vely, тайл_,
  { {0x7af50086,0x76410185,0x69d5004a,0x00000000}},	//   _взає, wely, _územ,
  { {0x62850016,0x76412f0c,0x7875013d,0x00000000}},	//   _olho, tely, _sávs,
  { {0xbb840021,0xf1fb0053,0xab74005e,0x00000000}},	//   _الكي, ्रफ़_, _угуш,
  { {0x657a001f,0x18370021,0x661c2f0d,0x00000000}},	//   gyth, _مرشح, órka,
  { {0x76412f0e,0x752f0051,0x62852f0f,0x00000000}},	//   sely, ńczo, _alho,
  { {0x386d0117,0x3aeb00d1,0x75212f10,0x00000000}},	//   mjer_, _jøp_, sulz,
  { {0x36690001,0x386d02aa,0x471a0047,0x00000000}},	//   _јако_, ljer_, _יונג,
  { {0x62850024,0x3aeb00d1,0x6146015b,0x00000000}},	//   _dlho, _løp_, шева,
  { {0xe0df051e,0x64a3005a,0x386d1ebe,0x00000000}},	//   _ciò_, _маща, njer_,
  { {0x387f0014,0x386d00ca,0x4e0601f6,0x00000000}},	// [4e00] ikur_, ijer_, изаб,
  { {0x7c3d0058,0x22930021,0x387f004b,0x00000000}},	//   _ısra, _وليس, hkur_,
  { {0x387f007a,0x386d2f11,0x629c2f12,0x00000000}},	//   kkur_, kjer_, miro,
  { {0xe5360047,0xf5360047,0x629c2f13,0x00000000}},	//   יטעט_, יטער_, liro,
  { {0xab27005e,0xf4170047,0xddea007e,0x00000000}},	//   иоца_, בֿות_, _لرزه_,
  { {0x291c017f,0x386d00b9,0x629c2f14,0x00000000}},	//   trva_, ejer_, niro,
  { {0x64962e6a,0xadba0044,0x6da32099,0x00000000}},	//   ršij, _شهرا_, _дира,
  { {0x69c8104c,0xa967005e,0xb866007e,0x00000000}},	//   _vzde, рића_, شابو,
  { {0x657a0185,0xe6662d76,0xc7c60121,0x00000000}},	//   wyth, атно, шски,
  { {0x291c10f5,0x2ca62f15,0x7be70023,0x00000000}},	//   prva_, lnod_, āruš,
  { {0x69c8001c,0xd7ef2f16,0x787c2f17,0x00000000}},	//   _uzde, _му_, _lévi,
  { {0x657a0034,0x387f0089,0x2ca6001f,0x00000000}},	//   ryth, ckur_, nnod_,
  { {0x92b70021,0x787c00be,0xa3b40042,0x00000000}},	//   لحسا, _névi, _जुआ_,
  { {0xa01b00ea,0x877b0149,0x68e82f18,0x00000000}},	//   _elöl, _באדי, _kudd,
  { {0x80070cbb,0x224300a5,0xa174012c,0x00000000}},	//   ичае, rejk_, огрі,
  { {0x2730008b,0x61fa005b,0x68e82f19,0x00000000}},	//   oàn_, ıtla, _mudd,
  { {0x0eeb0086,0x629c2f1a,0x7bc0002b,0x00000000}},	// [4e10] тьби_, biro, _nymu,
  { {0x787c0003,0x629c01f4,0x66c60014,0x00000000}},	//   _dévi, ciro, iðko,
  { {0x2ca60185,0xab62005b,0x6d5a00ea,0x00000000}},	//   fnod_, _şüph, _átal,
  { {0xa5d900b5,0x8d280086,0x661d0078,0x00000000}},	//   אַני, роїв_, ėski,
  { {0x7bc0001f,0x6486017d,0x6d4a0014,0x00000000}},	//   _cymu, _jóia, æfar,
  { {0x7bc0001f,0x2ca62f1b,0x8e850021,0x00000000}},	//   _dymu, anod_, _السه,
  { {0x3cf00024,0x68e8001f,0x387f05b5,0x00000000}},	//   ľové_, _cudd, tkur_,
  { {0x7b00000f,0x629c2061,0xbca5013a,0x00000000}},	//   öztá, ziro, _امري,
  { {0x387f0026,0x7bc0001f,0x61e50025,0x00000000}},	//   rkur_, _gymu, _oghl,
  { {0xba740032,0x386d0031,0x68e8001f,0x00000000}},	//   _والت, sjer_, _fudd,
  { {0x629c2f1c,0x68e82f1d,0xa928012c,0x00000000}},	//   viro, _gudd, _віче_,
  { {0x7ae92f1e,0x7ae12f1f,0x0708005d,0x00000000}},	//   _kuet, _hilt, _چيني_,
  { {0x888c0047,0x4393000d,0x27ff04b5,0x00000000}},	//   _בראַ, заўс, mbun_,
  { {0x6d5a017f,0x26d90080,0x787c0164,0x00000000}},	//   _štam, ůsob_, _révi,
  { {0x7ae9024a,0xd1790086,0x787c0003,0x00000000}},	//   _luet, асті_, _sévi,
  { {0x629c00eb,0x7ae900ac,0x6a7d01a8,0x00000000}},	//   siro, _ouet, _dèfi,
  { {0xa01b00c7,0x64460019,0xee3a2f16,0x00000000}},	// [4e20] _glöm, meki, лна_,
  { {0xb2260076,0xdd8f007e,0x42261e51,0x00000000}},	//   _умол, کوم_, _удов,
  { {0x7bc00185,0x64460229,0x27140013,0x00000000}},	//   _symu, oeki, ành_,
  { {0xe046018e,0x7ae10139,0x1d070f55,0x00000000}},	//   _унми, _ailt, сеци_,
  { {0x68e82f20,0x7ae12f21,0x7d1e007d,0x00000000}},	//   _sudd, _bilt, srps,
  { {0xdd200080,0xbae50086,0x60c42f22,0x00000000}},	//   může, іцій, llim,
  { {0x5d860032,0x60c42f23,0x644600fe,0x00000000}},	//   _الأل, olim, keki,
  { {0x69c1001f,0xd90d007e,0x7c95000d,0x00000000}},	//   _dyle, ئین_, _друц,
  { {0x69c1005b,0xc6f7014c,0x3eba006f,0x00000000}},	//   _eyle, бных_, oopt_,
  { {0x7ae101e3,0x86980001,0x95380002,0x00000000}},	//   _gilt, ркос_, азот_,
  { {0x245f024a,0xe72f007e,0xe6d90014,0x00000000}},	//   _nämä_, وصی_, ðráð,
  { {0xab5d0051,0x9964004c,0x64462b02,0x00000000}},	//   _wyże, _kůže_, geki,
  { {0xa01b0137,0xdc9b0063,0x97c60121,0x00000000}},	//   _flöj, ריכל, _уйде,
  { {0x99640080,0x60c42f24,0x68e20025,0x00000000}},	//   _může_, elim, _hiod,
  { {0x7e752f25,0x64462f26,0x9f490139,0x00000000}},	//   _rozp, beki, rcaí_,
  { {0x64a40dd5,0x9f490025,0x60c42f27,0x00000000}},	//   _наја, scaí_, glim,
  { {0x6d4e0cc6,0xa01b0014,0x6d5c095b,0x00000000}},	// [4e30] _asba, _hlök, _arra,
  { {0x443904c6,0x60c42f28,0x0f14012c,0x00000000}},	//   lfs_, alim, ямую,
  { {0x9f590014,0x443900e5,0x60c42f29,0x00000000}},	//   _jesú_, ofs_, blim,
  { {0x106b0021,0x7ae127ab,0x27e60013,0x00000000}},	//   _إحدى_, _silt, _ngon_,
  { {0x7ae10004,0xcb6900e1,0x6d4e2f2a,0x00000000}},	//   _pilt, рале_, _esba,
  { {0x64460051,0x98aa008f,0x4aa80054,0x00000000}},	//   zeki, _ībā_, бкін_,
  { {0x68e22f2b,0x7c3b00a4,0x7ae12f2c,0x00000000}},	//   _biod, _tbur, _vilt,
  { {0x7ae900fe,0x69c1108f,0x58d20259,0x00000000}},	//   _tuet, _vyle, мојт,
  { {0x7c240025,0x7b670b3f,0x200b003b,0x00000000}},	//   óire, _утве, _meci_,
  { {0x69c12f2d,0x2489035d,0x27ff0089,0x00000000}},	//   _tyle, _alam_, sbun_,
  { {0x0446047e,0x64462f2e,0x44392f2f,0x00000000}},	//   оенн, teki, ffs_,
  { {0xf9920063,0x2ee309fe,0x7c2b2f30,0x00000000}},	//   _קרא_, _lijf_, nggr,
  { {0xe60e2ba9,0x78a92f31,0x64462f32,0x00000000}},	//   _од_, mnev, reki,
  { {0x78bb0080,0x2b40005b,0x78a9042e,0x00000000}},	//   louv, çici_, lnev,
  { {0x2cbf0080,0x60c40717,0x64461045,0x00000000}},	//   _okud_, tlim, peki,
  { {0x200b0164,0x53a60086,0x78bb0164,0x00000000}},	//   _ceci_, _майб, nouv,
  { {0x60c400e3,0x200b0729,0x26c50331,0x00000000}},	// [4e40] rlim, _deci_, ollo_,
  { {0x245f024a,0x66cf00d1,0x5d5a0001,0x00000000}},	//   _tämä_, bøke, ијер_,
  { {0x0d860088,0x60c40529,0x200b2f33,0x00000000}},	//   ўлен, plim, _feci_,
  { {0x853a0047,0x0b1a0044,0xbbe90044,0x00000000}},	//   יגעי, لقصة_, مرهم_,
  { {0x69c51255,0x78a92f34,0x2cad007d,0x00000000}},	//   ühen, dnev, _djed_,
  { {0xed5a0001,0x200b003b,0x7c2b00b9,0x00000000}},	//   _ког_, _zeci_, aggr,
  { {0x6d5c0027,0xed580066,0x391400de,0x00000000}},	//   _urra, _éľ_, أوبز,
  { {0xd8b70032,0x26c52f35,0x787c00ea,0x00000000}},	//   يديا_, ello_, _névt,
  { {0xa01b007a,0x76aa07b0,0xc66a005e,0x00000000}},	//   _slök, итов_, ашне_,
  { {0x8c49005b,0xd946005e,0xd6d000f2,0x00000000}},	//   arşı, _мези, عقد_,
  { {0x286a0001,0x994a01a7,0xceb30047,0x00000000}},	//   _врло_, _خلال_, ויז_,
  { {0x78bb0164,0xe3b8005b,0x26c52f36,0x00000000}},	//   couv, ğın_, allo_,
  { {0xe3b801f7,0xc87f00bd,0xc4580076,0x00000000}},	//   şın_, öße_, циях_,
  { {0x628e0034,0x9f59051e,0x659402b6,0x00000000}},	//   ghbo, _gesù_, _налу,
  { {0xd258000d,0xe9ce000d,0x4439004d,0x00000000}},	//   цця_, нкi_, pfs_,
  { {0x248900e3,0x66cf00d1,0x76482f37,0x00000000}},	//   _ulam_, røke, ledy,
  { {0x66cf076c,0x9f340086,0x64860139,0x00000000}},	// [4e50] søke, меті, _móil,
  { {0x2cbf00b9,0x395e004d,0x76482f38,0x00000000}},	//   _skud_, _orts_, nedy,
  { {0x2ee30122,0x38660b10,0x64a4007d,0x00000000}},	//   _vijf_, _onor_, rđiv,
  { {0x764800a4,0x6aaa002b,0x7dd00014,0x00000000}},	//   hedy, enff, _sósí,
  { {0xfb680032,0x78a92f39,0xeaae0156,0x00000000}},	//   قصوى_, vnev, ей_,
  { {0x76480051,0x38660137,0x3211056c,0x00000000}},	//   jedy, _anor_, nazy_,
  { {0x76482f3a,0x69dc0014,0x787c013d,0x00000000}},	//   dedy, _úrel, _névs,
  { {0x08c5005e,0xb4b50082,0x718c009a,0x00000000}},	//   џбин, जको_, יְחַ,
  { {0x78bb0164,0x32112f3b,0x6496085a,0x00000000}},	//   rouv, kazy_, išit,
  { {0x26c50290,0x7afb00a4,0x78bb2f3c,0x00000000}},	//   ullo_, _itut, souv,
  { {0xc8ab005a,0x64860025,0x78a92f3d,0x00000000}},	//   _къде_, _fóil, pnev,
  { {0xc86400a0,0xfbc7007e,0x3ea100a4,0x00000000}},	//   _отчи, فت_, hiht_,
  { {0x69c7010a,0x7528001c,0xd8b80021,0x00000000}},	//   _øjeb, audz, _بدلا_,
  { {0x75281a03,0x64962f3e,0x320c0066,0x00000000}},	//   budz, ešit, údy_,
  { {0x45d20001,0xa06a032d,0xd13200f2,0x00000000}},	//   _пољс, бава_, عمر_,
  { {0xe45f00fe,0xd5b8001c,0x628e2f3f,0x00000000}},	//   llön_, rgāt_, shbo,
  { {0xd0070076,0x1e86000d,0x7ee60021,0x00000000}},	// [4e60] яете_, плам, سكان,
  { {0x64960078,0xef1702fe,0x539b009a,0x00000000}},	//   ršiu, яму_, _ליפו,
  { {0x3f861994,0xf27b0063,0x7afb2f40,0x00000000}},	//   šou_, _הריש, _atut,
  { {0x2b5f01a8,0x236000a8,0x787c006c,0x00000000}},	//   _bruc_, _krij_, _lévr,
  { {0x64860027,0x6f63000d,0xddce0195,0x00000000}},	//   _nóim, _звяз, _dobš,
  { {0x645600e5,0x753d0051,0x38662f41,0x00000000}},	//   _layi, łszy, _snor_,
  { {0xd90d007e,0x64860139,0xadc30013,0x00000000}},	//   لیل_, _póil, _trạc,
  { {0x645600ac,0xd601008b,0x20120058,0x00000000}},	//   _nayi, _đún, nayi_,
  { {0x49080053,0x3b0701e2,0xe7580054,0x00000000}},	//   _सबको_, _нето_, ципі_,
  { {0x9f9701d8,0xbafb014e,0x8b030080,0x00000000}},	//   פדיה_, _להמש, ářen,
  { {0x2fc700aa,0xf76f007e,0x645605b4,0x00000000}},	//   ́ng_, نای_, _bayi,
  { {0x38660529,0x764800d1,0x6f160022,0x00000000}},	//   _unor_, sedy, ksyc,
  { {0x787c0164,0x75280024,0x32112f42,0x00000000}},	//   _févr, sudz, tazy_,
  { {0x6b8200a4,0xb7db009a,0x356a015b,0x00000000}},	//   iyog, _הקדי, _грин_,
  { {0xe63b014e,0xe2c80021,0x31680002,0x00000000}},	//   _התוכ, سوفو_, пшто_,
  { {0x629e2f43,0xa2cd0042,0x2ec50042,0x00000000}},	//   _empo, _दीर्, वत्त,
  { {0x3438007e,0xddeb007e,0xa2b51f1d,0x00000000}},	// [4e70] _رسيد_, مراه_, _обич,
  { {0xdd210006,0x64560075,0xb698009a,0x00000000}},	//   rįžt, _zayi, קֹּת,
  { {0x64960024,0x7afb2f44,0x2d870066,0x00000000}},	//   pšit, _stut, áne_,
  { {0x317e00bd,0x2d810168,0x00000000,0x00000000}},	//   ätze_, ryhe_,   ,
  { {0x61ec00ea,0x2d87143a,0xaab9005d,0x00000000}},	//   _állá, šne_, يدتر_,
  { {0x64860025,0x9f04009e,0xa96902fa,0x00000000}},	//   _róim, _سوفو, жика_,
  { {0xa2a0016a,0x6d5a007d,0xfa56005d,0x00000000}},	//   _ऑगस्, _štav, برنگ,
  { {0x08d4000d,0x2b5f2f45,0xa7650054,0x00000000}},	//   нцыя, _truc_, дкид,
  { {0x6605004b,0x999e0078,0x6008009a,0x00000000}},	//   _õhkk, _batų_, הִתְ,
  { {0x64562f46,0x45850d34,0x64961058,0x00000000}},	//   _sayi, дгов, jšir,
  { {0x64560034,0xe3b8005b,0x20120150,0x00000000}},	//   _payi, ğım_, yayi_,
  { {0xe3b8005b,0x03a62a35,0x6aa32f47,0x00000000}},	//   şım_, димо, linf,
  { {0x67290bc6,0x7983001f,0x6aa30022,0x00000000}},	//   quej, lynw, oinf,
  { {0xa50901aa,0x23600122,0x3f8c008f,0x00000000}},	//   _дека_, _vrij_, _ādu_,
  { {0x2d1c0053,0x64562f48,0x41b50062,0x00000000}},	//   _पटेल_, _tayi, естт,
  { {0xf41f0072,0xa0672183,0x64b60044,0x00000000}},	//   lkän_, маса_, _تحتر,
  { {0x8fa30245,0x6aa3073a,0x649600a8,0x00000000}},	// [4e80] вате, kinf, bšir,
  { {0x752f0022,0xc3c9043e,0x59dd0042,0x00000000}},	//   ńczu, _عظيم_, मधार,
  { {0x6aa3250a,0xfe790121,0xb05b0050,0x00000000}},	//   dinf, чёты_, _ikän,
  { {0x44f3001b,0xcea9009f,0xc1730063,0x00000000}},	//   _mã_, בי_, _סחר_,
  { {0x4bda007e,0xcce50021,0x44f32f49,0x00000000}},	//   آباد_, رسمي, _lã_,
  { {0x39450150,0x6aa32f4a,0x7983002b,0x00000000}},	//   _bpls_, ginf, fynw,
  { {0xa9672f4b,0x44f30013,0x9f4b0014,0x00000000}},	//   дија_, _nã_, élög_,
  { {0x64961c7b,0xd90d007e,0x17540094,0x00000000}},	//   zšir, صیه_, евия,
  { {0xb05b00c7,0xab65001c,0x6d5e00d1,0x00000000}},	//   _okän, _peļņ, lvpa,
  { {0xda660067,0x6aa300e5,0x7983002b,0x00000000}},	//   _تاري, cinf, bynw,
  { {0x98a7004c,0x7e7c081b,0x15140085,0x00000000}},	//   ntně_, _morp, эдня,
  { {0x9f402f4c,0x25fe0161,0x7ae800b9,0x00000000}},	//   nció_, _श्री_, _hidt,
  { {0xbf9b00e8,0x69c8035a,0xddce0022,0x00000000}},	//   _leêr, _hyde, _jabł,
  { {0x44f3017d,0x98a7004c,0x7e7c2300,0x00000000}},	//   _fã_, ktně_, _norp,
  { {0x7ae82f4d,0x9f4000ea,0x44f30013,0x00000000}},	//   _midt, kció_, _gã_,
  { {0x442f0146,0x7afc00c2,0xd0d40062,0x00000000}},	//   _øg_, _črtn, восъ,
  { {0x6aa300ac,0xddd5004c,0x24840072,0x00000000}},	// [4e90] yinf, _pozů, ömme_,
  { {0x7e7c1b2d,0x7e550021,0x765a0ede,0x00000000}},	//   _corp, عناص, ndty,
  { {0x44f3001b,0x7e7c0179,0xa6e20014,0x00000000}},	//   _xã_, _dorp, _íðus,
  { {0x7e7c0025,0x6ab90053,0x2bd30082,0x00000000}},	//   _eorp, ेत्र, _तरदा,
  { {0x6d5a2f4e,0x9098005a,0x7e7c0831,0x00000000}},	//   _štat, _цвят_, _forp,
  { {0x9f400994,0x765801d9,0x69c81351,0x00000000}},	//   ació_, _navy, _byde,
  { {0x09f60021,0x6aa32f4f,0xbc95005e,0x00000000}},	//   رفية_, rinf, _завј,
  { {0x9f400994,0x6aa32f50,0xc0520063,0x00000000}},	//   cció_, sinf, ָ֖ה_,
  { {0xe7a90612,0xf41f0072,0xb6cc0058,0x00000000}},	//   явил_, tkän_, ğünü,
  { {0xb6cc01f7,0xe3b8005b,0xa01b004d,0x00000000}},	//   şünü, şık_, _klös,
  { {0x9f40051e,0xddce0022,0xf41f0050,0x00000000}},	//   nciò_, _zabł, rkän_,
  { {0xb05b00c7,0xe7950002,0x44f32f49,0x00000000}},	//   _skän, _пиењ, _vã_,
  { {0xf7450055,0x7dee00ea,0xd8380085,0x00000000}},	//   _чело, nősí, _цэх_,
  { {0x76580078,0x6d550022,0xa01b00a5,0x00000000}},	//   _gavy, _osza, _olös,
  { {0x64a60088,0x673b2f51,0x61432f52,0x00000000}},	//   _пака, ltuj, лера,
  { {0xa0b50138,0x7e7c2f53,0x645a008f,0x00000000}},	//   вљуј, _sorp, ētis,
  { {0x7bc90035,0x3cff007d,0x44202f54,0x00000000}},	// [4ea0] _nyeu, _čuva_, _idi_,
  { {0x673b2f55,0x2caf0014,0xa01b00a5,0x00000000}},	//   ituj, engd_, _slöt,
  { {0x44200150,0x61460699,0x9f590331,0x00000000}},	//   _kdi_, _џема, _besó_,
  { {0x673b2f56,0x7ae80137,0x4420004c,0x00000000}},	//   ktuj, _sidt, _jdi_,
  { {0x98a70080,0x80630076,0x9f402ee1,0x00000000}},	//   stně_, _свяж, rció_,
  { {0xada62f57,0x6f042f58,0x673b00a8,0x00000000}},	//   _загл, mpic, dtuj,
  { {0x9f402f59,0x6ee90006,0x7ae82f5a,0x00000000}},	//   pció_, _užba, _vidt,
  { {0x76580006,0x7ae81e5b,0x6f042f5b,0x00000000}},	//   _savy, _widt, opic,
  { {0x765800eb,0x69c700b9,0x64a400ea,0x00000000}},	//   _pavy, _øjen, tőin,
  { {0x69c82f5c,0x66cf00d1,0x6f0401f4,0x00000000}},	//   _tyde, søkn, ipic,
  { {0x765a2f5d,0x3495005e,0x64a4013d,0x00000000}},	//   rdty, ванр, rőin,
  { {0xd5b7000d,0x2ebe0053,0xc9b7009a,0x00000000}},	//   эсы_, ्तुत, _אהבת_,
  { {0x366a0076,0x78a2017f,0x4420001f,0x00000000}},	//   _надо_, _imov, _ddi_,
  { {0x44202f5e,0xa6aa007e,0x26b6030b,0x00000000}},	//   _edi_, _عاشق_, _ящер,
  { {0xe5f7014e,0x7c2000c3,0x442018c3,0x00000000}},	//   _אזור_, _odmr, _fdi_,
  { {0x30a4200c,0x44202f5f,0xd018030b,0x00000000}},	//   грув, _gdi_, ефф_,
  { {0x6d47007a,0x752f0051,0x7ff4007e,0x00000000}},	// [4eb0] _spja, ącze, اسفا,
  { {0x644f2f60,0x442008c4,0x9f540085,0x00000000}},	//   leci, _zdi_, ывуч,
  { {0x44200185,0x6d5a1c0d,0x64ab004c,0x00000000}},	//   _ydi_, _štar, přid,
  { {0x9f40051e,0x644f2f61,0x673b2f62,0x00000000}},	//   rciò_, neci, ytuj,
  { {0x9f400290,0x60cd005b,0x20092f63,0x00000000}},	//   sciò_, mlam, mbai_,
  { {0x7dee000f,0x644f017d,0xe9a9007e,0x00000000}},	//   rősí, heci, وگان_,
  { {0xf2d40047,0x644f017e,0x60cd2f64,0x00000000}},	//   װעק_, keci, olam,
  { {0x673b024a,0xd5b1008b,0x60cd132d,0x00000000}},	//   ttuj, hác_, nlam,
  { {0x75280045,0x645d00d1,0x7d1c00c2,0x00000000}},	//   erdz, ddsi, _zvrs,
  { {0x2d850004,0xf41f00c7,0x273900cd,0x00000000}},	//   _üles_, skäl_, rèn_,
  { {0x44200150,0x673b2f65,0x45d50062,0x00000000}},	//   _pdi_, stuj, ъцит,
  { {0x273900cd,0x64a6000d,0x644f0331,0x00000000}},	//   pèn_, тама, geci,
  { {0x96b50001,0x289a0047,0x60cd2f66,0x00000000}},	//   _искљ, _קינא, dlam,
  { {0xcb120063,0x60cd0214,0x672901e1,0x00000000}},	//   שלם_, elam, mrej,
  { {0xa5640032,0x644f2f67,0x6729013d,0x00000000}},	//   _مدين, beci, lrej,
  { {0x68fc000f,0x44200035,0x60cd2f68,0x00000000}},	//   _érde, _udi_, glam,
  { {0x7d1c007d,0x68eb2f69,0x225a0078,0x00000000}},	// [4ec0] _svrs, _migd, _tapk_,
  { {0xe1fa03d1,0xaefb008b,0x76412f6a,0x00000000}},	//   _юго_, _trùn, nfly,
  { {0xe0da0138,0x32180592,0x6026036a,0x00000000}},	//   _ово_, mary_, _идна,
  { {0x60cd0469,0x1d07005e,0x68eb14e2,0x00000000}},	//   clam, теци_, _nigd,
  { {0x60c400fe,0x24800051,0x672900b9,0x00000000}},	//   moim, _moim_, jrej,
  { {0x644f0045,0x32180034,0x2492001f,0x00000000}},	//   zeci, nary_, _llym_,
  { {0x764118a4,0x7d1c082a,0x67292f6b,0x00000000}},	//   dfly, _uvrs, erej,
  { {0x7d5700b5,0x60c40072,0x752808b7,0x00000000}},	//   _בילד_, noim, vrdz,
  { {0xf62a0086,0x98b70062,0x67292f6c,0x00000000}},	//   міни_, ълът_, grej,
  { {0x60c40025,0x3aeb007e,0xe6660002,0x00000000}},	//   hoim, _قبلی_, ттио,
  { {0x60cd005b,0xd5b00021,0xb05b0137,0x00000000}},	//   ylam, صفح_, _skäm,
  { {0x9169008b,0x746b0330,0x291e2f6d,0x00000000}},	//   hực_, фров_, _ivta_,
  { {0x645d0a06,0x24840137,0x644f2f6e,0x00000000}},	//   rdsi, ömma_, reci,
  { {0x46a3005a,0xc7d70063,0x644f2f6f,0x00000000}},	//   _качв, _סוגי_, seci,
  { {0x60cd2f70,0xb6d90047,0x644f2c1c,0x00000000}},	//   tlam, _אַקט, peci,
  { {0x64860025,0xf0b402fe,0x291c004b,0x00000000}},	//   _sóiv, айсь, isva_,
  { {0x9ed90189,0x6d5a007d,0x20090078,0x00000000}},	// [4ed0] емат_, _štap, rbai_,
  { {0xd25104de,0x60cd2f71,0x291c004b,0x00000000}},	//   _اند_, slam, ksva_,
  { {0x67290066,0x60cd2f72,0xe139012c,0x00000000}},	//   zrej, plam, _язні_,
  { {0xbb950062,0x6729069f,0x1b190121,0x00000000}},	//   лаещ, yrej, ежды_,
  { {0x7641001f,0x68eb2f73,0x0c240454,0x00000000}},	//   yfly, _rigd, рмін,
  { {0x6729017f,0xbbd30053,0xc959005e,0x00000000}},	//   vrej, _तरीक, ешиц_,
  { {0xc27c0063,0x3f89002b,0x98ac0058,0x00000000}},	//   ורגי, lyau_, _ardı_,
  { {0x88c50080,0xc1740063,0x69c701e1,0x00000000}},	//   _ověř, שחק_, _øjem,
  { {0x67290ffe,0xf094009f,0xd6390054,0x00000000}},	//   urej, ינק_, няні_,
  { {0x67292f74,0x64ab0080,0x249200a3,0x00000000}},	//   rrej, yřic, _slym_,
  { {0x672900b9,0x76412f75,0x34aa032d,0x00000000}},	//   srej, rfly, евно_,
  { {0x67292f76,0x764108a9,0x32180ac3,0x00000000}},	//   prej, sfly, wary_,
  { {0x32180037,0x60c400fe,0x66cf00d1,0x00000000}},	//   tary_, voim, nøkk,
  { {0x78a92f77,0xb6071705,0x64ab004c,0x00000000}},	//   liev, _рядк, třic,
  { {0x32180037,0x60c42f78,0x26c52f79,0x00000000}},	//   rary_, toim, molo_,
  { {0xa0a30002,0x321800e5,0x2ebe0082,0x00000000}},	//   басд, sary_, ्त्त,
  { {0xddd50114,0x60c42f7a,0x3218056c,0x00000000}},	// [4ee0] _rozš, roim, pary_,
  { {0x6ee90006,0xee371321,0x78a92f7b,0x00000000}},	//   _užbl, лну_, hiev,
  { {0x60c40016,0x91690013,0x26c501f4,0x00000000}},	//   poim, rực_, iolo_,
  { {0x317b0047,0x20562f7c,0x00000000,0x00000000}},	//   _נאכד, _стор,   ,
  { {0x26c52f7d,0x8f750054,0xa3aa0042,0x00000000}},	//   kolo_, _курі, _गेम_,
  { {0xc3330132,0x628e1837,0x98a000a8,0x00000000}},	//   מוד_, nkbo, čič_,
  { {0x26c52f7e,0x00000000,0x00000000,0x00000000}},	//   dolo_,   ,   ,
  { {0x6b8d00ea,0x7d031912,0x6cd60044,0x00000000}},	//   öngé, ínse, _إقرا,
  { {0x628e00d1,0xc7c60121,0x8ee50082,0x00000000}},	//   kkbo, ыски, _ढ़ूँढ़_,
  { {0x0f57014e,0x9b930032,0x26c52f7f,0x00000000}},	//   ניים_, _الكت, golo_,
  { {0x6475013c,0x88c5004c,0x45d41326,0x00000000}},	//   агну, _svěř, ронс,
  { {0x26c52f80,0x628e2f81,0xc985005e,0x00000000}},	//   aolo_, ekbo, _туђи,
  { {0x26c52f82,0x752f0051,0x2455005d,0x00000000}},	//   bolo_, ącza, هنگس,
  { {0x26c52f83,0xb05b0072,0x7d190022,0x00000000}},	//   colo_, _ikäi, ąwsz,
  { {0x644000cd,0x661a0556,0x11280054,0x00000000}},	//   òmic, matk, люти_,
  { {0x88bc0080,0x6aaa2f84,0x98a7000c,0x00000000}},	//   _uvěd, hiff, mună_,
  { {0x3f8f0026,0xb4c30053,0x88c5004c,0x00000000}},	// [4ef0] águ_, ्ती_, _uvěř,
  { {0x661a000f,0xe3b80058,0xc7d70063,0x00000000}},	//   natk, ğıt_, רומי_,
  { {0xf1ab007e,0x3ced008f,0x5d5504c3,0x00000000}},	//   _ساده_, _piev_, ркет,
  { {0x661a0397,0x26c501f4,0x23692f85,0x00000000}},	//   hatk, zolo_, _kraj_,
  { {0x661a0c85,0x7e2b000d,0x93fc0041,0x00000000}},	//   katk, _піва_, גלדי,
  { {0xb4c30161,0x44fa00ac,0x661a2f86,0x00000000}},	//   ्तु_, _oë_, jatk,
  { {0x78a902b0,0x26c5051e,0x661a1e2d,0x00000000}},	//   tiev, volo_, datk,
  { {0xf0920047,0x661a008f,0x7d01003b,0x00000000}},	//   ַני_, eatk, _cârţ,
  { {0x26c502f6,0x661a00e3,0x6c840021,0x00000000}},	//   tolo_, fatk, _القم,
  { {0x26c50290,0x0f580047,0x78a90717,0x00000000}},	//   uolo_, ריזם_, siev,
  { {0x78a9001c,0x26c50db9,0x7afc00c2,0x00000000}},	//   piev, rolo_, _črti,
  { {0xe3660856,0x26c52ae4,0x6675007e,0x00000000}},	//   акми, solo_, ادکر,
  { {0x661a0974,0x26c5051e,0x64860025,0x00000000}},	//   batk, polo_, _sóis,
  { {0x412a1b79,0x27ff24b9,0x64860025,0x00000000}},	//   кого_, lcun_, _cóir,
  { {0x7c3b2f87,0x6b8b2f88,0xe5a20001,0x00000000}},	//   _ocur, hygg, _миши,
  { {0x7bcd001c,0x2b4d059e,0x6aaa004d,0x00000000}},	//   ļauj, _opec_, ziff,
  { {0xb4d20053,0xee3a150f,0xa3e50053,0x00000000}},	// [4f00] वती_, кна_, भेद_,
  { {0x7c3b2f89,0x9d460121,0x531b0041,0x00000000}},	//   _acur, иезд, _שויצ,
  { {0xc27b0063,0xed36000d,0x2b4d2f8a,0x00000000}},	//   _סרטי, рэзэ, _apec_,
  { {0x8c462f8b,0xdd8f0049,0xeb0622f2,0x00000000}},	//   реде, بوم_, ачко,
  { {0x661a1472,0xbb43055d,0x6aaa00e5,0x00000000}},	//   yatk, жечк, tiff,
  { {0x3eb8007d,0x7c3b2f8c,0xa176009a,0x00000000}},	//   _ujrt_, _ecur, ֹעֵד_,
  { {0x661a2f8d,0x6aaa2f8e,0x6e47013d,0x00000000}},	//   vatk, riff, ésbő,
  { {0x6d5c2f8f,0x6aaa0137,0x661a0dde,0x00000000}},	//   _isra, siff, watk,
  { {0xd6da1087,0x69c500bd,0x290500a8,0x00000000}},	//   кто_, üher, _etla_,
  { {0x7afd02dd,0x752f0051,0x56780062,0x00000000}},	//   _ésta, ączn, убоя_,
  { {0x20000024,0x661a2f90,0xb05b0072,0x00000000}},	//   kcii_, ratk, _ikäv,
  { {0x661a028d,0x20d7005b,0xb4c30053,0x00000000}},	//   satk, eçin_, ्ते_,
  { {0x661a0397,0x64860025,0x98a72f91,0x00000000}},	//   patk, _póir, atnē_,
  { {0x98a7000c,0x23690066,0x6d4e01e1,0x00000000}},	//   pună_, _vraj_, _opba,
  { {0x30a72f92,0xa0a7226a,0x067b009a,0x00000000}},	//   арав, ашал, _בנגל,
  { {0x64a40141,0xe3b80058,0x64c404a0,0x00000000}},	//   _маја, ğır_, _ويول,
  { {0xe3b8005b,0x6d5c017e,0x6d4e008f,0x00000000}},	// [4f10] şır_, _asra, _apba,
  { {0x7c3b09ee,0x443915e8,0x425501fb,0x00000000}},	//   _scur, lgs_, _اندر,
  { {0x2d872f93,0x66180058,0xe2a60014,0x00000000}},	//   âne_, _mevk, _íðan_,
  { {0x44392f94,0x31560047,0x6722085a,0x00000000}},	//   ngs_, _פירן_, _ovoj,
  { {0x69da2f95,0x6d5c0058,0x62852f96,0x00000000}},	//   _azte, _esra, _koho,
  { {0x62852f97,0x5a47000d,0x6b8b2f98,0x00000000}},	//   _joho, рэда, rygg,
  { {0x69da0051,0x8d950021,0x62852f99,0x00000000}},	//   _czte, _الأش, _moho,
  { {0x27ff0003,0x96010053,0x20192cea,0x00000000}},	//   ucun_, ोर्ट_, _jesi_,
  { {0xb8fe0161,0x20192f9a,0xd7060076,0x00000000}},	//   _दी_, _mesi_, бные_,
  { {0x27ff19b9,0xf669014d,0x661800a8,0x00000000}},	//   scun_, احظه_, _cevk,
  { {0x752f0051,0x79a72f9b,0xfe9a009a,0x00000000}},	//   ączo, _трае, ריתמ,
  { {0x64860025,0x7c390b7a,0x44392f9c,0x00000000}},	//   _cóip, ngwr, ggs_,
  { {0x26d90994,0xc7f60063,0xe60e2f9d,0x00000000}},	//   ïsos_, _הזנת_, _нд_,
  { {0xcb12014e,0xd2950086,0x238a0078,0x00000000}},	//   הלך_, орсь, vėją_,
  { {0x2019053b,0xdddc000c,0x40962f9e,0x00000000}},	//   _besi_, _morţ, брат,
  { {0x387f2f9f,0x66180058,0x10a31326,0x00000000}},	//   njur_, _zevk, писн,
  { {0xa067011c,0x20000ea4,0xd5b10013,0x00000000}},	// [4f20] щата_, rcii_, iám_,
  { {0x1fb515d4,0xe45f0137,0xdc100053,0x00000000}},	//   істр, slöt_, ार्ड_,
  { {0x387f0026,0xcf890149,0x6df9014b,0x00000000}},	//   kjur_, עט_, рхус_,
  { {0x20190035,0x62850089,0xeb9a17db,0x00000000}},	//   _gesi_, _zoho, лие_,
  { {0x387f00c7,0x64ab004c,0x38c8005d,0x00000000}},	//   djur_, dřil, یابی_,
  { {0x6e960032,0x5e960021,0x6d5c0025,0x00000000}},	//   _السا, _السط, _tsra,
  { {0xbad5000d,0x6d5c0089,0x67222fa0,0x00000000}},	//   ціцы, _usra, _svoj,
  { {0x387f0026,0x6618005b,0x8c432977,0x00000000}},	//   gjur_, _sevk, _несе,
  { {0xdddc000c,0x7f4404d4,0x6720007d,0x00000000}},	//   _forţ, ntiq, usmj,
  { {0x644000cd,0x3ce625ba,0x1f5b03c3,0x00000000}},	//   òmin, lmov_, נדיא,
  { {0x984a005a,0x69960086,0xd6d90022,0x00000000}},	//   _бяла_, _урах, atło_,
  { {0xc97701f9,0x67220648,0x228f004b,0x00000000}},	//   _לגבי_, _tvoj, _tükk_,
  { {0x20192fa1,0xc5f8001c,0x62852fa2,0x00000000}},	//   _resi_, ldēm_, _poho,
  { {0x20190351,0xc5940002,0xc513005d,0x00000000}},	//   _sesi_, _милј, _کبوت,
  { {0x20190290,0x55060001,0x41e4000d,0x00000000}},	//   _pesi_, _учла, зіта,
  { {0x3eaa006f,0xb5b70063,0x3ce61e9f,0x00000000}},	//   _ambt_, _ללוח_, jmov_,
  { {0x628501c2,0x2019021e,0x44292fa3,0x00000000}},	// [4f30] _toho, _vesi_, _ida_,
  { {0x395e0e7c,0x68fa2fa4,0xa01b00ca,0x00000000}},	//   _osts_, _outd, _zoöl,
  { {0x7f440003,0x20192fa5,0x2737004c,0x00000000}},	//   atiq, _tesi_, ožná_,
  { {0x3e850080,0xfc30006a,0x9cc80121,0x00000000}},	//   _sítě_, فحه_, быча_,
  { {0x644d0027,0xa03a00b5,0x903a00b5,0x00000000}},	//   _mbai, _דערפ, _דערה,
  { {0x660d007d,0xd5b70121,0x7c39002b,0x00000000}},	//   _đako, ́сь_, sgwr,
  { {0x644d0027,0x09e2000a,0x64ab0080,0x00000000}},	//   _obai, мошн, třil,
  { {0x7afd02dd,0x6d450025,0x6f0d006f,0x00000000}},	//   _ésto, mtha, opac,
  { {0x6604005b,0x7c2906a5,0x387f003b,0x00000000}},	//   _şika, _ider, rjur_,
  { {0x4429014f,0x2caf0122,0x644d2fa6,0x00000000}},	//   _ada_, ligd_, _abai,
  { {0x7afb0072,0x20d70058,0xe4520021,0x00000000}},	//   _huut, eçim_, وضح_,
  { {0x6d450185,0x2caf0122,0x44292493,0x00000000}},	//   itha, nigd_, _cda_,
  { {0x44290185,0x4393000d,0x7afb0659,0x00000000}},	//   _dda_, даўс, _juut,
  { {0x7afb0f75,0x3ce625ba,0xf6e70a29,0x00000000}},	//   _muut, zmov_, _уцен,
  { {0x0446011c,0xd1750121,0xf41f0072,0x00000000}},	//   _дейн, пыты, tkät_,
  { {0x629c04a3,0x7c291923,0xdddc004c,0x00000000}},	//   shro, _nder, _norš,
  { {0x2caf0122,0x7afb00e8,0x3f67005a,0x00000000}},	// [4f40] digd_, _nuut, оито_,
  { {0x44292fa7,0xcdd60001,0x6d452e58,0x00000000}},	//   _zda_, оцењ, ftha,
  { {0x22582ac2,0xbfa3001b,0x7f440623,0x00000000}},	//   merk_, _hiể, stiq,
  { {0xbfa3001b,0xa3be0053,0x7f4400f4,0x00000000}},	//   _kiể, _आशा_, ptiq,
  { {0x7c290185,0xdee606be,0x6d452fa8,0x00000000}},	//   _dder, _моми, atha,
  { {0x7c2901f7,0x752f0045,0x6da605ce,0x00000000}},	//   _eder, ńczy, _дига,
  { {0x7c240025,0xb05b0b6e,0xfaa30002,0x00000000}},	//   óirs, _fjäd, ќајо,
  { {0xd90d007e,0x2c100082,0x6fde0082,0x00000000}},	//   این_, ारओं_, _मरां,
  { {0xda0b0235,0x22582a40,0x8b66007e,0x00000000}},	//   _स्वत_, kerk_, _بازم,
  { {0x09e606b4,0xd6da0699,0xe7e00053,0x00000000}},	//   _дозн, јти_, खेगा_,
  { {0x7c29010a,0xa806000d,0x44292fa9,0x00000000}},	//   _yder, _дзел, _pda_,
  { {0xbfa3008b,0xe4a70086,0xc87f004d,0x00000000}},	//   _biể, ірно, ößt_,
  { {0x443f001c,0x6d45013d,0x6842004c,0x00000000}},	//   ļu_, ztha, _vůdč,
  { {0x443f0051,0x0204000d,0x6d4500f1,0x00000000}},	//   żu_, дзён, ytha,
  { {0x60d6001f,0x34952faa,0x7ea0004d,0x00000000}},	//   flym, _накр, _köpf,
  { {0x66cf0031,0xd5b90086,0x212d00c2,0x00000000}},	//   søkt, _усі_, čeh_,
  { {0x68e20139,0x644100ea,0x6f0d2fab,0x00000000}},	// [4f50] _mhod, őlis, upac,
  { {0xa2b40055,0x7d6b06f0,0x7afb0213,0x00000000}},	//   _обыч, ишев_, _ruut,
  { {0x2caf006f,0x68e2027d,0x7afb021e,0x00000000}},	//   tigd_, _ohod, _suut,
  { {0x6d45018d,0x7afb003a,0x6f0d2030,0x00000000}},	//   rtha, _puut, ppac,
  { {0x0f7900b5,0x60cd0072,0x907a0063,0x00000000}},	//   _האָב, moam, _הטרי,
  { {0x7ce3004b,0x53380063,0xda621213,0x00000000}},	//   kõrg, קנון_, евши,
  { {0x26cc25e5,0xdcff008f,0x66f20022,0x00000000}},	//   dodo_, ēvēt, _ałko,
  { {0x60cd2fac,0x7785005a,0x41bc0063,0x00000000}},	//   noam, злиз, יצוע,
  { {0x64ab0080,0xd7060121,0xe7310044,0x00000000}},	//   přij, пные_, رصة_,
  { {0x26cc0331,0x60cd2fad,0x00000000,0x00000000}},	//   godo_, hoam,   ,
  { {0x22582fae,0xd46a173e,0xf50505ac,0x00000000}},	//   verk_, бине_, язно,
  { {0x22582d1a,0x60cd0072,0x2a651ab2,0x00000000}},	//   werk_, joam, _halb_,
  { {0x26cc00c3,0x68e92faf,0x22582fb0,0x00000000}},	//   bodo_, mmed, terk_,
  { {0x68e215f4,0x2cbf00c7,0x98a00006,0x00000000}},	//   _zhod, _ljud_, čią_,
  { {0x66cf0031,0x40962fb1,0x24890783,0x00000000}},	//   søks, прат, _foam_,
  { {0xb05b01e3,0xbfa3008b,0xf41f0137,0x00000000}},	//   _skär, _tiể, skär_,
  { {0x22582ac2,0xdfd20021,0x44222fb2,0x00000000}},	// [4f60] perk_, ريط_, mak_,
  { {0x44222fb3,0x22160121,0x2cbf004b,0x00000000}},	//   lak_, _эфир, _ajud_,
  { {0x2cbf00c7,0x78bb007c,0x68e92fb4,0x00000000}},	//   _bjud_, knuv, kmed,
  { {0x44222fb5,0xb17b009d,0x00000000,0x00000000}},	//   nak_, _הטטר,   ,
  { {0x68e22fb6,0x4422013d,0xf236009d,0x00000000}},	//   _rhod, iak_, ֤רֶץ_,
  { {0x68e202f4,0x44220397,0x2a6500cd,0x00000000}},	//   _shod, hak_, _calb_,
  { {0x20070045,0x44221d29,0xceb30041,0x00000000}},	//   śnie_, kak_, _טיש_,
  { {0x4422134f,0x7ce30019,0xa7740141,0x00000000}},	//   jak_, võrg, длич,
  { {0x442209e8,0x26cc0fbe,0x68e22fb7,0x00000000}},	//   dak_, todo_, _vhod,
  { {0x7bcd003d,0x60cd20c4,0x24570013,0x00000000}},	//   ļaut, zoam, _ầm_,
  { {0x26cc0006,0x68e90024,0x1dbe0053,0x00000000}},	//   rodo_, bmed, ्थित,
  { {0x44221acc,0x7c221964,0xa37c0066,0x00000000}},	//   gak_, naor, _dôžé_,
  { {0x60cd2fb8,0x6d5e002b,0x248900be,0x00000000}},	//   voam, hwpa, _voam_,
  { {0x44220250,0x6d410137,0x35b40054,0x00000000}},	//   aak_, _ålag, _облр,
  { {0x44222fb9,0x60cd0ac2,0xd0d50062,0x00000000}},	//   bak_, toam, довъ,
  { {0x442201f7,0x7c220035,0x62950137,0x00000000}},	//   cak_, jaor, skzo,
  { {0x60cd0d6b,0x290c039f,0xd3710021,0x00000000}},	// [4f70] roam, _ltda_, _شهد_,
  { {0x60cd2fba,0xaa160085,0x68e92fbb,0x00000000}},	//   soam, _дзiц, zmed,
  { {0x753a0199,0xf3ff017d,0x68e9001f,0x00000000}},	//   nutz, ndão_, ymed,
  { {0x765a00fe,0xdddc056c,0x00000000,0x00000000}},	//   hety, _barł,   ,
  { {0x753a00bd,0x765a2fbc,0x7ce3004b,0x00000000}},	//   hutz, kety, võrd,
  { {0x9f96014e,0x88bc0080,0x44222fbd,0x00000000}},	//   _חדשה_, _dvěm, zak_,
  { {0x44222fbe,0xaa56005e,0x765a0fef,0x00000000}},	//   yak_, фију_, dety,
  { {0x38ca006a,0xd7092fbf,0x8835014b,0x00000000}},	//   يايی_, оние_, фэкц,
  { {0xcb34005a,0x44220d11,0xb6a502b3,0x00000000}},	//   _петъ, vak_, дипл,
  { {0x44222fc0,0x765a2fc1,0x68e92fc2,0x00000000}},	//   wak_, gety, smed,
  { {0x44222fc3,0x68e90137,0xaca3008d,0x00000000}},	//   tak_, pmed, _nhừn,
  { {0x68360058,0x7e670130,0x7d09005f,0x00000000}},	//   rüdü, _lajp, _česl,
  { {0x44222f70,0xd6290856,0xb3830071,0x00000000}},	//   rak_, _доле_, влял,
  { {0x7ea02fc4,0x44222fc5,0x7e670646,0x00000000}},	//   _köpe, sak_, _najp,
  { {0xaca3008b,0x4422083e,0x216711da,0x00000000}},	//   _chừn, pak_, мири_,
  { {0x98a0017f,0xe0da02fe,0x250a005d,0x00000000}},	//   čić_, іва_, _بروی_,
  { {0x7ea00137,0x4420003b,0x24840014,0x00000000}},	// [4f80] _löpe, _iei_, ömmu_,
  { {0xf767006a,0x44202fc6,0x3f8000cd,0x00000000}},	//   _یا_, _hei_, rxiu_,
  { {0x22940072,0x656f0013,0x7c220046,0x00000000}},	//   _näki_, ́chn, taor,
  { {0x44200812,0x23720022,0x98a7011b,0x00000000}},	//   _jei_, _kryj_, runě_,
  { {0x7c221a25,0x765a00ac,0x44202fc7,0x00000000}},	//   raor, yety, _mei_,
  { {0x38660027,0x34bb0053,0x44202fc8,0x00000000}},	//   _saor_, _उद्द, _lei_,
  { {0xd90d006a,0x2f0400c7,0x38660139,0x00000000}},	//   میل_, _hög_, _paor_,
  { {0x44202fc9,0x909b0041,0xdddc056c,0x00000000}},	//   _nei_, ַסיק, _tarł,
  { {0x6f02018d,0x765a2fca,0xb6f40d34,0x00000000}},	//   íoch, tety, нзиј,
  { {0x699601a4,0x753a0244,0xfd8a009a,0x00000000}},	//   _орех, tutz, ַטָּ,
  { {0xf76f04de,0x44202fcb,0x2f040026,0x00000000}},	//   های_, _bei_, _lög_,
  { {0x44200529,0xf3ff017d,0x765a2fcc,0x00000000}},	//   _cei_, rdão_, sety,
  { {0x4420142d,0xd7e20053,0x98350085,0x00000000}},	//   _dei_, _परिच, _чэхі,
  { {0x44201358,0x7d032fcd,0x753a0244,0x00000000}},	//   _eei_, ínsk, putz,
  { {0xd5af107a,0xe63b0063,0xd4db0021,0x00000000}},	//   _рс_, _ותוכ, _وبعض_,
  { {0x7c202fce,0x629e008f,0x4420002b,0x00000000}},	//   _nemr, _elpo, _gei_,
  { {0x645d2fcf,0x9e150085,0xb146005d,0x00000000}},	// [4f90] mesi, едзі, وییم_,
  { {0x645d2fd0,0x44202fd1,0xaca30013,0x00000000}},	//   lesi, _zei_, _thừn,
  { {0x21270013,0x7d1c002b,0x75280023,0x00000000}},	//   _ình_, _cwrs, nsdz,
  { {0x645d2fd2,0x8b6b003d,0xd196009d,0x00000000}},	//   nesi, ņēmē, _נכרי_,
  { {0x645d2fd3,0xcf2701fb,0xe452089e,0x00000000}},	//   iesi, _ترجي, רֶב_,
  { {0x2d470016,0x645d0725,0xa9690d4c,0x00000000}},	//   põe_, hesi, зика_,
  { {0xac1927b5,0x7d1c001f,0x28f50002,0x00000000}},	//   _нову_, _gwrs, нџис,
  { {0xe3b8005b,0xa76507fe,0x645d2fd4,0x00000000}},	//   ğız_, екид, jesi,
  { {0x44202fd5,0x59e10053,0xd5b1008b,0x00000000}},	//   _rei_, _फरवर, hát_,
  { {0x3964024a,0x44202fd6,0x4585098e,0x00000000}},	//   ässä_, _sei_, егов,
  { {0x4815000d,0x04462fd7,0xa522000d,0x00000000}},	//   _змес, ненн, лмэд,
  { {0xd46a0002,0xf7710021,0x645d2d4f,0x00000000}},	//   чиме_, _مات_, gesi,
  { {0xe72e2fd8,0x56950088,0xaca3001b,0x00000000}},	//   _ще_, _падт, _chứn,
  { {0xa7640086,0x2f040046,0x44202fd9,0x00000000}},	//   _шкід, _rög_, _wei_,
  { {0x645d2fda,0x67292ed0,0x44202fdb,0x00000000}},	//   besi, lsej, _tei_,
  { {0x645d2fdc,0x20e8004d,0xf41f0072,0x00000000}},	//   cesi, ißig_, ljän_,
  { {0x672902dd,0x8fa30098,0x96a60042,0x00000000}},	// [4fa0] nsej, гате, टोकॉ,
  { {0x7c200150,0x76412fdd,0x2fd9002b,0x00000000}},	//   _semr, ngly, _dysg_,
  { {0x06960047,0x20070051,0xe0da0635,0x00000000}},	//   עדעם_, śnia_, _нво_,
  { {0x99620080,0x0ca90021,0x61e11b89,0x00000000}},	//   tíže_, وطني_, ülle,
  { {0xeb970055,0xc5f8001c,0x7cfa004c,0x00000000}},	//   ниц_, ldēt_, _důra,
  { {0x672900b9,0x29660001,0x645d0298,0x00000000}},	//   dsej, ењив, zesi,
  { {0xed570076,0x672b02fb,0x645d005b,0x00000000}},	//   _пор_, _avgj, yesi,
  { {0xd90d005d,0x9874012c,0x49b70044,0x00000000}},	//   زیه_, тлиц, عاود_,
  { {0xb9070053,0x645d2fde,0xb8e80042,0x00000000}},	//   _मी_, vesi, _ईद_,
  { {0x645d00e8,0xa96a018e,0x67530021,0x00000000}},	//   wesi, _низа_, اخير,
  { {0x7d092f42,0xf99f000a,0x645d2fdf,0x00000000}},	//   _česk, _сè_, tesi,
  { {0x7afa02f0,0x7792007e,0xddc7008f,0x00000000}},	//   _hitt, _میبا, _sajū,
  { {0x92820047,0xdc34004a,0x645d2fe0,0x00000000}},	//   אַטן_, júči, resi,
  { {0x877b00b5,0xe3bf006d,0xf773009f,0x00000000}},	//   _מאדי, gaña_, _תקס_,
  { {0x645d2fe1,0x7afa2fe2,0x81d50054,0x00000000}},	//   pesi, _mitt, товх,
  { {0x7bde0045,0x7afa2fe3,0x69da0b19,0x00000000}},	//   ępuj, _litt, _myte,
  { {0xe3bf0331,0x9f340054,0x61e10244,0x00000000}},	// [4fb0] baña_, леті, üllb,
  { {0x3f87007d,0x7c240014,0x7afa2fe4,0x00000000}},	//   ćnu_, ðirn, _nitt,
  { {0x69da069f,0xeab1005d,0x2fd9002b,0x00000000}},	//   _nyte, یعت_, _wysg_,
  { {0xc5f8008f,0x7c841594,0x61e500a8,0x00000000}},	//   ldēs_, луче, _izhl,
  { {0x69da002c,0x7afa2fe5,0x5fe401dd,0x00000000}},	//   _ayte, _bitt, _бірж,
  { {0x7afa02f6,0x1ee7007e,0x69da2fe6,0x00000000}},	//   _citt, _سوزی_, _byte,
  { {0x7afa2fe7,0xa96617f2,0xba280021,0x00000000}},	//   _ditt, вища_, رسوم_,
  { {0x67290019,0x7afa0026,0xe3bf006d,0x00000000}},	//   tsej, _eitt, zaña_,
  { {0x07a5000a,0x7afa2fe8,0x7f4d01f4,0x00000000}},	//   тапн, _fitt, ntaq,
  { {0x7ea000c7,0x67292edc,0x79a70456,0x00000000}},	//   _köpa, rsej, _прее,
  { {0x64a62fe9,0x7bdb00be,0x89340049,0x00000000}},	//   вана, _hyuu, _معنا,
  { {0x7afa2fea,0x04960085,0xe7b2005d,0x00000000}},	//   _zitt, троў, امید,
  { {0xe3bf02dd,0x7ea00137,0xccf20047,0x00000000}},	//   taña_, _löpa, יכט_,
  { {0x64410006,0x386d011d,0xda0e0013,0x00000000}},	//   ėlia, lder_, hỏng_,
  { {0xaca300aa,0xe5a20086,0xa01b0137,0x00000000}},	//   _nhữn, _вищи, _onöd,
  { {0x386d2feb,0x92820041,0x614301ce,0x00000000}},	//   nder_, אַכן_, јета,
  { {0xb05b01e3,0xe3bf048e,0x386d2fec,0x00000000}},	// [4fc0] _tjän, paña_, ider_,
  { {0xb05b01e3,0x386d001f,0xee371636,0x00000000}},	//   _hjäl, hder_, кну_,
  { {0x44320080,0x2d9c0024,0x7afa2bb5,0x00000000}},	//   _kdy_, áve_, _ritt,
  { {0x6aa1001f,0x2ca00025,0x386d2fed,0x00000000}},	//   _allf, óid_, jder_,
  { {0xef170055,0xcb540021,0x7afa04ca,0x00000000}},	//   _имя_, انتظ, _pitt,
  { {0x2a36000d,0xdb1100ea,0x61e9004c,0x00000000}},	//   тэдр, ágáb, řele,
  { {0x7afa2fee,0x386d002b,0x629c2fef,0x00000000}},	//   _vitt, fder_, ikro,
  { {0xfce62ff0,0x7afa2ff1,0xa967005e,0x00000000}},	//   _робо, _witt, тића_,
  { {0x47340138,0x7afa02f0,0xc6f824f8,0x00000000}},	//   ћнос, _titt, нних_,
  { {0x7afa0438,0xd5ba0002,0x4432176c,0x00000000}},	//   _uitt, дсм_, _ady_,
  { {0xceb3014e,0x22940019,0x7c2d0014,0x00000000}},	//   שית_, _läks_, ðarg,
  { {0x79b7014e,0x649f00ac,0xa9230066,0x00000000}},	//   _בלבד_, _eëin, ôžem,
  { {0xf7430054,0x07a30062,0x661d0078,0x00000000}},	//   _вечо, _кацн, ŕska,
  { {0x4432176c,0xf2c401d5,0xa2c4005e,0x00000000}},	//   _edy_, ассн, аљск,
  { {0xb05b0137,0xf2df003b,0xe2f80086,0x00000000}},	//   _fjäl, ntâi_, тері_,
  { {0x44320045,0x30a42ff2,0x61e50080,0x00000000}},	//   _gdy_, арув, _vzhl,
  { {0xe3bf02dd,0x26de1bb2,0x6ab8102d,0x00000000}},	// [4fd0] maño_, olto_, kivf,
  { {0xa01b0122,0x78a2006d,0x603e003b,0x00000000}},	//   _coör, _llov, tămâ,
  { {0x386d2ff3,0x4432001f,0x9e0400d7,0x00000000}},	//   yder_, _ydy_, рчул,
  { {0x603e003b,0xe7e20053,0x5ce40085,0x00000000}},	//   rămâ, _परंप, аюча,
  { {0x386d0093,0xd5b10013,0xfc640062,0x00000000}},	//   vder_, háp_, ръхн,
  { {0x386d0034,0x2a7e0013,0x539c0aeb,0x00000000}},	//   wder_, _cntb_, וידו,
  { {0x79a7005a,0x27e600ea,0x5a44000d,0x00000000}},	//   ърде, _azon_, рэча,
  { {0x386d0657,0x01fc0063,0x26de068f,0x00000000}},	//   uder_, ופול, elto_,
  { {0x386d2ff4,0xbc94007b,0x753a0244,0x00000000}},	//   rder_, _татј, ertz,
  { {0xb05b01e3,0x7ea00137,0x38ba008f,0x00000000}},	//   _själ, _löpn, fīrs_,
  { {0x69c40529,0xd6d90022,0x39152ff5,0x00000000}},	//   şier, guła_, _смер,
  { {0xe3bf006d,0x3a252ff6,0x79a40002,0x00000000}},	//   gaño_, _help_, _труе,
  { {0x29052ff7,0x20070080,0xaca30013,0x00000000}},	//   _hula_, ěnil_, _nhửn,
  { {0x3a2500d1,0x38ba008f,0x2ebf0053,0x00000000}},	//   _jelp_, mūra_, ्वोत,
  { {0x2905017f,0x629c2d43,0xe3bf0331,0x00000000}},	//   _jula_, rkro, baño_,
  { {0x290515c4,0xa0671a58,0xe3bf0331,0x00000000}},	//   _mula_, ласа_, caño_,
  { {0x29052269,0xbd8a007e,0x3fe60f92,0x00000000}},	// [4fe0] _lula_, کنان_, ужав,
  { {0x98a70080,0x7e230086,0x27e001e1,0x00000000}},	//   trně_, йдуж, _øine_,
  { {0x88bc0080,0x2ca604bf,0x644600b9,0x00000000}},	//   _květ, thod_, ogki,
  { {0x64462ff8,0xd4370047,0xb5fa0047,0x00000000}},	//   ngki, ָרסק_, גלעכ,
  { {0x60c40384,0x29052ff9,0x6d410e6c,0x00000000}},	//   mnim, _aula_, _ålan,
  { {0x60c42ffa,0x673b0b33,0x78a22ffb,0x00000000}},	//   lnim, druj, _slov,
  { {0x2480017f,0x7d030026,0xada6005e,0x00000000}},	//   _onim_, ínst, _савл,
  { {0x47342254,0x60c42ffc,0x6d4e0411,0x00000000}},	//   анис, nnim, _iqba,
  { {0x7c930032,0xf0930063,0xffb70047,0x00000000}},	//   _القص, מנה_, ָליש_,
  { {0x248000a4,0x05b20053,0x290500a5,0x00000000}},	//   _anim_, ुपलब, _fula_,
  { {0xe3bf006d,0x60c42ffd,0x2419026c,0x00000000}},	//   taño_, knim, коны_,
  { {0x64460031,0x13f50086,0x7e6e001c,0x00000000}},	//   ggki, изня, _labp,
  { {0x60c418e7,0x3eba0014,0x6eeb049c,0x00000000}},	//   dnim, kipt_, lübe,
  { {0x23690198,0x24802ffe,0x6d5c189f,0x00000000}},	//   _vsaj_, _enim_, _opra,
  { {0x6eeb2fff,0x60c4004d,0x6d5c3000,0x00000000}},	//   nübe, fnim, _npra,
  { {0xa01b006f,0x60c43001,0x301511da,0x00000000}},	//   _coöp, gnim, рдар,
  { {0x6d5c20b4,0xe4500021,0x442b3002,0x00000000}},	// [4ff0] _apra, _رضي_, mac_,
  { {0x88bc0080,0x442b3003,0x60c42dc3,0x00000000}},	//   _zvět, lac_, anim,
  { {0x60c400c3,0x1a65005d,0x12fa009a,0x00000000}},	//   bnim, ییری_, _שהתב,
  { {0xb19a014e,0x2905000c,0x442b3004,0x00000000}},	//   _ייתכ, _rula_, nac_,
  { {0xcb693005,0x442b0024,0x29050027,0x00000000}},	//   тале_, iac_, _sula_,
  { {0x29050397,0x5fba0063,0x7c2d0014,0x00000000}},	//   _pula_, _יצרנ, ðarb,
  { {0x0dc8019d,0xe509001b,0xa2d60053,0x00000000}},	//   _бути_, _mặc_, णवत्,
  { {0x38ba2b27,0x442b3006,0x2919004c,0x00000000}},	//   tūra_, jac_, _čsad_,
  { {0x6d5c02f4,0x8b5804f6,0x656a0139,0x00000000}},	//   _zpra, _مجلس_, _asfh,
  { {0x88bc0080,0x60c400c3,0x29053007,0x00000000}},	//   _svět, znim, _tula_,
  { {0x60c423a8,0xd5e50054,0xda7a0063,0x00000000}},	//   ynim, ржни, _שנער,
  { {0x20070051,0x38ba008f,0x7c2b3008,0x00000000}},	//   śnij_, pūra_, nagr,
  { {0x60c400c3,0x78a900d1,0x7c2b3009,0x00000000}},	//   vnim, mhev, iagr,
  { {0x6e270080,0x7ea00058,0x9756009a,0x00000000}},	//   _nejb, _röpo, _כינו_,
  { {0x60c4040d,0x6f060051,0x76ba0165,0x00000000}},	//   tnim, _sukc, _במספ,
  { {0x80660d34,0x661c005b,0x442b300a,0x00000000}},	//   јваж, ırke, cac_,

  { {0xa0670431,0x6d5c300b,0xb4c40042,0x00000000}},	// [5000] шата_, _spra, ्वी_,
  { {0x2d9a300c,0xdddc0022,0x60c4300d,0x00000000}},	//   type_, _garś, snim,
  { {0x3eba300e,0x60c400b2,0xc0e60085,0x00000000}},	//   ript_, pnim, _вонк,
  { {0xeb9a0055,0x7c2b00e8,0x6d5c0fff,0x00000000}},	//   кие_, gagr, _vpra,
  { {0x78bb01f4,0xa0c6007e,0x6205013d,0x00000000}},	//   diuv, _ميگو, _átlá,
  { {0x442b300f,0x6eeb004d,0x7ea00137,0x00000000}},	//   zac_, tübe, _köpm,
  { {0x67220045,0x2d870072,0x6d5c0f18,0x00000000}},	//   _swoj, änet_, _upra,
  { {0x6eeb1fa3,0x2d68005b,0x8c4312d5,0x00000000}},	//   rübe, _işe_, _месе,
  { {0x442b3010,0x6eeb004d,0x57f30062,0x00000000}},	//   vac_, sübe, опът,
  { {0xf70800aa,0x7d000037,0x64410006,0x00000000}},	//   _của_, _hims, ėlim,
  { {0x7d00005b,0x15aa0062,0x442b3011,0x00000000}},	//   _kims, тъпи_, tac_,
  { {0x67220045,0x395e0089,0x78a93012,0x00000000}},	//   _twoj, _ipts_, chev,
  { {0xbf9b0016,0x20070022,0x442b3013,0x00000000}},	//   _agên, śnik_, rac_,
  { {0x442b3014,0x673d00ea,0x20c5008f,0x00000000}},	//   sac_, ásje, rķim_,
  { {0x64400e7c,0x442b3015,0xdce50066,0x00000000}},	//   ómic, pac_, vyhľ,
  { {0xd25104de,0x628e08ea,0xd5fb0063,0x00000000}},	//   _کند_, ajbo, _בפור,
  { {0xe5090013,0xdcfe0078,0xc0f80054,0x00000000}},	// [5010] _tặc_, lypė, ретє_,
  { {0x7d000027,0x44290004,0x4fc4126b,0x00000000}},	//   _aims, _hea_, іста,
  { {0xd1670062,0x6e2701e1,0x4ea4007b,0x00000000}},	//   _тъпи, _vejb, црта,
  { {0x61e8004b,0x32110022,0x7cb40054,0x00000000}},	//   üdle, lczy_, осії,
  { {0x44293016,0x7c2b3017,0xa3dd0042,0x00000000}},	//   _mea_, ragr, _तुम_,
  { {0x3e570080,0x44293018,0x7d280025,0x00000000}},	//   _dětí_, _lea_, úrsó,
  { {0xb7bd000c,0xec6b2aa1,0x7c2b18a1,0x00000000}},	//   maţi, _ирак_, pagr,
  { {0xb7bd0529,0x6d453019,0xf7080013,0x00000000}},	//   laţi, muha, _sủa_,
  { {0x6d45240d,0x78a911a1,0x3c440021,0x00000000}},	//   luha, rhev, _ذَلِ,
  { {0xb7bd0529,0x7c29301a,0x7d0001b3,0x00000000}},	//   naţi, _heer, _zims,
  { {0x78a900d1,0x6d450277,0x4429301b,0x00000000}},	//   phev, nuha, _bea_,
  { {0x44290529,0x443e00bd,0xb4c40053,0x00000000}},	//   _cea_, ßt_, ्वे_,
  { {0x7c29301c,0x7ce30019,0x4429301d,0x00000000}},	//   _meer, tõrj, _dea_,
  { {0xb7bd003b,0x6d45301e,0x7c2906ad,0x00000000}},	//   jaţi, kuha, _leer,
  { {0x6d450019,0xd24f0021,0xb7bd003b,0x00000000}},	//   juha, عنف_, daţi,
  { {0x6d450397,0x644d0025,0x7c29301f,0x00000000}},	//   duha, _gcai, _neer,
  { {0x7d0001b3,0x7f4a0021,0xc4d3009a,0x00000000}},	// [5020] _rims, طلاق_, _מגה_,
  { {0xb7bd000c,0xe45f00fe,0x7cea0014,0x00000000}},	//   gaţi, nnön_, dýra,
  { {0x442900e5,0x6d4511c4,0x0ef90085,0x00000000}},	//   _yea_, guha, рэты_,
  { {0xf1c401c2,0x30860021,0xf2df006c,0x00000000}},	//   alší_, _الحف, stât_,
  { {0x7c2d0014,0xfb130021,0x2d8700a5,0x00000000}},	//   ðara, كونج, äner_,
  { {0xb7bd0529,0x6d4503f9,0xdce8005b,0x00000000}},	//   caţi, buha, ılır,
  { {0x2d68003b,0x7d003020,0xd90d005d,0x00000000}},	//   _uşe_, _tims, نیل_,
  { {0x3ae90027,0x7c293021,0x2cbd002b,0x00000000}},	//   rúpa_, _geer, ciwd_,
  { {0x44293022,0x4c35000d,0xf62a0054,0x00000000}},	//   _rea_, _фэст, ліни_,
  { {0x6b7b014e,0x644d0025,0x44290d0f,0x00000000}},	//   _גרמנ, _scai, _sea_,
  { {0x44290019,0x2fc7001b,0xa3ab0042,0x00000000}},	//   _pea_, ̃ng_, कैन_,
  { {0xb7bd0529,0xf1c0008b,0x7ce30019,0x00000000}},	//   zaţi, _ương_, võrk,
  { {0x44293023,0x6d453024,0x1634072d,0x00000000}},	//   _vea_, zuha, _деля,
  { {0x46f60055,0x6d4500a4,0x46670062,0x00000000}},	//   _учет, yuha, _гръм_,
  { {0x4429010e,0x32110051,0x30a71fa5,0x00000000}},	//   _tea_, rczy_, брав,
  { {0xfd4d008b,0x9055000d,0x61e9004c,0x00000000}},	//   _thoạ, ўвац, řelo,
  { {0xb7bd0529,0x59df0161,0x7ea00137,0x00000000}},	// [5030] taţi, _पुनर, _köph,
  { {0x2aab0146,0x2fc7001b,0x6d453025,0x00000000}},	//   _købe_, ăng_, tuha,
  { {0xb7bd0529,0x62850ac8,0x7c293026,0x00000000}},	//   raţi, _inho, _peer,
  { {0x6d453027,0x3c470021,0xb7bd003b,0x00000000}},	//   ruha, إضاف, saţi,
  { {0xb7bd000c,0x2aab00b9,0x6d45035d,0x00000000}},	//   paţi, _løbe_, suha,
  { {0x7c293028,0xab64000d,0x6d453029,0x00000000}},	//   _weer, явіл, puha,
  { {0xa8890062,0x7c29302a,0xb05b0137,0x00000000}},	//   ийка_, _teer, _djäv,
  { {0x6aa822f6,0x98bc0023,0x00000000,0x00000000}},	//   _eldf, tuvā_,   ,
  { {0xdddc01f7,0xc9d3007e,0x7a3400ea,0x00000000}},	//   _karş, _کماک, _sütő,
  { {0x628500d1,0xe5090013,0x2bb80044,0x00000000}},	//   _nnho, _dặn_, _طاقة_,
  { {0xaca3008b,0x25a300ea,0xdddc302b,0x00000000}},	//   _chủn, ájl_, _marş,
  { {0x39470367,0x6285302c,0xe7590054,0x00000000}},	//   muns_, _anho, _виді_,
  { {0x8b99009a,0xcc56009d,0x00000000,0x00000000}},	//   ׁבֹת, חברי_,   ,
  { {0xe5a51efa,0xe7160044,0xcb12009a,0x00000000}},	//   _мили, _بيوت_, ולך_,
  { {0xc616009a,0xa2e32ceb,0x4096286c,0x00000000}},	//   _וחצי_, форд, орат,
  { {0x6285270a,0x6ab60053,0x26c20066,0x00000000}},	//   _enho, _अग्र, ékov_,
  { {0xddc700c2,0xdd01004c,0x8afd004c,0x00000000}},	// [5040] _rajš, štěs, _zpře,
  { {0x394700ac,0x7ea00137,0x1eaa0021,0x00000000}},	//   kuns_, _köpi, جاري_,
  { {0x3947302d,0x5c060363,0x5d6a0081,0x00000000}},	//   juns_, ояла, рием_,
  { {0x2377007e,0x7be60054,0x7c8318ea,0x00000000}},	//   _امید_, ожеж, душе,
  { {0x845b009a,0xbc6702da,0x00000000,0x00000000}},	//   שכנז, زمون_,   ,
  { {0xbab7000d,0x5f271b37,0xeaf70044,0x00000000}},	//   огіх_, _форм_, يروت_,
  { {0xa2cd0235,0x3947302e,0xda650021,0x00000000}},	//   _सदस्, guns_, ثاني,
  { {0x290201e3,0x0b1a0021,0x7cf102ad,0x00000000}},	//   öka_, _نقرة_, gård,
  { {0x7c22302f,0x3947008f,0xdb24005d,0x00000000}},	//   mbor, auns_, _روای,
  { {0x7c223030,0x39473031,0x7d1e0829,0x00000000}},	//   lbor, buns_, opps,
  { {0x7c223032,0x291a0114,0x39473033,0x00000000}},	//   obor, ípad_, cuns_,
  { {0x290c003b,0x6d430078,0x8afd004c,0x00000000}},	//   _iuda_, šnag, _vpře,
  { {0x3ce614b3,0x290c0077,0x7c220168,0x00000000}},	//   ilov_, _huda_, ibor,
  { {0x290c27af,0xc1a70699,0xaca30013,0x00000000}},	//   _kuda_, ојби, _thủn,
  { {0x8afd0080,0x7c221817,0x290c3034,0x00000000}},	//   _upře, kbor, _juda_,
  { {0x765a00ac,0x290c3035,0x1f15000d,0x00000000}},	//   lfty, _muda_, змаў,
  { {0x9f5902ab,0x23280001,0x7c223036,0x00000000}},	// [5050] _også_, _доњи_, dbor,
  { {0xf3ff017d,0x7c223037,0x3ce60a80,0x00000000}},	//   leão_, ebor, elov_,
  { {0x290c3038,0xdddc3039,0x7cf105e7,0x00000000}},	//   _nuda_, _varş, håre,
  { {0x3ce600c3,0x7cf10829,0x7188009a,0x00000000}},	//   glov_, kåre, _וְשַ,
  { {0x7cf10137,0xf41f0072,0x7ce3004e,0x00000000}},	//   vård, ljäs_, kõrv,
  { {0x8f9a0063,0x2e480121,0x7cf104aa,0x00000000}},	//   _הישי, _мясо_, dåre,
  { {0x6d430025,0x20070022,0x7d0a0014,0x00000000}},	//   ánad, śniu_, ífst,
  { {0x290c303a,0x3947303b,0x6ef0004d,0x00000000}},	//   _duda_, runs_, räbe,
  { {0xb05b00a5,0x96750085,0x39470023,0x00000000}},	//   _hjäs, пыні, suns_,
  { {0x3947003b,0x16a90002,0x7545093d,0x00000000}},	//   puns_, свои_, пноз,
  { {0xf41f0072,0xceb2009a,0x99480044,0x00000000}},	//   yjät_, גיי_, _ولكل_,
  { {0x895a0063,0x38580054,0x6908009a,0x00000000}},	//   _לדעת, _мрію_, _וּסְ,
  { {0x44220078,0x629a004e,0xd763005d,0x00000000}},	//   rbk_, ötoo, _آنتی,
  { {0x290c006d,0x7c22303c,0xb77a0063,0x00000000}},	//   _yuda_, zbor, _לאנש,
  { {0xd179148d,0x703a0055,0x7c2200c0,0x00000000}},	//   ості_, йчас_, ybor,
  { {0x7c2d007a,0xa6e20026,0x7c3b1c8b,0x00000000}},	//   ðarl, öðvu, _ndur,
  { {0x7c2200c7,0xee3a303d,0x6266030b,0x00000000}},	// [5060] vbor, йна_, _евпа,
  { {0xee3a0088,0xb05b0137,0x9f4b00ea,0x00000000}},	//   ёне_, _sjät, émát_,
  { {0x929b014e,0xe29b014e,0x429b0063,0x00000000}},	//   _היית, _השיר, _הסיב,
  { {0xdcb90086,0xb53a0041,0x290c303e,0x00000000}},	//   ощі_, מגעש, _ruda_,
  { {0x20070080,0x290c303f,0x752f0051,0x00000000}},	//   ěnit_, _suda_, ączy,
  { {0x3ce601a6,0x7c223040,0xf41f0137,0x00000000}},	//   slov_, sbor, njär_,
  { {0xe7450013,0x3ce60734,0x58d4071f,0x00000000}},	//   ýõng_, plov_, мокт,
  { {0x6e2e02b0,0xb05b00c7,0xaca30013,0x00000000}},	//   _hebb, _hjär, _phụn,
  { {0xd6da011c,0x7f443041,0x2ca60137,0x00000000}},	//   йто_, nriq, mkod_,
  { {0x7cf105b9,0x2ca60137,0x95380002,0x00000000}},	//   råre, lkod_, озот_,
  { {0x94d5018e,0xa4d50083,0x7cf102fd,0x00000000}},	//   донц, доні, såre,
  { {0x2ca60137,0xe5090013,0xd5b70085,0x00000000}},	//   nkod_, _gặm_, ясы_,
  { {0x8387000d,0xd7e30086,0xe45f00ea,0x00000000}},	//   чыне, _пішо, lnök_,
  { {0x27e600bb,0x6e2e3042,0xc7b9013d,0x00000000}},	//   _iyon_, _nebb, iből_,
  { {0x7e750198,0x2ca60137,0x26de1d88,0x00000000}},	//   _razp, kkod_, moto_,
  { {0x61e5108f,0xc7b900ea,0x7f440003,0x00000000}},	//   _vyhl, kből_, friq,
  { {0xc43c0063,0x7c2d0026,0xb4d90053,0x00000000}},	// [5070] _התחי, ðarm, ़की_,
  { {0x2ca60089,0x4255007e,0xb05b1bec,0x00000000}},	//   ekod_, _کنگر, _pjäs,
  { {0x26cc0016,0x6e2e3043,0x27e63044,0x00000000}},	//   indo_, _debb, _lyon_,
  { {0x7f4402a7,0x644f00ac,0x26de01c2,0x00000000}},	//   briq, ngci, hoto_,
  { {0x6e2e051e,0xb05b00c7,0xc7b9013d,0x00000000}},	//   _febb, _fjär, gből_,
  { {0x60cd3045,0x26de0035,0xe9a9007e,0x00000000}},	//   lnam, joto_, يگان_,
  { {0x27e600bb,0x60cd0e9b,0x6295006f,0x00000000}},	//   _ayon_, onam, ijzo,
  { {0x26cc3046,0x645d006f,0x2b4008ed,0x00000000}},	//   endo_, jfsi, šica_,
  { {0x60cd060a,0xa8060331,0x26de3047,0x00000000}},	//   inam, _riñó, foto_,
  { {0x6f0f24b9,0x60cd3048,0x6d453049,0x00000000}},	//   _mucc, hnam, orha,
  { {0x60cd304a,0x6f0f304b,0x645d304c,0x00000000}},	//   knam, _lucc, ffsi,
  { {0x89340021,0x26cc304d,0x98bc0078,0x00000000}},	//   _أعلا, ando_, tuvą_,
  { {0x68e905dd,0x68fb1a23,0x7ea00137,0x00000000}},	//   mled, mmud, _köpt,
  { {0x68e9304e,0x2cad001f,0x645d14d1,0x00000000}},	//   lled, _lled_, afsi,
  { {0x2cad0019,0x35fb007e,0x68e9304f,0x00000000}},	//   _oled_, _ارشد_, oled,
  { {0x6e2e051e,0x20fa0053,0x60cd3050,0x00000000}},	//   _sebb, ्देश_, gnam,
  { {0x68e93051,0x6f0f0a02,0x63a00137,0x00000000}},	// [5080] iled, _cucc, ämnd,
  { {0x68e90080,0xee3a000d,0x24890226,0x00000000}},	//   hled, іне_, _znam_,
  { {0x60263052,0x68e93053,0x6f1d2f4a,0x00000000}},	//   _одна, kled, _etsc,
  { {0x68e90146,0x6e2e3054,0x60cd0025,0x00000000}},	//   jled, _webb, cnam,
  { {0xeb97000a,0x68e92869,0x6f0f01f4,0x00000000}},	//   миц_, dled, _gucc,
  { {0x6d430027,0x2ca600c7,0x68fb3055,0x00000000}},	//   ánac, skod_, emud,
  { {0x6d450185,0x2cad0034,0x6f0f2a9d,0x00000000}},	//   crha, _fled_, _zucc,
  { {0x88bc0080,0x68e93056,0xa7741369,0x00000000}},	//   _hvěz, gled, елич,
  { {0x9646000d,0x26de3057,0x68e23058,0x00000000}},	//   мэнд, toto_, _vkod,
  { {0xd6d90045,0x60cd3059,0x61e9004c,0x00000000}},	//   kułu_, znam, řeli,
  { {0x2cbf001f,0x26de305a,0x68e9305b,0x00000000}},	//   _ymud_, roto_, bled,
  { {0x291e0504,0x26de305c,0x645d004d,0x00000000}},	//   _itta_, soto_, ufsi,
  { {0x43940076,0x26de00c2,0x645d1c8b,0x00000000}},	//   ваяс, poto_, rfsi,
  { {0x45d41a5c,0x35d40121,0x6d45002b,0x00000000}},	//   _полс, _полё, yrha,
  { {0xe9ce0088,0x6f0f071d,0x7c2d0014,0x00000000}},	//   лкi_, _succ, ðark,
  { {0x60c400a4,0x24890331,0x68e0305d,0x00000000}},	//   giim, _unam_, nomd,
  { {0xbfab000d,0x60cd305e,0x2ef50782,0x00000000}},	// [5090] цтве_, rnam, езар,
  { {0x63a00137,0x291e305f,0x60cd3060,0x00000000}},	//   ämne, _otta_, snam,
  { {0x60cd0122,0x201e000c,0x68fb001f,0x00000000}},	//   pnam, _ştie_, ymud,
  { {0x20c5001c,0x61e1004d,0x6d4516e3,0x00000000}},	//   rķis_, üllu, rrha,
  { {0x68e0001c,0x2d8e004d,0x291e3061,0x00000000}},	//   domd, äfer_, _atta_,
  { {0x68e93062,0xfaa70065,0xdcef0058,0x00000000}},	//   wled, ьшен, ıdır,
  { {0x68e91f4a,0xc9a90121,0xaa56005e,0x00000000}},	//   tled, явке_, хију_,
  { {0x68fb00a4,0xd5b8008f,0x00000000,0x00000000}},	//   umud, abāk_,   ,
  { {0x291e0137,0xd70506da,0x68fb3063,0x00000000}},	//   _etta_, нзии, rmud,
  { {0xef1f0019,0x68fb004b,0x19951dd6,0x00000000}},	//   _mtü_, smud, _пазя,
  { {0x7d093064,0x7ea0005b,0x85e90121,0x00000000}},	//   _kies, _köpr, ядов_,
  { {0x7c2d007a,0xa6e20046,0x397a009a,0x00000000}},	//   ðarh, öðru, _מטענ,
  { {0x60c40004,0x850b0053,0x386d3065,0x00000000}},	//   viim, _संकट_, meer_,
  { {0x386d0ac8,0xd6d90051,0x394700ca,0x00000000}},	//   leer_, tułu_, orns_,
  { {0xf8c9008b,0x60c40213,0x00e4007e,0x00000000}},	//   hẩm_, tiim, نتری,
  { {0x7d090045,0xf7080013,0x26c53066,0x00000000}},	//   _nies, _rủi_, lilo_,
  { {0x2d830137,0x60c417b8,0x3f670caa,0x00000000}},	// [50a0] _arje_, riim, нито_,
  { {0x386d0173,0x3fe30817,0x60c41404,0x00000000}},	//   heer_, ужув, siim,
  { {0x386d0438,0x44323067,0x69c50080,0x00000000}},	//   keer_, _key_, úhel,
  { {0x7d0927f1,0xfc3200f2,0x0c760593,0x00000000}},	//   _cies, احا_, عداد,
  { {0x7d093068,0x386d00e8,0x26c50006,0x00000000}},	//   _dies, deer_, kilo_,
  { {0x443202dd,0xc3330063,0x2b4600cd,0x00000000}},	//   _ley_, רוג_, rroc_,
  { {0x26c51312,0x7d093069,0x386d306a,0x00000000}},	//   dilo_, _fies, feer_,
  { {0xa3c20235,0x386d0438,0x7cea0014,0x00000000}},	//   ्पा_, geer_, kýri,
  { {0x26c5051e,0x56c6005a,0x57f40062,0x00000000}},	//   filo_, ещна, ъпит,
  { {0xc6f71485,0x26c5306b,0x0f570063,0x00000000}},	//   нных_, gilo_, עיים_,
  { {0x386d04c6,0x2f160146,0xceb30a7a,0x00000000}},	//   beer_, _læg_, רית_,
  { {0x386d006f,0x38ba001c,0x78a9005f,0x00000000}},	//   ceer_, tūru_, ckev,
  { {0xdcf50051,0x7c2d0026,0x46a6000d,0x00000000}},	//   _urzą, ðari, _падв,
  { {0xda100053,0x69dc05b9,0x629e306c,0x00000000}},	//   ाशित_, _øres, _copo,
  { {0x629e0574,0xd5af21e8,0xa0c50044,0x00000000}},	//   _dopo, _сс_, نيسو,
  { {0x98bc0078,0x73c50044,0x00000000,0x00000000}},	//   tuvę_, _ليعم,   ,
  { {0x8464011c,0xa92300eb,0x7d09306d,0x00000000}},	// [50b0] _съще, ąžin, _ries,
  { {0x386d006f,0x9f6000ea,0x752d0022,0x00000000}},	//   zeer_, ásán_, _łazi,
  { {0x7d090b61,0xbd180054,0x753a030c,0x00000000}},	//   _pies, еції_, nstz,
  { {0x386d006f,0x26c5306e,0xef1f004b,0x00000000}},	//   xeer_, zilo_, _ttü_,
  { {0x386d04c6,0x7e2b0088,0x7d091efb,0x00000000}},	//   veer_, _ніва_, _vies,
  { {0xf09f008b,0xaa940086,0x753a001c,0x00000000}},	//   _hoà_, личч, kstz,
  { {0x386d2ac2,0x7d0920b4,0x26c5306f,0x00000000}},	//   teer_, _ties, vilo_,
  { {0x4809005a,0x78a93070,0x378901ce,0x00000000}},	//   мейн_, ukev, дбио_,
  { {0x44323071,0x386d3072,0x25a5001f,0x00000000}},	//   _rey_, reer_, wyll_,
  { {0x78a9024a,0x386d3073,0xc7a80021,0x00000000}},	//   skev, seer_, عديل_,
  { {0x188b000a,0x7ea00026,0xf2df003b,0x00000000}},	//   _нсдп_, _möpp, trân_,
  { {0x629e3074,0x26c516f3,0x7cea0014,0x00000000}},	//   _sopo, silo_, týri,
  { {0x78a600c7,0x7ae3172b,0xcc3a0047,0x00000000}},	//   ökve, oont, וערט,
  { {0x7cf83075,0x7ae33076,0xc7b900ea,0x00000000}},	//   míre, nont, mző_,
  { {0x7ae30025,0xc7b900ea,0x91e60429,0x00000000}},	//   iont, lző_, тове,
  { {0xe3b2007e,0x20550793,0x00860062,0x00000000}},	//   _نرخ_, лтур, ълбо,
  { {0x6d430025,0xb226006e,0x7cf105e7,0x00000000}},	// [50c0] ánan, _импл, tårn,
  { {0x6d4b0051,0x673b0072,0x3f803077,0x00000000}},	//   ągan, isuj, rviu_,
  { {0x7ae33078,0xbd8a0593,0xdb080046,0x00000000}},	//   dont, بنان_, _ólét,
  { {0x673b3079,0xe5f60041,0x8c4602d8,0x00000000}},	//   ksuj, דזער_, теде,
  { {0x7cf100c7,0xfafe008f,0x7cf8004c,0x00000000}},	//   pårn, žīma_, jíre,
  { {0x7ae3307a,0xaa530054,0x38c8005d,0x00000000}},	//   gont, ивіш, کاتی_,
  { {0xa9670dd5,0xfaa30002,0x3ea7181a,0x00000000}},	//   вија_, рајо, önte_,
  { {0xd90d006a,0x18740062,0xe45f0072,0x00000000}},	//   سیه_, угия, nnöt_,
  { {0x2cd5000d,0x7e7c307b,0x7ae3307c,0x00000000}},	//   _сюрр, _karp, bont,
  { {0x7c2d0026,0x91690013,0x7ae3095b,0x00000000}},	//   ðarv, hức_, cont,
  { {0x24590086,0x6d5e307d,0xdcf50022,0x00000000}},	//   нань_, ntpa, _arzę,
  { {0x249f0ac6,0x7cf8004c,0x672b013d,0x00000000}},	//   ðum_, bíre, öljá,
  { {0x6b8224ab,0x6d5e2af9,0x1867005e,0x00000000}},	//   nvog, htpa, _јачи_,
  { {0x63a00137,0x35dd0053,0x6d5e0244,0x00000000}},	//   ämna, _नुक़, ktpa,
  { {0x201e003b,0xf1a42125,0x62340d0a,0x00000000}},	//   _ştia_, артн, ресу,
  { {0x55970063,0x6455005e,0x7ae3307e,0x00000000}},	//   _ידוע_, _свиђ, zont,
  { {0x4439307f,0xdff5005e,0x1ee7005d,0x00000000}},	// [50d0] mas_, упањ, نوری_,
  { {0x717913bd,0xc2750001,0x44393080,0x00000000}},	//   _збор_, _слој, las_,
  { {0x7e7c001f,0xf09f008b,0x38662fa2,0x00000000}},	//   _darp, _toà_, _obor_,
  { {0x44393081,0xfbd90699,0x442b00e5,0x00000000}},	//   nas_, ндеј_, nbc_,
  { {0x44393082,0x6d5e006f,0xe5040053,0x00000000}},	//   ias_, atpa, रगति_,
  { {0xddce00ea,0x7ae30072,0x7cf8266a,0x00000000}},	//   _ebbő, uont, víre,
  { {0xdd940088,0x44393083,0x2d9c000e,0x00000000}},	//   _кары, kas_, øvet_,
  { {0x7ae33084,0x44393085,0x673b0659,0x00000000}},	//   sont, jas_, tsuj,
  { {0xe50a001b,0xd7090076,0xe45f00fe,0x00000000}},	//   _mặt_, нние_, tiön_,
  { {0xc7b900ea,0xf2df002b,0x1ab70042,0x00000000}},	//   rző_, frâm_, _अतिथ,
  { {0x44393086,0xe45f0072,0xc7b9013d,0x00000000}},	//   fas_, riön_, sző_,
  { {0x44393087,0x0446000d,0xa907007e,0x00000000}},	//   gas_, ыемн, _شبان,
  { {0xf7453088,0x6e35006f,0x889a009f,0x00000000}},	//   _село, _oezb, _רבני,
  { {0x387f3089,0x6e350114,0x4439308a,0x00000000}},	//   ldur_, _nezb, aas_,
  { {0x4439308b,0xa2c30053,0xa06a0d3e,0x00000000}},	//   bas_, रफ़्, нава_,
  { {0x387f007a,0x2d5c048e,0xa0b50001,0x00000000}},	//   ndur_, víe_, аљуј,
  { {0x387d0185,0x7e7c308c,0xa4fb0063,0x00000000}},	// [50e0] _mawr_, _parp, _אלקט,
  { {0x387d0185,0x6d5e0989,0x9c85005d,0x00000000}},	//   _lawr_, ttpa, یشنه,
  { {0x6e35000c,0x06360047,0x216a007b,0x00000000}},	//   _dezb, רנעט_, _џими_,
  { {0x387d0185,0x6d5e308d,0xe50a0013,0x00000000}},	//   _nawr_, rtpa, _gặt_,
  { {0x7e7c130a,0x387f308e,0xe4570047,0x00000000}},	//   _tarp, ddur_, רינט_,
  { {0x6b82230d,0x4439308f,0x3866004c,0x00000000}},	//   rvog, zas_, _sbor_,
  { {0x44393090,0xcd780063,0x4d780063,0x00000000}},	//   yas_, _בְּכ, _בָּא,
  { {0xacea0021,0x7c2d0026,0x44393091,0x00000000}},	//   _أرسل_, ðart, xas_,
  { {0x7d023092,0x44393093,0x67d40fb4,0x00000000}},	//   mmos, vas_, ропу,
  { {0xba1a0032,0x387f175c,0x44203094,0x00000000}},	//   _أيضا_, adur_, _afi_,
  { {0x8b030080,0x387d0185,0xa9260245,0x00000000}},	//   ířen, _fawr_, _сдел,
  { {0x6aa10290,0x44393095,0xd5b70446,0x00000000}},	//   _zolf, uas_, усь_,
  { {0x7d023096,0x44393097,0x5694013f,0x00000000}},	//   imos, ras_, _валт,
  { {0xaca30013,0x44393098,0x7d020072,0x00000000}},	//   _kiển, sas_, hmos,
  { {0x2b400512,0x2d8500cd,0x44393099,0x00000000}},	//   šich_, _àlex_, pas_,
  { {0x30a4000a,0xd4680001,0x6d43309a,0x00000000}},	//   брув, _биће_, ánam,
  { {0x611c00c3,0xb4b10053,0x0e350071,0x00000000}},	// [50f0] _včla, ओसी_, инаю,
  { {0x7cea007a,0x78a20019,0xd251014d,0x00000000}},	//   kýrs, _loov, _بند_,
  { {0xef1f00bd,0xd0110021,0x463b0047,0x00000000}},	//   _grün_, _ولد_, געבע,
  { {0x611c007d,0x6aa1309b,0x7d02013d,0x00000000}},	//   _učla, _solf, gmos,
  { {0x2d9c0831,0x6aa1309c,0x798814f6,0x00000000}},	//   øver_, _polf, _ardw,
  { {0x387f002b,0x6925309d,0xa9250085,0x00000000}},	//   wdur_, амка, адкл,
  { {0x7c2d0026,0x9ed80d34,0x48b502a1,0x00000000}},	//   ðars, _смрт_, ищит,
  { {0x6aa1309e,0x6eeb0244,0x387f0075,0x00000000}},	//   _wolf, rübu, udur_,
  { {0x387f005b,0x6eeb004d,0x6aa100a5,0x00000000}},	//   rdur_, sübu, _tolf,
  { {0x46f500e1,0xb05b0137,0x387d002b,0x00000000}},	//   јчит, _smäl, _wawr_,
  { {0x99620114,0x7cf8013d,0x7bda00dd,0x00000000}},	//   píše_, líra, ăcuţ,
  { {0x6b890122,0x38580049,0x6386309f,0x00000000}},	//   _kreg, _مشهد_, агма,
  { {0xa3e60161,0xdddc1bba,0xdd2f011b,0x00000000}},	//   _बुश_, _parū, _něžn,
  { {0x76430146,0x78a2006f,0x6d4b0051,0x00000000}},	//   _udny, _zoov, ągaj,
  { {0xe45f0137,0x672930a0,0x7d020078,0x00000000}},	//   rnör_, lpej, ymos,
  { {0xdd2f0080,0x7f4d017d,0x6b8930a1,0x00000000}},	//   _běžn, fraq, _oreg,
  { {0x6b890164,0x6ef0004b,0x1fa730a2,0x00000000}},	// [5100] _nreg, läbi, акти_,
  { {0x27f200d1,0x29f5008b,0x290f30a3,0x00000000}},	//   _øyne_, _óa_, _liga_,
  { {0x290f0331,0x1d0a0893,0x6561006c,0x00000000}},	//   _oiga_, вежи_, ntlh,
  { {0x8c3d003b,0x61e8004b,0xab2a30a4,0x00000000}},	//   _roşc, üdlu, вода_,
  { {0x3f8412a2,0x6b8930a5,0x61e90058,0x00000000}},	//   _ému_, _creg, ğele,
  { {0x78a20004,0x61e9005b,0x7c2d0026,0x00000000}},	//   _soov, şele, ðarr,
  { {0x8c960088,0xf8c9008b,0x6b8930a6,0x00000000}},	//   _краі, hẩu_, _ereg,
  { {0x25ff016a,0x7cf80080,0x248030a7,0x00000000}},	//   _रणजी_, bíra, _naim_,
  { {0x6b8930a8,0x290f270d,0x00000000,0x00000000}},	//   _greg, _diga_,   ,
  { {0x290f0627,0x27ef0137,0xb6060121,0x00000000}},	//   _eiga_, _dygn_, иянк,
  { {0x78a221ef,0xc4c70021,0x5924005d,0x00000000}},	//   _toov, لتحو, _اکتف,
  { {0x60d60051,0x8c3d0058,0xe7860092,0x00000000}},	//   jnym, _koşa, _вуко,
  { {0xe8d7014e,0x889b0063,0x60d62e1b,0x00000000}},	//   _דואר_, _שבדי, dnym,
  { {0x175707e9,0xa15930a9,0xa7bb009d,0x00000000}},	//   _כסדר_, лагу_, _שֶׁת,
  { {0x26cc30aa,0x24800003,0x290430ab,0x00000000}},	//   mido_, _faim_, omma_,
  { {0x6d4300c2,0x26cc304d,0x7f4d006c,0x00000000}},	//   šnak, lido_, traq,
  { {0x7eb200d1,0xc2eb0021,0x543c0041,0x00000000}},	// [5110] _væpn, _لعدم_, _סעזא,
  { {0x26cc0b2b,0x7cf80080,0x9f66008b,0x00000000}},	//   nido_, víra, _đuôi_,
  { {0xa184000d,0xafdb01e1,0xb7bd00dd,0x00000000}},	//   _дыял, _idøm, rbţi,
  { {0x4095043b,0x27230024,0xed580086,0x00000000}},	//   _الحر, nčný_, рої_,
  { {0x290f051e,0x7cf100df,0x2d8c00be,0x00000000}},	//   _riga_, nåri, _áden_,
  { {0x26cc006d,0x290f1118,0xe50a008b,0x00000000}},	//   jido_, _siga_, _lặp_,
  { {0x26cc0fca,0x290f0035,0x27230066,0x00000000}},	//   dido_, _piga_, kčný_,
  { {0x394930ac,0x60cd30ad,0x6b8930ae,0x00000000}},	//   čas_, niam, _treg,
  { {0x290f30af,0x6f050139,0xc87900dd,0x00000000}},	//   _viga_, omhc, noşi_,
  { {0x60cd051e,0x26cc0b24,0x60d606ce,0x00000000}},	//   hiam, gido_, znym,
  { {0x60cd00eb,0x290f0397,0x8578005a,0x00000000}},	//   kiam, _tiga_, асят_,
  { {0xe50a008b,0x67290656,0x6915004c,0x00000000}},	//   _cặp_, ppej, _všed,
  { {0x26cc0b2b,0x60cd30b0,0x60d60066,0x00000000}},	//   bido_, diam, vnym,
  { {0x26c700e3,0x26cc0fca,0x68e91815,0x00000000}},	//   _umno_, cido_, loed,
  { {0x78f90041,0x7c360014,0x60cd30b1,0x00000000}},	//   ָפּו, ðyrk, fiam,
  { {0x60cd30b2,0xe50a001b,0x24800025,0x00000000}},	//   giam, _gặp_, _uaim_,
  { {0xddd50198,0x2d8a007d,0x60d6025f,0x00000000}},	// [5120] _razš, _srbe_, rnym,
  { {0x68e90185,0x442230b3,0x60d60022,0x00000000}},	//   hoed, lck_, snym,
  { {0x60cd02f6,0x442230b4,0xc27b009f,0x00000000}},	//   biam, ock_, _גריי,
  { {0x26cc0016,0x7d1b00c2,0x2056005e,0x00000000}},	//   zido_, _čust, _утор,
  { {0x68e90185,0x78bb0db4,0x442230b5,0x00000000}},	//   doed, dhuv, ick_,
  { {0x26cc1358,0xdb830121,0xd37b009a,0x00000000}},	//   xido_, ягчи, טרנט,
  { {0x26cc30b6,0x6e3e0122,0x68e9001f,0x00000000}},	//   vido_, mapb, foed,
  { {0xa3b80235,0x4422006f,0x68e91615,0x00000000}},	//   चना_, jck_, goed,
  { {0x26cc30b7,0xf09f008b,0x2fc007eb,0x00000000}},	//   tido_, _giàu_, nzig_,
  { {0x60cd11cd,0x87e30076,0xda66007e,0x00000000}},	//   ziam, яюще, _داري,
  { {0x26cc04a6,0xa5f8018b,0x8c3d003b,0x00000000}},	//   rido_, рену_, _moşn,
  { {0x6d430025,0x7aea04a1,0x7c22198b,0x00000000}},	//   ánai, loft, ncor,
  { {0x2fc00122,0x7c220290,0x6e3e173c,0x00000000}},	//   jzig_, icor, kapb,
  { {0x7cf10838,0xdddc004c,0x60cd0022,0x00000000}},	//   råri, _narů, wiam,
  { {0x60cd30b8,0x2fc0006f,0x3f8b0734,0x00000000}},	//   tiam, ezig_, _srcu_,
  { {0xc879003b,0x7aea00ca,0x765a05a5,0x00000000}},	//   toşi_, hoft, lgty,
  { {0x40340055,0x2aab00b9,0x7c2230b9,0x00000000}},	// [5130] яетс, _købt_, dcor,
  { {0xc879003b,0x765a30ba,0x4255005d,0x00000000}},	//   roşi_, ngty, _بندر,
  { {0xec61000d,0xdd910021,0x60cd30bb,0x00000000}},	//   дзеi_, بوا_, piam,
  { {0xaca3008b,0x61fa0b42,0xf55b0041,0x00000000}},	//   _miện, ütle, רדאמ,
  { {0x68e90250,0xe9db007e,0xfaa52c9e,0x00000000}},	//   voed, گذشت_, жало,
  { {0x93fc0041,0x2d8702fd,0xd358009a,0x00000000}},	//   אלדי, ånes_, מידי_,
  { {0xaa560138,0x442200c7,0xce680086,0x00000000}},	//   цију_, yck_, _уряд_,
  { {0xd0fb0161,0xe8f900d7,0x7c2230bc,0x00000000}},	//   ्षिण_, јли_, ccor,
  { {0xcb34005a,0x78bb0137,0x68e930bd,0x00000000}},	//   _нетъ, rhuv, roed,
  { {0x7c3b03b2,0x68e930be,0x78bb30bf,0x00000000}},	//   _heur, soed, shuv,
  { {0x68e90104,0x7c3b30c0,0x21260066,0x00000000}},	//   poed, _keur, _čoho_,
  { {0x240a005a,0x442230c1,0x69dc005f,0x00000000}},	//   инни_, uck_, _žreg,
  { {0x7c3b30c2,0xbec3001c,0x7cf8013d,0x00000000}},	//   _meur, _ķīni, zíro,
  { {0x7c3b03b2,0xe716009a,0x00000000,0x00000000}},	//   _leur, _וחסר_,   ,
  { {0x7e7710b8,0x9f8b004d,0x99870078,0x00000000}},	//   dexp, tößt_, manų_,
  { {0x8066000d,0x2fc0051c,0x7aea013d,0x00000000}},	//   ўваж, tzig_, zoft,
  { {0x3eb80150,0x60c100ac,0xee3a1dd0,0x00000000}},	// [5140] _plrt_, ëlma, ина_,
  { {0x2fc0004d,0x7e770f4a,0x61e9003b,0x00000000}},	//   rzig_, gexp, şela,
  { {0x6e3e30c3,0x38b1013d,0x7c3b06ad,0x00000000}},	//   rapb, _várj_, _beur,
  { {0x6ef000fe,0x61fe019f,0x7afd008f,0x00000000}},	//   väbu, _izpl, _īsta,
  { {0x7c3b021f,0xbb43000a,0x7c2230c4,0x00000000}},	//   _deur, дечк, rcor,
  { {0x7c2230c5,0x7cf8004a,0x8c3d0058,0x00000000}},	//   scor, píro, _hoşl,
  { {0x6e3c00dd,0x7c3b30c6,0x7c220168,0x00000000}},	//   _ierb, _feur, pcor,
  { {0x7c3b0717,0x6e3c30c7,0x7aea30c8,0x00000000}},	//   _geur, _herb, soft,
  { {0xd6da011c,0xd7fa0097,0x6e3c30c9,0x00000000}},	//   ито_, шук_, _kerb,
  { {0x7d1c30ca,0x1996005e,0x99870078,0x00000000}},	//   _kurs, _мјер, ganų_,
  { {0x69150080,0x24190121,0x6e3c192e,0x00000000}},	//   _všec, йоны_, _merb,
  { {0xef1f00bd,0x7d1c30cb,0x657a002b,0x00000000}},	//   _früh_, _murs, rwth,
  { {0xd7940062,0x99870078,0x7cf100a5,0x00000000}},	//   _хилъ, banų_, pårv,
  { {0x7d1c0cfc,0xd6d90051,0x6e3c30cc,0x00000000}},	//   _ours, kuły_, _nerb,
  { {0x8c3d005b,0x7d1c0b95,0x27200013,0x00000000}},	//   _boşl, _nurs, _hòn_,
  { {0x7094000d,0xa3e60042,0xd6d90022,0x00000000}},	//   масф, _बुक_, duły_,
  { {0x6e3c08f0,0x200f0019,0xaadb0042,0x00000000}},	// [5150] _berb, ägi_, _बदलक,
  { {0x7c3b024a,0xdef10021,0x27200013,0x00000000}},	//   _seur, رًا_, _mòn_,
  { {0x6e3c04bf,0xd6d90051,0x9c190021,0x00000000}},	//   _derb, guły_, مياء_,
  { {0x317a0047,0x6aba30cd,0x6e3c0983,0x00000000}},	//   _פארד, _altf, _eerb,
  { {0x7c3b0994,0x628500bb,0x645d0078,0x00000000}},	//   _veur, _kaho, igsi,
  { {0x63a00137,0x337c0063,0x7d1c30ce,0x00000000}},	//   ämni, שְׁב, _furs,
  { {0xf2d400b5,0x201e003b,0x99870078,0x00000000}},	//   ועס_, _ştii_, vanų_,
  { {0x764a001f,0x6e3c30cf,0xfc3f0014,0x00000000}},	//   _adfy, _zerb, _þí_,
  { {0x2720001b,0x6d4530d0,0x6e3c30d1,0x00000000}},	//   _còn_, lsha, _yerb,
  { {0x645d2886,0x6285054e,0x6d430078,0x00000000}},	//   egsi, _naho, šnau,
  { {0x6e2500bd,0xf3e907e9,0x6f1d0f20,0x00000000}},	//   ichb, _עף_, _lusc,
  { {0x7f440164,0x628500a4,0xf2c90047,0x00000000}},	//   ysiq, _aaho, _גע_,
  { {0x2720008b,0x99870006,0x628530d2,0x00000000}},	//   _gòn_, panų_, _baho,
  { {0x645d1120,0x0cb80053,0x6d45119a,0x00000000}},	//   agsi, _आत्म, ksha,
  { {0x69c300ea,0xdddc000c,0xa6e10026,0x00000000}},	//   nzne, _marţ, öðud,
  { {0x6f1d141f,0x6e3c30d3,0x6297017d,0x00000000}},	//   _busc, _serb, _enxo,
  { {0x6e3c08f0,0x7d1c02a4,0xe5050021,0x00000000}},	// [5160] _perb, _surs, _تبوي,
  { {0x1fb5019d,0x7d1c0034,0x22650066,0x00000000}},	//   єстр, _purs, ľský_,
  { {0x6e3c0a5d,0x7f440164,0xc27b01f9,0x00000000}},	//   _verb, ssiq, _פרטי,
  { {0x628504e9,0x6e3c30d4,0x7cf105b9,0x00000000}},	//   _zaho, _werb, dårs,
  { {0x628530d5,0x6e3c0e53,0xd0f90161,0x00000000}},	//   _yaho, _terb, ंतरण_,
  { {0x7d1c30d6,0x6d450150,0xdb2300ea,0x00000000}},	//   _turs, bsha, írál,
  { {0x6f1d00bd,0x764109f2,0x6d43013d,0x00000000}},	//   _zusc, daly, ánat,
  { {0x8ddb0063,0x4ddb0063,0xc879003b,0x00000000}},	//   _הקלק, _החלו, geş_,
  { {0x69c30130,0x998c056c,0x80c10082,0x00000000}},	//   azne, _jedź_, रोटे,
  { {0x35b409b3,0x95d80002,0x64400014,0x00000000}},	//   дбор, ждот_, ðmin,
  { {0x69c30045,0x645a0006,0x628530d7,0x00000000}},	//   czne, ėtin, _raho,
  { {0x628500a4,0xbec3008f,0x79b70063,0x00000000}},	//   _saho, _ķīmi, _מלבד_,
  { {0x628530d8,0x9f59005b,0xd7060121,0x00000000}},	//   _paho, üyük_, _езди,
  { {0x764a0146,0x6f1d30d9,0xb05b004d,0x00000000}},	//   _udfy, _rusc, _kläg,
  { {0x291e014f,0x6f1d30da,0x645d00a4,0x00000000}},	//   _juta_, _susc, pgsi,
  { {0x62850185,0x55770047,0x61e9003b,0x00000000}},	//   _waho, _זעהן_, şelo,
  { {0x291e30db,0x442930dc,0x6d4730dd,0x00000000}},	// [5170] _luta_, _ifa_, _svja,
  { {0x6e2500bd,0x4ed40086,0x6d4530de,0x00000000}},	//   uchb, нюєт, tsha,
  { {0x7c2d0118,0x6e25103b,0x6f1530df,0x00000000}},	//   ñaro, rchb, _vizc,
  { {0x6e25004d,0xe45f0137,0x6d452e2d,0x00000000}},	//   schb, ngö_, rsha,
  { {0x68e4034d,0x9f890122,0x2d9c00c7,0x00000000}},	//   čidl, _vóór_, äver_,
  { {0x1ee7007e,0x7cf1102b,0x291e017e,0x00000000}},	//   _روزی_, tårs, _buta_,
  { {0x764130e0,0x644d30e1,0xef1f00be,0x00000000}},	//   valy, _odai, _huü_,
  { {0x7cf10205,0x764100a4,0x291e22ba,0x00000000}},	//   rårs, waly, _duta_,
  { {0xf708008b,0x76410465,0x7c2930e2,0x00000000}},	//   _hủy_, taly, _ifer,
  { {0x291e0009,0x644d30e3,0x442930e4,0x00000000}},	//   _futa_, _adai, _afa_,
  { {0xb05b00c7,0xc879003b,0x764130e5,0x00000000}},	//   _kläd, peş_, raly,
  { {0xb60500c2,0x57b50256,0x44291806,0x00000000}},	//   _rušč, _обет, _cfa_,
  { {0xaca3001b,0x672b02f0,0x38b80003,0x00000000}},	//   _chỉn, _utgj, _zéro_,
  { {0xb60500c3,0x9f560003,0x386d30e6,0x00000000}},	//   _pušč, _âgés_, lfer_,
  { {0xa1870001,0x6d43003b,0x7c2930e7,0x00000000}},	//   мбра_, ânal, _ofer,
  { {0xdddc00eb,0xc5f20063,0x7c2d006d,0x00000000}},	//   _narš, _שדה_, ñarl,
  { {0xe45f0072,0x386d30e8,0x4de60053,0x00000000}},	// [5180] riöt_, ifer_, _जुड़े_,
  { {0xb6050006,0x2d91007d,0xc003005e,0x00000000}},	//   _tušč, _brze_, тпук,
  { {0xb05b00c7,0x6449007a,0x201e000c,0x00000000}},	//   _bläd, ðeig, _ştiu_,
  { {0x386d006f,0x291e30e9,0x77690137,0x00000000}},	//   jfer_, _ruta_, ktex,
  { {0x291e003b,0x6d430014,0x386d002b,0x00000000}},	//   _suta_, ánar, dfer_,
  { {0x291e017f,0x7c2930ea,0x776930eb,0x00000000}},	//   _puta_, _efer, dtex,
  { {0x7c290185,0xe2a70026,0x78ab01e1,0x00000000}},	//   _ffer, æðir_, _bogv,
  { {0x52bb0235,0xb05b00c7,0x2c860006,0x00000000}},	//   _उत्स, _gläd, _būdų_,
  { {0xc7c60076,0x44291f2e,0xc7d80054,0x00000000}},	//   ьски, _rfa_, ямих_,
  { {0x291e30ec,0xc6f70895,0xa534012c,0x00000000}},	//   _tuta_, мных_, нноч,
  { {0x186a000a,0xafdb00b9,0x3ea71925,0x00000000}},	//   _мажи_, _udøv, önti_,
  { {0xb8930021,0x38b10014,0x35b3089d,0x00000000}},	//   _للمع, _báru_, тбюр,
  { {0x5c370047,0x1b7b0041,0xc7b6009e,0x00000000}},	//   ורכן_, ֿטלע, _تصاع,
  { {0xb05b0137,0x68e20023,0x57fb009a,0x00000000}},	//   _nmär, _hjod, _ולדו,
  { {0x2906001b,0xa4d50054,0x22432ee7,0x00000000}},	//   _khoa_, _покі, rajk_,
  { {0xd788001b,0x44290035,0xaca3008b,0x00000000}},	//   _kể_, _ufa_, _thỉn,
  { {0x332001a8,0xa29502fe,0x26de30ed,0x00000000}},	// [5190] _guix_, _запі, onto_,
  { {0x7c2930ee,0xce6b0085,0x386d013d,0x00000000}},	//   _sfer, ўрад_, zfer_,
  { {0x7c2900bd,0x386d001f,0x26de30ef,0x00000000}},	//   _pfer, yfer_, into_,
  { {0xfc3001fb,0x38b1013d,0xef1f0058,0x00000000}},	//   لحه_, _járt_, _brüt_,
  { {0xd7880013,0xdddc2c14,0x2258005d,0x00000000}},	//   _nể_, _varš, _عجیب_,
  { {0x8c3d003b,0xf7080013,0x78ab0023,0x00000000}},	//   _moşi, _tủy_, _sogv,
  { {0xd940000d,0xa9e4004c,0x8c6702d8,0x00000000}},	//   ацыi_, _přáé_, _отад,
  { {0x24890ac8,0x08d4000d,0x6915027d,0x00000000}},	//   _naam_, кцыя, _všeo,
  { {0x386d30f0,0x63a90050,0x00000000,0x00000000}},	//   rfer_, äenl,   ,
  { {0xd7060055,0x8aa7000d,0x645a0006,0x00000000}},	//   нные_, _ўрад, ėtim,
  { {0x386d00bd,0x7769092e,0x68e230f1,0x00000000}},	//   pfer_, stex, _fjod,
  { {0x332000cd,0x19b60047,0x26de19a1,0x00000000}},	//   _puix_, _אפער_, anto_,
  { {0xa3f5000d,0xe3b70121,0x2cad0983,0x00000000}},	//   вярш, ебя_, _moed_,
  { {0x290d30f2,0x2cad004b,0x68fb30f3,0x00000000}},	//   lmea_, _loed_, llud,
  { {0x11d50086,0x7cf80858,0x68fb004b,0x00000000}},	//   вітр, síri, olud,
  { {0x7cf830f4,0xb05b0137,0x68fb0058,0x00000000}},	//   píri, _smär, nlud,
  { {0x64460e53,0x48fa0047,0x7e56066f,0x00000000}},	// [51a0] maki, פּלא, етец,
  { {0x64461eb1,0x62920066,0x6a730058,0x00000000}},	//   laki, ákoľ, nıfı,
  { {0x68fb1ebe,0x2cad002b,0x56b60041,0x00000000}},	//   klud, _boed_, עפען_,
  { {0x2cad001f,0x644630f5,0xc5f20041,0x00000000}},	//   _coed_, naki, נדא_,
  { {0xfbd2007e,0x501b0063,0x691501c8,0x00000000}},	//   دتا_, _מוכו, _všel,
  { {0xe9860001,0x64461642,0x60c4017d,0x00000000}},	//   ећин, haki, lhim,
  { {0x644624ca,0x26c200ac,0x317a0047,0x00000000}},	//   kaki, ëkom_, לאַד,
  { {0x7d0304c6,0x2cad30f6,0x7e7e30f7,0x00000000}},	//   ïnst, _goed_, lepp,
  { {0x24890438,0x6d5e30f8,0x60c40072,0x00000000}},	//   _raam_, lupa, ihim,
  { {0x2489021f,0x26de30f9,0x8c3d000c,0x00000000}},	//   _saam_, unto_, _roşi,
  { {0x6d5e30fa,0x38b100ea,0x68fb007d,0x00000000}},	//   nupa, _párt_, blud,
  { {0x7e7e09fe,0xa4d50636,0x68fb169b,0x00000000}},	//   hepp, томі, clud,
  { {0x38b1013d,0x6b82002b,0x53470085,0x00000000}},	//   _várt_, nwog, эхна,
  { {0x6d5e30fb,0xaca30013,0xe7370141,0x00000000}},	//   kupa, _phịn, _џеј_,
  { {0x64460c55,0x64660072,0xd0d50062,0x00000000}},	//   baki, ätiö, вовъ,
  { {0xd5fb014e,0x6d5e08f0,0x60c40089,0x00000000}},	//   _מפור, dupa, ghim,
  { {0xf1b9003d,0x44390780,0x2cad00a3,0x00000000}},	// [51b0] ņš_, mbs_, _roed_,
  { {0xdd950055,0x44390359,0xaca3008b,0x00000000}},	//   казы, lbs_, _thịn,
  { {0xe2a70026,0x6d5e30fc,0x67220072,0x00000000}},	//   æður_, gupa, _luoj,
  { {0xec15006a,0x60c430fd,0xc5f30041,0x00000000}},	//   نواد, chim, אדע_,
  { {0x2cad00ac,0xeaae30fe,0xbc180054,0x00000000}},	//   _voed_, ай_, ніші_,
  { {0x6d5e30ff,0x69150080,0xb05b0832,0x00000000}},	//   bupa, _všem, _fläc,
  { {0x64461acc,0x6d5e1130,0x2cad0168,0x00000000}},	//   yaki, cupa, _toed_,
  { {0x291900c7,0x68fb004b,0x290d00dd,0x00000000}},	//   ösa_, ulud, umea_,
  { {0x69dc0026,0x7c39001f,0x64463100,0x00000000}},	//   _þren, mbwr, vaki,
  { {0xa6950095,0x64462fb9,0x44393101,0x00000000}},	//   триј, waki, ebs_,
  { {0xf09f0013,0x64463102,0x7d1b01a9,0x00000000}},	//   _nhào_, taki, _kius,
  { {0x89340032,0x7d090221,0x7e7e00cd,0x00000000}},	//   _إعلا, _jhes, zepp,
  { {0x94d3000d,0x387f27d9,0x64463103,0x00000000}},	//   роўц, meur_, raki,
  { {0x4804019d,0x387f3104,0x78a906bb,0x00000000}},	//   _спів, leur_, ljev,
  { {0x644600bb,0xf09f008b,0x7d0900fe,0x00000000}},	//   paki, _chào_, _ohes,
  { {0xe0da019d,0x8c3d01f7,0x78a93105,0x00000000}},	//   єва_, _koşu, njev,
  { {0x60c418a6,0x76433106,0xb05b0137,0x00000000}},	// [51c0] rhim, _keny, _släc,
  { {0x387f1a05,0x6d5e3107,0x60c43108,0x00000000}},	//   heur_, tupa, shim,
  { {0x2b4d0c6e,0x76433109,0x387f0438,0x00000000}},	//   _avec_, _meny, keur_,
  { {0x6d5e310a,0x7e7e21a4,0xdb090080,0x00000000}},	//   rupa, sepp, ěnýc,
  { {0x7d1b003e,0x628e310b,0x387f17bf,0x00000000}},	//   _dius, odbo, deur_,
  { {0xda630001,0x3866003b,0x6b8206aa,0x00000000}},	//   ављи, _scor_, rwog,
  { {0x6722024a,0x75230a02,0x2d8700b9,0x00000000}},	//   _suoj, _nunz, ænet_,
  { {0x7d1b21a4,0x31570047,0x442000d1,0x00000000}},	//   _gius, דיקן_, _ngi_,
  { {0x764302ab,0xaca3008b,0x6f1c310c,0x00000000}},	//   _beny, _giốn, _kirc,
  { {0x7cf80066,0x4420310d,0x78bb0656,0x00000000}},	//   ríru, _agi_, akuv,
  { {0x387f1991,0x6f1c000c,0xa4d90001,0x00000000}},	//   beur_, _mirc, едну_,
  { {0xa49b00cd,0x7cf80240,0x387f0003,0x00000000}},	//   emòr, píru, ceur_,
  { {0x7643310e,0x4439310f,0x69ca0244,0x00000000}},	//   _feny, rbs_, lzfe,
  { {0x752302f6,0x26c501d9,0x3f8f0026,0x00000000}},	//   _funz, chlo_, ægum_,
  { {0x171b0047,0x76480150,0x69ca004d,0x00000000}},	//   _קווע, mady, nzfe,
  { {0x6f1c0034,0x76430035,0xa6170063,0x00000000}},	//   _airc, _zeny, _בקוד_,
  { {0x76430009,0x7d1b051e,0x7d090185,0x00000000}},	// [51d0] _yeny, _rius, _rhes,
  { {0xfe700032,0x7d1b0ea2,0x2fc9006f,0x00000000}},	//   قدم_, _sius, rzag_,
  { {0x387f0003,0x5dd50021,0x6f1c25a1,0x00000000}},	//   yeur_, دقائ, _dirc,
  { {0x8c3d000c,0x387f0003,0xcd040054,0x00000000}},	//   _noşt, xeur_, аччи,
  { {0x387f0164,0x9ad5012c,0x00000000,0x00000000}},	//   veur_, люкі,   ,
  { {0x69150b4f,0x6d58027d,0xfa55007e,0x00000000}},	//   _išei, ávac, ارشگ,
  { {0x7d090037,0x764300f3,0x387f3110,0x00000000}},	//   _thes, _reny, teur_,
  { {0x76433111,0xb05b0050,0x6f1c3112,0x00000000}},	//   _seny, _yläa, _zirc,
  { {0x76430e53,0x387f03b2,0x78a900c3,0x00000000}},	//   _peny, reur_, rjev,
  { {0xb7bd0529,0x6b890019,0x05a90076,0x00000000}},	//   ncţi, _iseg, евой_,
  { {0xd46a0001,0x387f0003,0x8c3d003b,0x00000000}},	//   нине_, peur_, _foşt,
  { {0x76430009,0x3f4f003d,0xa9ba0041,0x00000000}},	//   _weny, kļu_, _אזער,
  { {0xe918019d,0x765c0045,0x7e9b001c,0x00000000}},	//   _році_, óryc, _kāpē,
  { {0x75230035,0x7eb200b9,0xf09f00cd,0x00000000}},	//   _tunz, _næpp, _anà_,
  { {0x2729007a,0x41b5005a,0x7ae33113,0x00000000}},	//   _hún_, астт, innt,
  { {0x291d053b,0xb7bd000c,0x44660062,0x00000000}},	//   _jiwa_, ecţi, _свив,
  { {0x3f4f001c,0x6b890290,0x69150080,0x00000000}},	// [51e0] gļu_, _nseg, _všeh,
  { {0x629e3114,0x6da605ef,0x21a611db,0x00000000}},	//   _unpo, лиза, _биом,
  { {0x6b89048e,0x2d96000d,0x27293115,0x00000000}},	//   _aseg, ырас, _lún_,
  { {0x10a6000a,0x7d030983,0x1b4a2d7b,0x00000000}},	//   _симн, ïnsp, езди_,
  { {0x2d8700b9,0x7cdc00c2,0xb05b0e77,0x00000000}},	//   æner_, dčrt, _klän,
  { {0xdb110014,0x69ca3116,0x656110c9,0x00000000}},	//   æfðu, tzfe, kulh,
  { {0x6b8902f6,0x272902dd,0x8c3d0529,0x00000000}},	//   _eseg, _aún_, _poşt,
  { {0x7ae30aee,0x8c790121,0x17540062,0x00000000}},	//   annt, _ищут_, авия,
  { {0x291d00a4,0x8881007e,0x8c3d003b,0x00000000}},	//   _diwa_, زیون, _voşt,
  { {0x65740001,0x27290025,0x5b7b0047,0x00000000}},	//   агођ, _dún_, _ארמא,
  { {0x6561017d,0xdef70047,0x76480051,0x00000000}},	//   gulh, רמיט_, rady,
  { {0x7648002c,0x26d90003,0xf09f008d,0x00000000}},	//   sady, ésor_, _phàm_,
  { {0xf09f008b,0xe737005e,0xb05b0137,0x00000000}},	//   _giày_, _беч_, _blän,
  { {0x291d0035,0x248d064f,0x24550013,0x00000000}},	//   _ziwa_, žem_, ụm_,
  { {0x62340086,0x61fe002b,0x5a9b0047,0x00000000}},	//   сесу, _cypl, עשלא,
  { {0x61fe0051,0x955301fb,0xb05b0ef1,0x00000000}},	//   _dypl, _اخوا, _elän,
  { {0x1ee7006a,0x7ae30014,0x2d983117,0x00000000}},	// [51f0] هوری_, ynnt, _arre_,
  { {0xaca3008b,0xb05b0e77,0x326701e4,0x00000000}},	//   _phỏn, _glän, _стив,
  { {0x61fe002b,0xff040503,0x9e072125,0x00000000}},	//   _gypl, сятн, учал,
  { {0x6fd00042,0x3c47009e,0x61e90244,0x00000000}},	//   _सेकं, اضاف, ßelu,
  { {0x2d98000f,0x909811ec,0x20c70019,0x00000000}},	//   _erre_, _свят_, _võid_,
  { {0x6b8900c2,0x39550856,0xa6e20014,0x00000000}},	//   _vseg, ањит, öðlu,
  { {0x611500eb,0x20c7004b,0xa9660062,0x00000000}},	//   _sąly, _tõid_, аища_,
  { {0x98a70078,0x7afd0023,0x61fa004e,0x00000000}},	//   rsnį_, _īstu, ütli,
  { {0x2903003d,0x7e9b001c,0x6a6703eb,0x00000000}},	//   ēja_, _tāpē, _مطال,
  { {0x681b003d,0x98a70006,0x64490026,0x00000000}},	//   _rādī, psnį_, ðein,
  { {0x27e0007a,0xdb1f0019,0x81c3008f,0x00000000}},	//   _þinn_, övõt, šēji,
  { {0x656113ba,0xb05b0504,0x232a1501,0x00000000}},	//   rulh, _slän, коми_,
  { {0xb05b00bd,0xf7451968,0x2aab0093,0x00000000}},	//   _plän, _тело, _søby_,
  { {0xfc160063,0xe8080083,0xb1e60044,0x00000000}},	//   יקרי_, _снід_, لأزه,
  { {0xa3e20235,0x61461259,0xe297007b,0x00000000}},	//   _दशक_, реба, јас_,
  { {0x91e30086,0x61fe027d,0x2167005e,0x00000000}},	//   іоте, _vypl, јити_,
  { {0x38b800ea,0x34fb0063,0xe3b20044,0x00000000}},	// [5200] _iért_, _בהקד, _ذرة_,
  { {0xe29a1213,0xee373118,0x539b009a,0x00000000}},	//   _рао_, ину_, _ייפו,
  { {0x5d6a0076,0x38b800ea,0x7206007e,0x00000000}},	//   тием_, _kért_, _خودم,
  { {0xcea90047,0x3393005d,0x8b660043,0x00000000}},	//   וי_, _الیز, لاتم,
  { {0x60c3003b,0xab940054,0x38b8013d,0x00000000}},	//   _înma, силі, _mért_,
  { {0xb05b00fe,0xd9540021,0x27e00078,0x00000000}},	//   _yläo, منتخ, _žino_,
  { {0x27e0003b,0x6d43003b,0x98c63119,0x00000000}},	//   _ţin_, ânat, исил,
  { {0x99970062,0xfce60201,0x8b360043,0x00000000}},	//   ркът_, _тобо, _نفرش,
  { {0xc6f80001,0xc6a60336,0x3ce600a8,0x00000000}},	//   лних_, арни, mnov_,
  { {0x6d5e0139,0x7d02311a,0x3ce600a8,0x00000000}},	//   orpa, llos, lnov_,
  { {0x7d02000c,0x7aed0003,0x95ca0184,0x00000000}},	//   olos, éate, тупа_,
  { {0x7d021a6c,0xdb0d0072,0x18a3263d,0x00000000}},	//   nlos, äkök, _махм,
  { {0x78a2311b,0x7d02311c,0xe7580054,0x00000000}},	//   _inov, ilos, _силі_,
  { {0x7d020199,0xa2c4005e,0x60c6311d,0x00000000}},	//   hlos, ољск, _alkm,
  { {0x85460088,0x7d02311e,0x25b800a5,0x00000000}},	//   _тэле, klos, ärld_,
  { {0x30a4000a,0xcf270032,0x78a200a8,0x00000000}},	//   орув, لرئي, _jnov,
  { {0x3ce600c3,0x6d5801d9,0x6d5e311f,0x00000000}},	// [5210] dnov_, ávan, erpa,
  { {0x93fc009a,0x7d02195e,0x00000000,0x00000000}},	//   _בלחי, elos,   ,
  { {0x63bd1631,0x20c70004,0x7d02004d,0x00000000}},	//   lysn, _võib_, flos,
  { {0xfbd300f2,0xb05b00a5,0x9b45009e,0x00000000}},	//   يتش_, _kläm, منصو,
  { {0x307a0047,0x69de2bc6,0x799a00e5,0x00000000}},	//   _גארנ, úpen, _artw,
  { {0x7d02214c,0x8338009d,0xc334009d,0x00000000}},	//   alos, סאוס_, קוצ_,
  { {0xfc67005a,0x7c2d006d,0x7d0227da,0x00000000}},	//   _възн, ñars, blos,
  { {0xb05b00c7,0x7d02233a,0xfc300021,0x00000000}},	//   _oläm, clos, _يحق_,
  { {0x3f89001f,0xcb340062,0xf09f008d,0x00000000}},	//   nwau_, _метъ, _chài_,
  { {0x38b80026,0x20e8005b,0xc879005b,0x00000000}},	//   _sért_, eğil_, dişe_,
  { {0x8afa0047,0x00000000,0x00000000,0x00000000}},	//   _עפעק,   ,   ,
  { {0xf41f00fe,0x6b9b3120,0x39153121,0x00000000}},	//   ydät_, _krug, _умер,
  { {0xd7770021,0x98f40044,0xb8cb0042,0x00000000}},	//   _خاضع, _بثلا, खा_,
  { {0x78a22ffb,0x3f9e004c,0x673b3122,0x00000000}},	//   _znov, _čtu_, mpuj,
  { {0xb05b00fe,0x3ce60066,0xd4d6000d,0x00000000}},	//   _eläm, ynov_, _гіпэ,
  { {0x2571007a,0x26c2001c,0xb05b0244,0x00000000}},	//   mál_, ūkot_, _fläm,
  { {0x4fa3005a,0x543b0047,0x257100ea,0x00000000}},	// [5220] питв, _געפא, lál_,
  { {0x52860021,0x6d5e007d,0x394500e5,0x00000000}},	//   _الدك, trpa, _owls_,
  { {0x6d5e006f,0x7d023123,0x02b70063,0x00000000}},	//   urpa, tlos, _הליך_,
  { {0x6b9b1631,0x7d0200fe,0xab2a079a,0x00000000}},	//   _brug, ulos, года_,
  { {0x7d020007,0x6d43003b,0x3ce63124,0x00000000}},	//   rlos, ânar, rnov_,
  { {0x78a2082a,0x6da606b4,0x6b9b1d87,0x00000000}},	//   _snov, _лига, _drug,
  { {0x7d022810,0xf41f092e,0x1c3a0085,0x00000000}},	//   plos, ndär_, _бязь_,
  { {0x6b9b3125,0x25710195,0x47341857,0x00000000}},	//   _frug, dál_, онис,
  { {0x78a200c2,0xd7940062,0xeb971e3b,0x00000000}},	//   _vnov, ципъ, _лит_,
  { {0x8c3d005b,0xd6d40085,0x09e609c8,0x00000000}},	//   _inşa, іжны, _лозн,
  { {0x257100ea,0xf76f007e,0x7c2d0734,0x00000000}},	//   gál_, وای_, žare,
  { {0x94ab0002,0x24190121,0x63bd0072,0x00000000}},	//   утоа_, ионы_, tysn,
  { {0x69150024,0x38cb006a,0x2efa03a7,0x00000000}},	//   _všet, _حالی_, kopf_,
  { {0x7ae40027,0xb5a60062,0x7cdc00a8,0x00000000}},	//   éith, _грий, zčrp,
  { {0xf6770047,0x225f0058,0x26c2008f,0x00000000}},	//   _לײגט_, ğuk_, ūkos_,
  { {0x764a0185,0x26de304d,0x69150240,0x00000000}},	//   _hefy, lito_, _ušet,
  { {0x63a91781,0x29040ff2,0x644f3126,0x00000000}},	// [5230] åend, ilma_, maci,
  { {0x26de3127,0x644f2c1c,0xdddc16fe,0x00000000}},	//   nito_, laci, _darž,
  { {0x60c3003b,0x81c3008f,0xdd9b05ac,0x00000000}},	//   _înmo, ģēsi, ыша_,
  { {0xd5fb00b5,0x6b9b007d,0xe9a9007e,0x00000000}},	//   נפאר, _prug, یگان_,
  { {0x1b190076,0x60cd3128,0x765801d1,0x00000000}},	//   ажды_, mham, _odvy,
  { {0x6b9b00ac,0x60cd3129,0x4174007e,0x00000000}},	//   _vrug, lham, _بایس,
  { {0x26de312a,0x644f312b,0x60cd312c,0x00000000}},	//   dito_, kaci, oham,
  { {0x60cd312d,0x26de017d,0x644f1cd7,0x00000000}},	//   nham, eito_, jaci,
  { {0x752a00bd,0x6b9b0955,0x644f312e,0x00000000}},	//   _aufz, _urug, daci,
  { {0x62950122,0x26de312f,0x25713130,0x00000000}},	//   jdzo, gito_, tál_,
  { {0x644f3131,0x34aa0571,0x9595005e,0x00000000}},	//   faci, авно_, црпљ,
  { {0x6295001c,0x644f3132,0xd46a0699,0x00000000}},	//   edzo, gaci, шиме_,
  { {0x60cd0035,0x68e93133,0x26de3134,0x00000000}},	//   dham, mned, bito_,
  { {0x26de2f07,0x43750086,0x68fb3135,0x00000000}},	//   cito_, чуют, loud,
  { {0x90b60138,0x644f3136,0xe0da0002,0x00000000}},	//   ољаш, baci, аќај_,
  { {0x644f0b07,0x60cd3137,0x68fb3138,0x00000000}},	//   caci, gham, noud,
  { {0x2f0f00bd,0x727a0062,0x254700ea,0x00000000}},	// [5240] züge_, _кснс_, lől_,
  { {0x68fb0a53,0xb05b00fe,0x67231bef,0x00000000}},	//   houd, _yläk, _jinj,
  { {0x2d9c0114,0x60cd0384,0xf27b0063,0x00000000}},	//   íve_, bham, _דריש,
  { {0x60cd046c,0x672302ea,0xf2df0003,0x00000000}},	//   cham, _linj, ssât_,
  { {0x68e93139,0x99a50130,0x5f760044,0x00000000}},	//   dned, _čuše_, _باجر,
  { {0x26de0460,0x644f313a,0xaa47005e,0x00000000}},	//   xito_, zaci, опља_,
  { {0x26de313b,0x60c41c1e,0x765c0051,0x00000000}},	//   vito_, okim, órym,
  { {0x764a0185,0x60c4313c,0x3ced1262,0x00000000}},	//   _sefy, nkim, _gjev_,
  { {0x3eb818eb,0xb05b00c7,0x60c40006,0x00000000}},	//   _kort_, _släk, ikim,
  { {0x26de0016,0xddde000c,0x98ab008f,0x00000000}},	//   uito_, cepţ, ālām_,
  { {0x68fb00e8,0x644f313d,0x3eb8155d,0x00000000}},	//   boud, taci, _mort_,
  { {0x26de313e,0x62950051,0x68fb1a05,0x00000000}},	//   sito_, wdzo, coud,
  { {0x26de313f,0x6d58004a,0x3eb83140,0x00000000}},	//   pito_, ávaj, _oort_,
  { {0x2547000f,0x660300ac,0x644f3141,0x00000000}},	//   ből_, _fynk, saci,
  { {0x644f03db,0x62873142,0x62953143,0x00000000}},	//   paci, rejo, rdzo,
  { {0x6287099a,0x60cd14d1,0xffe70200,0x00000000}},	//   sejo, uham, оюзн,
  { {0x3eb83144,0x44290004,0x60cd0ff0,0x00000000}},	// [5250] _bort_, _iga_, rham,
  { {0x3eb83145,0xdd9b2d76,0x60cd3146,0x00000000}},	//   _cort_, ише_, sham,
  { {0x68e90185,0x3eb80199,0x60cd0474,0x00000000}},	//   yned, _dort_, pham,
  { {0x60c4161f,0x6ab80082,0xe58b009a,0x00000000}},	//   ckim, _अवॉर, יָדָ,
  { {0x4429099b,0x644d0025,0xfaa50be6,0x00000000}},	//   _mga_, _meai, зало,
  { {0x644d017d,0x68fb2af9,0xda7b3147,0x00000000}},	//   _leai, woud, ряд_,
  { {0xceb200b5,0x6994000d,0x20bf0053,0x00000000}},	//   _אים_, дрых, _एकाध,
  { {0xa3cb0053,0x66030051,0x44293148,0x00000000}},	//   लना_, _rynk, _nga_,
  { {0x76410185,0xfa8b0076,0x66e50245,0x00000000}},	//   tbly, _всей_, зопа,
  { {0x44290004,0x2547000f,0xddde108f,0x00000000}},	//   _aga_, től_, lepš,
  { {0x764100e8,0xb05b00fe,0x68e900d1,0x00000000}},	//   rbly, _eläi, pned,
  { {0x2547000f,0x644d00dd,0xda08005d,0x00000000}},	//   ről_, _ceai, _بيمه_,
  { {0x67230397,0x644d0139,0x63a90050,0x00000000}},	//   _tinj, _deai, äenp,
  { {0xf67500b5,0x44290004,0x386d3149,0x00000000}},	//   _זײַט_, _ega_, lger_,
  { {0x2f1400c7,0x60c400fe,0x20c70019,0x00000000}},	//   lägg_, tkim, _võin_,
  { {0xf99200b5,0x55ba014e,0x386d314a,0x00000000}},	//   ערן_, _למצו, nger_,
  { {0x60c4314b,0x386d2c0e,0x776905c3,0x00000000}},	// [5260] rkim, iger_, nuex,
  { {0x26c500eb,0xd00f0021,0x60c4314c,0x00000000}},	//   nklo_, الك_, skim,
  { {0xccef0001,0x3eb8314d,0xa2bb0063,0x00000000}},	//   ећ_, _vort_, _המיט,
  { {0x3eb800bd,0xf5360047,0x386d006f,0x00000000}},	//   _wort_, לטער_, jger_,
  { {0x3eb81276,0x6e3b0058,0x66060022,0x00000000}},	//   _tort_, _şube, ękki,
  { {0x386d2da1,0xc3330149,0x68e0002b,0x00000000}},	//   eger_, עוו_, wimd,
  { {0xbefa0053,0x68e0005b,0x2480007d,0x00000000}},	//   ्तीन_, timd, _obim_,
  { {0x386d314e,0xddde008f,0x200f004d,0x00000000}},	//   gger_, cepš, ügig_,
  { {0x7b09007a,0x644d017d,0x68e0005b,0x00000000}},	//   ðstö, _reai, rimd,
  { {0x692a0080,0x24800089,0x68e0005b,0x00000000}},	//   _před, _abim_, simd,
  { {0x6aa80146,0xceb3014e,0x4429314f,0x00000000}},	//   _indf, תית_, _pga_,
  { {0x6aba0089,0xc9850021,0x00000000,0x00000000}},	//   _hotf, _تشكي,   ,
  { {0x28a90053,0x46a63150,0xb865005d,0x00000000}},	//   कारि, _надв, _زانو,
  { {0x971301dd,0xd3780054,0x78a7008f,0x00000000}},	//   _зміц, ччю_, ējve,
  { {0x867b0063,0x27320013,0xf67b0063,0x00000000}},	//   _הרוו, _hân_, _האומ,
  { {0x116a007e,0x44293151,0x1bec0042,0x00000000}},	//   تلفی_, _uga_, जपाल_,
  { {0xcd020022,0xc4f8009a,0xbefa0082,0x00000000}},	// [5270] _mość_, _מזהי_, ्तून_,
  { {0x27323152,0x7c29002b,0x2007008f,0x00000000}},	//   _mân_, _sger, āni_,
  { {0x273229d6,0x386d0807,0x5c7521dd,0x00000000}},	//   _lân_, yger_, длет,
  { {0x6aa800a5,0x3ea7013d,0xf045005d,0x00000000}},	//   _andf, űnt_, _تعدی,
  { {0x7aed0003,0xdb200066,0xdfd80062,0x00000000}},	//   éato, _štád, _еър_,
  { {0x2f140137,0x07f20047,0xd9390131,0x00000000}},	//   vägg_, _דאָס_, очиш_,
  { {0x386d3153,0x7bc23154,0x79a70054,0x00000000}},	//   tger_, ayou, ярде,
  { {0xb05b00fe,0x7c293155,0x386d3156,0x00000000}},	//   _eläv, _uger, uger_,
  { {0xcd020051,0x386d0238,0x27323157,0x00000000}},	//   _dość_, rger_, _cân_,
  { {0x2732001b,0xd7060076,0x79960051,0x00000000}},	//   _dân_, мные_, ływa,
  { {0x386d0137,0x7ae33158,0x58390085,0x00000000}},	//   pger_, mint, _дзея_,
  { {0x7ae33159,0x6d580139,0xfbc700f2,0x00000000}},	//   lint, ávai, نت_,
  { {0x7e0a0235,0x1e0a0161,0x2f14089f,0x00000000}},	//   _वर्ग_, _वर्ष_, läge_,
  { {0xdb00315a,0x6d580078,0x7ae3315b,0x00000000}},	//   _armê, švai, nint,
  { {0x7ae3315c,0x91e60062,0xdfd2005d,0x00000000}},	//   iint, фове, چيز_,
  { {0x7ae3315d,0x9fca315e,0xdfd214d7,0x00000000}},	//   hint, огба_, نيز_,
  { {0x7ae3315f,0x31780051,0x62970195,0x00000000}},	// [5280] kint, strz_, _faxo,
  { {0x7ae300eb,0x69c33160,0x9d463161,0x00000000}},	//   jint, kyne, дежд,
  { {0x7ae33162,0xe4d7005d,0x6aba3163,0x00000000}},	//   dint, _رویت_, _rotf,
  { {0x7c2d00b2,0x69c33164,0x7ae33165,0x00000000}},	//   žarn, dyne, eint,
  { {0x6d6700eb,0x7ae300c7,0xef1a0256,0x00000000}},	//   _įraš, fint, _ммм_,
  { {0x7ae33166,0x69c3002b,0xead80085,0x00000000}},	//   gint, fyne, ямлі_,
  { {0x2732008b,0xfaa30131,0xab660022,0x00000000}},	//   _sân_, тајо, wożą,
  { {0xcc8703ec,0x692a0080,0x2732003b,0x00000000}},	//   _обсе_, _přeb, _pân_,
  { {0xb05b004d,0x7ae33167,0x2f030046,0x00000000}},	//   _gläu, bint, _örfá_,
  { {0x2732008b,0x7ae33168,0x6aa80137,0x00000000}},	//   _vân_, cint, _undf,
  { {0x27e9007a,0xb05b0137,0x7e9b009a,0x00000000}},	//   _þann_, _klät, קסטו,
  { {0x692a0080,0x62973169,0x2732316a,0x00000000}},	//   _třeb, _saxo, _tân_,
  { {0xd91b0e2a,0x05de0042,0xe3c50044,0x00000000}},	//   _וואל, _फेरब, رْسَ,
  { {0x20c7004b,0x0576013a,0x86c400de,0x00000000}},	//   _võim_, _قاعد, _سيعن,
  { {0x41e42049,0xe1640044,0x00000000,0x00000000}},	//   віта, َدِي,   ,
  { {0x7ae3316b,0x34950131,0x5064129d,0x00000000}},	//   zint, _чаир, ктуа,
  { {0x13f40121,0x6297316c,0x69c30022,0x00000000}},	// [5290] _изъя, _taxo, zyne,
  { {0x20c70004,0x71790002,0x4439316d,0x00000000}},	//   _kõik_, _ебор_, lcs_,
  { {0x7ae30529,0xb05b00bd,0x257800ea,0x00000000}},	//   vint, _blät, nél_,
  { {0x4439316e,0x213e0025,0x7ae3316f,0x00000000}},	//   ncs_, íthe_, wint,
  { {0x60d60063,0x69c3001f,0x44393170,0x00000000}},	//   _נושא_, wyne, ics_,
  { {0xdb2500ea,0x49951c9d,0x69c33171,0x00000000}},	//   _épül, ешит, tyne,
  { {0x7ae33172,0x64460051,0x225e0022,0x00000000}},	//   rint, ybki, ótki_,
  { {0x2f1400bd,0x2578004c,0xef1f004b,0x00000000}},	//   räge_, dél_, _tsüs_,
  { {0x692a0080,0x7ae33173,0x69c33174,0x00000000}},	//   _přec, pint, syne,
  { {0xcf920063,0xb6590121,0x66cd0046,0x00000000}},	//   נטי_, чших_, _búka,
  { {0xb05b00fe,0x69dc0014,0x0609071f,0x00000000}},	//   _ylät, _þrep, янок_,
  { {0xcdda00b5,0xdb0000cd,0xe45f0137,0x00000000}},	//   פֿיר, _armè, skön_,
  { {0x61fb01f7,0x64460078,0x692a004c,0x00000000}},	//   şull, rbki, _třec,
  { {0xb05b00c7,0xf6790047,0x44393175,0x00000000}},	//   _oläs, _זאַמ, acs_,
  { {0x7c3b0014,0xd13200f2,0x0166030b,0x00000000}},	//   _ofur, امر_, экво,
  { {0x6026150f,0x4439013d,0x7fd60085,0x00000000}},	//   едба, ccs_, нізі,
  { {0x6fd60086,0xd00f0021,0x6e3b005b,0x00000000}},	// [52a0] хівц, ملف_, _şuba,
  { {0x4df60076,0xb05b0e77,0x63a423ce,0x00000000}},	//   няет, _slät, _irin,
  { {0x63a40026,0xb05b004d,0x628e3176,0x00000000}},	//   _hrin, _plät, mebo,
  { {0x63a43177,0x629c04bf,0xe45f0137,0x00000000}},	//   _krin, ldro, lhör_,
  { {0xab940054,0x8c650054,0x629c3178,0x00000000}},	//   тилі, ттєд, odro,
  { {0x387f007a,0x657a002b,0x7d0b3179,0x00000000}},	//   efur_, ytth, algs,
  { {0x629c003d,0x7c3b0185,0x387f001f,0x00000000}},	//   idro, _ffur, ffur_,
  { {0xf1b30063,0x629c001f,0x628e2655,0x00000000}},	//   רסה_, hdro, hebo,
  { {0x628e03b1,0xb05b004d,0x67d42099,0x00000000}},	//   kebo, _klär, топу,
  { {0x257802af,0x7c240b59,0x8f9b0063,0x00000000}},	//   tél_, žirs, ליפי,
  { {0x63a4317a,0x628e317b,0x629c00a3,0x00000000}},	//   _arin, debo, ddro,
  { {0x58060021,0x629c317c,0x7d02004e,0x00000000}},	//   _كواك, edro, noos,
  { {0xdb00317d,0x629c006f,0x4439317e,0x00000000}},	//   _armé, fdro, rcs_,
  { {0x69a40394,0x236400ea,0x4439317f,0x00000000}},	//   किपी, ámja_, scs_,
  { {0x63a43180,0x7d020ff2,0x69d83181,0x00000000}},	//   _erin, koos, nzve,
  { {0x629c1568,0x69d83182,0x63a43183,0x00000000}},	//   adro, izve, _frin,
  { {0xe315000a,0x6d5c04dd,0x29060035,0x00000000}},	// [52b0] _имињ, _avra, _mkoa_,
  { {0xdef83184,0x2bdb0053,0x628e3185,0x00000000}},	//   ных_, _मेगा, cebo,
  { {0xf6530047,0x63a40401,0x2d873186,0x00000000}},	//   רצע_, _zrin, ïne_,
  { {0x68e201e1,0x69d83187,0x7d020050,0x00000000}},	//   _nmod, dzve, goos,
  { {0x6d5c3188,0x0056009a,0xa227005d,0x00000000}},	//   _evra, _בשרת_, _ترکه,
  { {0x68e2001f,0xda620b3f,0x09e50320,0x00000000}},	//   _amod, авши, колн,
  { {0x6d581994,0xdef4000d,0x69ce004d,0x00000000}},	//   ávat, _спры, _übel,
  { {0x212b0080,0x77850062,0x628e0051,0x00000000}},	//   _jich_, влиз, zebo,
  { {0x212b00bd,0xb05b00fe,0x60c3003b,0x00000000}},	//   _mich_, _ylär, _înmu,
  { {0x2cbf016d,0x2cad0080,0x98b2001c,0x00000000}},	//   _houd_, _hned_, ādām_,
  { {0x628e0831,0x2cbf006f,0xd46a006e,0x00000000}},	//   vebo, _koud_, мине_,
  { {0x628e3051,0x63a41a72,0x78ab3189,0x00000000}},	//   webo, _prin, _ungv,
  { {0x65682aa8,0x628e318a,0x692a004c,0x00000000}},	//   ardh, tebo, _křen,
  { {0x68e20051,0x2cbf01a0,0x290d318b,0x00000000}},	//   _zmod, _loud_, llea_,
  { {0x628e318c,0x4276007e,0x23270815,0x00000000}},	//   rebo, _یادآ, тори_,
  { {0x7c2d00c3,0x63a4318d,0x55f60063,0x00000000}},	//   žarj, _trin, _במצב_,
  { {0x212b00bd,0xe45f00c7,0x9f4f0026,0x00000000}},	// [52c0] _dich_, phör_, ægð_,
  { {0x212b0c70,0x69a40161,0xa1c6000d,0x00000000}},	//   _eich_, किमी, _абод,
  { {0x6b890516,0x2258318e,0xb13a0021,0x00000000}},	//   _apeg, mark_, _تأخذ_,
  { {0x22580031,0xcb6a026b,0xbb4627b8,0x00000000}},	//   lark_, даде_, ведк,
  { {0x764801e1,0x6bd60049,0x6d45318f,0x00000000}},	//   ybdy, ختار, apha,
  { {0x212b02b0,0x6e430fe2,0x291f053b,0x00000000}},	//   _zich_, _верз, emua_,
  { {0x610c00bd,0xd91a0076,0x7d023190,0x00000000}},	//   eßli, мьи_, poos,
  { {0x07980001,0x2cbf0179,0x5886000d,0x00000000}},	//   евић_, _goud_, тыка,
  { {0x6c7b00b5,0x16340094,0x00000000,0x00000000}},	//   _קאמפ, лепя,   ,
  { {0x2b460268,0x291f05b3,0x290d003b,0x00000000}},	//   mpoc_, amua_, alea_,
  { {0xd5b7019d,0xaa370041,0x1e57089e,0x00000000}},	//   вся_, _סטאק_, כשיר_,
  { {0x290d3191,0x68e205e7,0x77ca0d82,0x00000000}},	//   clea_, _umod, _олег_,
  { {0x212b2392,0x212000c2,0x290400c2,0x00000000}},	//   _rich_, dmih_, moma_,
  { {0x212b0cd4,0x66e33192,0xd6d0007e,0x00000000}},	//   _sich_, _коча, _دقت_,
  { {0x7aed03b2,0xc1e80076,0x31c403d6,0x00000000}},	//   éati, вьте_, аств,
  { {0xe4d9007e,0x60d6001f,0x29043193,0x00000000}},	//   _سوخت_, ghym, noma_,
  { {0x7c2d00c2,0x30153194,0x22580b3c,0x00000000}},	// [52d0] žark, удар, bark_,
  { {0x2cbf0080,0x61ee00ea,0x6e450021,0x00000000}},	//   _soud_, ánlá, انضم,
  { {0x752d0035,0x6b893050,0x29043195,0x00000000}},	//   _kiaz, _speg, koma_,
  { {0xed580086,0xbc19000d,0x399c00ea,0x00000000}},	//   тої_, нілі_, zásá_,
  { {0x692a0080,0xdb850086,0x290417d2,0x00000000}},	//   _přen, угли, doma_,
  { {0x3f990003,0x4999042c,0x2cbf0983,0x00000000}},	//   _issu_, етия_, _woud_,
  { {0xb05b00fe,0x49bb007e,0xc8790058,0x00000000}},	//   _yläp, باشد_, lişi_,
  { {0x2cad001f,0x60cd30ad,0x752d00ca,0x00000000}},	//   _uned_, nkam, _niaz,
  { {0x2fc9002c,0x7d1b0035,0x399c013d,0x00000000}},	//   nyag_, _ihus, tásá_,
  { {0x60cd0228,0x9695005e,0x212000a8,0x00000000}},	//   hkam, уриш, zmih_,
  { {0x7d1b08f0,0x290d3196,0x60cd021e,0x00000000}},	//   _khus, plea_, kkam,
  { {0xc329014e,0x69da0047,0xaca30013,0x00000000}},	//   _זו_, _אַדו, _khốn,
  { {0x60cd3197,0x68e93198,0x22583199,0x00000000}},	//   dkam, mied, tark_,
  { {0xb05b00c7,0xdb200024,0x320c0051,0x00000000}},	//   _släp, _štúd, żdym_,
  { {0x7d1b0019,0x7d090078,0x212000a8,0x00000000}},	//   _ohus, _okes, tmih_,
  { {0x60cd002c,0x68e9319a,0xc0e30f9f,0x00000000}},	//   gkam, nied, боск,
  { {0x10a303d6,0x0eaa000d,0x22581a8c,0x00000000}},	// [52e0] щитн, нкай_, park_,
  { {0xdfcf0032,0x68e9319b,0x93b70063,0x00000000}},	//   أيك_, hied, _עליו_,
  { {0xc27b00b5,0x68e9319c,0xfc660062,0x00000000}},	//   _אריי, kied, гълн,
  { {0x629e002c,0x68e9008f,0x60cd0168,0x00000000}},	//   _hapo, jied, ckam,
  { {0x629e2a3e,0xaca3001b,0x59b60053,0x00000000}},	//   _kapo, _chốn, _अपहर,
  { {0x6721007d,0x629e319d,0x29040022,0x00000000}},	//   jmlj, _japo, woma_,
  { {0x3f8000cd,0x44320089,0x2904319e,0x00000000}},	//   ltiu_, _ogy_, toma_,
  { {0x629e204e,0x672101b3,0x64560058,0x00000000}},	//   _lapo, emlj, _neyi,
  { {0x473400d7,0x2904319f,0x3f8031a0,0x00000000}},	//   јнос, roma_, ntiu_,
  { {0x29040b7e,0xc6f70121,0x629e31a1,0x00000000}},	//   soma_, лных_, _napo,
  { {0x752d31a2,0xa967005a,0x290400c2,0x00000000}},	//   _piaz, _биха_, poma_,
  { {0x68e931a3,0x2ec10053,0xc8790058,0x00000000}},	//   cied, _शक्त, yişi_,
  { {0x6456005b,0x26130013,0x60cd31a4,0x00000000}},	//   _deyi, _ẹo_, vkam,
  { {0x629e31a5,0x60cd0051,0x6d5e31a6,0x00000000}},	//   _capo, wkam, kspa,
  { {0x765a31a7,0x40350cbb,0x6d5e00ca,0x00000000}},	//   maty, иевс, jspa,
  { {0x6d5e31a8,0x64560058,0xc8790058,0x00000000}},	//   dspa, _geyi, tişi_,
  { {0x69ca001f,0x7e550086,0xce6b0499,0x00000000}},	// [52f0] hyfe, иває, еред_,
  { {0x9e150088,0xc8790683,0x799a203c,0x00000000}},	//   адзі, rişi_, _ostw,
  { {0x999e00eb,0x692a0080,0x3f800268,0x00000000}},	//   _metų_, _přel, atiu_,
  { {0x9b750021,0x629e31a9,0xdd980766,0x00000000}},	//   لاتص, _zapo, ышу_,
  { {0x3f800994,0x6d5e00eb,0x68e931aa,0x00000000}},	//   ctiu_, aspa, vied,
  { {0x68e90045,0x7aea02f0,0xa9691a5c,0x00000000}},	//   wied, gift, вика_,
  { {0x68e91bfc,0x08d5042c,0x69ca2f15,0x00000000}},	//   tied, иция, gyfe,
  { {0x7d1b0009,0xaca3001b,0x08c531ab,0x00000000}},	//   _uhus, _thốn, рбин,
  { {0x68e931ac,0x78bb31ad,0xf048009a,0x00000000}},	//   ried, rjuv, נָה֙_,
  { {0xfaf300b3,0x765a1748,0x64560058,0x00000000}},	//   _اثر_, gaty, _seyi,
  { {0x7aed0003,0x68e931ae,0x24890089,0x00000000}},	//   éatu, pied, _bbam_,
  { {0x2d81018d,0x493a0063,0x629e31af,0x00000000}},	//   ithe_, _סגנו, _sapo,
  { {0x200f004b,0x629e31b0,0x074731b1,0x00000000}},	//   ügil_, _papo, _схем,
  { {0xe5a531b2,0xdb000016,0x52760002,0x00000000}},	//   _вики, _irmã, шуму,
  { {0xc323000d,0x64560058,0x6abe004d,0x00000000}},	//   імск, _teyi, öpfi,
  { {0x2d810139,0x15fa0063,0x6615004c,0x00000000}},	//   dthe_, _בהצע, ýzku,
  { {0x6d5e2209,0x4127026b,0x41030086,0x00000000}},	// [5300] wspa, рото_, ізув,
  { {0x3f8014b1,0x6d5e31b3,0x20c7004b,0x00000000}},	//   rtiu_, tspa, _sõit_,
  { {0x273b001b,0x3f8031b4,0x6d5e0ab6,0x00000000}},	//   _lên_, stiu_, uspa,
  { {0x692a0080,0x3f8000cd,0x236d00a8,0x00000000}},	//   _přem, ptiu_, šeje_,
  { {0x273b001b,0x7aea31b5,0xcf26007e,0x00000000}},	//   _nên_, tift, _نرسي,
  { {0x4ed50088,0x2966005e,0x2007003b,0x00000000}},	//   _люст, ањив, şnic_,
  { {0xaca3008b,0x2d810025,0x7aea06f1,0x00000000}},	//   _chồn, cthe_, rift,
  { {0x273b001b,0x692a31b6,0x765a0051,0x00000000}},	//   _bên_, _zřej, waty,
  { {0x69d5000f,0x765a0c47,0xd90d007e,0x00000000}},	//   _üzen, taty, ریه_,
  { {0x24890185,0xee310063,0xb6c60330,0x00000000}},	//   _sbam_, ּֽי_, рсий,
  { {0xdcfc232c,0xfaa30054,0x6b8231b7,0x00000000}},	//   _sprę, _фахо, ltog,
  { {0xdb00000c,0xf485007e,0x6b8231b8,0x00000000}},	//   _urmâ, حادی, otog,
  { {0x765a28d2,0x6b82020f,0xd7e3012c,0x00000000}},	//   paty, ntog, _мішо,
  { {0x2455008b,0x2d81096c,0xc7db009d,0x00000000}},	//   ấm_, ythe_, _שַׁכ,
  { {0x95ca0001,0x171b00b5,0x386600c2,0x00000000}},	//   _јула_, _שווע, _kdor_,
  { {0x6b822f04,0x40340076,0x273b008b,0x00000000}},	//   ktog, жетс, _yên_,
  { {0x692a0080,0x200f0026,0x61fe29f5,0x00000000}},	// [5310] _přej, ægi_, _expl,
  { {0xfda70001,0x22950021,0x6b820618,0x00000000}},	//   ијем, _الدس, dtog,
  { {0x20070051,0x66cd0014,0xf1a41406,0x00000000}},	//   łni_, _súkk, _дрян,
  { {0x765800fe,0xfc670062,0x20c7004b,0x00000000}},	//   _levy, ръжн, _võis_,
  { {0x645d0089,0xe47a0041,0x7bcb0075,0x00000000}},	//   iasi, טרײכ, uygu,
  { {0x629531b9,0x645d31ba,0xff04005a,0x00000000}},	//   nezo, hasi, _дясн,
  { {0x2d9c0146,0x645d31bb,0x4993007e,0x00000000}},	//   ævet_, kasi, تیار,
  { {0x98ac003b,0x645d31bc,0x8c3d0075,0x00000000}},	//   _rudă_, jasi, _başe,
  { {0x6b8231bd,0x6d410003,0x692a004c,0x00000000}},	//   ctog, _élab, _zřek,
  { {0xab280001,0x645d2322,0x6567013d,0x00000000}},	//   _вођа_, easi, ájho,
  { {0xdb26006a,0x76580078,0x645d31be,0x00000000}},	//   _اولی, _devy, fasi,
  { {0x273b001b,0x398100cd,0x18a40086,0x00000000}},	//   _tên_, mós_, _маєм,
  { {0xb05b00c7,0x889a0063,0x398131bf,0x00000000}},	//   _poän, _תבני, lós_,
  { {0x8c1a014e,0xf6390047,0x62950c84,0x00000000}},	//   טורי, _גײַל, gezo,
  { {0xf8db0161,0x98db0053,0x398131c0,0x00000000}},	//   _बताय, _बताए, nós_,
  { {0xc0e3000a,0xdb0900ac,0x29d3008b,0x00000000}},	//   поск, _breë, ịa_,
  { {0x6d47003d,0xdb09006f,0x62950d13,0x00000000}},	// [5320] _atja, _creë, bezo,
  { {0x692a0080,0xe45f0014,0xe29a0cf7,0x00000000}},	//   _přek, gjöf_, _сао_,
  { {0x9325009b,0x0d860f50,0x398131c1,0x00000000}},	//   _برين, слен, jós_,
  { {0x6b8231c2,0x3eaf001c,0x6aa100ca,0x00000000}},	//   ttog, ēgta_, _aalf,
  { {0x8c3d005b,0x6b740086,0x2cb7004c,0x00000000}},	//   _başb, ілку, _šedé_,
  { {0x2d9c0146,0x6b8231c3,0x5dd6026c,0x00000000}},	//   æves_, rtog, _любу,
  { {0xf98a007e,0x645d0a49,0x69d50058,0x00000000}},	//   اخته_, yasi, _üzel,
  { {0x1d0a0001,0x6b8231c4,0x7aed0003,0x00000000}},	//   _себи_, ptog, éatr,
  { {0x386600a8,0x853c0078,0x645d31c5,0x00000000}},	//   _vdor_, avėl, vasi,
  { {0x645d0009,0x60c60058,0x398101a8,0x00000000}},	//   wasi, _lokm, bós_,
  { {0x629508ea,0x645d31c6,0x6abe004d,0x00000000}},	//   vezo, tasi, öpfu,
  { {0x7643001f,0xf79a00f2,0xa926228d,0x00000000}},	//   _efny, _منصب_, _удел,
  { {0x645d2896,0x2cb20072,0x442d01cf,0x00000000}},	//   rasi, öydy_, äe_,
  { {0xadfa0053,0x2f0f004d,0x645d31c7,0x00000000}},	//   ्थान_, nügt_, sasi,
  { {0x692a0080,0x60c631c8,0x78a2004b,0x00000000}},	//   _přeh, _bokm, _kaov,
  { {0x957c0045,0x316c0024,0x62872caa,0x00000000}},	//   rząd, ádza_, sfjo,
  { {0xe45f013d,0x6d472221,0xa9230566,0x00000000}},	// [5330] khöz_, _stja, ážil,
  { {0xd251007e,0x78a225e8,0x63ad31c9,0x00000000}},	//   _تند_, _laov, _iran,
  { {0x40350088,0x63ad31ca,0x8d950043,0x00000000}},	//   _менс, _hran, تلاش,
  { {0x63ad31cb,0x6aa131cc,0xab660023,0x00000000}},	//   _kran, _salf, kaļē,
  { {0x2d9c0146,0x2f0f00bd,0xab640086,0x00000000}},	//   æver_, fügt_, звіл,
  { {0x398131cd,0x8c3d00dd,0x25630075,0x00000000}},	//   tós_, _başc, yıl_,
  { {0x6aa121eb,0xa9250121,0xfd130049,0x00000000}},	//   _valf, одкл, _فجر_,
  { {0x63ad0952,0x69d500ea,0x398131ce,0x00000000}},	//   _oran, _üzem, rós_,
  { {0x6aa1002b,0xbcb4004c,0x4c1701f3,0x00000000}},	//   _talf, šším, _طبرس,
  { {0x66e5019d,0x39810016,0x8f9c0047,0x00000000}},	//   іона, pós_, ריזי,
  { {0x7d0b0229,0x63ad31cf,0xceb431d0,0x00000000}},	//   oogs, _aran, ליץ_,
  { {0xdd7a0063,0x6c790047,0xa50a1a08,0x00000000}},	//   סטרל, סאָפ, рема_,
  { {0x256301f7,0x63ad31d1,0x60c631d2,0x00000000}},	//   sıl_, _cran, _rokm,
  { {0x63ad0518,0x60c60058,0xe57101fb,0x00000000}},	//   _dran, _sokm, _قطب_,
  { {0x63ad31d3,0xdb0901a8,0xdbd80014,0x00000000}},	//   _eran, _creé, hæða,
  { {0xddc70051,0x2f14004b,0x20e8003b,0x00000000}},	//   _wejś, mägi_, oşii_,
  { {0x20e8003b,0x63ad15ae,0x543b0047,0x00000000}},	// [5340] nşii_, _gran, _דעפא,
  { {0xafdb31d4,0x853c0078,0x26c71d81,0x00000000}},	//   _iføl, dvėj, _jono_,
  { {0xe45f0137,0x26c731d5,0xdc3c0066,0x00000000}},	//   bjöd_, _mono_, ráľo,
  { {0xadb70021,0xe60c0041,0xabaa030b,0x00000000}},	//   تهما_, נפאָ, ивез_,
  { {0x7ed60086,0x69c5065c,0xdbd80014,0x00000000}},	//   _дівч, ähen, gæða,
  { {0x29000006,0x26c731d6,0x44020053,0x00000000}},	//   čiam_, _nono_, _लखनऊ_,
  { {0x7d0b00b9,0x58d40121,0x853c0078,0x00000000}},	//   bogs, зойт, avėj,
  { {0xec770062,0x98a3005e,0x1d0731d7,0x00000000}},	//   _мпс_, диће, _деси_,
  { {0x2918001c,0x9f4400fe,0xd6d00021,0x00000000}},	//   ēra_, _ämä_, فقة_,
  { {0x31780066,0x26c70c9d,0x85740e82,0x00000000}},	//   kurz_, _cono_, плох,
  { {0xd6d7019d,0x4866005a,0x957c0045,0x00000000}},	//   іть_, _дълб, dząc,
  { {0x63ad1d56,0x2ca6001f,0x394e10bd,0x00000000}},	//   _pran, ndod_, mpfs_,
  { {0x26c70006,0x1818005d,0x82a70131,0x00000000}},	//   _fono_, _اراک_, ошве,
  { {0x63ad31d8,0x84340054,0xe45f013d,0x00000000}},	//   _vran, ьняє, gkör_,
  { {0x692a0080,0x63ad035a,0x610e005f,0x00000000}},	//   _dřev, _wran, kėlę,
  { {0x3ea331d9,0x63ad31da,0x50670085,0x00000000}},	//   _sajt_, _tran, ўтва,
  { {0xe4520132,0x26de0024,0x63ad2776,0x00000000}},	// [5350] _אֶת_, ohto_, _uran,
  { {0x957c0045,0xddab0c91,0xdbd80026,0x00000000}},	//   cząc, ител_, væða,
  { {0xf2d20041,0x26de0072,0x0dcb0131,0x00000000}},	//   _נעט_, ihto_, јузи_,
  { {0x8c3d01f7,0xd49800b5,0xd5fb0047,0x00000000}},	//   _başa, ַכות_, ספאר,
  { {0x7d0b31db,0xaa451528,0xfc3004a0,0x00000000}},	//   rogs, пелл, نحه_,
  { {0x7f3a014e,0x21290089,0xdbd80014,0x00000000}},	//   _לעשו, lmah_, ræða,
  { {0x853c005f,0x35ae0042,0xa9660094,0x00000000}},	//   svėj, टिफ़, пища_,
  { {0x26c702f6,0x26de00fe,0x2f14004b,0x00000000}},	//   _sono_, ehto_, vägi_,
  { {0xacda0041,0xf7710021,0xfaa40050,0x00000000}},	//   _פֿלי, راة_, öään_,
  { {0x21290089,0xd7e60121,0x55e504ef,0x00000000}},	//   hmah_, ямые_, зооб,
  { {0x21292edc,0x5afa0047,0x85780456,0x00000000}},	//   kmah_, _פלעצ, осят_,
  { {0x8c3d01f7,0x656e0025,0x64410051,0x00000000}},	//   _yaşa, ábha, ślin,
  { {0xf749043b,0x69ce0199,0x692a0080,0x00000000}},	//   _التي_, _über, _přev,
  { {0x26de0512,0x3178004d,0x68fb004b,0x00000000}},	//   chto_, turz_, lnud,
  { {0x76ba0063,0xe45f0137,0x68fb0652,0x00000000}},	//   _למספ, rkör_, onud,
  { {0xa507005a,0x957c0051,0x68fb0026,0x00000000}},	//   _неща_, sząc, nnud,
  { {0x8e3a00f2,0xd47b009a,0xc0e3234f,0x00000000}},	// [5360] مسار_, _האפל, хотк,
  { {0x6fb30021,0x44200058,0x6207013d,0x00000000}},	//   عملا, _izi_, érlé,
  { {0xdb09003b,0x69c50cb0,0x823b009a,0x00000000}},	//   _preî, ähel, _לעיצ,
  { {0x644625dd,0x8c3d3039,0x653a0041,0x00000000}},	//   ncki, _paşa, צענד,
  { {0xdb0900cd,0x6d410003,0x2ca631dc,0x00000000}},	//   _creï, _élan, rdod_,
  { {0x60c4017f,0xdb0000b9,0x05cb0042,0x00000000}},	//   ljim, _ormå, ाहाब,
  { {0x60d60078,0x60c431dd,0x68fb002b,0x00000000}},	//   okym, ojim, fnud,
  { {0x60c431de,0x60d60b4f,0x8c3d18ad,0x00000000}},	//   njim, nkym, _taşa,
  { {0x60d60078,0x4cbb009a,0xfa3604a0,0x00000000}},	//   ikym, _פזמו, _فراد,
  { {0x64460051,0xfa670499,0x60c40050,0x00000000}},	//   ecki, _наук_, hjim,
  { {0x4420000c,0xceb30063,0x44990121,0x00000000}},	//   _azi_, גית_, овню_,
  { {0x26de31df,0xc4c701fb,0x493b089e,0x00000000}},	//   shto_, ستجو, _הגאו,
  { {0x53470062,0x6105005f,0xa2ab0042,0x00000000}},	//   яхна, nėle, फ़ाल्,
  { {0x236d00c3,0xa195000d,0x27f7027d,0x00000000}},	//   šejo_, магч, šená_,
  { {0x442031e0,0x2fc000a5,0x2f14004b,0x00000000}},	//   _ezi_, exig_, nägu_,
  { {0x2129003e,0x3d060053,0x6d430066,0x00000000}},	//   umah_, षकों_, ínam,
  { {0x657a31e1,0x212900a8,0x1017005d,0x00000000}},	// [5370] luth, rmah_, سبرد,
  { {0x692a31b6,0x21290089,0xddc50066,0x00000000}},	//   _křes, smah_, zahŕ,
  { {0xdb190051,0x657a008d,0xe1670044,0x00000000}},	//   zywó, nuth, _عددي,
  { {0x69c5021e,0xd5a6005d,0x6ce40054,0x00000000}},	//   ähem, _یف_, ніче,
  { {0x6f020003,0x657a0139,0x0b44013c,0x00000000}},	//   éocc, huth, енін,
  { {0x4fd60063,0x0ac70121,0x8408013d,0x00000000}},	//   _חושב_, ящем, lsőé,
  { {0xdd94000d,0x64460051,0x3f8911ad,0x00000000}},	//   _пары, ycki, ltau_,
  { {0x23690117,0x26dc0016,0xd83e00c2,0x00000000}},	//   _ovaj_, _alvo_, ščno_,
  { {0x3f890096,0xd7c9007e,0x7c3b00a4,0x00000000}},	//   ntau_, زوده_, _igur,
  { {0x68fb006d,0x44200130,0x752431e2,0x00000000}},	//   snud, _rzi_, _shiz,
  { {0x692a0080,0xf771007e,0x290d006f,0x00000000}},	//   _přet, راک_, poea_,
  { {0xd7d50001,0x661d0080,0x2f140ae2,0x00000000}},	//   _ожењ, řsko, lägt_,
  { {0x78a9001c,0x94d3000d,0x240a0054,0x00000000}},	//   mdev, тоўц, інги_,
  { {0xc724019d,0x60dd006f,0x78a931e3,0x00000000}},	//   _здій, _alsm, ldev,
  { {0x692a0080,0x60c400c2,0xe45f00a5,0x00000000}},	//   _třet, tjim, pköp_,
  { {0x387f31e4,0x78a906fa,0x7c3b31e5,0x00000000}},	//   ngur_, ndev, _ngur,
  { {0x44200035,0x60d60006,0x60c40089,0x00000000}},	// [5380] _uzi_, rkym, rjim,
  { {0x63a431e6,0x29000006,0x78a90072,0x00000000}},	//   _isin, čiai_, hdev,
  { {0xdb0902dd,0xc0e6000d,0x629c31e7,0x00000000}},	//   _creí, _жонк, mero,
  { {0xdb00000f,0x629c31e8,0xddd50022,0x00000000}},	//   _ismé, lero, _bezł,
  { {0xbb432f9b,0x3f89001f,0xcb671c9b,0x00000000}},	//   вечк, ctau_, даче_,
  { {0x63a40035,0x78a90290,0x387f00cd,0x00000000}},	//   _msin, edev, egur_,
  { {0xc9860002,0xcb070021,0xedd6005d,0x00000000}},	//   фули, بيون_, _غيرد,
  { {0x387f0bad,0xdb09003b,0x61e30058,0x00000000}},	//   ggur_, _creâ, _ünle,
  { {0x47340076,0x629c31e9,0x36d41213,0x00000000}},	//   ннис, kero, еопр,
  { {0x692a0080,0x66cd0024,0x629c31ea,0x00000000}},	//   _přes, _súkr, jero,
  { {0x9e770063,0x63a431eb,0x78a91186,0x00000000}},	//   וגיה_, _asin, bdev,
  { {0x657a0027,0x628e00e8,0x6aa8002b,0x00000000}},	//   ruth, efbo, _hadf,
  { {0x657a00a4,0x97c60021,0x63a400ea,0x00000000}},	//   suth, _تتضم, _csin,
  { {0xf793000d,0x629c31ec,0x692a004c,0x00000000}},	//   _рашэ, gero, _třes,
  { {0x8c3d04ab,0x63a40004,0x95c40021,0x00000000}},	//   _başl, _esin, _سيظه,
  { {0x6448004c,0xe7d20042,0x84e80044,0x00000000}},	//   ědic, _तथाप, _يفوق_,
  { {0x6d4e001c,0x6aba006f,0x629c2730,0x00000000}},	// [5390] _atba, _ontf, bero,
  { {0x78a9001c,0xdef808a6,0x3f8931ed,0x00000000}},	//   zdev, мых_, rtau_,
  { {0x2d870164,0x3f8931ee,0x63a4013d,0x00000000}},	//   îne_, stau_, _zsin,
  { {0x3f89003b,0x200f004b,0x6d41006c,0x00000000}},	//   ptau_, ügis_, _élam,
  { {0xdcfc003d,0x00760063,0x20e8095a,0x00000000}},	//   _aprē, _אתרי_, rşit_,
  { {0x2b4d31ef,0x6aa8002b,0x6ee00244,0x00000000}},	//   _vtec_, _cadf, _pöbe,
  { {0x6d5c001f,0x2f14004d,0x8c3d005b,0x00000000}},	//   _gwra, rägt_, _yaşl,
  { {0x6aba0199,0x764a00b9,0x7e650360,0x00000000}},	//   _entf, _affy, lahp,
  { {0x692a0080,0x629c31f0,0x6d5c0051,0x00000000}},	//   _přer, yero, _zwra,
  { {0x78a900cd,0xf6510044,0x3a74013f,0x00000000}},	//   sdev, دئة_, _алфр,
  { {0x673800c2,0x78a900cd,0x85b90021,0x00000000}},	//   _divj, pdev, سادس_,
  { {0x628531f1,0xfbc7005d,0x02a80042,0x00000000}},	//   _acho, هت_, _छोड़न,
  { {0x93430076,0xdcf5001c,0x629c31f2,0x00000000}},	//   лняе, _apzī, tero,
  { {0x629c006d,0xc7d6009a,0xe5690044,0x00000000}},	//   uero, _רוסי_, _فمتى_,
  { {0x7e650089,0x02190086,0x2b890013,0x00000000}},	//   dahp, діть_, húc_,
  { {0x63a431f3,0xe45f0ee9,0x69c301a8,0x00000000}},	//   _tsin, ljön_, ixne,
  { {0x2b890024,0x63a41b1c,0x776931f4,0x00000000}},	// [53a0] júc_, _usin, nsex,
  { {0xef1731f5,0x5ea60021,0xc357009d,0x00000000}},	//   ему_, عمال, _רביז_,
  { {0x21390034,0x8c3d0058,0x6aa831f6,0x00000000}},	//   _fish_, _taşl, _radf,
  { {0x71a3000d,0x7ae3004d,0x5d16005d,0x00000000}},	//   _саюз, ehnt, رباز,
  { {0x8236005d,0xbc670cac,0xa429009a,0x00000000}},	//   _ترکا, رمون_, ֵֽנִ,
  { {0x61050006,0x9f400066,0xe45f013d,0x00000000}},	//   mėla, nzií_, jjön_,
  { {0x6ee0000f,0x7c960651,0xdb250025,0x00000000}},	//   _több, _прац, úpái,
  { {0x3eaa004d,0xada30086,0x69dc0058,0x00000000}},	//   _habt_, _щасл, _ürem,
  { {0x7792007e,0xa09b0149,0xfce304dc,0x00000000}},	//   ایتا, ליקט, _сото,
  { {0xc66a0121,0x39ae005f,0x15d8005e,0x00000000}},	//   чшие_, _tęs_, дмоћ_,
  { {0x8e3001ce,0xb95a009b,0x4a57009a,0x00000000}},	//   _сaдa_, _رجاء_, _נשאל_,
  { {0x3eaf001c,0xf7460002,0x628531f7,0x00000000}},	//   ēgti_, _зедо, _scho,
  { {0x9cd7009a,0x00000000,0x00000000,0x00000000}},	//   תוכה_,   ,   ,
  { {0x290000eb,0x2471008b,0xf7bb009a,0x00000000}},	//   čiau_, ễm_, _מזדמ,
  { {0xd6270001,0x59a60053,0x628501d1,0x00000000}},	//   _поље_, _कैमर, _vcho,
  { {0x62850051,0x69c50072,0xf487066f,0x00000000}},	//   _wcho, ähei, _чукн,
  { {0xd251006a,0x2d98051e,0x644d002b,0x00000000}},	// [53b0] _پنج_, _apre_, _ifai,
  { {0x21390034,0x4ed40086,0x93fc0063,0x00000000}},	//   _wish_, люєт, _מלחי,
  { {0x5336009a,0x8e840044,0x3135009a,0x00000000}},	//   _שנתן_, المه, _ֹנָם_,
  { {0xbc19000d,0x2b4900f8,0x8c3d0075,0x00000000}},	//   мілі_, íaco_, _taşm,
  { {0x2ca90066,0xdb0931f8,0x5c1406c3,0x00000000}},	//   ľad_, _preà, льшу,
  { {0xbb520032,0x49950601,0x2b892107,0x00000000}},	//   جنوب, вшит, rúc_,
  { {0x692a02f4,0xe9a80044,0x48e531f9,0x00000000}},	//   _přep, فدين_, кокв,
  { {0x0c72007e,0x776931fa,0xf1b40aeb,0x00000000}},	//   _نگهد, tsex, רסק_,
  { {0x2d040088,0x32d40072,0x0b94009b,0x00000000}},	//   _сярг, _käyt_, _مجلد,
  { {0x81c3001c,0xf1b30053,0xcf920063,0x00000000}},	//   ģēji, ुमान, סטי_,
  { {0x77691560,0xdb090139,0xb8950021,0x00000000}},	//   ssex, _greá, _للاع,
  { {0x43460189,0xe45f0137,0x27220026,0x00000000}},	//   кемв, sjön_, rðna_,
  { {0xe72e0079,0xe6c50021,0xa8780044,0x00000000}},	//   _ве_, _لتغي, _أحمر_,
  { {0x8c3d01f7,0xf1aa007e,0x644d002b,0x00000000}},	//   _başk, وازه_, _efai,
  { {0x9f400024,0x45d20459,0x644d001f,0x00000000}},	//   rzií_, _војс, _ffai,
  { {0x91030002,0xdd1c0078,0x6105005f,0x00000000}},	//   апсе, ršūn, tėla,
  { {0x2d9831fb,0x7ae10139,0x7fd50500,0x00000000}},	// [53c0] _spre_, _ollt, ліфі,
  { {0xdfcf0032,0x2fcf00c7,0x321a1ad3,0x00000000}},	//   غيل_, ägga_, _typy_,
  { {0xdca62c9e,0xe45f0014,0x254c004c,0x00000000}},	//   кажи, kjöl_, _těle_,
  { {0x7ae131fc,0x63b631fd,0x00000000,0x00000000}},	//   _allt, _kryn,   ,
  { {0x3eaa00b9,0x3eab00fe,0x28c50042,0x00000000}},	//   _tabt_, öitä_, वानि,
  { {0x5b1302fe,0xdb090331,0x63b6002b,0x00000000}},	//   аміт, _preá, _mryn,
  { {0xa9c3005a,0x3f80017d,0x78ab00b9,0x00000000}},	//   исък, luiu_, _bagv,
  { {0xb05b004d,0x7ae100a3,0xe8ea043e,0x00000000}},	//   _gnäd, _ellt, برتو_,
  { {0xbb460612,0x3f80017d,0x78ab0104,0x00000000}},	//   _резк, nuiu_, _dagv,
  { {0xb9960032,0x7d02064f,0x9a6a14d7,0x00000000}},	//   _للطب, lnos, _آمال_,
  { {0x7d020ec3,0xeab10132,0xa4d50636,0x00000000}},	//   onos, _לֹא_, гоні,
  { {0x29000006,0x63b60ea7,0x7d0231fe,0x00000000}},	//   čias_, _bryn, nnos,
  { {0x69d501f7,0x63b6001f,0x7d021798,0x00000000}},	//   _üzer, _cryn, inos,
  { {0x3f8000cd,0x7d0231ff,0x853c005f,0x00000000}},	//   duiu_, hnos, uvės,
  { {0x68e214a3,0x69d8013d,0xd7c6005d,0x00000000}},	//   _klod, nyve, _سوژه_,
  { {0x86370063,0x63b60f9b,0x7d02106b,0x00000000}},	//   _ברוב_, _fryn, jnos,
  { {0x31340001,0x3f800bc8,0x7d021058,0x00000000}},	// [53d0] ретр, guiu_, dnos,
  { {0x64490006,0x657a3200,0x3ce604aa,0x00000000}},	//   žeid, orth, ehov_,
  { {0x60cf000c,0x63ba008f,0xed580054,0x00000000}},	//   _tocm, ātne, воє_,
  { {0x3f80017d,0x657a19d9,0x7d023201,0x00000000}},	//   buiu_, irth, gnos,
  { {0xbc38006a,0x64410051,0x3af5000d,0x00000000}},	//   نسها_, śliw, лякс,
  { {0xa9270024,0x8c3d000c,0x7af82f6d,0x00000000}},	//   _obľú, _maşi, givt,
  { {0x7d02160f,0x69d83202,0x661c0058,0x00000000}},	//   bnos, gyve, ürkl,
  { {0x3ea10004,0x3eaf001c,0x68e23203,0x00000000}},	//   leht_, ēgtu_, _clod,
  { {0x657a0333,0xdcfc0078,0x68e2002b,0x00000000}},	//   erth, _aprė, _dlod,
  { {0xd7060121,0x98c4008f,0xc6a40131,0x00000000}},	//   лные_, ātām_, арџи,
  { {0xb955005a,0x2cbf000e,0x99890051,0x00000000}},	//   _свещ, _knud_, łał_,
  { {0x63b6001f,0xb6030078,0x78a0006c,0x00000000}},	//   _pryn, ššok, cemv,
  { {0x2d8100bd,0x657a3204,0xe45f0058,0x00000000}},	//   huhe_, arth, nköy_,
  { {0xa6b4005a,0xdb0900cd,0xe7390141,0x00000000}},	//   _всъщ, _dreç, _џек_,
  { {0x91e30448,0xdc200053,0x7d020022,0x00000000}},	//   боре, _बर्ड_, ynos,
  { {0xc486041d,0xe45f3205,0x69da0047,0x00000000}},	//   _слик, zköz_, ײַלו,
  { {0xd36f0021,0x7d020648,0x291f0072,0x00000000}},	// [53e0] _فهي_, vnos, ilua_,
  { {0x3f80017d,0x3ea1004d,0x78a0006f,0x00000000}},	//   ruiu_, geht_, zemv,
  { {0xd83e0006,0xa49b01a8,0x3945109c,0x00000000}},	//   ščio_, inòn, _nuls_,
  { {0x0b8a17db,0x7d023206,0x8d1a005d,0x00000000}},	//   ески_, unos, رزار_,
  { {0x7af802f4,0x254c0080,0x62810297,0x00000000}},	//   tivt, _měla_, ólog,
  { {0x4ed50062,0x7d020c19,0x657a002b,0x00000000}},	//   _кюст, snos, yrth,
  { {0xbea30001,0x3ce600c7,0x7d0215df,0x00000000}},	//   _ћаск, phov_, pnos,
  { {0x58d42ab5,0xd90d007e,0xafdb05a5,0x00000000}},	//   роит, ویل_, _ifør,
  { {0x657a001f,0x21200089,0xd6d00044,0x00000000}},	//   wrth, ilih_, ققة_,
  { {0x2a65004d,0x291f0072,0xb05b00a5,0x00000000}},	//   _gelb_, alua_, _knäc,
  { {0x69c501a5,0xf76f007e,0x68e2001f,0x00000000}},	//   ähet, يای_, _tlod,
  { {0xdb090016,0x291f0016,0x657a0025,0x00000000}},	//   _preç, clua_, rrth,
  { {0x8c3d000c,0xf3ff017d,0x212000a8,0x00000000}},	//   _paşi, raão_, dlih_,
  { {0x212000c2,0xf41f00a5,0x315b0044,0x00000000}},	//   elih_, ffär_, فجرة_,
  { {0x31c40432,0xe45f0075,0x00000000,0x00000000}},	//   бств, zköy_,   ,
  { {0x2120007d,0x10e7005d,0x90553207,0x00000000}},	//   glih_, اژدی_, рвац,
  { {0x3ea100bd,0x38660089,0x4255007e,0x00000000}},	// [53f0] teht_, _meor_, _پنجر,
  { {0x4429017f,0x38660025,0xc7d70063,0x00000000}},	//   _iza_, _leor_, אומי_,
  { {0x70950088,0x752d0222,0x2cbf039f,0x00000000}},	//   _канф, _khaz, _pnud_,
  { {0x4c951259,0x7bd90051,0xafdb01e1,0x00000000}},	//   ридс, tywu, _dfør,
  { {0xfb35000d,0x644f3208,0x8c480054,0x00000000}},	//   андэ, icci, упів_,
  { {0x3eaf001c,0x60cd22cb,0x2cad002b,0x00000000}},	//   ēgts_, ljam, _waed_,
  { {0x60cd00eb,0xdb00006d,0x6ee00504,0x00000000}},	//   ojam, _armó, _möbl,
  { {0x39590080,0x3b55005a,0x60cd3209,0x00000000}},	//   _čssd_, _вкар, njam,
  { {0x6d47320a,0x60cd0072,0x38ca005d,0x00000000}},	//   _huja, ijam, ضايی_,
  { {0x5967011c,0xa3b9016a,0x8c3d01f7,0x00000000}},	//   _бъда, घटन_, _başv,
  { {0x28c50053,0xf62508ef,0xe4c60251,0x00000000}},	//   वादि, рдно, айни,
  { {0x3869007a,0x628700ea,0xc3560062,0x00000000}},	//   _þar_, egjo, иъгъ,
  { {0x7d090117,0x7d1b0009,0x68e9320b,0x00000000}},	//   _mjes, _mkus, mhed,
  { {0x60cd003d,0x644f0a07,0x7e670080,0x00000000}},	//   ejam, acci, _nejp,
  { {0x70f60086,0xe0460076,0x44290035,0x00000000}},	//   ачає, инви, _eza_,
  { {0x6aa300bd,0xe3ba0086,0x68e9320c,0x00000000}},	//   henf, _аби_, nhed,

  { {0x27ed0995,0x6d55320d,0xf41f0137,0x00000000}},	// [5400] nzen_, _atza, sfär_,
  { {0x63a901f7,0x442001f7,0x27ed0194,0x00000000}},	//   çene, _iyi_, izen_,
  { {0x68e900e8,0x6aa302ab,0x6d471560,0x00000000}},	//   khed, denf, _cuja,
  { {0x60cd0051,0x68e9006f,0x4420320e,0x00000000}},	//   cjam, jhed, _kyi_,
  { {0x27ed0122,0x7c290045,0x68e9006f,0x00000000}},	//   jzen_, _czer, dhed,
  { {0x44200072,0x6aa3320f,0x957c0022,0x00000000}},	//   _myi_, genf, cząw,
  { {0x27ed0122,0x386602dd,0x3a3a00c7,0x00000000}},	//   ezen_, _peor_, äpp_,
  { {0x7d090031,0x68e93210,0xa3e60161,0x00000000}},	//   _gjes, ghed, पना_,
  { {0x6aa33211,0x44200150,0x69c5004d,0x00000000}},	//   benf, _nyi_, äher,
  { {0x7d1b02f4,0x752d3212,0x6d403213,0x00000000}},	//   _zkus, _shaz, _hima,
  { {0x6d400009,0x44200150,0x27ed3214,0x00000000}},	//   _kima, _ayi_, azen_,
  { {0x6d400089,0x68e93215,0x645d04b5,0x00000000}},	//   _jima, ched, ubsi,
  { {0xdcfc001c,0x62870a3f,0x692a004c,0x00000000}},	//   _aprī, tgjo, _ořez,
  { {0x6d403216,0x35f7007e,0xc207005e,0x00000000}},	//   _lima, ارید_, аџби,
  { {0x60cd0268,0xc1050021,0x104b0121,0x00000000}},	//   tjam, موسي, вязи_,
  { {0xe63b0063,0x6d401253,0x9553007e,0x00000000}},	//   _בתוכ, _nima, _بخوا,
  { {0x4395000a,0x692a0080,0xe104000d,0x00000000}},	// [5410] _уапс, _břez, цярп,
  { {0x63ad0273,0x6d473217,0x5187006e,0x00000000}},	//   _isan, _puja, _кума,
  { {0x7c293218,0x27ed000f,0x254c0080,0x00000000}},	//   _szer, zzen_, _mělo_,
  { {0xbd18019d,0x6d47007d,0x6d403219,0x00000000}},	//   ації_, _vuja, _cima,
  { {0x7c200c70,0x6d40014f,0x8c3d000c,0x00000000}},	//   _cymr, _dima, _naşt,
  { {0xa3b80053,0x6d400014,0x7983002b,0x00000000}},	//   छित_, _eima, tunw,
  { {0x98a60066,0xa3a90053,0x7d09007d,0x00000000}},	//   _choď_, _गैस_, _tjes,
  { {0x27ed321a,0x6d400150,0x63540080,0x00000000}},	//   tzen_, _gima, něný,
  { {0x7c200185,0x68e9321b,0x68fb2b6a,0x00000000}},	//   _gymr, rhed, riud,
  { {0x39b5003d,0x06c908a6,0x27ed321c,0x00000000}},	//   _tās_, угой_, rzen_,
  { {0x44260418,0xe5a5005a,0x27ed00ea,0x00000000}},	//   _šo_, щини, szen_,
  { {0x7d192761,0x33d60054,0x03a60591,0x00000000}},	//   nows, бігт, бимо,
  { {0x386d0831,0x69cc003b,0xdcfc008f,0x00000000}},	//   maer_, ăneş, _sprī,
  { {0x8c1a0063,0x7d190022,0x61ee0244,0x00000000}},	//   רושי, hows, tzbl,
  { {0x41b5011c,0x63ad00eb,0x9c8200c3,0x00000000}},	//   остт, _esan, ščic,
  { {0x7d190051,0x8c3d0058,0x386d321d,0x00000000}},	//   jows, _yaşt, naer_,
  { {0x6d40321e,0x692a0080,0x4426008b,0x00000000}},	// [5420] _rima, _přez, _áo_,
  { {0x52aa0001,0x6d40273d,0xdcfe004c,0x00000000}},	//   _свом_, _sima, rupč,
  { {0x610c01f7,0x6f1c00a8,0x10a6030b,0x00000000}},	//   ağla, _vkrc, _линн,
  { {0x98be003b,0x661c09ad,0x61e10093,0x00000000}},	//   _mută_, ürki, ølle,
  { {0x3b96005e,0xc053009d,0x00000000,0x00000000}},	//   сјет, _מזר_,   ,
  { {0x9e76007e,0xa39b0047,0x6f1c0130,0x00000000}},	//   _دهست, רױסז, _ukrc,
  { {0x6d40321f,0xa9670fe2,0x8c3d0058,0x00000000}},	//   _tima, бија_, _başs,
  { {0x1754042c,0x8c3d000c,0x27300013,0x00000000}},	//   овия, _paşt, oàng_,
  { {0x7b070027,0x27e20014,0x6ab10137,0x00000000}},	//   órtá, ákn_, ökfä,
  { {0xb6c60055,0x67530021,0x6d410003,0x00000000}},	//   ссий, أخير, _élar,
  { {0x79530044,0xe53502fa,0x7e9b009a,0x00000000}},	//   _فَلا, жень, נסטו,
  { {0x63ad0080,0x27220026,0x6fc80053,0x00000000}},	//   _psan, iðni_, रमां,
  { {0x254c004c,0x28c50053,0x6354004c,0x00000000}},	//   _tělo_, वारि, věný,
  { {0x656e0025,0x78250021,0x3f800ea2,0x00000000}},	//   ábhs, _بعمل, driu_,
  { {0x610500eb,0x31c40fe2,0xf549008b,0x00000000}},	//   lėli, пств, _hấn_,
  { {0x63ad3220,0xd1300044,0x00000000,0x00000000}},	//   _tsan, ّمِ_,   ,
  { {0xa49b0268,0x63ad3221,0x61050006,0x00000000}},	// [5430] riòd, _usan, nėli,
  { {0x200700dd,0x7f740054,0x7c2601c8,0x00000000}},	//   ăni_, ягує, _úkry,
  { {0x957c0045,0xf5490013,0x7d193222,0x00000000}},	//   cząt, _lấn_, tows,
  { {0x61050006,0x3f801997,0x5bb91406,0x00000000}},	//   kėli, briu_, илея_,
  { {0x3f800268,0xdfdb0062,0x7d1931ec,0x00000000}},	//   criu_, _сън_, rows,
  { {0x386d001f,0x61050078,0x7d190022,0x00000000}},	//   waer_, dėli, sows,
  { {0x386d000e,0x2d8500be,0x7d190022,0x00000000}},	//   taer_, _êle_, pows,
  { {0x98be003b,0x61fa0026,0xa3a90053,0x00000000}},	//   _rută_, útli, _गईं_,
  { {0x98be000c,0xdb23007e,0x386d3223,0x00000000}},	//   _sută_, _فوری, raer_,
  { {0xf5490013,0x0a6802f8,0xb6a52184,0x00000000}},	//   _dấn_, _грци_, циол,
  { {0x7ac40121,0x4af6005d,0xca480044,0x00000000}},	//   _эсте, _بکند_, _المه_,
  { {0x3993017d,0x2d8100fe,0xf2c90063,0x00000000}},	//   mãs_, irhe_, _בע_,
  { {0xd5b8001c,0x232a0094,0xd8a8005d,0x00000000}},	//   avā_, иоми_, _دهنو_,
  { {0x7b1f017d,0x55e50818,0x614616b4,0x00000000}},	//   cêut, _молб, жева,
  { {0xc5d50304,0x324300d6,0x216a01ce,0x00000000}},	//   _філь, дерг, риби_,
  { {0x3f803224,0xb3860121,0x957c0022,0x00000000}},	//   triu_, _длил, rząt,
  { {0x2545008f,0x3f800078,0xb4e60082,0x00000000}},	// [5440] _vēlu_, uriu_, फसी_,
  { {0x3f80017d,0x9e5a01d5,0x957c056c,0x00000000}},	//   rriu_, рраф_, cząs,
  { {0x412a0086,0x6da60021,0x98a50078,0x00000000}},	//   _воно_, تمام, _nulį_,
  { {0x3f80000c,0x0c263225,0xc7b900ea,0x00000000}},	//   priu_, омен, kvő_,
  { {0x8aca01ce,0xc8bd0082,0x00000000,0x00000000}},	//   ићка_, _ऍफ़ट,   ,
  { {0xe81d0053,0x61050078,0x1af40085,0x00000000}},	//   _पड़ा_, vėli, япля,
  { {0x3993017d,0x9203008f,0xc7b9013d,0x00000000}},	//   gãs_, šāvi, evő_,
  { {0x6d5e024a,0x39423226,0x61050078,0x00000000}},	//   mppa, öks_, tėli,
  { {0xc6f8019d,0x6d5e015c,0xc6a604f2,0x00000000}},	//   йних_, lppa, орни,
  { {0xf549001b,0x35f40cdf,0x6b820139,0x00000000}},	//   _vấn_, зпор, mrog,
  { {0xbb3b0047,0x47d4007e,0xa3b00042,0x00000000}},	//   _כעמי, زيگر, _टैब_,
  { {0xf549001b,0x9c830061,0xf74600d9,0x00000000}},	//   _tấn_, _účtu, _дедо,
  { {0x7b1f017d,0xb4270044,0xc6d3005d,0x00000000}},	//   pêut, تعدو, ستیت,
  { {0xdb0000bd,0x75d60044,0x00000000,0x00000000}},	//   _ermö, _ويشا,   ,
  { {0x306b0095,0x957c0022,0x2545008f,0x00000000}},	//   ијан_, rząs, _dēls_,
  { {0x6b823227,0x2d810130,0xb97b016e,0x00000000}},	//   krog, vrhe_, ינלי,
  { {0xd8d70047,0x6e3a0014,0xff500044,0x00000000}},	// [5450] קומט_, _útbj, نخل_,
  { {0x6b823228,0x62351810,0x00000000,0x00000000}},	//   drog, _непу,   ,
  { {0x4338005d,0xde190044,0x8d7700de,0x00000000}},	//   _بسيج_, حقات_, تاذا,
  { {0x272b00d1,0x6ce40054,0x3cd50456,0x00000000}},	//   jønn_, міче, яжес,
  { {0xef93007e,0x69de00d1,0x6d5e3229,0x00000000}},	//   _زیاد, øpen, appa,
  { {0x0ac70076,0x399300be,0xed5b0021,0x00000000}},	//   ющем, tãs_, _نشرت_,
  { {0x26c90013,0x3ebe0014,0xc27c069a,0x00000000}},	//   _đao_, _ótta_, ברוי,
  { {0xab95000a,0x6b82322a,0x88c90f59,0x00000000}},	//   _набљ, brog, слив_,
  { {0x96b9005e,0x8bb70021,0x6b82322b,0x00000000}},	//   буну_, _بإزا, crog,
  { {0xb05b00c7,0x29180046,0x2ed6009a,0x00000000}},	//   _snäl, _íran_, ִֽים_,
  { {0xd7c9007e,0x394c02ad,0x7d0b322c,0x00000000}},	//   _گوشه_, _guds_, ongs,
  { {0xa50a000a,0x499a0063,0x399a009a,0x00000000}},	//   сема_, _לשעב, _ליעד,
  { {0xddd5000f,0x7d0b2d70,0x96650217,0x00000000}},	//   _mező, ings, _екле,
  { {0x78a92076,0x8c1a0063,0x23690022,0x00000000}},	//   leev, מורי, _dwaj_,
  { {0x26c71663,0x52b9000d,0xdb1b017d,0x00000000}},	//   _inno_, цыяў_, _crué,
  { {0xaac70053,0x61050078,0x404a01ce,0x00000000}},	//   लाँक, kėlu, спао_,
  { {0x8fa318ea,0x00000000,0x00000000,0x00000000}},	// [5460] нате,   ,   ,
  { {0x63a403d5,0x7d0b322d,0x8cc10053,0x00000000}},	//   _ipin, engs, _रोबो,
  { {0x6b82001f,0x32db0063,0x6d5e0050,0x00000000}},	//   wrog, _החינ, uppa,
  { {0x315700b5,0xdc980086,0x628e0850,0x00000000}},	//   _מיטן_, івлі_, lgbo,
  { {0x628e006f,0xaac70053,0x78a900b9,0x00000000}},	//   ogbo, लांक, deev,
  { {0xe45f0137,0x629c09b7,0x7d0b322e,0x00000000}},	//   njör_, nfro, angs,
  { {0xf549001b,0xa96700e1,0x6da30571,0x00000000}},	//   _bấm_, пија_, _пира,
  { {0x26c702f6,0xacea0032,0xf549008b,0x00000000}},	//   _anno_, _ارسل_, _cấm_,
  { {0x272b00d1,0x6d4e322f,0x3ce61e9f,0x00000000}},	//   rønn_, _huba, mkov_,
  { {0x6d4e0009,0x3ce60599,0x272b04aa,0x00000000}},	//   _kuba, lkov_, sønn_,
  { {0x18a60055,0xba1a0021,0x6d4e312c,0x00000000}},	//   _нажм, _ايضا_, _juba,
  { {0x26c73230,0x3ce614d5,0x6d4e1aae,0x00000000}},	//   _enno_, nkov_, _muba,
  { {0x254c0080,0xa8470067,0x2d7800c3,0x00000000}},	//   _měli_, _علوم_, hče_,
  { {0x6d5c3231,0x56930540,0xa77b0063,0x00000000}},	//   _otra, _зашт, _פרופ,
  { {0x569b014e,0x39460052,0xa69b0063,0x00000000}},	//   _היוצ, _kios_, _השופ,
  { {0xd0d40062,0x6aaa13de,0x7bc0242f,0x00000000}},	//   носъ, heff, _ormu,
  { {0x3ce60dda,0x849808aa,0x64400078,0x00000000}},	// [5470] dkov_, _رئيس_, žmir,
  { {0x6d4e3232,0x6105005f,0x798300a3,0x00000000}},	//   _buba, vėlu, yrnw,
  { {0x2b4d00cd,0x6d4e3233,0x7d020efd,0x00000000}},	//   _suec_, _cuba, fios,
  { {0x39460025,0x7d022c21,0x6d5c0139,0x00000000}},	//   _nios_, gios, _dtra,
  { {0x212908f0,0x6d5c3234,0x6d4e0f20,0x00000000}},	//   mlah_, _etra, _euba,
  { {0x21293235,0x99d4007e,0xf5490013,0x00000000}},	//   llah_, کتها, _sấm_,
  { {0x6d4e3236,0x7bc00a87,0x3ce6122a,0x00000000}},	//   _guba, _ermu, bkov_,
  { {0x21290974,0x7d022b2e,0xac190690,0x00000000}},	//   nlah_, cios, _добу_,
  { {0x394602dd,0x6d5c0080,0x628e0137,0x00000000}},	//   _dios_, _ztra, ygbo,
  { {0x2129053b,0x999f013d,0xe5e10085,0x00000000}},	//   hlah_, űrők_, вымi_,
  { {0x21290974,0x6b8b0026,0x39460d2f,0x00000000}},	//   klah_, lugg, _fios_,
  { {0x59a60042,0x00000000,0x00000000,0x00000000}},	//   _कैटर,   ,   ,
  { {0x4c9a0063,0x629c3237,0xcc76009a,0x00000000}},	//   חברו, tfro, וגרת_,
  { {0x7d021d60,0x2129053b,0x6d5a0164,0x00000000}},	//   zios, elah_, _étag,
  { {0x3ced0019,0xa022005b,0x3ce60066,0x00000000}},	//   _olev_, _çözm, ykov_,
  { {0x6d4e3238,0x74f70021,0xa01b00a5,0x00000000}},	//   _ruba, _يفوز_, _odöd,
  { {0x2336019d,0x6d5c3239,0x63a40035,0x00000000}},	// [5480] _охор, _stra, _upin,
  { {0x2129053b,0x61f5004d,0x291f006c,0x00000000}},	//   alah_, ßflä, houa_,
  { {0x3ced323a,0x3ce622f1,0x7d020659,0x00000000}},	//   _blev_, tkov_, tios,
  { {0x25d600b5,0x7e6e323b,0x447b0047,0x00000000}},	//   ווען_, _webp, ַנצע,
  { {0xdb1b00cd,0x7d02057a,0xe6f20013,0x00000000}},	//   _cruï, rios, hườ,
  { {0x3ce6323c,0x290d05b3,0x3ced323d,0x00000000}},	//   skov_, enea_, _elev_,
  { {0x3ce616a9,0x6aaa0da0,0xa923004c,0x00000000}},	//   pkov_, reff, ěžno,
  { {0x57b4323e,0x7afd0006,0x6aaa323f,0x00000000}},	//   ебит, _įste, seff,
  { {0x69c13240,0x3eb83241,0x387d002b,0x00000000}},	//   _erle, _kart_, _ddwr_,
  { {0x98a3003d,0xddce20ae,0x6a833242,0x00000000}},	//   ējā_, _nebū, _алфа,
  { {0xceb30063,0xe6f2008b,0x3eb83243,0x00000000}},	//   דית_, gườ, _mart_,
  { {0xa4d50086,0x3eb804aa,0x291f0003,0x00000000}},	//   хомі, _lart_, coua_,
  { {0x44320045,0x29043244,0xd6da1849,0x00000000}},	//   _czy_, mima_, _мтк_,
  { {0x29043245,0x00000000,0x00000000,0x00000000}},	//   lima_,   ,   ,
  { {0x2129053b,0x98a60051,0x4af90041,0x00000000}},	//   tlah_, _choć_, פּשײ,
  { {0xdfd50088,0xe4a7000a,0x43950001,0x00000000}},	//   нобы, _црко, _заис,
  { {0x21290397,0x78a20035,0x3eb83246,0x00000000}},	// [5490] rlah_, _mbov, _bart_,
  { {0x2129053b,0x44293247,0x3eb83248,0x00000000}},	//   slah_, _iya_, _cart_,
  { {0x61e100c7,0xfbd0007e,0x33180021,0x00000000}},	//   älld, یته_, _تزيد_,
  { {0x29040117,0xd251006a,0x2fcf0137,0x00000000}},	//   jima_, _جنگ_, äggs_,
  { {0x3eb81e79,0xcb690076,0xf0440076,0x00000000}},	//   _fart_, чале_, _аэро,
  { {0x78a20037,0x26dc3249,0xb0620019,0x00000000}},	//   _abov, _novo_, _äärm,
  { {0x60dd324a,0x6b8b006f,0x6e940002,0x00000000}},	//   _kosm, sugg, _ширу,
  { {0x290d0529,0x2904324b,0x644d0139,0x00000000}},	//   unea_, gima_, _ngai,
  { {0x4429324c,0x290d324d,0xd7c9005d,0x00000000}},	//   _nya_, rnea_, سوده_,
  { {0x644d057a,0x7524004d,0x0ab80021,0x00000000}},	//   _agai, _skiz, _يطلب_,
  { {0xead4005a,0xf5062ac4,0x672300c2,0x00000000}},	//   _шофь, езно, _vknj,
  { {0x2904324e,0xe6f20013,0xd756007e,0x00000000}},	//   cima_, rườ, بلیت_,
  { {0x7d0a0014,0xd7c80044,0x00000000,0x00000000}},	//   éfsi, _يومه_,   ,
  { {0x2b5f0089,0x78bb324f,0x68e93250,0x00000000}},	//   _mtuc_, lduv, lked,
  { {0x56920fe2,0x28d30161,0xa49b00cd,0x00000000}},	//   _сајт, थापि, gnòs,
  { {0x69dc0268,0x78bb0019,0x75240035,0x00000000}},	//   _àree, nduv, _ukiz,
  { {0x3eb83251,0x7c293252,0x13b60021,0x00000000}},	// [54a0] _part_, _nyer, _أصبح,
  { {0x29043253,0x67213254,0x441b009a,0x00000000}},	//   zima_, nolj, _מופס,
  { {0x3eb83255,0x68e90d02,0x6e930593,0x00000000}},	//   _vart_, kked, الما,
  { {0x29041bb7,0x61e13256,0x7c293257,0x00000000}},	//   xima_, älle, _byer,
  { {0x29040117,0x0a940500,0xdbd1004d,0x00000000}},	//   vima_, валю, rüße,
  { {0x6f79009d,0x00000000,0x00000000,0x00000000}},	//   _קְרו,   ,   ,
  { {0x67210dd4,0x8c430058,0xee2a0021,0x00000000}},	//   dolj, ışan, _رأسه_,
  { {0x63b60137,0x68e9009c,0x00000000,0x00000000}},	//   _osyn, gked,   ,
  { {0x6d5a0164,0x26dc0016,0x6133005b,0x00000000}},	//   _étab, _povo_, nçla,
  { {0x29043258,0x4c35000d,0x67213259,0x00000000}},	//   sima_, _рэст, golj,
  { {0x2904325a,0x44292133,0x7ae5004d,0x00000000}},	//   pima_, _sya_, öhte,
  { {0x44290035,0xa49b01a8,0x68e923db,0x00000000}},	//   _pya_, ciòl, cked,
  { {0x24800185,0x60dd325b,0x672106bb,0x00000000}},	//   _ddim_, _rosm, bolj,
  { {0x442910ca,0xd5b0006a,0x26dc0290,0x00000000}},	//   _vya_, _نفت_, _uovo_,
  { {0x28c50161,0xd6570063,0x60dd325c,0x00000000}},	//   वाचि, _איות_, _posm,
  { {0x88bd0045,0x644d001f,0x657a2545,0x00000000}},	//   mośc, _ugai, msth,
  { {0x60dd017d,0x442900ac,0xdb07005b,0x00000000}},	// [54b0] _vosm, _uya_, _ölçe,
  { {0x68e900ea,0x2229005d,0xfe700043,0x00000000}},	//   zked, _يزدی_, مدم_,
  { {0x88bd0045,0x6d49001c,0x657a01a2,0x00000000}},	//   nośc, _piea, nsth,
  { {0x307900b5,0x672100ea,0x317a07e9,0x00000000}},	//   _קאָנ, zolj, _קארד,
  { {0x6ef201e1,0x68e90058,0xeb9904f2,0x00000000}},	//   _sæbe, vked, фил_,
  { {0x88bd0045,0x8afd004c,0x6aba00e5,0x00000000}},	//   kośc, _otře, _catf,
  { {0x672106bb,0x6ca727b8,0xab5d0022,0x00000000}},	//   volj, _праж, _drża,
  { {0x657a00b9,0x88bd0051,0x2d570058,0x00000000}},	//   dsth, dośc, _içe_,
  { {0x75eb000f,0x657a0034,0x68e9325d,0x00000000}},	//   közö, esth, rked,
  { {0x2caf0122,0x68e9325e,0x0ab401fb,0x00000000}},	//   legd_, sked, _محمد,
  { {0x9585005a,0x88bd078b,0xd9e50053,0x00000000}},	//   ълне, gośc, _कथित_,
  { {0xe945007e,0x9f400290,0xda040062,0x00000000}},	//   _شرای, nziò_, _счуп,
  { {0x6721074f,0x9cd60063,0x6c7a0041,0x00000000}},	//   polj, דורה_, וארפ,
  { {0x3f89002b,0x88bd0022,0xe5a51313,0x00000000}},	//   drau_, bośc, _аики,
  { {0xdb09004b,0xa822005d,0x321a005d,0x00000000}},	//   _iseä, _مکین, ذيرد_,
  { {0x3f89071c,0x2fc001e1,0xc616009a,0x00000000}},	//   frau_, tvig_, _בחצי_,
  { {0x4127026b,0xd0070afc,0x63b606a5,0x00000000}},	// [54c0] тото_, вете_, _usyn,
  { {0x6133005b,0xdddc003b,0x9e631c9b,0x00000000}},	//   rçla, _cerş, ивуд,
  { {0x9d46011c,0xdd8f0032,0x2fc0325f,0x00000000}},	//   вежд, قول_, svig_,
  { {0x7afd00eb,0xb63600b5,0x3f89001f,0x00000000}},	//   _įsta, דרעס_, brau_,
  { {0x8b960076,0xb4db00cd,0xe4570047,0x00000000}},	//   треч, lmàc, דינט_,
  { {0x9f40000f,0x63a9005b,0x8c43005e,0x00000000}},	//   rzió_, çeni, јеље,
  { {0xbb470044,0xcd02056c,0xbb290043,0x00000000}},	//   خلون_, _paść_, رسهٔ_,
  { {0xb9e30086,0x98c3000d,0xfce33260,0x00000000}},	//   ріши, асьл, _косо,
  { {0x8afd0080,0x88bd0045,0xf7720067,0x00000000}},	//   _stře, wośc, جاع_,
  { {0x95d8000a,0x88bd0051,0x657a030c,0x00000000}},	//   едот_, tośc, tsth,
  { {0x75eb00ea,0x7bc21031,0x00000000,0x00000000}},	//   vözö, lvou,   ,
  { {0x3f89002b,0x88bd0022,0x88930054,0x00000000}},	//   yrau_, rośc, _виїх,
  { {0x7bc203a8,0x244b0021,0x657a3261,0x00000000}},	//   nvou, بجدي_, ssth,
  { {0x2caf0122,0x65942338,0xf777009a,0x00000000}},	//   zegd_, _баку, _יעדי_,
  { {0x26ce3262,0x8cd50042,0x41270054,0x00000000}},	//   _info_, णामो, вфаб,
  { {0xa0880699,0x25d70063,0x3f893263,0x00000000}},	//   ксуз_, _יוון_, trau_,
  { {0xf54a008b,0xdddc18ad,0xd3a40085,0x00000000}},	// [54d0] _cấu_, _perş, _крэп,
  { {0xf54a001b,0x3f891d26,0xe2aa004c,0x00000000}},	//   _dấu_, rrau_, áčtí_,
  { {0x71d50063,0x645d002b,0xdd9b0505,0x00000000}},	//   _עוֹד_, ocsi, ьша_,
  { {0x50640086,0x27390164,0x645d3264,0x00000000}},	//   _втра, mène_, ncsi,
  { {0x27390003,0x62810051,0xceeb007e,0x00000000}},	//   lène_, ólow, _قرآن_,
  { {0x8f9a014e,0xf54a0013,0x3e7c004c,0x00000000}},	//   _אישי, _hất_, rátí_,
  { {0xf2d400b5,0x7bc20411,0xc8bf0121,0x00000000}},	//   יעס_, avou, о́вы,
  { {0xc7b100de,0x00000000,0x00000000,0x00000000}},	//   مّع_,   ,   ,
  { {0xf54a3265,0x9675000d,0xdbd6004d,0x00000000}},	//   _mất_, лыні, mäße,
  { {0x6d550035,0x752f0022,0xc987224c,0x00000000}},	//   _kuza, elcz, _ауди,
  { {0x4649000d,0x66053266,0x75460094,0x00000000}},	//   эзон_, упна, лноз,
  { {0x9a99001c,0x6d553267,0xa8790041,0x00000000}},	//   žādā, _muza, _װאַר,
  { {0x69c3004b,0xc879095a,0x6cfa0063,0x00000000}},	//   lvne, maş_, תפרס,
  { {0x7ae100fe,0x201c005b,0x43750086,0x00000000}},	//   _jolt, şvik_, шуют,
  { {0xf54a3268,0x7ae13269,0x2739135d,0x00000000}},	//   _bất_, _molt, gène_,
  { {0xb4db0268,0x61e10c16,0xf54a008b,0x00000000}},	//   rmàc, älla, _cất_,
  { {0x17560047,0x3075326a,0xb05b0244,0x00000000}},	// [54e0] ָסער_, русс, _anäs,
  { {0x4df60055,0x7ae101f4,0x6d550075,0x00000000}},	//   ляет, _nolt, _buza,
  { {0x27390003,0xdbd6004d,0x25710130,0x00000000}},	//   cène_, fäße, nšl_,
  { {0x2d8702dd,0x7bc2006f,0xf54a0013,0x00000000}},	//   ánea_, tvou, _tấu_,
  { {0xc879005b,0x69c305b9,0x3ebd0072,0x00000000}},	//   daş_, evne, öytä_,
  { {0x7ae1326b,0x7bc20479,0xcb6701ce,0x00000000}},	//   _colt, rvou, ћаје_,
  { {0xea95000d,0xee3702e1,0xef1704ed,0x00000000}},	//   ршчэ, _бнр_, _смр_,
  { {0x8c46026b,0x7ae10139,0xc879003b,0x00000000}},	//   _бебе, _eolt, gaş_,
  { {0x3f92005b,0xb6f40095,0x69c3326c,0x00000000}},	//   nuyu_, изиј, avne,
  { {0x6d860063,0xdb0e0072,0x6288013d,0x00000000}},	//   ְתָּ_, ökäy, ódol,
  { {0x645a0080,0xd884007e,0xc8790075,0x00000000}},	//   ětin, _نهای, baş_,
  { {0xc879003b,0x69c80580,0x27390003,0x00000000}},	//   caş_, _irde, vène_,
  { {0xf54a001b,0x2bc70053,0x987b0041,0x00000000}},	//   _rất_, लिया, _טראק,
  { {0x88bd0051,0x3f920058,0x68e2326d,0x00000000}},	//   nośn, duyu_, _hood,
  { {0x68e20d9e,0xd13b2785,0x7e7500a8,0x00000000}},	//   _kood, еха_, _rezp,
  { {0x68e2326e,0x27390003,0x657c2717,0x00000000}},	//   _jood, rène_, árhu,
  { {0x68e2326f,0x7f950062,0x27390003,0x00000000}},	// [54f0] _mood, разх, sène_,
  { {0x3f870117,0x200d007a,0x68e20004,0x00000000}},	//   čnu_, _þeim_, _lood,
  { {0xf54a001b,0x0dc80001,0xdc550002,0x00000000}},	//   _tất_, луци_, авењ,
  { {0x68e212bc,0x7ae10dd1,0xf54a0013,0x00000000}},	//   _nood, _solt, _uất_,
  { {0x6d5a0164,0xc879005b,0x3f790047,0x00000000}},	//   _étan, vaş_, _באָס,
  { {0x63ad0009,0xdefb0088,0x2bc70053,0x00000000}},	//   _mpan, _чым_, लिबा,
  { {0x68e210e9,0xdb000146,0x6d550035,0x00000000}},	//   _bood, _opmæ, _uuza,
  { {0x69c31035,0x63ad3270,0x77852953,0x00000000}},	//   rvne, _opan, ализ,
  { {0xccf2014e,0x7ae13271,0x68e23272,0x00000000}},	//   _וכן_, _tolt, _dood,
  { {0xe7390001,0x7d0b3273,0x628500b9,0x00000000}},	//   ђен_, ligs, _ndho,
  { {0xa2d90161,0x68e21c9f,0x63ad3274,0x00000000}},	//   मान्, _food, _apan,
  { {0x2730008b,0x68e20127,0x7bc93275,0x00000000}},	//   hành_, _good, _kreu,
  { {0x61e101e3,0x386d3276,0x2cbf3277,0x00000000}},	//   älln, mber_, _maud_,
  { {0xf770006a,0x386d103b,0x68e2006f,0x00000000}},	//   _راه_, lber_, _zood,
  { {0x11d50636,0x6592005e,0x386d004b,0x00000000}},	//   бітр, _дају, ober_,
  { {0x3f92005b,0x53ca0002,0x3d1f0053,0x00000000}},	//   tuyu_, _агим_, यकों_,
  { {0x8f760086,0x386d3278,0xb4db01a8,0x00000000}},	// [5500] рубі, iber_, omàn,
  { {0x543b0047,0x3f92005b,0x27300013,0x00000000}},	//   _בעפא, ruyu_, gành_,
  { {0xdcff0080,0x7d0b00bd,0x610c005b,0x00000000}},	//   _úvěr, figs, aşla,
  { {0x0b8a0c8d,0x7b66000d,0x5ca63279,0x00000000}},	//   вски_, атке, ридб,
  { {0x7bc9327a,0x68e22a40,0x2cbf1472,0x00000000}},	//   _creu, _rood, _daud_,
  { {0x68e20019,0xe9860001,0xee3a000d,0x00000000}},	//   _sood, аћин, _анг_,
  { {0xf2890047,0xb05b0137,0x68e2327b,0x00000000}},	//   אָפֿ, _knäp, _pood,
  { {0x7bc9327c,0xa7741e51,0x97a60a2f,0x00000000}},	//   _freu, блич, арол,
  { {0x3f8000cd,0x68e2327d,0x7bc9327e,0x00000000}},	//   nsiu_, _vood, _greu,
  { {0x68e2327f,0x69c800c2,0x56f40002,0x00000000}},	//   _wood, _trde, споѓ,
  { {0x68e20004,0x386d3280,0xd6d7014c,0x00000000}},	//   _tood, bber_, рты_,
  { {0x2ca60185,0x394f035a,0x6fc90053,0x00000000}},	//   nfod_, _gigs_, रिमं,
  { {0xda780024,0x79150047,0x938b0062,0x00000000}},	//   _keď_, _פֿעב_, ъсна_,
  { {0x61e100c7,0x47330054,0x7d0b0244,0x00000000}},	//   ällo, _дніс, zigs,
  { {0x2127007e,0xdb11013d,0xda780066,0x00000000}},	//   ليسی_, ófét, _meď_,
  { {0x67280ad5,0x90550085,0x3068005e,0x00000000}},	//   lodj, свац, ијун_,
  { {0x2cbf3281,0x63ad114c,0x3eb331b5,0x00000000}},	// [5510] _raud_, _upan, text_,
  { {0x2d8702dd,0xf54a008b,0x28a60053,0x00000000}},	//   áneo_, _hấp_, क्ति,
  { {0x2cbf0150,0x7d0b3282,0x6d5a0003,0x00000000}},	//   _paud_, tigs, _étal,
  { {0xbc19000d,0x237f007d,0x7bc93283,0x00000000}},	//   лілі_, šuju_, _preu,
  { {0x67283284,0x3ff90047,0x7d0b0f8c,0x00000000}},	//   kodj, _עפֿע, rigs,
  { {0x7bc93285,0xf54a0013,0x7d0b004d,0x00000000}},	//   _vreu, _lấp_, sigs,
  { {0x752d0051,0xceb20063,0x394f3286,0x00000000}},	//   _okaz, _מים_, _pigs_,
  { {0x26de0024,0x4c940076,0xac940376,0x00000000}},	//   ejto_, _мисс, _масш,
  { {0x69de0031,0x394f00ac,0x7d093287,0x00000000}},	//   øper, _vigs_, _imes,
  { {0x6728007d,0x7c3b00a8,0x7d1b18d7,0x00000000}},	//   godj, _izur, _hjus,
  { {0xb4db0268,0xa5941213,0xc9f40044,0x00000000}},	//   rmàn, орящ, _وسمع,
  { {0xf54a001b,0xb4db00cd,0xda78004c,0x00000000}},	//   _cấp_, smàn, _zeď_,
  { {0x67283288,0xa8560063,0x3835005e,0x00000000}},	//   bodj, _הינה_, _ундр,
  { {0x7d1b3289,0x6263328a,0xcc3a0047,0x00000000}},	//   _ljus, звра, טערט,
  { {0x7d09197c,0x27ed00ea,0x61050078,0x00000000}},	//   _omes, lyen_, lėly,
  { {0xf54a008b,0x7a4200ea,0x27ed0003,0x00000000}},	//   _gấp_, líté, oyen_,
  { {0x27ed328b,0x7c3b0035,0x3f800078,0x00000000}},	// [5520] nyen_, _nzur, usiu_,
  { {0x7a42000f,0x7d09328c,0x7d1b153e,0x00000000}},	//   níté, _ames, _ajus,
  { {0x3f800268,0xe1f2006a,0x27ed0072,0x00000000}},	//   ssiu_, _رسد_, hyen_,
  { {0x3d8b007e,0xa136007e,0xf54a0013,0x00000000}},	//   احلی_, _درخش, _xấp_,
  { {0x2ca60185,0x7d1b328d,0x88bd0022,0x00000000}},	//   rfod_, _djus, rośl,
  { {0x7d09328e,0x443201cf,0xaa570021,0x00000000}},	//   _emes, _myy_, ملها_,
  { {0xcaa50021,0x7e7e328f,0xda780066,0x00000000}},	//   تصني, mapp, _veď_,
  { {0x60c43290,0xdca30cd6,0x7e7e3291,0x00000000}},	//   ndim, _наси, lapp,
  { {0xda780080,0x2000000c,0x6d400058,0x00000000}},	//   _teď_, nzii_, _ihma,
  { {0x8b260088,0x7a4200ea,0x752d3292,0x00000000}},	//   _удзе, gíté, _skaz,
  { {0x6728163f,0x7e7e04ad,0x442000cd,0x00000000}},	//   rodj, iapp, _axi_,
  { {0x27ed2523,0x7e7e2158,0xce370063,0x00000000}},	//   byen_, happ, מאית_,
  { {0x7e7e10e9,0x27ed0031,0xf54a0013,0x00000000}},	//   kapp, cyen_, _vấp_,
  { {0xd765007e,0x60c43293,0x6456013d,0x00000000}},	//   _بنوی, edim, _egyi,
  { {0xeab10063,0x61ee002b,0xf54a0013,0x00000000}},	//   וֹן_, gybl, _tấp_,
  { {0x2d87004c,0x752d0e88,0x6b82260f,0x00000000}},	//   ánem_, _ukaz, ksog,
  { {0x6133005b,0x2d5e006c,0x24893294,0x00000000}},	// [5530] nçli, _aïe_, _idam_,
  { {0x9e150088,0x6d40014f,0x2d8700c3,0x00000000}},	//   одзі, _ahma, šnem_,
  { {0xa49b00cd,0x68fb002b,0xd6570063,0x00000000}},	//   biòt, yhud, ציאת_,
  { {0x7a4200ea,0x2489008d,0x7e7e0050,0x00000000}},	//   zíté, _jdam_, aapp,
  { {0x7d0900c3,0x44203295,0x27ed06a5,0x00000000}},	//   _vmes, _xxi_, xyen_,
  { {0x27ed3296,0xa8a70058,0x6d401013,0x00000000}},	//   vyen_, şmüş_, _ehma,
  { {0x6d58034d,0x7a4200ea,0x314b0063,0x00000000}},	//   ívat, víté, ְתִּ,
  { {0x7d093297,0x6105005f,0x27ed3298,0x00000000}},	//   _umes, tėly, tyen_,
  { {0x69ce0026,0x7c3b3299,0x7a4200ea,0x00000000}},	//   _áben, _uzur, títé,
  { {0xd7090076,0xd7050086,0x3dc60051,0x00000000}},	//   рное_, ізни, łowe_,
  { {0x27ed00e3,0x7a42000f,0x443200fe,0x00000000}},	//   syen_, ríté, _syy_,
  { {0x7a42000f,0x03a60076,0x89370049,0x00000000}},	//   síté, оимо, _اعطا,
  { {0xdd0c0045,0x7ccd003d,0x7a4200ea,0x00000000}},	//   _późn, mērķ, píté,
  { {0x36690138,0xddd5004c,0x00000000,0x00000000}},	//   _тако_, _nezů,   ,
  { {0x2d870024,0x24890089,0x96f60002,0x00000000}},	//   šnej_, _fdam_, _фејт_,
  { {0x60c400eb,0x463a0047,0x61ee1780,0x00000000}},	//   udim, _דעצע, rybl,
  { {0x7e7e1443,0x60c4329a,0x69c40023,0x00000000}},	// [5540] tapp, rdim, āiei,
  { {0x2000329b,0x63ab0137,0x23b3007e,0x00000000}},	//   rzii_, _ägna, _کمیس,
  { {0x629c0104,0x7e7e06f1,0x4d6602fe,0x00000000}},	//   mgro, rapp, цкев,
  { {0x2bca000a,0x629c1a33,0x7e7e04ca,0x00000000}},	//   илеп_, lgro, sapp,
  { {0x387f0150,0x8b26012f,0x7e7e329c,0x00000000}},	//   daur_, одде, papp,
  { {0x2fcf0146,0x298a005e,0x629c329d,0x00000000}},	//   ægge_, асио_, ngro,
  { {0x14ca0042,0xc4ca0042,0xa9670131,0x00000000}},	//   ियाण, ियाओ, оија_,
  { {0x6d5c0150,0x629c2b09,0x272a004c,0x00000000}},	//   _iura, hgro, zóně_,
  { {0x28a60053,0x6d5c329e,0x629c07f5,0x00000000}},	//   क्षि, _hura, kgro,
  { {0x6d5c329f,0x61e100a5,0xdb240050,0x00000000}},	//   _kura, ällk, ösäh,
  { {0xa01b00bd,0xe535000d,0x24890150,0x00000000}},	//   _geöf, зень, _pdam_,
  { {0x629c0a53,0x55070088,0x7e7c001f,0x00000000}},	//   egro, ічна, _lerp,
  { {0x38cb007e,0x3866002b,0x6d5c32a0,0x00000000}},	//   _خالی_, _ifor_, _lura,
  { {0x2d870080,0x28a60161,0x6d5c1da4,0x00000000}},	//   ánek_, क्रि, _oura,
  { {0x7ae8010a,0x6d5c32a1,0x386632a2,0x00000000}},	//   _modt, _nura, _kfor_,
  { {0x23a40137,0xc5f8008f,0xd0d40062,0x00000000}},	//   böj_, ncēm_, мосъ,
  { {0x7e7c0e53,0x6d5c32a3,0x629c059f,0x00000000}},	// [5550] _berp, _aura, bgro,
  { {0x7e7c028d,0x6d5c32a4,0xde970021,0x00000000}},	//   _cerp, _bura, تجرب,
  { {0xcddb0001,0x7bc00006,0x7e7c05b9,0x00000000}},	//   шња_, _asmu, _derp,
  { {0x6d5c04cf,0xd7bc0053,0x62880195,0x00000000}},	//   _dura, ्टाच, ódov,
  { {0x3af5014c,0x6d5c32a5,0x60da0063,0x00000000}},	//   зяйс, _eura, _הקרנ,
  { {0x9b68000d,0x6d5c32a6,0x9aa50044,0x00000000}},	//   ішча_, _fura, سمبو,
  { {0x02fc0063,0x254d0051,0x6d5c15a8,0x00000000}},	//   שלומ, _eśli_, _gura,
  { {0x28bd0053,0x7e65004d,0x64400066,0x00000000}},	//   ्यधि, lchp, ýmik,
  { {0x7f5d03b2,0x2d9e0137,0x7ae800b9,0x00000000}},	//   _jusq, _äter_, _fodt,
  { {0x7ae802fb,0x6d5c32a7,0x387f32a8,0x00000000}},	//   _godt, _yura, saur_,
  { {0x99d40044,0x9732005d,0x2bbf0042,0x00000000}},	//   _يتما, رکها, _शैता,
  { {0x26c300c3,0x629c0c5f,0x69c132a9,0x00000000}},	//   žjo_, wgro, _isle,
  { {0x08760047,0x629c1817,0x98e40021,0x00000000}},	//   _זענט_, tgro, _تكنو,
  { {0x254d0080,0x36c40086,0x853d0078,0x00000000}},	//   _měly_, _обіг, ltėl,
  { {0x867a0063,0xbbb80053,0x629c32aa,0x00000000}},	//   _הרצו, _इन्क, rgro,
  { {0x6d5a03b2,0x629c0162,0x7f5d2bf6,0x00000000}},	//   _étai, sgro, _busq,
  { {0x6d5c32ab,0x7e7c32ac,0x629c32ad,0x00000000}},	// [5560] _sura, _perp, pgro,
  { {0x9756014e,0x6d5c32ae,0xdfcf0021,0x00000000}},	//   פיעו_, _pura, ديك_,
  { {0xfc66011c,0x6d5c132e,0x256100ea,0x00000000}},	//   пълн, _qura, _jól_,
  { {0x7e7c09fe,0x6d5c08af,0xfd950054,0x00000000}},	//   _werp, _vura, ьшую,
  { {0x7e7c0e53,0x92e9007e,0x60c600a4,0x00000000}},	//   _terp, _طریق_, _iakm,
  { {0x6d5c32af,0xfaa30062,0x98a4008f,0x00000000}},	//   _tura, ешън, domā_,
  { {0x2bb80053,0xe2a70014,0x88bd0022,0x00000000}},	//   _इनका, áðir_, nośw,
  { {0x60c60080,0x3eba13cb,0x61e132b0,0x00000000}},	//   _jakm, lept_, älli,
  { {0x60c632b1,0x7ae8004d,0x2d9a0877,0x00000000}},	//   _makm, _todt, lupe_,
  { {0xabfb014e,0xa823007e,0x25610758,0x00000000}},	//   _ההמר, رکنن, _ból_,
  { {0x2fc700aa,0x387d0244,0x7c2d056c,0x00000000}},	//   ̉ng_, _fewr_, żart,
  { {0x3eba006f,0x394a005e,0x98a602d8,0x00000000}},	//   hept_, _узео_, _хиде,
  { {0x395e00e5,0x5347130d,0x00000000,0x00000000}},	//   _huts_, зхва,   ,
  { {0x66e329c9,0x60c600a4,0x28da0053,0x00000000}},	//   _поча, _aakm, भावि,
  { {0x7f5d32b2,0x60c632b3,0x256132b4,0x00000000}},	//   _susq, _bakm, _gól_,
  { {0x6ab90235,0x361b0063,0x691700dd,0x00000000}},	//   _इस्र, _לווד, rţeg,
  { {0x853d0006,0x752f0022,0x7e6532b5,0x00000000}},	// [5570] ntėm, mocz, tchp,
  { {0x395e28b0,0x6288013d,0xaf33005d,0x00000000}},	//   _outs_, ódot, رواژ,
  { {0x2d8732b6,0x395e32b7,0x645a004c,0x00000000}},	//   éne_, _nuts_, ětiv,
  { {0xbd180086,0x8c3d003b,0x6e350061,0x00000000}},	//   пції_, _obşt, _vyzb,
  { {0xfbab0376,0x61330075,0xdd31056c,0x00000000}},	//   стей_, uçlu, mężn,
  { {0x395e0164,0x3dc60051,0x3eba32b8,0x00000000}},	//   _buts_, łowa_, cept_,
  { {0xa9c40032,0x2d9a0164,0x0b420062,0x00000000}},	//   فزيو, cupe_, ъншн,
  { {0x28da0161,0x6ca432b9,0x395e01a8,0x00000000}},	//   भाषि, _пруж, _duts_,
  { {0x752f0051,0x29030006,0x25610022,0x00000000}},	//   docz, ėja_, _sól_,
  { {0xca48007e,0xb0c90053,0xe6190062,0x00000000}},	//   _کلمه_, ाएँग, ждо_,
  { {0x69c1017f,0x26cb004c,0xf2120042,0x00000000}},	//   _usle, ěco_, _डेढ़_,
  { {0x3eba004d,0xb4c80042,0x00000000,0x00000000}},	//   zept_, ईये_,   ,
  { {0xb901024c,0x46a50094,0xe72e252a,0x00000000}},	//   दा_, _жалв, _ае_,
  { {0x853d0006,0xdcfe001c,0x256121bc,0x00000000}},	//   ntėj, ispā, _tól_,
  { {0x752f0051,0xb0c90042,0x950a0044,0x00000000}},	//   bocz, ाएंग, _وقتك_,
  { {0x316c001c,0x6b8900c2,0xa0220058,0x00000000}},	//   īdz_, _oveg, _çökm,
  { {0x628800ea,0x26c732ba,0xaec602fe,0x00000000}},	// [5580] ódos, _kano_, мбал,
  { {0x2480252f,0xe2830121,0x2d9a0124,0x00000000}},	//   _heim_, _ильи, tupe_,
  { {0x80a60161,0x26c732bb,0x82fa007e,0x00000000}},	//   _छापे, _mano_, _هرگز_,
  { {0xcea90e2a,0x2d8712a1,0x2d9a32bc,0x00000000}},	//   יי_, ânea_, rupe_,
  { {0x1ab401d5,0xc0030085,0x61e100a5,0x00000000}},	//   ебля, _апяк, ällv,
  { {0x78a201f4,0x395e32bd,0x2aaa0054,0x00000000}},	//   _scov, _puts_, ітло_,
  { {0x200d007a,0x79a60002,0x80a50053,0x00000000}},	//   _þeir_, фрле, ङ्के,
  { {0x26c700bb,0x98a3005e,0x7cde003b,0x00000000}},	//   _aano_, виће, _dărâ,
  { {0xea8a0062,0x67d40200,0x80a60042,0x00000000}},	//   _мбал_, хопу, _छाने,
  { {0x752f0051,0x26c732be,0x7d0232bf,0x00000000}},	//   wocz, _cano_, lhos,
  { {0x24800199,0x15150612,0x75d40021,0x00000000}},	//   _beim_, едня, ريحا,
  { {0x68460021,0x7d0232c0,0x2ebb0042,0x00000000}},	//   _قَال, nhos, _उस्त,
  { {0x27e0005b,0xb7d70021,0x752f0051,0x00000000}},	//   _çin_, _يوما_, rocz,
  { {0xf54a008b,0xe60f007e,0x26c70331,0x00000000}},	//   _mấy_, اشی_, _gano_,
  { {0x5757014e,0x7d020035,0xf54a001b,0x00000000}},	//   _קבוע_, khos, _lấy_,
  { {0x673a04aa,0xd25802fe,0x00000000,0x00000000}},	//   lltj, ьця_,   ,
  { {0xf54a0013,0x74150049,0x853d0078,0x00000000}},	// [5590] _nấy_, _سودا, ytėj,
  { {0xf3ff017d,0x7d0232c1,0xddc70022,0x00000000}},	//   lcão_, ehos, _tejż,
  { {0x6b8932c2,0x673a32c3,0x4ea40062,0x00000000}},	//   _sveg, iltj, ърта,
  { {0xf54a0013,0x7d02013d,0xdd980054,0x00000000}},	//   _bấy_, ghos, ьшу_,
  { {0xf54a0013,0xe7030013,0x4fc4030b,0x00000000}},	//   _cấy_, hướ, _исра,
  { {0x673a006f,0xb33b0058,0xf54a0013,0x00000000}},	//   jltj, ftçi, _dấy_,
  { {0xfe54000d,0x853d0078,0xa9660330,0x00000000}},	//   _акрэ, rtėj, нища_,
  { {0x7d0232c4,0xc7c8001b,0x853d0006,0x00000000}},	//   chos, _bố_, stėj,
  { {0xc7c8001b,0x78bb32c5,0x26c732c6,0x00000000}},	//   _cố_, reuv, _pano_,
  { {0xeab00021,0x3ced006f,0xd7060121,0x00000000}},	//   _نعم_, _hoev_, енье_,
  { {0x6d5a03b2,0x3ea10706,0x26c713c2,0x00000000}},	//   _état, ight_, _vano_,
  { {0xed590080,0x673a00ca,0xc976009a,0x00000000}},	//   _již_, altj, _נגני_,
  { {0xdd0c0045,0x26c70035,0x394d32c7,0x00000000}},	//   _różn, _tano_, mmes_,
  { {0x394d32c8,0xa6c9005d,0xed59011b,0x00000000}},	//   lmes_, _روبل_, _liž_,
  { {0x394d32c9,0x3f89002b,0x2f041914,0x00000000}},	//   omes_, esau_, _högg_,
  { {0x7d0200e8,0xf1c00066,0x656e0139,0x00000000}},	//   xhos, ššou_, íbhe,
  { {0x291f00fe,0x1e960156,0xc952009f,0x00000000}},	// [55a0] inua_, ерер, רמן_,
  { {0x2fc018c0,0x394d2820,0x3377009a,0x00000000}},	//   rwig_, hmes_, _רעים_,
  { {0x61e100c7,0xe0da0002,0x2fc032ca,0x00000000}},	//   ällt, _евн_, swig_,
  { {0xa6de001b,0x91360086,0xfd660013,0x00000000}},	//   _nhưn, _їхні, _khuấ,
  { {0x673a00ac,0x212001b3,0x98a40078,0x00000000}},	//   yltj, mnih_, nomą_,
  { {0x212006bb,0xada6000d,0xda66002a,0x00000000}},	//   lnih_, _пагл, راتي,
  { {0xc7c800aa,0x7d020027,0x533700b5,0x00000000}},	//   _số_, phos, ענצן_,
  { {0x98a40006,0x6d4300cd,0x394d109c,0x00000000}},	//   komą_, ïnat, gmes_,
  { {0x7d000019,0xf76f007e,0x8b26000d,0x00000000}},	//   _ilms, یای_, _здае,
  { {0x98a40006,0x212000a8,0x394d2392,0x00000000}},	//   domą_, hnih_, ames_,
  { {0xceb30063,0x212000a8,0x2499005d,0x00000000}},	//   אית_, knih_, وندد_,
  { {0xc7c8008b,0xdcfe0006,0x3f89001f,0x00000000}},	//   _tố_, rupė, ysau_,
  { {0xb8f40161,0x212006bb,0x7bc2006f,0x00000000}},	//   िए_, dnih_, nwou,
  { {0xb4db0268,0x629a00cd,0xb7db0063,0x00000000}},	//   emàt, òtop, _מקדי,
  { {0xbb3b00b5,0x72280054,0x88bd0022,0x00000000}},	//   פעלי, ецтв_, mośr,
  { {0xe63b0063,0xb4db01a8,0xa63b0063,0x00000000}},	//   _מתוכ, gmàt, _מגור,
  { {0x6917003b,0x1017007e,0xa92301d1,0x00000000}},	// [55b0] nţea, ربرد, ížil,
  { {0x3ea10037,0x2d870016,0x61e100c7,0x00000000}},	//   ught_, âneo_, älls,
  { {0x212002e2,0x3f8932cb,0x26cc002b,0x00000000}},	//   bnih_, ssau_, iddo_,
  { {0x5ce432cc,0x21200734,0x628732cd,0x00000000}},	//   люча, cnih_, lajo,
  { {0x60cd1966,0x7bc200ca,0x2cbd00e5,0x00000000}},	//   mdam, gwou, rewd_,
  { {0x60cd0004,0xe3b40047,0x8c42005e,0x00000000}},	//   ldam, רױס_, јеше,
  { {0x60cd0006,0x6917003b,0x394d32ce,0x00000000}},	//   odam, eţea, tmes_,
  { {0x60cd010e,0x39590137,0xde580054,0x00000000}},	//   ndam, öss_, _часі_,
  { {0x394d32cf,0x62871a39,0x60cd32d0,0x00000000}},	//   rmes_, kajo, idam,
  { {0x628700c3,0xf7450001,0x753d00ea,0x00000000}},	//   jajo, ђено, elsz,
  { {0x60cd00eb,0x628722e7,0x442932d1,0x00000000}},	//   kdam, dajo, _axa_,
  { {0xb8150d34,0x98c4003b,0x98a40078,0x00000000}},	//   _идеј, ătăm_, tomą_,
  { {0x212006bb,0x6d490025,0x60cd32d2,0x00000000}},	//   vnih_, _mhea, ddam,
  { {0xe611007e,0x68e932d3,0x83c3005e,0x00000000}},	//   _پشت_, ljed, јбрж,
  { {0x212001a6,0xddc5004c,0x442900be,0x00000000}},	//   tnih_, dchů, _exa_,
  { {0xb4db00cd,0x60cd32d4,0x2f04004d,0x00000000}},	//   umàt, gdam, _möge_,
  { {0x628702dd,0xb4db0268,0x212032d5,0x00000000}},	// [55c0] bajo, rmàt, rnih_,
  { {0x6d490b7a,0x21200add,0x212d00c2,0x00000000}},	//   _ahea, snih_, čeha_,
  { {0x65630016,0x6d490027,0xac86000a,0x00000000}},	//   _junh, _bhea, вгел,
  { {0xdb1f0164,0x61e100c7,0x6d49057a,0x00000000}},	//   _évêq, ålle, _chea,
  { {0x26cc0185,0x6d490025,0xcb670001,0x00000000}},	//   yddo_, _dhea, ваче_,
  { {0x7bc200ca,0xbb57000d,0xfe462ceb,0x00000000}},	//   rwou, ваіх_, _анго,
  { {0x6d490027,0xcec30080,0xe5670242,0x00000000}},	//   _fhea, ářů_, _خط_,
  { {0x6d4913fb,0x2d9c00cd,0x20040014,0x00000000}},	//   _ghea, àveu_, _ýmis_,
  { {0x8706005a,0xaae20053,0x6a86005e,0x00000000}},	//   вяне, पादक, _алза,
  { {0x68e90755,0x691700dd,0x60cd1ada,0x00000000}},	//   ajed, rţea, zdam,
  { {0xdb1b32d6,0x68e9017f,0x6563017d,0x00000000}},	//   _usuá, bjed, _cunh,
  { {0xdddc0117,0x26ca00c3,0x320a0066,0x00000000}},	//   _održ, žbo_, dzby_,
  { {0x60cd004b,0x628732d7,0x88bd0051,0x00000000}},	//   vdam, tajo, pośr,
  { {0xd5b0007e,0x75d414d7,0x77f7009d,0x00000000}},	//   _هفت_, _ميتا, _במדד_,
  { {0x30a701dd,0x628732d8,0x3633005d,0x00000000}},	//   крав, rajo, _پروس,
  { {0x628732d9,0xdbca004b,0x7d03008f,0x00000000}},	//   sajo, _hõõr, īnsk,
  { {0x628732da,0x60cd32db,0x6ffa008f,0x00000000}},	// [55d0] pajo, rdam, _nācā,
  { {0x6d49057a,0x60cd16ee,0xdf390021,0x00000000}},	//   _shea, sdam, ركات_,
  { {0x6d490027,0x320a0051,0x7c3b0397,0x00000000}},	//   _phea, czby_, _syur,
  { {0xdd940088,0xada40086,0xdb0200b9,0x00000000}},	//   рацы, раїл, ntoæ,
  { {0xeab9005a,0x68e9017f,0x628532dc,0x00000000}},	//   ейл_, vjed, _keho,
  { {0x6d4932dd,0x628532de,0x93fc07e9,0x00000000}},	//   _whea, _jeho, ולדי,
  { {0x443e001b,0x6d49057a,0x3c93007e,0x00000000}},	//   ́t_, _thea, _نیاز,
  { {0x6d5a0164,0x08c507b0,0x7c2901a8,0x00000000}},	//   _étap, убин, _txer,
  { {0x69c80994,0x68e900ea,0x68fb04b4,0x00000000}},	//   _esde, rjed, rkud,
  { {0x68e9017f,0x6563017d,0xf1c001d9,0x00000000}},	//   sjed, _punh, ášku_,
  { {0x497512c1,0x5ee8009a,0x00000000,0x00000000}},	//   _слес, דַרְ,   ,
  { {0x5a0c00b5,0xf2c911b4,0x98f4000d,0x00000000}},	//   _קלאַ, _מע_, _вяшч,
  { {0x628505da,0xe0df008d,0x9cd60063,0x00000000}},	//   _beho, _chòm_, אורה_,
  { {0x628532df,0xd2950054,0xd6291a71,0x00000000}},	//   _ceho, ирсь, _поле_,
  { {0x0219019d,0x628532e0,0xf53f0b19,0x00000000}},	//   віть_, _deho, blå_,
  { {0x386d08dc,0x320a056c,0x26000042,0x00000000}},	//   ncer_, rzby_, शनरी_,
  { {0x6143006e,0x386d32e1,0xafe30256,0x00000000}},	// [55e0] сета, icer_, ботл,
  { {0x6d430003,0x628503ac,0x6fb30044,0x00000000}},	//   înan, _geho, إملا,
  { {0x1d1a0121,0xdd8f0044,0x5cf6012c,0x00000000}},	//   нюдь_, كول_, ляду,
  { {0x163600b5,0x00000000,0x00000000,0x00000000}},	//   אנער_,   ,   ,
  { {0x3b960001,0xdddc0114,0xb33b017d,0x00000000}},	//   ујет, _udrž, luça,
  { {0xb6a30013,0x6e3c002b,0xbb830044,0x00000000}},	//   _quầ, _tyrb, حلوي,
  { {0x7bc9003b,0x7981002b,0x5f0332e2,0x00000000}},	//   _eseu, _cwlw, _узра,
  { {0x6b4400cd,0x853d0078,0x7d190022,0x00000000}},	//   cògn, ntėt, ciws,
  { {0x1d070055,0x99850006,0xb6a3008b,0x00000000}},	//   _сети_, _bylų_, _tuầ,
  { {0x386d04d0,0x569400e1,0xb6c60062,0x00000000}},	//   acer_, јант, усий,
  { {0xdbca0019,0x69c801a8,0x291a0003,0x00000000}},	//   _võõr, _usde, épas_,
  { {0x69170529,0xe5350121,0x629a00be,0x00000000}},	//   nţel, ремь, óton,
  { {0x628500c3,0x3eb800b2,0xab000046,0x00000000}},	//   _peho, _obrt_, _þjóð_,
  { {0xf53f0f4b,0x853d0078,0x00000000,0x00000000}},	//   slå_, etėt,   ,
  { {0x8504007e,0x41e4046e,0xd5a2005d,0x00000000}},	//   _گوين, біта, _العی,
  { {0x2eff0003,0x212d1824,0xd904005d,0x00000000}},	//   _œuf_, čeho_, سی_,
  { {0x6285024a,0x3f15000d,0xa29501dd,0x00000000}},	// [55f0] _teho, адас, _капі,
  { {0x6917003b,0x6e950002,0xdb020137,0x00000000}},	//   eţel, рижу, ntoä,
  { {0x8afc0045,0xfe700044,0x7e470085,0x00000000}},	//   _międ, سدل_, ухае,
  { {0x7db40021,0x30790041,0x2ca9004e,0x00000000}},	//   إصلا, _שאָנ, üad_,
  { {0x69de00d1,0x4c840e74,0xcaa50044,0x00000000}},	//   åpen, слів, لصغي,
  { {0x60cf0058,0xff04000d,0x386d002b,0x00000000}},	//   _hacm, _лясн, wcer_,
  { {0x3b060062,0x53380047,0x2fd9004d,0x00000000}},	//   рещо_, אנגן_, _hrsg_,
  { {0x386d32e3,0xa7b501ce,0xed580043,0x00000000}},	//   ucer_, асој, _مشقت_,
  { {0xdddc000c,0x2f0400c7,0x2ca0017d,0x00000000}},	//   _terţ, _höga_, óide_,
  { {0x386d06a6,0xf1c00024,0x46f5130d,0x00000000}},	//   scer_, ššiu_, рчит,
  { {0xa50a295e,0x8afc0051,0xdddc005f,0x00000000}},	//   вена_, _sięg, _kerš,
  { {0x69dc04a6,0x7dd000ea,0x64a60085,0x00000000}},	//   _área, lósá, шама,
  { {0x2615016a,0x888c0047,0x69ce0014,0x00000000}},	//   _फेरी_, _טראַ, _áber,
  { {0x3dc60051,0xd5d90094,0xcc56009a,0x00000000}},	//   łowi_, _афиш_, יברי_,
  { {0x2ca6002b,0xa1870094,0x35a504ef,0x00000000}},	//   ygod_, ибра_, _тайг,
  { {0x61e100c7,0x60262e24,0x42230054,0x00000000}},	//   ålla, адба, ідтв,
  { {0x8e8607b0,0x8fa62bc7,0x1e8632e4,0x00000000}},	// [5600] игае, разе, илам,
  { {0xbe850032,0xd0590086,0x93fb069a,0x00000000}},	//   مجمو, урсі_, _סליי,
  { {0x729b0063,0xe29b0063,0xdb020137,0x00000000}},	//   _בסיס, _בשיר, ntoå,
  { {0x7e5532e5,0x8fa632e6,0x00000000,0x00000000}},	//   стуц, _каме,   ,
  { {0x6917000c,0x2ca60104,0x8f75046e,0x00000000}},	//   rţel, rgod_, _гусі,
  { {0x5b130086,0x2ca6001f,0x2f040137,0x00000000}},	//   оміт, sgod_, _föga_,
  { {0x79450045,0xdddc00c2,0x26ce003b,0x00000000}},	//   równ, _ferš, _rafo_,
  { {0xdca31e15,0x60c40315,0x893314d7,0x00000000}},	//   _маси, neim, يعيا,
  { {0x082a0062,0xfaa616e0,0xcb6a0085,0x00000000}},	//   ъцки_, _вазо, _разе_,
  { {0x60c432e7,0xe6660002,0xd6da0bd5,0x00000000}},	//   heim, штио, тти_,
  { {0xa3a9016a,0x3ed900b5,0x5ed90047,0x00000000}},	//   खून_, אַרא, אַרװ,
  { {0x2509007e,0x6d4232e8,0x9f4f013d,0x00000000}},	//   اردی_, nloa, ágú_,
  { {0xc865007e,0x60c432e9,0xb90a0042,0x00000000}},	//   _اطمي, deim, मा_,
  { {0x81c3003d,0x65660001,0x7526006f,0x00000000}},	//   ņēmu, _књиж, ankz,
  { {0x3168000a,0xf194005a,0xdbd10014,0x00000000}},	//   ишто_, жись, _lýðr,
  { {0x6d42003b,0x463b0047,0x20980121,0x00000000}},	//   jloa, _שעהע, иксы_,
  { {0xb33b005b,0x6e6732ea,0x7eb90085,0x00000000}},	// [5610] erçe, атеж, лгас_,
  { {0xc43c0063,0x69da32eb,0xa857089e,0x00000000}},	//   _בתחי, _orte, שימה_,
  { {0xdc750088,0xdddc2365,0xb33b0c77,0x00000000}},	//   быль, _perš, luço,
  { {0xcdd8005e,0x657a0139,0x98a4004c,0x00000000}},	//   шњу_, ipth, romě_,
  { {0xee870055,0x69da32ec,0x7dd000ea,0x00000000}},	//   _выбо, _arte, tósá,
  { {0x0056014e,0x68e2001f,0x4af9006a,0x00000000}},	//   _לשרת_, _anod, دکرد_,
  { {0x6ef302f4,0x853d0006,0xdd94000d,0x00000000}},	//   _výbě, orėd, _мары,
  { {0x2489003b,0x98a4005f,0xa7d50044,0x00000000}},	//   _neam_, ilmė_, متخص,
  { {0x69da32ed,0xe7390081,0x9f960244,0x00000000}},	//   _erte, леи_, _müßt_,
  { {0x68e200c2,0xd7060121,0x06e90054,0x00000000}},	//   _enod, йные_, умок_,
  { {0x24890034,0x19ab005e,0x00000000,0x00000000}},	//   _beam_, _штап_,   ,
  { {0x7bdb0cb0,0xb9550456,0xb8d40044,0x00000000}},	//   _kruu, _увещ, _وتنش,
  { {0x387f014f,0x61e100c7,0xb4c80053,0x00000000}},	//   mbur_, ålln, _उसी_,
  { {0x78a932ee,0x387f00e5,0x61fc00a3,0x00000000}},	//   lgev, lbur_, tyrl,
  { {0xa22a0062,0x26c51cbd,0x6d4232ef,0x00000000}},	//   ужва_, melo_, yloa,
  { {0xf06632f0,0x26c532f1,0x78a915ed,0x00000000}},	//   скап, lelo_, ngev,
  { {0x404a005e,0x9396014d,0x60c432f2,0x00000000}},	// [5620] упао_, _اجبا, reim,
  { {0xb33b01f7,0xb4db00cd,0x26c532f3,0x00000000}},	//   nuçl, nlàn, nelo_,
  { {0x628e0d89,0x2fc900a4,0x387f0089,0x00000000}},	//   mabo, awag_, kbur_,
  { {0x78a90122,0x2f040026,0x26c5006d,0x00000000}},	//   jgev, _gögn_, helo_,
  { {0x26c500ac,0x78a90d1e,0x25a51f96,0x00000000}},	//   kelo_, dgev, hull_,
  { {0x628e001f,0x26c5074f,0x6d420019,0x00000000}},	//   nabo, jelo_, sloa,
  { {0x26c532f4,0x6d4232f5,0x78a900ca,0x00000000}},	//   delo_, ploa, fgev,
  { {0x3ec50006,0x628e32f6,0x78a932f7,0x00000000}},	//   įstų_, habo, ggev,
  { {0x7d020146,0x63a60089,0x628e1154,0x00000000}},	//   mkos, jukn, kabo,
  { {0x7d02007a,0x63a6014f,0x26c532f8,0x00000000}},	//   lkos, dukn, gelo_,
  { {0xd6d70475,0x69da32f9,0x387f0014,0x00000000}},	//   сты_, _urte, bbur_,
  { {0x07a60854,0xe0df0013,0x387f0058,0x00000000}},	//   _гадн, _thòi_, cbur_,
  { {0x26c532fa,0x14aa0053,0x29d80013,0x00000000}},	//   belo_, _कारण, _hĩa_,
  { {0x26c532fb,0x628e32fc,0x5454007f,0x00000000}},	//   celo_, gabo, явят,
  { {0x25a50268,0x171b0047,0x7d0232fd,0x00000000}},	//   cull_, _גוגע, kkos,
  { {0x673a0268,0x628e00a4,0x7bc000b9,0x00000000}},	//   lotj, aabo, _opmu,
  { {0x752d00e3,0x2fc9002c,0x673a004b,0x00000000}},	// [5630] _ijaz, uwag_, ootj,
  { {0x2fc900ac,0x7d021986,0x628e32fe,0x00000000}},	//   rwag_, ekos, cabo,
  { {0x78a900ac,0x41b50021,0x7bc00023,0x00000000}},	//   ygev, _بمجر, _apmu,
  { {0x30a70076,0x7bdb0019,0x26c532ff,0x00000000}},	//   _уров, _pruu, zelo_,
  { {0x673a013d,0xdb0b0046,0x5b35005d,0x00000000}},	//   kotj, stgí, يعتر,
  { {0x38660185,0x49991087,0x7d0225fb,0x00000000}},	//   _agor_, атия_, akos,
  { {0x78a903a8,0x1986005a,0x26c5074f,0x00000000}},	//   tgev, общи_, velo_,
  { {0xb4c80053,0x628e3300,0x8afc0051,0x00000000}},	//   _उसे_, zabo, _pięc,
  { {0x78a902b0,0x656a00bd,0x26c53301,0x00000000}},	//   rgev, _aufh, telo_,
  { {0x78a9016d,0x26c5006d,0x21290150,0x00000000}},	//   sgev, uelo_, hnah_,
  { {0x8afc0045,0x78a9006f,0x24ea0818,0x00000000}},	//   _więc, pgev, амни_,
  { {0x67280019,0x21293302,0x63a6192f,0x00000000}},	//   andj, jnah_, tukn,
  { {0x26c508ea,0xb33b0058,0xa34a182b,0x00000000}},	//   pelo_, puçl, изма_,
  { {0x7d09245c,0x63a62595,0x212900a8,0x00000000}},	//   _lles, rukn, enah_,
  { {0x27ff3303,0x628e3304,0x63a63305,0x00000000}},	//   lyun_, rabo, sukn,
  { {0xa067065b,0xb1460726,0xdfd201fb,0x00000000}},	//   жата_, інал, ويز_,
  { {0xef1a05ee,0x27ed0934,0x7643002b,0x00000000}},	// [5640] ама_, nxen_, _hyny,
  { {0x27ed0994,0x3eae00bd,0x2129003e,0x00000000}},	//   ixen_, üft_, anah_,
  { {0x6f1e3306,0x65640072,0x7d023307,0x00000000}},	//   ripc, _kiih, tkos,
  { {0xf7670242,0x7643001f,0xd83e0195,0x00000000}},	//   _يا_, _myny, íčko_,
  { {0x6b440268,0x7d023308,0xa09b0047,0x00000000}},	//   lògi, rkos, _דיכט,
  { {0x60d600eb,0x7d023309,0x69c10139,0x00000000}},	//   ldym, skos, _bple,
  { {0xf98f0032,0x60d60006,0xf967093e,0x00000000}},	//   نبي_, odym, орый_,
  { {0x60d600eb,0xd7c8006a,0x656400fe,0x00000000}},	//   ndym, موعه_, _niih,
  { {0xd90d006a,0x6d4002cc,0x99e30066,0x00000000}},	//   دین_, _ikma, ĺňal,
  { {0x7d1b0051,0x60d60072,0x28da0082,0x00000000}},	//   _zmus, hdym, _मोरि,
  { {0x7643001f,0x60d60006,0x673a00c2,0x00000000}},	//   _cyny, kdym, rotj,
  { {0x37e60076,0x657500ea,0xdb0a0026,0x00000000}},	//   _моег, ízha, ðnæt,
  { {0xe9ff001b,0x60d6001f,0x8d5b0047,0x00000000}},	//   _kiếm_, ddym, יכטי,
  { {0x7643001f,0x752d0051,0x99430058,0x00000000}},	//   _fyny, _wjaz, _kış_,
  { {0x21290397,0x64b30080,0x6b4400cd,0x00000000}},	//   tnah_, _přič, gògi,
  { {0x752d0035,0x60d60078,0x798800a3,0x00000000}},	//   _ujaz, gdym, _mwdw,
  { {0xc05b019d,0x21290e53,0x32050080,0x00000000}},	// [5650] рів_, rnah_, šly_,
  { {0xcddb0001,0x21290089,0x7d09330a,0x00000000}},	//   иње_, snah_, _sles,
  { {0x2d870164,0x60d60078,0x2ef8330b,0x00000000}},	//   ène_, bdym, _dorf_,
  { {0x2d47017d,0x753d101d,0xc5f30063,0x00000000}},	//   põem_, nosz, ודע_,
  { {0x69c1330c,0xe9ff0013,0x999e004c,0x00000000}},	//   _sple, _biếm_, _bytů_,
  { {0x79450022,0x2d87006c,0x6ffa009a,0x00000000}},	//   mówi, ânes_, _ההשפ,
  { {0x7b060046,0x1a68005d,0xdc3c0023,0x00000000}},	//   _iðul, زینی_, kšķo,
  { {0x3ea9000c,0x7d0900d1,0x9943005b,0x00000000}},	//   şită_, _ules, _dış_,
  { {0x47c20076,0xf8ae005d,0xe8f60054,0x00000000}},	//   ебыв, اکم_, їль_,
  { {0x656400fe,0x290d0035,0x2904330d,0x00000000}},	//   _siih, shea_, akma_,
  { {0x60d6002b,0x69c1330e,0xed550063,0x00000000}},	//   ydym, _uple, ּבָר_,
  { {0x753d0163,0xd886005d,0x19ba009a,0x00000000}},	//   gosz, _فهمی, _למעב,
  { {0x6d5900ac,0x656400fe,0x4375012d,0x00000000}},	//   imwa, _viih, дуст,
  { {0x877a0063,0x2176030b,0x7d18013d,0x00000000}},	//   _האסי, зуар, évsz,
  { {0x6721330f,0x753d3310,0xa2ad0042,0x00000000}},	//   milj, bosz, _जार्,
  { {0x15fa0063,0x45fa0063,0x6b890ac3,0x00000000}},	//   _להצע, _להצג, _oweg,
  { {0x44260016,0x60d63311,0x9406005d,0x00000000}},	// [5660] _ão_, rdym, _روده,
  { {0x9f5f0014,0xc294005d,0x91f60044,0x00000000}},	//   órða_, _زیرب, _فأجا,
  { {0x42fb0063,0x02fb0063,0xc6920041,0x00000000}},	//   _ההיס, _הלימ, גאב_,
  { {0x61e10146,0xccf90051,0x67210050,0x00000000}},	//   ælle, _coś_, hilj,
  { {0x6721161b,0x2ef83312,0x8afd004c,0x00000000}},	//   kilj, _torf_, _zuři,
  { {0x69dc0014,0x6d5901c0,0x6b4d0046,0x00000000}},	//   _árek, amwa, túga,
  { {0x67210734,0x68f91f48,0xf2d3009a,0x00000000}},	//   dilj, _bowd, געו_,
  { {0x2d68003b,0x2d980003,0x8b660049,0x00000000}},	//   _eşec_, _ivre_, _فاطم,
  { {0x672100ea,0x6b89002b,0xed572099,0x00000000}},	//   filj, _gweg, _хот_,
  { {0x95ca107a,0x9f9b004d,0x47340002,0x00000000}},	//   бума_, _läßt_, ќнос,
  { {0x7ae8010a,0xd90f0088,0xe5350200,0x00000000}},	//   _indt, _зь_, день,
  { {0x29020db4,0x7afa3313,0xa9250014,0x00000000}},	//   ökad_, _hott, rkþá,
  { {0x6721017f,0x753d101d,0x69d5004c,0x00000000}},	//   bilj, rosz, _ázer,
  { {0x7afa024a,0x23650137,0x672100b2,0x00000000}},	//   _jott, ölj_, cilj,
  { {0x2d9c03d9,0x7afa3314,0x76bb0063,0x00000000}},	//   ável_, _mott, _המופ,
  { {0x7afa177d,0xd5b8008f,0xd2580054,0x00000000}},	//   _lott, mtā_, яця_,
  { {0x40340076,0x88bd0051,0xd5b8008f,0x00000000}},	// [5670] еетс, liśc, ltā_,
  { {0x7afa1976,0x42750c03,0xa283005d,0x00000000}},	//   _nott, _югос, _سیرو,
  { {0xd5b8003d,0x6b890051,0x4ea4000d,0x00000000}},	//   ntā_, _sweg, эрта,
  { {0xd5b8001c,0xb1b70022,0xfd470085,0x00000000}},	//   itā_, ążęc, чэзн,
  { {0x7afa0fdb,0x2d9800a8,0x6d593315,0x00000000}},	//   _bott, _evre_, rmwa,
  { {0xd5b8001c,0xb33b0058,0x7afa1130,0x00000000}},	//   ktā_, irço, _cott,
  { {0x7afa3316,0x68f900f6,0x67213317,0x00000000}},	//   _dott, _powd, vilj,
  { {0x290b0025,0x7ae806a5,0x2d813318,0x00000000}},	//   óca_, _endt, mphe_,
  { {0x2d9e00c7,0x6721007d,0x7afa0941,0x00000000}},	//   _åter_, tilj, _fott,
  { {0x6673007e,0x7afa028a,0x2d680058,0x00000000}},	//   رگتر, _gott, _iğer_,
  { {0xcb120063,0x67213319,0xddd5013d,0x00000000}},	//   _שלב_, rilj, _kezű,
  { {0x6721331a,0xc51a0085,0x36180085,0x00000000}},	//   silj, іўні_, яцыю_,
  { {0x224d004c,0xd5b8008f,0x37c7005e,0x00000000}},	//   řekl_, atā_, _хљеб,
  { {0xf62500e1,0x200c008f,0x88bd0022,0x00000000}},	//   _одло, _ādi_, biśc,
  { {0xc5d50086,0xc7b900ea,0x443e0051,0x00000000}},	//   _ціль, ltő_, łt_,
  { {0xdb02214f,0x2d9c004c,0xc5f20063,0x00000000}},	//   troë, ávem_, _ידו_,
  { {0xc7b900ea,0xdc3c0066,0xb33b0058,0x00000000}},	// [5680] ntő_, _páčk, orçl,
  { {0x3f800006,0xc579009a,0x8fa3231c,0x00000000}},	//   rpiu_, ַרְת, тафе,
  { {0x7afa331b,0x6917003b,0xdd8f0593,0x00000000}},	//   _rott, nţes, لول_,
  { {0x7afa02f6,0x0c260b3f,0x69dc0014,0x00000000}},	//   _sott, ммен, _árei,
  { {0x7afa331c,0xeb9701f6,0xc7b9013d,0x00000000}},	//   _pott, дич_, jtő_,
  { {0x63a60014,0xa3df0042,0x2417009a,0x00000000}},	//   irkn, णित_, וחנן_,
  { {0x2d6801f7,0xb4db00cd,0x7afa0014,0x00000000}},	//   _eğer_, noàc, _vott,
  { {0xa022005b,0xf1b30063,0xb9e30054,0x00000000}},	//   _şöyl, דסה_, тіши,
  { {0xb8d60235,0x99920051,0x88bd0051,0x00000000}},	//   _जा_, ódło_, wiśc,
  { {0x7ae80146,0x98c3008f,0x7afa0072,0x00000000}},	//   _undt, īvās_, _uott,
  { {0x63a6331d,0xda650044,0x1833005d,0x00000000}},	//   erkn, _كامي, فریح,
  { {0xd5b8001c,0x6b820d5f,0xdb020003,0x00000000}},	//   rtā_, opog, droé,
  { {0xd5b8001c,0x9405005d,0x534701a4,0x00000000}},	//   stā_, روسه, дхва,
  { {0x17540619,0xd703005a,0x2d8100c9,0x00000000}},	//   _явля, _изчи, yphe_,
  { {0x2caf0137,0x26cc331e,0x399a008f,0x00000000}},	//   yggd_, medo_, nīs_,
  { {0x26cc331f,0xa2bf0042,0x22580121,0x00000000}},	//   ledo_, _लॉर्, фисы_,
  { {0x6b8208ea,0xd1640062,0x9f553320,0x00000000}},	// [5690] jpog, търи, евач,
  { {0x6b8200c2,0xbdfb007e,0x9e15000d,0x00000000}},	//   dpog, يرضا_, ндзі,
  { {0xdb02006c,0x62953321,0xdbf90082,0x00000000}},	//   croé, mazo, ्न्ड_,
  { {0x399a001c,0x62953322,0xe087002a,0x00000000}},	//   dīs_, lazo, _تجدي,
  { {0xdcfe003d,0x0f7900b5,0x907a0063,0x00000000}},	//   espē, _מאָב, _מטרי,
  { {0x62950009,0x60cd0025,0x26cc3323,0x00000000}},	//   nazo, leam, jedo_,
  { {0x8d740044,0x00000000,0x00000000,0x00000000}},	//   _لاقا,   ,   ,
  { {0xc7b900ea,0x60cd3324,0x35a80053,0x00000000}},	//   ttő_, neam, _कमज़,
  { {0x62953325,0x7d0400fe,0x20040058,0x00000000}},	//   kazo, öise, _ümit_,
  { {0x60cd0025,0xdb2500fe,0xe619015a,0x00000000}},	//   heam, äpäi, здо_,
  { {0x69de0137,0x60cd0072,0x69dc00c2,0x00000000}},	//   åpet, keam, _šrev,
  { {0x03a63326,0x58b80044,0x17fb0044,0x00000000}},	//   нимо, _يانج_, _ورشة_,
  { {0xe72e04bb,0x6d4b3327,0x26cc28dc,0x00000000}},	//   _бе_, ilga, bedo_,
  { {0x629500ea,0xb606008b,0xdb0b00b9,0x00000000}},	//   gazo, _khở, btgå,
  { {0xa18a011c,0xa50a0d4c,0xc15601ce,0x00000000}},	//   ябва_, _нека_, ењањ,
  { {0x644100bd,0x6b823328,0x61e1000e,0x00000000}},	//   ßlic, ypog, ælla,
  { {0x446602a1,0x8fa31410,0x399a008f,0x00000000}},	// [56a0] _явив, лате, zīs_,
  { {0x6441005b,0x6d4b01dc,0x5f4601f3,0x00000000}},	//   şlic, elga, رنال,
  { {0x02b70063,0x93250021,0x7bde001c,0x00000000}},	//   _אליך_, _جرين, āpum,
  { {0xe5720047,0x60cd0dcf,0xc8ae0042,0x00000000}},	//   אַס_, ceam, _टाइट,
  { {0x10160032,0x26cc1167,0x29d13329,0x00000000}},	//   _أبجد, yedo_, _aša_,
  { {0x399a001c,0x6d4b332a,0xdcfe008f,0x00000000}},	//   tīs_, alga, tspē,
  { {0x6b82332b,0x26cc332c,0x58d405ac,0x00000000}},	//   spog, vedo_, войт,
  { {0xa96706b3,0xb9c30021,0xdb020003,0x00000000}},	//   нија_, اقيي, croî,
  { {0x399a001c,0xeab20021,0xdca30062,0x00000000}},	//   sīs_, _معا_, _щати,
  { {0x26cc006d,0xb33b005b,0x68e7001c,0x00000000}},	//   uedo_, nuçt, ējda,
  { {0x26cc332d,0x99e90021,0x1a9b0041,0x00000000}},	//   redo_, _يعمق_, _זיבע,
  { {0x26cc0198,0x2ca00025,0xdb0b0137,0x00000000}},	//   sedo_, óidh_, rtgå,
  { {0x04670076,0x26cc332e,0x60cd004b,0x00000000}},	//   этом, pedo_, veam,
  { {0x6d42004b,0x66e3005e,0xa5c6013d,0x00000000}},	//   hooa, _боља, _adóű,
  { {0x60cd332f,0x62950d6d,0x6d4b28de,0x00000000}},	//   team, razo, ylga,
  { {0x62950080,0xdddc16fe,0xd0d40062,0x00000000}},	//   sazo, _berž, лосъ,
  { {0x60cd1f7a,0x62953330,0x4ea7030b,0x00000000}},	// [56b0] ream, pazo, ереа,
  { {0x69c83331,0xdb1b005b,0x60cd3332,0x00000000}},	//   _opde, _ipuç, seam,
  { {0x60cd3333,0xb255005e,0x3946013d,0x00000000}},	//   peam, _шкољ, _okos_,
  { {0x764a001f,0xc19a0063,0xeb090042,0x00000000}},	//   _myfy, _קשרי, वस्त_,
  { {0x4ea7018e,0x63bd3334,0x90980062,0x00000000}},	//   _прва, ntsn, _явят_,
  { {0x9f35019d,0xfe7003eb,0x5d850021,0x00000000}},	//   _регі, _هدف_, _للسل,
  { {0x9f340086,0x8f340086,0x6b4400cd,0x00000000}},	//   _сері, _серц, tògr,
  { {0x47c5012c,0x69a20082,0x00000000,0x00000000}},	//   вбив, _गिरी,   ,
  { {0x63af007d,0xe7b20021,0xb33b0058,0x00000000}},	//   jucn, لميد, nuçs,
  { {0x88bd0051,0x63af007d,0x55e51567,0x00000000}},	//   ciśn, ducn, вооб,
  { {0x764a001f,0xc98406da,0xc8b3005d,0x00000000}},	//   _cyfy, _бучи, _ملاک,
  { {0x2f0400c7,0x764a001f,0x2d47017d,0x00000000}},	//   _högt_, _dyfy, mões_,
  { {0x63af017f,0x2d47017d,0x394d06a5,0x00000000}},	//   gucn, lões_, mles_,
  { {0x394d3335,0x764a001f,0x93430121,0x00000000}},	//   lles_, _fyfy, иняе,
  { {0x63bd006f,0x764a001f,0x320c0114,0x00000000}},	//   atsn, _gyfy, ády_,
  { {0xdddc00eb,0x8afc0051,0x63af003b,0x00000000}},	//   _perž, _pięk, bucn,
  { {0x2d47017d,0x7524005b,0x394d2652,0x00000000}},	// [56c0] hões_, _imiz, iles_,
  { {0xdddc0ed9,0x394d004d,0xceea0085,0x00000000}},	//   _verž, hles_, ьдзе_,
  { {0x8afc0045,0x394d0acf,0xdce0003b,0x00000000}},	//   _więk, kles_, _nimă,
  { {0xb4db00cd,0x6da32544,0x2d47017d,0x00000000}},	//   slàv, рица, dões_,
  { {0xdd0c0051,0x2f040026,0x8c430085,0x00000000}},	//   _półn, _sögu_, аеце,
  { {0x394d3336,0xf9c60156,0xda34000d,0x00000000}},	//   eles_, вщин, лелы,
  { {0x2d47017d,0x6c860021,0xada602d8,0x00000000}},	//   gões_, _للأم, _јабл,
  { {0x3cff0003,0x394d13bb,0x28c20042,0x00000000}},	//   _gouv_, gles_, _वॉशि,
  { {0x29180006,0xab663337,0x9947009b,0x00000000}},	//   ėra_, _авал, خليل_,
  { {0x394d3338,0x75240016,0x7d003339,0x00000000}},	//   ales_, _amiz, _homs,
  { {0xe5b40088,0xceb301f9,0x2d47017d,0x00000000}},	//   ыйны, בית_, cões_,
  { {0x63bd080f,0x394d10c5,0x7d0004aa,0x00000000}},	//   ttsn, cles_, _joms,
  { {0xb8f6016a,0x7d0018cd,0x39440006,0x00000000}},	//   ाज_, _moms, moms_,
  { {0x27e61269,0x63bd1c2d,0x629a00f8,0x00000000}},	//   _iron_, rtsn, ótop,
  { {0x57570063,0xa3e30053,0x46a30141,0x00000000}},	//   _שבוע_, _नज़र_, _тајв,
  { {0x26dc00ca,0xc60e0042,0x3944333a,0x00000000}},	//   _havo_, ानीय_, noms_,
  { {0x2d470016,0x3f9b0164,0x93470021,0x00000000}},	// [56d0] zões_, usqu_, _لخدم,
  { {0x3f9b0164,0x61e10137,0xdb1b0003,0x00000000}},	//   rsqu_, ålls, _equê,
  { {0x8d74043b,0x395f00eb,0x78a20024,0x00000000}},	//   لانا, ymus_, _odov,
  { {0x3944276c,0x7c87005e,0x7d00333b,0x00000000}},	//   joms_, туже, _coms,
  { {0x21292f2b,0xcac90002,0x3944333c,0x00000000}},	//   miah_, егле_, doms_,
  { {0x2d470016,0x2129333d,0x60dd333e,0x00000000}},	//   tões_, liah_, _hasm,
  { {0x394d333f,0xceb20063,0x27e63340,0x00000000}},	//   tles_, _לים_, _aron_,
  { {0x2d470016,0xdb020026,0x394d3341,0x00000000}},	//   rões_, stoð, ules_,
  { {0x20090e53,0x2d470016,0x7cd40051,0x00000000}},	//   nyai_, sões_, _wśró,
  { {0x26dc051e,0x395f3342,0x79a73343,0x00000000}},	//   _cavo_, smus_, _арде,
  { {0x88bd0045,0x6d5b0089,0x21292528,0x00000000}},	//   liśm, _khua, kiah_,
  { {0x9f4000ac,0x27e6002b,0x60dd0d6d,0x00000000}},	//   tvië_, _fron_, _nasm,
  { {0x2129053b,0x673200ea,0xef280058,0x00000000}},	//   diah_, ódjá, lmüş_,
  { {0x26dc0006,0x290d00fe,0x9f40006f,0x00000000}},	//   _gavo_, lkea_, rvië_,
  { {0x21290360,0x6d493344,0xef280058,0x00000000}},	//   fiah_, _okea, nmüş_,
  { {0xdd00001c,0xdff60085,0xf1a904a0,0x00000000}},	//   ītīb, лязь, ضافه_,
  { {0x7d003345,0x68fb0035,0x2f1600b9,0x00000000}},	// [56e0] _roms, ijud, _læge_,
  { {0x7d003346,0x68fb004b,0x1fb50141,0x00000000}},	//   _soms, hjud, јстр,
  { {0x6d5b0027,0x290d00fe,0xb4db00cd,0x00000000}},	//   _bhua, kkea_, clàs,
  { {0x6d5b018d,0x672800c2,0xae590054,0x00000000}},	//   _chua, zidj, трує_,
  { {0x5b260088,0xda7a0088,0xac9703eb,0x00000000}},	//   лька, няй_, انها_,
  { {0x9e66005d,0xb9b40021,0xbb430092,0x00000000}},	//   _مازن, لمتع, бечк,
  { {0x2fc01b58,0x60dd3347,0x6d5b0025,0x00000000}},	//   ltig_, _yasm, _fhua,
  { {0x26dc0812,0x3eb2000c,0x60c43348,0x00000000}},	//   _savo_, şată_, nfim,
  { {0x2fc03349,0x0ab60021,0xabaa007e,0x00000000}},	//   ntig_, _محاد, _سهام_,
  { {0x2fc000bd,0x21291880,0xf77f017d,0x00000000}},	//   itig_, ziah_, íça_,
  { {0x68fb01e3,0x644d003e,0xceb30063,0x00000000}},	//   bjud, _syai, זית_,
  { {0x2fc0334a,0xdcfe0006,0x2ed10053,0x00000000}},	//   ktig_, rspė, _हस्त,
  { {0x60dd058c,0x26dc0006,0x661a12a6,0x00000000}},	//   _rasm, _tavo_, sztk,
  { {0x3dc60051,0x59b80053,0x69da1018,0x00000000}},	//   łowy_, _इमार, _kste,
  { {0x2fc000e8,0x60dd334b,0x656d334c,0x00000000}},	//   etig_, _pasm, _tiah,
  { {0xdb0b0146,0xdbd10019,0x2fc015e8,0x00000000}},	//   stgø, _püüa, ftig_,
  { {0x2eab0138,0x200f000f,0x212931ba,0x00000000}},	// [56f0] ењен_, ági_, riah_,
  { {0x21291852,0x69da334d,0x6d5b334e,0x00000000}},	//   siah_, _oste, _shua,
  { {0x212900f3,0x69da006f,0x74bc0042,0x00000000}},	//   piah_, _nste, ष्कृ,
  { {0xdd94000d,0x6e64082d,0xa15901ce,0x00000000}},	//   сацы, стуж, _јаму_,
  { {0xec780086,0x5bc40021,0x2ba7005e,0x00000000}},	//   упі_, متوف, ујев,
  { {0x3f89334f,0x637c0063,0x8a05263d,0x00000000}},	//   mpau_, תנגד, изле,
  { {0xf2d400b5,0x6d5b0027,0xd2b80063,0x00000000}},	//   מעס_, _thua, אלות_,
  { {0x68fb0089,0x290d0072,0xef280058,0x00000000}},	//   ujud, ukea_, rmüş_,
  { {0xf7190088,0x290d00fe,0x69da1292,0x00000000}},	//   віны_, rkea_, _este,
  { {0xd7090076,0x290d00fe,0x36690131,0x00000000}},	//   тное_, skea_, капо_,
  { {0xdce916ff,0x60c40014,0x5ee80063,0x00000000}},	//   _lieč, yfim, אַרְ,
  { {0xcdb6009a,0xa87b00de,0x00000000,0x00000000}},	//   ספרה_, _أحضر_,   ,
  { {0xd456005a,0xdce90024,0x9cd60063,0x00000000}},	//   ртнь, _nieč, בורה_,
  { {0x69da3350,0x00000000,0x00000000,0x00000000}},	//   _yste,   ,   ,
  { {0xdb1b004b,0xe2973351,0xd5e8013a,0x00000000}},	//   _usuõ, рас_, _معين_,
  { {0x7bdb00fe,0x387f227c,0x2fc03352,0x00000000}},	//   _osuu, ncur_, ttig_,
  { {0x2fc000bd,0x60c40405,0x4f26000d,0x00000000}},	// [5700] utig_, rfim, адаб,
  { {0xbda60021,0x27220013,0x387f0139,0x00000000}},	//   لحصو, rưng_, hcur_,
  { {0x2fc03353,0x629c3354,0x8afc056c,0x00000000}},	//   stig_, maro, _mięt,
  { {0x629c3355,0x69da004d,0xad6501fb,0x00000000}},	//   laro, _rste, مانه,
  { {0x1d07005e,0xab770044,0x3f540244,0x00000000}},	//   јечи_, لمنا_, läum_,
  { {0x39a614cf,0x629c3356,0x2d9c01d9,0x00000000}},	//   ашив, naro, áves_,
  { {0xc9a70002,0x6b4d0014,0x6da31dd0,0x00000000}},	//   авје_, júgu, _мира,
  { {0x4ddb0063,0x27c60054,0x629c2466,0x00000000}},	//   _בחלו, ащог, haro,
  { {0x629c3357,0x9f4000cd,0xc60e0053,0x00000000}},	//   karo, nviï_, ान्य_,
  { {0xa9a6011c,0x629c3358,0x636000ea,0x00000000}},	//   _вижд, jaro, lönf,
  { {0x69da3359,0x0f57014e,0x629c335a,0x00000000}},	//   _uste, שיים_, daro,
  { {0xd7e60086,0x48660062,0x62970877,0x00000000}},	//   _віко, _кълб, _sexo,
  { {0x629c0035,0x7bc2335b,0x93b40085,0x00000000}},	//   faro, ntou, обяц,
  { {0x629c335c,0xdce908b7,0xe6940044,0x00000000}},	//   garo, _rieč, _الثد,
  { {0x01270002,0x533410ae,0xa75b009a,0x00000000}},	//   аќам, церт, _שדור,
  { {0x629c0173,0x7bc20509,0x2075000d,0x00000000}},	//   aaro, ktou, слаў,
  { {0x629c335d,0x7b320022,0x3e870021,0x00000000}},	// [5710] baro, ołud, لشاف,
  { {0x629c335e,0x8afc0051,0x02a7335f,0x00000000}},	//   caro, _mięs, _трим,
  { {0xdcfc001c,0x7bc2123c,0xa3df0042,0x00000000}},	//   _strā, etou, णिक_,
  { {0xc57900b5,0xdb0b006d,0xee380054,0x00000000}},	//   אָסט, rugí, шнє_,
  { {0x2bda0235,0xd0f6009a,0x00f6009a,0x00000000}},	//   _मैदा, _המרת_, _הזרם_,
  { {0x73d8009a,0xdf44014b,0x00000000,0x00000000}},	//   שֵׁב_, _дэсп,   ,
  { {0x29d80013,0x49980085,0x6d580078,0x00000000}},	//   _cũa_, атыя_, įvar,
  { {0x629c3360,0xf77f017d,0x97c50021,0x00000000}},	//   zaro, íço_, مقبو,
  { {0x8afc0051,0x7c240139,0x387f00dd,0x00000000}},	//   _pięt, úirt, rcur_,
  { {0x46f50076,0x387f3361,0x6917003b,0x00000000}},	//   счит, scur_, nţez,
  { {0x629c3362,0xa37b004b,0x6d5e0022,0x00000000}},	//   varo, svõl, łzał,
  { {0x7ae13363,0x25aa1a34,0x94060044,0x00000000}},	//   _halt, ábla_, موجه,
  { {0x629c0ac6,0x4424008b,0x7ae13364,0x00000000}},	//   taro, àm_, _kalt,
  { {0x4463005a,0xf6790047,0x6610013d,0x00000000}},	//   явяв, _גאַמ, ökké,
  { {0x7b320045,0x629c3365,0x69c33366,0x00000000}},	//   sług, raro, ntne,
  { {0xd1320021,0x629c3367,0x7bc2033b,0x00000000}},	//   أمر_, saro, ytou,
  { {0x29c1008b,0xdce00078,0x629c3368,0x00000000}},	// [5720] hóa_, _gimę, paro,
  { {0x1ea90021,0x93fb0063,0xdcfc003b,0x00000000}},	//   لامي_, _עליי, _otră,
  { {0x61461111,0x69c30077,0x8365009b,0x00000000}},	//   _гена, jtne, _بديل,
  { {0x63a431c8,0x7bc20072,0x63600014,0x00000000}},	//   _kvin, ttou, föng,
  { {0x5c970088,0xdcfc003b,0x63600014,0x00000000}},	//   скія_, _atră, göng,
  { {0x7bc23369,0x7ae1336a,0x5f060349,0x00000000}},	//   rtou, _calt, _узга,
  { {0x853d0006,0x7bc2336b,0xf2d30063,0x00000000}},	//   orėt, stou, פעה_,
  { {0x61e100b9,0x7c240139,0x6360336c,0x00000000}},	//   ælli, úirs, lönd,
  { {0x7ae1100f,0x7d0d0072,0x69c3336d,0x00000000}},	//   _falt, öase, atne,
  { {0x7ae1336e,0xd6da336f,0x64410058,0x00000000}},	//   _galt, ути_, şlik,
  { {0x86260088,0x63a43370,0x69c300e5,0x00000000}},	//   сьпе, _avin, ctne,
  { {0x2d73007d,0x7ae100a8,0x7b320022,0x00000000}},	//   _kćer_, _zalt, słud,
  { {0x443f017d,0xf7463371,0x84340054,0x00000000}},	//   çu_, _ледо, зняє,
  { {0x65940088,0xdc3700b5,0x63a9073c,0x00000000}},	//   _даку, מאכט_, šeno,
  { {0x63a43372,0x2bda0082,0x1757009d,0x00000000}},	//   _evin, _मैसा, _הסגר_,
  { {0x86370063,0x4155000d,0x60d63373,0x00000000}},	//   _לרוב_, івас, geym,
  { {0x6e99000a,0x752f0051,0x63a43374,0x00000000}},	// [5730] ивар_, micz, _gvin,
  { {0x752f0045,0x69c30240,0x1eab0044,0x00000000}},	//   licz, ytne, طائي_,
  { {0xf3cb006a,0x2d87006f,0x69c30137,0x00000000}},	//   _شبکه_, ëne_, xtne,
  { {0x752f0045,0x7ae10419,0x6aa8002b,0x00000000}},	//   nicz, _salt, _addf,
  { {0xdcfc000c,0x7b320022,0x7ae13375,0x00000000}},	//   _stră, dłub, _palt,
  { {0x539c0149,0x69c33376,0x752f0022,0x00000000}},	//   ניוו, ttne, hicz,
  { {0x20120024,0x7ae13377,0x63600014,0x00000000}},	//   čniť_, _valt, söng,
  { {0x98bf003b,0x2bd9007e,0xe7a9123e,0x00000000}},	//   două_, _پارک_, авил_,
  { {0x6d4b3378,0x69c314d5,0x7ae114e3,0x00000000}},	//   moga, stne, _talt,
  { {0x6d4b3379,0x3f840003,0xe739002b,0x00000000}},	//   loga, _émue_, grŵp_,
  { {0x752f0045,0xceb211b4,0x63a4337a,0x00000000}},	//   ficz, ויי_, _svin,
  { {0x752f0051,0x628500b9,0x6d4b337b,0x00000000}},	//   gicz, _afho, noga,
  { {0xe72e0619,0x636000bd,0x78bb001c,0x00000000}},	//   _же_, höne, mguv,
  { {0x6d4b337c,0xdb02017d,0xe2970786,0x00000000}},	//   hoga, rroç, жар_,
  { {0x60d60026,0x6d4b337d,0x7d040072,0x00000000}},	//   teym, koga, öisk,
  { {0x853d0006,0x78bb23d4,0x63a402ad,0x00000000}},	//   urėt, nguv, _tvin,
  { {0x1016000d,0x63a4003b,0x60d6337e,0x00000000}},	// [5740] цьвя, _uvin, reym,
  { {0x27e20026,0x2f560085,0x7e560129,0x00000000}},	//   ækni_, ітас, отец,
  { {0x6d4b2cdf,0x98a4000c,0x6b89337f,0x00000000}},	//   foga, nimă_, _ateg,
  { {0xf09f001b,0xa3ce0053,0x63600137,0x00000000}},	//   _hoàn_, _रहा_, sönd,
  { {0x653b0047,0xdb1b1358,0x5c030456,0x00000000}},	//   סענד, _equí, дяща,
  { {0x6360000f,0x752f0022,0x7f190054,0x00000000}},	//   lönb, zicz, _лісу_,
  { {0xddc30138,0x8ad5000d,0x66df0078,0x00000000}},	//   _обри, яюцц, iškė,
  { {0x2cba007e,0x984f005b,0xdce200c2,0x00000000}},	//   _خُرد_, _ağır_, omoč,
  { {0x8afc0051,0xdce60078,0x2d98002b,0x00000000}},	//   _chęc, _ūmėd, _hwre_,
  { {0xe5c60055,0x15ea0086,0x752f0051,0x00000000}},	//   осмо, аємо_, wicz,
  { {0x6d433380,0x69c4003b,0x672f0066,0x00000000}},	//   énag, ăies, _žijú,
  { {0x7d023381,0x3ce61c25,0x7c221b9e,0x00000000}},	//   njos, ndov_, ozor,
  { {0xdce200c2,0x7c223382,0xe947005d,0x00000000}},	//   jmoč, nzor, _برلی,
  { {0x672a0026,0x78a03383,0xc34b130d,0x00000000}},	//   _umfj, lamv, ряме_,
  { {0x7d02003d,0x398301f7,0x853d0078,0x00000000}},	//   kjos, _kısa_, urės,
  { {0x2eed000c,0x98a600c2,0xa98b009a,0x00000000}},	//   _şef_, _omoč_, יָמִ,
  { {0x6d4b0016,0x39a5001c,0xa37b004b,0x00000000}},	// [5750] voga, zēs_, kvõi,
  { {0x7c221228,0x7d020078,0x6d4b002b,0x00000000}},	//   dzor, ejos, woga,
  { {0x6d4b3384,0x6b893385,0x7c223386,0x00000000}},	//   toga, _steg, ezor,
  { {0xdce200c2,0x6f070051,0x6d4b005f,0x00000000}},	//   bmoč, _wojc, uoga,
  { {0x8c450002,0x6d4b3387,0x2bbb0021,0x00000000}},	//   џеле, roga, شاشة_,
  { {0x673a006f,0x31690f99,0x39a5001c,0x00000000}},	//   jntj, lmaz_, tēs_,
  { {0x98a4000c,0x3ea1004b,0xdd91002a,0x00000000}},	//   ximă_, maht_, _سوء_,
  { {0x39a5001c,0x3169005b,0x673a00ca,0x00000000}},	//   rēs_, nmaz_, entj,
  { {0x63a9055e,0x39a5001c,0x6b8900c2,0x00000000}},	//   šenj, sēs_, _uteg,
  { {0x1dd20053,0x98a4003b,0x7d090717,0x00000000}},	//   _सहमत, timă_, _hoes,
  { {0x9f40017d,0x7b320051,0xceb20047,0x00000000}},	//   nviá_, słuc, עיט_,
  { {0x04463147,0x36180085,0x4a5a009a,0x00000000}},	//   земн, юцыю_, _הדעו,
  { {0x7d093388,0x27e90025,0x4393000d,0x00000000}},	//   _moes, _éan_, наўс,
  { {0x7d1b001f,0x3ce600c2,0x877a0041,0x00000000}},	//   _llus, zdov_, _פאצי,
  { {0x60cf02dd,0x62630160,0xe2a70014,0x00000000}},	//   _bbcm, евра, íðar_,
  { {0x0446005a,0x64430051,0x394d01c6,0x00000000}},	//   _нейн, _śnie, noes_,
  { {0x94bb014e,0xf09f001b,0x6564002c,0x00000000}},	// [5760] _המפת, _toàn_, _ihih,
  { {0x7d1b0449,0x8c3d005b,0x394d3389,0x00000000}},	//   _alus, _keşf, hoes_,
  { {0xee3a0001,0x98a40078,0x7d09338a,0x00000000}},	//   љне_, limą_, _boes,
  { {0xdb1b00cd,0x2d870e7c,0x4c6a0002,0x00000000}},	//   _aquà, ínea_, биен_,
  { {0x98a400eb,0x629e014f,0x7d090706,0x00000000}},	//   nimą_, _kepo, _does,
  { {0x63a6338b,0x7c22338c,0x7d1b338d,0x00000000}},	//   iskn, rzor, _elus,
  { {0x7c2200ea,0x394d001f,0x65640150,0x00000000}},	//   szor, foes_, _ohih,
  { {0xa37b0019,0x58860088,0x98a40006,0x00000000}},	//   svõi, чыка, kimą_,
  { {0x98a400eb,0x6d400089,0xeb972099,0x00000000}},	//   jimą_, _ijma, _нит_,
  { {0x752d0080,0x98a40006,0x63a60618,0x00000000}},	//   _smaz, dimą_, dskn,
  { {0xa4d90138,0x2720001b,0x31690058,0x00000000}},	//   одну_, _lòng_, ymaz_,
  { {0xe995007e,0x394d017d,0x6564338e,0x00000000}},	//   _آهنگ, coes_, _chih,
  { {0x399a0006,0x98a40006,0x27200013,0x00000000}},	//   lūs_, gimą_, _nòng_,
  { {0x26c2005f,0x7c2d0046,0xcb8b009a,0x00000000}},	//   đkos_, úari, מְלֹ,
  { {0x65880080,0x629e338f,0x2d5c006d,0x00000000}},	//   _běhe, _depo, víen_,
  { {0xe63b0063,0x25d70047,0x55bb0063,0x00000000}},	//   _לתוכ, _זוהן_, _המהו,
  { {0xc05b019d,0x224d0051,0x24890331,0x00000000}},	// [5770] сів_, łek_, _ifam_,
  { {0x3169003d,0x629e0007,0x2720001b,0x00000000}},	//   smaz_, _gepo, _dòng_,
  { {0x7d1b3390,0x7d093391,0x753d3392,0x00000000}},	//   _plus, _poes, onsz,
  { {0x399a0078,0x31350085,0xdb0b0244,0x00000000}},	//   dūs_, _цемр, zugä,
  { {0xaf37006a,0xed580086,0xdb1b017d,0x00000000}},	//   _فرست, чої_, _aquá,
  { {0x7d090983,0x60cd3393,0x62870022,0x00000000}},	//   _woes, lfam, ncjo,
  { {0xe9d9019d,0x7d090102,0x2fc93394,0x00000000}},	//   іки_, _toes, ltag_,
  { {0x7d1b01f7,0x63a60acd,0x60cd3395,0x00000000}},	//   _ulus, yskn, nfam,
  { {0x2fc93396,0x62870022,0xab390054,0x00000000}},	//   ntag_, kcjo, _дпау_,
  { {0x05a90055,0x98a400eb,0x399a001c,0x00000000}},	//   овой_, vimą_, būs_,
  { {0xdb26007e,0x6aa33397,0xdbd70072,0x00000000}},	//   _تولی, manf, säät,
  { {0x98a40006,0x629e3398,0x6aa3001f,0x00000000}},	//   timą_, _sepo, lanf,
  { {0x3e7c0080,0x629e17e5,0xe3b20021,0x00000000}},	//   nští_, _pepo, خرج_,
  { {0x2fc90146,0x6aa33399,0x98a40006,0x00000000}},	//   dtag_, nanf, rimą_,
  { {0xa50a0ae8,0x27200013,0x27ed339a,0x00000000}},	//   _мека_, _sòng_, lven_,
  { {0x4f96000a,0x27ed0b28,0x98a40006,0x00000000}},	//   држу, oven_, pimą_,
  { {0x8fa304e3,0x3e7c004c,0x1fb50896,0x00000000}},	// [5780] кате, jští_, есхр,
  { {0x2720001b,0x27ed28b0,0xdfcf01fb,0x00000000}},	//   _vòng_, iven_, شيم_,
  { {0x6aa3339b,0x6ce60086,0x60cd3040,0x00000000}},	//   danf, діле, bfam,
  { {0x68e900b9,0x399a0006,0x27200013,0x00000000}},	//   jded, vūs_, _tòng_,
  { {0x27ed02b0,0x68e9339c,0xdb1b0331,0x00000000}},	//   jven_, dded, _apuñ,
  { {0x6aa30333,0x399a0078,0x6d59339d,0x00000000}},	//   ganf, tūs_, alwa,
  { {0x27ed0122,0x999e0006,0x2966005e,0x00000000}},	//   even_, _rytų_, мњив,
  { {0xa96700e1,0x63a9339e,0x68e900a4,0x00000000}},	//   мија_, šeni, gded,
  { {0x399a0078,0xa7140054,0x00000000,0x00000000}},	//   sūs_, емпі,   ,
  { {0x9781006a,0x291d001f,0x55940002,0x00000000}},	//   دیوه, _elwa_, наоѓ,
  { {0x290200c7,0x60cd339f,0x27ed33a0,0x00000000}},	//   ökas_, yfam, aven_,
  { {0x249f0014,0x9f400072,0x60cd01db,0x00000000}},	//   úum_, lviä_, xfam,
  { {0x7a130080,0x69ca11ad,0x88160044,0x00000000}},	//   _větš, ltfe, _تباط,
  { {0x2d5500b9,0xbcfd008b,0xdb0b0137,0x00000000}},	//   lået_, _nhũn, stgö,
  { {0x6d590cc4,0x8c3d003b,0x9f400072,0x00000000}},	//   ylwa, _ieşe, iviä_,
  { {0x2d550146,0xd0d40062,0x2fc90e77,0x00000000}},	//   nået_, косъ, ttag_,
  { {0x4034184a,0x7afa0438,0x63600014,0x00000000}},	// [5790] ветс, _ontt, mönn,
  { {0x6d59006f,0x63bd33a1,0x69ca2545,0x00000000}},	//   wlwa, musn, ktfe,
  { {0x7cd903d6,0x200f0019,0x68e933a2,0x00000000}},	//   змер_, ägib_, yded,
  { {0x2fc90146,0xdd94000d,0xf53f00d1,0x00000000}},	//   ptag_, тацы, nnå_,
  { {0x68e900b9,0x3e7c004c,0xeb992977,0x00000000}},	//   vded, uští_, чил_,
  { {0x317900ea,0x63600014,0xdcf5003b,0x00000000}},	//   _hisz_, hönn, _buză,
  { {0xfaa6005d,0x6aa333a3,0xe9d101f3,0x00000000}},	//   رجوی, ranf, اغت_,
  { {0x2d5500b9,0x7d0400fe,0x63bd16ed,0x00000000}},	//   gået_, öist, kusn,
  { {0x68e933a4,0x6b8000a4,0x69ca00d1,0x00000000}},	//   rded, _gumg, atfe,
  { {0x27ed2909,0x63bd01cd,0x29020137,0x00000000}},	//   rven_, dusn, ökar_,
  { {0x8c3d003b,0x67210014,0xd8790044,0x00000000}},	//   _deşe, rhlj, _فمات_,
  { {0x89960063,0x6aa126d3,0x64430022,0x00000000}},	//   _נכנס_, _helf, _śnia,
  { {0x2d9c06b2,0x97d80032,0x7455005a,0x00000000}},	//   ávez_, _يظهر_, върх,
  { {0xe9ff001b,0xaa810014,0x2d5c01a8,0x00000000}},	//   _giảm_, _þýdd, víem_,
  { {0x76580078,0xc5d50054,0xe4eb0042,0x00000000}},	//   _gyvy, _чіль, _जोकि_,
  { {0xc57a0063,0xdbd701cf,0xc0e333a5,0x00000000}},	//   _צרפת, _kääp, лоск,
  { {0x9f4000fe,0x79810474,0x6f6625a6,0x00000000}},	// [57a0] yviä_, _lulw, еваз,
  { {0xe9e5001b,0x2d5c00cd,0xceea000d,0x00000000}},	//   _đúng_, ríem_, ядзе_,
  { {0x2d9c0164,0x69ca00bd,0x387d001f,0x00000000}},	//   ève_, xtfe, _ogwr_,
  { {0x69150014,0x659a0041,0x1c460121,0x00000000}},	//   _fáei, פינק, ннем,
  { {0x2d550031,0xeb970121,0xa37b004b,0x00000000}},	//   vået_, еич_, lvõr,
  { {0x6aa10185,0x853d0006,0x69ca2713,0x00000000}},	//   _celf, gsėj, ttfe,
  { {0x2d5510c4,0x3f820035,0xdbd20019,0x00000000}},	//   tået_, _huku_, lüüt,
  { {0x2c570045,0x61230019,0x3f8233a6,0x00000000}},	//   _będą_, _võlg, _kuku_,
  { {0x6aa100ea,0xc7d7093e,0x7ae800a4,0x00000000}},	//   _felf, емых_, _tadt,
  { {0x61230019,0x6aa1001f,0x69ca33a7,0x00000000}},	//   _tõlg, _gelf, ptfe,
  { {0x613b00fe,0x3f822eab,0x9b170063,0x00000000}},	//   nälä, _luku_, _רחבה_,
  { {0x6aa102b0,0xdb0d0026,0x63bd33a8,0x00000000}},	//   _zelf, ákök, tusn,
  { {0x8c3d01f7,0x3f8233a9,0x5347089a,0x00000000}},	//   _teşe, _nuku_, ехва,
  { {0x61230019,0x63bd33aa,0x27e60072,0x00000000}},	//   _mõle, rusn, _ison_,
  { {0x63bd003e,0xf53f0666,0x3f8233ab,0x00000000}},	//   susn, pnå_, _auku_,
  { {0x3f8206a7,0x865b0063,0x365b0063,0x00000000}},	//   _buku_, _מדוי, _מכונ,
  { {0xb4dd0053,0x64a4005e,0xb9cb008d,0x00000000}},	// [57b0] ड़ी_, _сања, _bướ_,
  { {0x2007017f,0x3f8f001c,0xc43c0063,0x00000000}},	//   ćni_, īgu_, _מתחי,
  { {0xf09f008b,0x26de33ac,0x6123004b,0x00000000}},	//   _loài_, ieto_, _põld,
  { {0x6aa1021f,0xbd180086,0x63ad33ad,0x00000000}},	//   _self, нції_, _kvan,
  { {0x26de33ae,0xac840054,0xc7b9013d,0x00000000}},	//   keto_, угіл, rzők_,
  { {0x3ce900c3,0x5018018e,0x26de33af,0x00000000}},	//   žav_, _џорџ_, jeto_,
  { {0x2d852614,0x6aa106a5,0x7bcb33b0,0x00000000}},	//   _île_, _velf, stgu,
  { {0x63ad02eb,0x98750001,0x6123004b,0x00000000}},	//   _ovan, купљ, _hõlb,
  { {0x61230019,0x3ce0004b,0x2d832c7d,0x00000000}},	//   _kõlb, õive_, _huje_,
  { {0xdbd70072,0x46f50062,0x7b770021,0x00000000}},	//   _vääp, тчит, _أطرا,
  { {0x63ad16a6,0x8804005d,0xd62933b1,0x00000000}},	//   _avan, نظیم, фоне_,
  { {0x5a0a0047,0x2f160014,0xf9880044,0x00000000}},	//   _קלײַ, _vægi_, _أنني_,
  { {0x7784000d,0x290f021a,0x26de33b2,0x00000000}},	//   _бліз, _ioga_, beto_,
  { {0x26de33b3,0x9f4000ac,0x3f82147d,0x00000000}},	//   ceto_, rwië_, _ruku_,
  { {0x3f8233b4,0x290f027c,0x63ad33b5,0x00000000}},	//   _suku_, _koga_, _evan,
  { {0x21760001,0x68eb33b6,0xddc70051,0x00000000}},	//   ђувр, _jagd, _wyjś,
  { {0x68eb00bb,0x63ad007d,0x3fe60062,0x00000000}},	// [57c0] _magd, _gvan, ъжав,
  { {0x8afc0051,0x68eb1c59,0x7b320051,0x00000000}},	//   _więz, _lagd, tłum,
  { {0x63ad33b7,0x2d5500cf,0xdee32338,0x00000000}},	//   _zvan, våer_, рохи,
  { {0x68eb002c,0x61230019,0xe9ff008b,0x00000000}},	//   _nagd, _põle, _nhằm_,
  { {0x99410051,0x78a2004b,0x5c97000d,0x00000000}},	//   kół_, _reov, ткія_,
  { {0x7b1400cd,0x3b53000d,0x60c433b8,0x00000000}},	//   _nàut, акір, lgim,
  { {0x26de00fe,0x2d550829,0x68eb33b9,0x00000000}},	//   veto_, råer_, _bagd,
  { {0xdb0b017d,0x60c433ba,0xc2130063,0x00000000}},	//   nsgê, ngim, שהה_,
  { {0x68eb00bb,0xf803000d,0x26de33bb,0x00000000}},	//   _dagd, ачэн, teto_,
  { {0xd5b8001c,0x6726001c,0x0aea0054,0x00000000}},	//   trā_, īkjo, _ідей_,
  { {0x2fc00025,0x5ebb0063,0x78a20019,0x00000000}},	//   huig_, וזיק, _teov,
  { {0xb4dd0053,0x69da0150,0x68eb33bc,0x00000000}},	//   ड़े_, _ipte, _gagd,
  { {0x6d4200fe,0x26de33bd,0x38600139,0x00000000}},	//   inoa, peto_, _áir_,
  { {0x68e0005b,0x60c433be,0x2d8733bf,0x00000000}},	//   lemd, egim, ínek_,
  { {0x8c3d0058,0x290f33c0,0x20c7195f,0x00000000}},	//   _meşa, _yoga_, ксаг,
  { {0x60c40290,0x7415007e,0x68e0005b,0x00000000}},	//   ggim, _موبا, nemd,
  { {0x691c0164,0x4fc7005a,0x63ad33c1,0x00000000}},	// [57d0] _réel, ъсва, _uvan,
  { {0x4fc40d34,0x69da33c2,0x63a91a7e,0x00000000}},	//   јста, _opte, šens,
  { {0x394602dd,0x02a4000d,0xc7b900ea,0x00000000}},	//   _ojos_, _трым, rzői_,
  { {0x2fc000cd,0x463b0041,0xa3c70042,0x00000000}},	//   buig_, ועבע, _उमा_,
  { {0x8bc7000a,0x62800080,0x68e033c3,0x00000000}},	//   тсед, ěmov, demd,
  { {0x6b650088,0x68eb0d02,0x2d8300c2,0x00000000}},	//   ыкла, _sagd, _tuje_,
  { {0x68eb00bb,0x290f001c,0x8c3d00dd,0x00000000}},	//   _pagd, _poga_, _deşa,
  { {0x7c8700d7,0xa9662377,0x89d6007e,0x00000000}},	//   _јуве, лища_, اوير_,
  { {0x290f2069,0x9b880044,0x6eca0042,0x00000000}},	//   _voga_, _لنقل_, स्कु,
  { {0x06090121,0x245d013d,0x55e50154,0x00000000}},	//   енок_, zámú_, гооб,
  { {0x290f0117,0x68eb29d9,0x7c2b004d,0x00000000}},	//   _toga_, _tagd, lzgr,
  { {0x2f16007a,0xdcfc003d,0x04960085,0x00000000}},	//   _hægt_, _kurā, ыроў,
  { {0x99410051,0x7c2b004d,0x9f9b0072,0x00000000}},	//   pół_, nzgr, _jäät_,
  { {0x78a90019,0x3ced004b,0x638333c4,0x00000000}},	//   laev, _laev_, сгра,
  { {0x395f0019,0x321e004a,0x63600072,0x00000000}},	//   olus_, áty_, lönk,
  { {0x2fc00229,0x661c01f2,0xc095005e,0x00000000}},	//   tuig_, ørke, ишућ,
  { {0x75240035,0x6fa50021,0x80660a36,0x00000000}},	// [57e0] _iliz, لإلك, уваж,
  { {0xa2e6000a,0x26c532a7,0x636000ea,0x00000000}},	//   _соод, nglo_, zönj,
  { {0x629c33c5,0x7524007d,0x8f750086,0x00000000}},	//   mbro, _kliz, руті,
  { {0xe45f00c7,0xd00a0002,0x6d42003b,0x00000000}},	//   mför_, _земе_, unoa,
  { {0x395f0019,0xdb5a013c,0x6d4225f2,0x00000000}},	//   dlus_, нюк_, rnoa,
  { {0x629c33c6,0xbda601fb,0x395f0526,0x00000000}},	//   nbro, _محرو, elus_,
  { {0xfc3f007a,0xe45f00c7,0xe607006a,0x00000000}},	//   _þín_, nför_, _اش_,
  { {0x61230019,0x395f175c,0xdce2007d,0x00000000}},	//   _kõla, glus_, dmoć,
  { {0x629c00ca,0x68e033c7,0x58d70085,0x00000000}},	//   kbro, remd, удыя_,
  { {0x68e00026,0x75240035,0x395f0006,0x00000000}},	//   semd, _aliz, alus_,
  { {0x7524158e,0xcf570063,0x0f5701f9,0x00000000}},	//   _bliz, רבית_, ריים_,
  { {0xe45f0137,0xdb0b0137,0x629c2a4d,0x00000000}},	//   dför_, rrgå, ebro,
  { {0x7bc20034,0xb7960001,0x3866007d,0x00000000}},	//   nuou, _срећ, _uzor_,
  { {0xa01b00c7,0xd693005e,0x629c33c8,0x00000000}},	//   _oför, _лишћ, gbro,
  { {0x2d5c00cd,0x22590121,0x316b005e,0x00000000}},	//   líeu_, тивы_, ешао_,
  { {0x6aaa33c9,0x6360004d,0xaffd0054,0x00000000}},	//   haff, hönh, мобi,
  { {0x6aaa023a,0xcebb0001,0x656d00a4,0x00000000}},	// [57f0] kaff, еље_, _ihah,
  { {0x7bc200e5,0x78a90058,0xaa9e0085,0x00000000}},	//   duou, zaev, _дзiў,
  { {0x6aaa0150,0x395f33ca,0xc7b9013d,0x00000000}},	//   daff, ylus_, lzőt_,
  { {0x2cd50121,0x7c2b33cb,0x1d09005e,0x00000000}},	//   рждё, tzgr, ђели_,
  { {0xd7e60032,0x7bc200e5,0xaca8007e,0x00000000}},	//   _بك_, guou, اههٔ_,
  { {0x645a0529,0xff07000d,0x661a0072,0x00000000}},	//   ştig, _сямн, kytk,
  { {0x395f0004,0xaa49005a,0x2f1600b9,0x00000000}},	//   tlus_, ъпка_, _vægt_,
  { {0x63bd017f,0x395f0150,0xc27c0047,0x00000000}},	//   krsn, ulus_, ערהי,
  { {0x31580047,0x7bc200e5,0x395f33cc,0x00000000}},	//   װיזן_, cuou, rlus_,
  { {0x6aaa08cd,0xdb19004d,0x395f17a7,0x00000000}},	//   caff, ntwü, slus_,
  { {0x49b8007e,0xd5b8001c,0x629c0415,0x00000000}},	//   _ماند_, dzās_, vbro,
  { {0x7ae333cd,0x9582000d,0x2d5c00cd,0x00000000}},	//   lent, ўляе, bíeu_,
  { {0x656d0035,0x7b0400ea,0x63600137,0x00000000}},	//   _dhah, _átté, löni,
  { {0xe45f00c7,0x7ae333ce,0x68440086,0x00000000}},	//   tför_, nent, _уніа,
  { {0x7ae32319,0x629c33cf,0xdcfc003b,0x00000000}},	//   ient, rbro, _jură,
  { {0xe45f01e3,0x75240035,0x629c0610,0x00000000}},	//   rför_, _uliz, sbro,

  { {0x9325006a,0x7ae333d0,0x629c09fe,0x00000000}},	// [5800] _گرين, kent, pbro,
  { {0x13030088,0x61230019,0x7ae333d1,0x00000000}},	//   _дзьм, _võla, jent,
  { {0x69c30019,0x291f0072,0x7ae30e5c,0x00000000}},	//   june, kkua_, dent,
  { {0xdbd20019,0x7ae300ac,0x6aaa33d2,0x00000000}},	//   _tüüp, eent, waff,
  { {0xeb060459,0xb92a008b,0xccb70086,0x00000000}},	//   ичко, _thuế_, ргії_,
  { {0x7ae333d3,0x69c300e8,0x63a40035,0x00000000}},	//   gent, fune, _mwin,
  { {0x69c333d4,0xdcfc000c,0x8884007e,0x00000000}},	//   gune, _cură, میان,
  { {0x2120085a,0xb4cb0053,0x63a40b3c,0x00000000}},	//   nkih_, र्फ़_, _owin,
  { {0x7ae333d5,0x69c333d6,0x36d41b08,0x00000000}},	//   bent, aune, бопр,
  { {0x2d5c0268,0x656d33d7,0x63bd017f,0x00000000}},	//   ríeu_, _shah, vrsn,
  { {0xceb30063,0x48e60076,0x2a36000d,0x00000000}},	//   חית_, _воев, _тэар,
  { {0x673a0268,0x2fd200c7,0x6aa8001f,0x00000000}},	//   sitj, ktyg_, _hedf,
  { {0x2d5c02dd,0xd7940021,0x212000c2,0x00000000}},	//   líes_, _التخ, dkih_,
  { {0x18671001,0x63a428b0,0x23e40054,0x00000000}},	//   _тачи_, _dwin, ціюв,
  { {0x2d5c006d,0x2729008b,0x6aa81781,0x00000000}},	//   níes_, _súng_, _medf,
  { {0xa5080001,0xba3c0006,0x644d00cd,0x00000000}},	//   _већа_, _neįm, _txai,
  { {0xc05b019d,0x7ae333d8,0x69c3004d,0x00000000}},	// [5810] тів_, yent, zune,
  { {0x6d5b0228,0x21290222,0xff530021,0x00000000}},	//   _skua, shah_, آخر_,
  { {0xe2a7007a,0xddcb0080,0x2d870003,0x00000000}},	//   íður_, řižk, êne_,
  { {0x7ae333d9,0x0d84000d,0x753d0758,0x00000000}},	//   went, ілін, nisz,
  { {0x2d8c1560,0x4ea702d8,0x6aa83277,0x00000000}},	//   _éden_, _врба, _bedf,
  { {0x7ae302dd,0x8ccc0053,0x63600d90,0x00000000}},	//   uent, _हाथो, töni,
  { {0xd2b80063,0x6aa8001f,0x753d00ea,0x00000000}},	//   בלות_, _dedf, kisz,
  { {0x6d5b0035,0x7ae309b7,0x61fa0137,0x00000000}},	//   _ukua, sent, åtli,
  { {0x6d590045,0x7ae333da,0x2bda007e,0x00000000}},	//   mowa, pent, _مالک_,
  { {0x69c333db,0x6d590886,0x6285001f,0x00000000}},	//   pune, lowa, _ngho,
  { {0x99850032,0x63a42e38,0x8506005d,0x00000000}},	//   _الصو, _swin, مودن,
  { {0x753d000f,0x6d5933dc,0x4975005a,0x00000000}},	//   gisz, nowa, _улес,
  { {0x6b8902dd,0xdcf5003d,0x212000c2,0x00000000}},	//   _jueg, _atzī, vkih_,
  { {0x6d590051,0xe6950044,0xf6290044,0x00000000}},	//   howa, _الغد, _مسعى_,
  { {0x6d590045,0x6b89048e,0x2120082a,0x00000000}},	//   kowa, _lueg, tkih_,
  { {0x63a433dd,0x6d590022,0x753d119b,0x00000000}},	//   _twin, jowa, cisz,
  { {0x6d590045,0x612a0026,0x21671736,0x00000000}},	// [5820] dowa, _nýle, сити_,
  { {0xbeaa007e,0x212001b3,0x2fd20137,0x00000000}},	//   اهان_, skih_, rtyg_,
  { {0xc3330047,0x248d016b,0x2fd200ac,0x00000000}},	//   _מוז_, žeme_, styg_,
  { {0x6d590045,0x6b81001f,0x2d5c006d,0x00000000}},	//   gowa, _ailg, víes_,
  { {0x6b8104ab,0x4c560021,0x3133014b,0x00000000}},	//   _bilg, حضار, _хеўр,
  { {0x2fc0002b,0x9f96004b,0x753d1556,0x00000000}},	//   mrig_, _müüt_, zisz,
  { {0xbea3005a,0x6d590051,0x67210077,0x00000000}},	//   _хаск, bowa, dklj,
  { {0x3eaa02b0,0x6b8902dd,0x6d590045,0x00000000}},	//   _hebt_, _fueg, cowa,
  { {0x7e87013d,0x98ad0022,0xbb86005d,0x00000000}},	//   _árpá, zieć_, _طلاي,
  { {0x95d8000a,0x753d0051,0x8afc0051,0x00000000}},	//   адот_, wisz, _chęt,
  { {0x9f4002dd,0x753d000f,0x38c8007e,0x00000000}},	//   lvió_, tisz, _ناشی_,
  { {0x672108ea,0x3eaa00bd,0x5559000d,0x00000000}},	//   aklj, _lebt_, рамя_,
  { {0x6d430164,0x6721085a,0x2d9801f4,0x00000000}},	//   énai, bklj, _ltre_,
  { {0x6d590045,0xa5f833de,0x2d980003,0x00000000}},	//   zowa, _веку_, _otre_,
  { {0x6d590035,0x79821d03,0x2d8a1ba2,0x00000000}},	//   yowa, _kiow, _nube_,
  { {0x909933df,0x61fa0026,0xd904005d,0x00000000}},	//   рват_, ætla, ری_,
  { {0x3ce600c2,0x2d8a33e0,0xbe870021,0x00000000}},	// [5830] deov_, _aube_, مجاو,
  { {0x6d590051,0x6b8904d0,0x6d4a33e1,0x00000000}},	//   wowa, _rueg, éfan,
  { {0x6d590045,0x3eaa0034,0x61230019,0x00000000}},	//   towa, _debt_, _hõlm,
  { {0x20c7000a,0x672100c2,0x0dc80002,0x00000000}},	//   _усог, zklj, суфи_,
  { {0x6d591112,0x6b890290,0x0c75007e,0x00000000}},	//   rowa, _queg, زگرد,
  { {0x6d590045,0x2d87013d,0x6ed80042,0x00000000}},	//   sowa, ínes_, न्दु,
  { {0x6d590051,0x672100c2,0x2d8a007d,0x00000000}},	//   powa, vklj, _gube_,
  { {0xf41f00fe,0x6b811634,0x63600f57,0x00000000}},	//   kyä_, _wilg, lönt,
  { {0x6b8133e2,0x2d8a007d,0xf41f0072,0x00000000}},	//   _tilg, _zube_, jyä_,
  { {0x2d9800d1,0x637200b9,0x2caf0137,0x00000000}},	//   _ytre_, mæng, lagd_,
  { {0x61230004,0x637205b9,0xa50a33e3,0x00000000}},	//   _põll, læng, аена_,
  { {0x6721017f,0x27e0000c,0xd874005d,0x00000000}},	//   sklj, _ţine_, _کامب,
  { {0x44240114,0xe4570086,0x43930085,0x00000000}},	//   ám_, жжя_, маўс,
  { {0x59dd0053,0x2fc016af,0x9346071f,0x00000000}},	//   _महार, vrig_, інве,
  { {0x63720146,0x6360013d,0x613a01ce,0x00000000}},	//   hæng, dönt, ачар_,
  { {0x60261001,0x2fc033e4,0x6123004b,0x00000000}},	//   одба, trig_, _hõlj,
  { {0x78ab000f,0x2d8a006d,0x2fc006aa,0x00000000}},	// [5840] _megv, _sube_, urig_,
  { {0xdfcf08aa,0x2fc033e5,0xe6b70053,0x00000000}},	//   ئيل_, rrig_, _आयोज,
  { {0xee3a0001,0x2fc001e1,0x216a2ba3,0x00000000}},	//   јне_, srig_, _вини_,
  { {0xdca30138,0xed5a0076,0xbc6601ea,0x00000000}},	//   даци, шое_, овек,
  { {0x63720146,0x0b930021,0xdb0a01c8,0x00000000}},	//   gæng, وجود, žnít,
  { {0x9f40006d,0x2d8a04bc,0x0efa000d,0x00000000}},	//   rvió_, _tube_, _тэмы_,
  { {0xcebf0080,0x637205b9,0xdd92007e,0x00000000}},	//   _úřad_, mænd, _آور_,
  { {0x637200b9,0x48141259,0x257200ea,0x00000000}},	//   lænd, змис, náld_,
  { {0xc1730063,0x070a0062,0x78ab008f,0x00000000}},	//   וחה_, ахни_, _degv,
  { {0x661c0093,0x4b260021,0xf41f0072,0x00000000}},	//   ørko, _بعرف, vyä_,
  { {0x61230004,0x7bc22493,0x2d8500ea,0x00000000}},	//   _sõlm, lrou, _élet_,
  { {0xe4e7019d,0xf41f00fe,0x2bb10042,0x00000000}},	//   ціон, tyä_, ुंचा,
  { {0x636000fe,0x7d7b0063,0x7d040072,0x00000000}},	//   yönt, ינטו, öisy,
  { {0x7c2f01f7,0x98a30078,0x2d8433e6,0x00000000}},	//   _ücre, ėją_, _lime_,
  { {0xd13b33e7,0x7bc20592,0x637200b9,0x00000000}},	//   аха_, hrou, dænd,
  { {0x2d840019,0x63600137,0x7bc2004c,0x00000000}},	//   _nime_, föns, krou,
  { {0x61fe006f,0x63600d90,0x3f830130,0x00000000}},	// [5850] _erpl, tönt, _piju_,
  { {0x2d840164,0x10480054,0xdef10044,0x00000000}},	//   _aime_, іяти_, عًا_,
  { {0x8c3d1c93,0x27290066,0x0cd60042,0x00000000}},	//   _ieşi, _júna_, ठभूम,
  { {0x62950051,0x7bc2002b,0x2d8433e8,0x00000000}},	//   lczo, frou, _cime_,
  { {0x78ab00ac,0x63600014,0xb4fc0047,0x00000000}},	//   _regv, pönt, יפאי,
  { {0xdefb0088,0x637205b9,0x60cd2258,0x00000000}},	//   _тым_, ræng, lgam,
  { {0x2729007a,0x8a02005a,0x248900a3,0x00000000}},	//   _núna_, езще, _ogam_,
  { {0x6372010a,0x60cd33e9,0x24890089,0x00000000}},	//   mæne, ngam, _ngam_,
  { {0x2572027d,0x853d0006,0x6d4b0137,0x00000000}},	//   nále_, ipėd, mnga,
  { {0x24890025,0x6b9b00a4,0x78ab0229,0x00000000}},	//   _agam_, _itug, _wegv,
  { {0xf9f9006a,0x636000ea,0x2d85013d,0x00000000}},	//   _دفاع_, zöns, _éles_,
  { {0x691c0003,0x6d4b33ea,0x62950022,0x00000000}},	//   _dées, nnga, eczo,
  { {0x68e90019,0x3991017d,0x93c6003b,0x00000000}},	//   meed, _hás_, _orăş,
  { {0x3991007a,0x25720080,0x2cad09fe,0x00000000}},	//   _kás_, dále_, _leed_,
  { {0xc69200b5,0x61311d0d,0xd0040053,0x00000000}},	//   _טאג_, _målf, रम्भ_,
  { {0x55ba01d8,0x60cd00bb,0x399133eb,0x00000000}},	//   _המקו, ggam, _más_,
  { {0x637205b9,0x69c333ec,0x2d8433ed,0x00000000}},	// [5860] tænd, hrne, _rime_,
  { {0x6d4b08f0,0x7bc2006f,0x2d840089,0x00000000}},	//   enga, vrou, _sime_,
  { {0x44220186,0x3991016b,0x0d861599,0x00000000}},	//   lyk_, _nás_, член,
  { {0x637200b9,0x27ed0150,0x63600014,0x00000000}},	//   sænd, kwen_, pöns,
  { {0x637200b9,0x2cad0625,0x8c3d005b,0x00000000}},	//   pænd, _deed_, _yeşi,
  { {0x6b9b0027,0x7bc204bc,0x39910025,0x00000000}},	//   _dtug, rrou, _bás_,
  { {0x2d8433ee,0x39910025,0x68e914f6,0x00000000}},	//   _time_, _cás_, feed,
  { {0x4422021f,0x07980001,0xdce200c3,0x00000000}},	//   kyk_, овић_, oloč,
  { {0xba3c0006,0xdcfc0078,0x8b360121,0x00000000}},	//   _neįv, _strė, _ена́_,
  { {0x39910025,0x6d4225cc,0x45b80054,0x00000000}},	//   _fás_, lioa, огою_,
  { {0x399133ef,0xba9b0063,0x60cd0058,0x00000000}},	//   _gás_, _הסבי, ygam,
  { {0x68e90034,0x6d42003b,0x7aea007d,0x00000000}},	//   ceed, nioa, left,
  { {0xf76f006a,0x645a183b,0x7c2233f0,0x00000000}},	//   ضای_, ştin, nyor,
  { {0xdce200c3,0x61230019,0x7aea0137,0x00000000}},	//   dloč, _tõlk, neft,
  { {0xe9ff001b,0x6d4b001f,0xd6db0063,0x00000000}},	//   _phẩm_, ynga, _החול,
  { {0x60cd0006,0x61310d7d,0xe164005e,0x00000000}},	//   ugam, _målg, еђун,
  { {0x61fc007d,0x60cd33f1,0x69ca004d,0x00000000}},	// [5870] avrl, rgam, hufe,
  { {0x51870088,0x2cad0034,0x257201c8,0x00000000}},	//   _нума, _seed_, rále_,
  { {0xe9ff008b,0x2cad0089,0x6b9b33f2,0x00000000}},	//   _thẩm_, _peed_, _stug,
  { {0x69c300c3,0x6d42000c,0x637200b9,0x00000000}},	//   vrne, gioa, ræne,
  { {0x68e902dd,0x69d8001c,0x69c3001f,0x00000000}},	//   veed, etve, wrne,
  { {0x09e50856,0x7aea00b9,0x6d4b00a4,0x00000000}},	//   докн, geft, snga,
  { {0x68e90004,0x2cad0019,0xdb0b0026,0x00000000}},	//   teed, _teed_, gsgá,
  { {0x6d42000c,0x39910114,0x27ed0244,0x00000000}},	//   cioa, _vás_, twen_,
  { {0x68e91a20,0x27ed0122,0x69dc0137,0x00000000}},	//   reed, uwen_, _ären,
  { {0x7d1b0034,0x27ed33f3,0x69ca12e2,0x00000000}},	//   _hous, rwen_, bufe,
  { {0x442200ac,0xdce200c2,0x6907000d,0x00000000}},	//   wyk_, zloč, _нядз,
  { {0x7d1b33f4,0xd46a1314,0x04460062,0x00000000}},	//   _jous, жиме_, демн,
  { {0x395f33f5,0x394d33f6,0x7bcb00a4,0x00000000}},	//   mous_, mnes_, nugu,
  { {0x2b490025,0x442233f7,0x395f33f8,0x00000000}},	//   éach_, ryk_, lous_,
  { {0x394d048e,0x7bcb0026,0x442233f9,0x00000000}},	//   ones_, hugu, syk_,
  { {0x395f0c69,0x7d1b00fe,0x394d33fa,0x00000000}},	//   nous_, _nous, nnes_,
  { {0xdb0b000f,0xa0670c8d,0xa4460086,0x00000000}},	// [5880] zsgá, дата_, _інод,
  { {0xe7e50161,0xe9ff001b,0x9f4b0290,0x00000000}},	//   _कहना_, _nhắm_, _uscì_,
  { {0xbf9b0003,0x7d1b33fb,0x395f33fc,0x00000000}},	//   _prêc, _bous, kous_,
  { {0x6da30001,0x395f223e,0x2d9c008f,0x00000000}},	//   тица, jous_, īve_,
  { {0x6d420529,0x7bcb11c4,0x7d09004c,0x00000000}},	//   rioa, gugu, _dnes,
  { {0x69d8076c,0x394d33fd,0x6d430164,0x00000000}},	//   ttve, enes_, énar,
  { {0x386600e3,0x7aea33fe,0xba3c0006,0x00000000}},	//   _syor_, reft, _neįt,
  { {0x69ca0c38,0x394d33ff,0x2ef8005b,0x00000000}},	//   rufe, gnes_, _harf_,
  { {0x6d403400,0x1867005e,0x69d83401,0x00000000}},	//   _imma, маћи_, stve,
  { {0x7d090198,0x394d3402,0x752d0401,0x00000000}},	//   _znes, anes_, _slaz,
  { {0x645a000c,0x752d0d0f,0x6f1c3403,0x00000000}},	//   ştil, _plaz, _morc,
  { {0x2ca6006f,0x6576001f,0xc7a60121,0x00000000}},	//   nbod_, _chyh, _жидк,
  { {0x248d055e,0x2732001b,0x6123004b,0x00000000}},	//   žemo_, _nâng_, _kõlv,
  { {0x27e6002c,0x57f3000d,0xd7a9007e,0x00000000}},	//   _ipon_, _шпіт, _ردهٔ_,
  { {0x9294000d,0x6d403404,0xe5e80072,0x00000000}},	//   тасц, _omma, ömää,
  { {0x752d017f,0x39443405,0x645a0003,0x00000000}},	//   _ulaz, nims_, écié,
  { {0xb33b00cd,0x613101f2,0x2ca600ca,0x00000000}},	// [5890] apça, _nåle, dbod_,
  { {0xce6b295e,0x25720026,0x61310137,0x00000000}},	//   оред_, mála_, _såld,
  { {0x2ef800bd,0x7d1b3406,0x257200ea,0x00000000}},	//   _darf_, _pous, lála_,
  { {0x63ad0009,0x6d5a0026,0xb4db00cd,0x00000000}},	//   _kwan, _ítal, mnàs,
  { {0x7d090198,0x394d02ab,0x61310137,0x00000000}},	//   _vnes, vnes_, _våld,
  { {0x63ad0009,0xd5b8003d,0x6d40253a,0x00000000}},	//   _mwan, ksā_, _emma,
  { {0x394d003d,0x7bcb3407,0x25720027,0x00000000}},	//   tnes_, sugu, hála_,
  { {0x7d093408,0x21293409,0x6b881c2a,0x00000000}},	//   _unes, nkah_, _eidg,
  { {0x8b670032,0xd7e60076,0x395f1db4,0x00000000}},	//   _قائم, емые_, rous_,
  { {0x25720025,0x21290397,0x394d340a,0x00000000}},	//   dála_, hkah_, snes_,
  { {0x63ad340b,0x394d340c,0x21291496,0x00000000}},	//   _awan, pnes_, kkah_,
  { {0xaa5b0047,0x661c065e,0x67b904a0,0x00000000}},	//   _װאָרט_, ärka, _فاتح_,
  { {0x63ad002b,0x782700f2,0x6d4a0003,0x00000000}},	//   _cwan, _تعال, éfai,
  { {0x27320529,0x68f9001f,0x68fb0019,0x00000000}},	//   _când_, _hawd, ldud,
  { {0xc7b9000f,0x2ca60185,0x2732000c,0x00000000}},	//   lső_, ybod_, _dând_,
  { {0x68fb340d,0x4f960086,0x2129017e,0x00000000}},	//   ndud, ержу, gkah_,
  { {0x6f1c340e,0x63ad001f,0xdb0b0014,0x00000000}},	// [58a0] _porc, _gwan, yrgð,
  { {0x6292034d,0x27ff00fe,0x2732340f,0x00000000}},	//   ékoľ, ivun_, _gând_,
  { {0x4ac9024c,0xf1bf0024,0x6131314f,0x00000000}},	//   _राजव, ýšte_, _såle,
  { {0x39440295,0xe9ff008b,0x291d0051,0x00000000}},	//   xims_, _chậm_, _nowa_,
  { {0xdb970088,0x2ca63410,0x4af80076,0x00000000}},	//   евіч_, rbod_, делю_,
  { {0x68fb0089,0x613100b8,0x2ca600ca,0x00000000}},	//   edud, _våle, sbod_,
  { {0x39443411,0x39580014,0x6b880504,0x00000000}},	//   tims_, _írsk_, _vidg,
  { {0x6d400397,0x68fb002c,0xdbd600fe,0x00000000}},	//   _umma, gdud, _pääa,
  { {0xc7b900ea,0x39443412,0x7791005d,0x00000000}},	//   gső_, rims_, لینا,
  { {0x3f8a0009,0xccf90051,0x8c3d003b,0x00000000}},	//   _jibu_, _zaś_, _veşt,
  { {0x2732000c,0x18a6065b,0xdce9003b,0x00000000}},	//   _rând_, _заем, _înăb,
  { {0x63ad0035,0x3f8a00a4,0x25723413,0x00000000}},	//   _pwan, _libu_, tála_,
  { {0x7afa03e8,0x27e60034,0x212900c2,0x00000000}},	//   _katt, _upon_, vkah_,
  { {0x93880076,0x2572248c,0xe7e50042,0x00000000}},	//   есса_, rála_, _कहता_,
  { {0x31c40431,0x7afa177d,0x2732003b,0x00000000}},	//   лств, _matt, _vând_,
  { {0x21290150,0x7afa326b,0x35b30062,0x00000000}},	//   ukah_, _latt, _сбър,
  { {0x21293414,0x4034018e,0x63ad0035,0x00000000}},	// [58b0] rkah_, гетс, _uwan,
  { {0x238a0024,0x21293415,0x7afa0611,0x00000000}},	//   ľujú_, skah_, _natt,
  { {0x238a0024,0x7e28000d,0x21290360,0x00000000}},	//   žujú_, ніца_, pkah_,
  { {0x7afa0072,0xdd940085,0xbe64005d,0x00000000}},	//   _aatt, уацы, دهمي,
  { {0x2556001c,0x7afa04ca,0xb0b60063,0x00000000}},	//   nāla_, _batt, _בפרס_,
  { {0xbbd10161,0x7afa055b,0x2903001c,0x00000000}},	//   _समीक, _catt, ējam_,
  { {0x0dc80076,0x7afa3149,0xe9ff008b,0x00000000}},	//   _пути_, _datt, _thậm_,
  { {0x2556008f,0x7d160072,0x8d77005d,0x00000000}},	//   kāla_, öyst, _سازا,
  { {0x7afa104f,0x69ce00b9,0x290b005b,0x00000000}},	//   _fatt, _åben, ıca_,
  { {0x7afa3416,0x645a0058,0x4439013d,0x00000000}},	//   _gatt, ştik, dzs_,
  { {0x65c50062,0x64a63417,0x27ff0072,0x00000000}},	//   ъбна, кана, svun_,
  { {0xe8940088,0x2fc900ac,0xc7b9013d,0x00000000}},	//   _баць, krag_, pső_,
  { {0x7afa107b,0x20003418,0x78a93419,0x00000000}},	//   _yatt, xvii_, mbev,
  { {0x2fc9341a,0x03a332e4,0x2b4700ca,0x00000000}},	//   drag_, риро, ninc_,
  { {0x3f8a06c2,0x44390023,0xe297341b,0x00000000}},	//   _ribu_, azs_, тас_,
  { {0x78a90173,0x853d0078,0xa2ce0082,0x00000000}},	//   nbev, lpėn, _ताक्,
  { {0xf8b200b5,0x54a50021,0x2167341c,0x00000000}},	// [58c0] ישן_, _صحيف, тити_,
  { {0x61230004,0xafe3030b,0xbea6012c,0x00000000}},	//   _sõlt, рофл, тажк,
  { {0x78a900ac,0x63a600ac,0x42560d34,0x00000000}},	//   kbev, lpkn, _штит,
  { {0x7afa341d,0xddc3089a,0x0c26341e,0x00000000}},	//   _satt, рбци, кмен,
  { {0x7afa055b,0x6123004b,0xe44d0063,0x00000000}},	//   _patt, _võlt, ּתוֹ,
  { {0x69dc0137,0x629c341f,0xd788008d,0x00000000}},	//   _ärek, ncro, _yểu_,
  { {0x7afa2e43,0x78a900f5,0xe45f3420,0x00000000}},	//   _vatt, fbev, ngör_,
  { {0x7afa25ca,0xacea0021,0x78a91a81,0x00000000}},	//   _watt, _ترسل_, gbev,
  { {0x798b0185,0x2ca9006d,0x2bc90053,0x00000000}},	//   _digw, ñade_, _रिया,
  { {0xa37b017d,0x613100cf,0xa2d70042,0x00000000}},	//   otõe, _måla, _बाध्,
  { {0x2d8c013d,0x75d404a0,0x99d30044,0x00000000}},	//   _édes_, ديجا, _نقلت,
  { {0x2556001c,0xdccf0013,0xc4bf0053,0x00000000}},	//   tāla_, hỉnh_, ्लेख,
  { {0xd6d2006a,0xe9ff008b,0x443f0013,0x00000000}},	//   _نقش_, _thảm_, àu_,
  { {0x5693000d,0x2d870871,0x44393421,0x00000000}},	//   _кашт, ínez_, rzs_,
  { {0xe45f0137,0x442d3422,0x3205004c,0x00000000}},	//   ggör_, še_, íly_,
  { {0x39980c3f,0x30a40817,0x257900ea,0x00000000}},	//   _més_, ирув, féle_,
  { {0xa0750001,0xbf9b0003,0x254f0022,0x00000000}},	// [58d0] угач, _grêl, jęli_,
  { {0x61f9000d,0xa2f50086,0x629c3423,0x00000000}},	//   _зноў_, _споч, ccro,
  { {0x39980003,0xe8df0013,0x63bd0014,0x00000000}},	//   _nés_, hiền_, lssn,
  { {0xf6530063,0xccef01ce,0x5d55014b,0x00000000}},	//   בצע_, ећa_, ыкет,
  { {0x69ca007a,0x63bd00c7,0xc05b0086,0x00000000}},	//   erfe, nssn, _цін_,
  { {0xab640088,0x8f6900de,0x00000000,0x00000000}},	//   авіл, _أمسك_,   ,
  { {0xa96911e6,0x798b1780,0x795e002b,0x00000000}},	//   ника_, _pigw, lëwy,
  { {0x645a000c,0x39980003,0xe9ff008b,0x00000000}},	//   ştii, _dés_, _chạm_,
  { {0x2b490027,0x78a93424,0x7e7a0014,0x00000000}},	//   éacs_, rbev, _útpr,
  { {0x656f103b,0x78a93425,0x7c24004b,0x00000000}},	//   elch, sbev, äire,
  { {0x78a9069f,0x27290066,0x09e40054,0x00000000}},	//   pbev, _júni_, _воєн,
  { {0xe45f0137,0x7bcb3426,0x799a0041,0x00000000}},	//   vgör_, orgu, _טשעס,
  { {0x290f01e3,0x4424008b,0xc3d6000d,0x00000000}},	//   _inga_, âm_, ыўны,
  { {0xcc3a00b5,0xe45f0137,0xdc3a0047,0x00000000}},	//   געשט, tgör_, געשר,
  { {0x629c06e8,0x254f056c,0x11da0044,0x00000000}},	//   rcro, zęli_, عورة_,
  { {0x2556003d,0x2176000a,0x41590121,0x00000000}},	//   mālo_, ѓувр, вшую_,
  { {0xe29a06c9,0x6fb60044,0xf537009d,0x00000000}},	// [58e0] _пап_, امطا, _תרפז_,
  { {0x63a43427,0xd2aa000d,0xbf9b017d,0x00000000}},	//   _itin, _якое_, _grêm,
  { {0x2556001c,0x7bcb3428,0x9858008f,0x00000000}},	//   nālo_, ergu, iņām_,
  { {0xac97006a,0x61fa007a,0x613100c7,0x00000000}},	//   هنما_, ætlu, _tåla,
  { {0xa37b0016,0x60d6001f,0x77f20053,0x00000000}},	//   stõe, mgym, _अनेक_,
  { {0x39980016,0x7bc40006,0x63a40035,0x00000000}},	//   _pés_, šiuo, _mtin,
  { {0xe9ff001b,0xf2d30063,0x656f001f,0x00000000}},	//   _phạm_, צעה_, ylch,
  { {0x39980268,0xa96700e1,0x98a3005e,0x00000000}},	//   _vés_, лија_, биће,
  { {0x63a43429,0x4734342a,0x274a079b,0x00000000}},	//   _ntin, инис, ечно_,
  { {0x58370076,0x4ff70047,0x290f0026,0x00000000}},	//   узья_, נזיע_, _enga_,
  { {0xca560138,0x49ca342b,0x63a4342c,0x00000000}},	//   _стањ, _член_, _atin,
  { {0x9f490026,0x63a400cd,0xa2d70042,0x00000000}},	//   hvað_, _btin, _बाह्,
  { {0xbf9b0016,0x3eba342d,0xccf30063,0x00000000}},	//   _prêm, kapt_, זכר_,
  { {0x2127006a,0x2572013d,0x7bcd0078,0x00000000}},	//   گيری_, nálj_, šaug,
  { {0x2d9c03d9,0x63a4342e,0x92580a29,0x00000000}},	//   ível_, _etin, гарт_,
  { {0x7bcb0014,0xc446005d,0xc177043e,0x00000000}},	//   yrgu, ایین_, ادست,
  { {0x3ecb0001,0xbf9b017d,0x4ea70131,0x00000000}},	// [58f0] ећем_, _trêm, греа,
  { {0x543c0047,0x2903001c,0xdb210058,0x00000000}},	//   _רעזא, ējai_, ütüp,
  { {0x628801d1,0x60ce0075,0x9e070085,0x00000000}},	//   ždor, _şimş, ычал,
  { {0x1ad20042,0x621a009a,0x00000000,0x00000000}},	//   _साउथ, _סורק,   ,
  { {0x8d740021,0xe8df0013,0x63a4003b,0x00000000}},	//   حالا, hiển_, _xtin,
  { {0xa3d60053,0xeb96049f,0x39462b0d,0x00000000}},	//   ांत_, шиш_, _amos_,
  { {0x7f580002,0x52d80041,0x19f90085,0x00000000}},	//   _сарс_, אווע_, тэль_,
  { {0x613102ad,0xa92528dd,0x1a68005d,0x00000000}},	//   _målo, рдил, دیمی_,
  { {0x64c80006,0x6d4b342f,0x2572013d,0x00000000}},	//   nčių, miga, bálj_,
  { {0x5745126b,0xe9ff008b,0x636000ea,0x00000000}},	//   рноб, _nhầm_, sönz,
  { {0xbb840021,0x9178008b,0x7ae5004b,0x00000000}},	//   _اللي, _lớn_, õhtu,
  { {0x6d4b3430,0x290f3431,0xa4f8007e,0x00000000}},	//   niga, _unga_, اکثر_,
  { {0x7c2b002b,0x97a7005e,0x6d4b3432,0x00000000}},	//   nygr, _срел, iiga,
  { {0x46a500e1,0x656600ea,0x61380025,0x00000000}},	//   _такв, sokh, _míle,
  { {0x51860021,0xa2d70042,0x6566013d,0x00000000}},	//   لشرق, _बार्, pokh,
  { {0x10a60245,0x6d4b3433,0x057a0044,0x00000000}},	//   риан, jiga, _جمعة_,
  { {0x6d4b3434,0x67233435,0xdfa50021,0x00000000}},	// [5900] diga, _konj, محلي,
  { {0x613101e3,0x3f8e0014,0x6d4b2401,0x00000000}},	//   _håll, öfu_, eiga,
  { {0x67233436,0x61380331,0x75243437,0x00000000}},	//   _monj, _píld, _koiz,
  { {0xb64c00b5,0x4d660088,0x4d4a0062,0x00000000}},	//   עגאָ, шкев, ъпен_,
  { {0x61380080,0x2ca902dd,0x6131018c,0x00000000}},	//   _cíle, ñada_, _måll,
  { {0xf7670021,0x6138004c,0x6d4b004b,0x00000000}},	//   _ذا_, _díle, aiga,
  { {0x6d4b0273,0xab270001,0x3eb83438,0x00000000}},	//   biga, роја_, _iert_,
  { {0x6b830137,0x7c2b002b,0x3eb800ca,0x00000000}},	//   amng, bygr, _hert_,
  { {0x67230164,0x69c1005b,0x2fc01150,0x00000000}},	//   _bonj, _evle, nsig_,
  { {0xf1bf0024,0x7d023439,0x67231ea0,0x00000000}},	//   žšie_, ldos, _conj,
  { {0x3eb8000f,0x6723343a,0x8b3b0063,0x00000000}},	//   _mert_, _donj, _שתבצ,
  { {0x7d02343b,0xe8df008b,0x35471518,0x00000000}},	//   ndos, riển_, рхов,
  { {0xb7960001,0x2d981293,0xc5580086,0x00000000}},	//   _трећ, _lure_, рияє_,
  { {0x6131076c,0x7d0200fe,0x6723007d,0x00000000}},	//   _pålo, hdos, _gonj,
  { {0x9f40006f,0x637b003b,0x35f70021,0x00000000}},	//   atië_, eînc, _نريد_,
  { {0x44b500e1,0x7d00343c,0x6848008f,0x00000000}},	//   _убис, _nams, pīdī,
  { {0xcebb0001,0x656d0035,0xe9ff0013,0x00000000}},	// [5910] вље_, _ikah, _thầm_,
  { {0x2d980009,0x6d4b343d,0x3eb8343e,0x00000000}},	//   _bure_, wiga, _cert_,
  { {0x645a003b,0x6d4b343f,0xfe70007e,0x00000000}},	//   ştit, tiga, ودم_,
  { {0xe1f0006a,0x2d983440,0x7d000ac9,0x00000000}},	//   _کسی_, _dure_, _cams,
  { {0x6d4b3441,0xfc050336,0x2d983442,0x00000000}},	//   riga, спло, _eure_,
  { {0x3da70079,0x3eb8007a,0x61310b2a,0x00000000}},	//   _враб, _gert_, _målm,
  { {0xdef8000d,0x6d4b0035,0x67233323,0x00000000}},	//   _тыя_, piga, _ronj,
  { {0x637200b9,0x853d0006,0x7d0600ea,0x00000000}},	//   tænk, spėj, térő,
  { {0x3ea109d6,0x6d493443,0xad580121,0x00000000}},	//   ocht_, _imea, _трёх_,
  { {0x637200b9,0x257228ba,0xa3d60053,0x00000000}},	//   rænk, máli_, ांस_,
  { {0x75240198,0x3ea10199,0x1e3a0047,0x00000000}},	//   _poiz, icht_, ָגרא,
  { {0xc32901d8,0xb8950032,0x673a017f,0x00000000}},	//   _או_, _الإع, ahtj,
  { {0x3f990035,0x691c0003,0x25720066,0x00000000}},	//   _nusu_, _réex, náli_,
  { {0x673a102c,0xc483000d,0x3f910734,0x00000000}},	//   chtj, яляк, _nizu_,
  { {0x43433444,0x6d410078,0x2fc0002b,0x00000000}},	//   черв, _įlan, wsig_,
  { {0x3f4f001c,0x2fc03445,0x3eb83446,0x00000000}},	//   kļus_, tsig_, _sert_,
  { {0xf3f1001b,0x4e960032,0x2d980034,0x00000000}},	// [5920] ặc_, مشار, _sure_,
  { {0x7d003447,0x2fc000e8,0x6d490016,0x00000000}},	//   _sams, rsig_, _amea,
  { {0x3eb83448,0x6e930021,0xddb60021,0x00000000}},	//   _vert_, ألما, صحاب,
  { {0x3ea10027,0x3eb800bd,0x61fe017f,0x00000000}},	//   acht_, _wert_, _ispl,
  { {0xac180001,0x6d5b3449,0x200b007d,0x00000000}},	//   ролу_, _djua, _grci_,
  { {0x8fa3005a,0x63b60185,0x2120082a,0x00000000}},	//   _харе, _mwyn, ljih_,
  { {0x79a30088,0x394d344a,0x21200734,0x00000000}},	//   прые, fies_, ojih_,
  { {0x2120082a,0x394d344b,0xfce32c5c,0x00000000}},	//   njih_, gies_, _носо,
  { {0x98a30001,0x8d4b0063,0x78bd0014,0x00000000}},	//   чиње, _עֲלֵ, ðsva,
  { {0x19ba019d,0x2ca40089,0x6ffb0041,0x00000000}},	//   _будь_, _hfmd_, נפיג,
  { {0x394d344c,0xb9960021,0xd946344d,0x00000000}},	//   bies_, _الصب, _лежи,
  { {0x394d344e,0x63b6001f,0x6aba04aa,0x00000000}},	//   cies_, _bwyn, _hetf,
  { {0xdb090026,0x2903001c,0xb97b0047,0x00000000}},	//   _kveð, ējat_, _ענדי,
  { {0x6aba00b8,0x63b6002b,0x2904004e,0x00000000}},	//   _jetf, _dwyn, ldma_,
  { {0x3f99014f,0x5a9b0047,0xe9ff0013,0x00000000}},	//   _susu_, רשלא, _thấm_,
  { {0x63b6001f,0x61310232,0x2904344f,0x00000000}},	//   _fwyn, _tålm, ndma_,
  { {0x645a04ab,0x63b60185,0x61fe3450,0x00000000}},	// [5930] ştir, _gwyn, _espl,
  { {0x3ea100bd,0x6aba0b9c,0x799a0b7a,0x00000000}},	//   ucht_, _netf, _outw,
  { {0x2ca902dd,0x212000c2,0x3ea10b06,0x00000000}},	//   ñado_, bjih_, rcht_,
  { {0x3ea100bd,0x61313451,0xfce50086,0x00000000}},	//   scht_, _målk, іоло,
  { {0xeab902e4,0xed580086,0x5bcb005e,0x00000000}},	//   айл_, щої_, ућег_,
  { {0xc9a90184,0x447c0047,0x2cbd002b,0x00000000}},	//   авке_, אנדע, sawd_,
  { {0x394d3452,0xf2d40047,0x291f0072,0x00000000}},	//   ties_, לעס_, tjua_,
  { {0x6d490035,0x637200b9,0x321e0072,0x00000000}},	//   _umea, ræni, ätyi_,
  { {0xf7190088,0xe8df008b,0x394d0da1,0x00000000}},	//   аіны_, hiện_, ries_,
  { {0x394d3453,0xa6990001,0x799a0035,0x00000000}},	//   sies_, шњих_, _futw,
  { {0xab84000d,0x63b6002b,0x394d3454,0x00000000}},	//   _хутк, _swyn, pies_,
  { {0x2903003d,0x63b6001f,0x69c32a76,0x00000000}},	//   ējas_, _pwyn, msne,
  { {0x2556001c,0x69c33455,0x212000a8,0x00000000}},	//   nāli_, lsne, vjih_,
  { {0x69c30384,0x6b9b004b,0x6d59004d,0x00000000}},	//   osne, _muug, hnwa,
  { {0xcb120132,0x212000c3,0x69c33456,0x00000000}},	//   ולם_, tjih_, nsne,
  { {0x61380026,0x2556001c,0x69c33457,0x00000000}},	//   _bíla, kāli_, isne,
  { {0xfe7800eb,0x212000c3,0x25a00080,0x00000000}},	// [5940] _šį_, rjih_, _čili_,
  { {0xef170b29,0x49100053,0x6721007d,0x00000000}},	//   ому_, _दोनो_, njlj,
  { {0x6aba00b9,0x273b0003,0xe4d3007e,0x00000000}},	//   _retf, _gêne_, _عقید,
  { {0xa06a0001,0xb4db00cd,0x69c3238a,0x00000000}},	//   _вама_, liàr, dsne,
  { {0x2d8600ac,0x68e9001f,0x60070e82,0x00000000}},	//   rmoe_, dfed, _дням_,
  { {0xaff900b5,0x39a609c2,0xa01b013d,0x00000000}},	//   _פּרי, ошив, _szög,
  { {0x7bc21b30,0x68e93458,0xdca60062,0x00000000}},	//   ssou, ffed, _мави,
  { {0x63a9000c,0x20070051,0x6b9b0050,0x00000000}},	//   ţeni, łnie_, _fuug,
  { {0x29020024,0x25720114,0x69c33459,0x00000000}},	//   ľka_, nálu_, asne,
  { {0xbf9b0003,0x29020d71,0xf7720593,0x00000000}},	//   _trêv, žka_, باع_,
  { {0xff7b0047,0xb4db00cd,0x7e9b0063,0x00000000}},	//   שטימ, diàr, יסיו,
  { {0x20090078,0x2572011b,0x00000000,0x00000000}},	//   yvai_, kálu_,   ,
  { {0x2635001b,0x6933000d,0x69d8345a,0x00000000}},	//   áo_, _іншу, luve,
  { {0xdcfc00eb,0x69d803b2,0x7aea004d,0x00000000}},	//   _turė, ouve, nfft,
  { {0x9294345b,0x61380460,0x69d8345c,0x00000000}},	//   дарц, _síla, nuve,
  { {0x9099005a,0xd4b90121,0x61380014,0x00000000}},	//   сват_, _улиц_, _píla,
  { {0xe57200b5,0xb4db00cd,0x442f00b9,0x00000000}},	// [5950] _אַז_, siàs, _æg_,
  { {0x613105dd,0x6d5900e5,0x69d801cf,0x00000000}},	//   _måli, wnwa, kuve,
  { {0x68e9001f,0x20090006,0xbf9b0003,0x00000000}},	//   yfed, svai_, _arêt,
  { {0xc4f80047,0x2556008f,0x69d8345d,0x00000000}},	//   ַזוי_, tāli_, duve,
  { {0x69d80003,0x69c3001f,0xeb9903d1,0x00000000}},	//   euve, wsne, щил_,
  { {0x257200ea,0xe7b7001c,0x69c3345e,0x00000000}},	//   lált_, ūtīš, tsne,
  { {0x69c32eb4,0xa9220066,0x69d8345f,0x00000000}},	//   usne, _šľac, guve,
  { {0x257200ea,0x69c33460,0x98dd0085,0x00000000}},	//   nált_, rsne, ускi,
  { {0x1bd50076,0x2bd20042,0x88bd0022,0x00000000}},	//   _хозя, _सिया, ejśc,
  { {0x613100c7,0x7af800c2,0x69c31343,0x00000000}},	//   _dåli, cevt, psne,
  { {0xb9e70086,0xb4db00cd,0x6907000d,0x00000000}},	//   _фізи, viàr, _мядз,
  { {0xf3f1008b,0x4638000d,0x2d8e01a8,0x00000000}},	//   ặn_, ючыя_, ífex_,
  { {0x889a0063,0x61380046,0xe5773461,0x00000000}},	//   _הבני, _bíln, язю_,
  { {0x443e0051,0x03390054,0x765d0244,0x00000000}},	//   ąt_, оїсь_, ßsys,
  { {0x798900e5,0x661c0ae2,0x6138004c,0x00000000}},	//   omew, ärkt, _díln,
  { {0x25aa006d,0x613100d1,0x3f83004b,0x00000000}},	//   íble_, _målw, _ahju_,
  { {0x69d8004d,0x915e008d,0xe53b009a,0x00000000}},	// [5960] zuve, gắn_, _לתקר,
  { {0xdfcf03eb,0xbf9b0003,0xf413009a,0x00000000}},	//   ايل_, _rrêt, _נפת_,
  { {0xe29b0063,0x2d9c0003,0xd29b009a,0x00000000}},	//   _לשיר, êve_, _לשיט,
  { {0xbf9b0164,0x25723462,0xdd8f009e,0x00000000}},	//   _prêt, máls_, هول_,
  { {0x79820185,0x62830080,0x30761849,0x00000000}},	//   _rhow, _únor, _хунс,
  { {0x79823463,0x69d8001c,0x637200b9,0x00000000}},	//   _show, tuve, mæns,
  { {0x7d7a007e,0x1d0a01f6,0x798200a3,0x00000000}},	//   _همسر_, _леви_, _phow,
  { {0x69d800c7,0x61310d7d,0x6e930044,0x00000000}},	//   ruve, _påli, _ألفا,
  { {0x2556001c,0x7af800c2,0x69d83464,0x00000000}},	//   nālu_, pevt, suve,
  { {0x257200ea,0x290a0051,0x9b460754,0x00000000}},	//   zált_, śba_, _عناو,
  { {0x7ec700ea,0x25720014,0xa4d501dd,0x00000000}},	//   lépí, jáls_, моні,
  { {0x4a7b00b5,0xa806006d,0x8e570047,0x00000000}},	//   _פראב, _cañó, לייג_,
  { {0x257200ea,0xe26e011b,0x00000000,0x00000000}},	//   vált_, éčné_,   ,
  { {0x661c3465,0x6138004c,0x83f80896,0x00000000}},	//   ärks, _bílo, џерс_,
  { {0x61383466,0x61310f4b,0x2572013d,0x00000000}},	//   _cílo, _målv, tált_,
  { {0xdce9001c,0x92581849,0xd677009a,0x00000000}},	//   _okeā, част_, _מתוק_,
  { {0xb4d90235,0x257200ea,0x656f13e4,0x00000000}},	// [5970] ाली_, rált_, moch,
  { {0x656f3467,0x63ad3468,0xa925004a,0x00000000}},	//   loch, _itan, možň,
  { {0x200201f7,0x321e0072,0x7ec7013d,0x00000000}},	//   _eski_, ätyt_, eépí,
  { {0x656f152c,0x00000000,0x00000000,0x00000000}},	//   noch,   ,   ,
  { {0x22070080,0x69c802f0,0x656f3469,0x00000000}},	//   bíhá_, _avde, ioch,
  { {0x63ad10ca,0x212b00bd,0xddca000c,0x00000000}},	//   _mtan, _hoch_, _înşt,
  { {0x19890065,0x656f346a,0x2bc90042,0x00000000}},	//   обки_, koch, _रिका,
  { {0xf1c00080,0x26de001c,0xce940062,0x00000000}},	//   ýšit_, egto_, _часъ,
  { {0xf6d50086,0x212b002b,0x1bd40156,0x00000000}},	//   міня, _moch_, _потя,
  { {0x7c3600d1,0x6f0702f7,0x212b346b,0x00000000}},	//   øyre, _jajc, _loch_,
  { {0x7a350021,0x6f070f74,0x63ad346c,0x00000000}},	//   _تفاص, _majc, _atan,
  { {0x212b0199,0x957d0078,0xb8090044,0x00000000}},	//   _noch_, ltąj, _ويضم_,
  { {0xad1a014e,0x69ce0137,0xa2b20082,0x00000000}},	//   קושר, _åber, _अभद्,
  { {0x6f071ef9,0x613100a5,0x68fb2b09,0x00000000}},	//   _najc, _målu, leud,
  { {0xfd64008b,0x63ad346d,0x249f008f,0x00000000}},	//   _chuộ, _etan, žuma_,
  { {0x212b001f,0x2556001c,0x2cbf001f,0x00000000}},	//   _coch_, tālu_, _neud_,
  { {0x212b0995,0xa494006a,0x853d0078,0x00000000}},	// [5980] _doch_, _سیست, rpėt,
  { {0x63720146,0x6386000d,0x63a9008f,0x00000000}},	//   ræns, _ігна, ģent,
  { {0x68fb024a,0x7bc90164,0xdee30856,0x00000000}},	//   keud, _aveu, тохи,
  { {0x212b001f,0x20070051,0x63720014,0x00000000}},	//   _goch_, łnia_, pæns,
  { {0x0b8a0174,0x749b0063,0x2cbf002b,0x00000000}},	//   оски_, קיספ, _deud_,
  { {0x656f346e,0x8f75000d,0x60c4346f,0x00000000}},	//   zoch, _зусі, laim,
  { {0x656f0035,0x2556001c,0x9f4b00cd,0x00000000}},	//   yoch, nāls_, _escó_,
  { {0x68fb0146,0x6f0700b2,0x60c40d17,0x00000000}},	//   geud, _zajc, naim,
  { {0x656f3470,0xc173009a,0x00000000,0x00000000}},	//   voch, כחה_,   ,
  { {0x64460051,0x60c413b8,0xc9f60021,0x00000000}},	//   dzki, haim, _يساع,
  { {0x6f03017d,0xd5b7014c,0x656f3471,0x00000000}},	//   ônci, мся_, toch,
  { {0xb4d90053,0x68fb01e1,0xdb0200a5,0x00000000}},	//   ाले_, ceud, spoä,
  { {0x656f3472,0x87260021,0x613106f1,0x00000000}},	//   roch, _يعتم, _målt,
  { {0xf64f007e,0xc87f004d,0x212b011b,0x00000000}},	//   ائی_, üße_, _soch_,
  { {0x60c43473,0xc8080013,0x31c4005e,0x00000000}},	//   faim, _hở_, кств,
  { {0x60c43474,0x52140062,0x00000000,0x00000000}},	//   gaim, ъдст,   ,
  { {0x3f98003e,0x63ad3475,0xe8110053,0x00000000}},	// [5990] _biru_, _utan, ़िया_,
  { {0x63ad003d,0xc808001b,0xfd64001b,0x00000000}},	//   ķinā, _mở_, _thuộ,
  { {0x212b0122,0x7bc9017f,0x61310137,0x00000000}},	//   _toch_, _sveu, _sålu,
  { {0x27ff001f,0xdb0b0046,0xd657009a,0x00000000}},	//   ywun_, nsgö, ויבת_,
  { {0x68ed006d,0xc8080013,0x39810014,0x00000000}},	//   _ñadi, _nở_, jósa_,
  { {0xfbd004de,0x2cbf002b,0x6b650085,0x00000000}},	//   شته_, _weud_, экла,
  { {0x69950f8d,0x18a50083,0x68fb0050,0x00000000}},	//   нрих, найм, teud,
  { {0x6d420ab9,0x25720026,0xc8080013,0x00000000}},	//   choa, jálp_, _bở_,
  { {0x69dc02ab,0x2fc900a4,0x7b080072,0x00000000}},	//   _åren, nsag_, östä,
  { {0xc8080013,0x68fb3476,0x7c843477,0x00000000}},	//   _dở_, seud, _русе,
  { {0x7d1b1607,0x65c5000d,0x68fb00fe,0x00000000}},	//   _knus, эбна, peud,
  { {0xd46a0259,0x61310f2d,0x04460121,0x00000000}},	//   зиме_, _måls, еемн,
  { {0x395f3478,0x7d093479,0x8afc0022,0x00000000}},	//   mnus_, _maes, _ujęc,
  { {0xa856014e,0x43930088,0x2556008f,0x00000000}},	//   _אינה_, лаўс, tāls_,
  { {0x64463310,0x395f347a,0x638302b6,0x00000000}},	//   szki, onus_, угра,
  { {0x78a92784,0x20000035,0x395f347b,0x00000000}},	//   ncev, twii_, nnus_,
  { {0x78a9051e,0x60c4347c,0x87ac0047,0x00000000}},	// [59a0] icev, raim, ַשאַ,
  { {0x61310137,0x26c50843,0x60c4347d,0x00000000}},	//   _sålt, nalo_, saim,
  { {0xdb0900ac,0x60c4347e,0xdddc004c,0x00000000}},	//   _ateï, paim, _vzrů,
  { {0x9f400268,0xfd76007e,0x7d09188a,0x00000000}},	//   stià_, رداخ, _caes,
  { {0x3f980089,0x26c5347f,0x6281017c,0x00000000}},	//   _tiru_, kalo_, ýlov,
  { {0x23a60024,0x26c5061c,0xee3a005e,0x00000000}},	//   _môj_, jalo_, _енг_,
  { {0xc808001b,0x6f630002,0x26c53480,0x00000000}},	//   _sở_, _сврз, dalo_,
  { {0x6564065f,0x395f3481,0x7d1b0130,0x00000000}},	//   _njih, gnus_, _gnus,
  { {0x6d400d9e,0x9a6a007e,0x26c53482,0x00000000}},	//   _ilma, _کمال_, falo_,
  { {0x78a90290,0xc8080013,0x395f3483,0x00000000}},	//   acev, _vở_, anus_,
  { {0x61310307,0x0f57014e,0xdb0b0014,0x00000000}},	//   _målr, תיים_, tsgö,
  { {0x63a9006d,0x69ca3484,0x07a617db,0x00000000}},	//   íeno, msfe, _задн,
  { {0x295700b5,0x26c53485,0xdb0b0014,0x00000000}},	//   _אסאך_, balo_, rsgö,
  { {0xdb0000c7,0x69d82cb0,0x273200dd,0x00000000}},	//   _utmä, orve, _cânt_,
  { {0x6d4004ab,0x6b9a0199,0x92682127,0x00000000}},	//   _olma, _mitg, ерта_,
  { {0xab660051,0xdc13003b,0x867b0063,0x00000000}},	//   leżą, nşăr, _מרוו,
  { {0xdfd40121,0xd468005e,0x69d8004d,0x00000000}},	// [59b0] лоты, _пиће_, hrve,
  { {0x7d090185,0x7bcd00eb,0x2fc900b9,0x00000000}},	//   _saes, šauk, rsag_,
  { {0x7d0902f6,0xab660051,0x2fc901e1,0x00000000}},	//   _paes, ieżą, ssag_,
  { {0x628500c3,0x69ca000e,0x26c50607,0x00000000}},	//   _izho, dsfe, zalo_,
  { {0x7d090019,0x75f60058,0x2007008f,0x00000000}},	//   _vaes, _yüzö, ānis_,
  { {0xdf47000d,0x657d004d,0x212900c2,0x00000000}},	//   _чэмп, hlsh, ljah_,
  { {0x78a9003b,0xbca50021,0xb0f60014,0x00000000}},	//   tcev, _لمزي, _þýða,
  { {0x7d1b010e,0x6d580003,0x212900c2,0x00000000}},	//   _unus, évat, njah_,
  { {0x78a93486,0xfbd0007e,0x26c53487,0x00000000}},	//   rcev, _هتل_, talo_,
  { {0x78a90290,0xdb0000cd,0x6b9a0058,0x00000000}},	//   scev, _numè, _gitg,
  { {0x69d8007d,0x26c51ce6,0x96650054,0x00000000}},	//   crve, ralo_, ткне,
  { {0x2129017e,0xf09f0013,0x03a60c59,0x00000000}},	//   jjah_, _ngà_, кимо,
  { {0x263c008b,0x21293488,0x7bcb1034,0x00000000}},	//   ảo_, djah_, nsgu,
  { {0x27ed3489,0x290d348a,0x4375348b,0x00000000}},	//   mten_, ldea_, густ,
  { {0x27ed1c3f,0x65640150,0x2732003b,0x00000000}},	//   lten_, _tjih, _vânt_,
  { {0x290d177c,0xf8b30053,0xb05b004d,0x00000000}},	//   ndea_, ीरिय, _adäq,
  { {0x27ed348c,0xdb091358,0x290d348d,0x00000000}},	// [59c0] nten_, _ateí, idea_,
  { {0x27ed348e,0x127a0021,0x61380139,0x00000000}},	//   iten_, _يحدث_, _míli,
  { {0x200d003d,0x27ed348f,0x63a43490,0x00000000}},	//   _šeit_, hten_, _huin,
  { {0x63a424d4,0x6b9a00cd,0x27ed3491,0x00000000}},	//   _kuin, _sitg, kten_,
  { {0x6b9a00cd,0x27ed3492,0x61380139,0x00000000}},	//   _pitg, jten_, _níli,
  { {0x290d000c,0x680f00ea,0x27ed10eb,0x00000000}},	//   edea_, ződö, dten_,
  { {0x61ee3493,0x394400e5,0x27ed3494,0x00000000}},	//   ntbl, thms_, eten_,
  { {0x27ed3495,0x69ca3496,0x69d83497,0x00000000}},	//   ften_, rsfe, rrve,
  { {0x27ed3498,0xd7c7006a,0x61380080,0x00000000}},	//   gten_, نويه_, _cíli,
  { {0x6b9a0ac8,0x7791007e,0x61380139,0x00000000}},	//   _uitg, مینا, _díli,
  { {0xdb003499,0x2cad001f,0x27ed349a,0x00000000}},	//   _numé, _yfed_, aten_,
  { {0x27ed05e4,0xa9270006,0x29240195,0x00000000}},	//   bten_, gužė, ávač_,
  { {0x27ed349b,0x63a4120d,0x67d41259,0x00000000}},	//   cten_, _cuin, _солу,
  { {0x63a40027,0x9f4000fe,0xb05b0244,0x00000000}},	//   _duin, ntiä_, _beän,
  { {0xe6780085,0x671f0042,0xf1a4034b,0x00000000}},	//   _яйкі_, बारक_, иртн,
  { {0x628500c3,0x63a40027,0x9f400072,0x00000000}},	//   _vzho, _fuin, htiä_,
  { {0x40340055,0x61ee07a7,0x21290222,0x00000000}},	// [59d0] аетс, atbl, rjah_,
  { {0xdb000003,0x2ee7004d,0x753d087d,0x00000000}},	//   _fumé, ünf_, lksz,
  { {0xb05b00bd,0x27ed00bd,0x4439349c,0x00000000}},	//   _geän, zten_, lys_,
  { {0x753d000f,0xc5f30a7a,0x44390345,0x00000000}},	//   nksz, ידע_, oys_,
  { {0x50da014e,0x4439349d,0x27ed349e,0x00000000}},	//   _אקרא, nys_, xten_,
  { {0x54760047,0xc43c0047,0x39e90121,0x00000000}},	//   נגװע_, ותדי, едко_,
  { {0x2b89034d,0xc9f50021,0x6138349f,0x00000000}},	//   júce_, استع, _síli,
  { {0x09f60032,0x2b890024,0x443916f6,0x00000000}},	//   افية_, dúce_, kys_,
  { {0x8c190047,0x2d8700cd,0x27ed34a0,0x00000000}},	//   _אוּי, ïneu_, uten_,
  { {0x6d5934a1,0x443900eb,0x26c300ed,0x00000000}},	//   liwa, dys_, újo_,
  { {0xa01b00fe,0x61ee01bb,0x28dc0053,0x00000000}},	//   _hyöd, xtbl, _याचि,
  { {0x6d5900bb,0x6e210268,0x63a434a2,0x00000000}},	//   niwa, _àlbu, _puin,
  { {0xd4560086,0x63a434a3,0x20070051,0x00000000}},	//   утнь, _quin, łnij_,
  { {0x6d59002c,0x03a32d07,0x61ee01c5,0x00000000}},	//   hiwa, сиро, ttbl,
  { {0x6d590045,0xc5d5019d,0x443934a4,0x00000000}},	//   kiwa, _сіль, ays_,
  { {0x867a014e,0x63a43065,0x6682007e,0x00000000}},	//   _ארצו, _tuin, _دیپل,
  { {0x442634a5,0x61ee34a6,0x1f660085,0x00000000}},	// [59e0] _ço_, stbl, гкам,
  { {0x61ee1778,0x73061fa2,0x4f9634a7,0x00000000}},	//   ptbl, _споз, урбу,
  { {0x733b0047,0x17560041,0x2bc60042,0x00000000}},	//   _נעטס, נסער_, रीना,
  { {0xa37b0019,0xcea90063,0x6d59194c,0x00000000}},	//   stõt, לי_, giwa,
  { {0x9f400072,0xafe30f50,0x4bd7005d,0x00000000}},	//   ttiä_, _лоял, هبود_,
  { {0xdceb001c,0x69c1001f,0x78bb0006,0x00000000}},	//   rogā, _bwle, ebuv,
  { {0x7ec8008f,0x443934a8,0x3f670ace,0x00000000}},	//   rūpē, zys_, _сиро_,
  { {0x9f4000fe,0xaea1005b,0x443900fe,0x00000000}},	//   stiä_, ğışl, yys_,
  { {0xbc660138,0x6b46007a,0x273b001b,0x00000000}},	//   _свак, _aðge, _kênh_,
  { {0x17f70032,0xbb760076,0x7d020019,0x00000000}},	//   ارية_, _субъ, leos,
  { {0x69c10185,0x44390d63,0xab930032,0x00000000}},	//   _gwle, wys_, _اللغ,
  { {0xdce0001c,0x443934a9,0xe6630054,0x00000000}},	//   _ikmē, tys_, стьо,
  { {0x443f0013,0xf993009a,0xe73a071f,0x00000000}},	//   áu_, _הרף_, _пед_,
  { {0x443934aa,0x61380014,0x7d0234ab,0x00000000}},	//   rys_, _mílu, heos,
  { {0x7c390051,0x443f34ac,0xa2950500,0x00000000}},	//   zywr, šu_, раві,
  { {0x637b00dd,0x80b504c3,0x443934ad,0x00000000}},	//   eînt, рбах, pys_,
  { {0x9099005a,0x273b0013,0x9f5534ae,0x00000000}},	// [59f0] тват_, _bênh_, авач,
  { {0x3e6b005a,0xd5b8001c,0x6d59056c,0x00000000}},	//   ншен_, opā_, wiwa,
  { {0x6d5900bb,0x539a0063,0x9b45007e,0x00000000}},	//   tiwa, _שיתו, ینصو,
  { {0x55bb0063,0x2dd80021,0x6138239e,0x00000000}},	//   גמאו, ابلة_, _sílv,
  { {0x9f490027,0x6d590bbf,0x50f40500,0x00000000}},	//   ltaí_, riwa, _узят,
  { {0x6d591c7c,0x6ee20053,0xe4580041,0x00000000}},	//   siwa, _पाएँ, ניגט_,
  { {0xdea4006a,0x4424008b,0x2d8734af,0x00000000}},	//   _ایمی, ̣m_, ïnes_,
  { {0x8cc8007e,0x613800cd,0x7d0200be,0x00000000}},	//   _موفق_, _fílu, ceos,
  { {0x9f490027,0x78a202f7,0xaae70049,0x00000000}},	//   htaí_, _dgov, _مساو,
  { {0x7a1c000c,0xdceb003b,0x2d9e0516,0x00000000}},	//   _bătă, bogă, _éter_,
  { {0x24890222,0x7a1c003b,0xaa6720cc,0x00000000}},	//   _azam_, _cătă, _стак,
  { {0x201901f4,0xd7f50121,0x98750085,0x00000000}},	//   _orsi_, _взды, _клец,
  { {0x61380025,0xd5b8001c,0x4424008d,0x00000000}},	//   _mílt, apā_, ãm_,
  { {0x290f048e,0x66e20001,0x98480062,0x00000000}},	//   _haga_, _доша, _щяха_,
  { {0xf67900b5,0x24890089,0xc156005e,0x00000000}},	//   _באַמ, _ezam_, ањањ,
  { {0x290f08a4,0x26c7002b,0x2d9f34b0,0x00000000}},	//   _jaga_, _heno_, _niue_,
  { {0xa49b00cd,0x290f1d2b,0x33330d7c,0x00000000}},	// [5a00] leòn, _maga_, _foxx_,
  { {0xdce90024,0x290f34b1,0xf3f1008b,0x00000000}},	//   _cieľ, _laga_, ặt_,
  { {0x200b051e,0x3869007a,0x60c600c3,0x00000000}},	//   _esci_, _þarf_, _tekm,
  { {0x2d8d34b2,0x6138017d,0xe5f60047,0x00000000}},	//   _chee_, _pílu, יזער_,
  { {0x3ce600a8,0x1be702b6,0x7d0234b3,0x00000000}},	//   rgov_, идци_, reos,
  { {0x26c70009,0x7d1d34b4,0x7d0234b5,0x00000000}},	//   _neno_, _ĳsse, seos,
  { {0x26d80066,0xf2d30063,0xf96a1501,0x00000000}},	//   órom_, קעה_, крий_,
  { {0xdceb000c,0x98b7005a,0x2d950121,0x00000000}},	//   rogă, алът_, _грус,
  { {0x1ae60055,0x290f007a,0x8ad60032,0x00000000}},	//   _возм, _daga_, _نتائ,
  { {0x61fe076c,0x26c70198,0x66180240,0x00000000}},	//   _oppl, _ceno_, _prvk,
  { {0x63b6001f,0x7bcd34b6,0x2489013d,0x00000000}},	//   _atyn, šaut, _szam_,
  { {0x78a2017f,0xd5b8008f,0x7a1c00dd,0x00000000}},	//   _ugov, rpā_, _vătă,
  { {0x25720240,0x7d1d00be,0x290434b7,0x00000000}},	//   nály_, _ósse, mema_,
  { {0x290434b8,0x957d0022,0x7a1c00dd,0x00000000}},	//   lema_, krąg, _tătă,
  { {0x26cc0b2b,0x27e434b9,0xeb91009a,0x00000000}},	//   mado_, lumn_, לָל_,
  { {0xa37b0016,0x2d05016a,0x26cc30b7,0x00000000}},	//   drõe, _रसेल_, lado_,
  { {0x9f490025,0xc0c834ba,0x30140085,0x00000000}},	// [5a10] staí_, русе_, одтр,
  { {0x26cc0fca,0xdb00003b,0x290434bb,0x00000000}},	//   nado_, _lumâ, hema_,
  { {0x2b890024,0x26cc017d,0x290434bc,0x00000000}},	//   júca_, iado_, kema_,
  { {0x61380025,0x290434bd,0x26cc00f8,0x00000000}},	//   _díls, jema_, hado_,
  { {0x290f00f3,0xed58019d,0x60cd00fe,0x00000000}},	//   _raga_, шої_, maam,
  { {0x26cc06b2,0x60cd003a,0x2904004b,0x00000000}},	//   jado_, laam, eema_,
  { {0x2d8d0706,0x26cc04a6,0xa2ba0053,0x00000000}},	//   _thee_, dado_, ्रत्,
  { {0x29040019,0x26c734be,0x60cd34bf,0x00000000}},	//   gema_, _seno_, naam,
  { {0x25a000f3,0x26cc00ed,0x290f34c0,0x00000000}},	//   _riil_, fado_, _vaga_,
  { {0x26cc34c1,0xbb850021,0x60cd015c,0x00000000}},	//   gado_, _الطي, haam,
  { {0x290f34c2,0x60cd065c,0xfaf00044,0x00000000}},	//   _taga_, kaam, _تثق_,
  { {0x60cd003a,0x39461780,0x4a5a009a,0x00000000}},	//   jaam, _glos_, _גדעו,
  { {0xe72e0055,0x26cc34c3,0xc9740021,0x00000000}},	//   _ее_, bado_, _بالث,
  { {0x68e934c4,0x6ef20014,0x26cc095b,0x00000000}},	//   lged, iðbó, cado_,
  { {0x60cd34c5,0x32433371,0x91860044,0x00000000}},	//   faam, перг, مجرم,
  { {0x661c010a,0x60cd005f,0xa3e80042,0x00000000}},	//   ærke, gaam, मंद_,
  { {0x752434c6,0x644f0022,0x69dc05a5,0x00000000}},	// [5a20] _iniz, czci, _årev,
  { {0x2bab0053,0x290434c7,0x32461d11,0x00000000}},	//   _चढ़ा, zema_, _геог,
  { {0xa75a00b5,0x61fe34c8,0x7524004c,0x00000000}},	//   נדער, _uppl, _kniz,
  { {0x26cc0fca,0x68e9006f,0x0c260454,0x00000000}},	//   zado_, jged, ймен,
  { {0x6b46007a,0x26cc34c9,0xd57b0047,0x00000000}},	//   _aðga, yado_, אָגר,
  { {0xf76704de,0x26cc1088,0x3ebe0026,0x00000000}},	//   _را_, xado_, _ýtt_,
  { {0x26cc0fac,0xdce20ae1,0x290434ca,0x00000000}},	//   vado_, lnoč, tema_,
  { {0x37d80002,0x27e400e5,0x68e934cb,0x00000000}},	//   адиќ_, tumn_, gged,
  { {0x26cc34cc,0xdb01017d,0x7bcd001c,0x00000000}},	//   tado_, _milê, šaur,
  { {0x60cd0122,0x3ae8006a,0x7bdf006d,0x00000000}},	//   zaam, _خبری_, áque,
  { {0x26cc34cd,0x60cd0035,0x1634130d,0x00000000}},	//   rado_, yaam, ценя,
  { {0x394600fe,0x26cc34ce,0x0e9b069a,0x00000000}},	//   _ulos_, sado_, טשיל,
  { {0xb8960032,0x26cc04a6,0x60cd00fe,0x00000000}},	//   _الشع, pado_, vaam,
  { {0x644f0022,0x1659005d,0x00000000,0x00000000}},	//   rzci, اسیک_,   ,
  { {0x60cd00fe,0xdce9001c,0x6d4234cf,0x00000000}},	//   taam, _pieļ, kkoa,
  { {0xf9b70063,0xa0b9030b,0xa15834d0,0x00000000}},	//   מהלך_, ргау_, басу_,
  { {0xa3e80053,0x60cd34d1,0xdde10022,0x00000000}},	// [5a30] मूद_, raam, łużb,
  { {0xc7f900b5,0x60cd1c0e,0x777a01a8,0x00000000}},	//   יִער, saam, notx,
  { {0x6d4b001f,0x60cd00fe,0x68e932e9,0x00000000}},	//   thga, paam, yged,
  { {0x667b0047,0x249f001c,0x6fb50044,0x00000000}},	//   נטאק, žumu_, _ومجا,
  { {0xd59c0041,0xffe40af2,0x00000000,0x00000000}},	//   אבאל, _нюрн,   ,
  { {0x63bd0006,0x6d4b3170,0x7ae72049,0x00000000}},	//   ipsn, shga, сюдж,
  { {0xdb00006d,0x68e91647,0xe37c0041,0x00000000}},	//   _atmó, tged, ארגר,
  { {0x316934d2,0x68e934d3,0xd99600de,0x00000000}},	//   nnaz_, uged, ينوت_,
  { {0xfbe00161,0x6d4934d4,0x68e934d5,0x00000000}},	//   _नियम, _ilea, rged,
  { {0xa3e80053,0x7524007d,0x68e934d6,0x00000000}},	//   मंस_, _sniz, sged,
  { {0x63bd006f,0xa2ba0053,0xf5060f50,0x00000000}},	//   epsn, ्रस्, озно,
  { {0xc329014e,0x2f0a0022,0x69de0066,0x00000000}},	//   _בו_, mógł_, špec,
  { {0x395f34d7,0xd3fa0085,0xd38a0054,0x00000000}},	//   mius_, шэні_, ийме_,
  { {0x394d03d9,0x957d0045,0xdb010016,0x00000000}},	//   lhes_, stąp, _silê,
  { {0x69dc1781,0x6d492bc4,0x2be00053,0x00000000}},	//   _året, _olea, _निभा,
  { {0x395f0498,0x73e6019c,0x9987005f,0x00000000}},	//   nius_, _доиз, mynų_,
  { {0x2b890066,0xa284005d,0x00000000,0x00000000}},	// [5a40] júco_, تیگو,   ,
  { {0x6d4934d8,0x6e3e0137,0xdb01002b,0x00000000}},	//   _alea, typb, _dilë,
  { {0x395f0006,0x6d420072,0x6d4934d9,0x00000000}},	//   kius_, tkoa, _blea,
  { {0x6d4934da,0xd5fa0041,0x4c862ceb,0x00000000}},	//   _clea, יפער, олев,
  { {0xa01b34db,0x6d4207b7,0x6d490139,0x00000000}},	//   _szöv, rkoa, _dlea,
  { {0x6d493061,0x6d4234dc,0x394d004e,0x00000000}},	//   _elea, skoa, ehes_,
  { {0x6d490fc4,0xc3330063,0x8fa3151b,0x00000000}},	//   _flea, ווג_, _царе,
  { {0xa01b00fe,0x68400025,0x395f34dd,0x00000000}},	//   _myön, _nádú, gius_,
  { {0x87060062,0x872a000d,0xa01b0072,0x00000000}},	//   ояне, аўна_, _lyön,
  { {0x656d34de,0x394d004b,0xf1bf0066,0x00000000}},	//   _sjah, ahes_, ýške_,
  { {0xceb30063,0x395f2020,0xa01b0075,0x00000000}},	//   וית_, bius_, _nyön,
  { {0xd90e007e,0x394d081b,0xda650593,0x00000000}},	//   _شیخ_, ches_, _عالي,
  { {0xd7ef0032,0xa91d00c2,0xb7180263,0x00000000}},	//   _لكن_, olžn, _голф_,
  { {0x63bd34df,0x75d40044,0x31c70085,0x00000000}},	//   rpsn, _فيتا, жсав,
  { {0x656d0150,0x53980054,0x95ca34e0,0x00000000}},	//   _tjah, івся_, _тула_,
  { {0x63bd0137,0xa3e80053,0x61f50244,0x00000000}},	//   ppsn, मूह_, rtzl,
  { {0x2eab0001,0x9055000d,0xb2a70021,0x00000000}},	// [5a50] ањен_, чвац, _وحده,
  { {0x6d490025,0x3ea706a5,0x249f008f,0x00000000}},	//   _slea, ønt_, žums_,
  { {0x6d491a74,0x98af001c,0x63ad34e1,0x00000000}},	//   _plea, _logā_, _huan,
  { {0x63ad10ca,0x395f0268,0x657d34e2,0x00000000}},	//   _kuan, xius_, nosh,
  { {0x7c070021,0xdb0034e3,0x63ad1944,0x00000000}},	//   تباك, _sumá, _juan,
  { {0xdb0100ea,0xaa350062,0x657d0168,0x00000000}},	//   _kilé, зхищ, hosh,
  { {0x395f34e4,0xeaf80754,0x63a534e5,0x00000000}},	//   tius_, ترنت_, _mihn,
  { {0x6131069f,0x39810014,0x21391f51,0x00000000}},	//   _påly, jóst_, _josh_,
  { {0x395f34e6,0x63ad34e7,0xab870083,0x00000000}},	//   rius_, _nuan, _дужк,
  { {0x394d0b7a,0x99870006,0x395f34e8,0x00000000}},	//   shes_, tynų_, sius_,
  { {0x395f00eb,0x673c00c7,0x394d12ee,0x00000000}},	//   pius_, örja, phes_,
  { {0xa3d70161,0x661c0146,0x63ad34e9,0x00000000}},	//   ाओं_, ærka, _buan,
  { {0x63ad048e,0xdb01006c,0x00000000,0x00000000}},	//   _cuan, _ailé,   ,
  { {0x98ad017f,0x63ad34ea,0x68fb001f,0x00000000}},	//   iječ_, _duan, lfud,
  { {0x62850185,0x3cff0061,0x63ad004d,0x00000000}},	//   _cyho, _obuv_, _euan,
  { {0x55da00b5,0x68fb002b,0x63ad00a3,0x00000000}},	//   _פֿונ, nfud, _fuan,
  { {0x63ad34eb,0x75d0004c,0xb4d80042,0x00000000}},	// [5a60] _guan, _vězň, ाणी_,
  { {0xa01b00fe,0xdce9007d,0x1e960e51,0x00000000}},	//   _työn, _dječ, прер,
  { {0x6285001f,0xf7720063,0x200f0026,0x00000000}},	//   _gyho, עקב_, ægir_,
  { {0x442034ec,0x2be00053,0xdd9201fb,0x00000000}},	//   _kri_, _निदा, روش_,
  { {0x7c2600c3,0x60c42892,0x0eba007f,0x00000000}},	//   _škrb, mbim, _губы_,
  { {0x60c40812,0x7bc90185,0x442034ed,0x00000000}},	//   lbim, _dweu, _mri_,
  { {0x657d0ba7,0x68fb001f,0x6738007d,0x00000000}},	//   yosh, ffud, _rovj,
  { {0x442034ee,0x4ddb0063,0x60c40089,0x00000000}},	//   _ori_, _לחלו, nbim,
  { {0x6738017f,0xebe30540,0xdb0000b9,0x00000000}},	//   _povj, _потп, _rumæ,
  { {0x95d8000a,0x63ad34ef,0x4427001b,0x00000000}},	//   одот_, _ruan, _ăn_,
  { {0x442031e6,0x657d34f0,0x3abb0063,0x00000000}},	//   _ari_, tosh, _המבנ,
  { {0x442000f3,0x63ad005b,0x6dac0058,0x00000000}},	//   _bri_, _puan, _işad,
  { {0x9f40006d,0x442034f1,0x63ad0e5c,0x00000000}},	//   ntió_, _cri_, _quan,
  { {0x889b0063,0x657d0035,0x4420001f,0x00000000}},	//   _הבדי, sosh, _dri_,
  { {0x3981007a,0x442034f2,0x6f1500c2,0x00000000}},	//   póst_, _eri_, _razc,
  { {0x60f90088,0x26ce001f,0x63ad0ebe,0x00000000}},	//   ўная_, _hefo_, _tuan,
  { {0xf485007e,0xe81f0053,0x442034f3,0x00000000}},	// [5a70] _تاثی, बिया_, _gri_,
  { {0xeeab000d,0xdce9007d,0xc885004d,0x00000000}},	//   стак_, _vječ, ößig_,
  { {0x8cf50088,0xc5f8001c,0x213900f1,0x00000000}},	//   дзец, ntē_, _tosh_,
  { {0x3f9a017e,0xc5f8008f,0xe7dd0042,0x00000000}},	//   ampu_, itē_, _मिलप,
  { {0xfc46001b,0x1be90086,0x6dac000c,0x00000000}},	//   _đích_, ідки_, _aşad,
  { {0xdb09005b,0xc5f8008f,0xac74005d,0x00000000}},	//   _önün, ktē_, رانش,
  { {0xa3b40235,0x6b4f00b9,0xd2b8009a,0x00000000}},	//   _जून_, _nøge, הלות_,
  { {0x3a3a0137,0x673c0137,0xa01b0072,0x00000000}},	//   äppa_, örjn, _lyöm,
  { {0x661c00b9,0xd7ee0021,0x68fb00a8,0x00000000}},	//   ærkn, لكي_, rfud,
  { {0x6b4f010a,0xb4e60161,0xdb230072,0x00000000}},	//   _bøge, कल्प_, äräm,
  { {0x442034f4,0xa50a0cd6,0x23cb0082,0x00000000}},	//   _sri_, оена_, ़ीसद,
  { {0x2b920003,0x442018c4,0x637f004c,0x00000000}},	//   râce_, _pri_, háně,
  { {0x9755005e,0xe8940085,0xb8e30042,0x00000000}},	//   _откљ, _заць, ्र_,
  { {0x7d0b00e8,0x7989001f,0x9f400003,0x00000000}},	//   hegs, llew, prié_,
  { {0x03a30612,0x26c5002b,0x201c008f,0x00000000}},	//   тиро, mblo_, āvim_,
  { {0x61e100ea,0x442034f5,0xa01b0072,0x00000000}},	//   álla, _tri_, _työl,
  { {0x442034f6,0x60c434f7,0xa01b013d,0x00000000}},	// [5a80] _uri_, rbim, _ször,
  { {0x2fc000ca,0x42560044,0xd1ba00de,0x00000000}},	//   rpig_, _ينظر, _واجا_,
  { {0x7cf1013d,0x2be00042,0xe29a34f8,0x00000000}},	//   zűrő, _निहा, _фан_,
  { {0x25e00053,0xe8df0013,0x2fc0331d,0x00000000}},	//   _किसी_, _trộm_, ppig_,
  { {0xdca33121,0x798934f9,0x00000000,0x00000000}},	//   ваци, dlew,   ,
  { {0x9f4002dd,0x7d0b0019,0x798934fa,0x00000000}},	//   rtió_, aegs, elew,
  { {0x9f40234b,0x798900ac,0x2be00053,0x00000000}},	//   stió_, flew, _निवा,
  { {0xb81402a9,0xa81425d5,0x6b4f01e1,0x00000000}},	//   едиј, едиш, _røge,
  { {0x6b4f1631,0x36d40fc7,0xc6e6012c,0x00000000}},	//   _søge, нопр, мінп,
  { {0x7bc2221f,0xeeeb008b,0x99890130,0x00000000}},	//   mpou, _đừng_, ćaš_,
  { {0xa01b0072,0x6d4a34fb,0x79890168,0x00000000}},	//   _ryöm, ūfau, blew,
  { {0xc5f8001c,0xc8660ac5,0x26c51f66,0x00000000}},	//   rtē_, _отли, ablo_,
  { {0x24920051,0xc5f8001c,0x443f008b,0x00000000}},	//   _czym_, stē_, âu_,
  { {0xdb19004d,0xc5f8008f,0x69d808ed,0x00000000}},	//   sswö, ptē_, osve,
  { {0x442d000c,0xd13b042a,0xf1a720cc,0x00000000}},	//   ţe_, оха_, дран,
  { {0x69d834fc,0xf1940054,0x6fb90145,0x00000000}},	//   isve, вись, згар_,
  { {0x657600ea,0xa01b0072,0x25a9004b,0x00000000}},	// [5a90] ézhe, _työm, _iial_,
  { {0xa01b00fe,0x64400963,0x69d834fd,0x00000000}},	//   _hyök, ämie, ksve,
  { {0x637f0080,0x7d0b00ea,0x656f170c,0x00000000}},	//   ráně, tegs, onch,
  { {0x2be00053,0x60dd00b9,0x69d834fe,0x00000000}},	//   _निशा, _udsm, dsve,
  { {0x7bc40529,0x636900c2,0x7d0b34ff,0x00000000}},	//   ţiun, ažne, regs,
  { {0x98af0045,0x6b4f00b9,0x2be00053,0x00000000}},	//   _mogą_, _søgb, _निरा,
  { {0x3f810080,0x53380047,0xa91d0066,0x00000000}},	//   mohu_, ונגן_, hože,
  { {0x9f400014,0x2d78007d,0x6e942a35,0x00000000}},	//   ltið_, včeg_, _рису,
  { {0x99410051,0x79893500,0x69d83501,0x00000000}},	//   móż_, rlew, asve,
  { {0x656f0016,0xe7310032,0x798900ac,0x00000000}},	//   ench, اصة_, slew,
  { {0x2b89034d,0x2489003e,0xcb340062,0x00000000}},	//   júci_, _ayam_, _шефъ,
  { {0xdb013502,0x2b890066,0x98730023,0x00000000}},	//   _milí, dúci_, ažām_,
  { {0x66e5000d,0xb9360047,0xf9920149,0x00000000}},	//   _зола, _רננו_, _ערד_,
  { {0x212b051e,0xdbc6004b,0x0443005e,0x00000000}},	//   _anch_, _tööe, ћерн,
  { {0x27ed3503,0x7bc2004c,0x2b890066,0x00000000}},	//   luen_, zpou, rúch_,
  { {0xa91d0dd8,0x9f400014,0x290d00dd,0x00000000}},	//   bože, etið_, neea_,
  { {0x6566002c,0x27ed3504,0xdfd2007e,0x00000000}},	// [5aa0] mikh, nuen_, ايط_,
  { {0xe1fa0055,0xa01b024a,0x2cad0034,0x00000000}},	//   _его_, _myöh, _aged_,
  { {0x64463505,0xdb010764,0x9afe0013,0x00000000}},	//   lyki, _cilí, _nitơ_,
  { {0x41bb0063,0x65663506,0xa2ba0053,0x00000000}},	//   _מצטע, nikh, ्रक्,
  { {0xdb010014,0x64460078,0x290d00dd,0x00000000}},	//   _eilí, nyki, deea_,
  { {0x69d83507,0xdb01349f,0x27ed0b06,0x00000000}},	//   tsve, _filí, duen_,
  { {0x656600a4,0x69d80072,0x27ed3508,0x00000000}},	//   kikh, usve, euen_,
  { {0x64460006,0xf41f00fe,0xeeeb008b,0x00000000}},	//   kyki, yvä_, _đứng_,
  { {0x27ed0876,0x69d83509,0x25a9350a,0x00000000}},	//   guen_, ssve, _rial_,
  { {0x644600eb,0x79800035,0x61ee00a4,0x00000000}},	//   dyki, somw, kubl,
  { {0x61ee00b2,0x0f570063,0xa3d30042,0x00000000}},	//   jubl, גיים_, हीन_,
  { {0xb4eb0161,0xa91d085a,0x290d003b,0x00000000}},	//   मले_, tože, ceea_,
  { {0x25a90d7e,0xf7460448,0x656f0206,0x00000000}},	//   _vial_, _педо, rnch,
  { {0xa91d350b,0x61e100ea,0x7528008f,0x00000000}},	//   rože, állo, ēdza,
  { {0xa01b024a,0x61ee027c,0x41e42049,0x00000000}},	//   _työk, gubl, літа,
  { {0xf8b20161,0xfc46008b,0xa91d007d,0x00000000}},	//   ीडिय, _đính_, pože,
  { {0xa91d0080,0x752d0035,0x212b0013,0x00000000}},	// [5ab0] ložc, _inaz, _vnch_,
  { {0xdb01350c,0x20e1008b,0x6281004b,0x00000000}},	//   _milã, ỗi_, ülos,
  { {0x9f40007a,0x7bc4003b,0x7bc0350d,0x00000000}},	//   rtið_, ţiul, _atmu,
  { {0xf42a0066,0x9f400014,0x3f81004e,0x00000000}},	//   späť_, stið_, sohu_,
  { {0x9f400014,0x99410022,0x4d880044,0x00000000}},	//   ptið_, róż_, رَهُ_,
  { {0x656600ac,0x16100053,0x8c42350e,0x00000000}},	//   zikh, ़बार_, реше,
  { {0xddcb0006,0x7ceb005b,0x64460051,0x00000000}},	//   čiųj, görü, zyki,
  { {0xa91d00c2,0x27ed350f,0x9d183510,0x00000000}},	//   olži, tuen_, _пост_,
  { {0xa3d3016a,0xa91d00c3,0x290d003b,0x00000000}},	//   हीम_, tožb, reea_,
  { {0x7d1b3511,0x64460006,0x27ed0093,0x00000000}},	//   _haus, vyki, ruen_,
  { {0x6b833512,0xd5e50062,0x6d980871,0x00000000}},	//   mong, ъжни, bíad,
  { {0xd46a000a,0x64460915,0x7d1b00cc,0x00000000}},	//   диме_, tyki, _jaus,
  { {0x656600e8,0x27ed234b,0x44243513,0x00000000}},	//   rikh, quen_, ím_,
  { {0x64460006,0x6b833514,0x66e53515,0x00000000}},	//   ryki, nong, _рока,
  { {0x6b8305b3,0x64460b66,0x6263013e,0x00000000}},	//   iong, syki, авра,
  { {0x64460078,0xc0e30002,0x9f400072,0x00000000}},	//   pyki, иоск, ntiö_,
  { {0x6b833516,0xef1a0076,0xdb080164,0x00000000}},	// [5ac0] kong, мма_, _fidè,
  { {0x03aa0021,0x3eae05e7,0x9f400072,0x00000000}},	//   _تدعو_, øft_, htiö_,
  { {0x60d62a7a,0x6b833517,0x7d1b3518,0x00000000}},	//   paym, dong, _baus,
  { {0x98ad0080,0x69de1c0d,0xdb00000e,0x00000000}},	//   ěněn_, špek, _humø,
  { {0x69c13519,0x6b832423,0x3f980168,0x00000000}},	//   _atle, fong, _thru_,
  { {0x7ceb005b,0xef1f0022,0x6b83351a,0x00000000}},	//   törü, ążce_, gong,
  { {0x2b890024,0x6f1c0025,0x7d1b2a81,0x00000000}},	//   júcu_, _iarc, _faus,
  { {0x7d1b00eb,0xdce2007d,0x6d4b004d,0x00000000}},	//   _gaus, dnoć, ckga,
  { {0x6d400025,0x7ceb0058,0x6f1c351b,0x00000000}},	//   _ioma, sörü, _karc,
  { {0x98af0051,0x47340001,0x7d1b01b3,0x00000000}},	//   _mogę_, унос, _zaus,
  { {0x6f1c2810,0xa4d501dd,0x6d40351c,0x00000000}},	//   _marc, лоні, _koma,
  { {0x4e350047,0xb4bf0053,0x6d400a52,0x00000000}},	//   אָשן_, ेरे_, _joma,
  { {0xdb080003,0x6d40330e,0xdb0100be,0x00000000}},	//   _aidé, _moma, _hilá,
  { {0x6d402418,0x36d42dc1,0x6f1c351d,0x00000000}},	//   _loma, _сокр, _narc,
  { {0xa91d01a6,0xd4c70002,0x22590121,0x00000000}},	//   loža, _испп, хивы_,
  { {0x6d40003d,0x752d0a1a,0x6b4f00b9,0x00000000}},	//   _noma, _unaz, _nøgn,
  { {0xa91d007d,0x63690078,0x6f1c2737,0x00000000}},	// [5ad0] noža, ažna, _barc,
  { {0xdb080003,0x7d1b351e,0xa8570063,0x00000000}},	//   _fidé, _saus, דימה_,
  { {0x3ea700c7,0x7c221203,0x6d402a5b,0x00000000}},	//   änt_, evor, _boma,
  { {0xbd18019d,0xa159000d,0x6b830035,0x00000000}},	//   кції_, _чаму_, wong,
  { {0x6b83351f,0x20060164,0x7c223520,0x00000000}},	//   tong, çoit_, gvor,
  { {0x6b830035,0x7afc004d,0x68e200be,0x00000000}},	//   uong, _örtl, _adod,
  { {0xa3d3016a,0x2d870003,0xc3340063,0x00000000}},	//   हीत_, înes_, יוס_,
  { {0x6b830a69,0x7c2206ac,0x6f1c3521,0x00000000}},	//   song, bvor, _zarc,
  { {0x6b833522,0x5c751225,0x77850121,0x00000000}},	//   pong, _слат, ллиз,
  { {0xaa0b0021,0xdce2007d,0x6d40006f,0x00000000}},	//   _يزال_, tnoć, _zoma,
  { {0x8c4201f7,0x2ca90024,0x69c13523,0x00000000}},	//   _öğre, ľadu_, _utle,
  { {0x7528008f,0x20190059,0xa91d0734,0x00000000}},	//   ēdzo, _ossi_, boža,
  { {0x2d8f0027,0xdce2007d,0x6d9800be,0x00000000}},	//   ilge_, snoć, líac,
  { {0x291d0b1c,0x6d5a0078,0x43753524,0x00000000}},	//   _hawa_, _įtam, ауст,
  { {0x201921b7,0xc0e60071,0x291d2a14,0x00000000}},	//   _assi_, ловк, _kawa_,
  { {0x291d00f3,0x291f0009,0xdb083525,0x00000000}},	//   _jawa_, ndua_, _vidé,
  { {0x27ff0d81,0x6f1c3526,0xd0260085,0x00000000}},	// [5ae0] ntun_, _parc, ымай,
  { {0x6b4f010a,0x2d8f3527,0x764e00d1,0x00000000}},	//   _søgn, elge_, øbyg,
  { {0x2019051e,0x394d02ab,0x6d401b27,0x00000000}},	//   _essi_, kkes_, _poma,
  { {0x291d20ea,0x7c2204d9,0x200b0150,0x00000000}},	//   _nawa_, tvor, _fpci_,
  { {0x0b8a1c5e,0x6f1c0051,0x7d023528,0x00000000}},	//   нски_, _tarc, rfos,
  { {0x8c430138,0x6d400034,0x2d870003,0x00000000}},	//   сеље, _woma, îner_,
  { {0x27410080,0x6d403529,0x2be00161,0x00000000}},	//   _méně_, _toma, _निका,
  { {0xdb01000f,0x6d4000fe,0x2120352a,0x00000000}},	//   _vilá, _uoma, ndih_,
  { {0xcaf600b3,0x291d0035,0x2000352b,0x00000000}},	//   _مساب, _dawa_, ntii_,
  { {0x394d0034,0xa01b0072,0xa91d08ed,0x00000000}},	//   akes_, _työv, roža,
  { {0xd5b70055,0x6440024a,0xa37b352c,0x00000000}},	//   лся_, ämin, nsõe,
  { {0x291d1040,0xc8b60021,0x9f520072,0x00000000}},	//   _gawa_, _إصاب, ltyä_,
  { {0x765a0022,0x4992005d,0x6fb00082,0x00000000}},	//   szty, _پیکر, _अंगू,
  { {0x77f7014e,0x6b4f0146,0xa01b00fe,0x00000000}},	//   _עמוד_, _nøgl, _myöt,
  { {0xf3ff017d,0x31c4352d,0x659507b0,0x00000000}},	//   stã_, йств, _каку,
  { {0x9f520072,0x6d580983,0x26190042,0x00000000}},	//   htyä_, ëval, _बनती_,
  { {0xc05b019d,0xb4db00cd,0xf1940200,0x00000000}},	// [5af0] хів_, khàz, сить,
  { {0x4429352e,0x394d009c,0x7ed4005d,0x00000000}},	//   _ira_, zkes_, مزما,
  { {0xc33200b5,0xb7c3000c,0x636900c3,0x00000000}},	//   _ווי_, ăţil, lžno,
  { {0xa37b004b,0x2d8f004b,0x2be00042,0x00000000}},	//   ssõd, ulge_, _निखा,
  { {0x60cd352f,0x291d3530,0x2000003b,0x00000000}},	//   mbam, _rawa_, ctii_,
  { {0x291d0009,0xbec3008f,0x60cd3531,0x00000000}},	//   _sawa_, čūse, lbam,
  { {0xba77007e,0x61e1013d,0x26140042,0x00000000}},	//   داشت, állh, _फैली_,
  { {0x44293532,0x7d040019,0x27ff0026,0x00000000}},	//   _ora_, õist, ttun_,
  { {0x291f3533,0x2d7800a8,0x27ff0058,0x00000000}},	//   rdua_, očen_, utun_,
  { {0x753d0045,0x27ff3534,0x394d3535,0x00000000}},	//   ejsz, rtun_, skes_,
  { {0x27ff1b33,0x394d0150,0x44293536,0x00000000}},	//   stun_, pkes_, _ara_,
  { {0x6e2106b2,0x6d5a0006,0x44290ddc,0x00000000}},	//   _álbu, _įtak, _bra_,
  { {0x99840032,0xa01b00fe,0x60cd2061,0x00000000}},	//   _النو, _myös, dbam,
  { {0x33190088,0x44293537,0x27ed00a5,0x00000000}},	//   ліся_, _dra_, mren_,
  { {0x29d30529,0xc5d5019d,0x82a60086,0x00000000}},	//   nţa_, _тіль, равж,
  { {0x867a014e,0x44290c32,0x27ed3538,0x00000000}},	//   _ברצו, _fra_, oren_,
  { {0x657d000f,0x9f520072,0x27ed3539,0x00000000}},	// [5b00] érhe, ytyä_, nren_,
  { {0xdd1f0066,0x6dac003b,0x7d09353a,0x00000000}},	//   _ríšs, _eşal, _abes,
  { {0x27ed0199,0x2fc900bb,0xa01b024a,0x00000000}},	//   hren_, apag_, _syöt,
  { {0x44290812,0xa37b03d9,0x2cb20031,0x00000000}},	//   _yra_, rsõe, øyd_,
  { {0xa37b03d9,0x9f52024a,0x27ed00b9,0x00000000}},	//   ssõe, ttyä_, jren_,
  { {0x6b460026,0x69dc06a5,0x61ee06a5,0x00000000}},	//   _aðgr, _ærek, orbl,
  { {0x12e900b5,0x9f5200fe,0x27ed353b,0x00000000}},	//   אַפּ, rtyä_, eren_,
  { {0xa01b00fe,0x9f5200fe,0xd943005e,0x00000000}},	//   _työt, styä_, жећи,
  { {0xdce9007d,0x29d3003b,0x57b3007f,0x00000000}},	//   _sjeć, aţa_, обыт,
  { {0xa91d00c3,0xf803000d,0xeb76000d,0x00000000}},	//   ložl, ічын, _тыбэ,
  { {0x27ed353c,0xe8fa0651,0x44291289,0x00000000}},	//   aren_, _але_, _sra_,
  { {0x99750055,0x69ca00bd,0x44290e24,0x00000000}},	//   _лучш, mpfe, _pra_,
  { {0x7d0100ea,0x53471fa5,0x6369007d,0x00000000}},	//   láró, ахва, užno,
  { {0x4429021f,0x389b0149,0x35f7005d,0x00000000}},	//   _vra_, _סיגנ, درید_,
  { {0xe1670001,0x6dac005b,0x6d58008f,0x00000000}},	//   ађан, _aşam, īvaj,
  { {0x4429353d,0x04670054,0x60cd004b,0x00000000}},	//   _tra_, _втом, ubam,
  { {0x909906be,0xa01b0072,0x4429353e,0x00000000}},	// [5b10] уват_, _ryös, _ura_,
  { {0xa37b004b,0x7d01013d,0xbf020042,0x00000000}},	//   ssõb, káró, र्लभ_,
  { {0x7d0100ea,0x6d5904bf,0x2fc90139,0x00000000}},	//   járó, thwa, spag_,
  { {0x27ed001f,0xdd98000d,0x61f50058,0x00000000}},	//   yren_, ашч_, muzl,
  { {0xf1a405ac,0x8cc60042,0xd8260044,0x00000000}},	//   _фрэн, ाड़ो, _ةٍ_,
  { {0x6d59353f,0xab64013c,0x9e35007f,0x00000000}},	//   shwa, овіл, _легч,
  { {0xa01b00fe,0x61f5005b,0x7d01013d,0x00000000}},	//   _työs, nuzl, gáró,
  { {0x9915019d,0x29d3003b,0x7d0906a5,0x00000000}},	//   ські, rţa_, _ubes,
  { {0x27ed3540,0xccf2014e,0xdc550131,0x00000000}},	//   uren_, _מכן_, _увањ,
  { {0x6d5a0078,0x27ed3541,0x7d01013d,0x00000000}},	//   _įtai, rren_, báró,
  { {0xaa950021,0xe81c0042,0x69de011b,0x00000000}},	//   _الاث, _बैठा_, ápet,
  { {0x05560c07,0x6e360063,0x27ed3542,0x00000000}},	//   стоя, צטרף_, pren_,
  { {0x6c790047,0x321a005d,0xd8b80044,0x00000000}},	//   ראָפ, گيزد_, _ضدنا_,
  { {0xdc9a0047,0xc87900dd,0xf668005d,0x00000000}},	//   טירל, gaşe_, احیه_,
  { {0x661c010a,0x61ee00f5,0x15462a3b,0x00000000}},	//   ærkt, urbl, _гейм,
  { {0x2167036a,0xdb083543,0x31bc3544,0x00000000}},	//   биси_, _ridí, _víz_,
  { {0x4127011c,0x25ab00cd,0x937a0021,0x00000000}},	// [5b20] щото_, ïble_, _مصدر_,
  { {0x79890250,0xa01b00fe,0x66f90053,0x00000000}},	//   hoew, _pyör, ्भिक_,
  { {0x257200c2,0xdce00023,0xa2b7009a,0x00000000}},	//   ašle_, _ammā, _לפיד_,
  { {0xb5fa0047,0xddb7000d,0xd5fa0047,0x00000000}},	//   טלעכ, ёгіі_, טפער,
  { {0x9f4000fe,0x1ab43545,0xdd8f0049,0x00000000}},	//   triä_, обля, روه_,
  { {0x7d0100ea,0xa01b0072,0xd5b80023,0x00000000}},	//   táró, _työr, uvāk_,
  { {0x0f570047,0x46db0042,0xcb0700de,0x00000000}},	//   _פילם_, _मज़ह, صيين_,
  { {0xa3d8016a,0x69ca004d,0xed570861,0x00000000}},	//   ाठा_, rpfe, _лос_,
  { {0x7d0100ea,0xeafa0021,0x9f490014,0x00000000}},	//   sáró, _مرات_, otað_,
  { {0x25a00da5,0x9f490026,0x501b0063,0x00000000}},	//   _ahil_, ntað_, נויו,
  { {0x151502dc,0x2f3b009d,0x00000000,0x00000000}},	//   одня, אגיד,   ,
  { {0x9f470512,0x61f50058,0x25a0006c,0x00000000}},	//   čné_, vuzl, _chil_,
  { {0xa3d30161,0x5896006a,0x9f490014,0x00000000}},	//   हीं_, _اجاز, ktað_,
  { {0x661c010a,0x9f40017d,0x96ba2469,0x00000000}},	//   ærks, ssiê_, _суду_,
  { {0x39460004,0x26de3546,0x6d98006d,0x00000000}},	//   _koos_, mato_, vían,
  { {0x26de0c9c,0x9055012c,0x86c20043,0x00000000}},	//   lato_, овбц, _بيژن,
  { {0x656f3547,0xdbf1004c,0x61f50058,0x00000000}},	// [5b30] mich, _příh, suzl,
  { {0x26de3134,0x656f3548,0x39463549,0x00000000}},	//   nato_, lich, _loos_,
  { {0x656f0290,0x62880022,0x2ddb0044,0x00000000}},	//   oich, żdor, ابطة_,
  { {0x656f354a,0xd5fb0041,0x6ad10082,0x00000000}},	//   nich, רפאר, हर्र,
  { {0x69c8001c,0x9f490139,0x1b190121,0x00000000}},	//   _atde, lraí_, ижды_,
  { {0x656f0199,0x7528001c,0x26de004c,0x00000000}},	//   hich, ēdzi, jato_,
  { {0x9f490025,0x644f001f,0x39462493,0x00000000}},	//   nraí_, hyci, _boos_,
  { {0x656f0080,0x7bcb0137,0x3ebb0078,0x00000000}},	//   jich, ppgu, šytą_,
  { {0xf8ae006a,0xa91d0512,0x5fe20053,0x00000000}},	//   نکه_, ložk, _पिछल,
  { {0x26de354b,0x656f00bd,0x0609270f,0x00000000}},	//   gato_, eich, анок_,
  { {0xe57a005a,0x656f354c,0x3a3a0137,0x00000000}},	//   изо_, fich, äppt_,
  { {0x656f354d,0x957d005f,0x34aa354e,0x00000000}},	//   gich, drąs, ивно_,
  { {0x26de1eee,0x66e501f6,0xe73905a0,0x00000000}},	//   bato_, _дола, _вел_,
  { {0x26de02f6,0x16390032,0x9f490025,0x00000000}},	//   cato_, _نسبة_, fraí_,
  { {0x9f490027,0x656f354f,0x25b101a8,0x00000000}},	//   graí_, bich, çolà_,
  { {0x68fb3550,0x644f0051,0x7de0013d,0x00000000}},	//   ngud, byci, _lásá,
  { {0x0fda0076,0x9f400139,0x9f490014,0x00000000}},	// [5b40] рьбы_, mriú_, ttað_,
  { {0x44203551,0x67233552,0x75240089,0x00000000}},	//   _isi_, _janj, _haiz,
  { {0x61460079,0x8d660086,0x672316f4,0x00000000}},	//   _дена, овже, _manj,
  { {0x629e0198,0x568c00b5,0x6723003e,0x00000000}},	//   _izpo, נטאַ, _lanj,
  { {0x44200080,0x75243553,0x2d7800c2,0x00000000}},	//   _jsi_, _maiz, lček_,
  { {0x3946021f,0x656f3554,0x67233555,0x00000000}},	//   _soos_, zich, _nanj,
  { {0x26de02f6,0x644f0045,0xde030086,0x00000000}},	//   vato_, zyci, _опри,
  { {0x7524007d,0xdb0800f8,0x60c43556,0x00000000}},	//   _naiz, _didá, ncim,
  { {0x26de055b,0x656f0ee6,0x6d98006d,0x00000000}},	//   tato_, vich, níam,
  { {0xfa360021,0x672305d5,0x8c1b0063,0x00000000}},	//   _وراد, _canj, _דומי,
  { {0x26de3134,0x656f3557,0x75243558,0x00000000}},	//   rato_, tich, _baiz,
  { {0x26de3559,0x6d42003b,0x60c4007d,0x00000000}},	//   sato_, njoa, jcim,
  { {0x656f355a,0x26de355b,0x26030331,0x00000000}},	//   rich, pato_, año_,
  { {0x9f490025,0x656f355c,0x60c4355d,0x00000000}},	//   traí_, sich, ecim,
  { {0x75240d87,0x9f400025,0x316b0001,0x00000000}},	//   _faiz, briú_, ашао_,
  { {0xd1380088,0x9f490027,0x6723355e,0x00000000}},	//   оху_, rraí_, _zanj,
  { {0x656d00bb,0xcebb0001,0x10040062,0x00000000}},	// [5b50] _imah, аље_, дяхм,
  { {0x68e00397,0x3dd8001f,0x60c4076d,0x00000000}},	//   hamd, _bwrw_, acim,
  { {0x3dd8002b,0x68e02eda,0x7bc926d3,0x00000000}},	//   _cwrw_, kamd, _steu,
  { {0x6d980e7c,0x26dc355f,0x9ce7000d,0x00000000}},	//   bíam, _levo_, іцел,
  { {0x9f4002dd,0x31cf0047,0x6d980331,0x00000000}},	//   guió_, _אָנפֿר, cíam,
  { {0x8b22047e,0x64400072,0x3dd8002b,0x00000000}},	//   едше, ämii, _fwrw_,
  { {0x7de000ea,0x60dd005b,0x656d1f75,0x00000000}},	//   _vásá, _kesm, _omah,
  { {0xad27007e,0xf27c0063,0x627c0149,0x00000000}},	//   _برآو, ירוש, ינונ,
  { {0x60dd03d9,0x6723351f,0x636900fc,0x00000000}},	//   _mesm, _panj, ažni,
  { {0x656d330d,0x75243560,0xdc880063,0x00000000}},	//   _amah, _saiz, _וְעָ,
  { {0x9f400025,0x6723027c,0xa37b0019,0x00000000}},	//   triú_, _vanj, tsõn,
  { {0x68e0000c,0x79680051,0x60dd3561,0x00000000}},	//   camd, yświ, _nesm,
  { {0x752400eb,0x60c4007d,0x395f0137,0x00000000}},	//   _vaiz, vcim, mhus_,
  { {0x442024e9,0xa37b004b,0x6d9800be,0x00000000}},	//   _vsi_, ssõn, víam,
  { {0x44200051,0x60c4007d,0x395f004b,0x00000000}},	//   _wsi_, tcim, ohus_,
  { {0x629e018a,0x2d782414,0x21673052,0x00000000}},	//   _vzpo, rček_, писи_,
  { {0x44203562,0x60dd12c7,0xb4d80053,0x00000000}},	// [5b60] _usi_, _desm, िरी_,
  { {0x60dd0004,0x1eaa0032,0x6d980b23,0x00000000}},	//   _eesm, ماضي_, ríam,
  { {0xf53f1d0d,0xddcb005b,0x395f1310,0x00000000}},	//   kmål_, ğişk, khus_,
  { {0xcf8900b5,0xeeeb008b,0x6d5b0025,0x00000000}},	//   אט_, _đụng_, _clua,
  { {0x6d42024a,0xf53f00d1,0xeb9a0002,0x00000000}},	//   rjoa, dmål_, бид_,
  { {0x6d5b0019,0x2007003b,0xac970021,0x00000000}},	//   _elua, ănit_, أنها_,
  { {0x8e830002,0x7c2b0137,0x26dc07b7,0x00000000}},	//   _згре, avgr, _revo_,
  { {0x6d5b0025,0x8b66007e,0xd91a0086,0x00000000}},	//   _glua, _کارم, ськ_,
  { {0x68e0002c,0xf803000d,0x48140054,0x00000000}},	//   ramd, нчэн, ємос,
  { {0x23a40137,0x68e03563,0x395f004e,0x00000000}},	//   nöjd_, samd, ahus_,
  { {0xd6d70055,0xf5e30083,0xd9f00082,0x00000000}},	//   чты_, ніям, _घटित_,
  { {0xd5b70076,0x23a40137,0x19bb009a,0x00000000}},	//   ясь_, höjd_, _המאב,
  { {0x60dd09fb,0xe4a40121,0x545427b8,0x00000000}},	//   _resm, ерро, евят,
  { {0x69dc06a5,0x2fcb007d,0x60dd00be,0x00000000}},	//   _æres, _rtcg_, _sesm,
  { {0xa1950086,0x60dd01b3,0x56930785,0x00000000}},	//   давч, _pesm, _пашт,
  { {0x9f470080,0xf67b0063,0xa91d00c2,0x00000000}},	//   ční_, _לאומ, toži,
  { {0x60dd027d,0xd0110044,0x00000000,0x00000000}},	// [5b70] _vesm, ضلا_,   ,
  { {0xa91d3564,0x6d5b0139,0x61f20058,0x00000000}},	//   roži, _slua, üklü,
  { {0x6d5a0006,0x7d190051,0x657d3565,0x00000000}},	//   _įtar, tews, onsh,
  { {0xa91d0124,0x657d3566,0xaffd0054,0x00000000}},	//   poži, nnsh, _комi,
  { {0xa4b80063,0xc5f8008f,0x7d193567,0x00000000}},	//   פלגה_, dzēm_, rews,
  { {0x20090006,0x60c20066,0xdd16017c,0x00000000}},	//   mtai_, ľome, väťd,
  { {0xc9a90076,0x395f3568,0x20093569,0x00000000}},	//   овке_, thus_, ltai_,
  { {0x21290974,0x32380063,0xdce900c2,0x00000000}},	//   ndah_, לטון_, _kmeč,
  { {0x98bd0051,0xf53f060b,0x21290222,0x00000000}},	//   _nową_, rmål_, idah_,
  { {0x200900eb,0xf53f356a,0x85e90098,0x00000000}},	//   itai_, smål_, одов_,
  { {0x7ae3356b,0xdb030025,0xdcfb02f7,0x00000000}},	//   mant, nmní, _ljuč,
  { {0x20090006,0xdb030025,0x7ae3356c,0x00000000}},	//   ktai_, imní, lant,
  { {0x0563005a,0x212911fe,0xc9740593,0x00000000}},	//   твян, ddah_, _ثالث,
  { {0x7ae30029,0x21290089,0x07a4071f,0x00000000}},	//   nant, edah_, _заін,
  { {0x6b4f1262,0x6dbe0024,0x7ae3356d,0x00000000}},	//   _høgs, _vďak, iant,
  { {0x7ae3356e,0x2d7800b2,0xd5b80023,0x00000000}},	//   hant, lčev_, avās_,
  { {0x75c80080,0xdee61406,0xd00708b0,0x00000000}},	// [5b80] _věze, дози, мете_,
  { {0xef170076,0x21290089,0x7ae3356f,0x00000000}},	//   мму_, adah_, jant,
  { {0x9d46005a,0x44320240,0x23a40137,0x00000000}},	//   межд, _hry_, röjd_,
  { {0x4432021f,0x7ae33037,0x2d8f30b3,0x00000000}},	//   _kry_, eant, goge_,
  { {0x6b540268,0x7ae31e3e,0x25620014,0x00000000}},	//   _hàgi, fant, _tólf_,
  { {0x7ae33570,0x60d6002b,0x8c43005e,0x00000000}},	//   gant, lbym, теље,
  { {0x61fc0426,0x6e96005d,0x539b009d,0x00000000}},	//   nurl, _آلزا, חיסו,
  { {0x6b4f0146,0x6b5400cd,0x2d8f006d,0x00000000}},	//   _søgt, _màgi, coge_,
  { {0xdb0800fe,0x79a3005a,0xfce3005e,0x00000000}},	//   _pidä, ърше, _шото,
  { {0x657d0034,0xddc9000c,0x7ae30aca,0x00000000}},	//   wnsh, _înţe, cant,
  { {0xdceb001c,0x61fc0089,0x7bc03571,0x00000000}},	//   ligā, jurl, _humu,
  { {0x7bc03572,0x44323573,0x20093574,0x00000000}},	//   _kumu, _bry_, ytai_,
  { {0x7bc00009,0x44323575,0xed5f0066,0x00000000}},	//   _jumu, _cry_, úžia_,
  { {0x44320034,0x289b0063,0x7bc03576,0x00000000}},	//   _dry_, _וידא, _mumu,
  { {0xa2940086,0x7bc03577,0xb607004a,0x00000000}},	//   варі, _lumu, _vaší,
  { {0x2129003e,0xc17b0086,0xdbc60058,0x00000000}},	//   udah_, іїв_, _göçe,
  { {0x7bc0003d,0xc05b019d,0x44320051,0x00000000}},	// [5b90] _numu, ців_, _gry_,
  { {0x20093578,0x7ae33579,0xdce9007d,0x00000000}},	//   rtai_, xant, _rjeđ,
  { {0x2009357a,0x7ae3357b,0xdceb008f,0x00000000}},	//   stai_, vant, eigā,
  { {0x7bc0002c,0xe510008b,0x7ae312bc,0x00000000}},	//   _bumu, _lặng_, want,
  { {0x0c75007e,0x7ee70062,0x4fc40121,0x00000000}},	//   رگرد, _оцве, _асса,
  { {0x7bc000a4,0xe510008b,0x7ae30419,0x00000000}},	//   _dumu, _nặng_, uant,
  { {0x7ae3357c,0xdeb4000d,0xa91d004c,0x00000000}},	//   rant, _абры, kožt,
  { {0xd2b8014e,0xaa560021,0x7ae3357d,0x00000000}},	//   ולות_, عليا_, sant,
  { {0x6d5900ac,0x7bc00dac,0x7ae32e47,0x00000000}},	//   mkwa, _gumu, pant,
  { {0xd7090be6,0xa37b004b,0x6d59357e,0x00000000}},	//   чное_, ssõj, lkwa,
  { {0x6dac01f7,0xcf920063,0x395d002b,0x00000000}},	//   _işar, רטי_, _tlws_,
  { {0xab5d0051,0x7bc0132d,0x7ae10611,0x00000000}},	//   _duże, _yumu, _helt,
  { {0x4424008b,0x69c127a3,0x7ae1357f,0x00000000}},	//   ìm_, _hule, _kelt,
  { {0x6b540c3f,0x69c13580,0xfbd20063,0x00000000}},	//   _pàgi, _kule, רתם_,
  { {0x2d780240,0x7ae13581,0x03a30121,0x00000000}},	//   očet_, _melt, уиро,
  { {0xdb0102dd,0x644001a5,0x69c13582,0x00000000}},	//   _kiló, ämis, _mule,
  { {0x20870071,0x69c13583,0x6d59006f,0x00000000}},	// [5ba0] ейти_, _lule, dkwa,
  { {0xdceb001c,0x6d59006f,0x69c10003,0x00000000}},	//   vigā, ekwa, _oule,
  { {0x7bc03584,0x6d5900ac,0x17560047,0x00000000}},	//   _sumu, fkwa, עסער_,
  { {0x7bc0002c,0xedd3006a,0x9f47027d,0x00000000}},	//   _pumu, ايند, čná_,
  { {0xe5050161,0x7ae13585,0xdca31240,0x00000000}},	//   ष्टि_, _belt, гаци,
  { {0x6d593586,0x7ae10305,0x69c13587,0x00000000}},	//   akwa, _celt, _bule,
  { {0x78a200ea,0x443f008b,0x7ae13588,0x00000000}},	//   _szov, ̣u_, _delt,
  { {0x7bc000bb,0x7ae10019,0x799b00a4,0x00000000}},	//   _tumu, _eelt, gluw,
  { {0xd90d007e,0x7c24005b,0x7ae13589,0x00000000}},	//   تین_, çird, _felt,
  { {0x999c0006,0x7ae1358a,0x7c22358b,0x00000000}},	//   tyvų_, _gelt, mwor,
  { {0xa4d50086,0x7d02358c,0x7c22358d,0x00000000}},	//   коні, ogos, lwor,
  { {0xdb010460,0x7d02358e,0x7ae1358f,0x00000000}},	//   _filó, ngos, _zelt,
  { {0x69c100bd,0xe510008b,0x9947007e,0x00000000}},	//   _zule, _tặng_, _سلول_,
  { {0xdbc70004,0xb4bb007e,0xd3240200,0x00000000}},	//   _tööt, _کاغذ_, льси,
  { {0x22580080,0xdb0100cd,0xb1a7005e,0x00000000}},	//   _čeká_, _kilò, ешак,
  { {0xa69b0063,0x569b009a,0x6f1e00a3,0x00000000}},	//   _משופ, _מיוצ, eepc,
  { {0x442f007a,0xdb0a0014,0x7d020022,0x00000000}},	// [5bb0] _ég_, amfé, dgos,
  { {0x7c223590,0x32550131,0x7d023591,0x00000000}},	//   dwor, _авор, egos,
  { {0x6d59006f,0xf7730047,0x7c2230de,0x00000000}},	//   tkwa, נקע_, ewor,
  { {0x9f40006d,0x7ae13592,0x69c13593,0x00000000}},	//   frió_, _selt, _rule,
  { {0xa37b0019,0x212b001f,0x6fb50021,0x00000000}},	//   esõi, _iach_, _لمحا,
  { {0x6f1e1e4c,0x69c11ff0,0x212b01a8,0x00000000}},	//   cepc, _pule, _hach_,
  { {0xda620071,0xee840121,0x7ae13594,0x00000000}},	//   ивши, _быто, _velt,
  { {0x7ae10199,0x99150086,0x9f400118,0x00000000}},	//   _welt, тькі, brió_,
  { {0x7c870001,0x68e23595,0xe7b40078,0x00000000}},	//   _чуве, _deod, _šešė,
  { {0x69c13596,0x7c24005b,0x212b0700,0x00000000}},	//   _tule, çire, _lach_,
  { {0xdb0100cd,0x799b00a4,0x3b640062,0x00000000}},	//   _filò, pluw, _сътв,
  { {0x212b3597,0x201900f3,0x68e23598,0x00000000}},	//   _nach_, _opsi_, _geod,
  { {0xa01b0072,0x9cd6009a,0xc483012c,0x00000000}},	//   _työy, כורה_, илюк,
  { {0x987a0047,0xf3ff017d,0x394f0783,0x00000000}},	//   _קאסט, azão_, _hogs_,
  { {0x27ff024a,0x02190086,0x212b3599,0x00000000}},	//   luun_, ніть_, _bach_,
  { {0x7c22359a,0x8afc0022,0xf1a90044,0x00000000}},	//   ywor, _klęc, فاقه_,
  { {0xf5770032,0x6b5d0164,0x27ff00fe,0x00000000}},	// [5bc0] _جميع_, _règn, nuun_,
  { {0x212b0037,0xd36f0032,0x93fb0e2a,0x00000000}},	//   _each_, _وهي_, _קליי,
  { {0x212b0333,0x00000000,0x00000000,0x00000000}},	//   _fach_,   ,   ,
  { {0x212b0027,0x27ff00fe,0x202700fe,0x00000000}},	//   _gach_, kuun_, äviä_,
  { {0x6e3500bd,0x0b8a0336,0x7d02359b,0x00000000}},	//   _erzb, мски_, rgos,
  { {0x9f401143,0x7d0200ed,0x67130053,0x00000000}},	//   rrió_, sgos, त्मक_,
  { {0x7db6000d,0x212b0dde,0x6e350022,0x00000000}},	//   _асац, _yach_, _grzb,
  { {0xdb0902dd,0xa37b004b,0xdceb003b,0x00000000}},	//   _dueñ, rsõi, rigă,
  { {0xc173014e,0x5963005a,0x4b26000a,0x00000000}},	//   יחה_, ръща, _имав,
  { {0x95d8000a,0x47330fdc,0x02be0042,0x00000000}},	//   ндот_, аньс, ्डोन,
  { {0x0f570063,0x6b7b009f,0x68e2359c,0x00000000}},	//   דיים_, _קרבנ, _teod,
  { {0x8a790047,0xa5d7005d,0xd5b80a7d,0x00000000}},	//   _אָנק, کبیر_, кся_,
  { {0x385a0044,0x161e0042,0x9998013d,0x00000000}},	//   _تشاد_, _बनकर_, _érő_,
  { {0x27f90066,0x212b359d,0xa857009a,0x00000000}},	//   ásne_, _sach_, _בידה_,
  { {0x53340001,0x31c41259,0xa0220072,0x00000000}},	//   јест, иств, ööno,
  { {0xf1a70699,0xc6b7009a,0x50f4359e,0x00000000}},	//   тргн, _בלוז_, изст,
  { {0x290400a4,0x6733004c,0x4fc402d7,0x00000000}},	// [5bd0] igma_, řejš, асха,
  { {0x4429359f,0x212b004d,0xdd340043,0x00000000}},	//   _isa_, _wach_, یرنظ,
  { {0x733a00b5,0x212b001f,0x752f0051,0x00000000}},	//   _װערס, _tach_, odcz,
  { {0xff5f003b,0xeea80062,0x867b009a,0x00000000}},	//   _atît_, ттук_, ורבו,
  { {0xdb0902dd,0xed59017f,0x75c1008f,0x00000000}},	//   _sueñ, _niže_, _vēzi,
  { {0x27ff00fe,0x6c52005e,0xaed40085,0x00000000}},	//   vuun_, скљу, _ворш,
  { {0xdb0101d9,0xc879003b,0x9f400046,0x00000000}},	//   _uhlí, maşi_, mrið_,
  { {0xc879000c,0x44290aba,0x27ff00fe,0x00000000}},	//   laşi_, _osa_, tuun_,
  { {0x38ca007e,0x7c840002,0x60cd35a0,0x00000000}},	//   رايی_, _куфе, icam,
  { {0x75c80080,0x7c2935a1,0xed59007d,0x00000000}},	//   _vězn, _iser, _diže_,
  { {0x394f00c7,0xc879003b,0x27ff0072,0x00000000}},	//   _togs_, iaşi_, suun_,
  { {0xd763007e,0x27ff0072,0xc3290063,0x00000000}},	//   انگی, puun_, _מו_,
  { {0x1994000d,0x60cd35a2,0xe72e00e2,0x00000000}},	//   _таця, dcam, _ле_,
  { {0x752f0051,0xdce2001c,0x44292ee0,0x00000000}},	//   adcz, bloķ, _dsa_,
  { {0x6b5d03b2,0x442935a3,0x27ed02ea,0x00000000}},	//   _règl, _esa_, lsen_,
  { {0xc879000c,0x3f9800d1,0x9f400026,0x00000000}},	//   eaşi_, _skru_, erið_,
  { {0x27ed35a4,0xc9520063,0x7c2935a5,0x00000000}},	// [5be0] nsen_, זמן_, _nser,
  { {0x32460138,0x7d0935a6,0x27ed2be7,0x00000000}},	//   _беог, _aces, isen_,
  { {0x277600b7,0x7c291fa9,0x60cd2321,0x00000000}},	//   נגען_, _aser, bcam,
  { {0x7c290016,0x27ed35a7,0x60cd0290,0x00000000}},	//   _bser, ksen_, ccam,
  { {0x7c2900ea,0x27ed153a,0xc7c80013,0x00000000}},	//   _cser, jsen_, _mốc_,
  { {0x6be30032,0x6721017f,0x27ed35a8,0x00000000}},	//   حكوم, jelj, dsen_,
  { {0x7c2935a9,0x672101b3,0x61ee35aa,0x00000000}},	//   _eser, delj, nsbl,
  { {0x290400a4,0x61ee00f5,0x89380095,0x00000000}},	//   ugma_, isbl, тпис_,
  { {0x31570047,0x6d4035ab,0x672100ea,0x00000000}},	//   טיקן_, _inma, felj,
  { {0xa8170021,0x656435ac,0x256200ea,0x00000000}},	//   اتير_, _alih, _róla_,
  { {0x49060032,0x7aea00b9,0xc7c80013,0x00000000}},	//   _مواق, maft, _bốc_,
  { {0xc5f8003d,0x61ee115e,0xc7c80013,0x00000000}},	//   dzēt_, dsbl, _cốc_,
  { {0xc9930032,0xb9930032,0x61ee00ac,0x00000000}},	//   _النظ, _النب, esbl,
  { {0x442935ad,0x660135ae,0x7bcf0003,0x00000000}},	//   _vsa_, bulk, _écue,
  { {0xd6270001,0xdb1a35af,0x9f4000fe,0x00000000}},	//   _боје_, _cité, isiä_,
  { {0x7aea0199,0xc7c8008b,0x29ca008b,0x00000000}},	//   haft, _gốc_, _mùa_,
  { {0x9f4035b0,0x765a00fe,0xc879003b,0x00000000}},	// [5bf0] ksiä_, lyty, taşi_,
  { {0x7d090387,0x60cd30a3,0xa8570063,0x00000000}},	//   _sces, scam, אימה_,
  { {0xc879003b,0x7aea0360,0x539c0063,0x00000000}},	//   raşi_, daft, _איזו,
  { {0xeb1d0161,0xcce7007e,0x27ed35b1,0x00000000}},	//   फ़्त_, اساي, ysen_,
  { {0x3b0908a0,0x69d800ac,0x88bd0022,0x00000000}},	//   вело_, epve, ieśc,
  { {0x6d4035b2,0xdb010139,0x4bd8005d,0x00000000}},	//   _enma, _bhlá, ابند_,
  { {0x67212cf1,0xdb010027,0xcb660054,0x00000000}},	//   velj, _chlá, раще_,
  { {0x27ed35b3,0x765a2c17,0x0a18005d,0x00000000}},	//   tsen_, dyty, افيک_,
  { {0x7c2935b4,0x672135b5,0x68e935b6,0x00000000}},	//   _user, telj, raed,
  { {0x27ed35b7,0x61ee00ac,0x9f400072,0x00000000}},	//   rsen_, ysbl, csiä_,
  { {0xcb68006a,0xc5f8003d,0x27ed2be6,0x00000000}},	//   _حمله_, dzēs_, ssen_,
  { {0x67210add,0xdb1a0827,0x27ed35b8,0x00000000}},	//   selj, _rité, psen_,
  { {0x672135b9,0x660135ba,0x61ee002b,0x00000000}},	//   pelj, sulk, wsbl,
  { {0x394d000f,0x61ee35bb,0x765a0022,0x00000000}},	//   ljes_, tsbl, byty,
  { {0xc7c8008b,0x395f35bc,0xdb010137,0x00000000}},	//   _tốc_, okus_, _filö,
  { {0x395f0006,0x65640035,0xc5f8001c,0x00000000}},	//   nkus_, _ulih, rzēt_,

  { {0x629e0051,0xb05b0137,0x61ee35bd,0x00000000}},	// [5c00] _wypo, _sfär, ssbl,
  { {0x395f0019,0x629e35be,0x61ee35bf,0x00000000}},	//   hkus_, _typo, psbl,
  { {0x394d0122,0x395f0019,0x26e30053,0x00000000}},	//   kjes_, kkus_, _ग़ैर_,
  { {0xf1bf001b,0x29ca0013,0xdd8f014d,0x00000000}},	//   _giá_, _rùa_, وول_,
  { {0x386d0d0e,0x394d0d0e,0xd24f007e,0x00000000}},	//   jzer_, djes_, _فنی_,
  { {0xdce6005b,0xdb97000d,0x765a0072,0x00000000}},	//   ımın, авіч_, yyty,
  { {0x636b00bd,0xca48007e,0x9966005e,0x00000000}},	//   _fünf, العه_, итил,
  { {0x7aea05b9,0x765a0072,0x6d4035c0,0x00000000}},	//   saft, vyty, _unma,
  { {0xed570076,0x2012015d,0x777a01a8,0x00000000}},	//   _тот_, ntyi_, titx,
  { {0x394d006d,0x69d835c1,0x636b35c2,0x00000000}},	//   ajes_, ppve, _zünf,
  { {0x386d0016,0xd6860076,0x68fd0006,0x00000000}},	//   azer_, рупп, ųsda,
  { {0x6b9801f2,0x79530021,0x765a0051,0x00000000}},	//   lovg, _وَلا, ryty,
  { {0x9f47034d,0x765a00fe,0x636b0b64,0x00000000}},	//   čnú_, syty, _jüng,
  { {0x93880076,0x69c835c3,0x31600058,0x00000000}},	//   асса_, _kude, ekiz_,
  { {0x7ae835c4,0x22b80021,0x96b7005e,0x00000000}},	//   _medt, لدفع_, _кућу_,
  { {0x69c82393,0xeeeb008b,0x7ae835c5,0x00000000}},	//   _mude, _đựng_, _ledt,
  { {0x657d35c6,0xdb010013,0x69c835c7,0x00000000}},	// [5c10] mish, _kilô, _lude,
  { {0x69c80173,0x657d077d,0x395f00c2,0x00000000}},	//   _oude, lish, zkus_,
  { {0x69c835c8,0x75d3000c,0x395f0078,0x00000000}},	//   _nude, _găzd, ykus_,
  { {0x657d077d,0xbbf50044,0xf296009a,0x00000000}},	//   nish, مستث, _לכתר_,
  { {0xdc980086,0xf5380149,0x3d080053,0x00000000}},	//   авці_, יטאר_, _हारे_,
  { {0x657d0009,0x69c82e26,0x636b004d,0x00000000}},	//   hish, _bude, _düng,
  { {0x657d0009,0x394d35c9,0x0a6b005a,0x00000000}},	//   kish, tjes_, ърди_,
  { {0x386d04da,0xdd940088,0x248d0045,0x00000000}},	//   tzer_, _дасы, żemy_,
  { {0x2562048e,0x657d0009,0x7ae800b9,0x00000000}},	//   _sólo_, dish, _fedt,
  { {0x386d00bd,0x645d0006,0x2562017d,0x00000000}},	//   rzer_, dysi, _pólo_,
  { {0x386d000f,0x657d075a,0x394d006f,0x00000000}},	//   szer_, fish, pjes_,
  { {0x7a7a00b5,0x201200fe,0xa0220019,0x00000000}},	//   _גרעס, ytyi_, ööko,
  { {0x69c800bd,0x7bc900cd,0x7bc135ca,0x00000000}},	//   _zude, _jueu, _kilu,
  { {0x657d0035,0x69c80509,0x289a0063,0x00000000}},	//   aish, _yude, _גינא,
  { {0x657d29da,0x7d1b14d8,0x7bc90003,0x00000000}},	//   bish, _obus, _lueu,
  { {0x201200fe,0x98a20078,0x75d3003b,0x00000000}},	//   ttyi_, žką_, _văzd,
  { {0x9f400027,0x636b00bd,0x80aa0c0b,0x00000000}},	// [5c20] msiú_, _bünd, ував_,
  { {0x73060138,0x9f400025,0x201200fe,0x00000000}},	//   _упоз, lsiú_, rtyi_,
  { {0xb3bb0063,0x201200fe,0x9f490025,0x00000000}},	//   _תמיכ, styi_, csaí_,
  { {0xdb1b0026,0x2364001c,0xdd990086,0x00000000}},	//   _stuð, īmju_, аші_,
  { {0x69c835cb,0x7bc135cc,0xad65007e,0x00000000}},	//   _sude, _bilu, غامه,
  { {0x657d0009,0x636b005b,0xc7c8008b,0x00000000}},	//   zish, _günd, _bốn_,
  { {0x7ae802ab,0x7bc11366,0x645d0051,0x00000000}},	//   _vedt, _dilu, zysi,
  { {0x7bc100eb,0xafdb35cd,0x636b00bd,0x00000000}},	//   _eilu, _drøf, _zünd,
  { {0x7bc9135d,0xdce9017f,0x96ea35ce,0x00000000}},	//   _gueu, _smeć, льна_,
  { {0x657d0b54,0x69c835cf,0xfe0c0053,0x00000000}},	//   wish, _tude, _हमास_,
  { {0x69c8024a,0x657d0009,0x44202fb3,0x00000000}},	//   _uude, tish, _api_,
  { {0x6b5d0268,0x645d0006,0xc4e30053,0x00000000}},	//   _règi, tysi, परेख,
  { {0x657d29da,0x3f9a001c,0x53470062,0x00000000}},	//   rish, kopu_, бхва,
  { {0x657d0009,0x645d35d0,0x442035d1,0x00000000}},	//   sish, rysi, _dpi_,
  { {0x657d0009,0x200027d7,0x636b004b,0x00000000}},	//   pish, erii_, _ründ,
  { {0x9f490027,0x44200150,0x636b1ab2,0x00000000}},	//   rsaí_, _fpi_, _sünd,
  { {0x2d870080,0x9f5535d2,0xcf7901ce,0x00000000}},	// [5c30] énem_, овач, абац_,
  { {0x80d90235,0xdb1a01a8,0x3ec7030b,0x00000000}},	//   _फ्रे, _bití, ссаб,
  { {0x7bc101f4,0xbfa80854,0x7bc90005,0x00000000}},	//   _rilu, стте_, _sueu,
  { {0xa69b0047,0x200035d3,0x7bc135d4,0x00000000}},	//   נשאפ, brii_, _silu,
  { {0x6aa1001f,0x7bc935d5,0x8c420058,0x00000000}},	//   _sylf, _queu, _öğle,
  { {0x76450026,0xacf7005d,0x2418009a,0x00000000}},	//   _áhyg, _گسست, צחון_,
  { {0x636b005b,0x6d4d004b,0x7bc135d6,0x00000000}},	//   _güne, öaas, _vilu,
  { {0xc7c8008b,0x7bc90003,0x27ff35d7,0x00000000}},	//   _vốn_, _tueu, trun_,
  { {0x7d040025,0x69c235d8,0x6aa1002b,0x00000000}},	//   óise, _dioe, _wylf,
  { {0x75d3000c,0xc7c8008b,0xd7750021,0x00000000}},	//   _răzb, _tốn_, تابع,
  { {0xaa670856,0xc7c80013,0xda020053,0x00000000}},	//   _утак, _uốn_, रूआत_,
  { {0x857a0002,0x442035d9,0xdb1a002b,0x00000000}},	//   рсот_, _ppi_, _gitâ,
  { {0x6fa90042,0xa3d30085,0x3d0e0082,0x00000000}},	//   कतां, моўч, ण्टे_,
  { {0xfbd20063,0x437535da,0xe8840085,0x00000000}},	//   ותך_, пуст, _эгіп,
  { {0x6b840025,0x44200089,0x443935db,0x00000000}},	//   éigi, _wpi_, avs_,
  { {0x44202660,0x79892493,0xe0da08b0,0x00000000}},	//   _tpi_, nnew, рва_,
  { {0x88bd0045,0x291d0035,0x442035dc,0x00000000}},	// [5c40] ześn, _mbwa_, _upi_,
  { {0x799b0122,0x7c24005b,0x20fa008b,0x00000000}},	//   houw, çirm, ỏi_,
  { {0x6441003d,0xc3330063,0x4e2a0bb8,0x00000000}},	//   ālie, _חות_, роен_,
  { {0xafdb02ab,0x68eb007d,0x20001423,0x00000000}},	//   _brød, _negd, prii_,
  { {0xead41485,0x798935dd,0x69c2002b,0x00000000}},	//   поль, dnew, _rioe,
  { {0x69c2002b,0x7989059f,0x636b35de,0x00000000}},	//   _sioe, enew, _tüne,
  { {0x7989002b,0x6b8d0139,0xbea335df,0x00000000}},	//   fnew, éaga, _жарк,
  { {0x799b006f,0x298a0856,0xa37b017d,0x00000000}},	//   gouw, јско_, mpõe,
  { {0xf74a019d,0x98b7005a,0xe7260086,0x00000000}},	//   аїни_, олът_, оєнн,
  { {0x25620026,0x78a20035,0x7c2d0555,0x00000000}},	//   _fólk_, _vyov, çare,
  { {0x799b0122,0xe5350183,0x7f3b009a,0x00000000}},	//   bouw, пень, בעיו,
  { {0x68460021,0xdb1a003b,0xe45f0072,0x00000000}},	//   _وَال, _uitâ, työ_,
  { {0xd5b80071,0xccf30063,0x94ab35e0,0x00000000}},	//   юсь_, וכר_, ртна_,
  { {0x44390b2a,0x25a00075,0xb86500de,0x00000000}},	//   rvs_, _ekil_, _عانو,
  { {0x2d873384,0x6728017f,0xd1bb009e,0x00000000}},	//   ének_, medj, لارا_,
  { {0x672835e1,0x4fd50121,0x3495183e,0x00000000}},	//   ledj, зжат, _найр,
  { {0x656f0025,0x50670603,0xb4d70042,0x00000000}},	// [5c50] mhch, цтва, िडी_,
  { {0x69da35e2,0x6728007d,0x644000b9,0x00000000}},	//   _otte, nedj, æmie,
  { {0x6608004b,0x5f740044,0xa91d0605,0x00000000}},	//   nudk, ذاكر, liže,
  { {0xf6530063,0x8d74002a,0x0dc8012c,0x00000000}},	//   וצע_, وانا, ілій_,
  { {0x636b01f7,0x60d60047,0x69da35e3,0x00000000}},	//   _günc, _מורא_, _atte,
  { {0x394603d9,0x3c1e001c,0x6728007d,0x00000000}},	//   _anos_, dāvā_, jedj,
  { {0xaa560001,0x6608053b,0x63a708ea,0x00000000}},	//   зију_, judk, iljn,
  { {0x2bcb0042,0x3cf80044,0x850a0082,0x00000000}},	//   ाददा, _وعقد_, _वाइट_,
  { {0x799b0122,0x69da35e4,0xa91d027c,0x00000000}},	//   rouw, _ette, jiže,
  { {0x25a035e5,0x7989001f,0x68eb0717,0x00000000}},	//   _skil_, snew, _wegd,
  { {0x6370089f,0x8674000d,0xdb03013d,0x00000000}},	//   _häng, дыяц, jlné,
  { {0x656f057a,0x2d9d0051,0xdb1a00be,0x00000000}},	//   ghch, nowe_, _titã,
  { {0xed590a80,0x33d50086,0xe4690121,0x00000000}},	//   _mož_, діст, ошёл_,
  { {0x69da35e6,0x637035e7,0x29d10046,0x00000000}},	//   _ytte, _mäng, _káa_,
  { {0x637035e8,0x88bd0045,0x2d9d0051,0x00000000}},	//   _läng, ześl, kowe_,
  { {0x41b50086,0xc6920063,0x9f47027d,0x00000000}},	//   дсут, _ראה_, čný_,
  { {0x2d9d0051,0x200935e9,0x10090021,0x00000000}},	// [5c60] dowe_, guai_, قتلى_,
  { {0x2ca400a5,0x161f0042,0x7e9a0044,0x00000000}},	//   _rymd_, _बहार_, منذر_,
  { {0x3f8f017d,0xdd8f19b6,0x2d9d056c,0x00000000}},	//   égua_, еш_, fowe_,
  { {0xed590080,0x20090089,0xdb010139,0x00000000}},	//   _což_, buai_, _ghlú,
  { {0xcb340062,0xdb1a01a8,0xa37b00be,0x00000000}},	//   делъ, _pità, spõe,
  { {0x88bd0045,0x6c830032,0xe9e60bd8,0x00000000}},	//   reśl, علوم, пцио,
  { {0x321804ff,0x2d9d0051,0xdb1a01d1,0x00000000}},	//   ntry_, bowe_, _citá,
  { {0x637035ea,0x66080137,0x2d9d0022,0x00000000}},	//   _händ, vudk, cowe_,
  { {0x637035eb,0x394600c3,0x6728007d,0x00000000}},	//   _känd, _vnos_, tedj,
  { {0xf53f06a5,0x6608004b,0x45d41501,0x00000000}},	//   glån_, tudk, моос,
  { {0xaadb014e,0x69da16c0,0x9f52006d,0x00000000}},	//   _החבר, _utte, luyó_,
  { {0x394631ea,0x2c200053,0x63702063,0x00000000}},	//   _unos_, _यहां_, _länd,
  { {0xb447000d,0x63700137,0x660801c2,0x00000000}},	//   чэнк, _oänd, sudk,
  { {0xa91d085a,0x2d9d0022,0x656f35ec,0x00000000}},	//   riže, zowe_, shch,
  { {0x171b0063,0xa91d0078,0x35f700f2,0x00000000}},	//   _הווע, siže, _فريد_,
  { {0x20090397,0x636b004b,0xc5eb0063,0x00000000}},	//   tuai_, _düna, _הַזֹ,
  { {0x656d2b22,0x637035ed,0x9379030b,0x00000000}},	// [5c70] _ilah, _bänd, _мбит_,
  { {0x29030006,0x2d9d0051,0xcebb005e,0x00000000}},	//   ėjai_, wowe_, бље_,
  { {0x7bdb04c6,0x200908f0,0x2d9d0045,0x00000000}},	//   _stuu, suai_, towe_,
  { {0x98aa0051,0x6b5d0003,0x2fd90044,0x00000000}},	//   śbę_, _nègr, _ووجد_,
  { {0x2d9d0051,0xac09013c,0x636200be,0x00000000}},	//   rowe_, інка_, _sôni,
  { {0x7c94006a,0x2d9d0051,0x63700504,0x00000000}},	//   رشنا, sowe_, _väng,
  { {0x656d028d,0x2d9d0022,0xbb280085,0x00000000}},	//   _olah, powe_, яцце_,
  { {0x9f52006d,0x7d55000d,0xdb1a00ea,0x00000000}},	//   buyó_, _ўвах, _vitá,
  { {0x6370024a,0xdd940088,0x290d35ee,0x00000000}},	//   _häne, _чаты, rgea_,
  { {0x656d35ef,0x636200be,0x316c008f,0x00000000}},	//   _alah, _tôni, īdzi_,
  { {0x6370004b,0x656d0114,0x6b8335f0,0x00000000}},	//   _jäne, _blah, ming,
  { {0x6d5b0003,0x6b8335f1,0xf53f0137,0x00000000}},	//   _joua, ling, slån_,
  { {0x200f01a8,0xb8820066,0x637000a5,0x00000000}},	//   àgil_, šíri, _läne,
  { {0x7c2401f7,0x6d5b18e6,0x6b8335f2,0x00000000}},	//   çiri, _loua, ning,
  { {0xc7b2014e,0x21a60002,0x6b8335f3,0x00000000}},	//   _שבו_, дивм, iing,
  { {0x637000c7,0x6b8335f4,0x4fea0141,0x00000000}},	//   _sänd, hing, жман_,
  { {0x321835f5,0x88ba0047,0x9f490014,0x00000000}},	// [5c80] stry_, ַמעז, trað_,
  { {0x6d490025,0x656d00c2,0x6b8335f6,0x00000000}},	//   _anea, _zlah, jing,
  { {0xf2d3014e,0x6b831cdd,0x63700140,0x00000000}},	//   _בעת_, ding, _vänd,
  { {0x9f52006d,0x6370004d,0x9f4000f5,0x00000000}},	//   tuyó_, _däne, opië_,
  { {0x637000c7,0x6d5b35f7,0x6b8335f8,0x00000000}},	//   _tänd, _doua, fing,
  { {0x6b8335f9,0x7c2d19df,0x9f52006d,0x00000000}},	//   ging, çara, ruyó_,
  { {0x7f5c017d,0xbe1600de,0x00000000,0x00000000}},	//   _iorq, _توزع,   ,
  { {0xc7c8008b,0x6b830c55,0xed430794,0x00000000}},	//   _hối_, aing, _инсп,
  { {0x3ce635fa,0x872a000d,0x6b8335fb,0x00000000}},	//   mbov_, оўна_, bing,
  { {0x6d5b006c,0x3ae8005d,0x6b8325cb,0x00000000}},	//   _zoua, _ربطی_, cing,
  { {0x9f4000cd,0xc7c8008b,0xc9560121,0x00000000}},	//   lsió_, _mối_, _отды,
  { {0x7bc80397,0xc7c8008b,0xcdf70063,0x00000000}},	//   _hidu, _lối_, ומטי_,
  { {0x9f400268,0x7bc825e5,0x636b00bd,0x00000000}},	//   nsió_, _kidu, _dünn,
  { {0x926b0899,0xb4af0082,0x56943207,0x00000000}},	//   орба_, _करी_, _палт,
  { {0xc7c8008b,0x1b7b0047,0xa91d00b2,0x00000000}},	//   _nối_, קטלע, liža,
  { {0x6b8335fc,0x45fb0063,0x2618006c,0x00000000}},	//   zing, _וההג, méo_,
  { {0x6b83077d,0xf0bb007e,0x6aa801f2,0x00000000}},	// [5c90] ying, زارش_, _lydf,
  { {0x2fc70026,0x6362017d,0xc7c8008b,0x00000000}},	//   öng_, _bônu, _bối_,
  { {0xdb1a00fe,0x6b8335fd,0xc7c80013,0x00000000}},	//   _mitä, ving, _cối_,
  { {0x6b8335fe,0xc7c80013,0xac95030b,0x00000000}},	//   wing, _dối_, наеш,
  { {0x7bc80150,0x8b250121,0x50da0063,0x00000000}},	//   _bidu, едле, _מקרא,
  { {0x6b830035,0xc5f8008f,0x6738007d,0x00000000}},	//   uing, ksē_, _navj,
  { {0x7bc80801,0x6aa8002b,0x6b8306f1,0x00000000}},	//   _didu, _cydf, ring,
  { {0x26180164,0x6b8335ff,0xdb1a0019,0x00000000}},	//   déo_, sing, _aitä,
  { {0x6b833281,0x7bc82437,0xed59007d,0x00000000}},	//   ping, _fidu, _niži_,
  { {0x636b1f4a,0x9a270021,0xdce908ed,0x00000000}},	//   _sünn, _يعان, _mleč,
  { {0x6aa8002b,0xd7c90043,0x00000000,0x00000000}},	//   _gydf, _کوته_,   ,
  { {0xe9190086,0x2d8f00ac,0x7bc8003b,0x00000000}},	//   _ході_, nnge_, _zidu,
  { {0x31690240,0xe8060053,0x2d8f2523,0x00000000}},	//   dkaz_, _शिया_, inge_,
  { {0x4b790041,0x395d0168,0xb4fb0082,0x00000000}},	//   לאָו, _hows_, ्लॉप_,
  { {0x41b60601,0x02190054,0x7f5c006c,0x00000000}},	//   есат, міть_, _rorq,
  { {0x213906b8,0xc7c8008b,0x6738007d,0x00000000}},	//   _cash_, _rối_, _zavj,
  { {0x7f5c0747,0x63700137,0x21393600,0x00000000}},	// [5ca0] _porq, _vänb, _dash_,
  { {0xe3b20021,0x2d8f3601,0x27eb017c,0x00000000}},	//   _حرب_, enge_, ácny_,
  { {0xe8ac0235,0x7bc8051e,0xdce209a1,0x00000000}},	//   _चर्च, _ridu, skoč,
  { {0x22450146,0x7bc80019,0xafe60002,0x00000000}},	//   ælke_, _sidu, _помл,
  { {0x7bc80019,0xb1430121,0x6aa801e1,0x00000000}},	//   _pidu, _снял, _sydf,
  { {0x9f400994,0xc7c8001b,0xafdb0093,0x00000000}},	//   rsió_, _tối_, _krøn,
  { {0x9f400994,0x316c003d,0x996600e1,0x00000000}},	//   ssió_, ūdzu_, етпл,
  { {0x6738017f,0x9a670021,0x395d00e5,0x00000000}},	//   _savj, عميل_, _cows_,
  { {0xdb1a024a,0x7bc8003e,0xb4af0053,0x00000000}},	//   _pitä, _tidu, _करे_,
  { {0x26180003,0x7bdf0e7c,0xa91d00b2,0x00000000}},	//   téo_, íque, riža,
  { {0xe6940076,0x673a0137,0xa91d0078,0x00000000}},	//   тины, rdtj, siža,
  { {0xe4a73147,0xa91d08ed,0x6444004b,0x00000000}},	//   ерго, ližn, _brii,
  { {0xe7860259,0x213900e5,0x31692f3e,0x00000000}},	//   _пуко, _rash_, vkaz_,
  { {0x636b01f7,0x65b60080,0xafdb06a5,0x00000000}},	//   _günl, váhe, _brøn,
  { {0xb5a7019d,0xa5d70021,0xdcfb00c2,0x00000000}},	//   _прий, _كبير_, _smuč,
  { {0x8afc0022,0xdce93602,0x64442f47,0x00000000}},	//   _klęs, _pleč, _frii,
  { {0xc05b0086,0xaf07000a,0x6362017d,0x00000000}},	// [5cb0] чів_, ечек, _côns,
  { {0xa91d082a,0x44293603,0x660805a9,0x00000000}},	//   jižn, _ipa_, ordk,
  { {0xafdb02ab,0x6448001c,0xdce9007d,0x00000000}},	//   _grøn, ādie, _smeđ,
  { {0x753d000f,0x2d8f051e,0x3eaa00b9,0x00000000}},	//   ndsz, unge_, _dybt_,
  { {0x44290089,0x753d3604,0x395d2392,0x00000000}},	//   _jpa_, idsz, _rows_,
  { {0x996c0080,0x201c003b,0x1ee7007e,0x00000000}},	//   měř_, ăvit_, _سوری_,
  { {0x2d8702dd,0x6995005a,0x53380063,0x00000000}},	//   énes_, крих, גנון_,
  { {0x44293605,0x39780121,0x752f0022,0x00000000}},	//   _opa_, есью_, jecz,
  { {0x20090139,0x395d00e5,0x44293606,0x00000000}},	//   nrai_, _vows_, _npa_,
  { {0xe645005a,0x7c293096,0xab62005b,0x00000000}},	//   веоп, _iper, şürm,
  { {0x4429014f,0xa50a3607,0x66050062,0x00000000}},	//   _apa_, мена_, ъпна,
  { {0x200900eb,0x29030006,0x64443608,0x00000000}},	//   krai_, ėjas_, _prii,
  { {0xe72e0635,0x68e93609,0x66080934,0x00000000}},	//   _ке_, mbed, ardk,
  { {0x2009360a,0x68e9360b,0xf6250085,0x00000000}},	//   drai_, lbed, _адко,
  { {0xcb120e2a,0x2009360c,0x4429360d,0x00000000}},	//   ילם_, erai_, _epa_,
  { {0x68e9360e,0x644426ea,0x973c0130,0x00000000}},	//   nbed, _trii, moća,
  { {0x64a60001,0x64441a61,0x2fca0089,0x00000000}},	// [5cc0] _јапа, _urii, _pibg_,
  { {0xafdb0093,0x68e9004d,0x69cb360f,0x00000000}},	//   _trøn, hbed, _lige,
  { {0x7c293610,0x25b100ea,0x68e90104,0x00000000}},	//   _aper, _álló_, kbed,
  { {0x69cb3611,0xc7c80013,0xafdb05e7,0x00000000}},	//   _nige, _hốt_, _krøl,
  { {0xed59007d,0xa91d0124,0x62a30022,0x00000000}},	//   _nižu_, tižn, ętoś,
  { {0xdb030016,0x752f0045,0x79820035,0x00000000}},	//   lonê, zecz, _smow,
  { {0xa91d00b2,0xc7c80013,0x7c293612,0x00000000}},	//   rižn, _mốt_, _eper,
  { {0x79a6005a,0x58380330,0xc7c8008d,0x00000000}},	//   ърле, езия_, _lốt_,
  { {0x69cb14c5,0x99970062,0xdb013613,0x00000000}},	//   _dige, ъкът_, _chló,
  { {0x69cb3614,0x61fe0024,0xdb1a0e1f,0x00000000}},	//   _eige, _ovpl, _litú,
  { {0x752f0045,0x68e93615,0x44292bd8,0x00000000}},	//   tecz, bbed, _spa_,
  { {0x29121609,0x79820051,0x7af800c2,0x00000000}},	//   _øya_, _umow, lavt,
  { {0xc4580076,0xc7c80013,0x94a80065,0x00000000}},	//   виях_, _bốt_, втра_,
  { {0xa5c7007a,0x2009175f,0xc7c8008b,0x00000000}},	//   _bjóð, vrai_, _cốt_,
  { {0x2d843616,0xc7c80013,0x69c03617,0x00000000}},	//   _omme_, _dốt_, omme,
  { {0x656900fe,0x44293618,0x20093619,0x00000000}},	//   öehd, _tpa_, trai_,
  { {0x25a90150,0xa0c40021,0x7ff400f2,0x00000000}},	// [5cd0] _ikal_, ليفو, لسلا,
  { {0x6370361a,0x68e9017f,0x65b6004a,0x00000000}},	//   _täna, zbed, máha,
  { {0xf41f024a,0x637003c8,0x9f340086,0x00000000}},	//   ltä_, _känn, рехі,
  { {0x5c750a91,0x6370238f,0xf53f00a5,0x00000000}},	//   ллет, _jänn, ndå_,
  { {0xf41f024a,0x6370361b,0x69cb361c,0x00000000}},	//   ntä_, _männ, _rige,
  { {0x69cb2d2c,0xf41f024a,0x2d84024a,0x00000000}},	//   _sige, itä_, _emme_,
  { {0x69cb361d,0x68e9361e,0xf41f0072,0x00000000}},	//   _pige, tbed, htä_,
  { {0xe9a9007e,0x6441001c,0xd2b80063,0x00000000}},	//   رگان_, ālij, כלות_,
  { {0xccf20063,0x68e9361f,0x69cb3620,0x00000000}},	//   _לכן_, rbed, _vige,
  { {0x25a9003e,0x68e91b28,0x69c008ce,0x00000000}},	//   _akal_, sbed, amme,
  { {0xcb68006a,0xc7c80013,0x6370004b,0x00000000}},	//   _جمله_, _rốt_, _bänn,
  { {0xc7c80013,0xc9840699,0xceb207e9,0x00000000}},	//   _sốt_, _кучи, מיי_,
  { {0x973c017f,0xa5c70026,0x95830121,0x00000000}},	//   moćn, _sjóð, сляе,
  { {0xdb1a006d,0x69dc0003,0x66e2101a,0x00000000}},	//   _sitú, _érec, _лоша,
  { {0x679a0047,0x412a13e1,0xafdb01f2,0x00000000}},	//   _אױסג, ново_, _drøm,
  { {0x79890045,0x00e4007e,0x10a60f8d,0x00000000}},	//   niew, شتری, гибн,
  { {0xc7c8001b,0xceea000d,0xd0070ae8,0x00000000}},	// [5ce0] _tốt_, едзе_, лете_,
  { {0xef170001,0xdb030014,0x62090058,0x00000000}},	//   лму_, llnæ, üslü,
  { {0x9d46005a,0xdb030016,0x6fb30021,0x00000000}},	//   лежд, ponê, حملا,
  { {0xdb0300cd,0xacf60021,0xc237009a,0x00000000}},	//   lonè, اسات, _ערכו_,
  { {0x1af40454,0x2d9e0516,0x7af83621,0x00000000}},	//   апля, _ítem_, tavt,
  { {0x2cad00e5,0x5bb70e74,0xdfcf009b,0x00000000}},	//   _dyed_, глія_, _ريف_,
  { {0x39a60062,0x7af83622,0x2cad3623,0x00000000}},	//   лшив, ravt, _eyed_,
  { {0xf41f024a,0x798900e8,0x6e930032,0x00000000}},	//   ytä_, giew, _الفا,
  { {0xd6d00032,0x1d070062,0xd37f007d,0x00000000}},	//   يقة_, _щети_, šćih_,
  { {0x25a935cd,0x65b618a8,0x61e200c2,0x00000000}},	//   _skal_, váha, _čoln,
  { {0xdb0300cd,0x0f570063,0x98a40078,0x00000000}},	//   donè, איים_, demą_,
  { {0x1a9b00b7,0xf41f024a,0x86730054,0x00000000}},	//   _איבע, ttä_, слює,
  { {0x637001e3,0xdceb0078,0xf76f007e,0x00000000}},	//   _vänn, aigė, زای_,
  { {0xdb0300cd,0x636b004d,0xa66601fb,0x00000000}},	//   gonè, _küni, _مطبو,
  { {0xf41f09ff,0x637000fe,0x06b1004c,0x00000000}},	//   stä_, _tänn, čící_,
  { {0x65b60026,0x39810078,0x636b092a,0x00000000}},	//   páha, tųsi_, _müni,
  { {0x2ef5000a,0x26ca0066,0xdb01004c,0x00000000}},	// [5cf0] изар, ľbou_, _sklí,
  { {0x200706bb,0xdb0300cd,0x3dcd2a14,0x00000000}},	//   čni_, conè, _siew_,
  { {0x2cad1880,0x75d3003b,0xecf90601,0x00000000}},	//   _syed_, _păzi, вееш_,
  { {0xd258014b,0x00000000,0x00000000,0x00000000}},	//   _сць_,   ,   ,
  { {0x79890860,0xdca500e1,0x3dcd3624,0x00000000}},	//   view, јали, _view_,
  { {0xfbd000b3,0xda65005a,0x200f00cd,0x00000000}},	//   سته_, ивли, àgiu_,
  { {0x79892ac2,0xdd9b0088,0xc334009a,0x00000000}},	//   tiew, _зша_, מוס_,
  { {0x7c3e0051,0x7afd008f,0x8e840044,0x00000000}},	//   łpra, _ēstu, _طلقه,
  { {0x79893625,0x23a50053,0xae0d0053,0x00000000}},	//   riew, ओवाद, ांकन_,
  { {0x386200c7,0x79893626,0xa7b5005e,0x00000000}},	//   äkra_, siew, јсиј,
  { {0xafdb0093,0x0f580149,0x957d0078,0x00000000}},	//   _brøk, טיזם_, mpąj,
  { {0xd46a0002,0xe4c60062,0xdb033627,0x00000000}},	//   виме_, ийни, doné,
  { {0x7d040025,0x3775000d,0x7bcf0003,0x00000000}},	//   óisi, _выйс, _écus,
  { {0x63a700b2,0xafdb01e1,0x27ff3628,0x00000000}},	//   gojn, _trøj, msun_,
  { {0x0cb20235,0xafdb05b9,0x644b00f8,0x00000000}},	//   _जर्म, _frøk, _ágin,
  { {0x68fb00eb,0x00e63629,0x7a4000ea,0x00000000}},	//   naud, ржан, látá,
  { {0xdb030268,0x65b600ea,0x63a70606,0x00000000}},	// [5d00] ponè, láho, bojn,
  { {0xc3fb0063,0x27ff00fe,0x7a4000ea,0x00000000}},	//   _שליש, isun_, nátá,
  { {0x3eae1c23,0x7c3b362a,0x68fb0213,0x00000000}},	//   æft_, _asur, kaud,
  { {0x656400fe,0xe29b0063,0x27ff362b,0x00000000}},	//   _joih, _ישיר, ksun_,
  { {0x68fb001c,0x20da00a8,0xaa57005d,0x00000000}},	//   daud, ršič_, یلها_,
  { {0xf53f00c7,0xf4130063,0x65b6013d,0x00000000}},	//   llåt_, קפו_, káho,
  { {0x65b600ea,0x3f8f0003,0x65bd00ea,0x00000000}},	//   jáho, ègue_, léhe,
  { {0xada30088,0x7d1b0139,0x49380121,0x00000000}},	//   _дасл, _gcus, узию_,
  { {0xa3b60235,0x4973019d,0x65b60080,0x00000000}},	//   जता_, ільс, táhn,
  { {0xe56800b7,0x68fb004b,0x7c2200dd,0x00000000}},	//   _אַ_, aaud, mtor,
  { {0x637001e3,0x2d9e0164,0xa4d50086,0x00000000}},	//   _vänl, _êtes_, йоні,
  { {0x65b60080,0x6d40362c,0x7bcf0003,0x00000000}},	//   sáhn, _jama, _écur,
  { {0x6d40362d,0x3857007e,0x7c22362e,0x00000000}},	//   _mama, _نشود_, ntor,
  { {0x6d4015c4,0x7c22362f,0xf87b0063,0x00000000}},	//   _lama, itor, _שְׁל,
  { {0x7c220213,0xe2f80054,0x6ed5004c,0x00000000}},	//   htor, ресі_, hřbí,
  { {0x65b60024,0x6d40240d,0x75d3003b,0x00000000}},	//   náhl, _nama, _căzu,
  { {0xdefb0055,0x9f5200fe,0xdfd10021,0x00000000}},	// [5d10] вые_, ksyä_, سيا_,
  { {0x7d1b051e,0xdb0302dd,0x65760024,0x00000000}},	//   _scus, poné, _zlyh,
  { {0x6d403630,0x5cd50021,0x765c0072,0x00000000}},	//   _bama, مقاط, äryh,
  { {0xbd18019d,0x29060035,0xa5d90047,0x00000000}},	//   иції_, _ndoa_, אַסי,
  { {0x6d403631,0x4439002b,0x68fb3632,0x00000000}},	//   _dama, nws_, vaud,
  { {0xa03a0047,0xdf47000d,0x5ba80085,0x00000000}},	//   _געשפ, _тэмп, акім_,
  { {0x7c223633,0xf1bf008b,0xa91d0734,0x00000000}},	//   ator, _khá_, liži,
  { {0xa37b0019,0x2d8e0003,0x27ff0659,0x00000000}},	//   spõh, éfet_, tsun_,
  { {0x7c2203db,0x68fb16ec,0x27ff3634,0x00000000}},	//   ctor, raud, usun_,
  { {0x6d402f70,0x65b600ea,0xe7390001,0x00000000}},	//   _zama, táho, ћен_,
  { {0x27ff051e,0x68fb3635,0x68e2002b,0x00000000}},	//   ssun_, paud, _ffod,
  { {0x2902000f,0x6d40021a,0xf1bf3636,0x00000000}},	//   ókat_, _xama, _nhá_,
  { {0x65b6000f,0xc8da0047,0xa91d00b2,0x00000000}},	//   sáho, _עקסט, jiži,
  { {0x395f248f,0x65bd013d,0x43750fc7,0x00000000}},	//   ljus_, véhe, оуст,
  { {0x11da0021,0x44393637,0x7c221556,0x00000000}},	//   اورة_, aws_, ztor,
  { {0xf1bf017d,0x659300e1,0x65bd00ea,0x00000000}},	//   _chá_, _нају, téhe,
  { {0xf1bf0025,0x75d3000c,0x386d3638,0x00000000}},	// [5d20] _dhá_, _văzu, nyer_,
  { {0x395f0004,0x7c223639,0xb4db00cd,0x00000000}},	//   hjus_, vtor, ndàn,
  { {0x637001e3,0x65bd000f,0x6d40363a,0x00000000}},	//   _länk, séhe, _pama,
  { {0x2ef8021f,0x7c22363b,0xa136005d,0x00000000}},	//   _werf_, ttor, _اردش,
  { {0x6d422b1f,0x6d40003b,0xdb0101da,0x00000000}},	//   rdoa, _vama, _sklá,
  { {0x6d4005b3,0x7c22363c,0x395f0078,0x00000000}},	//   _wama, rtor, ejus_,
  { {0x5a340086,0x7c22363d,0x65b6004c,0x00000000}},	//   інит, stor, táhl,
  { {0xdb010080,0x7c22363e,0x7d960021,0x00000000}},	//   _vklá, ptor, _الرؤ,
  { {0xd90d007e,0xdb1a013d,0xa714012c,0x00000000}},	//   ئیه_, _kitü, омпі,
  { {0x8b650032,0x65b60080,0xdce0007d,0x00000000}},	//   _والم, sáhl, _momč,
  { {0xdb010080,0x4a9a000d,0x7afa19bd,0x00000000}},	//   _uklá, _стаў_, _iett,
  { {0x4439001f,0xd5b8046f,0xc7b900ea,0x00000000}},	//   tws_, йся_, ltől_,
  { {0x44392d27,0x69da0035,0x386d00c7,0x00000000}},	//   uws_, _hute, cyer_,
  { {0x69da24d4,0x4439001f,0x7afa363f,0x00000000}},	//   _kute, rws_, _jett,
  { {0xf1bf008b,0x7afa3640,0xa785007e,0x00000000}},	//   _phá_, _mett, _بشنو,
  { {0x9294000d,0xc05b013c,0xdcfb007d,0x00000000}},	//   часц, ліз_, _imuć,
  { {0x657d0027,0x7ff70032,0xc7b900ea,0x00000000}},	// [5d30] mhsh, إسرا, ktől_,
  { {0x7afa16a2,0x69da015e,0x644d0003,0x00000000}},	//   _nett, _oute, _irai,
  { {0x3a3e0089,0x2eff0003,0x69da2106,0x00000000}},	//   _nstp_, _œufs_, _nute,
  { {0xd5b9001c,0x61e80114,0xbcb50121,0x00000000}},	//   ktām_, ídle, обещ,
  { {0x7afa3641,0x69da3642,0x386d05a5,0x00000000}},	//   _bett, _aute, xyer_,
  { {0x7afa0c6e,0x661d0045,0x7ee50021,0x00000000}},	//   _cett, ński, _ذكرن,
  { {0x637000c7,0x7afa1781,0x2e48005a,0x00000000}},	//   _sänk, _dett, _лято_,
  { {0x644d0027,0x636b00bd,0xdb0305ab,0x00000000}},	//   _orai, _küns, moní,
  { {0xb9010161,0x395f004b,0x2d8f03ac,0x00000000}},	//   _दल_, rjus_, mige_,
  { {0x69da0016,0x2d8f1dd8,0x752d0035,0x00000000}},	//   _fute, lige_, _abaz,
  { {0x69da3643,0xb4db00cd,0x0655000d,0x00000000}},	//   _gute, rdàn, ітоў,
  { {0x637000c7,0x7afa3644,0x94260076,0x00000000}},	//   _tänk, _zett, омме,
  { {0x644d3645,0x32110051,0x2d8f004b,0x00000000}},	//   _crai, erzy_, iige_,
  { {0x2d8f004d,0x27ed3646,0xdb03004c,0x00000000}},	//   hige_, mpen_, koní,
  { {0x7d0902f4,0x27ed3647,0x644d3648,0x00000000}},	//   _odes, lpen_, _erai,
  { {0x2d8f02e2,0x27ed006f,0xf53f0d7d,0x00000000}},	//   jige_, open_, slår_,
  { {0x2d8f05da,0x42d602fe,0x644d3649,0x00000000}},	// [5d40] dige_, _міну, _grai,
  { {0xdb03006d,0x7d09364a,0x44320061,0x00000000}},	//   foní, _ades, _ipy_,
  { {0x0d86183f,0x67210053,0x7afa364b,0x00000000}},	//   олжн, _मानक_, _rett,
  { {0x69da364c,0x7bc10370,0x2d8f364d,0x00000000}},	//   _rute, _ahlu, gige_,
  { {0x69da00eb,0x27ed0122,0x61ee00e8,0x00000000}},	//   _sute, jpen_, lpbl,
  { {0x69da0492,0xafdb04b1,0x7d09364e,0x00000000}},	//   _pute, _prøv, _edes,
  { {0x27ed0122,0xfe42006a,0x7e230fe2,0x00000000}},	//   epen_, _تکذی, _одрж,
  { {0x6370004d,0x7afa0da0,0xd943005e,0x00000000}},	//   _däni, _wett, дећи,
  { {0x77b400cd,0xc7d705ac,0x7afa364f,0x00000000}},	//   làxi, омых_, _tett,
  { {0xdb1a0016,0x7bc10025,0x69da3650,0x00000000}},	//   _vitó, _ghlu, _tute,
  { {0x32180034,0x9f4000fe,0x69da003a,0x00000000}},	//   jury_, mpiä_, _uute,
  { {0x758b0612,0x644d3651,0xada10014,0x00000000}},	//   рсов_, _prai, _óútf,
  { {0xdb030331,0xf7462e1a,0x5347030b,0x00000000}},	//   zoní, _медо, охва,
  { {0x644d0164,0x2d8f0d13,0xe7373652,0x00000000}},	//   _vrai, zige_, _меч_,
  { {0xf3640076,0x236c0137,0x644d035a,0x00000000}},	//   фтян, ödja_, _wrai,
  { {0xa91d0006,0x644d3653,0xab5d0051,0x00000000}},	//   sižv, _trai, _duży,
  { {0x4395005a,0x6441003d,0x644d14ee,0x00000000}},	// [5d50] _наис, ālis, _urai,
  { {0x2d8f0104,0x2d9c01e0,0x9f490014,0x00000000}},	//   wige_, éven_, gsað_,
  { {0xdb1a0080,0x636b00bd,0x2d8f0523,0x00000000}},	//   _chtí, _wüns, tige_,
  { {0xb23a00b5,0x6e2504bf,0xe2920047,0x00000000}},	//   _פערז, rthb, _טװי_,
  { {0xdb0a0146,0x2d8f1c66,0xab5d0022,0x00000000}},	//   ilfæ, rige_, _zuży,
  { {0x2d8f3654,0xdb0316eb,0xcb6604ed,0x00000000}},	//   sige_, poní, заше_,
  { {0x09e2005a,0x2d8f25b9,0xef23001c,0x00000000}},	//   нощн, pige_, _ceļš_,
  { {0x7d092867,0xe29c0063,0xe9a80021,0x00000000}},	//   _udes, ישור, يدين_,
  { {0xdbc60019,0xf1b40063,0x69e1007d,0x00000000}},	//   vöön, וסק_, _šveđ,
  { {0x63703655,0x27ed3656,0x77820121,0x00000000}},	//   _hänv, rpen_, ельз,
  { {0xdbc610f0,0x29d1007d,0x321800e5,0x00000000}},	//   töön, _ušao_, xury_,
  { {0x7aba014e,0x27ed0196,0xb925005d,0x00000000}},	//   _הצעו, ppen_, _رفتي,
  { {0x4424001f,0xdce0008f,0xdb0a00a5,0x00000000}},	//   îm_, _jomā, rmfö,
  { {0x32183657,0x69c93658,0xe8200042,0x00000000}},	//   tury_, lmee, _ममता_,
  { {0xaacb0053,0x69c2002b,0x72c30896,0x00000000}},	//   ाधिक, _yhoe, ебрз,
  { {0xe0da005a,0x69c913de,0x64400014,0x00000000}},	//   сва_, nmee, æmis,
  { {0x351b0063,0x216708ac,0x69c90072,0x00000000}},	// [5d60] _הופנ, чити_, imee,
  { {0x2257004c,0x61ee00a5,0xa3bf0042,0x00000000}},	//   ácký_, ppbl, ेषण_,
  { {0x32db009a,0x22f7009d,0x82f7009d,0x00000000}},	//   _לחינ, _מזין_, _מציב_,
  { {0x71a62099,0xed890085,0x44760063,0x00000000}},	//   _хамз, осік_, ּעַל_,
  { {0x69c921ef,0x69c2002b,0x7602013d,0x00000000}},	//   dmee, _rhoe, _kízá,
  { {0xdce0001c,0x69c90229,0x69c23659,0x00000000}},	//   _domā, emee, _shoe,
  { {0xcb070021,0x69c2365a,0xbea31fc6,0x00000000}},	//   سيين_, _phoe, _зарк,
  { {0xd90d007e,0xafdb04aa,0x7e9b0063,0x00000000}},	//   لیم_, _trøt, _הסלו,
  { {0xd8230138,0x3ce60024,0xeafa007e,0x00000000}},	//   едњи, mcov_, _هرات_,
  { {0x7d02365b,0x3ce60066,0x69c200e5,0x00000000}},	//   laos, lcov_, _whoe,
  { {0x69c900e8,0x69c200ca,0x63ae365c,0x00000000}},	//   bmee, _thoe, dobn,
  { {0x3ce60024,0x7d02365d,0xb495005e,0x00000000}},	//   ncov_, naos, димљ,
  { {0x94ab365e,0xdb03365f,0x00000000,0x00000000}},	//   стна_, loná,   ,
  { {0x7bdf07a8,0xa8570063,0x39463660,0x00000000}},	//   íqui, _מידה_, _haos_,
  { {0x82a40459,0x99890024,0x39463661,0x00000000}},	//   еште, ňať_, _kaos_,
  { {0xdb0a01e3,0x2d9c000f,0x673a3662,0x00000000}},	//   llfä, ével_, letj,
  { {0xa068000a,0x3ce60066,0x4fd50d3b,0x00000000}},	// [5d70] паѓа_, dcov_, джат,
  { {0xdb03027d,0x673a3663,0x39463664,0x00000000}},	//   koná, netj, _laos_,
  { {0x661a01b3,0xf7730041,0x8d74005d,0x00000000}},	//   nutk, עקע_, کالا,
  { {0x6fd80053,0x9f490139,0xac95007f,0x00000000}},	//   _भूकं, mpaí_, маеш,
  { {0x673a2d4e,0xcb6900d7,0xeb8e0a8f,0x00000000}},	//   ketj, жале_, ви_,
  { {0x673a00c3,0x661a3665,0x69c9006f,0x00000000}},	//   jetj, kutk, wmee,
  { {0x661a0397,0xaa560001,0x2d9f00d1,0x00000000}},	//   jutk, дију_, _tjue_,
  { {0xeeeb00aa,0x637000fe,0x661a0150,0x00000000}},	//   _động_, _hänt, dutk,
  { {0x799b00e8,0xfc3003eb,0x69c923af,0x00000000}},	//   rnuw, _محل_, rmee,
  { {0x37890086,0x673a00b9,0x06090b3f,0x00000000}},	//   ібно_, getj, онок_,
  { {0x69c9004b,0xe5a62474,0x63700b75,0x00000000}},	//   pmee, дини, _mänt,
  { {0x6abe004d,0x63700072,0xe8590085,0x00000000}},	//   üpfe, _länt, _маеш_,
  { {0x63ae034d,0x18690002,0x673a02c0,0x00000000}},	//   tobn, _фали_, betj,
  { {0x661a014f,0x3ce62029,0xd7c9005d,0x00000000}},	//   butk, zcov_, _بوته_,
  { {0x661a0089,0x23270062,0x63ae0392,0x00000000}},	//   cutk, ьори_, robn,
  { {0x291f3666,0x63ae3667,0x41b50054,0x00000000}},	//   ngua_, sobn, есут,
  { {0x3ce60024,0xdb0300ea,0xdb0a0137,0x00000000}},	// [5d80] vcov_, zoná, llfå,
  { {0xe3b20021,0x27f90066,0x2be10053,0x00000000}},	//   _جرب_, ásny_, _पढ़ा,
  { {0xdb1a00ea,0x3ce60066,0x7d022c17,0x00000000}},	//   _kitö, tcov_, taos,
  { {0xdb0300ea,0x6d91004a,0x673a013d,0x00000000}},	//   voná, sťan, zetj,
  { {0xdd8f0021,0x3ce60066,0x7d023668,0x00000000}},	//   جون_, rcov_, raos,
  { {0x63703669,0x212000c2,0xcb67005e,0x00000000}},	//   _tänu, lgih_, даље_,
  { {0x637000c7,0x673a366a,0x3ce60066,0x00000000}},	//   _häns, vetj, pcov_,
  { {0xd910006a,0x637000c7,0x64440072,0x00000000}},	//   ایش_, _käns, _osii,
  { {0xdb030014,0xb4bd0042,0x7d000023,0x00000000}},	//   llný, _अरे_, _iems,
  { {0x7d0000c7,0x637000c7,0x661a366b,0x00000000}},	//   _hems, _mäns, tutk,
  { {0x7d000026,0x63701ea9,0x39460178,0x00000000}},	//   _kems, _läns, _taos_,
  { {0x661a366c,0x673a366d,0x65bd01d1,0x00000000}},	//   rutk, setj, rého,
  { {0x2904366e,0xdb1a0075,0x88582530,0x00000000}},	//   mama_, _ditö, _хилс_,
  { {0x2904366f,0x661a2241,0xe8d7009a,0x00000000}},	//   lama_, putk, _חודר_,
  { {0xd848001b,0x65950088,0x6444024a,0x00000000}},	//   _họ_, _паку, _esii,
  { {0x200f017d,0x7d0000ea,0x29043670,0x00000000}},	//   ágio_, _nems, nama_,
  { {0x03c7000a,0x1128030b,0x753d208d,0x00000000}},	// [5d90] _осом, ьюри_, mesz,
  { {0x753d000f,0xcebb0001,0x29043671,0x00000000}},	//   lesz, оље_, hama_,
  { {0x637001e3,0x29043672,0xd848008d,0x00000000}},	//   _vänt, kama_, _lọ_,
  { {0x29043673,0x29d10114,0x753d00ea,0x00000000}},	//   jama_, _však_, nesz,
  { {0xed580086,0x5eeb0088,0xdb030164,0x00000000}},	//   ьої_, _мфвг_, nonç,
  { {0xce950062,0x290400dd,0xd6c60044,0x00000000}},	//   _загъ, eama_, _مق_,
  { {0x2d870164,0x753d013d,0x7d0000a5,0x00000000}},	//   ènes_, kesz, _fems,
  { {0x29043674,0xd8480013,0x7d003675,0x00000000}},	//   gama_, _bọ_, _gems,
  { {0x20090498,0xc795026c,0xd8480013,0x00000000}},	//   nsai_, ерны, _cọ_,
  { {0x16650071,0x6d49002b,0x20090a10,0x00000000}},	//   евом, _haea, isai_,
  { {0x29043676,0xda09007e,0x753d013d,0x00000000}},	//   bama_, _ريشه_, fesz,
  { {0x29040117,0xc329014e,0x753d0d21,0x00000000}},	//   cama_, _לו_, gesz,
  { {0x200f00f8,0x7c2b3677,0x5cac009d,0x00000000}},	//   ágil_, ntgr, ַׁלַ,
  { {0x7c2b004d,0x324601d5,0x61e80445,0x00000000}},	//   itgr, негг, ídlo,
  { {0x69d90035,0x7c2b004b,0x753d013d,0x00000000}},	//   _kiwe, htgr, besz,
  { {0x4fea0ace,0x68e90e57,0x7c2b2523,0x00000000}},	//   зман_, nced, ktgr,
  { {0x6d4b001f,0x3f160002,0x212000a8,0x00000000}},	// [5da0] ddga, еќет, rgih_,
  { {0x637001e3,0x290410d2,0x6d5b3678,0x00000000}},	//   _väns, zama_, _anua,
  { {0x2009053b,0x7bcf0003,0x29043679,0x00000000}},	//   asai_, _écuy, yama_,
  { {0xd5b9001c,0xfce6367a,0x69d9367b,0x00000000}},	//   stāv_, ходо, _niwe,
  { {0x6d49001f,0x29043244,0xdb0300fe,0x00000000}},	//   _daea, vama_, konä,
  { {0x753d0045,0x6d4b00b9,0xcb340062,0x00000000}},	//   zesz, adga, текъ,
  { {0x3ebe0026,0x7d00005b,0x7c2b00f5,0x00000000}},	//   _átt_, _tems, atgr,
  { {0x6d49001f,0xb4db00cd,0x7e0b0063,0x00000000}},	//   _gaea, ldàv, _מִמֶ,
  { {0x69d90185,0x753d00ea,0xc7ba000d,0x00000000}},	//   _diwe, vesz, зён_,
  { {0x2904367c,0x6d62007d,0x69d9004d,0x00000000}},	//   sama_, štač, _eiwe,
  { {0x2904367d,0x753d00ea,0x9f420050,0x00000000}},	//   pama_, tesz, _itkä_,
  { {0x7bda367e,0x68e906e2,0x29c100ea,0x00000000}},	//   _hitu, cced, lóan_,
  { {0x753d367f,0x7bda3680,0x32183681,0x00000000}},	//   resz, _kitu, erry_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x81c70076,0x4789000d,0x61fe002b,0x00000000}},	//   ещае, _ўсім_, _cwpl,
  { {0xb6bb0063,0x61d8014c,0x7bda3682,0x00000000}},	//   _מצוי, емся_, _litu,
  { {0x20090006,0x23650137,0x63700072,0x00000000}},	// [5db0] usai_, öljs_, _vänr,
  { {0x7bda0035,0xf53f0137,0xc27502d8,0x00000000}},	//   _nitu, leå_, _алој,
  { {0x6d910024,0xcfa40002,0xe7170063,0x00000000}},	//   sťam, ушти, תחבר_,
  { {0x7c2b24e1,0xd5b9008f,0x68e900be,0x00000000}},	//   ttgr, mtās_, xced,
  { {0x7bda1362,0x69da0053,0x8c4532ea,0x00000000}},	//   _bitu, _पंजी, теле,
  { {0x9f9400bd,0x26010053,0x7bda3683,0x00000000}},	//   mäß_, वीडी_, _citu,
  { {0x7bda08f0,0x3da70088,0xdce2017f,0x00000000}},	//   _ditu, _зраб, akođ,
  { {0x9f4200fe,0x68e90460,0xdb1a0003,0x00000000}},	//   _etkä_, uced, _sitô,
  { {0x69d90035,0x7bda0150,0x68e90b11,0x00000000}},	//   _viwe, _fitu, rced,
  { {0xd5b9001c,0x7bda0150,0xf048009d,0x00000000}},	//   ktās_, _gitu, תָה֙_,
  { {0xab8401eb,0x00000000,0x00000000,0x00000000}},	//   _сутк,   ,   ,
  { {0xa3e60161,0xf506005a,0x7bda0035,0x00000000}},	//   _बंद_, ъзмо, _zitu,
  { {0xe8180053,0x394d3684,0x7de5005f,0x00000000}},	//   _दिया_, mdes_, _sėsl,
  { {0xc88301f7,0x394d3685,0x66e21259,0x00000000}},	//   ığı_, ldes_, _коша,
  { {0xd5b9008f,0x394d0327,0x69dc013d,0x00000000}},	//   gtās_, odes_, _éret,
  { {0x394d3686,0x29c100ea,0x9f94004d,0x00000000}},	//   ndes_, zóan_, fäß_,
  { {0xdb1a00fe,0x61430893,0xd007173e,0x00000000}},	// [5dc0] _yhtä, шета, кете_,
  { {0xef17000a,0xd5b9001c,0x13a8005d,0x00000000}},	//   кму_, stāt_, _سنجی_,
  { {0x11d60021,0x7bda3687,0xfe4325de,0x00000000}},	//   _لتحد, _ritu, инфо,
  { {0xdb0a076c,0x6b8109f8,0x7bda3688,0x00000000}},	//   llfø, _allg, _situ,
  { {0xdb0a02dd,0x7bda00fe,0xc7b900ea,0x00000000}},	//   sofí, _pitu, ntős_,
  { {0x394d3689,0xdee602f8,0x1bb30085,0x00000000}},	//   edes_, _јови, абіў,
  { {0xdb0a0146,0x79a6026b,0x7bda368a,0x00000000}},	//   ilfø, крие, _vitu,
  { {0x2902243a,0x394d368b,0x3c92005d,0x00000000}},	//   úka_, gdes_, _پیتز,
  { {0xebe6019d,0x57b405fb,0xa3b20042,0x00000000}},	//   _розп, лбит, टका_,
  { {0x394d368c,0xc7ba0121,0x8b4500de,0x00000000}},	//   ades_, ьёй_, _مضمن,
  { {0xf53f0137,0xb763000d,0x98a20075,0x00000000}},	//   teå_, ртый, ıkı_,
  { {0xd9460138,0xceb30132,0x661501d9,0x00000000}},	//   _једи, יית_, ázka,
  { {0x661d00eb,0x48130086,0x645600e5,0x00000000}},	//   ąska, _вміс, _cryi,
  { {0xa295000d,0x645600e5,0xa3a40092,0x00000000}},	//   гагі, _dryi, ајск,
  { {0xdcfb0117,0xd5b9008f,0xe7370896,0x00000000}},	//   _sluč, utās_, _реј_,
  { {0xc6d90047,0x7d040014,0xd5b9008f,0x00000000}},	//   _אַפר, ðisl, rtās_,
  { {0x636b00bd,0x9055000d,0xd5b9001c,0x00000000}},	// [5dd0] _münz, ывац, stās_,
  { {0xb433034d,0x657d368d,0x2ef40caa,0x00000000}},	//   ľúčo, lksh, изур,
  { {0x645a003d,0x394d368e,0x9df90121,0x00000000}},	//   ātie, ydes_, хнет_,
  { {0x7db4000d,0x2b4c0150,0x657d1dfa,0x00000000}},	//   асіц, _aadc_, nksh,
  { {0x394d368f,0x711a009a,0x00000000,0x00000000}},	//   vdes_, _אורפ,   ,
  { {0x447c00b5,0x6d910066,0x399a008f,0x00000000}},	//   ונדע, zťah, zīst_,
  { {0x79820034,0x61e500fe,0xaa080044,0x00000000}},	//   _blow, _juhl, نزيل_,
  { {0x63b500ea,0x394d3690,0xca740085,0x00000000}},	//   hozn, udes_, рушы,
  { {0x63b50758,0x394d3691,0x8c1904a0,0x00000000}},	//   kozn, rdes_, _سيار_,
  { {0x394d0150,0xf745005e,0x7c3b003b,0x00000000}},	//   sdes_, ћено, _ipur,
  { {0x79822392,0xf771007e,0x98b8008f,0x00000000}},	//   _flow, لاگ_, īzāk_,
  { {0x798204bf,0x7a7a0047,0x78a43692,0x00000000}},	//   _glow, _ארעס, _žive,
  { {0x68fb33d5,0xf773005d,0xedb6009a,0x00000000}},	//   mbud, _پاش_, רִית_,
  { {0xade30161,0x389a0063,0x6d910066,0x00000000}},	//   गदान_, _איננ, sťah,
  { {0xafdb00d1,0xf6390047,0x7dca0026,0x00000000}},	//   _esøk, _טײַל, lýse,
  { {0x64560034,0x65690072,0xd5b200f2,0x00000000}},	//   _tryi, öeht, _دفع_,
  { {0x7dda0080,0xefca0076,0x7d040026,0x00000000}},	// [5de0] _důsl, елал_, ðism,
  { {0x7dda0080,0x44221d29,0x65bd013d,0x00000000}},	//   _půso, muk_, véhi,
  { {0x7e56000d,0x7c3b3693,0x03570047,0x00000000}},	//   ытац, _apur, _עיטש_,
  { {0x56b60041,0xac0a3694,0x9dba005d,0x00000000}},	//   אפען_, енда_, رداز_,
  { {0xdca316ef,0x68fb3695,0x6b98004d,0x00000000}},	//   баци, dbud, tivg,
  { {0x636b0058,0x68fb3696,0x2d863697,0x00000000}},	//   _büny, ebud, shoe_,
  { {0xb4db0268,0x7ed50086,0x7c3b1f09,0x00000000}},	//   ndàr, _вітч, _epur,
  { {0x68fb0122,0x636b01f7,0x63b50024,0x00000000}},	//   gbud, _düny, zozn,
  { {0xba18006a,0x44223698,0x2d840656,0x00000000}},	//   ريکا_, juk_, _ilme_,
  { {0x4422014f,0x9f401f22,0x3f9a0360,0x00000000}},	//   duk_, mpió_, nipu_,
  { {0x3ce906bb,0x68fb0089,0xd6860002,0x00000000}},	//   žave_, bbud, ѓуоп,
  { {0xdb180014,0x61e50422,0xd5670da2,0x00000000}},	//   ilví, _ruhl, утоп,
  { {0x63b5013d,0xa8770049,0x657d3699,0x00000000}},	//   tozn, _محور_, rksh,
  { {0xb865007e,0x69c0369a,0xfbd4009a,0x00000000}},	//   _خامو, llme, יתָ_,
  { {0x63b5369b,0x69c0369c,0xd5bb0da2,0x00000000}},	//   rozn, olme, _пси_,
  { {0x50f51001,0x44221d29,0xeeeb0013,0x00000000}},	//   рзат, buk_, _đống_,
  { {0x200f000f,0xb7bd000c,0x4422369d,0x00000000}},	// [5df0] égi_, suţe, cuk_,
  { {0x2906017d,0x68fb232d,0xeeab0062,0x00000000}},	//   _leoa_, zbud, нтек_,
  { {0x68fb001f,0x4fc4093e,0x7c3b0b9c,0x00000000}},	//   ybud, сста, _spur,
  { {0x69c022bd,0x7c2201f4,0x71470156,0x00000000}},	//   jlme, fuor, _схож,
  { {0xf3ff017d,0x55780047,0x6ee70593,0x00000000}},	//   ixão_, װעגן_, _مسأل,
  { {0xaa150459,0xab62005b,0x447c0047,0x00000000}},	//   афиј, şünm, ענגע,
  { {0xdb060046,0x69c00075,0x4422369e,0x00000000}},	//   ðmál, flme, zuk_,
  { {0x27e6269d,0x442205b4,0xdb0a01c8,0x00000000}},	//   _buon_, yuk_, rofá,
  { {0x7d0b369f,0x77850fec,0x68fb36a0,0x00000000}},	//   mags, илиз, rbud,
  { {0x25a90004,0xe7390001,0xe7b20032,0x00000000}},	//   _ajal_, њен_, يميد,
  { {0x3915007e,0x68fb36a1,0xa8060331,0x00000000}},	//   _نواز, pbud, _peñó,
  { {0x44222920,0x7d0b002c,0x3860007d,0x00000000}},	//   tuk_, nags, _šire_,
  { {0xc5f8008f,0x660b005f,0x99d4043e,0x00000000}},	//   apē_, _šokė, _اتلا,
  { {0x68e236a2,0x88c80086,0x799b0035,0x00000000}},	//   _zgod, _слів_, liuw,
  { {0xd1960079,0x442236a3,0x03a30076,0x00000000}},	//   ашањ, suk_, циро,
  { {0x44221320,0x9d37000d,0x7989002b,0x00000000}},	//   puk_, _афiц, nhew,
  { {0x55bb0063,0x7d0b1b80,0x90a50021,0x00000000}},	// [5e00] _במקו, dags, محكم,
  { {0x6fc20024,0x7c220072,0xa3ba00f2,0x00000000}},	//   môck, vuor, _جابر_,
  { {0x6e460121,0x9965008f,0x6d4236a4,0x00000000}},	//   реез, zēš_, teoa,
  { {0x163600b5,0x7c22006c,0x3dcd36a5,0x00000000}},	//   ינער_, tuor, _chew_,
  { {0xa5d900b5,0xcb6a1001,0x6c5406b4,0x00000000}},	//   אַװי, каде_, склу,
  { {0xe45707e9,0x78b604aa,0x1eca0092,0x00000000}},	//   יינט_, _øyvi, _алги_,
  { {0x7d0b0537,0x7c2200fe,0xafdb00b9,0x00000000}},	//   bags, suor, _spøg,
  { {0x66cf00ea,0x628e36a6,0xda770062,0x00000000}},	//   zóké, izbo, ряш_,
  { {0xdb030019,0x7c2236a7,0x394f36a8,0x00000000}},	//   elnõ, quor, _dags_,
  { {0x10370063,0x00000000,0x00000000,0x00000000}},	//   סטים_,   ,   ,
  { {0x0f570063,0x394f01a8,0x5a960f34,0x00000000}},	//   ביים_, _fags_, _траф,
  { {0xd5b8019d,0xdb060026,0xd6d7000d,0x00000000}},	//   ися_, ðmæl, шты_,
  { {0x28d20053,0x98aa008f,0xf76f007e,0x00000000}},	//   देशि, īmēm_, سای_,
  { {0xf74336a9,0x92a70141,0x394436aa,0x00000000}},	//   _мечо, ајбл, lems_,
  { {0xdce00080,0x41e70086,0x66cf013d,0x00000000}},	//   _pomě, ріга, róké,
  { {0x3f980089,0xdb0a00ea,0x25a901c8,0x00000000}},	//   _amru_, elfü, _ujal_,
  { {0x39440078,0x3dcd002b,0x0f152049,0x00000000}},	// [5e10] iems_, _rhew_, ймаю,
  { {0x7d1d03e8,0xeeeb001b,0x29c100ea,0x00000000}},	//   _össz, _đồng_, tóak_,
  { {0xdfd8011c,0x7d0b0d88,0xc7b30063,0x00000000}},	//   рът_, tags, קבע_,
  { {0xb6d90047,0xafdb04aa,0xab620058,0x00000000}},	//   אַנט, _spød, şülm,
  { {0xa3ae0161,0x7c840001,0x3944144b,0x00000000}},	//   _कदम_, жује, dems_,
  { {0xdb030164,0x7f850032,0xdb18017d,0x00000000}},	//   onné, _السن, lovê,
  { {0x7d0b002c,0x752d000c,0x9f400290,0x00000000}},	//   pags, _ocaz, ppiò_,
  { {0x2129014f,0x78a41e45,0xe8180053,0x00000000}},	//   ngah_, _živa, _दिशा_,
  { {0x79891150,0x3c440044,0xa3b70082,0x00000000}},	//   rhew, _وَفِ, जवा_,
  { {0x9b740032,0xab740021,0x2d9d14ce,0x00000000}},	//   _والص, _والإ, liwe_,
  { {0x644d0025,0x7d09312c,0x32110051,0x00000000}},	//   _asai, _kees, jszy_,
  { {0xaca3008b,0x7d090213,0x63a90003,0x00000000}},	//   _ngừn, _jees, éenn,
  { {0x7d0936ab,0x7d040026,0x3f8100ca,0x00000000}},	//   _mees, ðisi, kkhu_,
  { {0x7d09126e,0x85430078,0x628e004d,0x00000000}},	//   _lees, _šėto, tzbo,
  { {0xa2bb0235,0xf770007e,0x15f50593,0x00000000}},	//   _शुद्, _تان_, _استح,
  { {0x7d09003d,0x3ce008ed,0x628e36ac,0x00000000}},	//   _nees, živi_, rzbo,
  { {0xa0670581,0x656400a4,0xa3d80053,0x00000000}},	// [5e20] бата_, _inih, िषद_,
  { {0xdfcf0593,0x32110022,0xf457009a,0x00000000}},	//   فيق_, bszy_, _פייר_,
  { {0x6564108f,0xa91d0006,0x7d0936ad,0x00000000}},	//   _knih, sižy, _bees,
  { {0x10a625d8,0xe8180042,0xf2d30aeb,0x00000000}},	//   _гимн, _दिला_, _מעת_,
  { {0x7d0d007a,0xe3bf006d,0x7d0936ae,0x00000000}},	//   ðasa, luña_, _dees,
  { {0x3ce90066,0x9b580074,0xe9f80085,0x00000000}},	//   ľava_, рикт_, анкі_,
  { {0x3ce90add,0x7d09016d,0x8e860021,0x00000000}},	//   žava_, _fees, _الأه,
  { {0x7d091999,0x65640014,0x7bc336af,0x00000000}},	//   _gees, _nnih, alnu,
  { {0x20120089,0x49730054,0x2caa0002,0x00000000}},	//   nsyi_, їльс, _скап_,
  { {0x7d09006f,0xa6140b3f,0x274a005e,0x00000000}},	//   _zees, омоч, учио_,
  { {0xdb030066,0x6ac60049,0x657600e5,0x00000000}},	//   noný, _اقام, _boyh,
  { {0x61fc00c2,0x26c2001c,0x6370004d,0x00000000}},	//   dprl, āko_, _gänz,
  { {0x32110051,0x443f00cd,0x7e7e36b0,0x00000000}},	//   wszy_, ïu_, hypp,
  { {0xf41f00fe,0x2d9d0022,0x47d40044,0x00000000}},	//   rrä_, ziwe_, _بيتر,
  { {0x1b7b0047,0x439436b1,0x32110022,0x00000000}},	//   נטלע, чарс, uszy_,
  { {0x35a40079,0xf1940076,0x32110051,0x00000000}},	//   _најг, пись, rszy_,
  { {0x644d36b2,0x7d0936b3,0x6b8801e1,0x00000000}},	// [5e30] _usai, _rees, _oldg,
  { {0x3f8736b4,0x32110051,0x7d0936b5,0x00000000}},	//   ónu_, pszy_, _sees,
  { {0x91e40002,0x2d9d00ac,0xdcf90593,0x00000000}},	//   _ноќе, tiwe_, لفات_,
  { {0xa15936b6,0x05c90053,0xdb180813,0x00000000}},	//   _таму_, रतिब, lovè,
  { {0x2d9d0035,0x0c250086,0x7d0936b7,0x00000000}},	//   riwe_, імкн, _vees,
  { {0x7d0909fe,0x09f50121,0xb7bd00dd,0x00000000}},	//   _wees, очия, orţe,
  { {0x290d00ca,0x7d0936b8,0x4a450054,0x00000000}},	//   taea_, _tees, інив,
  { {0xa3e90235,0xceb20063,0x09e203d6,0x00000000}},	//   यदा_, _חיל_, мощн,
  { {0xd7e60121,0x17f90044,0x290d0050,0x00000000}},	//   омые_, جربة_, raea_,
  { {0xbca40067,0xd7090121,0xdb03004b,0x00000000}},	//   _عملي, шное_, nonü,
  { {0x2b4700cd,0x05aa0121,0x6370004d,0x00000000}},	//   menc_, ивой_, _tänz,
  { {0xfe830078,0x95962049,0xba470078,0x00000000}},	//   _grįš_, ішні, grįš,
  { {0x2ec60161,0xd7f80259,0x69c60042,0x00000000}},	//   _वर्त, _луј_, ातरी,
  { {0xf1bf0024,0x7e7e00fe,0xd3ba0086,0x00000000}},	//   _aká_, yypp, румі_,
  { {0xe796007e,0x31760002,0xdb030022,0x00000000}},	//   _بانک, оѓат, lonó,
  { {0x649a0079,0xe3bf0871,0x65c30ac5,0x00000000}},	//   _втор_, ruña_, _обща,
  { {0x387f0150,0x10a60591,0x2fda0044,0x00000000}},	// [5e40] nyur_, циан, لورد_,
  { {0x03a60002,0xbc6a007e,0x386d01a8,0x00000000}},	//   _фиоо, یمان_, ixer_,
  { {0x2b4700cd,0x6e460049,0x63bc36b9,0x00000000}},	//   denc_, تنام, morn,
  { {0x302a0086,0xa802005b,0x4d66000d,0x00000000}},	//   _комп_, çıkl, юкев,
  { {0x63bc006f,0x973c007d,0xdb182f90,0x00000000}},	//   oorn, liće, lové,
  { {0xdb970088,0x7de50006,0x63bc0415,0x00000000}},	//   овіч_, _pėst, norn,
  { {0x63bc051e,0x973c007d,0xdb1836ba,0x00000000}},	//   iorn, niće, nové,
  { {0x8d270062,0xf3f9003b,0xdb0336bb,0x00000000}},	//   _мосв_, ţţi_, fonó,
  { {0xd90d007e,0x7d021da2,0x63bc00b1,0x00000000}},	//   ایه_, mbos, korn,
  { {0x3dc62e0d,0xdb180114,0x63bc36bc,0x00000000}},	//   llow_, kové, jorn,
  { {0x63bc36bd,0x2956005a,0x44220de8,0x00000000}},	//   dorn, _мъдр, erk_,
  { {0x973c007d,0x7d0220a4,0xdb1801c8,0x00000000}},	//   diće, nbos, dové,
  { {0xdb0305d5,0x27f8007e,0x63bc36be,0x00000000}},	//   conó, _افتد_, forn,
  { {0x27f90066,0x63bc36bf,0x46140044,0x00000000}},	//   ísne_, gorn, _فوتر,
  { {0xdb1836c0,0x442236c1,0x66b30054,0x00000000}},	//   rovè, ark_, _обшу,
  { {0xdb1800c7,0x35f7007e,0x3f8a36c2,0x00000000}},	//   llvä, _برود_, _albu_,
  { {0xa0680002,0x63bc36c3,0x12e70085,0x00000000}},	// [5e50] оаѓа_, born, _мінг,
  { {0x3dc60034,0x973c017f,0x248406a5,0x00000000}},	//   elow_, biće, ømme_,
  { {0x78a408ea,0xc3320149,0x2b47013d,0x00000000}},	//   _živl, _אוי_, venc_,
  { {0x3ce90066,0x7c220ae2,0xd13b0062,0x00000000}},	//   ľavo_, fror, _тхо_,
  { {0xdfdb011c,0x3ce900c3,0xdc980086,0x00000000}},	//   _във_, žavo_, овці_,
  { {0x50da0063,0x2f28014b,0xf2d5009a,0x00000000}},	//   _לקרא, _мюсо_, ֔עַ_,
  { {0x4ea4005e,0x2b4736c4,0xbd6b0121,0x00000000}},	//   _жрта, renc_, _крае_,
  { {0x386d0994,0x63bc36c5,0x98af007d,0x00000000}},	//   txer_, zorn, šače_,
  { {0x7c2236c6,0x63bc36c7,0x973c0130,0x00000000}},	//   cror, yorn, ziće,
  { {0x1b780032,0x6a670021,0xdb0336c8,0x00000000}},	//   _وصلة_, _وطال, ronó,
  { {0xa2bb0161,0x63bc065f,0x98ab005b,0x00000000}},	//   _शुल्, vorn, ıcı_,
  { {0xdb0336c9,0x973c017f,0x7c240025,0x00000000}},	//   inní, viće, áirg,
  { {0x63bc36ca,0xb7d6005d,0x19b80044,0x00000000}},	//   torn, تویا_, _بطلة_,
  { {0xdb180240,0x973c007d,0x27ff20aa,0x00000000}},	//   tové, tiće, mpun_,
  { {0x7d1b017f,0x63bc00c7,0x7d0236cb,0x00000000}},	//   _odus, rorn, ybos,
  { {0x31660118,0x66ed00ea,0x973c007d,0x00000000}},	//   ñoz_, _főké, riće,
  { {0x53a60076,0x27ff0150,0x1423000d,0x00000000}},	// [5e60] _наиб, npun_, _здым,
  { {0xdb0a00c7,0x7d1b000c,0x7c22006f,0x00000000}},	//   llfö, _adus, vror,
  { {0x27ff00e3,0xdd8f007e,0xee3a36cc,0x00000000}},	//   hpun_, گون_, сне_,
  { {0xdd990086,0x25a20080,0x7c2236cd,0x00000000}},	//   оші_, nikl_, tror,
  { {0x7d0236ce,0xdd8f0593,0x3dc636cf,0x00000000}},	//   rbos, دون_, rlow_,
  { {0x7d1b0659,0x543b0047,0x3dc636d0,0x00000000}},	//   _edus, מענא, slow_,
  { {0x61e60a1a,0xdb0300cd,0x27ff0089,0x00000000}},	//   _kikl, tonò, epun_,
  { {0x7c2236d1,0x645a008f,0x7bc11fdb,0x00000000}},	//   pror, ātij, _eklu,
  { {0x7dda0080,0x61e636d2,0x7c240139,0x00000000}},	//   _důst, _mikl, áird,
  { {0xdcfb007d,0xec130044,0x61e60075,0x00000000}},	//   _pluć, _أولد, _likl,
  { {0x78ad0024,0xb347017d,0x7c240006,0x00000000}},	//   _ľave, _liçõ, šird,
  { {0xc7b900ea,0x758b0121,0x78ad0078,0x00000000}},	//   lről_, ссов_, _žave,
  { {0x6fbe0042,0x5fbe0042,0x31b60042,0x00000000}},	//   ्तां, ्ताल, ंवैध,
  { {0x7dda0080,0x466a0330,0xe2f80054,0x00000000}},	//   _zůst, _грим_, зері_,
  { {0x2007007d,0x6d40035c,0xc7b9013d,0x00000000}},	//   ćnim_, _obma, iről_,
  { {0x31c4000a,0x25a2007d,0xd6a9005d,0x00000000}},	//   есув, cikl_, _بدهم_,
  { {0xc7b9000f,0x61e6028d,0x78a40c61,0x00000000}},	// [5e70] kről_, _dikl, _živj,
  { {0x4439001c,0x7dca0014,0x6d40004d,0x00000000}},	//   mts_, sýsl, _abma,
  { {0xa1950088,0x645d06a5,0x443936d3,0x00000000}},	//   _жанч, lvsi, lts_,
  { {0x44392bda,0x00000000,0x00000000,0x00000000}},	//   ots_,   ,   ,
  { {0x44390da1,0x7dda004c,0x00000000,0x00000000}},	//   nts_, _růst,   ,
  { {0xbb42005a,0x6d4036d4,0x69c20229,0x00000000}},	//   вешк, _ebma, _akoe,
  { {0x442b00cd,0x44392e38,0xdce80058,0x00000000}},	//   huc_, hts_, _çoğa,
  { {0xe8180053,0x443936d5,0x2b40007d,0x00000000}},	//   _दिखा_, kts_, đica_,
  { {0xdce0003d,0x27ff003e,0x6d4b334f,0x00000000}},	//   _domē, upun_, mega,
  { {0x27ff0397,0xe6190086,0x442b36d6,0x00000000}},	//   rpun_, одо_, duc_,
  { {0x6d4b0179,0x645d20e2,0x6abe004d,0x00000000}},	//   oega, evsi, üpft,
  { {0x7c24017f,0x9a880021,0x6d4b36d7,0x00000000}},	//   šire, _عَنْ_, nega,
  { {0x7c2b36d8,0x3958008f,0x61e636d9,0x00000000}},	//   nugr, ērst_, _rikl,
  { {0xa49b00cd,0x6d4b36da,0xf7450062,0x00000000}},	//   mbòl, hega, _цеко,
  { {0x0caa0161,0x443936db,0x645d005b,0x00000000}},	//   _कश्म, ats_, avsi,
  { {0x44390be9,0x27e70026,0x69c906aa,0x00000000}},	//   bts_, _hinn_, nlee,
  { {0x44390d20,0x6d4b36dc,0x200b002b,0x00000000}},	// [5e80] cts_, dega, _cwci_,
  { {0x290f36dd,0x78a4007d,0xef1a02fe,0x00000000}},	//   _lega_, _živk, іме_,
  { {0x27e7007a,0x61e61141,0x6d4b017d,0x00000000}},	//   _minn_, _tikl, fega,
  { {0x27e70560,0x3ea70025,0x6f0e08dc,0x00000000}},	//   _linn_, únta_, _webc,
  { {0xc7b900ea,0x61e101a8,0xab5c0023,0x00000000}},	//   tről_, ïlle, _akļa,
  { {0x290f0019,0x399100ea,0x39a5001c,0x00000000}},	//   _aega_, _lásd_, zēst_,
  { {0xcf570063,0x6d4b2e6a,0x2d8d00e5,0x00000000}},	//   _קבלת_, bega, _flee_,
  { {0xd90d007e,0xc7b900ea,0x69c90466,0x00000000}},	//   میم_, sről_, glee,
  { {0x274a0098,0xdb180195,0xab5c008f,0x00000000}},	//   очно_, loví, _ekļa,
  { {0x27e70025,0xf69800e1,0xdb03017d,0x00000000}},	//   _cinn_, звој_, hinê,
  { {0xdce0003d,0xe535000d,0x69c936de,0x00000000}},	//   _tomē, нень, blee,
  { {0x27e7007a,0x44392e83,0xd5670a36,0x00000000}},	//   _einn_, tts_, фтоп,
  { {0x27e71609,0x2007007d,0x1cbb0047,0x00000000}},	//   _finn_, ćnik_, ַמלע,
  { {0x443910c5,0x25a036df,0x6d4b0022,0x00000000}},	//   rts_, _emil_, zega,
  { {0xeb910047,0x7c2b00bd,0x443936e0,0x00000000}},	//   אָן_, zugr, sts_,
  { {0xd5b9001c,0x69c036e1,0xdb03017d,0x00000000}},	//   irāk_, nome, ginê,
  { {0x9099005a,0x6d4b36e2,0x629a0024,0x00000000}},	// [5e90] чват_, vega, útor,
  { {0x6e950184,0x325508ac,0x6fcb004d,0x00000000}},	//   низу, _звор, mück,
  { {0x4fc41968,0x6fcb004d,0x6d4b36e3,0x00000000}},	//   тста, lück, tega,
  { {0x69c00022,0x98a20022,0xdbed01ce,0x00000000}},	//   jome, żkę_, бскe_,
  { {0x6d5d0026,0x69c9006f,0x69c036e4,0x00000000}},	//   _ósam, vlee, dome,
  { {0x686d0047,0x6d4b36e5,0x7c2b006f,0x00000000}},	//   _באַזו, sega, rugr,
  { {0x27e736e6,0x6d4b36e7,0x290f1353,0x00000000}},	//   _rinn_, pega, _pega_,
  { {0x69c0158d,0xeab0014d,0xdb030137,0x00000000}},	//   gome, جعه_, jonö,
  { {0xb7bd000c,0x69c90b93,0x290f36e8,0x00000000}},	//   luţi, rlee, _vega_,
  { {0x25a036e9,0xe7390001,0x69c92493,0x00000000}},	//   _smil_, чео_, slee,
  { {0x290f0198,0xaa950032,0xb7bd003b,0x00000000}},	//   _tega_, _ثلاث, nuţi,
  { {0x69c036ea,0xceb200ff,0x26c7005f,0x00000000}},	//   come, ריט_, _vyno_,
  { {0x394d36eb,0x27e736ec,0x186936ed,0x00000000}},	//   mees_, _tinn_, _хали_,
  { {0x394d021f,0x987a0047,0x33d50454,0x00000000}},	//   lees_, _מאנט, віст,
  { {0x28db0053,0xdb03002b,0x324312a5,0x00000000}},	//   मेरि, einë, лерг,
  { {0x394d36ee,0x78a436ef,0x6fcb004d,0x00000000}},	//   nees_, _živi, lüch,
  { {0xf99200b7,0xe3b2007e,0x8c9f0053,0x00000000}},	// [5ea0] ארן_, _مرد_, _खेलो,
  { {0xa2bb0161,0xdb181ca9,0x996c004c,0x00000000}},	//   _शुक्, toví, měť_,
  { {0x7dca0ac6,0x61fe08a9,0xdfcf0021,0x00000000}},	//   lýsi, _utpl, حيل_,
  { {0xdb0300cd,0x99800078,0xfd120021,0x00000000}},	//   linè, čiū_, اجا_,
  { {0x8ba6005a,0x394d0c5d,0x8cf30085,0x00000000}},	//   нидж, dees_, узіц,
  { {0xdb180080,0xb7bd000c,0xd5b9008f,0x00000000}},	//   poví, buţi, trāk_,
  { {0x394d00ac,0xb7bd000c,0xe9e633df,0x00000000}},	//   fees_, cuţi, нцио,
  { {0xf9920032,0x394d36f0,0x69c01dc1,0x00000000}},	//   طبع_, gees_, uome,
  { {0xdcef007d,0x57a61910,0x69c036f1,0x00000000}},	//   _šeće, ешна, rome,
  { {0x69c00009,0x5a962848,0x9f420072,0x00000000}},	//   some, _преф, _etkö_,
  { {0x6456014f,0x69c00e32,0x65950085,0x00000000}},	//   _asyi, pome, вану,
  { {0xceb3014e,0x6fcb00bd,0x399a008f,0x00000000}},	//   טית_, tück, gūst_,
  { {0x6fcb004d,0xa3bd0053,0xf53f0137,0x00000000}},	//   büch, इकल_, rfå_,
  { {0x6fcb0199,0xdb0301a8,0x48071313,0x00000000}},	//   rück, ginè, _џејн_,
  { {0xc68f0002,0xe167005e,0x25ea0042,0x00000000}},	//   _сѐ_, нђан, _घंटी_,
  { {0x661a00c7,0x3ce902e2,0x04950021,0x00000000}},	//   mstk, žavi_, _للبح,
  { {0x656d0035,0xb5070053,0xd6df0022,0x00000000}},	// [5eb0] _inah, _व्यय_, ąłem_,
  { {0xb7bd000c,0x661a36f2,0x90540085,0x00000000}},	//   tuţi, ostk, ывуц,
  { {0x394d0034,0x4e18007e,0xa2950454,0x00000000}},	//   yees_, فتند_, _рані,
  { {0xdb030164,0x63a736f3,0xe8210053,0x00000000}},	//   miné, lijn, _मिला_,
  { {0x2fd90021,0xd259001c,0xdb0336f4,0x00000000}},	//   _يوجد_, āņu_, liné,
  { {0xc4d40e2a,0x394d0104,0x661a36f5,0x00000000}},	//   נגס_, wees_, kstk,
  { {0xbd050164,0x394d36f6,0x29020058,0x00000000}},	//   _créé, tees_, ıkan_,
  { {0x63a70122,0x49980121,0x7c240ef0,0x00000000}},	//   hijn, етья_, šira,
  { {0x79890150,0x394d36f7,0x6fcb004d,0x00000000}},	//   rkew, rees_, tüch,
  { {0x656d04ab,0xfd4d001b,0x394d36f8,0x00000000}},	//   _anah, _ngoạ, sees_,
  { {0x6fcb00bd,0x6d5b0213,0x394d36f9,0x00000000}},	//   rüch, _kaua, pees_,
  { {0xdb180080,0x6d910066,0xdb0336fa,0x00000000}},	//   mová, eťaz, diné,
  { {0x399a00b5,0x6d5b05b3,0xdb182f90,0x00000000}},	//   _קינד, _maua, lová,
  { {0xdb0336fb,0xc3550062,0x63a736fc,0x00000000}},	//   conô, лъсъ, gijn,
  { {0xdb180080,0x21a60002,0x10f60085,0x00000000}},	//   nová, вивм, вязя,
  { {0x38600734,0xfe72007e,0xdb0a01a8,0x00000000}},	//   _širi_, یدا_, nofò,
  { {0xdb18004a,0x63a7006f,0x7bc336fd,0x00000000}},	// [5ec0] hová, bijn, konu,
  { {0xdb1802f4,0x63a7006f,0xdfcf01a7,0x00000000}},	//   ková, cijn, قيق_,
  { {0xe3b2006a,0xa22a005a,0xdb180080,0x00000000}},	//   _مرگ_, _южна_, jová,
  { {0xdb1802f4,0x6d93005b,0x6d5b132b,0x00000000}},	//   dová, _açab, _caua,
  { {0x7bc336fe,0xdb0a06fe,0xeb9a263d,0x00000000}},	//   fonu, xofó, мид_,
  { {0x661a0051,0x2bc70062,0x7bc336ff,0x00000000}},	//   ystk, кущо_, gonu,
  { {0xcb670001,0xdb18004c,0x8fa31c9b,0x00000000}},	//   таје_, gová, _таре,
  { {0x69d90185,0x63a73700,0xea950085,0x00000000}},	//   _chwe, zijn, ышчэ,
  { {0xdb34006a,0x8c460001,0x4813000d,0x00000000}},	//   _مذاک, _језе, амыс,
  { {0xdb180260,0x656d3561,0x7bc33701,0x00000000}},	//   bová, _snah, conu,
  { {0xdb182f42,0xdce00006,0xafdb00d1,0x00000000}},	//   cová, _pomė, _spøk,
  { {0x891a006a,0x63a7006f,0x6448000c,0x00000000}},	//   _آغاز_, wijn, ădin,
  { {0xd873006a,0x63a7006f,0x6dbc007d,0x00000000}},	//   _ناوب, tijn, mčad,
  { {0x6235270f,0xdb030003,0xdbcf0066,0x00000000}},	//   легу, tiné, _sľúb,
  { {0x91c70001,0x63a73702,0x248d0a97,0x00000000}},	//   вљал, rijn, šem_,
  { {0xe5c40086,0x656d0380,0x7bc33703,0x00000000}},	//   _всьо, _unah, zonu,
  { {0xdb1802f4,0x63a73704,0x7bc3005b,0x00000000}},	// [5ed0] zová, pijn, yonu,
  { {0x2fc700aa,0x24843705,0x3e070062,0x00000000}},	//   ông_, ämme_, вядв,
  { {0xdb180080,0x200201f7,0x9987003b,0x00000000}},	//   xová, _etki_, nunţ_,
  { {0xdb1802f4,0xa49b01a8,0x442b002b,0x00000000}},	//   vová, rcòf, orc_,
  { {0x7bc33706,0x23ad00c2,0xa3b8007e,0x00000000}},	//   tonu, ažje_, _سایر_,
  { {0x764a0146,0xdb182de9,0x442b0139,0x00000000}},	//   _opfy, tová, irc_,
  { {0xa9a51705,0x69d9002b,0x7bc33707,0x00000000}},	//   ликд, _phwe, ronu,
  { {0xdb180080,0x7f5c2630,0xceb20149,0x00000000}},	//   rová, _zarq, _היל_,
  { {0xdb180080,0xf771013a,0x7bc33708,0x00000000}},	//   sová, ماد_, ponu,
  { {0xdb180080,0x68fb3709,0x7dd80014,0x00000000}},	//   pová, scud, ríse,
  { {0x6f1502dd,0x386600a5,0xdcfb004c,0x00000000}},	//   _mezc, _eror_, _louč,
  { {0x3ce9017f,0x6b81370a,0xd5b90023,0x00000000}},	//   žavu_, _holg, zrāv_,
  { {0x28f80076,0x386601e1,0xf74514e9,0x00000000}},	//   _речь_, _gror_, _бело,
  { {0x395f2684,0x395d001f,0x7d19002b,0x00000000}},	//   ldus_, _haws_, haws,
  { {0x321e0195,0x442b370b,0x395f370c,0x00000000}},	//   éty_, arc_, odus_,
  { {0x395f370d,0x20020150,0x395d00e5,0x00000000}},	//   ndus_, _ptki_, _jaws_,
  { {0xdb0100ea,0x7f5c370e,0xd175000d,0x00000000}},	// [5ee0] _emlé, _parq, шыры,
  { {0x395d0034,0x4420370f,0xd00f00f2,0x00000000}},	//   _laws_, _ivi_, سلم_,
  { {0x6fd00137,0x11d603eb,0x7c2b23ef,0x00000000}},	//   läck, _متحد, ergr,
  { {0x427b0047,0x7dd8017d,0x395d002b,0x00000000}},	//   _נאכג, dísc, _naws_,
  { {0x395f0185,0x6b813710,0x7f5c3711,0x00000000}},	//   ddus_, _bolg, _tarq,
  { {0x8f760086,0x6b813712,0x395f0078,0x00000000}},	//   _сумі, _colg, edus_,
  { {0x261100c3,0x2d9c0164,0x8a460021,0x00000000}},	//   jšo_, èves_, ائتم,
  { {0x7d0d007a,0x4420027c,0x316000f8,0x00000000}},	//   ðast, _ovi_, ndiz_,
  { {0x6b810199,0x58d80062,0x5b360593,0x00000000}},	//   _folg, ъдия_, _معار,
  { {0x2ca70001,0x6c830021,0xf62a0086,0x00000000}},	//   _скуп_, _الْم, німи_,
  { {0x9f4a0025,0xd5b9001c,0x44203713,0x00000000}},	//   _cibé_, krāt_, _avi_,
  { {0x6d4600c7,0x394600a4,0x386606a3,0x00000000}},	//   _ökad, _ubos_, _tror_,
  { {0x261100c3,0x98a31e51,0xb865007e,0x00000000}},	//   ašo_, _лице, _پانو,
  { {0x7524051e,0x44200006,0x7d190051,0x00000000}},	//   _ediz, _dvi_, zaws,
  { {0xdcfb0080,0xb5950086,0x6fd0004d,0x00000000}},	//   _souč, _вийш, mäch,
  { {0x6fd03714,0xdcfb3715,0x442b013d,0x00000000}},	//   läch, _pouč, prc_,
  { {0x7ff70021,0x0f150071,0x442004f9,0x00000000}},	// [5ef0] اسرا, имаю, _gvi_,
  { {0x6fd000bd,0x395f0006,0x644d00a4,0x00000000}},	//   näch, zdus_, _ipai,
  { {0x644e00c3,0x12fa0063,0x395f002b,0x00000000}},	//   čniš, _בהתב, ydus_,
  { {0x6b8102ab,0x6fd0004d,0x25ab00a3,0x00000000}},	//   _solg, häch, nicl_,
  { {0xf41f024a,0x6b811e49,0x44200ebd,0x00000000}},	//   nsä_, _polg, _xvi_,
  { {0x200906a7,0x3f8f001c,0x61ef00dd,0x00000000}},	//   mpai_, īgus_, _hicl,
  { {0x6b810102,0x6fd0004d,0x49951b06,0x00000000}},	//   _volg, däch, ишит,
  { {0x395f3716,0x6b810518,0x2009008f,0x00000000}},	//   udus_, _wolg, opai_,
  { {0x395f003d,0x3f830720,0x5d840021,0x00000000}},	//   rdus_, _koju_, _القل,
  { {0x6fd00137,0xdb030139,0xb7bd003b,0x00000000}},	//   väck, oiní, orţi,
  { {0xe8150235,0x44200117,0x2d850164,0x00000000}},	//   _दौरा_, _svi_, _îles_,
  { {0x629c00c3,0x6fd00137,0xca2c0047,0x00000000}},	//   vzro, täck, _טובֿ,
  { {0x6d490027,0x290d0035,0xdb033717,0x00000000}},	//   _mbea, mbea_, minâ,
  { {0x6fd000c7,0x798200ca,0x889a0165,0x00000000}},	//   räck, _zoow, _בבני,
  { {0xf53f0146,0x629c017f,0x6d490137,0x00000000}},	//   rnår_, uzro, _obea,
  { {0xd1320032,0x60260086,0x61ef2070,0x00000000}},	//   تمر_, идба, _cicl,
  { {0xf53f02fb,0xcef60d34,0x20870065,0x00000000}},	// [5f00] pnår_, ачењ, айти_,
  { {0xdb033718,0x644100dd,0x8fa60085,0x00000000}},	//   finí, ălit, шазе,
  { {0xed5a019d,0xd5b9001c,0xee3a3719,0x00000000}},	//   кож_, prāt_, тне_,
  { {0x22470137,0x3d100053,0x9d460054,0x00000000}},	//   _änka_, ारें_, редд,
  { {0x3ad5008b,0xdb03017d,0xb7bd003b,0x00000000}},	//   _áp_, dinâ, arţi,
  { {0xca2606da,0x61f10014,0xab3817e2,0x00000000}},	//   афии, _óklá, упку_,
  { {0x8a030002,0x5f79009a,0x34d30042,0x00000000}},	//   озје, _עָשׂ, _सर्द,
  { {0x6fd0004d,0x23ad00c2,0x9977003b,0x00000000}},	//   wäch, ižja_, văţ_,
  { {0x57f3093e,0x973c007d,0xa9670141,0x00000000}},	//   опыт, lići, риња_,
  { {0x997700dd,0x2d84371a,0x61e40b75,0x00000000}},	//   tăţ_, _home_, hmil,
  { {0x2d84371b,0x61e40080,0x644d1729,0x00000000}},	//   _kome_, kmil, _spai,
  { {0x6fd000bd,0xf41f0072,0x61e4371c,0x00000000}},	//   säch, tsä_, jmil,
  { {0xb4470088,0x94a8143c,0x61e414cb,0x00000000}},	//   шэнк, атра_, dmil,
  { {0x248400c7,0x61e40214,0xa5c70014,0x00000000}},	//   ämma_, emil, _blóð,
  { {0xf41f09ff,0xb06200fe,0xd5b9001c,0x00000000}},	//   ssä_, äänn, urās_,
  { {0x2d84371d,0x3d100161,0xf41f0072,0x00000000}},	//   _nome_, ारों_, psä_,
  { {0xc1040021,0x75d5007e,0x7c2400b2,0x00000000}},	// [5f10] توقي, _پيکا, širj,
  { {0x6e67005a,0x68f50080,0x61e4371e,0x00000000}},	//   итеж, ězdi, amil,
  { {0xede7000d,0x2d8400ac,0x7dd100d1,0x00000000}},	//   аўдн, _bome_, låsi,
  { {0x2d84055b,0x91e40002,0xdb0a0014,0x00000000}},	//   _come_, _моќе, nnfæ,
  { {0x99510a63,0x1bd50062,0x2d84371f,0x00000000}},	//   _náš_, бодя, _dome_,
  { {0x2bbb0032,0xebc7005e,0xdb0a006c,0x00000000}},	//   خاصة_, шљен, nifè,
  { {0xb222007a,0x2d840016,0x5e950021,0x00000000}},	//   _áætl, _fome_, _الأط,
  { {0x7dd80024,0xd2b80132,0x61fa0014,0x00000000}},	//   písa, ילות_, ítli,
  { {0xf8a9006a,0xf719000d,0x290d3720,0x00000000}},	//   دگاه_, ліны_, rbea_,
  { {0x25a9053b,0xda67005d,0x00000000,0x00000000}},	//   _amal_, _پائي,   ,
  { {0x61e43721,0x16a90094,0x8aa7309f,0x00000000}},	//   ymil, увни_, _трад,
  { {0x857a000a,0x764100ac,0xceb2009f,0x00000000}},	//   усот_, rtly, ליי_,
  { {0xa5c70026,0xe8210053,0x61e401e1,0x00000000}},	//   _slóð, _मिटा_, vmil,
  { {0x61e400e5,0x25a93722,0xd6a8005d,0x00000000}},	//   wmil, _emal_, ادیم_,
  { {0xe2973723,0x9196005e,0x412a0f50,0x00000000}},	//   бар_, бјаш, лово_,
  { {0x61e41e90,0x21a3007b,0x973c0130,0x00000000}},	//   umil, писм, vići,
  { {0xe0da3724,0xa3ba007e,0x03a60121,0x00000000}},	// [5f20] ува_, _مادر_, _гипо,
  { {0xe47b01d8,0x2d840034,0x61e43725,0x00000000}},	//   _עריכ, _some_, smil,
  { {0xdb0300cd,0x4422356a,0xc7d60063,0x00000000}},	//   dinà, lsk_, צועי_,
  { {0xc6da0047,0x628e0078,0x44220137,0x00000000}},	//   אַדר, mybo, osk_,
  { {0x442231d4,0x653b0047,0xdb0100ea,0x00000000}},	//   nsk_, רענד, _emlí,
  { {0xdb0300cd,0x6d930075,0x44223726,0x00000000}},	//   ginà, _uçan, isk_,
  { {0x2d843727,0x628e3728,0x5b230044,0x00000000}},	//   _tome_, nybo, سفيل,
  { {0xed5a019d,0xd90d007e,0x442204aa,0x00000000}},	//   _щоб_, نیم_, ksk_,
  { {0x98ad017c,0x44223729,0x628e01d1,0x00000000}},	//   adeľ_, jsk_, hybo,
  { {0x99510512,0x7d02051e,0x628e0006,0x00000000}},	//   _váš_, lcos, kybo,
  { {0x9f9400fe,0x7d020331,0x7c22372a,0x00000000}},	//   mää_, ocos, lsor,
  { {0x799b0122,0x7d0200c3,0x628e0006,0x00000000}},	//   chuw, ncos, dybo,
  { {0x6f1e000f,0x442200b9,0x7d0201f4,0x00000000}},	//   kapc, gsk_, icos,
  { {0x9f9400fe,0xe6940121,0x63ae00c2,0x00000000}},	//   nää_, _милы, gibn,
  { {0xdb0a372b,0x78ad0066,0x4422372c,0x00000000}},	//   rifè, _ľavi, ask_,
  { {0x644000cd,0x78ad0078,0x16370063,0x00000000}},	//   àmic, _žavi, _הנהר_,
  { {0x9f9400fe,0x628e0058,0xc10414d7,0x00000000}},	// [5f30] kää_, aybo, سولي,
  { {0x9f9400fe,0x673a00b9,0x7c22372d,0x00000000}},	//   jää_, ngtj, dsor,
  { {0xdfd8005a,0xdb03027d,0x9e150086,0x00000000}},	//   сът_, jiná, ідді,
  { {0x25b90026,0xfe700021,0x3cd50bb8,0x00000000}},	//   nnsl_, عدل_, ожес,
  { {0x913a0047,0x7c840001,0xef670062,0x00000000}},	//   _דערק, зује, _лъво,
  { {0xcb690001,0x60dd008f,0x7e620022,0x00000000}},	//   раке_, _izsm, łopa,
  { {0xfbd00021,0x49990ac5,0xdb03372e,0x00000000}},	//   رته_, ития_, giná,
  { {0xe9d90635,0x38290001,0xdcfb003b,0x00000000}},	//   јки_, ажио_, _două,
  { {0x628e0022,0x2eb90042,0x7c22372f,0x00000000}},	//   zybo, _आशुत, csor,
  { {0x6dbc3730,0x76253731,0x998000b2,0x00000000}},	//   nčan, омоз, čiš_,
  { {0x98b901f7,0x7d1b3732,0x36c505ac,0x00000000}},	//   ısı_, _keus, юбог,
  { {0x3cf00053,0x442206f1,0x1dc90042,0x00000000}},	//   ुँचे_, tsk_, िकित,
  { {0x628e001f,0x44242840,0x44222c2d,0x00000000}},	//   wybo, ém_, usk_,
  { {0x442204b1,0x7c240025,0x6dbc007d,0x00000000}},	//   rsk_, áiri, jčan,
  { {0x6d930058,0xa18a0062,0x1546089a,0x00000000}},	//   _açam, абва_, _дейм,
  { {0x7c24027c,0x7bca3733,0x7c22001f,0x00000000}},	//   širi, zofu, ysor,
  { {0xef1a3734,0x7bca0035,0xdb0301c2,0x00000000}},	// [5f40] има_, yofu, ziná,
  { {0xafdb0307,0x65641668,0x3fe30086,0x00000000}},	//   _spør, _haih, джув,
  { {0x9f94024a,0x2eee0137,0x7763132b,0x00000000}},	//   vää_, äff_, _manx,
  { {0xdb030114,0x64460072,0x216a0054,0x00000000}},	//   viná, otki, _тими_,
  { {0x9f94024a,0x7c830076,0x7d023735,0x00000000}},	//   tää_, дуще, rcos,
  { {0x7d023736,0x7c223737,0x7d1b00ac,0x00000000}},	//   scos, rsor, _eeus,
  { {0x7c223738,0x9f9400fe,0x6446004b,0x00000000}},	//   ssor, rää_, htki,
  { {0x9f94024a,0x6f1c3739,0x2d9533e3,0x00000000}},	//   sää_, _herc, _ерус,
  { {0xa3da0053,0xdb032d4b,0xc19b0047,0x00000000}},	//   ़ता_, dinæ, ישקי,
  { {0x24440137,0xdb03027d,0x478a0062,0x00000000}},	//   döm_, piná, рсим_,
  { {0x4efb0047,0x0f570063,0x45d5007b,0x00000000}},	//   יליג, חיים_, зонс,
  { {0x65ab0074,0xd49b0054,0xe60f005d,0x00000000}},	//   ртог_, арг_, کشی_,
  { {0xf3ff017d,0x6564373a,0x6d4025cb,0x00000000}},	//   rvão_, _daih, _mcma,
  { {0x8c480058,0xb8070044,0x00000000,0x00000000}},	//   mağı, _بيوم_,   ,
  { {0x6dbc3010,0xb595005e,0x9268373b,0x00000000}},	//   včan, _никш, орта_,
  { {0x65c4373c,0x6b88373d,0x60f90895,0x00000000}},	//   _обја, _lodg, сная_,
  { {0x7dd80024,0x6f1c373e,0x8c480058,0x00000000}},	// [5f50] rísl, _berc, nağı,
  { {0x6f1c373f,0xdfd101a7,0x5e6b0001,0x00000000}},	//   _cerc, ريا_, ијег_,
  { {0x44393740,0xdb030058,0x6dbc3741,0x00000000}},	//   lus_, linç, rčan,
  { {0x44393742,0xd5b9001c,0xdce0005b,0x00000000}},	//   ous_, ksām_, _almı,
  { {0x6f1c001f,0x6dbc29c3,0x44393743,0x00000000}},	//   _ferc, pčan, nus_,
  { {0xf1bf007a,0x2d9d0035,0x6d460137,0x00000000}},	//   _hjá_, shwe_, _ökan,
  { {0x44393744,0x2d870003,0x69c40078,0x00000000}},	//   hus_, ênes_, čien,
  { {0x6dbc08ea,0x776301a8,0xb2bc009f,0x00000000}},	//   nčal, _sanx, ימור,
  { {0x44393745,0x65640089,0x291f3746,0x00000000}},	//   jus_, _raih, raua_,
  { {0xe7390001,0x6d593747,0x753d3748,0x00000000}},	//   љен_, lewa, egsz,
  { {0x44393749,0xc4c9009a,0x6f48009a,0x00000000}},	//   eus_, _עג_, חֲרַ,
  { {0x4439374a,0x200b004c,0x6d59374b,0x00000000}},	//   fus_, _otci_, newa,
  { {0x6564024a,0x8c4801f7,0x644600fe,0x00000000}},	//   _vaih, cağı, utki,
  { {0x291d0035,0x2444374c,0x6d59374d,0x00000000}},	//   _hewa_, röm_, hewa,
  { {0x64460045,0x6721017f,0xf77000b3,0x00000000}},	//   stki, malj, _جان_,
  { {0x4439374e,0x6f1c374f,0xdb033750,0x00000000}},	//   bus_, _serc, linä,
  { {0x2120003e,0x6f1c3751,0xe53b0063,0x00000000}},	// [5f60] raih_, _perc, _התפר,
  { {0x291d3752,0xdb030656,0x67213753,0x00000000}},	//   _lewa_, ninä, nalj,
  { {0x6f1c3754,0x02fb0063,0x6b8811c6,0x00000000}},	//   _verc, _ללימ, _rodg,
  { {0x0d86000d,0x6d591b28,0x7e620051,0x00000000}},	//   ялен, gewa, łopo,
  { {0x0b8a011c,0x25fd0053,0x6f1c3755,0x00000000}},	//   йски_, _रूसी_, _terc,
  { {0xa136007e,0xab27005e,0x61fe3756,0x00000000}},	//   _برگش, поља_, _kupl,
  { {0x67213757,0x9ea70dd5,0x4bd9000d,0x00000000}},	//   dalj, _евра_, цьця_,
  { {0x6d590ff0,0xa8a6005e,0x79a30121,0x00000000}},	//   cewa, зрок, ерье,
  { {0x291d00f3,0xdca308a0,0x7dd10205,0x00000000}},	//   _dewa_, _зати, råst,
  { {0xdce0027c,0x44393758,0xdc9b3759,0x00000000}},	//   _jamč, vus_, _הסמכ,
  { {0x443900e8,0xe535066e,0x8c480058,0x00000000}},	//   wus_, мень, sağı,
  { {0xdb03017d,0x7c24007d,0x39ea005e,0x00000000}},	//   tinç, širu, _удео_,
  { {0x443902a8,0x6f050022,0x67210130,0x00000000}},	//   uus_, ychc, balj,
  { {0xf1bf007a,0x4439375a,0x6d590051,0x00000000}},	//   _sjá_, rus_, zewa,
  { {0x4439375b,0xf2c41c9d,0x66e302d8,0x00000000}},	//   sus_, естн, _поља,
  { {0x4439375c,0x61fe375d,0xdb0a0331,0x00000000}},	//   pus_, _dupl, difí,
  { {0xf53f0307,0xa2cd0053,0x20d70021,0x00000000}},	// [5f70] mgå_, _दुर्, سترج,
  { {0x6e95005e,0x39b7003b,0x4fd401d5,0x00000000}},	//   мизу, răsi_, ежут,
  { {0x44290031,0xb81e0161,0x6d59375e,0x00000000}},	//   _hva_, _मौसम_, tewa,
  { {0xf53f0031,0x4429375f,0xdb1a18a8,0x00000000}},	//   ngå_, _kva_, _októ,
  { {0x61e1006f,0x5067000d,0x6d593760,0x00000000}},	//   ïllu, _этна, rewa,
  { {0x291d014f,0x9f4700fe,0x6dbc085a,0x00000000}},	//   _sewa_, önä_, nčaj,
  { {0x6721074f,0x291d0035,0x752d007d,0x00000000}},	//   valj, _pewa_, _odaz,
  { {0x4429055e,0xceb20063,0xdb180114,0x00000000}},	//   _ova_, _סין_, mový,
  { {0xf53f0146,0x7c240027,0xdb18004a,0x00000000}},	//   dgå_, áirt, lový,
  { {0x7c293761,0x66050062,0xa088009a,0x00000000}},	//   _iver, мпоа, לְתִ,
  { {0x7c2917d3,0xdb18004a,0x672108ed,0x00000000}},	//   _hver, nový, ralj,
  { {0xc3290ee1,0x6721017f,0x7dd80014,0x00000000}},	//   _כו_, salj, vísk,
  { {0x61fe3762,0x89340021,0x7aed0080,0x00000000}},	//   _supl, _أعما, žitě,
  { {0x9980034d,0x7ae40080,0xdb18004a,0x00000000}},	//   čiť_, řite, kový,
  { {0x386d0f15,0x3f8a02f7,0x614602f8,0x00000000}},	//   lver_, _robu_, мева,
  { {0x7dd80026,0x3f8a007d,0xdb180114,0x00000000}},	//   rísk, _sobu_, dový,
  { {0xb17b0137,0x7dd80014,0x386d365a,0x00000000}},	// [5f80] _ihål, sísk, nver_,
  { {0x7d093763,0xb17b00d1,0xdb0a00ed,0x00000000}},	//   _afes, _uhån, tifí,
  { {0xdfcf0032,0x386d02ab,0x61fe00a4,0x00000000}},	//   جيل_, hver_, _uupl,
  { {0x7c290244,0xfbcf005d,0x00000000,0x00000000}},	//   _bver, یتو_,   ,
  { {0x386d0122,0x7dd81ea0,0xfb860085,0x00000000}},	//   jver_, nísi, дыйн,
  { {0x6dbc00c2,0xdb0a00d1,0xdb180114,0x00000000}},	//   očak, nnfø, bový,
  { {0x7c290034,0x386d244c,0x7d09001f,0x00000000}},	//   _ever, ever_, _ffes,
  { {0x39420019,0xd91a0086,0x7c3100b9,0x00000000}},	//   üks_, цьк_, åkræ,
  { {0x6dbc0024,0x660d0dec,0x7c293764,0x00000000}},	//   yčaj, _čaka, _gver,
  { {0x9f410025,0x7dd8006d,0x26d8004b,0x00000000}},	//   omhá_, dísi, üroo_,
  { {0x7c290024,0x4429074f,0x386d3765,0x00000000}},	//   _zver, _sva_, aver_,
  { {0x9a250021,0x7dd80530,0x56930499,0x00000000}},	//   _أعلن, físi, тают,
  { {0xf53f00c7,0xf8e20053,0xdce20066,0x00000000}},	//   rgå_, _परिय, hkoľ,
  { {0xf53f0137,0xb17b0137,0x75fe0023,0x00000000}},	//   sgå_, _ehål, _līzi,
  { {0xdce20024,0xdb180124,0x07a30092,0x00000000}},	//   jkoľ, xový, _јајн,
  { {0x6448000c,0x23ad00c2,0x3f8e0014,0x00000000}},	//   ădir, ižji_, öfun_,
  { {0x44293766,0x2d860150,0x00000000,0x00000000}},	// [5f90] _uva_, djoe_,   ,
  { {0xdb180240,0xc7d8009d,0x00000000,0x00000000}},	//   tový, פַּכ,   ,
  { {0x7c291e79,0x63b500c2,0x9df90121,0x00000000}},	//   _sver, mizn, чнет_,
  { {0xdb18004a,0x386d3767,0x60e80058,0x00000000}},	//   rový, yver_, örmü,
  { {0xac270076,0xdb18027d,0x399100ea,0x00000000}},	//   ффек, sový, _mást_,
  { {0x69c2017d,0x2484004b,0xdb180061,0x00000000}},	//   _ajoe, ämmi_, pový,
  { {0xd90f007e,0x19f50002,0x6d5b0021,0x00000000}},	//   لیا_, нџир, _وجرح_,
  { {0x7c2903a5,0x386d001c,0x9f590114,0x00000000}},	//   _tver, tver_, _musí_,
  { {0x386d1672,0x7c290ffb,0x61ed3768,0x00000000}},	//   uver_, _uver, imal,
  { {0x386d2b13,0xbf1d0053,0x61ed3769,0x00000000}},	//   rver_, _फ़ोन_, hmal,
  { {0x394d004d,0x386d376a,0x7d04376b,0x00000000}},	//   pfes_, sver_, žise,
  { {0x7dd8006d,0x3991004c,0x9958017c,0x00000000}},	//   tísi, _pásu_, _téš_,
  { {0xcd960063,0x38580044,0x61ed0023,0x00000000}},	//   גדרת_, _يشهد_, dmal,
  { {0x7dd8006d,0xf745006e,0xdce20066,0x00000000}},	//   rísi, _чеко, ykoľ,
  { {0xdb0a0827,0x7dd8006d,0x0cdc0053,0x00000000}},	//   nifá, sísi, _बर्म,
  { {0x61ed376c,0x69db0072,0x645a003b,0x00000000}},	//   gmal, nlue, ătib,
  { {0x55bb0063,0x3fe6376d,0x10150044,0x00000000}},	// [5fa0] _ממקו, ежав, َبْد,
  { {0x2d9f00fe,0x61ed376e,0x63b5376f,0x00000000}},	//   _alue_, amal, cizn,
  { {0xdee60b3f,0x2d9f3770,0xdce20066,0x00000000}},	//   хожи, _blue_, ukoľ,
  { {0xbd670086,0x2d9f00e5,0x7413005d,0x00000000}},	//   ерше_, _clue_, _جویا,
  { {0x2004000c,0x7f1a0088,0x6dbc005f,0x00000000}},	//   _îmi_, _ніву_, nčai,
  { {0x62810031,0x69c200ca,0x80af0042,0x00000000}},	//   ålog, _sjoe, ूपरे,
  { {0xcb070021,0xada62785,0x69db088a,0x00000000}},	//   ريين_, _завл, flue,
  { {0x6d930003,0x6df60044,0x2d9f3771,0x00000000}},	//   _sçav, _أكرا, _glue_,
  { {0xa3c0024c,0x2c0b007e,0xd83a000d,0x00000000}},	//   ंचा_, _فعلی_, чэй_,
  { {0x999f003d,0x69db00fe,0x61ed0745,0x00000000}},	//   ārši_, alue, zmal,
  { {0x61ed0045,0x63b5115b,0xcb8b0063,0x00000000}},	//   ymal, vizn, _מְאֹ,
  { {0x69db0732,0xba9b0063,0x7cf60058,0x00000000}},	//   clue, _מסבי, _gürü,
  { {0x19b70047,0x5893005d,0xf98700de,0x00000000}},	//   _אפאר_, _مجوز, _سنوي_,
  { {0xb3640062,0x62950022,0xa87b0041,0x00000000}},	//   лъск, tyzo, _מאדר,
  { {0x7cf6005b,0x2002190b,0x61ed3772,0x00000000}},	//   _yürü, _auki_, tmal,
  { {0x2509007e,0x26db01f9,0x61ed1621,0x00000000}},	//   _غربی_, _מקומ, umal,
  { {0x69c0120e,0x61ed3773,0x40342338,0x00000000}},	// [5fb0] inme, rmal, летс,
  { {0x200f003d,0xdb0a0014,0x8fa4005e,0x00000000}},	//   īgi_, lifæ, гађе,
  { {0x88bd0051,0x61ed005b,0x25b2001f,0x00000000}},	//   jaśn, pmal, _ymyl_,
  { {0x4c950002,0x442b28ea,0x56b70041,0x00000000}},	//   киес, osc_, עפאן_,
  { {0xdce0008f,0xc0580054,0xcb693774,0x00000000}},	//   _pamā, _пір_, дале_,
  { {0x7cf601f7,0x69c03775,0x44393776,0x00000000}},	//   _sürü, enme, irs_,
  { {0xdddc00ea,0xdb0a0026,0x9b920002,0x00000000}},	//   _errő, kifæ, ријц,
  { {0x69c00034,0x69db0072,0x44390130,0x00000000}},	//   gnme, ulue, krs_,
  { {0x442b0051,0x88e50062,0x98a53777,0x00000000}},	//   jsc_, ъжие, типе,
  { {0x69c0016d,0x69db00fe,0x7c2b230d,0x00000000}},	//   anme, slue, msgr,
  { {0x442b000c,0x7cf6005b,0x44393778,0x00000000}},	//   esc_, _türü, ers_,
  { {0x44390046,0xa5960054,0x38353779,0x00000000}},	//   frs_, трощ, _андр,
  { {0x7c2b3144,0x7dd80080,0x44630062,0x00000000}},	//   nsgr, míst, авяв,
  { {0x33d5126b,0x7dd80955,0x7c2b377a,0x00000000}},	//   гіст, líst, isgr,
  { {0x442b0025,0x799b0035,0x3f8e0026,0x00000000}},	//   asc_, okuw, öfum_,
  { {0x25a000f3,0xf8a5007e,0x798900d1,0x00000000}},	//   _ulil_, مک_, njew,
  { {0x41030002,0x6603322c,0x20d60054,0x00000000}},	// [5fc0] рзув, _hunk, тівс,
  { {0x6723377b,0x6603187b,0x7524004d,0x00000000}},	//   _jenj, _kunk, _heiz,
  { {0x67232920,0x7524377c,0x395f00fe,0x00000000}},	//   _menj, _keiz, keus_,
  { {0x660308d5,0x200200fe,0xdd990086,0x00000000}},	//   _munk, _tuki_, нші_,
  { {0x7dd83306,0x395f377d,0x7c2b2109,0x00000000}},	//   díst, deus_, gsgr,
  { {0x3946003b,0x7dd80026,0x6e3e00b9,0x00000000}},	//   _scos_, vísu, pupb,
  { {0xdb0300fe,0x395f377e,0xa9c6377f,0x00000000}},	//   ynnö, feus_, ксик,
  { {0x395f276a,0x9f43006d,0x7dd81493,0x00000000}},	//   geus_, _fijó_, gíst,
  { {0x69c00037,0xf1b3014e,0x8b26000d,0x00000000}},	//   rnme, יסה_, _адзе,
  { {0x799b0035,0x672300b2,0x66033780,0x00000000}},	//   akuw, _cenj, _bunk,
  { {0x44390185,0xd5b9003d,0x7524004d,0x00000000}},	//   wrs_, ksāt_, _beiz,
  { {0x7dd80016,0x4439001c,0x44200150,0x00000000}},	//   míss, trs_, _bwi_,
  { {0x44393781,0x442d0164,0x442b0290,0x00000000}},	//   urs_, ée_, usc_,
  { {0x44200185,0x03c40121,0x66033782,0x00000000}},	//   _dwi_, ассм, _funk,
  { {0xa2d60161,0x645a003b,0x7dd81494,0x00000000}},	//   _मुद्, ătia, níss,
  { {0x7c2b001f,0x9294000d,0xf1a40603,0x00000000}},	//   ysgr, шасц, арун,
  { {0x1075026c,0xcfab0044,0x9f550094,0x00000000}},	// [5fd0] ылаю, وائم_, лвач,
  { {0xcebb0001,0x6728017f,0xf0e30053,0x00000000}},	//   мље_, nadj, _खरीद_,
  { {0xdfd8011c,0xb0620019,0x12950002,0x00000000}},	//   тът_, äärn, _синџ,
  { {0x7dd80858,0x6d93005b,0xf6530149,0x00000000}},	//   díss, _açar, יצע_,
  { {0x2129003e,0x656d3783,0x7a400124,0x00000000}},	//   maah_, _maah, yštá,
  { {0xdd0301f7,0x7c2b1a92,0x7d16005b,0x00000000}},	//   ırıl, rsgr, ıysa,
  { {0x7dd83784,0x61fd3785,0x395f3786,0x00000000}},	//   tíst, _kisl, teus_,
  { {0x67232c8d,0x66030072,0xd5b9008f,0x00000000}},	//   _senj, _runk, isās_,
  { {0x6723310a,0x66032d70,0x7dd82aac,0x00000000}},	//   _penj, _sunk, ríst,
  { {0x67283378,0x66033787,0x6dbc017f,0x00000000}},	//   gadj, _punk, učav,
  { {0x6723007a,0x78a900ea,0x395f3788,0x00000000}},	//   _venj, szev, peus_,
  { {0x672800ac,0xb4db00cd,0xe81e0053,0x00000000}},	//   aadj, rgàn, _मौका_,
  { {0x21290089,0x69d905b3,0xe73906da,0x00000000}},	//   daah_, _ikwe, _зел_,
  { {0x5b7901f9,0x61fd3789,0x9f580003,0x00000000}},	//   ׂרָא, _aisl, _tiré_,
  { {0xdb030025,0x61fd378a,0x31be004c,0x00000000}},	//   ghné, _bisl, hůze_,
  { {0x6dbc1b7e,0xbf9b017d,0x76410150,0x00000000}},	//   nčat, _quên, muly,
  { {0x3160003d,0x442000a4,0xd5b9001c,0x00000000}},	// [5fe0] reiz_, _uwi_, rsāt_,
  { {0x6d490469,0xb81b0053,0x336608ac,0x00000000}},	//   _acea, पीएम_, _свог,
  { {0x52760086,0x3f91282d,0x61460062,0x00000000}},	//   _супу, _dozu_, _йена,
  { {0x7dd80555,0x61fd378b,0x9e75005e,0x00000000}},	//   víss, _gisl, шћуј,
  { {0x55ad0041,0x351b009d,0x00000000,0x00000000}},	//   ויאַ, גוננ,   ,
  { {0x437600b5,0x69c50003,0x7dd80555,0x00000000}},	//   רײַן_, éhen, tíss,
  { {0xad5a0a72,0xbea6378c,0x5fdb009a,0x00000000}},	//   _прах_, _савк, _נחלק,
  { {0x6d490027,0x7bc3001f,0x7dd804a5,0x00000000}},	//   _gcea, annu, ríss,
  { {0xa2d60053,0xf0b70047,0x7dd804a5,0x00000000}},	//   _मुस्, ָליר_, síss,
  { {0x6dbc0066,0x3cf10066,0x36d402b3,0x00000000}},	//   ačat, ňovú_, иопр,
  { {0x656d0332,0x7fd70047,0x6728378d,0x00000000}},	//   _paah, רויס_, radj,
  { {0xceb3014e,0xdb010003,0x645a003b,0x00000000}},	//   מית_, _allè, ătin,
  { {0xdb18017d,0x656f1205,0x249f0014,0x00000000}},	//   vivê, rdch, áum_,
  { {0x76410078,0x644f378e,0x6dbc378f,0x00000000}},	//   buly, rtci, očas,
  { {0x5b7b0047,0x656d0058,0xc6770049,0x00000000}},	//   ערלא, _taah, _محيط_,
  { {0xdb080026,0xdb030114,0xf204000d,0x00000000}},	//   _umdæ, diný, сяро,
  { {0x61fd001c,0x7bda002c,0xdb18004b,0x00000000}},	// [5ff0] _visl, _oktu, lovõ,
  { {0x6d493790,0xb4c30053,0x2fc7008d,0x00000000}},	//   _scea, ्थी_, õng_,
  { {0x6dbc0240,0xb7bd003b,0x3f91004c,0x00000000}},	//   jčas, usţi, _vozu_,
  { {0x5314007e,0x61fd0035,0xdb010003,0x00000000}},	//   _پذیر, _uisl, _illé,
  { {0x8b250ac5,0x7a11008f,0x6dbc0566,0x00000000}},	//   адле, _māte, včat,
  { {0x7bc32ffc,0xaa350054,0x69d9056c,0x00000000}},	//   unnu, ахищ, _skwe,
  { {0xf9910021,0xfaa525ef,0x8cb10082,0x00000000}},	//   قبة_, райо, _आइको,
  { {0xddca003b,0x7a0a0022,0x7c150054,0x00000000}},	//   ănţu, _tętn, _вдає,
  { {0xf09200b5,0x290d000c,0x6dbc00a2,0x00000000}},	//   ַנט_, rcea_, ačas,
  { {0xe1ff00cd,0x6dbc1035,0x22a00072,0x00000000}},	//   _lió_, bčas, näkö_,
  { {0x6dbc007d,0xda09005d,0xdb180046,0x00000000}},	//   mčar, _شيشه_, fnvæ,
  { {0x58d5011c,0x69d900ac,0x68ee0058,0x00000000}},	//   _коет, _ukwe, öndü,
  { {0xdb013791,0xdd140066,0x645a00dd,0x00000000}},	//   _allé, núši, ătio,
  { {0xa6950001,0x6dbc00b2,0x98a21a2f,0x00000000}},	//   _вриј, nčar, _фише,
  { {0xa2d60053,0x412a17f2,0x232724cc,0x00000000}},	//   _मुश्, ково_, роси_,
  { {0x75d30044,0x25fe0082,0x00000000,0x00000000}},	//   _ويوا, _रूची_,   ,

  { {0xff260001,0xd00706be,0x02db0053,0x00000000}},	// [6000] имао, иете_, _मुठभ,
  { {0x2d80003d,0xef171578,0x44323792,0x00000000}},	//   ķiem_, иму_, _ivy_,
  { {0xe8e20053,0xcd06000d,0x733b0149,0x00000000}},	//   _पर्च, апей, _בעיס,
  { {0xdc2a007e,0xe1ff008b,0xcf890047,0x00000000}},	//   نسته_, _gió_, וט_,
  { {0x2ca0018d,0xbc230054,0x629c0168,0x00000000}},	//   áid_, оєщи, lyro,
  { {0x649b0063,0xba760021,0x39980014,0x00000000}},	//   כסנד, لاعت, _lést_,
  { {0xead8000d,0x29020078,0xeb97007b,0x00000000}},	//   ымкі_, žkam_, риј_,
  { {0x7c66006a,0x63bc2096,0x0c3a0021,0x00000000}},	//   _پارل, hirn, _لكرة_,
  { {0xa3d60161,0x63bc0150,0xdb033793,0x00000000}},	//   िका_, kirn, chnï,
  { {0x4734042c,0xdb18004b,0x8c1b0063,0x00000000}},	//   щнос, tovõ, _סובי,
  { {0xeb970001,0xc9860086,0x3f790047,0x00000000}},	//   _њих_, _вули, אָרע,
  { {0x998000eb,0x63bc002b,0xb866007e,0x00000000}},	//   čių_, eirn, _ناتو,
  { {0xe4e70086,0x7bd8004b,0x14cb0121,0x00000000}},	//   рінн, oovu, тыни_,
  { {0x99890024,0xa3a40259,0xdb0301a8,0x00000000}},	//   čať_, ојск, linò,
  { {0x79820037,0xe5c70076,0xdb183794,0x00000000}},	//   _know, _вспо, rivè,
  { {0x200f017d,0x7bd80240,0x66150066,0x00000000}},	//   ígio_, hovu, ízke,
  { {0xb6070024,0x629c002c,0x63bc3795,0x00000000}},	// [6010] _teší, ayro, birn,
  { {0x7a0a0051,0xdb180137,0x00000000,0x00000000}},	//   _pętl, nnvä,   ,
  { {0xdb183796,0xddce00a2,0x60c90078,0x00000000}},	//   invä, _srbš, _žemd,
  { {0x7db4000d,0x75ff005f,0xd657009d,0x00000000}},	//   осіц, _mūzo, שיאת_,
  { {0x7dd80066,0x65a60014,0xd1fa0047,0x00000000}},	//   rísp, _jóha, _תּיכ,
  { {0x1b490076,0x3e17007e,0xda65013a,0x00000000}},	//   узки_, _نظرس, ماعي,
  { {0x53380063,0xaa560044,0xda64009b,0x00000000}},	//   בנון_, ملوا_, قايي,
  { {0x63bc08ed,0xdb183797,0x00000000,0x00000000}},	//   zirn, envä,   ,
  { {0xe8f90076,0x629c0051,0x00000000,0x00000000}},	//   ыли_, zyro,   ,
  { {0xf7450138,0x39980026,0xdb1800a5,0x00000000}},	//   љено, _sést_, gnvä,
  { {0x63bc00c3,0xdce0007d,0x69c40066,0x00000000}},	//   virn, _pamć, čier,
  { {0xdeb60063,0x629c3798,0x59640094,0x00000000}},	//   מפתח_, vyro, _мъча,
  { {0x291f0009,0x39980080,0x6d5b0139,0x00000000}},	//   mbua_, _vést_, _mbua,
  { {0xdb180164,0xa01b0026,0x79820051,0x00000000}},	//   tivé, _kröf, _znow,
  { {0xd299019d,0x63bc1ff0,0x1db70042,0x00000000}},	//   атті_, rirn, _आगंत,
  { {0xdb180164,0xd54a0002,0x98a4008f,0x00000000}},	//   rivé, _спие_, lamā_,
  { {0x7bd80035,0x629c0137,0x63bc24bd,0x00000000}},	// [6020] yovu, syro, pirn,
  { {0x44770063,0x644607b7,0x656600ea,0x00000000}},	//   _פעיל_, muki, lekh,
  { {0xdb030139,0x64463799,0xee3a0bc7,0x00000000}},	//   ghní, luki, уне_,
  { {0x60c90006,0x61310014,0xa3c00042,0x00000000}},	//   _žeme, rðlí, ंचक_,
  { {0x98a4001c,0x6446379a,0x212000c2,0x00000000}},	//   kamā_, nuki, mbih_,
  { {0x98a4001c,0x2a6c017d,0x61e4379b,0x00000000}},	//   jamā_, _psdb_, llil,
  { {0x6e960593,0xdb0301c8,0x61e4379c,0x00000000}},	//   _الزا, chní, olil,
  { {0x67ef00b9,0xd90e007e,0x61e421bd,0x00000000}},	//   højd, ریت_, nlil,
  { {0xa01b00bd,0x644600c2,0x61e4379d,0x00000000}},	//   _eröf, juki, ilil,
  { {0x64461b35,0xe7b8005e,0x7ae10e41,0x00000000}},	//   duki, ргош_, _fylt,
  { {0xdb1800c7,0x61e409f7,0xa01b0014,0x00000000}},	//   rnvä, klil, _gröf,
  { {0x758b1528,0x6f01125f,0x6566013d,0x00000000}},	//   усов_, _úlce, gekh,
  { {0x889401f6,0xe894379e,0x61e4097a,0x00000000}},	//   _филх, _фаль, dlil,
  { {0x2120003e,0x98a4001c,0x58f7009a,0x00000000}},	//   ebih_, camā_, _המדע_,
  { {0xb2840055,0x64460006,0xf1a70cd6,0x00000000}},	//   пытк, auki, бран,
  { {0x61e4002c,0x6446002c,0x672a0026,0x00000000}},	//   glil, buki, _hefj,
  { {0x752f0051,0xf1940b3f,0x7538009a,0x00000000}},	// [6030] macz, чить, _האחד_,
  { {0xb17b00c7,0xdb030025,0x61e4379f,0x00000000}},	//   _skåd, thní, alil,
  { {0x9f58197c,0x61e437a0,0xa15909c8,0x00000000}},	//   _dirà_, blil, _кану_,
  { {0x752f0045,0xcd2b014d,0x98a4008f,0x00000000}},	//   nacz, اسان_, zamā_,
  { {0x6738007d,0x7bf90446,0x853c009a,0x00000000}},	//   _odvj, андр_, רגדי,
  { {0x7ae100e8,0x290637a1,0xaa150092,0x00000000}},	//   _pylt, _agoa_, офиј,
  { {0x19890076,0x1ee7007e,0x644637a2,0x00000000}},	//   ибки_, _طوری_, zuki,
  { {0x48590088,0xad27007e,0xc8590054,0x00000000}},	//   ароў_, _درآو, ашої_,
  { {0x660a00bd,0xa01b0026,0x67ef00b9,0x00000000}},	//   _aufk, _drög, høje,
  { {0x61e401f7,0x6d4a005b,0x25a90019,0x00000000}},	//   zlil, ılaş, _alal_,
  { {0x20030035,0x8aa737a3,0x8b080063,0x00000000}},	//   _miji_, _урад, _הִנֵ,
  { {0x64460009,0x20190019,0x7c24000c,0x00000000}},	//   tuki, _otsi_, ţire,
  { {0x61e4005b,0x6d4b00ac,0xdb0a0354,0x00000000}},	//   vlil, igga, rnfö,
  { {0xb6a50076,0x67ef0146,0x69c90104,0x00000000}},	//   _милл, føje, lnee,
  { {0x752f0051,0xa49b00cd,0x69c937a4,0x00000000}},	//   bacz, scòp, onee,
  { {0x69c937a5,0x69db066d,0x644637a6,0x00000000}},	//   nnee, noue, puki,
  { {0xb8860026,0x2003014f,0x200b017e,0x00000000}},	// [6040] mtíð, _biji_, _cuci_,
  { {0x98a4003b,0x69db2142,0x61e42061,0x00000000}},	//   lamă_, houe, slil,
  { {0x2019024a,0x8236005d,0xbe66005d,0x00000000}},	//   _etsi_, _برخا, تهاي,
  { {0xa01b00c7,0x365a0047,0x9f580e7c,0x00000000}},	//   _bröd, יכענ, _dirá_,
  { {0x0b8a37a7,0x9f5800cd,0x200337a8,0x00000000}},	//   иски_, _tirà_, _fiji_,
  { {0xdce00080,0x66040aba,0x6d4b37a9,0x00000000}},	//   _zamě, _liik, agga,
  { {0xada60076,0xee370002,0x387d002b,0x00000000}},	//   _давл, _мнр_, _arwr_,
  { {0xa9c30086,0xd90d007e,0x6604004b,0x00000000}},	//   дськ, هیم_, _niik,
  { {0x99580080,0xdb080d02,0x20040003,0x00000000}},	//   _též_, _omdø, _émis_,
  { {0x752f0022,0x69c9004e,0x7c65043e,0x00000000}},	//   wacz, anee, _عاقل,
  { {0xf09f008b,0x3f980c15,0x69db37aa,0x00000000}},	//   _ngàn_, _moru_, boue,
  { {0x672100c2,0x62810838,0x69db0003,0x00000000}},	//   ablj, ålom, coue,
  { {0xf76f006a,0x6604053b,0xdb030139,0x00000000}},	//   رای_, _diik, mhná,
  { {0x67ef010a,0xfbbc0053,0x69c037ab,0x00000000}},	//   tøje, ्चिम, lime,
  { {0x200b014f,0xdce00080,0x6d4b0137,0x00000000}},	//   _suci_, _pamě, ygga,
  { {0xdb1837ac,0x6440006d,0xd7f8003b,0x00000000}},	//   diví, ámic, lmă_,
  { {0x3cf60053,0x69c000fe,0x34b40121,0x00000000}},	// [6050] ेशों_, iime, _объё,
  { {0xa2d60053,0x75d2001c,0x69c026cc,0x00000000}},	//   _मुक्, rāze, hime,
  { {0x69c900fe,0x752d0089,0xd7f8003b,0x00000000}},	//   ynee, _keaz, imă_,
  { {0x442910ca,0x3f8e0026,0x9f58017d,0x00000000}},	//   _kwa_, öfur_, _virá_,
  { {0x0c241c15,0x7c840001,0x69db0003,0x00000000}},	//   дмін, дује, voue,
  { {0x44290035,0x70fa0063,0xb09a0063,0x00000000}},	//   _mwa_, _להרח, _הישר,
  { {0x69db0fe4,0x44290022,0x8cbb0042,0x00000000}},	//   toue, _lwa_, _शेरो,
  { {0x69c02308,0x9dab0062,0x20040003,0x00000000}},	//   gime, _тъга_, _émir_,
  { {0x66040004,0x69c937ad,0x2c5e001c,0x00000000}},	//   _riik, rnee, gādā_,
  { {0x7c29001f,0x69c9006f,0xd7f8003b,0x00000000}},	//   _iwer, snee, gmă_,
  { {0x7a300025,0x69c0099a,0x672100b2,0x00000000}},	//   _vótá, bime, rblj,
  { {0x69c037ae,0xd7f8003b,0xd46a0002,0x00000000}},	//   cime, amă_, биме_,
  { {0x660400fe,0xd4da000d,0xb8860014,0x00000000}},	//   _viik, сьні_, rtíð,
  { {0x44290051,0x394d37af,0xa3b60053,0x00000000}},	//   _dwa_, lges_, चों_,
  { {0xa2d60235,0x66e20da6,0xa6b4005a,0x00000000}},	//   _मुख्, _поша, _осъщ,
  { {0x386d1c9f,0x60c90006,0x394d0238,0x00000000}},	//   ower_, _žema, nges_,
  { {0x8afc0022,0xdb03004e,0x5155012c,0x00000000}},	// [6060] _zbęd, minõ, ьтру,
  { {0xe45700b5,0xe3b2007e,0x3fe337b0,0x00000000}},	//   _צייט_, _سرخ_, ежув,
  { {0x3f98007a,0x386d00bd,0xdfcf0067,0x00000000}},	//   _voru_, hwer_, ديل_,
  { {0x21020006,0x7bca001f,0x69c037b1,0x00000000}},	//   _ačiū_, wnfu, xime,
  { {0x394d37b2,0x69c037b3,0xdd990066,0x00000000}},	//   dges_, vime, _doň_,
  { {0x98a40006,0x7c290983,0x394d37b4,0x00000000}},	//   namą_, _dwer, eges_,
  { {0xe9f80088,0x7c290d13,0x69c037b5,0x00000000}},	//   онкі_, _ewer, time,
  { {0x394d02ab,0x3eae0058,0xf41f0050,0x00000000}},	//   gges_, ıktı_, ypä_,
  { {0x7c290185,0x752d1fa6,0x98a40006,0x00000000}},	//   _gwer, _reaz, kamą_,
  { {0x98a40006,0xec370063,0x2c5e001c,0x00000000}},	//   jamą_, _מאמר_, rādā_,
  { {0x45d50079,0x6b880146,0xd7f80529,0x00000000}},	//   донс, _indg, rmă_,
  { {0x65ab005e,0xd7f8003b,0x24800168,0x00000000}},	//   стог_, smă_, _brim_,
  { {0x764800d1,0x2480132b,0xd7fa289a,0x00000000}},	//   sudy, _crim_, _лук_,
  { {0x083b014e,0x75ff001c,0xb4bd0042,0x00000000}},	//   _פעול, _mūzi, _आधी_,
  { {0xdb0a33ef,0xa75b0063,0xdb0301a9,0x00000000}},	//   lifó, _הדור, binõ,
  { {0x6b9a00ca,0xf41f0072,0x442937b6,0x00000000}},	//   _lotg, ppä_, _twa_,
  { {0x248037b7,0xe53c0063,0x90550085,0x00000000}},	// [6070] _grim_, _התחר, ьвац,
  { {0xdefb0076,0x06fd004c,0x6b9a0244,0x00000000}},	//   бые_, čívá_, _notg,
  { {0x3ea700ea,0x7c291b4a,0x7d0900ca,0x00000000}},	//   ánt_, _swer, _pges,
  { {0x386d00ac,0x9327007e,0x7c2937b8,0x00000000}},	//   ywer_, _برکن, _pwer,
  { {0xe5380047,0x3b090002,0x7c2937b9,0x00000000}},	//   לטאט_, оело_, _qwer,
  { {0x2bdd0042,0x8234005d,0x4478009a,0x00000000}},	//   यवधा, _تریا, פעול_,
  { {0x394d0994,0x00000000,0x00000000,0x00000000}},	//   tges_,   ,   ,
  { {0xcda9007e,0x6b88103b,0x7d0937ba,0x00000000}},	//   _بهره_, _endg, _uges,
  { {0x386d37bb,0x7c970021,0x394d0294,0x00000000}},	//   uwer_, _عشرا, rges_,
  { {0x87b80076,0x386d0051,0xdb0100ea,0x00000000}},	//   зуют_, rwer_, _ellá,
  { {0x7bc337bc,0xc98709c3,0x386d37bd,0x00000000}},	//   minu, _нуди, swer_,
  { {0xf1bf0139,0x248037be,0x7bc337bf,0x00000000}},	//   _nmá_, _prim_, linu,
  { {0xe73909e1,0xdb03004b,0xc7950044,0x00000000}},	//   _дел_, rinõ, _يشتب,
  { {0xdb0a00cd,0x98140021,0xe731007e,0x00000000}},	//   lifò, _أبنا, _شصت_,
  { {0x91e62bc7,0x98a40078,0xd19a005e,0x00000000}},	//   дове, ramą_, отач_,
  { {0x248037c0,0x7bc337c1,0x98a4005f,0x00000000}},	//   _trim_, hinu, samą_,
  { {0x7bc337c2,0x91e32d76,0xe3ba0002,0x00000000}},	// [6080] kinu, тоте, _мби_,
  { {0x249f00bd,0x7bc30420,0x0fda000d,0x00000000}},	//   äume_, jinu, цьбы_,
  { {0x7bc337c3,0x6b9a087d,0x7e5637c4,0x00000000}},	//   dinu, _rotg, ьтац,
  { {0x26130016,0x644600e5,0x98ad0042,0x00000000}},	//   _mão_, orki, टनाए,
  { {0x3ea6001c,0xb4db00cd,0x26130013,0x00000000}},	//   ņot_, lgàr, _lão_,
  { {0xbf9b0003,0xdca3005e,0x6ac90053,0x00000000}},	//   _quêt, ђаји, िपूर,
  { {0x261313a8,0xdb23013d,0x7f170044,0x00000000}},	//   _não_, úráj, _آيفز_,
  { {0xdb0a0139,0xc8080013,0x28a60054,0x00000000}},	//   mhfí, _hởi_, дшог,
  { {0x7bc337c5,0xb4bd0042,0x6b9a0244,0x00000000}},	//   binu, _आधे_, _totg,
  { {0x6b880146,0x2613008b,0x8b96000d,0x00000000}},	//   _undg, _bão_, _ўрач,
  { {0x2613017d,0xae0e0053,0x644637c6,0x00000000}},	//   _cão_, िदिन_, erki,
  { {0x2613017d,0xfaa301ef,0x7c2216f1,0x00000000}},	//   _dão_, _шахо, opor,
  { {0x79fb0063,0xe4e40086,0x64400a10,0x00000000}},	//   _ולאח, вірн, šmin,
  { {0x7c2237c7,0x29020006,0xf1bf0014,0x00000000}},	//   ipor, žkas_, _smá_,
  { {0x644600fe,0xa278005e,0xdd140066,0x00000000}},	//   arki, мбру_, dĺži,
  { {0x26070161,0x2509007e,0x06fd0080,0x00000000}},	//   _सूची_, _عربی_, čítá_,
  { {0x399b0063,0x765a0072,0xdb18011b,0x00000000}},	// [6090] קימד, ltty, zivá,
  { {0xc808001b,0x645a000c,0x7bc3190d,0x00000000}},	//   _bởi_, ătit, xinu,
  { {0x4439001c,0x2f380021,0x7bc337c8,0x00000000}},	//   lss_, بثقة_, vinu,
  { {0x765a00fe,0x3866017d,0x44392535,0x00000000}},	//   itty, _opor_, oss_,
  { {0xe2a60026,0x386637c9,0x7bc337ca,0x00000000}},	//   öðva_, _npor_, tinu,
  { {0xdb1837cb,0x765a0196,0x443937cc,0x00000000}},	//   tivá, ktty, iss_,
  { {0xbed50001,0xc808008b,0x0b160021,0x00000000}},	//   _човј, _gởi_, رقية_,
  { {0x4439001c,0x2bdd0053,0x98a40022,0x00000000}},	//   kss_, यवहा, lamę_,
  { {0x261303d9,0x31790045,0xcc17007e,0x00000000}},	//   _são_, _masz_, _آذرب,
  { {0x765a0d02,0x2613017d,0x6a670021,0x00000000}},	//   ftty, _pão_, _يطال,
  { {0x75f60080,0x4439272f,0xc4c90063,0x00000000}},	//   háze, ess_, _פג_,
  { {0x26130016,0x31790051,0x99840021,0x00000000}},	//   _vão_, _nasz_, _للمو,
  { {0xa8a7006a,0x644637cd,0x09b80044,0x00000000}},	//   _تصاو, urki, _تطلع_,
  { {0x26130016,0x6446004d,0x889a0063,0x00000000}},	//   _tão_, rrki, _מבני,
  { {0x3666011c,0x4439103b,0x387f37ce,0x00000000}},	//   _защо_, ass_, lvur_,
  { {0xb4db00cd,0xdb010137,0x395f0003,0x00000000}},	//   rgàr, _illä, nfus_,
  { {0xa0672a4b,0x7bc1004c,0x25d70047,0x00000000}},	// [60a0] ната_, _omlu, _רופן_,
  { {0x7d1b00cd,0x442037cf,0x7c220137,0x00000000}},	//   _afus, _iti_, vpor,
  { {0x2f1500ea,0x44200150,0x6ac90053,0x00000000}},	//   _súgó_, _hti_, िपोर,
  { {0x7c2237d0,0x44200078,0xc808008d,0x00000000}},	//   tpor, _kti_, _vởi_,
  { {0x7c2237d1,0x7ae800a5,0x7e75013d,0x00000000}},	//   upor, _sydt, _eszp,
  { {0x44200035,0x765a00fe,0x77a400cd,0x00000000}},	//   _mti_, ytty, _tòxi,
  { {0xed6301c2,0x7c2218d2,0x386637d2,0x00000000}},	//   íží_, spor, _spor_,
  { {0xfce60086,0xdbd20019,0x443937d3,0x00000000}},	//   _зобо, lüüs, yss_,
  { {0x399800ea,0x7ae800ac,0xc7c60f55,0x00000000}},	//   _kész_, _wydt, есни,
  { {0x31600089,0x7ae800ac,0xdbd2004b,0x00000000}},	//   hfiz_, _tydt, nüüs,
  { {0xffb700b5,0xa9260002,0x9f4b0003,0x00000000}},	//   גליש_, _здел, ûlée_,
  { {0x7bc10024,0x765a0246,0xd6d702dc,0x00000000}},	//   _zmlu, rtty, эты_,
  { {0x938b005a,0x386600c2,0x7bc1002b,0x00000000}},	//   псва_, _upor_, _ymlu,
  { {0x44200025,0x443937d4,0x75f6004c,0x00000000}},	//   _dti_, rss_, váze,
  { {0x6d4037d5,0xf41f00c7,0xdce0001c,0x00000000}},	//   _odma, kväg_, _kamē,
  { {0xdb180659,0xd5b9008f,0x75f6011b,0x00000000}},	//   livä, opām_, táze,
  { {0x656f37d6,0x9f6b0330,0xdbd2004b,0x00000000}},	// [60b0] mech, зрез_, füüs,
  { {0x75f60080,0xdb0100fe,0x200a0290,0x00000000}},	//   ráze, _yllä, _cibi_,
  { {0xa01b0464,0x644f37d7,0x6e670121,0x00000000}},	//   _grön, luci, этаж,
  { {0x7bc10080,0x656f027d,0x657d37d8,0x00000000}},	//   _smlu, nech, ndsh,
  { {0x645d0004,0x212937d9,0x657d10da,0x00000000}},	//   ntsi, mbah_, idsh,
  { {0x200a01f7,0xcb66026b,0x9b680001,0x00000000}},	//   _gibi_, ваше_, ешћа_,
  { {0x9e3502a1,0x645d004b,0x4fd60063,0x00000000}},	//   _шевч, htsi, _יושב_,
  { {0x645d0004,0x61ed00a4,0xa922005a,0x00000000}},	//   ktsi, nlal, адъл,
  { {0x61ed002c,0x7648001f,0xf8ae007e,0x00000000}},	//   ilal, erdy, يکه_,
  { {0x644f0d0f,0x4420004b,0x16a90002,0x00000000}},	//   duci, _rti_, двои_,
  { {0x44200146,0x2d9f00ac,0x46f5005a,0x00000000}},	//   _sti_, _koue_, ъчит,
  { {0x2d9f0164,0x798b0035,0xe0110053,0x00000000}},	//   _joue_, _ungw, ़दाद_,
  { {0x212900c3,0x6285001f,0xe4e5000d,0x00000000}},	//   dbah_, _arho, гіён,
  { {0x61ed014f,0xf8b60063,0x657d37da,0x00000000}},	//   elal, _בפני_, adsh,
  { {0x399800ea,0x644f001c,0xf1aa01fb,0x00000000}},	//   _rész_, auci, واره_,
  { {0x61ed37db,0x44200d52,0x644f37dc,0x00000000}},	//   glal, _tti_, buci,
  { {0x644f0876,0x628500bd,0x442037dd,0x00000000}},	// [60c0] cuci, _erho, _uti_,
  { {0x61ed37de,0x21290089,0x00000000,0x00000000}},	//   alal, abah_,   ,
  { {0x290f00c7,0xdb1802f0,0x2d9f0003,0x00000000}},	//   _ogga_, nivå, _boue_,
  { {0x90c60088,0x290f0150,0x2d9f01a8,0x00000000}},	//   _абме, _ngga_, _coue_,
  { {0xf41f00c7,0xdb1800fe,0xdb0a0137,0x00000000}},	//   rväg_, yivä, nifö,
  { {0x656f0045,0xf41f0137,0x61e40072,0x00000000}},	//   zech, sväg_, loil,
  { {0xdce0001c,0x644f0051,0xdb180cb0,0x00000000}},	//   _pamē, zuci, vivä,
  { {0x61e400fe,0xf2d30063,0x2d9f00ac,0x00000000}},	//   noil, יעו_, _goue_,
  { {0xa9670001,0x656f37df,0xdb180659,0x00000000}},	//   тиња_, vech, tivä,
  { {0x656f330b,0x644f007d,0x61e437e0,0x00000000}},	//   wech, vuci, hoil,
  { {0x61e400fe,0xe535268e,0xd6da0054,0x00000000}},	//   koil, лень, ьти_,
  { {0x645d0c4a,0x61e400fe,0x79a3018e,0x00000000}},	//   ttsi, joil, _врше,
  { {0x656f37e1,0x61e400fe,0x645d37e2,0x00000000}},	//   rech, doil, utsi,
  { {0x656f37e3,0x645d37e4,0x644f37e5,0x00000000}},	//   sech, rtsi, ruci,
  { {0x764f0045,0x645d37e6,0x2129014f,0x00000000}},	//   ącyc, stsi, tbah_,
  { {0x645d0019,0x6285027c,0xdb0100a5,0x00000000}},	//   ptsi, _vrho, _ullå,
  { {0x61ed014f,0x2d9f0003,0x7e99007e,0x00000000}},	// [60d0] rlal, _roue_, کنار_,
  { {0x61ed37e7,0x212937e8,0xdb030066,0x00000000}},	//   slal, sbah_, rhnú,
  { {0xe45f00fe,0x660d0441,0x75f611ba,0x00000000}},	//   ltö_, _kiak, láza,
  { {0x61e419d9,0x9c5937e9,0x1c3905ac,0x00000000}},	//   coil, ешку_, езды_,
  { {0x660d0009,0xe45f00fe,0xfeb8007e,0x00000000}},	//   _miak, ntö_, _یافت_,
  { {0x8bc70062,0x660d0050,0xdb01013d,0x00000000}},	//   ъсед, _liak, _illú,
  { {0x68eb00b9,0xaa560001,0xe45f0072,0x00000000}},	//   _sygd, гију_, htö_,
  { {0x99f5000d,0x75f60a63,0x16190053,0x00000000}},	//   ыялі, káza, _नंबर_,
  { {0x2d0f0042,0xf1b40aeb,0xa2ca0082,0x00000000}},	//   िशील_, יסק_, _हेन्,
  { {0x25a00034,0x660d004b,0xe8f60085,0x00000000}},	//   _soil_, _aiak, ылы_,
  { {0xadc3008b,0x25a00003,0xd7a40042,0x00000000}},	//   _giản, _poil_, _ओवरच,
  { {0xdb1800a5,0x857a02fa,0x00000000,0x00000000}},	//   rivå, хсот_,   ,
  { {0xb6070026,0x660d37ea,0xa78501fb,0x00000000}},	//   _sjáð, _diak, _مشغو,
  { {0xb8820114,0xdb0a00a5,0x69c937eb,0x00000000}},	//   čítk, rifö, liee,
  { {0x61e40f3b,0xa01b0137,0x25a000e5,0x00000000}},	//   toil, _dröm, _toil_,
  { {0x69c90173,0x75f60066,0x0496000d,0x00000000}},	//   niee, báza, _броў,
  { {0xe0da005a,0x75f6006d,0xc5fb0063,0x00000000}},	// [60e0] хва_, cáza, _אפקט,
  { {0x660d0035,0x69c91013,0xd47b0041,0x00000000}},	//   _ziak, hiee, _טאפל,
  { {0x4432001f,0x33770047,0x4d4a08b0,0x00000000}},	//   _hwy_, _געים_, епен_,
  { {0xcd36006a,0x7a11008f,0xad260044,0x00000000}},	//   اراب, _jātu, ارضو,
  { {0xac94007b,0x69c937ec,0x4c941e1b,0x00000000}},	//   ралш, diee, рилс,
  { {0x44320185,0xcc87005e,0xdee611db,0x00000000}},	//   _mwy_, убље_, _боги,
  { {0x69c90173,0x75f600ea,0x3f670086,0x00000000}},	//   fiee, záza, _щиро_,
  { {0x60c900eb,0x69c90019,0xdb080137,0x00000000}},	//   _žemi, giee, _omdö,
  { {0x4432001f,0x57b425ef,0x4c78009a,0x00000000}},	//   _nwy_, ибит, _שָֽׁ,
  { {0x473437ed,0x75f637ee,0x660d37ef,0x00000000}},	//   шнос, váza, _siak,
  { {0x17f70021,0x660d0072,0xc6a60a29,0x00000000}},	//   درية_, _piak, урпи,
  { {0x69c90122,0xe9da0086,0xe45f00fe,0x00000000}},	//   ciee, _яке_, ttö_,
  { {0xe973007e,0x7bca0035,0x443f37f0,0x00000000}},	//   _دهند, oifu, éu_,
  { {0x4432001f,0xa01b0137,0x75f6013d,0x00000000}},	//   _dwy_, _fröj, ráza,
  { {0x171b00b5,0xe45f00fe,0x62351577,0x00000000}},	//   _אווע, stö_, ребу,
  { {0x44320185,0x6440017d,0x7bca004b,0x00000000}},	//   _fwy_, âmic, hifu,
  { {0x7bca0035,0x2f190121,0x6aaa002b,0x00000000}},	// [60f0] kifu, возь_, hyff,
  { {0x7bca0035,0xd1010053,0x673a01a8,0x00000000}},	//   jifu, लेषण_, natj,
  { {0x7bca37f1,0x0dcb018e,0x2489007d,0x00000000}},	//   difu, нуди_, _hram_,
  { {0x673a00ea,0xd657009a,0x3d0f0042,0x00000000}},	//   hatj, ריאת_, िशें_,
  { {0x113a0063,0xa91d37f2,0x69c9004b,0x00000000}},	//   _שתשל, ndže, viee,
  { {0xfaa50363,0xa91d0130,0x7a03013d,0x00000000}},	//   иало, idže, _lőtt,
  { {0x69c9056f,0x9f840244,0x673a013d,0x00000000}},	//   tiee, _höß_, datj,
  { {0x7bca0089,0x3eae05b9,0x629a0072,0x00000000}},	//   aifu, øfte_, ätoi,
  { {0x69c937f3,0xa91d007d,0xc7950895,0x00000000}},	//   riee, jdže, арны,
  { {0x4432001f,0x69c93339,0x673a00ea,0x00000000}},	//   _rwy_, siee, gatj,
  { {0x7bfa00b5,0x69c937f4,0x96b937f5,0x00000000}},	//   _ספעצ, piee, тупу_,
  { {0x4432001f,0x6933007e,0x673a37f6,0x00000000}},	//   _pwy_, _اکثر, aatj,
  { {0x27e500c2,0x69d900ca,0x29160066,0x00000000}},	//   poln_, _ijwe, ácať_,
  { {0xf7710032,0xd348007e,0xa01b0137,0x00000000}},	//   _ذات_, دیده_, _tröj,
  { {0x248913f8,0xa01b0137,0xdb0a0244,0x00000000}},	//   _eram_, _frök, chfä,
  { {0x248937f7,0xdb010f01,0x7c24003b,0x00000000}},	//   _fram_, _polê, ţiri,
  { {0x248937f8,0x75f6013d,0x0fc6030b,0x00000000}},	// [6100] _gram_, lázo, айан,
  { {0x6d5b027b,0xee0e0053,0x7f460054,0x00000000}},	//   _acua, िद्ध_, режж,
  { {0x527624fe,0xdff50505,0x539b009a,0x00000000}},	//   _тупу, сять, _סיטו,
  { {0x75f60195,0x4c860a71,0xac8601d5,0x00000000}},	//   zázn, илев, игел,
  { {0x27220080,0x6e2900c2,0xed57000d,0x00000000}},	//   nční_, _čebe, роч_,
  { {0x6d5b37f9,0x212000c2,0x9987005f,0x00000000}},	//   _ecua, lcih_, ksnų_,
  { {0x7bca37fa,0xda7a0062,0x6e43085e,0x00000000}},	//   rifu, тял_, _мерз,
  { {0xdb010268,0x6d5b0027,0x3869000c,0x00000000}},	//   _molè, _gcua, _ţara_,
  { {0xb9970076,0x673a00ea,0x1d070002,0x00000000}},	//   рвых_, tatj, _вети_,
  { {0x07b80021,0xaa460456,0x87060094,0x00000000}},	//   اهدة_, _вежл, ияне,
  { {0xdce00006,0x673a37fb,0xceb30041,0x00000000}},	//   _pamė, ratj, ַיש_,
  { {0x58860088,0xa01b004d,0xdceb008f,0x00000000}},	//   _выка, _fröh, legā,
  { {0x54540121,0xa91d1bbd,0x95d80330,0x00000000}},	//   овят, udže, рдят_,
  { {0x9f580871,0x75fd013d,0x75f6017c,0x00000000}},	//   _miró_, déze, bázo,
  { {0x31c70088,0xdb010164,0xdceb001c,0x00000000}},	//   асав, _colè, iegā,
  { {0xa5350076,0x248937fc,0xdb21013d,0x00000000}},	//   _унич, _tram_, _ütöt,
  { {0x2489013d,0x4059014d,0x753d12a6,0x00000000}},	// [6110] _uram_, طلاح_, masz,
  { {0x753d000f,0x2fc7001b,0xdf390021,0x00000000}},	//   lasz, òng_, اكات_,
  { {0x3ea7000c,0x3f810360,0x394637fd,0x00000000}},	//   ânt_, rdhu_, _odos_,
  { {0x753d0163,0x60c90078,0x51950021,0x00000000}},	//   nasz, _žemu, _الحذ,
  { {0x629a0024,0xbc480002,0xdb1a00a5,0x00000000}},	//   ätov, ачје_, _omtä,
  { {0x753d000f,0x67381236,0xe0df01a8,0x00000000}},	//   hasz, _nevj, _ixò_,
  { {0xe1ff001b,0x753d14e0,0xf9910021,0x00000000}},	//   _khó_, kasz, كبة_,
  { {0x20110009,0x63a5004d,0x52d80047,0x00000000}},	//   _hizi_, _lohn, יווע_,
  { {0xe1ff0025,0x20190035,0xdb0137fe,0x00000000}},	//   _mhó_, _jusi_, _molé,
  { {0x27950055,0x20190045,0x291f1cbe,0x00000000}},	//   сшир, _musi_, scua_,
  { {0x6b9c00cd,0x6be40021,0x201137ff,0x00000000}},	//   _òrga, _بكلم, _mizi_,
  { {0x39420026,0x6b810139,0xd9450002,0x00000000}},	//   ókst_, _halg, _ѓели,
  { {0xe611007e,0x212000c2,0x64490078,0x00000000}},	//   _کشت_, vcih_, šein,
  { {0x27220080,0xdb0100cd,0x6b810019,0x00000000}},	//   rční_, _polè, _jalg,
  { {0x6b813800,0x644f3801,0x753d3802,0x00000000}},	//   _malg, arci, basz,
  { {0x201907b7,0xdb0136f4,0xe1ff008b,0x00000000}},	//   _busi_, _colé, _chó_,
  { {0x2120005b,0x25b7007e,0x2011005b,0x00000000}},	// [6120] rcih_, _دهيد_, _bizi_,
  { {0x2a690051,0xdb010003,0x6b8100be,0x00000000}},	//   łaby_, _tolè, _nalg,
  { {0x2011005b,0x764100ac,0x0e660699,0x00000000}},	//   _dizi_, nsly, скен,
  { {0xc27b014e,0x20190290,0x764106a5,0x00000000}},	//   _ערכי, _fusi_, isly,
  { {0x9f580290,0x20110089,0x20190089,0x00000000}},	//   _dirò_, _fizi_, _gusi_,
  { {0x6b813803,0x6fb6007e,0x2d800195,0x00000000}},	//   _calg, _امسا, žie_,
  { {0x6b813804,0x9f96004b,0xdceb008f,0x00000000}},	//   _dalg, _müüs_, regā,
  { {0x764100e8,0x9f581ff0,0x6444004b,0x00000000}},	//   dsly, _girò_, _ovii,
  { {0x764100e8,0xa3c90053,0x6b8101a8,0x00000000}},	//   esly, लोड_, _falg,
  { {0x6b813805,0x907b0063,0x7bc80058,0x00000000}},	//   _galg, נטיי, _umdu,
  { {0x7bdf03b2,0x764100d1,0x95d90699,0x00000000}},	//   éque, gsly, идот_,
  { {0xd6d71b79,0x63a5004d,0xceb3009f,0x00000000}},	//   сть_, _sohn, פיר_,
  { {0x8b030080,0xe4e7013c,0xdb030139,0x00000000}},	//   ěřen, сінн, bhnó,
  { {0x9f580025,0x38cb007e,0xdceb00dd,0x00000000}},	//   _bhrí_, _حامی_, legă,
  { {0x753d00ea,0xe1ff008b,0xdb013806,0x00000000}},	//   pasz, _phó_, _polé,
  { {0x63a500bd,0x201101f7,0x2019008f,0x00000000}},	//   _wohn, _sizi_, _pusi_,
  { {0x656d002c,0x64403807,0xdb010003,0x00000000}},	// [6130] _ibah, ámit, _volé,
  { {0x442925e5,0x10040062,0xf53f0137,0x00000000}},	//   _ita_, пяхм, akåt_,
  { {0xdb010003,0xa3b8005d,0x20113808,0x00000000}},	//   _tolé, _داير_, _vizi_,
  { {0x6b813809,0x6d59001f,0xb17b04aa,0x00000000}},	//   _salg, ugwa, _sjåf,
  { {0x6b810004,0x20190d68,0x7ae4005b,0x00000000}},	//   _palg, _uusi_, şitl,
  { {0xf41f00fe,0x764100ac,0xd6d70121,0x00000000}},	//   yvän_, ysly, ́ть_,
  { {0xb16e0026,0x6b8129b8,0xfaa20062,0x00000000}},	//   _þýði, _valg, дащо,
  { {0x7bd8006f,0x4429380a,0x7c2b299b,0x00000000}},	//   anvu, _ota_, ppgr,
  { {0xa01b0137,0x764f0051,0x6d49380b,0x00000000}},	//   _eröv, ącym, _idea,
  { {0x2cb200d1,0xa01b0137,0xdb1f0072,0x00000000}},	//   øyde_, _fröv, ävät,
  { {0x69e70088,0x36690635,0x3f833747,0x00000000}},	//   _людз, шано_, _maju_,
  { {0x7c290080,0xa50a000a,0x3f83014f,0x00000000}},	//   _kter, иена_, _laju_,
  { {0x764100c7,0xf7450f55,0x34fa0083,0x00000000}},	//   ssly, _дело, рхню_,
  { {0xf41f0137,0x04430002,0x79820022,0x00000000}},	//   mväl_, ќерн, _zaow,
  { {0x7c29380c,0x613a0095,0x4429380d,0x00000000}},	//   _lter, ичар_, _eta_,
  { {0x6d490025,0x44290222,0x7c29380e,0x00000000}},	//   _ndea, _fta_, _oter,
  { {0x3f83053b,0xd5b9001c,0x20870071,0x00000000}},	// [6140] _baju_, apās_, ойти_,
  { {0x2480005b,0x75f6004c,0xcef6007b,0x00000000}},	//   _isim_, kázk, очењ,
  { {0x3f83017f,0xfe720021,0x69cb029a,0x00000000}},	//   _daju_, بدء_, _omge,
  { {0xf53f01bc,0x44290137,0x3ea70137,0x00000000}},	//   lkår_, _yta_, änta_,
  { {0x6d49001f,0xdca306e0,0xac0a013e,0x00000000}},	//   _ddea, маци, анда_,
  { {0xa01b00c7,0xdb180024,0x7b660086,0x00000000}},	//   _pröv, bivý, ітле,
  { {0x0ef90088,0x67ef00b9,0x2258004b,0x00000000}},	//   _гэты_, højs, nurk_,
  { {0x2480017f,0x2caf380f,0x6e93007e,0x00000000}},	//   _osim_, bygd_, _تلفا,
  { {0x225800ca,0x91bb0041,0x2d84005f,0x00000000}},	//   hurk_, ימקי, _iame_,
  { {0xc5f9008f,0x75f6013d,0xa91d3810,0x00000000}},	//   rtēm_, lázh, rdža,
  { {0x44293811,0xc5f9008f,0x3ffb009a,0x00000000}},	//   _sta_, stēm_, שפיע,
  { {0x3ebe0026,0xe5c70086,0x999f003b,0x00000000}},	//   _ýttu_, існо, ărţi_,
  { {0xf9d900b5,0x248d00cd,0x7c293812,0x00000000}},	//   _פֿעל, íem_, _xter,
  { {0x98a30001,0xa7fd00ea,0x4429004b,0x00000000}},	//   _циље, ltűn, _vta_,
  { {0x69cb001f,0xd13b3813,0xc6a60002,0x00000000}},	//   _ymge, иха_, _фрли,
  { {0x61f9000d,0x224d3814,0x656d25e5,0x00000000}},	//   ёнаў_, ček_, _ubah,
  { {0x316902dd,0x2bdb0053,0x44293815,0x00000000}},	// [6150] rfaz_, _बदला, _uta_,
  { {0x316900be,0x4e8b04d6,0x59ca0042,0x00000000}},	//   sfaz_, ищем_, ़ोतर,
  { {0x7c293816,0xdb073817,0x877b009a,0x00000000}},	//   _ster, ülün, שאבי,
  { {0x2d840037,0x427a00b5,0x127a0047,0x00000000}},	//   _came_, _פארג, _פארע,
  { {0x506403d6,0xfd10007e,0x2d843818,0x00000000}},	//   _отра, نجه_, _dame_,
  { {0x447c2648,0x4c84000d,0x75f60240,0x00000000}},	//   ינדע, ьлів, tázk,
  { {0x2d8404ca,0xee780044,0x8d7702da,0x00000000}},	//   _fame_, _وصفت_, _وارا,
  { {0x2d840034,0x75f60512,0xd90f007e,0x00000000}},	//   _game_, rázk, نیا_,
  { {0x7c290897,0x8c250044,0x8c190044,0x00000000}},	//   _uter, _رفضه, _طيار_,
  { {0x2d84085a,0xf41f0137,0x3b540330,0x00000000}},	//   _zame_, rväl_, _окур,
  { {0x248000be,0x60090078,0x61ed2a58,0x00000000}},	//   _ssim_, _užmu, koal,
  { {0x67ef010a,0x69cb0199,0x25a90034,0x00000000}},	//   tøjs, _umge, _coal_,
  { {0x60021f32,0x29160021,0xdce9007d,0x00000000}},	//   lôme, _عقود_, _obeč,
  { {0xdc880063,0x232700fb,0xf7e80044,0x00000000}},	//   קְרָ, зори_, _وروى_,
  { {0x41b6005a,0x60020c77,0xf7720063,0x00000000}},	//   псат, nôme, _נקה_,
  { {0x25a92b71,0x69db3819,0x320900a4,0x00000000}},	//   _goal_, nnue, gmay_,
  { {0x24800089,0x2d84381a,0x55bb0063,0x00000000}},	// [6160] _usim_, _rame_, _למקו,
  { {0x2d841a22,0x75fd013d,0x6446381b,0x00000000}},	//   _same_, nézn, mski,
  { {0xa01b0137,0x27460025,0xdb01381c,0x00000000}},	//   _brös, líní_, _bolí,
  { {0x86360047,0xa06a1599,0x600200be,0x00000000}},	//   פאנג_, _лама_, dôme,
  { {0x6446381d,0x2d86381e,0x27460139,0x00000000}},	//   nski, rdoe_, níní_,
  { {0x69db381f,0x64463820,0x1af43821,0x00000000}},	//   enue, iski, мпля,
  { {0xd3570047,0x2d840498,0x7bdf0003,0x00000000}},	//   ליסי_, _tame_, équa,
  { {0xa9c30086,0xa01b092e,0x64463822,0x00000000}},	//   еськ, _tröt, kski,
  { {0xe872007e,0x64463823,0x60c43824,0x00000000}},	//   رندگ, jski, nzim,
  { {0x25a9014f,0x60020016,0x64463825,0x00000000}},	//   _soal_, lômb, dski,
  { {0xb8f30235,0x64462c1a,0x66042493,0x00000000}},	//   _हे_, eski, _bhik,
  { {0x18a600a0,0x1a9b0047,0x5e570041,0x00000000}},	//   _наем, _ליבע, היטע_,
  { {0xafdb01f2,0x64463826,0x44b40085,0x00000000}},	//   _svøm, gski, ебяс,
  { {0x07a3000d,0xf3f1008b,0x60c43827,0x00000000}},	//   _пачн, ộ_, dzim,
  { {0xd3780086,0xa2940086,0x629a0066,0x00000000}},	//   ччя_, нарі, ätop,
  { {0x61f9000d,0x64461a96,0x52142184,0x00000000}},	//   інаў_, bski, едст,
  { {0x765a3828,0xe45f00ea,0x27460139,0x00000000}},	// [6170] luty, szöb_, cíní_,
  { {0x14d800b5,0xdb0105ab,0x61ed3829,0x00000000}},	//   _מוחל_, _solí, soal,
  { {0x60c416ae,0xf3ff017d,0xdb010955,0x00000000}},	//   azim, ltão_, _polí,
  { {0xf3ff017d,0xdb07006c,0x248c005f,0x00000000}},	//   otão_, _émér, žimų_,
  { {0x69c00027,0xf3ff0016,0x8ccd0053,0x00000000}},	//   dhme, ntão_, _देशो,
  { {0x765a00fe,0x69de0003,0x600211f5,0x00000000}},	//   kuty, épen, tôme,
  { {0xa01b382a,0xdb180195,0x75f6013d,0x00000000}},	//   _trös, chví, mázv,
  { {0xdb080164,0x3eae00bd,0x3829005e,0x00000000}},	//   _modè, äfte_, ожио_,
  { {0x9f64005b,0xd7f8003b,0x87550062,0x00000000}},	//   ütçe_, flă_, мънц,
  { {0x69c00378,0x6d5d0058,0x64461286,0x00000000}},	//   ahme, _ısay, vski,
  { {0x64460045,0x9be40086,0x6d5a003b,0x00000000}},	//   wski, _чітк, şcaţ,
  { {0xd7f8000c,0x79a40002,0x6446382b,0x00000000}},	//   ală_, _прче, tski,
  { {0x644600eb,0xb4b80053,0xd7f8003b,0x00000000}},	//   uski, चने_, blă_,
  { {0x395f0019,0xb17b0137,0x7989029e,0x00000000}},	//   lgus_, _skåp, ldew,
  { {0x27460139,0xa18a0062,0x6446382c,0x00000000}},	//   síní_, обва_, sski,
  { {0x395f382d,0x6446034a,0xe1fa0603,0x00000000}},	//   ngus_, pski, іга_,
  { {0x60c4017f,0xa0670431,0x61e102fc,0x00000000}},	// [6180] uzim, мата_, élla,
  { {0x7d1b382e,0xd00a005e,0x60c4004d,0x00000000}},	//   _agus, цезе_, rzim,
  { {0xa2060086,0x4420382f,0xf4130063,0x00000000}},	//   _опод, _hui_, _שפת_,
  { {0x44201fc9,0x60260095,0x205604ef,0x00000000}},	//   _kui_, _одма, _отгр,
  { {0x75e8005b,0x7989002b,0x0c7a0049,0x00000000}},	//   mızd, ddew, تصاب_,
  { {0x442003c6,0xdca3005e,0x6fc00058,0x00000000}},	//   _mui_, таљи, _böce,
  { {0x44203830,0x0e550062,0x75f6013d,0x00000000}},	//   _lui_, _пътя, lázu,
  { {0x75e801f7,0x44200164,0x31600058,0x00000000}},	//   nızd, _oui_, ngiz_,
  { {0xdb080164,0xb81400e1,0x6d403831,0x00000000}},	//   _modé, ндиј, _iema,
  { {0x69c00034,0xa09b0047,0x6d400b21,0x00000000}},	//   shme, קייט, _hema,
  { {0xbbd7014e,0x6d4008f0,0x0f57014e,0x00000000}},	//   _קובץ_, _kema, ויים_,
  { {0xadc30013,0x75f6013d,0xb8860014,0x00000000}},	//   _miến, kázu, gríð,
  { {0x442002f6,0x6d4008f0,0x39440d93,0x00000000}},	//   _cui_, _mema, mams_,
  { {0x442000e8,0xa3c90161,0xf3ff0016,0x00000000}},	//   _dui_, लों_, rtão_,
  { {0xf3ff03d9,0x66270024,0x7c200360,0x00000000}},	//   stão_, ľské, _lumr,
  { {0x39440006,0xdb080003,0x662701c2,0x00000000}},	//   nams_, _codé, žské,
  { {0xdbd601a5,0x201801f7,0xd0d4005a,0x00000000}},	// [6190] _kään, _biri_, вотъ,
  { {0x2018053b,0xdbd6021e,0x657d3832,0x00000000}},	//   _ciri_, _jään, lesh,
  { {0x20180397,0x6d401203,0xdfd80062,0x00000000}},	//   _diri_, _bema, фът_,
  { {0x3944031c,0x3f871fc3,0x657d3833,0x00000000}},	//   jams_, žnu_, nesh,
  { {0x7c200025,0x6d4002a0,0x6b8828b2,0x00000000}},	//   _cumr, _dema, _badg,
  { {0x6d400019,0x20183834,0x657d0035,0x00000000}},	//   _eema, _giri_, hesh,
  { {0x645d0009,0x6d400034,0x657d077d,0x00000000}},	//   husi, _fema, kesh,
  { {0x6b9a00bd,0x657d0035,0x7d1b0035,0x00000000}},	//   _entg, jesh, _ugus,
  { {0xa2d10161,0x645d1b74,0xdb010024,0x00000000}},	//   _डेस्, jusi, _dolá,
  { {0x6b883835,0x6d403836,0x0902000d,0x00000000}},	//   _gadg, _zema, ыпын,
  { {0x442002f6,0xf1bf0016,0xdb010025,0x00000000}},	//   _sui_, _olá_, _folá,
  { {0x657d0b54,0x645d3837,0x3944001c,0x00000000}},	//   gesh, fusi, cams_,
  { {0x44203838,0x26ca0024,0xd4f5000d,0x00000000}},	//   _qui_, úbor_, вяры,
  { {0x442000aa,0xf1bf00ea,0x437505ef,0x00000000}},	//   _vui_, _alá_, куст,
  { {0x645d00eb,0x657d3839,0x61e90869,0x00000000}},	//   ausi, besh, čeln,
  { {0x2018383a,0x645d11ab,0x4420383b,0x00000000}},	//   _siri_, busi, _tui_,
  { {0x645d2bbe,0x2f560071,0x394f1f67,0x00000000}},	// [61a0] cusi, етес, _mdgs_,
  { {0x7f860032,0x0479006a,0x6d40383c,0x00000000}},	//   علان, _کلیک_, _sema,
  { {0x201800c3,0x6d400397,0xdb1a0164,0x00000000}},	//   _viri_, _pema, _ulté,
  { {0xadc3008b,0x10a6365e,0x208a0062,0x00000000}},	//   _viến, _зимн, _ейми_,
  { {0x2018383d,0x6b8809fe,0x39440078,0x00000000}},	//   _tiri_, _padg, vams_,
  { {0x657d0009,0xf09f001b,0xadc3001b,0x00000000}},	//   zesh, _ngày_, _tiến,
  { {0x657d0009,0x6d40383e,0x3944109f,0x00000000}},	//   yesh, _tema, tams_,
  { {0xdbd6024a,0x7bc30024,0x657d00ac,0x00000000}},	//   _sään, ahnu, xesh,
  { {0xdbd60072,0xdb01383f,0xfce3049f,0x00000000}},	//   _pään, _volá, _бото,
  { {0x7bc30199,0x645d143b,0x39440078,0x00000000}},	//   chnu, vusi, sams_,
  { {0xd6da1099,0x39440a10,0xab69013a,0x00000000}},	//   яти_, pams_, _تحقق_,
  { {0x3f8a3840,0xdb18004a,0x645d3841,0x00000000}},	//   _labu_, chvá, tusi,
  { {0xdb0700ea,0x657d077d,0x6285004b,0x00000000}},	//   ülön, resh, _ssho,
  { {0xf1bf007a,0x7ae4000c,0x645d3842,0x00000000}},	//   _slá_, şitu, rusi,
  { {0x61e1006d,0x645d3843,0xa3c20053,0x00000000}},	//   éllo, susi, ्फ़_,
  { {0x7afa00d1,0x645d3844,0x657d00ac,0x00000000}},	//   _mytt, pusi, qesh,
  { {0x3f8a0b54,0xdbd1004b,0x7afa0196,0x00000000}},	// [61b0] _babu_, tüüb, _lytt,
  { {0x6002017d,0xdb18004b,0x2a720022,0x00000000}},	//   tôma, livõ, łyby_,
  { {0x7afa04b1,0x8e990021,0x00000000,0x00000000}},	//   _nytt, بناء_,   ,
  { {0x3eae01e3,0xdb18004b,0x644d0078,0x00000000}},	//   äfta_, nivõ, _kvai,
  { {0x7bc30025,0x628a0014,0x50670054,0x00000000}},	//   thnu, _áfor, _ятна,
  { {0x7afa06a3,0x8234007e,0xdb18004b,0x00000000}},	//   _bytt, _جریا, hivõ,
  { {0xa91d0006,0xda620071,0x75e80058,0x00000000}},	//   ldži, авщи, nızc,
  { {0xa91d00eb,0x59750088,0x644d006c,0x00000000}},	//   odži, тыку, _ovai,
  { {0xa91d0006,0x7bc30003,0xdb18004e,0x00000000}},	//   ndži, phnu, divõ,
  { {0xa91d0006,0xd7ee0021,0xeb930021,0x00000000}},	//   idži, يكي_, _حظر_,
  { {0xd7090055,0x644d1664,0x7bc107b9,0x00000000}},	//   ьное_, _avai, _illu,
  { {0xdb183845,0xa91d0078,0x75fd013d,0x00000000}},	//   givõ, kdži, nézh,
  { {0xc4830085,0x45d30085,0xd7950044,0x00000000}},	//   аляк, роўс, _للإخ,
  { {0x07a50699,0x2b471035,0x69e3007d,0x00000000}},	//   _јакн, nanc_, šteđ,
  { {0x3f8a014f,0x434307da,0xdb0100cd,0x00000000}},	//   _rabu_, ресв, _dolç,
  { {0x3f8a0089,0x75f600ea,0x386d3846,0x00000000}},	//   _sabu_, rázs, oter_,
  { {0x7bc100fe,0xc5f9001c,0xa3c20053,0x00000000}},	// [61c0] _ollu, rtēt_, ंसद_,
  { {0xe29a0001,0x386d3847,0xc5f9008f,0x00000000}},	//   _жао_, iter_, stēt_,
  { {0x386d3848,0x644d001c,0x75f6258b,0x00000000}},	//   hter_, _zvai, lázq,
  { {0xf2d3014e,0x386d136a,0x798b00a4,0x00000000}},	//   _כעת_, kter_, _nagw,
  { {0x3f8a14f0,0x386d3849,0x7afa384a,0x00000000}},	//   _tabu_, jter_, _sytt,
  { {0x75fd013d,0x1bf30085,0x386d384b,0x00000000}},	//   tézk, апіў, dter_,
  { {0x29000006,0x0a6a000a,0x386d2e38,0x00000000}},	//   _šia_, фрли_, eter_,
  { {0xa9670001,0x7bc10019,0x6f03005b,0x00000000}},	//   вића_, _ellu, ünce,
  { {0xbc6a006a,0xa3c20053,0x386d384c,0x00000000}},	//   _زمان_, ंसा_, gter_,
  { {0xdb080024,0xf41f00fe,0x7afa00fe,0x00000000}},	//   _hodí, ivät_, _tytt,
  { {0xa91d00eb,0x9f580025,0x386d2e91,0x00000000}},	//   zdži, _bhrú_, ater_,
  { {0xa91d0078,0x386d384d,0xdb18004b,0x00000000}},	//   ydži, bter_, uivõ,
  { {0x386d384e,0xdb18004b,0x44320013,0x00000000}},	//   cter_, rivõ, _cty_,
  { {0x9f9a0019,0xdb18042e,0x798b0022,0x00000000}},	//   _jääb_, sivõ, _zagw,
  { {0x26da0019,0x2418014c,0xfc48008b,0x00000000}},	//   _äpo_, торы_, hử_,
  { {0xc5f9008f,0xf2070054,0x31c41340,0x00000000}},	//   rtēs_, тяго, асув,
  { {0x34950088,0xa91d0006,0xf487013c,0x00000000}},	// [61d0] _сапр, udži, _руйн,
  { {0x69c20185,0xa283007e,0x7bd80035,0x00000000}},	//   _lloe, _پیرو, jivu,
  { {0x7e28000d,0xa91d068a,0x386d3024,0x00000000}},	//   віча_, leže, zter_,
  { {0xdb0300bd,0x386d384f,0xc6d90047,0x00000000}},	//   rknü, yter_, ײַער,
  { {0x115a00b5,0x386d3850,0x6002017d,0x00000000}},	//   _אדרע, xter_, cômo,
  { {0xadc3008b,0x798b00a4,0xab640086,0x00000000}},	//   _thắn, _sagw, ивіл,
  { {0x798b002c,0x69c22490,0x3b640062,0x00000000}},	//   _pagw, _bloe, ръчв,
  { {0xf985000a,0x2489017f,0x60c90006,0x00000000}},	//   угио, _osam_, _žemy,
  { {0x386d03b2,0x5c990088,0x7bd80019,0x00000000}},	//   uter_, _якая_, bivu,
  { {0x798b021f,0xa91d00c2,0x386d2da6,0x00000000}},	//   _wagw, deže, rter_,
  { {0x61e90117,0x2489014f,0xb8fa0042,0x00000000}},	//   čelj, _asam_, _डे_,
  { {0xf41f024a,0x69c23065,0x600b0058,0x00000000}},	//   yvät_, _gloe, lümd,
  { {0x3a250102,0xa01b00ea,0x44243851,0x00000000}},	//   _hulp_, _csök, êm_,
  { {0xf7450079,0x3f81007d,0x9f84013d,0x00000000}},	//   _секо, jehu_, _töé_,
  { {0x2489003d,0xa01b0137,0xf6790047,0x00000000}},	//   _esam_, _esök, _טאַמ,
  { {0x05660fc7,0xc48601ea,0xf1aa02da,0x00000000}},	//   _свин, _блик, رازه_,
  { {0x9106093e,0xa91d00c2,0x10a30781,0x00000000}},	// [61e0] упае, ležb, битн,
  { {0x728a0138,0x351b0063,0xf2a63852,0x00000000}},	//   _због_, _אופנ, _биоп,
  { {0xdb083853,0xae7a0085,0xc7d6009a,0x00000000}},	//   _podí, эсах_, נועי_,
  { {0x65663854,0x21a60121,0x224c0260,0x00000000}},	//   ngkh, _симм, ádku_,
  { {0x61e43855,0xdb08027d,0x7bd83856,0x00000000}},	//   mnil, _vodí, tivu,
  { {0x69c2006f,0x61e41cf1,0x3dc63857,0x00000000}},	//   _sloe, lnil, show_,
  { {0xed5a0086,0x69c2006f,0x61e43858,0x00000000}},	//   _пов_, _ploe, onil,
  { {0x7bd8024a,0xdd00005b,0xb998005e,0x00000000}},	//   sivu, ştın, твих_,
  { {0x69c20162,0x7bd80072,0x600b0058,0x00000000}},	//   _vloe, pivu, bümd,
  { {0x2bf60088,0x06fd0080,0x61e41434,0x00000000}},	//   _сябр, číná_, hnil,
  { {0xa91d082a,0x61e43859,0x3a9a0054,0x00000000}},	//   veže, knil, _ятаю_,
  { {0x61e401d1,0x9f5f0046,0x00000000,0x00000000}},	//   jnil, ðrún_,   ,
  { {0xa91d0734,0x75fd013d,0xcbb80042,0x00000000}},	//   teže, kézv, _अवाञ,
  { {0xd2350062,0x61e4385a,0xb357005d,0x00000000}},	//   ингъ, enil, دیدا_,
  { {0x57fb0063,0xa91d02f7,0x7bdf385b,0x00000000}},	//   _רלוו, reže, équi,
  { {0xa91d00c3,0x61e4385c,0x11d40021,0x00000000}},	//   seže, gnil, متقد,
  { {0x24890016,0x4fd5208c,0x361c009a,0x00000000}},	// [61f0] _usam_, ажат, _אוהד,
  { {0x600b01f7,0x61e40012,0x443910c5,0x00000000}},	//   küme, anil, mps_,
  { {0x44391930,0xa3c20053,0x3eba385d,0x00000000}},	//   lps_, ंसर_, gypt_,
  { {0x44390be9,0x644f01f4,0x645d385e,0x00000000}},	//   ops_, osci, orsi,
  { {0xcb6900e1,0xeb8e1a5c,0x3f8102f7,0x00000000}},	//   вале_, ои_, pehu_,
  { {0x644f0025,0x443912f0,0x645d1d43,0x00000000}},	//   isci, ips_, irsi,
  { {0xdce9017f,0x60cd385f,0x645d004d,0x00000000}},	//   _obeć, lzam, hrsi,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xc9a60076,0x6d4b3860,0x60cd3861,0x00000000}},	//   рвые_, maga, nzam,
  { {0x6d4b15c4,0x7c39001f,0xa7b50259,0x00000000}},	//   laga, mpwr, рсиј,
  { {0x61e43862,0x98aa001c,0x44393863,0x00000000}},	//   ynil, ēmām_, eps_,
  { {0x660d0009,0x6d4b31e6,0x6b8314eb,0x00000000}},	//   _chak, naga, leng,
  { {0xdb080025,0x4463005a,0xe72e1375,0x00000000}},	//   _iodá, овяв, _ме_,
  { {0x60cd003d,0x6b8307d7,0x6d4b3864,0x00000000}},	//   dzam, neng, haga,
  { {0x6d4b002c,0x78a900cd,0x753d00ea,0x00000000}},	//   kaga, lxev, bbsz,
  { {0x61e40529,0x6b8311aa,0x6d4b3865,0x00000000}},	//   unil, heng, jaga,
  { {0x69c900fe,0x6b833138,0xdb0103ea,0x00000000}},	// [6200] ihee, keng, _colú,
  { {0x6b833866,0xe80b0161,0xf41f00c7,0x00000000}},	//   jeng, _सीमा_, svär_,
  { {0xdd8f0001,0x60cd0035,0x6d4b3867,0x00000000}},	//   ош_, azam, faga,
  { {0x6d4b18b1,0x3e6e0080,0x644400ac,0x00000000}},	//   gaga, rýt_, _kwii,
  { {0x4c940cbb,0x60cd0051,0x7d090051,0x00000000}},	//   силс, czam, _czes,
  { {0x69c90122,0x6d4b0455,0x6b833868,0x00000000}},	//   ehee, aaga, geng,
  { {0x6d4b014f,0x753d0022,0x7d09013d,0x00000000}},	//   baga, ybsz, _ezes,
  { {0x645d0185,0x6d4b0025,0x6c36007e,0x00000000}},	//   yrsi, caga, _نفرا,
  { {0x6e20002c,0xdce200c3,0xdb08027d,0x00000000}},	//   _iimb, ogoč, _dodá,
  { {0xdb1a000f,0x75240035,0x6e2030c9,0x00000000}},	//   _eltá, _agiz, _himb,
  { {0x645d0185,0x60cd0290,0x7bdf0003,0x00000000}},	//   wrsi, zzam, èque,
  { {0x69c90122,0x6e200035,0xaadb0063,0x00000000}},	//   chee, _jimb, _בחבר,
  { {0xb4c10053,0x75e8005b,0x6e203869,0x00000000}},	//   ंने_, mızl, _mimb,
  { {0x75240290,0x6e2009ee,0x4439386a,0x00000000}},	//   _egiz, _limb, rps_,
  { {0xd6270138,0x6d4b00bb,0x69c000d1,0x00000000}},	//   _које_, yaga, okme,
  { {0x75e801f7,0x660d0035,0xb1a40500,0x00000000}},	//   nızl, _uhak, ошук,
  { {0x6b830035,0x69c0004b,0x6d4b386b,0x00000000}},	// [6210] yeng, ikme, vaga,
  { {0x60cd386c,0x6d4b15e7,0x6671007e,0x00000000}},	//   rzam, waga, _بگیر,
  { {0x6e20386d,0x60cd0051,0x22950021,0x00000000}},	//   _bimb, szam, _الجس,
  { {0x6b830397,0x44290150,0xde580086,0x00000000}},	//   weng, _kua_, раці_,
  { {0x6d4b014f,0x4429058c,0x6b83386e,0x00000000}},	//   raga, _jua_, teng,
  { {0x6d4b002c,0x3ea700c7,0x4429001b,0x00000000}},	//   saga, änts_, _mua_,
  { {0x0d67011c,0x69c9006f,0x69db00cd,0x00000000}},	//   _възм, thee, tiue,
  { {0x49980055,0x6b8306ee,0x69c90072,0x00000000}},	//   атья_, seng, uhee,
  { {0x44290027,0x69db00cd,0x6b8303d7,0x00000000}},	//   _nua_, riue, peng,
  { {0x44212322,0x38bc0139,0x7bca00e0,0x00000000}},	//   _nih_, _sárú_, chfu,
  { {0x7c292589,0x3f91386f,0x66f2004c,0x00000000}},	//   _huer, _mazu_, věké,
  { {0xc3290ee1,0x44293870,0x69de013d,0x00000000}},	//   _טו_, _bua_, épet,
  { {0x4421017f,0x44293871,0x394d3872,0x00000000}},	//   _bih_, _cua_, maes_,
  { {0x7c29048e,0xfbc7006a,0x44290397,0x00000000}},	//   _muer, ست_, _dua_,
  { {0x442913a3,0x21a60002,0x75fd009c,0x00000000}},	//   _eua_, бивм, tézt,
  { {0x7c2900e8,0x75461415,0xe80b0082,0x00000000}},	//   _ouer, _униз, _सीता_,
  { {0x6e203873,0x4429014f,0x10a3065b,0x00000000}},	// [6220] _rimb, _gua_, питн,
  { {0x43860021,0x3366000d,0xaf96005e,0x00000000}},	//   _الدق, _увог, љшај,
  { {0x3f910199,0x7e6500e3,0x60020016,0x00000000}},	//   _dazu_, guhp, nômi,
  { {0x237f017f,0x4429002b,0x7c290285,0x00000000}},	//   đuje_, _yua_, _buer,
  { {0x7c2902dd,0x7bca0034,0x89d8007e,0x00000000}},	//   _cuer, thfu, یوتر_,
  { {0x7c293874,0xac250454,0x3f913875,0x00000000}},	//   _duer, іфік, _gazu_,
  { {0x69a40161,0x6e203876,0xc3330063,0x00000000}},	//   काली, _timb, לוג_,
  { {0x7c29048e,0xadc30013,0x38340962,0x00000000}},	//   _fuer, _thạn, онир,
  { {0x7c210c4a,0x69c03877,0x98b70062,0x00000000}},	//   _filr, rkme, йлът_,
  { {0x44290016,0x7c2f0164,0x75e8005b,0x00000000}},	//   _rua_, _écra, sızl,
  { {0x44293878,0x7c2900bd,0x69de00ea,0x00000000}},	//   _sua_, _zuer, épes,
  { {0x442100f3,0x6fc001e3,0xceb301f9,0x00000000}},	//   _sih_, _böck, לית_,
  { {0x4429001b,0xa91d00b2,0x65600139,0x00000000}},	//   _qua_, ležn, ómha,
  { {0xb8de0235,0x4429008b,0x600b005b,0x00000000}},	//   ीन_, _vua_, küma,
  { {0x69d90185,0xd5bb005a,0x3f910051,0x00000000}},	//   _ymwe, _бсп_, _razu_,
  { {0x6fc000bd,0x44293879,0x463b0047,0x00000000}},	//   _höch, _tua_, _געהע,
  { {0x7bc801f7,0xc6050161,0x44210c61,0x00000000}},	// [6230] _oldu, रतीय_, _tih_,
  { {0x2fc7001b,0x6d490244,0x6aa80042,0x00000000}},	//   óng_, _seea, _कपूर,
  { {0x6fc00199,0x7c2902dd,0xf3ff017d,0x00000000}},	//   _möch, _suer, stãs_,
  { {0x29d3000c,0x7c29387a,0xa91d085a,0x00000000}},	//   nţat_, _puer, dežn,
  { {0x7bc60006,0x6d49387b,0x7c292a64,0x00000000}},	//   _įkur, _veea, _quer,
  { {0x40340156,0xeb991159,0x5274005d,0x00000000}},	//   _херс, рик_, _بایز,
  { {0xdb0a004d,0x03bc0041,0x7c29004d,0x00000000}},	//   ckfü, רצול, _wuer,
  { {0x08c525aa,0x7c29387c,0x7bc80014,0x00000000}},	//   жбин, _tuer, _eldu,
  { {0x7c21007a,0x394d387d,0x2c72002b,0x00000000}},	//   _tilr, raes_, câd_,
  { {0x2903001c,0x69de0003,0xaa590121,0x00000000}},	//   āja_, éper, _вижу_,
  { {0x6b9c02dd,0x6d5e0078,0x7bc30195,0x00000000}},	//   _órga, ėpav, mknu,
  { {0x69d900bd,0x24800089,0x7bc30014,0x00000000}},	//   _umwe, _ppim_, lknu,
  { {0x26c300c3,0xe9190086,0xf795000d,0x00000000}},	//   šjo_, _тоді_, _мадэ,
  { {0xe7390d34,0x7bc3387e,0x7d0605a5,0x00000000}},	//   _тек_, nknu, _økse,
  { {0x41b61006,0xe8020042,0xc5f600de,0x00000000}},	//   осат, _रीटा_, _وثبت,
  { {0x7afe004b,0x02060083,0x75f6009c,0x00000000}},	//   üpti, ізан, házz,
  { {0x7bc30026,0xb4db01a8,0xe1f70500,0x00000000}},	// [6240] kknu, rbàc, ігу_,
  { {0xdb1a0050,0xd00f005d,0x33660044,0x00000000}},	//   _yltä, پلم_, _بهدف,
  { {0xd37b0047,0x2c72002b,0xaec6014b,0x00000000}},	//   _דריט, wâd_, ўбел,
  { {0x2c72001f,0x60100072,0xa3c20053,0x00000000}},	//   tâd_, däme, ंसक_,
  { {0xf1b30063,0x66060072,0x61430085,0x00000000}},	//   _חסר_, ilkk, _іера,
  { {0x2ac60001,0x749b0041,0xa91d08ed,0x00000000}},	//   жљив, יינפ, težn,
  { {0x441b0063,0x3ebe387f,0x601000a5,0x00000000}},	//   בוסס, _ætt_, rämd,
  { {0xa91d1312,0xea95000d,0x9d460085,0x00000000}},	//   režn, яшчэ, _феад,
  { {0xc2130063,0xa91d082a,0xd83a000d,0x00000000}},	//   והה_, sežn, шэй_,
  { {0xc07b0047,0x66060072,0x7bc33880,0x00000000}},	//   סטיש, elkk, cknu,
  { {0xa91d003d,0x600b0019,0x6595045b,0x00000000}},	//   bežo, kümn, пану,
  { {0xe4a70071,0x6fc0004d,0x6d421dfa,0x00000000}},	//   орго, _wöch, nboa,
  { {0x6fc0004d,0x29d3003b,0x7aed0058,0x00000000}},	//   _töch, rţat_, şatt,
  { {0x6d423881,0x66060072,0x823701f3,0x00000000}},	//   hboa, alkk, قررا,
  { {0xe6580032,0x6234000a,0x8837001c,0x00000000}},	//   _البث_, десу, ķēša,
  { {0xc0350259,0x26d80066,0xe2f80054,0x00000000}},	//   знај, úrou_, цесі_,
  { {0x629e0089,0x61f8000d,0x51f8014b,0x00000000}},	// [6250] _erpo, інуў_, іную_,
  { {0xdb18007a,0xdb210114,0xaf073119,0x00000000}},	//   mkvæ, _štít, очек,
  { {0xeeab0699,0x68e4004c,0xdb180046,0x00000000}},	//   штак_, _židl, lkvæ,
  { {0xb17b19e5,0x12fa009a,0x867b009d,0x00000000}},	//   _småf, _להתב, שראו,
  { {0xd59c0047,0xdb180026,0xc1050242,0x00000000}},	//   יבאל, nkvæ, _روسي,
  { {0x00ba0063,0xf0820043,0x42ab009d,0x00000000}},	//   _המשמ, _سیمپ, ֹסֵ֑,
  { {0xf1bf3882,0x9f41017d,0x7bc33883,0x00000000}},	//   _giác_, anhã_, rknu,
  { {0x3e7500c7,0x7c2f0003,0x7bc33884,0x00000000}},	//   måt_, _écro, sknu,
  { {0x3e750137,0xdddc004c,0xd87600de,0x00000000}},	//   låt_, _zprů, كميت_,
  { {0x7c3b3885,0x2fb60063,0xf77104a0,0x00000000}},	//   _itur, ִּים_, راخ_,
  { {0x3e750137,0x38ca005d,0xa91d0061,0x00000000}},	//   nåt_, لایی_, pežo,
  { {0xca960063,0x69dc0078,0xd7c9005d,0x00000000}},	//   _מדעי_, _įreg, _گوته_,
  { {0xe8ee011c,0x69cb05b5,0xdb180014,0x00000000}},	//   _чл_, _ilge, gkvæ,
  { {0x3e7500c7,0xf8b60063,0x6d42003b,0x00000000}},	//   kåt_, _מפני_, zboa,
  { {0xdbd700fe,0x515a000d,0x6d423886,0x00000000}},	//   määs, йшаў_, yboa,
  { {0x7c3b01f7,0x3e750137,0x5bb80042,0x00000000}},	//   _otur, dåt_, _अव्व,
  { {0x3cdb0042,0xdb013887,0xb8860046,0x00000000}},	// [6260] _खेले_, _koló, msíð,
  { {0xc003000a,0xb8860026,0x6d5b3888,0x00000000}},	//   епук, lsíð, _adua,
  { {0x7c3b3889,0x69cb166f,0xdee3388a,0x00000000}},	//   _atur, _olge, нофи,
  { {0x600b005b,0x26120042,0x865a009d,0x00000000}},	//   lüml, _धीमी_, מדעי,
  { {0x6d5b002b,0x601000a5,0xc19b009a,0x00000000}},	//   _ddua, rämb, _השכי,
  { {0x69cb388b,0x600b005b,0x3e750829,0x00000000}},	//   _alge, nüml, båt_,
  { {0x9d460086,0x629c00ca,0x71d60063,0x00000000}},	//   _невд, nvro, ּוִד_,
  { {0x89d80021,0xa91d00c2,0x629c1560,0x00000000}},	//   توبر_, pežl, ivro,
  { {0x600b005b,0xa91d0734,0x67d40edb,0x00000000}},	//   küml, ležj, допу,
  { {0xdb01388c,0x69cb388d,0x6e2e388e,0x00000000}},	//   _coló, _elge, _kubb,
  { {0xb886007a,0xbb3b0063,0x201a1882,0x00000000}},	//   fsíð, _העבי, impi_,
  { {0xd6d7066e,0x56930505,0xdb180046,0x00000000}},	//   яты_, хают, tkvæ,
  { {0x9f84005b,0x4dfb0047,0x6e2e16be,0x00000000}},	//   _göç_, מפטא, _lubb,
  { {0x48130086,0x6492007d,0x00000000,0x00000000}},	//   _зміс, džić,   ,
  { {0x03240121,0x36330021,0x877b0063,0x00000000}},	//   едён, _كريس, _האוי,
  { {0xdb010058,0xd843004c,0x201a0050,0x00000000}},	//   _rolü, _íčý_, empi_,
  { {0x600b005b,0x7f950085,0x00000000,0x00000000}},	// [6270] büml, маах,   ,
  { {0x9f840137,0xdb01388f,0x6e2e3890,0x00000000}},	//   _nöä_, _polü, _bubb,
  { {0x7c3b2da1,0x51f93891,0xb3bc009a,0x00000000}},	//   _stur, _мною_, _למזכ,
  { {0x21670055,0x201a00fe,0x3e750137,0x00000000}},	//   _этог, ampi_, råt_,
  { {0xfbd0007e,0x61ed3892,0xf09f00cd,0x00000000}},	//   گتن_, mnal, _urà_,
  { {0x3e750137,0x32093893,0x6ee70044,0x00000000}},	//   påt_, llay_, _فسأل,
  { {0x61ed1c6c,0x6e2e3894,0xdbd70072,0x00000000}},	//   onal, _gubb, vääs,
  { {0x600b005b,0x61ed3895,0xa2b50042,0x00000000}},	//   züml, nnal, _उपन्,
  { {0xdb013896,0x7c3b05b3,0x61ed3897,0x00000000}},	//   _colò, _utur, inal,
  { {0xa91d00c3,0x62853898,0xe7310021,0x00000000}},	//   ležk, _opho, خصة_,
  { {0x4af9005d,0x61ed0244,0x60100050,0x00000000}},	//   _بکشد_, knal, näma,
  { {0xdbd70cb0,0xceb2069a,0x8afa009a,0x00000000}},	//   sääs, דיט_, _והעי,
  { {0xb886007a,0xdbd70ff2,0xdcfb007d,0x00000000}},	//   rsíð, pääs, _obuč,
  { {0x660e0024,0xb8860026,0x225e01d9,0x00000000}},	//   _ďaku, ssíð, átko_,
  { {0x628e006f,0x600b005b,0x3dcd001f,0x00000000}},	//   uwbo, rüml, _olew_,
  { {0x3209002c,0x61ed3899,0x629c006f,0x00000000}},	//   glay_, gnal, rvro,
  { {0x66040035,0xe45f00ea,0x6e2e32ac,0x00000000}},	// [6280] _ikik, ször_, _subb,
  { {0x6e2e02f6,0x76410146,0x3209002c,0x00000000}},	//   _pubb, oply, alay_,
  { {0x3dcd389a,0xa3cb0042,0xdb0a00a5,0x00000000}},	//   _blew_, ऊसर_, lkfö,
  { {0xa91d00c3,0x5ce60021,0x56b60047,0x00000000}},	//   režj, وكال, ופען_,
  { {0x361b00b5,0x2f560062,0x61e4389b,0x00000000}},	//   קונד, _отвс, miil,
  { {0xdb210024,0x61e4000c,0x3a26001f,0x00000000}},	//   _štát, liil, _siop_,
  { {0x3dcd0034,0x0a6a0086,0xa91d0066,0x00000000}},	//   _flew_, ірки_, bežk,
  { {0xa9c3019d,0x61e40529,0xdb010268,0x00000000}},	//   вськ, niil, _polò,
  { {0x60c4003e,0xb78a005e,0x3f98389c,0x00000000}},	//   nyim, ољне_, _karu_,
  { {0x8c43389d,0x3e60003b,0x61ed389e,0x00000000}},	//   _рефе, pătă_, znal,
  { {0x69d7006f,0x3f98389f,0x61ed38a0,0x00000000}},	//   ëxec, _maru_, ynal,
  { {0x7c280c79,0xd943005e,0xdb1800a5,0x00000000}},	//   _hidr, _аеци, rkvä,
  { {0x3a3e38a1,0x61e4000c,0x657d0026,0x00000000}},	//   _http_, diil, rfsh,
  { {0x62850137,0x600b004d,0x466a0141,0x00000000}},	//   _ppho, tümm, _дрим_,
  { {0x61e438a2,0x533404e3,0x60c40058,0x00000000}},	//   fiil, тест, eyim,
  { {0x3209002c,0xdb1a017d,0x61e4003b,0x00000000}},	//   ulay_, _potê, giil,
  { {0x9f58007a,0x3f980397,0x752d000f,0x00000000}},	// [6290] _skrá_, _baru_, _igaz,
  { {0xed590117,0xf1bf008b,0x661d38a3,0x00000000}},	//   _može_, _gián_, lmsk,
  { {0x61e4047f,0x79820051,0x8e990021,0x00000000}},	//   biil, _obow, ثناء_,
  { {0x61e40529,0xafdb00b9,0xed580054,0x00000000}},	//   ciil, _stød, дої_,
  { {0x394f00e8,0x7c2806a3,0x60d60051,0x00000000}},	//   _regs_, _bidr, czym,
  { {0x60100137,0xa91d00c2,0x7c28006c,0x00000000}},	//   lämn, sežk, _cidr,
  { {0x7c2838a4,0x78a21824,0x394f0168,0x00000000}},	//   _didr, _arov, _pegs_,
  { {0x601000c7,0x76410024,0x644d001f,0x00000000}},	//   nämn, vply, _owai,
  { {0x98a538a5,0x8bd90094,0xed59011b,0x00000000}},	//   хипе, _емас_, _cože_,
  { {0x78a20034,0x61e4000c,0x386200ea,0x00000000}},	//   _drov, ziil, ákra_,
  { {0x644d0592,0x78a200ca,0xd5e60769,0x00000000}},	//   _awai, _erov, ежни,
  { {0x76410acd,0x2604006d,0x60100137,0x00000000}},	//   rply, eñor_, jämn,
  { {0x61e4021e,0x60100137,0x69c9085b,0x00000000}},	//   viil, dämn, mkee,
  { {0x69c9024a,0x6e29103b,0x764138a6,0x00000000}},	//   lkee, _lieb, pply,
  { {0x9694000d,0x386d38a7,0x78a201da,0x00000000}},	//   _арыш, luer_, _zrov,
  { {0xc323018e,0xdd991994,0x6e2938a8,0x00000000}},	//   умск, _naň_, _nieb,
  { {0xe0da011c,0x644d0185,0x386d0164,0x00000000}},	// [62a0] чва_, _gwai, nuer_,
  { {0x60d60045,0xe47b0063,0xb358007e,0x00000000}},	//   rzym, _צריכ, _زیرا_,
  { {0xf1bf001b,0x3f982359,0x4432008b,0x00000000}},	//   _giáo_, _varu_, _huy_,
  { {0x6e290045,0x3f980150,0x7c2838a9,0x00000000}},	//   _cieb, _waru_, _sidr,
  { {0xdb080164,0x4c9407b0,0xa91d16ff,0x00000000}},	//   _indé, тилс, beži,
  { {0x4432048e,0xdb1a017d,0xed5900c2,0x00000000}},	//   _muy_, _hoté, _rože_,
  { {0x44320164,0x661d0051,0x6e2938aa,0x00000000}},	//   _luy_, ymsk, _fieb,
  { {0x69c90250,0x78a201e7,0x68ed004c,0x00000000}},	//   gkee, _prov, _žada,
  { {0x386d2bb7,0xe9370021,0xfd570063,0x00000000}},	//   guer_, رسيت_, _רשמי_,
  { {0xdb1a0066,0x8b26000d,0x290a008f,0x00000000}},	//   _loté, _здзе, āba_,
  { {0xdb08006c,0x386d0b0b,0xa5f92c1b,0x00000000}},	//   _ondé, auer_, дену_,
  { {0x78a238ab,0x386d0164,0x44322b36,0x00000000}},	//   _trov, buer_, _buy_,
  { {0xc4580076,0xb4cb0053,0x60100137,0x00000000}},	//   ниях_, लने_, vämn,
  { {0x26c50080,0x4432001b,0xdb1a00cd,0x00000000}},	//   bylo_, _duy_, _potè,
  { {0xa91d38ac,0xa5bb00ea,0x60100137,0x00000000}},	//   veži, tmód, tämn,
  { {0x9b170063,0x765a0203,0xdb1a0003,0x00000000}},	//   תחלה_, msty, _coté,
  { {0x765a38ad,0xdb1a0003,0x443218b9,0x00000000}},	// [62b0] lsty, _doté, _guy_,
  { {0x7c2f03b2,0xafdb00b9,0xdb0838ae,0x00000000}},	//   _écri, _støb, _endé,
  { {0xdfd8005a,0x6e29001c,0x69c900ac,0x00000000}},	//   хът_, _pieb, ykee,
  { {0xa2b60063,0x765a2cf8,0x28d90053,0x00000000}},	//   _ספרד_, isty, _बेझि,
  { {0xdd8e007e,0xeb9938af,0xfd740043,0x00000000}},	//   زوو_, дил_, ادمخ,
  { {0xf1bf008b,0x6b620001,0xf3ff017d,0x00000000}},	//   _hoá_, акша, irão_,
  { {0x6b9a001f,0x9f05007e,0x7d0900ac,0x00000000}},	//   _datg, _شورو, _wyes,
  { {0x765a328f,0x386d38b0,0xe628008b,0x00000000}},	//   dsty, tuer_, _chỗ_,
  { {0x69c903a8,0x87f9000d,0x26c5002b,0x00000000}},	//   rkee, дэнт_, wylo_,
  { {0x69c93281,0xf3ff03d9,0x765a00ac,0x00000000}},	//   skee, drão_, fsty,
  { {0xf3ff0016,0x4975000d,0x4432008b,0x00000000}},	//   erão_, _алес, _suy_,
  { {0x89370021,0x443238b1,0xf3ff00be,0x00000000}},	//   _أعضا, _puy_, frão_,
  { {0x386d38b2,0x4432008b,0xdb1c00ea,0x00000000}},	//   quer_, _quy_, özök,
  { {0x765a310b,0xd70538b3,0x59a90042,0x00000000}},	//   bsty, _изли, काकर,
  { {0xf3ff017d,0x63be0014,0x7df50022,0x00000000}},	//   arão_, _vopn, ząsa,
  { {0x4432001b,0x201800e5,0x016301e4,0x00000000}},	//   _tuy_, _shri_, иксо,
  { {0xe45a0088,0xf1bf001b,0xc9520063,0x00000000}},	// [62c0] _ўжо_, _giám_, ימן_,
  { {0xbea638b4,0x9f5f0014,0x69de013d,0x00000000}},	//   казк, ærða_, épez,
  { {0x66160080,0xdb1a004c,0x6b9a0244,0x00000000}},	//   ůzku, _toté, _ratg,
  { {0x2d8f004b,0xdb080331,0x6b4e0022,0x00000000}},	//   gege_, _undé, _mógł,
  { {0x2018002b,0xdf74007e,0x60100050,0x00000000}},	//   _thri_, _مگاب, lämm,
  { {0x64460006,0x765a38b5,0x20180050,0x00000000}},	//   ipki, ysty, _uhri_,
  { {0x7bca006f,0xa91d008f,0xa50f0042,0x00000000}},	//   rkfu, iežu, _सर्च_,
  { {0xf1bf008b,0x9874005e,0xa2b50053,0x00000000}},	//   _xoá_, глиц, _उपस्,
  { {0x3e7c38b6,0x0c2620cc,0x4c8500f2,0x00000000}},	//   lít_, _аман, _مؤلف,
  { {0x765a06a3,0x57b438b7,0x97a60cd6,0x00000000}},	//   tsty, убот, трил,
  { {0xdb0100b9,0x601000fe,0xa01b0137,0x00000000}},	//   _anlæ, jämm, _spök,
  { {0xf3ff017d,0x60100963,0xadf40053,0x00000000}},	//   trão_, dämm, ेकिन_,
  { {0x765a38b8,0x04c90021,0xdcef0023,0x00000000}},	//   ssty, روسي_, _ādīt,
  { {0xf3ff017d,0xed5900c2,0x765a38b9,0x00000000}},	//   rrão_, _moža_, psty,
  { {0x3e7c0080,0xf2c40245,0xd2500021,0x00000000}},	//   jít_, астн, ْنِ_,
  { {0xa3cf0235,0x64401bb7,0x3e7c10c9,0x00000000}},	//   _शतक_, ímic, dít_,
  { {0x248900c2,0xdb082329,0xf19404d6,0x00000000}},	// [62d0] _upam_, _kodó, шить,
  { {0xb4c10053,0xceeb01fb,0x753d013d,0x00000000}},	//   ूनी_, وران_, lcsz,
  { {0x69dc0006,0x3e7c00ea,0xc3320063,0x00000000}},	//   _įren, gít_, _לוי_,
  { {0x645d1b2d,0xdb080022,0x753d009c,0x00000000}},	//   ossi, _lodó, ncsz,
  { {0x4d640086,0x68ed0066,0x11da0063,0x00000000}},	//   рків, _ľado, _נחשב,
  { {0x2d8f0077,0xf0920063,0x3e7c1329,0x00000000}},	//   sege_, _הנך_, bít_,
  { {0xbed50001,0x2d8f00b9,0x09e538ba,0x00000000}},	//   _совј, pege_, локн,
  { {0x645d01e1,0xac74005d,0x8d77005d,0x00000000}},	//   kssi, _چالش, _جاسا,
  { {0x2ba4016a,0x6ce70086,0x7d0403ea,0x00000000}},	//   _गोवा, _ріве, üist,
  { {0x6d59367c,0x645d38bb,0xe45f0072,0x00000000}},	//   lawa, dssi, työn_,
  { {0xdb010016,0x7f55006d,0xa91d00c2,0x00000000}},	//   _colô, _mezq, vežu,
  { {0xb17b0137,0x6d5903f9,0xd46a0141,0x00000000}},	//   _smån, nawa, ниме_,
  { {0x7bc138bc,0x98790047,0x645d03d4,0x00000000}},	//   _kolu, _נאַט, gssi,
  { {0x6d593534,0x64460006,0xadc3008b,0x00000000}},	//   hawa, rpki, _khẳn,
  { {0x645d1b2d,0x29c3006d,0x6d5911c4,0x00000000}},	//   assi, _uñas_, kawa,
  { {0xdb0100c7,0x6d5938bd,0x7bc100ac,0x00000000}},	//   _inlä, jawa, _lolu,
  { {0x6d590045,0x26010053,0x387f06fd,0x00000000}},	// [62e0] dawa, रवरी_, ntur_,
  { {0x3e7c0080,0xa4b70063,0x7bc100ac,0x00000000}},	//   tít_, _עליה_, _nolu,
  { {0x9e660062,0x3f160002,0x25b7005d,0x00000000}},	//   увед, уќат, _شهید_,
  { {0x6d591acc,0x2bbe0053,0x387f38be,0x00000000}},	//   gawa, ्स्थ, ktur_,
  { {0xf1b30063,0x3e7c00ea,0xdd8f0021,0x00000000}},	//   _הסר_, sít_, ثون_,
  { {0x6606024a,0xafe638bf,0xda660021,0x00000000}},	//   hokk, _согл, هابي,
  { {0x387f007a,0xadc3001b,0x6d592983,0x00000000}},	//   etur_, _chẳn, bawa,
  { {0x387f0026,0x66060488,0xaa87007e,0x00000000}},	//   ftur_, jokk, انيم_,
  { {0xdb010502,0xd90d007e,0xdb0838c0,0x00000000}},	//   _anlä, ویم_, _indí,
  { {0xa09700b5,0x807b0047,0xdb01231d,0x00000000}},	//   נדיק_, עניצ, _polô,
  { {0xca75000d,0x35f50054,0xe5b5066e,0x00000000}},	//   _вучы, ипор, айны,
  { {0xd6d70928,0x645d2755,0x660638c1,0x00000000}},	//   уть_, tssi, gokk,
  { {0x7bc1005b,0xb4c10053,0xdb1a38c2,0x00000000}},	//   _yolu, ूने_, _motí,
  { {0x6d590035,0x645d003a,0xa91d0066,0x00000000}},	//   zawa, rssi, režt,
  { {0x66660062,0x6d591642,0x236c00ea,0x00000000}},	//   _сълз, yawa, ódja_,
  { {0xdb1a13ff,0x29d80025,0x66060150,0x00000000}},	//   _notí, _déag_, cokk,
  { {0x6e35007d,0x9f6b0499,0xdb010137,0x00000000}},	// [62f0] _suzb, ерез_, _inlå,
  { {0xdefb22c1,0x6aa806a9,0x6d400026,0x00000000}},	//   ные_, _ordf, _afma,
  { {0x7bc138c3,0x6d59170b,0xdb1a006d,0x00000000}},	//   _rolu, tawa, _botí,
  { {0x387f0026,0x5f240cf7,0x7bc10e55,0x00000000}},	//   ytur_, сфуз, _solu,
  { {0x6d5938c4,0x6aa80025,0x7bc138c5,0x00000000}},	//   rawa, _ardf, _polu,
  { {0x6d59053b,0x7aa50021,0xe45f0072,0x00000000}},	//   sawa, لإعل, isö_,
  { {0x6d59082c,0xda64007e,0xdd95007f,0x00000000}},	//   pawa, مايي, _кавы,
  { {0xc9a90432,0x7bd80019,0xdb1a017d,0x00000000}},	//   твие_, ahvu, _botâ,
  { {0xa922011c,0x66060072,0xbdf8007e,0x00000000}},	//   одъл, vokk, _صرفا_,
  { {0x77820055,0xadc3008b,0x387f38c6,0x00000000}},	//   ольз, _thẳn, rtur_,
  { {0x387f007a,0x644438c7,0x66061834,0x00000000}},	//   stur_, _stii, tokk,
  { {0x6606024a,0x29d80025,0x7d160051,0x00000000}},	//   uokk, _céad_, żyse,
  { {0x394d38c8,0x660638c9,0x89340049,0x00000000}},	//   mbes_, rokk, _اعما,
  { {0xb6a5019d,0x46a5000a,0xf745000a,0x00000000}},	//   _викл, _вакв, _теко,
  { {0x764302f0,0x3f930240,0xc5f9008f,0x00000000}},	//   _utny, dexu_, trēt_,
  { {0x386d0164,0xc5f9008f,0xc0460021,0x00000000}},	//   orer_, urēt_, لخطو,
  { {0x386d0f1b,0xc5f9008f,0x7f5a005e,0x00000000}},	// [6300] nrer_, arēs_, вјет_,
  { {0x8236006a,0xa2e62b4f,0x386d38ca,0x00000000}},	//   _پردا, _воод, irer_,
  { {0xed5a1485,0x386d00bd,0xdb1a0080,0x00000000}},	//   вое_, hrer_, _potí,
  { {0x25a00034,0x386d05dd,0x6e2200a4,0x00000000}},	//   _jail_, krer_, umob,
  { {0x386d00b9,0x25a038cb,0x6e2238cc,0x00000000}},	//   jrer_, _mail_, rmob,
  { {0x386d02ab,0x764804aa,0x6e2238cd,0x00000000}},	//   drer_, ypdy, smob,
  { {0x16060053,0xf1ca0053,0x386d38ce,0x00000000}},	//   रवार_, _रवान, erer_,
  { {0x386d38cf,0xdea4007e,0x298a012d,0x00000000}},	//   frer_, _پیچی, тско_,
  { {0xdb1a03d9,0x386d38d0,0x98b70062,0x00000000}},	//   _botã, grer_, илът_,
  { {0xf7b80001,0x1ae60ae8,0xc7c60062,0x00000000}},	//   угој_, _козм, рсии,
  { {0x64400014,0x394d2a60,0x25a038d1,0x00000000}},	//   ímin, bbes_, _bail_,
  { {0x386d1569,0x25d90121,0xa9670062,0x00000000}},	//   brer_, уммы_, _вица_,
  { {0x386d0003,0x25a0002b,0xd4c40092,0x00000000}},	//   crer_, _dail_, осрп,
  { {0x2bbe0042,0x15140054,0xd4070505,0x00000000}},	//   ्सटा, ідря, рями,
  { {0x25a038d2,0x82a40141,0xb8050044,0x00000000}},	//   _fail_, оште, _ابنه,
  { {0x25a00e6c,0x3ead38d3,0xe45f0050,0x00000000}},	//   _gail_, _čet_, psö_,
  { {0x7a350006,0x660d38d4,0x629a01e1,0x00000000}},	// [6310] _ište, _ikak, ætor,
  { {0x539938d5,0x337502a1,0xcea7005e,0x00000000}},	//   _своя_, _угор, ијеп,
  { {0x394d2106,0x2ca6003b,0xa195210d,0x00000000}},	//   ybes_, evod_, _ланч,
  { {0x386d31d4,0x237f017f,0xf2d200b5,0x00000000}},	//   yrer_, đuju_, _זעט_,
  { {0x61ed38d6,0xcb690a29,0x9b450021,0x00000000}},	//   mial, гале_, منشو,
  { {0x8234006a,0xdb1a00cd,0x386d1662,0x00000000}},	//   _دریا, _botà, vrer_,
  { {0xaa560001,0x7a350c61,0xdcfb007d,0x00000000}},	//   бију_, _ošte, _obuć,
  { {0x386d38d7,0x82f80063,0xadc30013,0x00000000}},	//   trer_, יצוב_, _thằn,
  { {0x25a00c2e,0x394d0269,0x386d3318,0x00000000}},	//   _rail_, rbes_, urer_,
  { {0x6010024a,0x3a870076,0x394d090d,0x00000000}},	//   tämi, _выдв, sbes_,
  { {0x61ed38d8,0x869801a4,0xa5bb38d9,0x00000000}},	//   kial, атят_, rmón,
  { {0xed5938da,0x386d01a8,0x6010026d,0x00000000}},	//   _jež_, prer_, rämi,
  { {0xb607007a,0xdb080139,0xe4690121,0x00000000}},	//   _sláð, _indá, ишёл_,
  { {0x660d004b,0xed590195,0x43431579,0x00000000}},	//   _ekak, _lež_, зерв,
  { {0x25a00780,0xa3e90053,0x216a3088,0x00000000}},	//   _tail_, _मगर_, ливи_,
  { {0x463a00b5,0xed590114,0x261938db,0x00000000}},	//   _געקע, _než_, léon_,
  { {0xdfcf007e,0xe3b20049,0x1f661b43,0x00000000}},	// [6320] کيل_, _فرد_, йкам,
  { {0x61ed004b,0x94bb009a,0xa819009a,0x00000000}},	//   aial, _עמית, אֵ֣י,
  { {0x61ed38dc,0x139b009a,0x5337009a,0x00000000}},	//   bial, _גביע, _לנין_,
  { {0x629e0117,0xdb1a231d,0x26190003,0x00000000}},	//   _ispo, _notá, héon_,
  { {0xed5900c2,0x447b0041,0x00000000,0x00000000}},	//   _dež_, ָנצע,   ,
  { {0x8f75000d,0x629e38dd,0x5043197b,0x00000000}},	//   _мусі, _kspo, _херб,
  { {0xdb1a006d,0xea8a007e,0x2619006c,0x00000000}},	//   _botá, اختن_, déon_,
  { {0x600b004b,0xf9920044,0x6df60044,0x00000000}},	//   lümp, سبع_, _اكرا,
  { {0x26cc002b,0xb17b05a5,0xd943005e,0x00000000}},	//   wydo_, _småk, чењи,
  { {0x660d021f,0x629e017f,0x61ed38de,0x00000000}},	//   _skak, _ospo, zial,
  { {0x5986000d,0x09e60121,0xadc30013,0x00000000}},	//   _глеб, _ложн, _chặn,
  { {0x89a50021,0x69db38df,0xca37009f,0x00000000}},	//   _وإنم, chue, _הנאה_,
  { {0x629e01d9,0x7a3500c2,0xdce2007d,0x00000000}},	//   _aspo, _všte, ogođ,
  { {0x07a3026c,0x6456002b,0x23e4000d,0x00000000}},	//   _начн, _dwyi, пісв,
  { {0xd7f8000c,0x98a4005b,0x82370021,0x00000000}},	//   mnă_, mamı_, إرسا,
  { {0x52150086,0xd0d50076,0x7a35007d,0x00000000}},	//   ідат, ообъ, _ušte,
  { {0x61ed38e0,0x629e20c1,0x94770049,0x00000000}},	// [6330] rial, _espo, _ادعا,
  { {0xdb1f00ea,0x61ed38e1,0x7df50078,0x00000000}},	//   űvés, sial, mąsi,
  { {0x60cd16bf,0xeeab000d,0x6e990133,0x00000000}},	//   syam, ытак_, рвер_,
  { {0xdb01017d,0xd7f8003b,0x067b0041,0x00000000}},	//   _falê, hnă_, רנאל,
  { {0x61fd006f,0xe0e4000d,0xdb01017d,0x00000000}},	//   _ijsl, _еўро, _galê,
  { {0xaa49000a,0xcac9005e,0xb17b00a5,0x00000000}},	//   апка_, игле_, _småh,
  { {0xdab9000d,0x443329bd,0x98a40058,0x00000000}},	//   рылі_, _mix_, damı_,
  { {0x3eae0146,0x39590014,0x68f60078,0x00000000}},	//   æfte_, úss_, _žyda,
  { {0xc795014c,0x6d5b002b,0x9be70054,0x00000000}},	//   орны, _ieua, _ліжк,
  { {0xf1bf0025,0x16650156,0xd7f8003b,0x00000000}},	//   _fhág_, овом, gnă_,
  { {0x6d5b00f3,0x7c3b38e2,0xf6260062,0x00000000}},	//   _keua, _huur, ждно,
  { {0xd7f8000c,0x8c3d005b,0x44331e92,0x00000000}},	//   ană_, _arşi, _aix_,
  { {0x7c3b047f,0x98f4000d,0x395f38e3,0x00000000}},	//   _juur, _няшч, maus_,
  { {0xa3e40053,0xd8b2007e,0xb8ed0053,0x00000000}},	//   पों_, _آموخ, रह_,
  { {0x44330164,0x7c3b0bda,0x232a032d,0x00000000}},	//   _dix_, _luur, рови_,
  { {0x443300cd,0x395f38e4,0x6d5b071c,0x00000000}},	//   _eix_, naus_, _neua,
  { {0x6ab60161,0x629e0051,0xb4db00cd,0x00000000}},	// [6340] _अप्र, _wspo, lcàn,
  { {0x395f38e5,0xdb0100be,0x1df40042,0x00000000}},	//   haus_, _valê, ेक्ष_,
  { {0x35af0053,0x629e38e6,0x69d9002b,0x00000000}},	//   _जोड़, _uspo, _olwe,
  { {0xbc4a0001,0x7c3b38e7,0x2cad1781,0x00000000}},	//   ачке_, _buur, _bred_,
  { {0x2cad38e8,0x629c001f,0x395f0c97,0x00000000}},	//   _cred_, lwro, daus_,
  { {0x7c3b016d,0xe0fb0063,0x69d938e9,0x00000000}},	//   _duur, _כלכל, _alwe,
  { {0x98a40058,0x291d0022,0x2cad1270,0x00000000}},	//   vamı_, _azwa_, _ered_,
  { {0x395f0006,0x8c4a0054,0xc8660f8d,0x00000000}},	//   gaus_, _впав_, отои,
  { {0x6141000f,0x2cad0302,0x98a40058,0x00000000}},	//   _háló, _gred_, tamı_,
  { {0xd7f8000c,0x7674130d,0x7df50078,0x00000000}},	//   ună_, плоф, vąsi,
  { {0x212700aa,0xd7f8000c,0x7c3b006f,0x00000000}},	//   ̀nh_, rnă_, _zuur,
  { {0x443304bc,0xb90a0856,0xd6d7000d,0x00000000}},	//   _six_, _кнез_, юты_,
  { {0x7a3538ea,0x7bc838eb,0xa3f80042,0x00000000}},	//   _išta, _kodu, ूकंप_,
  { {0x44330003,0x7df50078,0xa3ff004c,0x00000000}},	//   _qix_, rąsi, řeží_,
  { {0x386602ab,0x9f840026,0xd1eb0002,0x00000000}},	//   _hvor_, _röð_, аќал_,
  { {0x7a01008f,0x41e70085,0xd6db009a,0x00000000}},	//   pēte, ціга, _כחול,
  { {0xc05b0054,0x40590593,0x7bda38ec,0x00000000}},	// [6350] ріб_, صلاح_, _oltu,
  { {0x644f0994,0x7f5c0994,0x395f0078,0x00000000}},	//   mpci, _cerq, zaus_,
  { {0x7c3b0aba,0xdfd8005a,0x8db50086,0x00000000}},	//   _suur, цът_, зслі,
  { {0x4035005a,0x644f006f,0x2cad18c4,0x00000000}},	//   _немс, opci, _pred_,
  { {0x2fc7001b,0x395f0b4e,0xeb8e0988,0x00000000}},	//   ưng_, vaus_, ни_,
  { {0x7bc80529,0x7c3b0173,0xbb850021,0x00000000}},	//   _codu, _vuur, سلبي,
  { {0xaa560001,0xfbd0007e,0x6e3c16c4,0x00000000}},	//   пију_, ختن_, _gurb,
  { {0x2cad00f5,0x628701a8,0x78a9013d,0x00000000}},	//   _tred_, itjo, tvev,
  { {0x395f1a14,0x2cad007d,0x7bc8002b,0x00000000}},	//   raus_, _ured_, _fodu,
  { {0x7afc00c2,0x7bc838ed,0x3866339e,0x00000000}},	//   _žrte, _godu, _dvor_,
  { {0x3669005e,0x395f0656,0x3946002b,0x00000000}},	//   љамо_, paus_, _ffos_,
  { {0xdb010080,0x75f6008f,0xf990005d,0x00000000}},	//   _nalé, kšze, _لبه_,
  { {0x63a500bd,0xb9c40021,0x993a0063,0x00000000}},	//   _bahn, _تقني, _התנה,
  { {0xc879005b,0xdb0100cd,0xdb030066,0x00000000}},	//   muş_, _palè, edné,
  { {0xc87911f0,0xe1ff0014,0x8c1a0063,0x00000000}},	//   luş_, _bjó_, מושי,
  { {0x395d0034,0xdb011b84,0x2b8f005b,0x00000000}},	//   _jews_, _valè, lıcı_,
  { {0x7f5c0994,0xdb0800b9,0x63a5004d,0x00000000}},	// [6360] _perq, _indå, _fahn,
  { {0x2b8f01f7,0x6e3c04b5,0xe0d705f4,0x00000000}},	//   nıcı_, _purb, чву_,
  { {0xe3570149,0x7bc838ee,0xdd8f0085,0x00000000}},	//   _משיח_, _rodu, нш_,
  { {0xf41f00fe,0xd7f1008b,0xb2bb0063,0x00000000}},	//   ntän_, hĩ_, _המטר,
  { {0xc173014e,0xa116007e,0x7bc838ef,0x00000000}},	//   _אחר_, _روست, _podu,
  { {0x60100137,0x6e3c0897,0x5c970085,0x00000000}},	//   räms, _turb, якія_,
  { {0x29d80027,0x7bc838f0,0x6a130043,0x00000000}},	//   _déan_, _vodu, کبور,
  { {0xada30088,0x7bc800bd,0x3f9a2a2b,0x00000000}},	//   _пасл, _wodu, lepu_,
  { {0xeb36007e,0x9f4a01a8,0x29020058,0x00000000}},	//   _فراخ, _ambé_, çka_,
  { {0xf1bf001b,0x58370121,0x3b832124,0x00000000}},	//   _khác_, язья_, _плуг,
  { {0x916d0013,0x63a538f1,0x98b80058,0x00000000}},	//   hối_, _rahn, ğrı_,
  { {0x63a5005b,0xb8660021,0x7abb0063,0x00000000}},	//   _sahn, _فاتو, _לצבו,
  { {0x7df50078,0x63a538f2,0xba090044,0x00000000}},	//   mąst, _pahn, _بتلك_,
  { {0xd794005a,0x7a01001c,0x889b0063,0x00000000}},	//   _цикъ, mēta, _לבדי,
  { {0x764a0031,0x7a01001c,0xdb0138f3,0x00000000}},	//   _utfy, lēta, _palé,
  { {0xc2c40021,0x63a5004d,0x067b0aeb,0x00000000}},	//   ريقي, _wahn, _הנהל,
  { {0x63a500e3,0xd904006a,0x7a01001c,0x00000000}},	// [6370] _tahn, ای_, nēta,
  { {0xe9e20051,0x660f38f4,0x644d1358,0x00000000}},	//   leźć_, lock, _itai,
  { {0x3a3e0089,0xf1bf0013,0x7f45004d,0x00000000}},	//   _nutp_, _chác_, rchq,
  { {0x2b8f005b,0xf1bf008b,0x78a2007c,0x00000000}},	//   zıcı_, _giáp_, _osov,
  { {0x2b8f005b,0x0db80021,0x656d00a4,0x00000000}},	//   yıcı_, ثالث_, _mdah,
  { {0x3f9a003b,0x7a01008f,0x9f84004b,0x00000000}},	//   cepu_, dēta, _söö_,
  { {0xfaa2005a,0xf41f0072,0xa5bb0139,0x00000000}},	//   ващо, ytän_, amói,
  { {0xfaf0007e,0x60100c16,0xd2b80063,0x00000000}},	//   دثه_, lämp, ללות_,
  { {0x2b8f005b,0xc8c9007e,0x37750766,0x00000000}},	//   tıcı_, زودن_, мынс,
  { {0xe6450782,0x60c20072,0xc87918ad,0x00000000}},	//   меоп, äomi, ruş_,
  { {0x9f840004,0x38ca007e,0x644d38f5,0x00000000}},	//   _töö_, مایی_, _atai,
  { {0x7a350078,0x9e99014b,0x00000000,0x00000000}},	//   _išto, сцiр,   ,
  { {0x45d30088,0x60100832,0x7a01001c,0x00000000}},	//   тоўс, kämp, cēta,
  { {0x69cb0122,0x644d0027,0xf41f01e9,0x00000000}},	//   _hoge, _dtai, stän_,
  { {0x69cb0180,0x644d38f6,0x60100e77,0x00000000}},	//   _koge, _etai, dämp,
  { {0x69cb38f7,0xe45f0072,0xed591235,0x00000000}},	//   _joge, työt_, _kožu_,
  { {0x69cb38f8,0x799b0122,0x200700c2,0x00000000}},	// [6380] _moge, ieuw, čnin_,
  { {0x2497006a,0xe29a0001,0x69cb38f9,0x00000000}},	//   _کنید_, _дао_, _loge,
  { {0x7a01001c,0x69cb006f,0x0d860cb5,0x00000000}},	//   zēta, _ooge, длен,
  { {0x69cb010a,0xcf8900b5,0xd1fa009d,0x00000000}},	//   _noge, יט_, _וּ֝כ,
  { {0x958800eb,0xdca3012d,0x8c4304e3,0x00000000}},	//   _grąž, каци, вече,
  { {0xa91d0006,0xdb0813a3,0xf1bf008b,0x00000000}},	//   igžd, _indú, _thác_,
  { {0xb17b00b9,0x69cb38fa,0xda7a045b,0x00000000}},	//   _flåd, _boge, іяк_,
  { {0x69cb36e8,0xdde9007e,0x7a01001c,0x00000000}},	//   _coge, _فرقه_, tēta,
  { {0xcb6a02b6,0xfcaa0043,0x7189009d,0x00000000}},	//   _маае_, _بازو_, פְקַ,
  { {0x6d440024,0x7a01001c,0x2918001c,0x00000000}},	//   žiad, rēta, āra_,
  { {0x644d38fb,0x7a01001c,0xd491008b,0x00000000}},	//   _stai, sēta, ằm_,
  { {0xafdb00d1,0xd6d70121,0x7a01008f,0x00000000}},	//   _utøv, фть_, pēta,
  { {0x3a2600c7,0x443f001b,0xd94300e1,0x00000000}},	//   _ihop_, êu_, _речи,
  { {0x69cb102c,0xacd90047,0x660f38fc,0x00000000}},	//   _zoge, פֿרי, sock,
  { {0xa1950086,0x2607018e,0x60100072,0x00000000}},	//   навч, _очиг, vämp,
  { {0xdb1a0139,0x656d0130,0x8aab009d,0x00000000}},	//   _botú, _udah, חֹמֶ,
  { {0x644d0035,0x7bd80e41,0x60100137,0x00000000}},	// [6390] _utai, kkvu, tämp,
  { {0x25a90438,0xab630051,0x7a11004c,0x00000000}},	//   _haal_, ążka, mětř,
  { {0xf3ff017d,0x4ea4005e,0xdef10021,0x00000000}},	//   lsão_, крца, دًا_,
  { {0xc05b0086,0xbd4514d7,0x41d30082,0x00000000}},	//   _міг_, رنتي, _सविस,
  { {0xf3ff0016,0x25a91f79,0x644b11f5,0x00000000}},	//   nsão_, _maal_, _égid,
  { {0xd01b0002,0x7afc007d,0xf3ff017d,0x00000000}},	//   _ффм_, _žrta, isão_,
  { {0xb6060080,0x69cb38fd,0x8d7701f3,0x00000000}},	//   _hláš, _poge, _يارا,
  { {0xb6060114,0xa8550002,0x3a2638fe,0x00000000}},	//   _kláš, нтој, _chop_,
  { {0x799b001f,0x69cb2825,0xe8f938ff,0x00000000}},	//   reuw, _voge, яли_,
  { {0x612a00ea,0x2d9d3900,0x4bdb007e,0x00000000}},	//   lölé, lewe_, _ببرد_,
  { {0x69cb0037,0x998d0022,0x25a93901,0x00000000}},	//   _toge, tleń_, _baal_,
  { {0xa954019d,0xa50a315e,0x7a01008f,0x00000000}},	//   _акці, зема_, mēto,
  { {0x7a01001c,0x25a900ac,0xdce90080,0x00000000}},	//   lēto, _daal_, _odeč,
  { {0x07a20076,0xa91d005f,0x1876009a,0x00000000}},	//   _башн, rgžd, _נעצר_,
  { {0xb7da014e,0x41b609c2,0x7a01008f,0x00000000}},	//   _מקסי, нсат, nēto,
  { {0x09b50041,0x21a3089a,0x00000000,0x00000000}},	//   עפּט_, лисм,   ,
  { {0x6026000a,0xd02614db,0x41060054,0x00000000}},	// [63a0] едаа, емай, хзав,
  { {0x25a9006f,0x65663902,0x84570047,0x00000000}},	//   _zaal_, lakh, _רביס_,
  { {0xb17b10c4,0x2446001b,0xdb1a0003,0x00000000}},	//   _slåe, _hôm_, _entê,
  { {0x2d9d00e8,0xafdb07e6,0x443a3903,0x00000000}},	//   gewe_, _støt, _hip_,
  { {0xf1bf008b,0x61f6005b,0x443a3904,0x00000000}},	//   _khán_, miyl, _kip_,
  { {0xab940086,0x3a260b95,0xa5bb0139,0x00000000}},	//   тикі, _shop_, clóf,
  { {0x2d962fe9,0xed5a295e,0x3a2600a3,0x00000000}},	//   _прас, _нов_, _phop_,
  { {0x61f6005b,0x7e7e00c7,0xdb013905,0x00000000}},	//   niyl, mupp, _galí,
  { {0x7e7e3906,0x60d600fe,0x61e43907,0x00000000}},	//   lupp, nyym, ihil,
  { {0xa5bb3908,0x61f60058,0x25a93909,0x00000000}},	//   ológ, hiyl, _saal_,
  { {0x752400e3,0x7e7e00c7,0xd6d711ec,0x00000000}},	//   _aziz, nupp, етя_,
  { {0x7c3a0198,0x443a0006,0x7a250014,0x00000000}},	//   _hitr, _aip_, tóte,
  { {0x61e4390a,0x7e7e004d,0x66e600ea,0x00000000}},	//   dhil, hupp, _béké,
  { {0xf3ff03d9,0x443a390b,0xf1bf390c,0x00000000}},	//   rsão_, _cip_, _chán_,
  { {0xf3ff03d9,0x25a904c6,0xdce900c3,0x00000000}},	//   ssão_, _taal_, _rdeč,
  { {0xda100161,0x20070add,0x61e4390d,0x00000000}},	//   ावित_, čnim_, ghil,
  { {0x64400871,0x7a01008f,0x20980766,0x00000000}},	// [63b0] ímit, zēto, нкты_,
  { {0x251c00b5,0xdb01006d,0x61e4390e,0x00000000}},	//   _צוזא, _salí, ahil,
  { {0x61f6005b,0x63ad008f,0x661d13e4,0x00000000}},	//   biyl, ļinā, olsk,
  { {0x443a390f,0x61e43910,0xdb1a0005,0x00000000}},	//   _zip_, chil, _intè,
  { {0x2d9d00e8,0xdb030080,0xdb01029c,0x00000000}},	//   rewe_, rdní, _valí,
  { {0x443a00cd,0xeb960e6b,0x7c3a374b,0x00000000}},	//   _xip_, виш_, _citr,
  { {0x2fc70026,0x09e5055d,0x7c3a3911,0x00000000}},	//   öngu_, кокн, _ditr,
  { {0x7a01001c,0x6d560058,0x9e3412c1,0x00000000}},	//   rēto, ıyac, _бесч,
  { {0x7c3a014f,0x6d440024,0x656600ea,0x00000000}},	//   _fitr, žiac, vakh,
  { {0xa5bb0025,0x7d0900ac,0x661d3912,0x00000000}},	//   hlód, _ixes, elsk,
  { {0x65660397,0x6e3b0035,0xe7390002,0x00000000}},	//   takh, _kiub, ќен_,
  { {0x75e60022,0x7c3a1165,0x7a08004c,0x00000000}},	//   _mózg, _zitr, těte,
  { {0x656606a7,0xf1bf008b,0x3e410006,0x00000000}},	//   rakh, _phán_, _dėti_,
  { {0x387f1860,0x65663913,0x6b831c8d,0x00000000}},	//   muur_, sakh, ngng,
  { {0x61f6005b,0x443a3914,0x61e407c6,0x00000000}},	//   tiyl, _vip_, thil,
  { {0x66040035,0x69c91b20,0xdb0100cd,0x00000000}},	//   _ujik, njee, _malà,
  { {0xa0673915,0x61f601f7,0x7643002c,0x00000000}},	// [63c0] ката_, riyl, _huny,
  { {0x3fe32ff2,0xafdb04b1,0x61f6005b,0x00000000}},	//   ажув, _stør, siyl,
  { {0x7c3a051e,0x7d1b002c,0x69db00fe,0x00000000}},	//   _ritr, _ayus, kkue,
  { {0xdd8f0021,0x200100a4,0xdd900021,0x00000000}},	//   قوم_, anhi_, صوت_,
  { {0x6e3b003e,0x656400fe,0xdb1a3916,0x00000000}},	//   _diub, _meih, _inté,
  { {0x387f2187,0x65640333,0x6e29004d,0x00000000}},	//   duur_, _leih, _eheb,
  { {0x7ac3005a,0xdb0100cd,0x628e3917,0x00000000}},	//   исъе, _calà, ntbo,
  { {0x7c3a0045,0x2d820031,0xdb01017d,0x00000000}},	//   _witr, _øke_, _salã,
  { {0x7c3a03b2,0xab5c001c,0x387f0983,0x00000000}},	//   _titr, _soļu, guur_,
  { {0x7c3a0250,0x76431496,0x69db0072,0x00000000}},	//   _uitr, _buny, akue,
  { {0xdb0100cd,0x69c6112c,0x973c007d,0x00000000}},	//   _galà, ökes, jeće,
  { {0x973c017f,0x7a250051,0xa5bb017d,0x00000000}},	//   deće, rótc, emór,
  { {0x2955005a,0x661d3918,0x628e3919,0x00000000}},	//   _съхр, rlsk, etbo,
  { {0xdb0100ea,0xdb1a250d,0x20180150,0x00000000}},	//   _halá, _anté, _nkri_,
  { {0x179b0063,0x06270002,0xed5f0195,0x00000000}},	//   _חיוב, _ифим, ážka_,
  { {0x2918005b,0xd6d90086,0xdb030046,0x00000000}},	//   ğraf_, _яті_, ndná,
  { {0xdb01391a,0x2269005f,0x6e3b0023,0x00000000}},	// [63d0] _malá, _šukė_, _riub,
  { {0xa5bb0027,0xdefb0076,0xdb010137,0x00000000}},	//   slód, мые_, _inlö,
  { {0x387f006f,0x6f1c001f,0xf7730149,0x00000000}},	//   zuur_, _cyrc, שקע_,
  { {0xf1bf008b,0x6f1c002b,0xdb01004c,0x00000000}},	//   _khám_, _dyrc, _nalá,
  { {0xbc190088,0xf1bf0024,0x7a250014,0x00000000}},	//   нікі_, _iná_, jóta,
  { {0xe5040161,0x7a350006,0xdb0100cd,0x00000000}},	//   रपति_, _išti, _palà,
  { {0xfb840088,0xbe880001,0x6f1c002b,0x00000000}},	//   рычн, _исте_, _gyrc,
  { {0x387f0462,0x20120066,0xa819005d,0x00000000}},	//   tuur_, ľniť_, کتبر_,
  { {0x656400bd,0x75e60051,0x69c900fe,0x00000000}},	//   _reih, _józe, rjee,
  { {0x764306c2,0x68e90045,0x87b80076,0x00000000}},	//   _puny, rzed, вуют_,
  { {0x200716ea,0xdce00080,0xaa550d34,0x00000000}},	//   čnih_, _odmě, _свеш,
  { {0x26190164,0x7a250014,0xdb01391b,0x00000000}},	//   déos_, bóta, _galá,
  { {0x973c007d,0xdb1a0195,0x69c00042,0x00000000}},	//   veće, _motý, वारी,
  { {0x656400bd,0x644000cd,0x394d391c,0x00000000}},	//   _weih, ímiq, lces_,
  { {0x386d1c36,0x973c017f,0x7cea013d,0x00000000}},	//   lser_, teće, _köré,
  { {0x394d1e3e,0xafdb00d1,0x628e3140,0x00000000}},	//   nces_, _støp, rtbo,
  { {0x973c017f,0x386d391d,0xf4850002,0x00000000}},	// [63e0] reće, nser_, _куќн,
  { {0xd848001b,0x53a60001,0x5f760021,0x00000000}},	//   _học_, _саоб, طائر,
  { {0x394d0051,0xdb1a00a3,0x7a25013d,0x00000000}},	//   kces_, _antî, zóta,
  { {0xc27b00b5,0x386d02ab,0xa155005a,0x00000000}},	//   _ארטי, kser_, _върш,
  { {0x386d0146,0xd8480013,0xdb1a01c8,0x00000000}},	//   jser_, _mọc_, _dotý,
  { {0x386d0146,0xd848008b,0x2aaa0001,0x00000000}},	//   dser_, _lọc_, етио_,
  { {0xdb01391e,0x386d0244,0xdee604ef,0x00000000}},	//   _palá, eser_, _сови,
  { {0x98740c8d,0xdd920242,0x291d0022,0x00000000}},	//   алиц, _دور_, _bywa_,
  { {0x69470066,0xcd0614db,0x1d072530,0x00000000}},	//   dčeľ, _спай, _бети_,
  { {0x08970032,0x18970021,0x394d2839,0x00000000}},	//   اضيع_, اضية_, aces_,
  { {0xdb0103e8,0xd8480013,0x386d391f,0x00000000}},	//   _talá, _bọc_, aser_,
  { {0x1f370047,0x394d3920,0x5886000d,0x00000000}},	//   טריר_, cces_, _быка,
  { {0xa85600d7,0xd848008b,0xf5390066,0x00000000}},	//   _стеј, _dọc_, äť_,
  { {0xdce003f5,0x25ad38da,0xdd1c008f,0x00000000}},	//   _nemč, žel_, kšžo,
  { {0xdb0805ec,0x75280022,0x21e7004b,0x00000000}},	//   _indó, ędza, _lõhe_,
  { {0xf1bf008b,0x7a01008f,0x21550085,0x00000000}},	//   _thám_, vētk, ркаў,
  { {0xdff5005e,0xdfdb0062,0xdb01004d,0x00000000}},	// [63f0] апањ, нъж_, _unlö,
  { {0x1e0d0053,0x44270043,0xe8d7009d,0x00000000}},	//   िक्ष_, _حربف, אומר_,
  { {0xa195000d,0x141c009f,0x3f8f0022,0x00000000}},	//   _канч, _אוזב, ęgu_,
  { {0x6d440006,0xdd95000d,0x386d3921,0x00000000}},	//   žian, рады, yser_,
  { {0xd264001c,0xdb08005b,0xdb010075,0x00000000}},	//   _viņš_, _endü, _kalç,
  { {0x207a0047,0xdb1a017d,0x7a01008f,0x00000000}},	//   _באשא, _notó, mēti,
  { {0x7a01003d,0xda620071,0x9e350002,0x00000000}},	//   lēti, овщи, _вевч,
  { {0x386d3922,0x394d3923,0x28b10082,0x00000000}},	//   tser_, uces_, जिलि,
  { {0xdb1a048e,0x394d02a0,0x7a01008f,0x00000000}},	//   _botó, rces_, nēti,
  { {0xd8480013,0x386d0807,0x2cb80049,0x00000000}},	//   _sọc_, rser_, _حافظ_,
  { {0xe975007e,0x9f9600b9,0x386d2523,0x00000000}},	//   _نهاد, _væø_, sser_,
  { {0xdb0100b9,0x386d3924,0x19590895,0x00000000}},	//   _palæ, pser_, _рады_,
  { {0xdb1a3925,0x044612b9,0xb17b00a5,0x00000000}},	//   _fotó, регн, _plån,
  { {0xdb0104a5,0x443e0072,0xdb1a0022,0x00000000}},	//   _calç, öt_, _gotó,
  { {0x78bc008f,0x7a253926,0x644b006c,0x00000000}},	//   ārve, nóto, _égin,
  { {0x65bb00fe,0xd848008b,0x24f60086,0x00000000}},	//   _vähä, _họa_, _вчор,

  { {0x973c017f,0x7bc13927,0x64a6286a,0x00000000}},	// [6400] meća, _onlu, _тапа,
  { {0x65bb024a,0x7a35005f,0x2f5632e5,0x00000000}},	//   _tähä, _ištu, ртас,
  { {0x1eca005a,0x5d6a0076,0xbea6000d,0x00000000}},	//   ължи_, вием_, раек,
  { {0x629e0314,0x06960047,0x7a01008f,0x00000000}},	//   _ippo, ידעם_, bēti,
  { {0x9cf60001,0xa5bb00ea,0x66063928,0x00000000}},	//   јчеш, nlóa, inkk,
  { {0x3eab0072,0x6353004c,0x0bf30054,0x00000000}},	//   äitä_, mění, опію,
  { {0xb4db0268,0xe9e62953,0x7eb501eb,0x00000000}},	//   ncàr, ицио, _лётч,
  { {0x973c017f,0x394200d1,0xf41f12b8,0x00000000}},	//   jeća, øks_, ltät_,
  { {0x629e0150,0x63530080,0xc7c6268f,0x00000000}},	//   _lppo, nění, асни,
  { {0x387900ea,0xf41f00fe,0xc7d70076,0x00000000}},	//   ásra_, ntät_, имых_,
  { {0xd848008b,0x8c1b0063,0x09e60651,0x00000000}},	//   _dọa_, _יומי, _кожн,
  { {0xdb1a00cd,0xceb30aeb,0xc9831fc6,0x00000000}},	//   _fotò, קיר_, _души,
  { {0x53470138,0x69c200ac,0x6576002b,0x00000000}},	//   ихва, _inoe, _ddyh,
  { {0x7a01008f,0x66063929,0x07a30002,0x00000000}},	//   vēti, ankk, _мачн,
  { {0x25b000fe,0x973c007d,0xa16701ce,0x00000000}},	//   öllä_, beća, ињак,
  { {0x31c4019d,0x5187000a,0x7a250026,0x00000000}},	//   осув, јува, jótl,
  { {0xb4db01a8,0x4f6b05f4,0xdb03006c,0x00000000}},	// [6410] rcàs, вшем_, genê,
  { {0x7a01001c,0x3d1a0053,0xdb1a0530,0x00000000}},	//   rēti, _बड़े_, _antí,
  { {0xee87000d,0x442300b2,0x7a08004c,0x00000000}},	//   рызо, mlj_, větn,
  { {0x7a01008f,0x6e22392a,0xce180083,0x00000000}},	//   pēti, glob, аціі_,
  { {0x442300c3,0xf3f0007e,0x4c84000d,0x00000000}},	//   olj_, _رأی_, жлів,
  { {0xdfd80062,0x92b4005d,0x3b090f56,0x00000000}},	//   _къс_, _احیا, лело_,
  { {0x6fc40053,0x7eb000ea,0x4423392b,0x00000000}},	//   रारू, rópá, ilj_,
  { {0xf9910021,0x2cac0072,0x3ebe0014,0x00000000}},	//   سبب_, ähdä_, _átta_,
  { {0x973c0117,0x7a08004c,0xe9a80021,0x00000000}},	//   veća, pětn, شدين_,
  { {0xdb0100bd,0x7d040025,0x7d1e0051,0x00000000}},	//   _palä, úise, ępst,
  { {0x38c10026,0x7cfd06a5,0x38ca007e,0x00000000}},	//   færð_, _færø, نایی_,
  { {0x5a350001,0xda65005d,0xe57a0085,0x00000000}},	//   _унет, _ناچي, ызм_,
  { {0xf41f00fe,0x7989120a,0xd848008b,0x00000000}},	//   ytät_, mgew, _tọa_,
  { {0xf8b6014e,0xb05b0c38,0x973c007d,0x00000000}},	//   _לפני_, _kräf, seća,
  { {0xfbd20063,0x6383000d,0x973c0130,0x00000000}},	//   לתך_, ягра, lećn,
  { {0x68ec005b,0xb14606be,0x798911a9,0x00000000}},	//   _öldü, снал, ngew,
  { {0xb4db0268,0x600a0699,0x25fd0042,0x00000000}},	// [6420] scàr, гнам_, _लगती_,
  { {0x798900bd,0x7a01008f,0xdb18004c,0x00000000}},	//   hgew, mētu, ejvý,
  { {0x6e221253,0x6d440006,0xa136007e,0x00000000}},	//   tlob, žiam, _گردش,
  { {0x798902b0,0x7a08004c,0xc3330063,0x00000000}},	//   jgew, věto, _מות_,
  { {0x973c007d,0x6e22392c,0xa1360021,0x00000000}},	//   jećn, rlob, _دردش,
  { {0x69c2006f,0x6281392d,0x7989083f,0x00000000}},	//   _snoe, álog, egew,
  { {0xeaaf0021,0x224200d1,0x200f0003,0x00000000}},	//   فعي_, _kikk_, égie_,
  { {0x7989392e,0xf1bf008b,0xd8480013,0x00000000}},	//   ggew, _phái_, _dọn_,
  { {0x8b960b3f,0x29d80139,0x2242004b,0x00000000}},	//   _греч, _béar_, _mikk_,
  { {0x22420031,0x29d80139,0xf69802d8,0x00000000}},	//   _likk_, _péas_, авој_,
  { {0x501b0063,0x38c10026,0xf41f0137,0x00000000}},	//   רויו, tærð_, ktär_,
  { {0xdb1a03d9,0xdce0003d,0xf1bf001b,0x00000000}},	//   _entã, _zemā, _thái_,
  { {0xa5bb0024,0x999f005b,0x39460150,0x00000000}},	//   blón, lmuş_, _igos_,
  { {0x29d80139,0x48130054,0xf64f005d,0x00000000}},	//   _géar_, _еміс, بئی_,
  { {0x7a3500eb,0x9f5a0003,0xdb030110,0x00000000}},	//   _ištr, cipé_, genè,
  { {0x224200ea,0xbbb40042,0xc693009d,0x00000000}},	//   _cikk_, ंयुक, _זאק_,
  { {0x7a080080,0x656f2ae9,0x4fd510f6,0x00000000}},	// [6430] větl, mach, ожат,
  { {0x645d01e3,0x752d017f,0x656f392f,0x00000000}},	//   mpsi, _izaz, lach,
  { {0x22420031,0x394600e3,0x61e3000c,0x00000000}},	//   _fikk_, _ogos_, _înlo,
  { {0x22420031,0x63a70045,0x656f3930,0x00000000}},	//   _gikk_, lejn, nach,
  { {0x7a35017f,0x628709d5,0xdb1a00cd,0x00000000}},	//   _oštr, lujo, _antà,
  { {0x62870164,0x3946001f,0xb05b00bd,0x00000000}},	//   oujo, _agos_, _präf,
  { {0x61ed0019,0x79891203,0x973c007d,0x00000000}},	//   ohal, tgew, dećo,
  { {0x61ed3931,0x6295006f,0x26de0006,0x00000000}},	//   nhal, itzo, dyto_,
  { {0x2cad0037,0x76580006,0x798905e4,0x00000000}},	//   _used_, _atvy, rgew,
  { {0xb05b00c7,0x656f1202,0x316b0051,0x00000000}},	//   _träf, each, _lecz_,
  { {0x63a73932,0x656f00bd,0x7afc027c,0x00000000}},	//   dejn, fach, _žrtv,
  { {0x656f0027,0x62870891,0x55f6000d,0x00000000}},	//   gach, dujo, ічну,
  { {0x61ed10ca,0x9c820080,0x3e48005b,0x00000000}},	//   dhal, _účte, _işte_,
  { {0x316000e3,0x7a01008f,0x682f04aa,0x00000000}},	//   wbiz_, rētu, føde,
  { {0xf6d5000d,0x22420019,0x656f3933,0x00000000}},	//   _філя, _pikk_, bach,
  { {0x320900bb,0x656f3934,0x41aa0141,0x00000000}},	//   gnay_, cach, јван_,
  { {0x62870078,0x201a2479,0xdb0104a5,0x00000000}},	// [6440] aujo, topi_, _calú,
  { {0xb4e60161,0x6287006d,0x63a70080,0x00000000}},	//   पनी_, bujo, cejn,
  { {0x4d4a036a,0x201a01b3,0x61ed3935,0x00000000}},	//   апен_, ropi_, bhal,
  { {0x44443936,0xdb0801c2,0xdce0003b,0x00000000}},	//   _hi_, _nadá, _nemă,
  { {0x44443937,0xa6de008b,0xf1bf008b,0x00000000}},	//   _ki_, _ngưn, _cháu_,
  { {0x2ca914b1,0x27160080,0xdb1a00f8,0x00000000}},	//   çada_, něné_, _antá,
  { {0xb05b0832,0xb17b00d1,0x61e40072,0x00000000}},	//   _präg, _blåh, okil,
  { {0x61e40bcf,0x7a250025,0xdb080460,0x00000000}},	//   nkil, nóth, _cadá,
  { {0x98a30001,0x61e40026,0x62871035,0x00000000}},	//   диње, ikil, zujo,
  { {0xc7b8017f,0x660d0f4e,0x44443938,0x00000000}},	//   kođe_, _sjak, _ni_,
  { {0xb05b00bd,0x61ed0024,0xf1bf0013,0x00000000}},	//   _träg, yhal, _khát_,
  { {0x2fd80027,0x656f0025,0x69a10053,0x00000000}},	//   _lorg_, uach, _कॉपी,
  { {0x44443939,0x63a70080,0x656f393a,0x00000000}},	//   _bi_, tejn, rach,
  { {0xdb082f42,0x68ec005b,0x682f00b9,0x00000000}},	//   _zadá, ıldı, tøde,
  { {0x63a7034d,0x4444393b,0x6fc90161,0x00000000}},	//   rejn, _di_, रासं,
  { {0x244f01f7,0x320900a4,0x629500bd,0x00000000}},	//   _tüm_, unay_, rtzo,
  { {0x4444393c,0x61ed393d,0xdb030066,0x00000000}},	// [6450] _fi_, rhal, rené,
  { {0x4444393e,0x61e400a4,0x61ed393f,0x00000000}},	//   _gi_, akil, shal,
  { {0xdb0a007a,0x644d0025,0x656d014f,0x00000000}},	//   ldfæ, _huai, _keah,
  { {0x6445002c,0x661d00fe,0x44443940,0x00000000}},	//   _hihi, nosk, _zi_,
  { {0xe7bc0161,0x444401f7,0x64453941,0x00000000}},	//   ्ञाप, _yi_, _kihi,
  { {0x68e0002b,0xdce0003b,0xdb080195,0x00000000}},	//   dymd, _semă, _sadá,
  { {0x644d0027,0x644500fe,0x539c0149,0x00000000}},	//   _luai, _mihi, יסגא,
  { {0x2fd80122,0xb05b00c7,0x6445002c,0x00000000}},	//   _zorg_, _träd, _lihi,
  { {0x644d0027,0xafdb00d1,0x661d3942,0x00000000}},	//   _nuai, _støy, dosk,
  { {0xbca40021,0xe8f6000d,0x64451aac,0x00000000}},	//   _تمكي, ялы_, _nihi,
  { {0xdb1a0016,0x44443943,0x61e40026,0x00000000}},	//   _botõ, _ri_, ykil,
  { {0x20010009,0x644d0025,0x64a6000d,0x00000000}},	//   hihi_, _buai, пама,
  { {0x644d0027,0xb4e60161,0x644500a4,0x00000000}},	//   _cuai, पने_, _bihi,
  { {0x69d90037,0x29240024,0x20010035,0x00000000}},	//   _howe, ísať_, jihi_,
  { {0x61e401f7,0x6445014f,0x232a06b4,0x00000000}},	//   tkil, _dihi, сови_,
  { {0x644d0027,0x6d490025,0x799b001f,0x00000000}},	//   _fuai, _ngea, nfuw,
  { {0x61e43944,0x44443945,0x24530021,0x00000000}},	// [6460] rkil, _ti_, _كنيس,
  { {0x69d90034,0x61fd0019,0xd12f0021,0x00000000}},	//   _lowe, _emsl, امك_,
  { {0xf1bf20fc,0xcf25007e,0x61e40058,0x00000000}},	//   _phát_, ورمي, pkil,
  { {0x69d90045,0x2cbf102d,0x224c004c,0x00000000}},	//   _nowe, _brud_, ídku_,
  { {0x91bb0063,0x2001053b,0x5d1a0021,0x00000000}},	//   _המכי, bihi_, حتاج_,
  { {0xf1bf0025,0x2cbf002b,0x7a08004c,0x00000000}},	//   _fhás_, _drud_, měti,
  { {0xb05b004d,0x6fc90053,0xf1bf0139,0x00000000}},	//   _gräb, रारं, _ghás_,
  { {0x5eeb0063,0x69d93946,0xa5bb013d,0x00000000}},	//   _הַמְ, _cowe, alój,
  { {0x69dd004b,0x661d0050,0x69d90168,0x00000000}},	//   ösea, vosk, _dowe,
  { {0x25a00019,0x644d0139,0x68e03947,0x00000000}},	//   _abil_, _ruai, rymd,
  { {0x212700aa,0xdc3b0047,0x47341b79,0x00000000}},	//   ́nh_, _פעבר, ьнос,
  { {0x64453948,0x69d93949,0xe9470043,0x00000000}},	//   _sihi, _gowe, _فرهی,
  { {0x644d03d9,0x644519fb,0xe4c70121,0x00000000}},	//   _quai, _pihi, чённ,
  { {0x69d90122,0x493b014e,0x661d0019,0x00000000}},	//   _zowe, _הגדו, sosk,
  { {0x661d0240,0x35f50002,0x7bda2ed8,0x00000000}},	//   posk, _опкр, _motu,
  { {0x644d0027,0xdb1a00c7,0x7a25017d,0x00000000}},	//   _tuai, _intä, tóti,
  { {0xc05b0086,0x7bda0019,0x7bc8394a,0x00000000}},	// [6470] сіб_, _ootu, _ondu,
  { {0x4427394b,0x8fa4005e,0x7bda394c,0x00000000}},	//   _ón_, нађе, _notu,
  { {0x200101f7,0xdfd8005a,0xce590002,0x00000000}},	//   rihi_, чът_, цаец_,
  { {0x2ca90016,0x20010ebe,0x2cbf006c,0x00000000}},	//   çado_, sihi_, _prud_,
  { {0xee38019d,0xd59c0047,0xb17b02fd,0x00000000}},	//   їні_, מבאל, _blåv,
  { {0x69d9394d,0xda650021,0xb05b0137,0x00000000}},	//   _sowe, واعي, _träb,
  { {0x75280045,0x69d90fc5,0xee840121,0x00000000}},	//   ędzi, _powe, _пыто,
  { {0x7bc80b9c,0x08c500e1,0x2cbf394e,0x00000000}},	//   _endu, дбин, _trud_,
  { {0x69d90034,0xf8a9007e,0x8b47005d,0x00000000}},	//   _vowe, تگاه_, _فضان,
  { {0xd7090076,0xdb03394f,0xcb68005e,0x00000000}},	//   жное_, lení, _нађе_,
  { {0x69d904ff,0x2d8f06a5,0xda08005d,0x00000000}},	//   _towe, ogge_, _کينه_,
  { {0xf3e9014e,0xae000161,0xdb030066,0x00000000}},	//   _דף_, लोपन_, není,
  { {0x6d442e3e,0xab04004b,0x7ae33950,0x00000000}},	//   žiav, öövä, lynt,
  { {0x33d50101,0x68e605e7,0x7a08004c,0x00000000}},	//   ніст, økde, věti,
  { {0x044331ab,0x75e60022,0xd808009a,0x00000000}},	//   терн, _józk, _מִקָ,
  { {0xdb03027d,0x25a01035,0x163a00de,0x00000000}},	//   jení, _ubil_, _بستة_,
  { {0xdb030240,0x63b73951,0xdb1a0137,0x00000000}},	// [6480] dení, _faxn, _intå,
  { {0x2d8f3952,0xdfa60021,0xdee60074,0x00000000}},	//   egge_, بحري, мози,
  { {0xb05b004d,0x01660121,0x7bda3953,0x00000000}},	//   _präc, _окно, _rotu,
  { {0x7ae30072,0x2d920058,0x7bda3954,0x00000000}},	//   dynt, üye_, _sotu,
  { {0x3ead0117,0xc173014e,0x68ed0045,0x00000000}},	//   _ćete_, _בחר_, _żadn,
  { {0x2ac60001,0x69dd0d88,0x2d8f0290,0x00000000}},	//   дљив, ösen, agge_,
  { {0x160e0161,0x7ae30031,0x7bda000c,0x00000000}},	//   ाचार_, gynt, _votu,
  { {0x80b50053,0xdb03004c,0xa5bb013d,0x00000000}},	//   _उनमे, cení, rlók,
  { {0x7bda33db,0xad26007e,0x3942004b,0x00000000}},	//   _totu, _آرزو, äks_,
  { {0x7bc83955,0xcbc6005d,0x0137009a,0x00000000}},	//   _undu, _تزري, ורפת_,
  { {0xeb970086,0xd848001b,0x17f70021,0x00000000}},	//   _цих_, _mọi_, برية_,
  { {0x6d440006,0x7c2a35bd,0xf1bf0013,0x00000000}},	//   žiau, llfr, _nháp_,
  { {0xdb01004a,0xdca60021,0xe6c6005d,0x00000000}},	//   _malý, دى_, ستگي,
  { {0x7a13000c,0xdb03004a,0xf907005d,0x00000000}},	//   măta, zení, _تأمی,
  { {0x07a30259,0x7c2a3956,0x2d8f0246,0x00000000}},	//   _рајн, ilfr, ygge_,
  { {0x973c017f,0x7a250046,0xdd31056c,0x00000000}},	//   jeći, bótu, tężo,
  { {0xc34b0088,0x973c017f,0x7a13000c,0x00000000}},	// [6490] _мяне_, deći, năta,
  { {0x7ae300fe,0x5fc90053,0xceeb0242,0x00000000}},	//   yynt, राइल, يران_,
  { {0xb17b073a,0xdb033957,0xa1590054,0x00000000}},	//   _blåt, tení, _нану_,
  { {0x7bde0014,0x8c950054,0xbdf80044,0x00000000}},	//   öpun, еркі, ورنا_,
  { {0xdb030024,0x7ae3001f,0x2d9d00ac,0x00000000}},	//   rení, wynt, rfwe_,
  { {0x9f5a00cd,0x7ae30072,0xdb0301c8,0x00000000}},	//   cipà_, tynt, sení,
  { {0xd848001b,0xb17b00d1,0x3ce9085a,0x00000000}},	//   _gọi_, _flåt, šav_,
  { {0x628700fe,0x030d008b,0xc7b8007d,0x00000000}},	//   irjo, _đều_, vođa_,
  { {0x6d5b0035,0x7c150086,0xa5bb0025,0x00000000}},	//   _ifua, _здає, clói,
  { {0x660f0022,0x3ce0004e,0xead53958,0x00000000}},	//   enck, äive_, _позь,
  { {0x6d440078,0x7a08004c,0x66e50085,0x00000000}},	//   žiat, větv, хона,
  { {0x98a000eb,0x6d5900ac,0x2bc70053,0x00000000}},	//   _šią_, ncwa, लाका,
  { {0x8cc20053,0x69cb08ce,0xe8ee006e,0x00000000}},	//   लियो, _inge, _сл_,
  { {0xb6020080,0xe787000d,0x973c007d,0x00000000}},	//   _žáda, _цудо, zeći,
  { {0xf1bf001b,0x67ed0014,0xd348005d,0x00000000}},	//   _pháp_, _gúja, بیده_,
  { {0x3ebe0026,0xd8480013,0x8cc20042,0x00000000}},	//   _átti_, _rọi_, लिमो,
  { {0x628700fe,0x66063959,0x04570021,0x00000000}},	// [64a0] arjo, mikk, _كلية_,
  { {0xb17b1699,0x6606395a,0x900a0044,0x00000000}},	//   _slåt, likk, أزرق_,
  { {0xf1bf008b,0x69cb1104,0xb17b0137,0x00000000}},	//   _tháp_, _onge, _plåt,
  { {0x628e00a4,0x6d5900ac,0x66060d68,0x00000000}},	//   mubo, gcwa, nikk,
  { {0xdb030024,0x628e395b,0x66060072,0x00000000}},	//   rdný, lubo, iikk,
  { {0x660610f7,0x628e0080,0xa5bb0405,0x00000000}},	//   hikk, oubo, rlói,
  { {0x628e395c,0x629c395d,0x7c2a00e5,0x00000000}},	//   nubo, ntro, rlfr,
  { {0xf2d30063,0x66061c1e,0x7e9b0063,0x00000000}},	//   רעה_, jikk, _מסלו,
  { {0x628e395e,0x8c950097,0xbc6a007e,0x00000000}},	//   hubo, _архі, _رمان_,
  { {0x69cb395f,0x63ae00d1,0x7a13003b,0x00000000}},	//   _enge, jebn, răta,
  { {0x63ae0080,0x8c1b0047,0x66063960,0x00000000}},	//   debn, _צובי, fikk,
  { {0x7a13003b,0x63bc00c2,0x7a490003,0x00000000}},	//   păta, edrn, rêtè,
  { {0xdb03027d,0x7a250026,0x37e62254,0x00000000}},	//   mená, rótt, _подг,
  { {0x63ae0199,0x6606024a,0xb05b3961,0x00000000}},	//   gebn, aikk, _brän,
  { {0xdbc70019,0x31c7000d,0x17570063,0x00000000}},	//   _töös, нсав, _אסור_,
  { {0x660600ea,0xd49b005e,0xb05b0ae2,0x00000000}},	//   cikk, _еро_, _drän,
  { {0xb17b0829,0x629c3962,0xc61d0042,0x00000000}},	// [64b0] _slås, atro, नवीय_,
  { {0x629c307e,0xb05b0e77,0xb17b00a5,0x00000000}},	//   btro, _frän, _plås,
  { {0xb05b01e3,0x4423017f,0x3ea700cd,0x00000000}},	//   _grän, moj_, ïnt_,
  { {0x31790047,0x44233963,0x127a0047,0x00000000}},	//   _קאָד, loj_, _קארע,
  { {0x672a0026,0x973c007d,0xa176016e,0x00000000}},	//   _lyfj, meću, _בערד_,
  { {0x44230117,0x224b0509,0xe0df0013,0x00000000}},	//   noj_, _hick_, _ngòi_,
  { {0x3da70088,0xdea4006a,0x224b3964,0x00000000}},	//   _праб, _میلی, _kick_,
  { {0x6d5b0035,0x63ae0051,0xdb013965,0x00000000}},	//   _ufua, zebn, _saló,
  { {0x4423065f,0xbcdb0021,0x6d440066,0x00000000}},	//   koj_, _عذرا_, žiar,
  { {0x44230117,0x66060162,0x3ddf0150,0x00000000}},	//   joj_, wikk, _houw_,
  { {0x3dcd0034,0x66063966,0xdb013967,0x00000000}},	//   _knew_, tikk, _való,
  { {0x7a130529,0xdce00080,0x3ddf0122,0x00000000}},	//   măto, _nemě, _jouw_,
  { {0x63ae02f4,0x7a13000c,0xf41f03c8,0x00000000}},	//   tebn, lăto, rrän_,
  { {0x629c175f,0x66063968,0x442301b3,0x00000000}},	//   ttro, sikk, goj_,
  { {0x7a13000c,0x629c0016,0x63ae04d9,0x00000000}},	//   năto, utro, rebn,
  { {0x63ae06bb,0x212b0080,0x629c2943,0x00000000}},	//   sebn, _bych_, rtro,
  { {0x628e002c,0xdb180066,0x4423306e,0x00000000}},	// [64c0] subo, rdvé, boj_,
  { {0xb05b0502,0x212b3969,0x3dcd00e5,0x00000000}},	//   _trän, _dych_, _anew_,
  { {0x224b01e3,0x3ddf0122,0x6e220019,0x00000000}},	//   _fick_, _bouw_, toob,
  { {0x224b01e3,0x98b1004c,0xb05b0137,0x00000000}},	//   _gick_, íběh_, _kräl,
  { {0xdb0a0146,0x22400019,0x3212396a,0x00000000}},	//   ldfø, mmik_, mnyy_,
  { {0xdce00080,0x3a260089,0x7a350078,0x00000000}},	//   _země, _skop_, _išty,
  { {0x63a3000f,0x7a13000c,0xdb0a00b9,0x00000000}},	//   _önne, găto, ndfø,
  { {0x7a080080,0xa9c30086,0x21e7004b,0x00000000}},	//   věts, аськ, _põhi_,
  { {0xdca60079,0xf1bf013d,0x1c46239d,0x00000000}},	//   _јази, _okán_, _анам,
  { {0x6604000f,0x394f0034,0x7a13003b,0x00000000}},	//   _amik, _eggs_, băto,
  { {0x7a13000c,0x442324a3,0x98a3008f,0x00000000}},	//   căto, voj_, ājā_,
  { {0x6f0313a8,0x3ebe0026,0x628100ea,0x00000000}},	//   únci, _áttu_, álom,
  { {0x4423025d,0xdb0a01e1,0xd8480013,0x00000000}},	//   toj_, edfø, _bọt_,
  { {0x224b0be9,0xa295000d,0x44230078,0x00000000}},	//   _sick_, лагі, uoj_,
  { {0x224b0034,0xf8370063,0x4423114b,0x00000000}},	//   _pick_, _שנות_, roj_,
  { {0x52140088,0xb05b00c7,0xed5901b3,0x00000000}},	//   адст, _fräl, _kaže_,
  { {0xcf9b0001,0x7a13003b,0x973c007d,0x00000000}},	// [64d0] дје_, zăto, reću,
  { {0x61440001,0x973c007d,0x224000c2,0x00000000}},	//   ређа, seću, amik_,
  { {0xdb030994,0x212b001f,0xed590077,0x00000000}},	//   menç, _wych_, _laže_,
  { {0xed58019d,0x212b0045,0x7c3a004b,0x00000000}},	//   вої_, _tych_, _ahtr,
  { {0xdb03017d,0xdd94000d,0x61ed396b,0x00000000}},	//   oenç, рачы, mkal,
  { {0x7a13000c,0xdb0300cd,0x61ed396c,0x00000000}},	//   tăto, nenç, lkal,
  { {0x3ddf006f,0x7a08004c,0xab263774,0x00000000}},	//   _touw_, větr, лоша_,
  { {0xdb1a0268,0x7a13000c,0xc5f9001c,0x00000000}},	//   _matè, răto, spēj_,
  { {0x7a13000c,0x7c2300e5,0x9d150121,0x00000000}},	//   săto, ponr, _сдач,
  { {0x7a13000c,0xdb030026,0xa7b50d34,0x00000000}},	//   păto, venæ, усиј,
  { {0x764d00f3,0x61ed396d,0xd70508a8,0x00000000}},	//   _biay, kkal, узни,
  { {0x21e7004b,0x443a396e,0xb05b0244,0x00000000}},	//   _kõhu_, _shp_, _präl,
  { {0x443a396f,0x07a50062,0xc7a50601,0x00000000}},	//   _php_, _балн, _билк,
  { {0xdc3500b5,0x61ed3970,0xec350047,0x00000000}},	//   טאָט_, ekal, טאָר_,
  { {0x68e93971,0xd8480013,0x479a0aeb,0x00000000}},	//   lyed, _vọt_, _ניקס,
  { {0x61ed002c,0x69db006d,0x66043972,0x00000000}},	//   gkal, njue, _umik,
  { {0x68e90974,0xb05b00c7,0xa5bb00ea,0x00000000}},	// [64e0] nyed, _främ, alós,
  { {0xdb030016,0x442e006f,0xcef60002,0x00000000}},	//   cenç, _óf_, лчењ,
  { {0x61f63973,0x65763974,0x139b0149,0x00000000}},	//   phyl, _keyh, _אביע,
  { {0x6e3b3975,0xed5a0371,0x63be004b,0x00000000}},	//   _chub, ход_, _hapn,
  { {0xa0750076,0x63be00ea,0x0cd402a1,0x00000000}},	//   _высш, _kapn, ролю,
  { {0x7ff60021,0xdb1a10c9,0xdb030050,0x00000000}},	//   _إسحا, _haté, kenä,
  { {0x60c40016,0x63be0717,0xda4a0121,0x00000000}},	//   lvim, _mapn, нчил_,
  { {0x5a34000a,0x24800c61,0x60c43976,0x00000000}},	//   јнит, _ovim_, ovim,
  { {0xdb1a1676,0x2733008b,0x20180150,0x00000000}},	//   _maté, _ạn_, _kjri_,
  { {0xdb1a3977,0xca76000d,0xdb0300cd,0x00000000}},	//   _laté, _буды, xenç,
  { {0x26c7007d,0xdb033978,0xa5f9005e,0x00000000}},	//   _crno_, venç, вену_,
  { {0xdb0a0016,0x60c4005b,0xa5bb017d,0x00000000}},	//   nefí, kvim, coól,
  { {0xdb030016,0xdb1a00cd,0xb05b004d,0x00000000}},	//   tenç, _satè, _präm,
  { {0xe454014c,0x89370085,0x7bde0072,0x00000000}},	//   скры, _спіс_, öpuh,
  { {0xdb030367,0xdb1a175e,0x3f870014,0x00000000}},	//   renç, _baté, ónum_,
  { {0x67380117,0xdb1a0164,0xdb030016,0x00000000}},	//   _izvj, _caté, senç,
  { {0x623400d7,0x15a80062,0xdb1a1eff,0x00000000}},	// [64f0] сету, _същи_, _daté,
  { {0x61ed08c4,0xa5bb0139,0x6aba004d,0x00000000}},	//   skal, clór, _ostf,
  { {0x60c43716,0x6e990c0b,0x7d550062,0x00000000}},	//   avim, твер_, авех,
  { {0x63be0240,0x6b9c0014,0x867b009a,0x00000000}},	//   _zapn, _örgj, תראו,
  { {0x6aba0529,0x317a016e,0xeb99350e,0x00000000}},	//   _astf, _בארד, вил_,
  { {0xda650601,0xa3cb0042,0x8c451528,0x00000000}},	//   авки, _रोम_, шеле,
  { {0x6e3b0035,0x69c0006f,0x6ff40022,0x00000000}},	//   _thub, fdme, yńcz,
  { {0x09e52254,0xdb030072,0x68f60022,0x00000000}},	//   роин, venä, _żyda,
  { {0xdb0301e1,0x682f05e7,0xf771002a,0x00000000}},	//   denå, lødi, ياد_,
  { {0xd7e60076,0xdb030ff2,0x69c03979,0x00000000}},	//   имые_, tenä, adme,
  { {0x2480017f,0x64560150,0x68fb004d,0x00000000}},	//   _svim_, _suyi, szud,
  { {0x75e600ea,0xdb030244,0xe4da005d,0x00000000}},	//   _rózs, renä, پوست_,
  { {0xb05b0137,0xdb03397a,0xd4f50085,0x00000000}},	//   _dräk, senä, бяры,
  { {0xdb1a00f8,0x69a10053,0x225e0195,0x00000000}},	//   _saté, क्री, ítko_,
  { {0xdb010080,0xf3ff017d,0x63be216f,0x00000000}},	//   _oblí, apão_, _vapn,
  { {0x71660032,0x60c4017f,0xe29700d7,0x00000000}},	//   شارك, tvim, јат_,
  { {0x42230086,0xdfd20067,0x661d00ea,0x00000000}},	// [6500] ідув, يير_, érke,
  { {0x38600025,0xd47b0063,0xe53b0063,0x00000000}},	//   _éire_, _שאיל, _בתפר,
  { {0xdfcf013a,0x387f0075,0xe4f60042,0x00000000}},	//   ظيم_, hsur_, ुछवि_,
  { {0x127b0047,0x248d01c8,0x6da62b70,0x00000000}},	//   _באטע, šeme_, рида,
  { {0xf1bf0013,0x1c461968,0xa3cb0042,0x00000000}},	//   _nháy_, андм, _रोड_,
  { {0x9e66005d,0xdff5014b,0xdfd202da,0x00000000}},	//   _نارن, _лясь, _بيس_,
  { {0x387f002b,0x2b77005d,0x80c40082,0x00000000}},	//   esur_, شینگ_, रिवे,
  { {0x79a30121,0x98740edb,0x28a60054,0x00000000}},	//   орье, блиц, ашог,
  { {0xf1bf008b,0x7aea0137,0x69c0397b,0x00000000}},	//   _cháy_, syft, rdme,
  { {0x07e60001,0x628e00c2,0x67f4005e,0x00000000}},	//   рцим, krbo, спођ,
  { {0x75d50032,0xcf570063,0x8f7b0063,0x00000000}},	//   ميدا, יבית_, כניק,
  { {0x26070086,0x98a624a6,0x395f397c,0x00000000}},	//   рчог, _виде, ccus_,
  { {0x2509007e,0x628e237d,0x98a30e5e,0x00000000}},	//   ارجی_, erbo, _мице,
  { {0xdb0304c7,0xed590078,0xf1bf0516,0x00000000}},	//   senå, _maža_, _saá_,
  { {0x9259000a,0x3e48000c,0xf8b60053,0x00000000}},	//   ѓаат_, _eşti_, _अनुप,
  { {0x41680001,0x33f40137,0xd6db0063,0x00000000}},	//   ијум_, _växa_, _יחול,
  { {0xc058000d,0x657d397d,0x628e397e,0x00000000}},	// [6510] аіх_, mash, arbo,
  { {0x4fd40086,0x657d397f,0x59a60053,0x00000000}},	//   ожут, lash, क्तर,
  { {0x63b50198,0x656f0195,0x10480054,0x00000000}},	//   mezn, obch, ряти_,
  { {0x387f001f,0x657d3980,0x63b53981,0x00000000}},	//   ysur_, nash, lezn,
  { {0x71d60063,0xfd10002a,0x6b65046e,0x00000000}},	//   _הורד_, وجه_, бкла,
  { {0xdb030066,0x29c30013,0xb47a0041,0x00000000}},	//   menú, _ựa_, אָקי,
  { {0x38660016,0x7a13003b,0x657d3982,0x00000000}},	//   _ator_, lăti, kash,
  { {0xdb1a3502,0x682f05a5,0xb05b004d,0x00000000}},	//   _antó, nødv, _präh,
  { {0x63b500ea,0x657d25d3,0x395f3983,0x00000000}},	//   kezn, dash, rcus_,
  { {0x3179000f,0xdb01017d,0x657b0014,0x00000000}},	//   _lesz_, _salõ, ðuhn,
  { {0x63b5366a,0xbbb30042,0x387f12e5,0x00000000}},	//   dezn, ंजीक, ssur_,
  { {0x7bc109ff,0xd46a0bb2,0xf3e9014e,0x00000000}},	//   _halu, лиме_, _אף_,
  { {0x7bc13984,0x5a0a0041,0x38cb01ce,0x00000000}},	//   _kalu, _גלײַ, _јуен_,
  { {0x7bc10dbb,0x03a60001,0x09340021,0x00000000}},	//   _jalu, љиво, _برمج,
  { {0xe6950032,0xb7da014e,0x7bc13985,0x00000000}},	//   _العد, _תקצי, _malu,
  { {0x7bc10228,0xe862003b,0x38660137,0x00000000}},	//   _lalu, _înţţ, _ytor_,
  { {0x7a13000c,0xe45f0137,0xe7ee0053,0x00000000}},	// [6520] găti, lvön_, _चकमा_,
  { {0x7bc13986,0x6295004c,0x5fd20042,0x00000000}},	//   _nalu, buzo, साइल,
  { {0x442a0150,0x683d0003,0x2c08005d,0x00000000}},	//   mob_, cède, یعتی_,
  { {0x7e6300ea,0x7bc100a4,0x442a3987,0x00000000}},	//   ínpa, _aalu, lob_,
  { {0x628101c2,0x7c830376,0x442a19fb,0x00000000}},	//   álov, пуще, oob_,
  { {0x3ebd00fe,0x657d0035,0x68f60051,0x00000000}},	//   äytä_, zash, _żydo,
  { {0x2bb90161,0x7ac6026c,0x7bc13988,0x00000000}},	//   _इसरा, ссле, _dalu,
  { {0x7ae50019,0x7bc30024,0x6da316ef,0x00000000}},	//   ähta, adnu, _ниса,
  { {0x224c0080,0xe9180086,0x657d1e49,0x00000000}},	//   ídky_, ропі_, vash,
  { {0x657d075a,0x7bc13989,0x60bb0041,0x00000000}},	//   wash, _galu, נציד,
  { {0x6e450026,0x63b507c3,0xdb0e00fe,0x00000000}},	//   _útbú, vezn, äkäy,
  { {0x61e6003d,0xbb3b0047,0x7c2a398a,0x00000000}},	//   _nokl, _געבי, lofr,
  { {0x200a0035,0xdb1a0118,0xd90e007e,0x00000000}},	//   _ombi_, _matí, _سید_,
  { {0xb05b01e3,0x63a9017f,0xdb1a398b,0x00000000}},	//   _kräv, đeno, _latí,
  { {0xa77b00b5,0x61e60c4a,0x657d02ae,0x00000000}},	//   _גרופ, _bokl, pash,
  { {0x245d00aa,0x3f8e0026,0x200a251e,0x00000000}},	//   _tìm_, ófun_, _ambi_,
  { {0x61e6398c,0x62950080,0x3179013d,0x00000000}},	// [6530] _dokl, suzo, _vesz_,
  { {0xdefb0076,0x2f15000d,0x442a0870,0x00000000}},	//   лые_, одзё, cob_,
  { {0x317900ea,0x41c40053,0x61e60130,0x00000000}},	//   _tesz_, _लोकस, _fokl,
  { {0xd0d50062,0x660f2f3b,0xa69b0047,0x00000000}},	//   _домъ, nick, רשאפ,
  { {0xdb1800b9,0x7bc12719,0x200f013d,0x00000000}},	//   ndvæ, _palu, égis_,
  { {0xdfdb011c,0x547c0047,0x660f398d,0x00000000}},	//   _съм_, נטוו, hick,
  { {0x660f00c7,0xce94005a,0x7bc30c84,0x00000000}},	//   kick, _наръ, rdnu,
  { {0xf865000a,0x39e9005e,0x7bc1102e,0x00000000}},	//   овио, рдио_, _walu,
  { {0x2aa10045,0x660f398e,0x5c07000d,0x00000000}},	//   sób_, dick, _ляжа,
  { {0xdb1a398f,0xaf760047,0x6e2b29ea,0x00000000}},	//   _zatí, ֿערס_, logb,
  { {0x660f0512,0x38ca007e,0xae000053,0x00000000}},	//   fick, هایی_, लोकन_,
  { {0xd62a0be6,0x58d50189,0x660f004a,0x00000000}},	//   роме_, _моет, gick,
  { {0x628502f0,0x59840086,0xb05b004d,0x00000000}},	//   _avho, _хліб, _kräu,
  { {0x386d3990,0xdce90066,0x2b40004c,0x00000000}},	//   mper_, _oceľ, řice_,
  { {0xfbd20063,0x386d3991,0x61e609a1,0x00000000}},	//   ותם_, lper_, _pokl,
  { {0x799b1040,0x2cbf027d,0x386d3992,0x00000000}},	//   nguw, _osud_, oper_,
  { {0x442a3993,0xe0da0bd8,0x3fe60e48,0x00000000}},	// [6540] pob_, шва_, ожав,
  { {0x386d1991,0xa91d0024,0x7c2a017d,0x00000000}},	//   iper_, mažd, xofr,
  { {0x7a130529,0x91e63994,0x2cbf004b,0x00000000}},	//   lătu, _доне, _asud_,
  { {0x106600de,0x00000000,0x00000000,0x00000000}},	//   _وُجُ,   ,   ,
  { {0xb05b004d,0x5c730086,0xa01b0014,0x00000000}},	//   _bräu, дліт, _kvöl,
  { {0x200a0228,0x69c2006f,0xb05b004d,0x00000000}},	//   _umbi_, _saoe, _präv,
  { {0xdb1a3995,0x386d3996,0xeb970896,0x00000000}},	//   _satâ, eper_, циј_,
  { {0xab5c001c,0xa91d027d,0x9984004c,0x00000000}},	//   _daļa, každ, romů_,
  { {0xb7bc003d,0xb05b004d,0xbc6a0021,0x00000000}},	//   loģi, _fräu, _ضمان_,
  { {0xd90d007e,0x2918000c,0x660f0404,0x00000000}},	//   دیه_, ăra_, wick,
  { {0x8cc20161,0x660f016b,0x1f5b009f,0x00000000}},	//   लिको, tick, ידיא,
  { {0x3dc61683,0x2ca6004b,0xdb0a01e1,0x00000000}},	//   ndow_, otod_, tefæ,
  { {0x7a130529,0xf8ad006a,0x79800035,0x00000000}},	//   gătu, _یکی_, mamw,
  { {0xdb1800b9,0x660f2f62,0xdc8b3997,0x00000000}},	//   rdvæ, sick, יְלָ,
  { {0x3d110053,0x03c8000d,0xf434000d,0x00000000}},	//   _देने_, цыяй_, ферэ,
  { {0xb05b0137,0x7a13003b,0xf41f00e0,0x00000000}},	//   _orät, bătu, erät_,
  { {0x7a13000c,0xdcfb007d,0xdd1c0066,0x00000000}},	// [6550] cătu, _iduć, yššo,
  { {0x62810080,0x2cbf0150,0x2ca600a4,0x00000000}},	//   álos, _rsud_, dtod_,
  { {0xdb1810b9,0x35d00053,0x6e2b00ac,0x00000000}},	//   ndvä, _तोड़, togb,
  { {0xa91d017f,0x6281017f,0x386d2e50,0x00000000}},	//   laže, šlos, yper_,
  { {0x6e2b00b9,0x660d00a4,0x7980002b,0x00000000}},	//   rogb, _mmak, damw,
  { {0xa91d0080,0x22493998,0xab5c008f,0x00000000}},	//   naže, lmak_, _paļa,
  { {0xdb1a00cd,0xf4140063,0x660d065c,0x00000000}},	//   _catà, ופס_, _omak,
  { {0x224901f7,0xe9d90793,0xa2cc0053,0x00000000}},	//   nmak_, ски_, हित्,
  { {0x63a90117,0xa91d0606,0xb05b004d,0x00000000}},	//   đenj, kaže, _träu,
  { {0x660d3999,0x96b9005e,0x386d399a,0x00000000}},	//   _amak, буму_, rper_,
  { {0xdb0a2063,0x2249005b,0xf5290063,0x00000000}},	//   gefä, kmak_, _עץ_,
  { {0x60000137,0x386d0b82,0x7a1300dd,0x00000000}},	//   _gömf, pper_, tătu,
  { {0xdb1a0025,0x27e7399b,0xda080044,0x00000000}},	//   _iatá, _tonn_, _بينه_,
  { {0xdb1a000f,0x3f81399c,0x660d04b4,0x00000000}},	//   _hatá, jahu_, _emak,
  { {0x7d02399d,0x7a13003b,0x3f810130,0x00000000}},	//   zzos, sătu, dahu_,
  { {0x7a13003b,0x80660454,0x26c2008f,0x00000000}},	//   pătu, зваж, ākot_,
  { {0x859b0063,0x64620022,0xc5eb009a,0x00000000}},	// [6560] _השפו, ówią, _הַיֹ,
  { {0x6834051e,0xa8560063,0x7f75000d,0x00000000}},	//   tàdi, פיעה_, дуцц,
  { {0x44440117,0xdb0a0137,0x2ec60021,0x00000000}},	//   _ih_, ldfö, ثقاف,
  { {0x683400cd,0xdca60095,0xb05b004d,0x00000000}},	//   ràdi, зади, _prät,
  { {0x4444399e,0xdb0a0354,0x2ca6004b,0x00000000}},	//   _kh_, ndfö, utod_,
  { {0x0fda0032,0x61f600c7,0x78a400fe,0x00000000}},	//   _ابحث_, lkyl, _äivi,
  { {0x80c40161,0x75280051,0x2ca6399f,0x00000000}},	//   रिके, ędzy, stod_,
  { {0xdb1a0b23,0xa91d00c2,0xb05b39a0,0x00000000}},	//   _catá, zaže, _gräs,
  { {0xfc64006a,0xa967000a,0xdb01004d,0x00000000}},	//   _آخری, чиња_, _ablä,
  { {0x6d400418,0xdb030240,0x660d39a1,0x00000000}},	//   _izma, lený, _smak,
  { {0xa91d017f,0x2249005b,0xdb0a00a5,0x00000000}},	//   važe, ymak_, edfö,
  { {0xaac20235,0xdb030024,0xdb1810b9,0x00000000}},	//   _वैयक, nený, rdvä,
  { {0x44442ae5,0xa91d004c,0x00000000,0x00000000}},	//   _bh_, taže,   ,
  { {0x444439a2,0x764400a4,0x248d02f7,0x00000000}},	//   _ch_, _ehiy, šemo_,
  { {0x224901f7,0xc66a005e,0xa91d1871,0x00000000}},	//   tmak_, _ушле_, raže,
  { {0xa91d0080,0x31c40086,0x444439a3,0x00000000}},	//   saže, нсув, _eh_,
  { {0x224901f7,0x3f8139a4,0xdb030240,0x00000000}},	// [6570] rmak_, tahu_, dený,
  { {0xa7790047,0x61e41668,0xc034005e,0x00000000}},	//   ַרױפ, ajil, енуј,
  { {0x6d4000e3,0x224901f7,0xb05b0832,0x00000000}},	//   _azma, pmak_, _präs,
  { {0x3f810512,0x444439a5,0x661d39a6,0x00000000}},	//   sahu_, _zh_, nnsk,
  { {0x61fd1036,0x3f810509,0x628739a7,0x00000000}},	//   _ilsl, pahu_, lsjo,
  { {0xdb1a0331,0x44441ded,0x027e004c,0x00000000}},	//   _satá, _xh_, říže_,
  { {0x628739a8,0x60000137,0xb05b0137,0x00000000}},	//   nsjo, _dömd, _träs,
  { {0x60cd017d,0xdce00078,0xdb0339a9,0x00000000}},	//   ovam, _nemė, menü,
  { {0x3a2d03a8,0x9f5a02dd,0xdddc082a,0x00000000}},	//   roep_, cipó_, _uvrš,
  { {0x62870031,0x661d39aa,0x60002502,0x00000000}},	//   ksjo, ensk, _gömd,
  { {0x3d110161,0x4ac10053,0x6b830dbf,0x00000000}},	//   _देते_, _शनिव, mang,
  { {0x6b833534,0x444439ab,0x64451795,0x00000000}},	//   lang, _sh_, _ahhi,
  { {0x444439ac,0x629539ad,0x7a13003b,0x00000000}},	//   _ph_, erzo, bătr,
  { {0x6b8339ae,0xdb0a0137,0xdb03004a,0x00000000}},	//   nang, rdfö, zený,
  { {0x82a30086,0x645704bc,0x6b8339af,0x00000000}},	//   карж, _dixi, iang,
  { {0x645700cd,0x24440137,0x69c90e95,0x00000000}},	//   _eixi, döme_, ndee,
  { {0x44440037,0x628700d1,0x64570359,0x00000000}},	// [6580] _th_, asjo, _fixi,
  { {0x6b830397,0x61f617d3,0x39110047,0x00000000}},	//   jang, skyl, לטאַט,
  { {0x78a901a6,0xdb0313f9,0x68110080,0x00000000}},	//   htev, genü, mědě,
  { {0xb05b00fe,0x6b8339b0,0x63bc39b1,0x00000000}},	//   _isän, eang, lern,
  { {0xdb0914c0,0xdb030b33,0xdbc60019,0x00000000}},	//   čnýc, rený, _mööb,
  { {0x6d5b0290,0x69c90179,0x69d9162b,0x00000000}},	//   _egua, edee, _anwe,
  { {0x629c0006,0x69c90104,0xf41f0072,0x00000000}},	//   nuro, fdee, ksän_,
  { {0x63a9017f,0x9f5a0290,0xdb1800ea,0x00000000}},	//   đeni, cipò_, nevé,
  { {0xdb1a0016,0x63bc0666,0xdb0a0164,0x00000000}},	//   _antô, kern, iffé,
  { {0x69d9001f,0xddc9001c,0xdb180003,0x00000000}},	//   _enwe, _cieņ, hevé,
  { {0x06150076,0x63bc39b2,0x7bda191d,0x00000000}},	//   едню, dern, _intu,
  { {0xb4950001,0x629c001f,0x64570003,0x00000000}},	//   нимљ, duro, _sixi,
  { {0xe9f7019d,0xa3cb0053,0x7bc839b3,0x00000000}},	//   _інші_, रएल_, _kadu,
  { {0x63bc010a,0x7bc800e3,0x6295232d,0x00000000}},	//   gern, _jadu, trzo,
  { {0x64540001,0xa5f90001,0x545400e1,0x00000000}},	//   тврђ, _неку_, тврт,
  { {0x62870031,0xf1bf00ea,0x60cd0008,0x00000000}},	//   rsjo, _akár_, tvam,
  { {0x9099011c,0x63bc39b4,0x6b8339b5,0x00000000}},	// [6590] яват_, bern, yang,
  { {0x628726ef,0x6d5b0290,0x7bc80051,0x00000000}},	//   psjo, _sgua, _nadu,
  { {0x6b83326e,0x238a0024,0x040e008b,0x00000000}},	//   vang, šujú_, hườn,
  { {0x6b83058c,0x600000bd,0x7bda39b6,0x00000000}},	//   wang, _röme, _antu,
  { {0x6b8339b7,0x7bc81d4c,0xeb8e2474,0x00000000}},	//   tang, _badu, ли_,
  { {0x7bc839b8,0x6b8339b9,0x9f6500fe,0x00000000}},	//   _cadu, uang, ätät_,
  { {0xfb840088,0x7bc800bd,0xdd95000d,0x00000000}},	//   тычн, _dadu, _павы,
  { {0x4431000f,0x6d5b051e,0x78a939ba,0x00000000}},	//   hoz_, _ugua, ttev,
  { {0xddc9003d,0xf8c8001b,0x69c939bb,0x00000000}},	//   _pieņ, _cứ_, rdee,
  { {0x600000ea,0x69c90d1e,0xd709007f,0x00000000}},	//   _töme, sdee, зное_,
  { {0x68110080,0x26d139bc,0xdb030022,0x00000000}},	//   vědě, ízo_, renó,
  { {0x63bc0b9d,0x7bc82c3e,0x6b8139bd,0x00000000}},	//   wern, _zadu, _helg,
  { {0x63bc39be,0x6b81004e,0xd8b80044,0x00000000}},	//   tern, _kelg, _يدها_,
  { {0x629c39bf,0x63bc0a87,0x443100be,0x00000000}},	//   turo, uern, goz_,
  { {0x0443005a,0xed59001c,0x63bc39c0,0x00000000}},	//   уерн, _daži_, rern,
  { {0xe1ff0025,0xb05b0ae2,0xdb0a0003,0x00000000}},	//   _cló_, _präp, uffé,
  { {0x361b0063,0xa3cb0053,0xf8c8008b,0x00000000}},	// [65a0] _מוקד, _रोक_, _xứ_,
  { {0x7e7c001f,0xb05b00fe,0x44310331,0x00000000}},	//   _pwrp, _isäl, coz_,
  { {0xdbd90014,0x7bc839c1,0x216a0002,0x00000000}},	//   _ræðs, _radu, _нини_,
  { {0x60db16fe,0x9cca0895,0x97560063,0x00000000}},	//   _šume, зыка_, גיעו_,
  { {0x7bc839c2,0x6b8139c3,0x644e39c4,0x00000000}},	//   _padu, _belg, ombi,
  { {0x22590240,0x6a670058,0x2ac6005e,0x00000000}},	//   _zisk_, _sıfa, ељив,
  { {0x7bc839c5,0xf8c8008b,0x59d10053,0x00000000}},	//   _vadu, _sứ_, _दोहर,
  { {0x7bc800f3,0x6b81006f,0x6aaa002b,0x00000000}},	//   _wadu, _eelg, rtff,
  { {0x7bc80035,0x57a60062,0x0c3a0021,0x00000000}},	//   _tadu, ншна, _فكرة_,
  { {0x7bda014f,0xdb0a02ab,0x040e008b,0x00000000}},	//   _untu, kefø, rườn,
  { {0xa7de0024,0xa91d02e2,0x290b00f8,0x00000000}},	//   _kľúč_, raža, úcar_,
  { {0x63a50199,0x644e053b,0x2fca00a4,0x00000000}},	//   _schn, embi, _labg_,
  { {0xe61f017d,0x2259255c,0xa91d2f12,0x00000000}},	//   rnô_, _risk_, paža,
  { {0xe1ff0014,0xdb01006c,0x97c60044,0x00000000}},	//   _sló_, _sclé, _ستتم,
  { {0xdb0a00b9,0xed59007d,0xa91d0734,0x00000000}},	//   gefø, _važi_, nažn,
  { {0x644e39c6,0x7ae50656,0x75220130,0x00000000}},	//   ambi, ähti, _žoze,
  { {0x64a40095,0x60db004c,0xb0350a74,0x00000000}},	// [65b0] _бања, _šumb, внаш,
  { {0x7fb90593,0x23790044,0x88bb009a,0x00000000}},	//   ظهار_, _تمدد_, הזמי,
  { {0x93f40088,0x225939c7,0xfbdf0013,0x00000000}},	//   _спэц, _tisk_, _đê_,
  { {0x6b8139c8,0x2eee00c7,0xdd95000d,0x00000000}},	//   _selg, äffa_, тады,
  { {0xed4e019d,0x6b81154e,0x0cd4012c,0x00000000}},	//   ро_, _pelg, лоцю,
  { {0x5274007e,0x629a00ea,0xeb990590,0x00000000}},	//   _جایز, átog, фик_,
  { {0x6b81076c,0x63a30026,0xe9d10021,0x00000000}},	//   _velg, _önnu, لغة_,
  { {0x2612007d,0x9f3401dd,0x6b810983,0x00000000}},	//   ašoj_, _сесі, _welg,
  { {0x3f830150,0x6d350002,0x6c5539c9,0x00000000}},	//   _keju_, _реаф, _акау,
  { {0x29030006,0x399a0058,0x26120066,0x00000000}},	//   ąja_, tüsü_, ršom_,
  { {0xd62a1c9b,0xfdf50042,0x00000000,0x00000000}},	//   доне_, _आवास_,   ,
  { {0x24440137,0x3f83008f,0xdb0a05e7,0x00000000}},	//   döma_, _leju_, vefø,
  { {0x47c5000d,0xa91d39ca,0xe9f80054,0x00000000}},	//   _аблв, mažo, _янці_,
  { {0xccf20063,0xdb0a04aa,0x39440054,0x00000000}},	//   סכם_, tefø, _сніг,
  { {0x644e02ab,0x69cb39cb,0x036714db,0x00000000}},	//   rmbi, _kage, тиск_,
  { {0xdb0a0093,0x69cb39cc,0x00000000,0x00000000}},	//   refø, _jage,   ,
  { {0xed59017f,0x38ab000e,0xa5260f8d,0x00000000}},	// [65c0] _kažu_, nør_, _шмид,
  { {0x69cb39cd,0x6288004c,0x749b009a,0x00000000}},	//   _lage, ádos, _קייפ,
  { {0x0d8639ce,0x61ef0025,0x38ab06a5,0x00000000}},	//   влен, _focl, hør_,
  { {0x35aa0053,0x69cb03ac,0xa91d0ab3,0x00000000}},	//   _काफ़, _nage, važn,
  { {0x38ab0031,0xdca303d6,0x6da30152,0x00000000}},	//   jør_, иаци, рича,
  { {0x9e76007e,0x38ab0093,0xab5c0023,0x00000000}},	//   _لهست, dør_, _kaļi,
  { {0x394020b4,0x69cb39cf,0xdee30e0d,0x00000000}},	//   _šis_, _bage, _кори,
  { {0x38ab0831,0xddc90051,0xa91d39d0,0x00000000}},	//   før_, _mieś, ražn,
  { {0x38ab0146,0x61eb00bd,0x69cb216d,0x00000000}},	//   gør_, ögli, _dage,
  { {0x69cb0034,0xa7740076,0xdb180e08,0x00000000}},	//   _eage, ылоч, leví,
  { {0xf1bf0024,0xed59001c,0x60c4004d,0x00000000}},	//   áške_, _dažu_, hwim,
  { {0x60c405b3,0x1af70063,0x69cb0ed3,0x00000000}},	//   kwim, _שמאל_, _gage,
  { {0x39400025,0x69c039d1,0x98a32ba3,0x00000000}},	//   _áis_, meme, _виче,
  { {0x69cb0717,0x69c039d2,0x78a039d3,0x00000000}},	//   _zage, leme, mumv,
  { {0xe8e0001b,0xdb180016,0x69c0006f,0x00000000}},	//   _đội_, levâ, oeme,
  { {0xd9e50053,0x69c039d4,0xdb18004c,0x00000000}},	//   कायत_, neme, jeví,
  { {0x629a00cd,0x25a939d5,0x69c039d6,0x00000000}},	// [65d0] àtor, _ical_, ieme,
  { {0x26120024,0x69c00238,0x75380063,0x00000000}},	//   yšok_, heme, _באחד_,
  { {0x69c039d7,0x33f40137,0xf1ab0042,0x00000000}},	//   keme, _växt_, _छापन,
  { {0x69c000f3,0x78a0001c,0x6e220153,0x00000000}},	//   jeme, kumv, gnob,
  { {0xa91d004a,0xc19a07e9,0x1d340054,0x00000000}},	//   važo, _אשרי, анця,
  { {0x60da0047,0x38ab04aa,0x69cb39d8,0x00000000}},	//   _אַלג, vør_, _sage,
  { {0xa91d00eb,0x69cb39d9,0x25a939da,0x00000000}},	//   tažo, _page, _ocal_,
  { {0x683d0268,0x38ab02ab,0xb05b0137,0x00000000}},	//   mèdi, tør_, _osäk,
  { {0xdd03001c,0xf1ab0042,0xd876005d,0x00000000}},	//   ārēj, _छानन, هميت_,
  { {0x2d840b61,0x38ab06a5,0x69cb39db,0x00000000}},	//   _zeme_, rør_, _wage,
  { {0x69cb39dc,0x2d842422,0x248000e5,0x00000000}},	//   _tage, _yeme_, _swim_,
  { {0x69c039dd,0x7ae50019,0x8afa0aeb,0x00000000}},	//   ceme, ähtu, _אלעז,
  { {0xb17b0137,0xb90801fb,0x99d4005d,0x00000000}},	//   _onåb, _لزوم_, _ختلا,
  { {0xa91d0066,0xddc90051,0x389a009f,0x00000000}},	//   nažm, _pieś, _ניצנ,
  { {0x3ea10019,0x7c2300d1,0xdb1a0014,0x00000000}},	//   juht_, innr, _satú,
  { {0x442300c3,0x60db39de,0x25a9005f,0x00000000}},	//   anj_, _šuma, _gcal_,
  { {0x66040009,0x998d0051,0xc0e32aa1,0x00000000}},	// [65e0] _ilik, mień_, ботк,
  { {0x2d8439df,0xdee60f55,0x69c039e0,0x00000000}},	//   _seme_, лози, zeme,
  { {0xa5bb006d,0x683d00cd,0x69c039e1,0x00000000}},	//   inón, gèdi, yeme,
  { {0x69c00268,0x831b0047,0x645e39e2,0x00000000}},	//   xeme, _טויז, _hipi,
  { {0x645e0009,0x69c004bc,0x443a1ca6,0x00000000}},	//   _kipi, veme, _kkp_,
  { {0xbe86007e,0xdb0112e2,0x224039e3,0x00000000}},	//   _مجرو, _eclí, llik_,
  { {0x660401e3,0xc0030001,0x6e220150,0x00000000}},	//   _olik, _упрк, pnob,
  { {0x6ca60021,0x22402f32,0x200f008f,0x00000000}},	//   _مصطل, nlik_, īgie_,
  { {0x69c039e4,0x224039e5,0x2df70063,0x00000000}},	//   reme, ilik_, _עצמך_,
  { {0x201a002c,0x6604077d,0x443a2579,0x00000000}},	//   nipi_, _alik, _nkp_,
  { {0xf1bf0024,0xa01b0026,0xdab7007e,0x00000000}},	//   ššie_, _kvör, _مهلت_,
  { {0x0f570063,0x56930b3f,0x628e39e6,0x00000000}},	//   טיים_, щают, dsbo,
  { {0xdb1800cd,0x22401b35,0x629c0b32,0x00000000}},	//   levà, dlik_, erro,
  { {0x36d40076,0x60000137,0x645e39e7,0x00000000}},	//   _вокр, _sömn, _cipi,
  { {0x6604304a,0x443a39e8,0x645e39e9,0x00000000}},	//   _flik, _dkp_, _dipi,
  { {0x224000e8,0xdb0a39ea,0x44f52377,0x00000000}},	//   glik_, lefó, _впис,
  { {0xcf9b0001,0xf3f1008b,0x30150e87,0x00000000}},	// [65f0] еје_, ự_, адар,
  { {0x629a0024,0x645e39eb,0x628e0003,0x00000000}},	//   átoc, _gipi, bsbo,
  { {0xdb0a00bd,0x224039ec,0x656f0290,0x00000000}},	//   gefü, blik_, occh,
  { {0x7c3a0228,0x683d00cd,0x3ea100bd,0x00000000}},	//   _aktr, rèdi, ruht_,
  { {0x656f0290,0xfce539ed,0x0d840085,0x00000000}},	//   icch, роло, слін,
  { {0x683d0994,0xb09a0063,0x201a39ee,0x00000000}},	//   pèdi, _בישר, cipi_,
  { {0x6d9c0024,0x61ed39ef,0x5fce0042,0x00000000}},	//   _sťaž, ojal, _होटल,
  { {0x48b5005a,0x5c750141,0x61ed352a,0x00000000}},	//   ащот, _влат, njal,
  { {0x7989001f,0x6e3b00a4,0xdb030003,0x00000000}},	//   raew, _ikub, igné,
  { {0x660439f0,0x656f0290,0x998d0051,0x00000000}},	//   _slik, ecch, wień_,
  { {0x660439f1,0x645e0290,0x22400379,0x00000000}},	//   _plik, _ripi, ylik_,
  { {0x645e18ab,0x38660290,0x7bc31255,0x00000000}},	//   _sipi, _fuor_, lenu,
  { {0x6e3b0035,0x9f4a0024,0x645e0465,0x00000000}},	//   _mkub, _robí_, _pipi,
  { {0x7bc30019,0xdb1800ea,0x656f39f2,0x00000000}},	//   nenu, levá, acch,
  { {0x645e0009,0xdb0a0268,0x998d0051,0x00000000}},	//   _vipi, lefò, pień_,
  { {0x660439f3,0x61ed0026,0x22400917,0x00000000}},	//   _ulik, gjal, ulik_,
  { {0x68fb0150,0x224039f4,0x2c6b06a5,0x00000000}},	// [6600] nyud, rlik_, _nød_,
  { {0x6aa300bd,0x3fe30472,0xa01b0026,0x00000000}},	//   kunf, ожув, _svör,
  { {0x68fb0150,0x7c240025,0x7bc339f5,0x00000000}},	//   hyud, éirm, denu,
  { {0x61ed0045,0x443809ee,0x7bc30019,0x00000000}},	//   cjal, lor_, eenu,
  { {0x44380a53,0xcbe60121,0x7d970500,0x00000000}},	//   oor_, ицки, рвіс_,
  { {0x2c6b02ab,0x6e3b00ac,0x7bc339f6,0x00000000}},	//   _død_, _ekub, genu,
  { {0x6b8a1b26,0x386639f7,0x26120066,0x00000000}},	//   rafg, _suor_, lšou_,
  { {0x443839f8,0x7bc3004b,0x7a1d0013,0x00000000}},	//   hor_, aenu, ệtna,
  { {0xed570612,0x7e6000a4,0x443839f9,0x00000000}},	//   _вот_, _iimp, kor_,
  { {0x65640089,0x443803db,0x7e603986,0x00000000}},	//   _agih, jor_, _himp,
  { {0x4438100f,0xb05b004d,0x7c380066,0x00000000}},	//   dor_, _präz, movr,
  { {0x6b8806b8,0x7af70137,0x44380331,0x00000000}},	//   _hedg, äxte, eor_,
  { {0x443839fa,0x26120024,0x998b0024,0x00000000}},	//   for_, jšou_, ôcť_,
  { {0x7e6039fb,0x3cee0053,0x7c3839fc,0x00000000}},	//   _limp, _आपने_, novr,
  { {0xd8380198,0xe6940032,0x3f870026,0x00000000}},	//   moč_, _البد, ðnum_,
  { {0x764d0035,0x20180306,0x320900a4,0x00000000}},	//   _uhay, _amri_, uhay_,
  { {0x2f8b0001,0xc9530047,0x7c38085a,0x00000000}},	// [6610] вљен_, ַמע_, kovr,
  { {0x2c6b02ab,0x61ed0019,0x6b880e6c,0x00000000}},	//   _rød_, sjal, _nedg,
  { {0xe8e0001b,0x2c6b00b9,0x61ed0026,0x00000000}},	//   _đời_, _sød_, pjal,
  { {0xb05b0137,0x20180058,0x661d39fd,0x00000000}},	//   _späd, _emri_, nisk,
  { {0xbc190088,0x6d40001f,0xd83800c2,0x00000000}},	//   лікі_, _cyma, koč_,
  { {0xd83800c3,0x00f60063,0x7e6022cc,0x00000000}},	//   joč_, _המשך_, _eimp,
  { {0xa91d0006,0x7d060019,0x661d39fe,0x00000000}},	//   maži, _üksn, kisk,
  { {0x6e3b39ff,0x7bc33a00,0x1dcf0053,0x00000000}},	//   _ukub, senu, _सोचत,
  { {0x7bc30397,0x44381a8d,0x6d40001f,0x00000000}},	//   penu, yor_, _gyma,
  { {0x30da0047,0xdb1806a5,0x290d00be,0x00000000}},	//   אַטע, devæ, rzea_,
  { {0x661d3a01,0x44383a02,0x98b8008f,0x00000000}},	//   fisk, vor_, ārā_,
  { {0xdb010025,0x2cbf0150,0x661d3a03,0x00000000}},	//   _gclá, _kpud_, gisk,
  { {0x5a0c00b5,0xdb1800b9,0x4dda0063,0x00000000}},	//   _בלאַ, gevæ, אחרו,
  { {0x96f9009e,0x35ac0042,0xdd380023,0x00000000}},	//   _معبر_, ट्ज़, nāšo,
  { {0x661d3a04,0x44382283,0x98140044,0x00000000}},	//   bisk, ror_, _ببنا,
  { {0x63bb017f,0x7cde000c,0xdb1800b9,0x00000000}},	//   đuna, _hărţ, bevæ,
  { {0x443809fb,0x7e603a05,0x30760062,0x00000000}},	// [6620] por_, _rimp, субс,
  { {0x7e6900c3,0x60000137,0xa91d0734,0x00000000}},	//   _čepr, _tömm, gaži,
  { {0x7e600397,0x8d1a006a,0x6d403a06,0x00000000}},	//   _pimp, گزار_, _syma,
  { {0x26120066,0x998d00c2,0xa5bb01a8,0x00000000}},	//   pšou_, elež_, ciód,
  { {0x7c38017f,0xdca30727,0x8c460cbb,0x00000000}},	//   tovr, зачи, беде,
  { {0x6d400a63,0x9742017f,0x661d3a07,0x00000000}},	//   _vyma, šćim, zisk,
  { {0x6d400045,0x7e603a08,0x7ae5004b,0x00000000}},	//   _wyma, _timp, ähtp,
  { {0x1874042c,0x52d70063,0x9a670021,0x00000000}},	//   огия, מוצע_, حميل_,
  { {0x661d3a09,0x6d40005b,0xd838007d,0x00000000}},	//   visk, _uyma, toč_,
  { {0x7cde0529,0x661d0045,0xdb1800b9,0x00000000}},	//   _cărţ, wisk, vevæ,
  { {0x442701f7,0xb05b00fe,0x2127008b,0x00000000}},	//   _ın_, _isät, ̃nh_,
  { {0xd83800c3,0x6f090080,0xa96a0141,0x00000000}},	//   soč_, _řeck, _сида_,
  { {0x661d06a3,0xd7940062,0xe4c70121,0x00000000}},	//   risk, _дилъ, щённ,
  { {0x661d3a0a,0xdb1805b9,0x3f8a08ed,0x00000000}},	//   sisk, revæ, _nebu_,
  { {0xdb1a00bd,0xdb1800b9,0xa91d2291,0x00000000}},	//   _natü, sevæ, važi,
  { {0xdb1a013d,0x0697005d,0x25090043,0x00000000}},	//   _ható, _اخوت_, _نرخی_,
  { {0x6099007e,0xa5bb3a0b,0xdb1810f0,0x00000000}},	// [6630] شناس_, riód, levä,
  { {0x200705ec,0x3f671567,0x5437005d,0x00000000}},	//   óni_, стаб, _درعر,
  { {0xa91d3a0c,0x10480071,0xdb180072,0x00000000}},	//   raži, сяти_, nevä,
  { {0xdd940088,0x8d870076,0xa01b00bd,0x00000000}},	//   зацы, сужд, _zwöl,
  { {0xa91d0006,0xda780024,0x2bb90021,0x00000000}},	//   paži, _atď_, لاثة_,
  { {0xdb1800fe,0x3a990121,0x4fc71213,0x00000000}},	//   kevä, атию_, _усма,
  { {0x39e90086,0x93fc0047,0xfbd00593,0x00000000}},	//   идко_, רלוי, عته_,
  { {0x05d90042,0xaa5600de,0x00000000,0x00000000}},	//   _बोलब, يلوا_,   ,
  { {0x7cde000c,0x2d8f04bc,0x26dc0659,0x00000000}},	//   _părţ, mage_, _arvo_,
  { {0x2d8f3a0d,0x2ca00027,0x115c00b5,0x00000000}},	//   lage_, áide_, נדזע,
  { {0xa5bb013d,0x7e9c00dd,0x65c62c71,0x00000000}},	//   diób, căpă, обна,
  { {0x36160086,0x26dc007d,0x2d8f1823,0x00000000}},	//   ієнт, _drvo_, nage_,
  { {0x19590088,0x893703eb,0xd9450002,0x00000000}},	//   _тады_, _اعضا, _ќели,
  { {0xa5bb013d,0x2d8f3a0e,0x67d4012c,0x00000000}},	//   giób, hage_, _ночу,
  { {0xe363019d,0x7c240139,0x3363005e,0x00000000}},	//   дкри, éiri, дврг,
  { {0x21670193,0x9f5e006c,0x42070b69,0x00000000}},	//   жити_, _ôté_, онсо_,
  { {0x6143055d,0x2d8f3a0f,0xf41f0072,0x00000000}},	// [6640] дета, dage_, tsät_,
  { {0xa5bb00ea,0xdb1800d1,0xdfa6009e,0x00000000}},	//   ciób, levå, تحري,
  { {0x2d8f1652,0xa91d0130,0xee3a01ce,0x00000000}},	//   fage_, mažu, анж_,
  { {0x9f51006d,0x3f8a0114,0x2d8f2704,0x00000000}},	//   _alzó_, _webu_, gage_,
  { {0x61e61ebe,0x3f8a0150,0xdb0a0137,0x00000000}},	//   _inkl, _tebu_, nefö,
  { {0x8bc30062,0x3e68007e,0x7d06004b,0x00000000}},	//   дсъд, _هجری_, _üksm,
  { {0xe8e0001b,0x2d8f3a10,0xdb1a006d,0x00000000}},	//   _đối_, bage_, _rató,
  { {0x2d8f1346,0xddc30782,0x0d86080a,0x00000000}},	//   cage_, _обси, _флан,
  { {0xdb1a3a11,0x1d070076,0x225e004c,0x00000000}},	//   _catò, _дети_, ítky_,
  { {0x26dc01b3,0xdb0a0137,0xb05b004d,0x00000000}},	//   _prvo_, defö, _usät,
  { {0x45d53a12,0x998d0051,0xdb1a16eb,0x00000000}},	//   понс, nieś_, _obté,
  { {0xa5bb0331,0xe4e70054,0x91da0042,0x00000000}},	//   dióc, оігн, _पोलै,
  { {0x629a3715,0xdb183a13,0xba1714d7,0x00000000}},	//   štol, sevä, _بينا_,
  { {0x466a0c0b,0x998d0051,0x76463a14,0x00000000}},	//   _крим_, kieś_, alky,
  { {0x2d8f14ff,0xf485007e,0x72d41326,0x00000000}},	//   yage_, _کابی, морф,
  { {0xceeb007e,0x96180021,0xba9b0047,0x00000000}},	//   یران_, _وغير_, יסלי,
  { {0x2d8f04bc,0x200a0150,0x7c2a0014,0x00000000}},	// [6650] vage_, _blbi_, knfr,
  { {0xa91d027d,0x61e60c68,0x2d8f00e5,0x00000000}},	//   mažt, _enkl, wage_,
  { {0x644702e2,0x2d8f3a15,0x9f510290,0x00000000}},	//   mlji, tage_, _alzò_,
  { {0x24890122,0x6295000f,0x62350062,0x00000000}},	//   _kwam_, mszo, _хему,
  { {0x629500ea,0x7c2a0026,0x4c84000d,0x00000000}},	//   lszo, fnfr, длів,
  { {0x644702e2,0x99840006,0x60cd05b3,0x00000000}},	//   nlji, komų_, mwam,
  { {0x27e90013,0x64470014,0x2d8f3a16,0x00000000}},	//   _đan_, ilji, page_,
  { {0x600000bd,0x644700c2,0x99840078,0x00000000}},	//   _römi, hlji, domų_,
  { {0x644700c2,0x2d8d3a17,0xa9250e82,0x00000000}},	//   klji, _ieee_, ядил,
  { {0x629514e0,0x644700a8,0x798b0b06,0x00000000}},	//   kszo, jlji, _wegw,
  { {0x248918a6,0xb8f20053,0x644701b3,0x00000000}},	//   _awam_, _है_, dlji,
  { {0x4f160047,0x62953a18,0x60cd006f,0x00000000}},	//   פֿין_, dszo, kwam,
  { {0xa8790047,0x998d0022,0x76460014,0x00000000}},	//   _פאַר, zieś_, rlky,
  { {0x387f0397,0x644708ea,0x78a9006d,0x00000000}},	//   mpur_, glji, muev,
  { {0x629500ea,0x9f580058,0x877a0041,0x00000000}},	//   gszo, üzün_, _פאקי,
  { {0xdb1200ea,0x249f001c,0x1658005d,0x00000000}},	//   égér, šuma_, _بستک_,
  { {0xdb0a017d,0x6447074f,0x78a9076d,0x00000000}},	// [6660] lefô, blji, nuev,
  { {0x13a8007e,0xa3d40053,0x6295013d,0x00000000}},	//   _بندی_, _सोच_, bszo,
  { {0x69c900ac,0x0eb9000d,0x3246182e,0x00000000}},	//   keee, жучы_, _неог,
  { {0x7d060019,0xed5a026c,0x61e6004d,0x00000000}},	//   _üksk, бое_, _unkl,
  { {0xdd8f007e,0x1bd4130d,0x5c97000d,0x00000000}},	//   اوه_, доля, зкія_,
  { {0x6e2b0d89,0x69c901ec,0xddc90022,0x00000000}},	//   angb, eeee, _cheł,
  { {0x66060c12,0x2242004d,0xf1bf0014,0x00000000}},	//   kkkk, _kkkk_, _sjái_,
  { {0x22420089,0x644700b2,0x2cd60062,0x00000000}},	//   _jkkk_, zlji, _нюзр,
  { {0xe8e00013,0xdca3006e,0x6295013d,0x00000000}},	//   _đồi_, _пати, zszo,
  { {0xf698005e,0x7792007e,0x99840078,0x00000000}},	//   овој_, ریبا, tomų_,
  { {0x64470add,0x7bca075a,0x1b7b0063,0x00000000}},	//   vlji, mefu, _הטבע,
  { {0x6e22270a,0x6aaa0d2e,0x60cd0022,0x00000000}},	//   niob, muff, ywam,
  { {0x6447027c,0x63a10051,0x99840078,0x00000000}},	//   tlji, ólno, somų_,
  { {0x629500ea,0x6aaa0003,0x7bca3a19,0x00000000}},	//   tszo, ouff, nefu,
  { {0xf7d7014e,0xb354018e,0x644701b3,0x00000000}},	//   _מוגש_, екрш, rlji,
  { {0x644700c3,0x60cd0022,0xdb23006c,0x00000000}},	//   slji, twam, érém,
  { {0x6295000f,0x660d002c,0x7bca1ba6,0x00000000}},	// [6670] sszo, _ilak, kefu,
  { {0xc0580054,0xb05b0072,0x660d0014,0x00000000}},	//   піх_, _epän, _hlak,
  { {0x44230035,0x7bca0d1a,0x60cd3a1a,0x00000000}},	//   mij_, defu, swam,
  { {0xe0df008b,0x44233a1b,0x387f0014,0x00000000}},	//   _trò_, lij_, ypur_,
  { {0xdfdb0062,0x660d0077,0x9c59106a,0x00000000}},	//   _лъв_, _mlak, ошку_,
  { {0xa01b0026,0x7bca3a1c,0x44233a1d,0x00000000}},	//   _stöf, gefu, nij_,
  { {0x3946002c,0x660d017f,0x43780047,0x00000000}},	//   _ayos_, _olak, לײגן_,
  { {0xaa560001,0x3ebe0504,0xadd4005e,0x00000000}},	//   мију_, _ätta_, _посљ,
  { {0xdcfb007e,0x63bc001f,0x200e0078,0x00000000}},	//   _ارزش_, yfrn, škių_,
  { {0x7bca0034,0x22490397,0x99dd01c2,0x00000000}},	//   cefu, hlak_, plňo,
  { {0x44233a1e,0x22493a1f,0x660d3a20,0x00000000}},	//   dij_, klak_, _blak,
  { {0x387f3a21,0x629a007d,0xfd07005d,0x00000000}},	//   ppur_, štok, نج_,
  { {0x210100eb,0x442300c2,0x05550363,0x00000000}},	//   nčią_, fij_, етря,
  { {0x442300c3,0xb05b00c7,0x660d3a22,0x00000000}},	//   gij_, _spän, _elak,
  { {0x660d0b9c,0xd7590021,0xf6d50054,0x00000000}},	//   _flak, _بلغت_, _ціля,
  { {0xa5bb027d,0x3a2d3a23,0x00000000,0x00000000}},	//   lión, nnep_,   ,
  { {0x3cf90161,0xc5eb0132,0x7bca0035,0x00000000}},	// [6680] ्नों_, _וַיֹ, yefu,
  { {0x44230198,0x7d060019,0x7c2d0025,0x00000000}},	//   cij_, _üksi, éarl,
  { {0x44443a24,0xb05b00fe,0x224900ea,0x00000000}},	//   _ik_, _epäo, blak_,
  { {0xe9d90045,0x44443a25,0xdca60121,0x00000000}},	//   jdź_, _hk_, дади,
  { {0x44443a26,0x62a3008f,0x6e223a27,0x00000000}},	//   _kk_, īvoš, riob,
  { {0x7d02330d,0x98b1004c,0xe9d90022,0x00000000}},	//   ryos, ůběh_, edź_,
  { {0x7bca0b9c,0xa0670abb,0x44441605,0x00000000}},	//   refu, _цара_, _mk_,
  { {0x44233a28,0x44443a29,0x7bca0f87,0x00000000}},	//   zij_, _lk_, sefu,
  { {0xeb9a0079,0xfc2a0062,0x2d8600ca,0x00000000}},	//   _миа_, _джак_, mboe_,
  { {0xa5bb0024,0x31570047,0x3a2d00a4,0x00000000}},	//   gión, ויפן_, anep_,
  { {0xe8e000aa,0x660d3a2a,0xf795007e,0x00000000}},	//   _đổi_, _plak, رچوب_,
  { {0x4444061a,0x2fd8000c,0x3a3f066d,0x00000000}},	//   _ak_, _larg_, coup_,
  { {0x22490438,0x44233a2b,0x44443a2c,0x00000000}},	//   vlak_, tij_, _bk_,
  { {0x249f0006,0x68e200ea,0x24440137,0x00000000}},	//   šumo_, _irod, döms_,
  { {0x44440146,0xdb1a0080,0x224927cb,0x00000000}},	//   _dk_, _obtí, tlak_,
  { {0x44443a2d,0x442300c2,0x35f80021,0x00000000}},	//   _ek_, sij_, _يريد_,
  { {0x44230933,0x29043a2e,0x44443a2f,0x00000000}},	// [6690] pij_, nyma_, _fk_,
  { {0x22492864,0xf1bf013d,0x1154014b,0x00000000}},	//   slak_, _aját_, ткую,
  { {0x7c2d0027,0x7c230003,0x22493a30,0x00000000}},	//   éarm, vinr, plak_,
  { {0x68e23a31,0xdd9b0086,0xa01b2d60,0x00000000}},	//   _orod, іше_, _stöd,
  { {0x44440a5f,0x30790047,0xdb0901c2,0x00000000}},	//   _yk_, _מאָנ, čníc,
  { {0xe9d90045,0x60c0004b,0x2c7b00dd,0x00000000}},	//   wdź_, _ämma, _râdă_,
  { {0xbb420b4a,0xaa45005e,0x7c2333f2,0x00000000}},	//   лешк, некл, rinr,
  { {0x61fd003d,0x7c2300c7,0xf8af007e,0x00000000}},	//   _josl, sinr, لکت_,
  { {0x61fd3a32,0xa8051501,0x3a3f3a33,0x00000000}},	//   _mosl, езпл, roup_,
  { {0x2240007d,0x68e212cc,0x61fd030c,0x00000000}},	//   zoik_, _drod, _losl,
  { {0x999100ea,0x44440019,0xf6261efa,0x00000000}},	//   őző_, _rk_, едно,
  { {0x6445014f,0x44443a34,0x61fd001c,0x00000000}},	//   _akhi, _sk_, _nosl,
  { {0x44443a35,0x68e23a36,0xddce0078,0x00000000}},	//   _pk_, _grod, _subū,
  { {0x69d90474,0x78bb0026,0x7e693a37,0x00000000}},	//   _hawe, mtuv, _liep,
  { {0xa5bb04a6,0x24560026,0x78bb021e,0x00000000}},	//   gnós, væmd_, ltuv,
  { {0x7e690045,0x69db16a2,0x471a0063,0x00000000}},	//   _niep, ndue, _מוצג,
  { {0x69d90035,0x61f63a38,0xb05b0072,0x00000000}},	// [66a0] _mawe, rjyl, _epäm,
  { {0x248000a4,0x444428d3,0x69d9367b,0x00000000}},	//   _itim_, _uk_, _lawe,
  { {0x93b70063,0x78bb065c,0x29040051,0x00000000}},	//   _אליו_, htuv, zyma_,
  { {0xf1bf034d,0x69d93a39,0xa06a0001,0x00000000}},	//   íšte_, _nawe, _нама_,
  { {0x1016000d,0x7e693a3a,0xdcf7005d,0x00000000}},	//   _зьвя, _diep, فروش_,
  { {0xf5370047,0x2ca61d24,0x00000000,0x00000000}},	//   ענסי_, rrod_,   ,
  { {0x68e2017f,0x6da60141,0x3a2400dd,0x00000000}},	//   _srod, _пива, timp_,
  { {0xdb1f0080,0x2ca60509,0xcb0700f2,0x00000000}},	//   ávát, prod_, عيين_,
  { {0x2007004d,0x6253017d,0x69d93a3b,0x00000000}},	//   önig_, nçoa, _dawe,
  { {0x4c9b0063,0x6253017d,0x25a01d29,0x00000000}},	//   _משמע, içoa, _adil_,
  { {0x69db317f,0xddc700c2,0x32090058,0x00000000}},	//   bdue, _hujš, ykay_,
  { {0x7bda0009,0xceb30047,0x68e23a3c,0x00000000}},	//   _hatu, װיש_, _trod,
  { {0x61fd3a3d,0x7bda3a3e,0x68e20051,0x00000000}},	//   _rosl, _katu, _urod,
  { {0x7bda003e,0x69d90035,0x7d060019,0x00000000}},	//   _jatu, _zawe, _üksu,
  { {0x69d90009,0x236500c7,0x7bda3a3f,0x00000000}},	//   _yawe, älj_, _matu,
  { {0x320900a4,0x7bda3a40,0x00000000,0x00000000}},	//   ukay_, _latu,   ,
  { {0x7e691f12,0x1fa70d82,0x69c000ca,0x00000000}},	// [66b0] _riep, ерег, ifme,
  { {0x6d5d0025,0x60db007d,0xb604004c,0x00000000}},	//   _úsai, _šums, rmář,
  { {0x7e69003d,0x3f91017f,0x4fc40088,0x00000000}},	//   _piep, _vezu_, ыста,
  { {0x78bb0078,0xb5fb013d,0x867b009a,0x00000000}},	//   ytuv, lmáb, פרדו,
  { {0xf53f0205,0xddc0000c,0x7bda3a41,0x00000000}},	//   mgås_, _simţ, _batu,
  { {0x7bda20ce,0x99dd004c,0x80ca0042,0x00000000}},	//   _catu, plňk, _सैटे,
  { {0xf771006a,0x7e693a42,0xdce90066,0x00000000}},	//   یاد_, _tiep, _udeľ,
  { {0x9f58051e,0x78bb0659,0xf53f00d1,0x00000000}},	//   _morì_, ttuv, ngås_,
  { {0x7bda3a43,0x290b0024,0x78bb0b4e,0x00000000}},	//   _fatu, áca_, utuv,
  { {0x69d90009,0xd709093e,0x7bda0d45,0x00000000}},	//   _wawe, дное_, _gatu,
  { {0x78bb047f,0x69d9001f,0xa7550062,0x00000000}},	//   stuv, _tawe, ътищ,
  { {0x78bb008f,0x69cb004c,0xb0ac0082,0x00000000}},	//   ptuv, íneč, टूँग,
  { {0x7bda0035,0x7d060019,0x79893a44,0x00000000}},	//   _yatu, _ükst, mbew,
  { {0x33d52049,0x798906ae,0xa2a60042,0x00000000}},	//   ліст, lbew, _छिद्,
  { {0xd4670138,0xb05b0072,0xf62a0021,0x00000000}},	//   тире_, _epäk, _يسعى_,
  { {0x798905e4,0x4431004d,0x78a90168,0x00000000}},	//   nbew, anz_, orev,
  { {0xf99200b7,0x41270431,0x78a931fa,0x00000000}},	// [66c0] ירן_, вото_, nrev,
  { {0x7989004d,0xc0e30054,0x10050054,0x00000000}},	//   hbew, шоук, ляєм,
  { {0x78a90122,0x7989006f,0x7bda3a45,0x00000000}},	//   hrev, kbew, _ratu,
  { {0xf53f060b,0x78a93a46,0x7bda3a47,0x00000000}},	//   mgår_, krev, _satu,
  { {0x7bda3a48,0x10a30086,0x629c1a62,0x00000000}},	//   _patu, _киян, lsro,
  { {0x2ac60001,0x62531569,0x78a93a49,0x00000000}},	//   вљив, nçon, drev,
  { {0x3cee0053,0xf53f13e7,0x7989004d,0x00000000}},	//   _आपके_, ngår_, fbew,
  { {0x7bda0009,0x58d8042c,0xc3330149,0x00000000}},	//   _watu, едия_, יוו_,
  { {0x9f583a4a,0x78a93a4b,0x7bda0e6c,0x00000000}},	//   _morí_, grev, _tatu,
  { {0xa5bb00ea,0x629c01b0,0x3f85004b,0x00000000}},	//   ciój, ksro, _õlut_,
  { {0xa3c80053,0x55950002,0x66b40121,0x00000000}},	//   ोजन_, ланѓ, ыбну,
  { {0xf53f0146,0x629c00d1,0x78a93a4c,0x00000000}},	//   dgår_, dsro, brev,
  { {0x78a90016,0xe4a70062,0x00000000,0x00000000}},	//   crev, ърно,   ,
  { {0xa3a40138,0x6aaa001f,0xddc20022,0x00000000}},	//   ијск, orff, lloń,
  { {0x442d017f,0x07a300e1,0x2bc40053,0x00000000}},	//   đe_, _тајн, ल्या,
  { {0x35b50330,0xa5bb013d,0x6253006c,0x00000000}},	//   _сбир, ziój, açon,
  { {0x115515ce,0x39da0042,0x4155014b,0x00000000}},	// [66d0] укаю, _मोज़ि, увас,
  { {0xa3d5000a,0x44273a4d,0xee870121,0x00000000}},	//   _сооч, _ön_, выдо,
  { {0x62670021,0xaca3008b,0x629a00ea,0x00000000}},	//   _لاحق, _trừn, átot,
  { {0x78a904aa,0x00000000,0x00000000,0x00000000}},	//   yrev,   ,   ,
  { {0xfd10006a,0xada4000d,0x6aaa002b,0x00000000}},	//   يجه_, раіл, erff,
  { {0xa5bb00ea,0xdddc0058,0xee95005d,0x00000000}},	//   fiók, _turş, _مدرک,
  { {0x63b5001c,0xe4580047,0x6e940cba,0x00000000}},	//   igzn, דיגט_, _вису,
  { {0x78a93a4e,0xb05b004d,0x2bc40082,0x00000000}},	//   trev, _späh, ल्बा,
  { {0x8bb70021,0x7989030c,0x6aaa0046,0x00000000}},	//   _لإضا, rbew, arff,
  { {0x7d04024a,0x78a93a4f,0xa3e20053,0x00000000}},	//   äise, rrev, _नों_,
  { {0xa5bb00ea,0x61ef3579,0x63b80137,0x00000000}},	//   ciók, _oncl, _övni,
  { {0x78a93a50,0xe8950054,0x99b201ce,0x00000000}},	//   prev, _бадь, иjег_,
  { {0xb05b00fe,0x629c0969,0x98a50174,0x00000000}},	//   _epäi, wsro, _силе,
  { {0xe1ff000f,0x61ef006d,0xe612007e,0x00000000}},	//   _fiók_, _ancl, _گشت_,
  { {0xb6a3001b,0x62533a51,0xe9ff0013,0x00000000}},	//   _xuấ, rçon, _ngẫm_,
  { {0xb5fb3a52,0xf53f0a8c,0xe612007e,0x00000000}},	//   rmác, rgår_, _دشت_,
  { {0x62530164,0x463b0047,0x629c27ff,0x00000000}},	// [66e0] pçon, _רעפע, ssro,
  { {0xf53f0137,0x61ef1e3e,0xe0d702dc,0x00000000}},	//   pgår_, _encl, ыву_,
  { {0x442a0019,0x9f5800cd,0x0d86199c,0x00000000}},	//   mib_, _torí_, глен,
  { {0x3ea70027,0x7bc30026,0xf2d30149,0x00000000}},	//   ánta_, efnu, _פער_,
  { {0x40950138,0x7bc300bd,0xb6a3008b,0x00000000}},	//   _врст, ffnu, _suấ,
  { {0x442a1a61,0xa5bb009c,0x9e76005d,0x00000000}},	//   nib_, tiók, _مهست,
  { {0xb6a30013,0x442a004b,0x7d040072,0x00000000}},	//   _quấ, iib_, äisb,
  { {0xaa540001,0x6b980c4a,0x7d0d00ea,0x00000000}},	//   јвиш, savg, önsé,
  { {0x442a1a23,0xc7ba0121,0xdb0800be,0x00000000}},	//   kib_, нён_, _abdô,
  { {0x442a0397,0x99dd0024,0x7e620c5f,0x00000000}},	//   jib_, dlňu, lmop,
  { {0x442a0526,0xa5bb013d,0xe9a6014b,0x00000000}},	//   dib_, liói, _баеп,
  { {0x24560026,0x78c70137,0x442a0244,0x00000000}},	//   væma_, årvä, eib_,
  { {0x249f1123,0x2ed10042,0xd49b082d,0x00000000}},	//   éum_, _सन्त, эрн_,
  { {0xd1bb007e,0x442a3a53,0x7c2a3a54,0x00000000}},	//   کاسا_, gib_, nifr,
  { {0xd25b0818,0xa29502fe,0x17972177,0x00000000}},	//   еца_, рабі, _גדול_,
  { {0xc6930047,0x442a3a55,0x51870002,0x00000000}},	//   _פאפ_, aib_, ѓуба,
  { {0x3fab0001,0xaca30013,0xb6340049,0x00000000}},	// [66f0] ењем_, _trứn, _دعوت,
  { {0x7ae81262,0x7e620229,0xb05b0072,0x00000000}},	//   _ordt, emop, _ysäy,
  { {0x7c2a3a56,0x64472c46,0x3e070085,0x00000000}},	//   difr, moji, лядв,
  { {0x7bc80397,0x61ef1d83,0x64473a57,0x00000000}},	//   _abdu, _uncl, loji,
  { {0x563800b5,0x7ae80139,0xa5bb013d,0x00000000}},	//   נאדע_, _ardt, giói,
  { {0x64472174,0x60120014,0xaae5009e,0x00000000}},	//   noji, _tæma, لسعو,
  { {0x3d953a58,0x7bc30014,0x3ee40062,0x00000000}},	//   _вибр, rfnu, _лютв,
  { {0xbd6b0002,0x7d04004d,0x1a0517f2,0x00000000}},	//   _зрзе_, äisc, рпим,
  { {0x20030a0d,0xd5ed001b,0xa5bb00ea,0x00000000}},	//   _koji_, _giả, ciói,
  { {0xb05b00fe,0x6e2b3a59,0x7c2a3a5a,0x00000000}},	//   _epäv, ligb, cifr,
  { {0x99f50088,0x442a0019,0xe739086c,0x00000000}},	//   _вялі, vib_, тен_,
  { {0x20030089,0x6e2b24f5,0x3a7a0063,0x00000000}},	//   _loji_, nigb, _סטנד,
  { {0x3202027d,0x442a0dbb,0x62853a5b,0x00000000}},	//   _roky_, tib_, _atho,
  { {0x799b006f,0xa01b0014,0x64473a5c,0x00000000}},	//   lauw, _stön, goji,
  { {0xa196005e,0xc7b20063,0x442a3a5d,0x00000000}},	//   ијај, _ובו_, rib_,
  { {0x3ddf006f,0xa5f70001,0x7d0400b9,0x00000000}},	//   _nauw_, _већу_, øisk,
  { {0x62850185,0x64472b27,0x442a004b,0x00000000}},	// [6700] _etho, boji, pib_,
  { {0x60d6001f,0x8fa61e4e,0x22a10078,0x00000000}},	//   rwym, раже, bėk_,
  { {0x3f9a0089,0xf1bf0331,0x23fb0063,0x00000000}},	//   rapu_, _imán_, _ספטמ,
  { {0x3f9a1fdc,0x91e61135,0x6b810046,0x00000000}},	//   sapu_, _томе, _aflg,
  { {0x2ca00025,0x7e623a5e,0x7c2a3a5f,0x00000000}},	//   éid_, rmop, tifr,
  { {0x9f5801a8,0x66040072,0x7e623a60,0x00000000}},	//   _torà_, _loik, smop,
  { {0x7c2a00c7,0x7b630121,0xbea30cd6,0x00000000}},	//   rifr, отъе, _марк,
  { {0xce34006a,0x3ddf006f,0x64470035,0x00000000}},	//   _اورک, _gauw_, zoji,
  { {0xb7bc008f,0x7c2a00a5,0xb05b0050,0x00000000}},	//   liģi, pifr, _epäu,
  { {0x7c2d0025,0x9cd70063,0xf8062363,0x00000000}},	//   éart, _דומה_, рчин,
  { {0xbb46005a,0xd6d7005a,0x66043a61,0x00000000}},	//   _тежк, атя_, _boik,
  { {0x6285006c,0x3946005e,0x386e00a3,0x00000000}},	//   _rtho, _кнег, _wifr_,
  { {0x644713ed,0x44b40062,0xe7860062,0x00000000}},	//   toji, обяс, _куйо,
  { {0x661600ac,0x5726005d,0x37060054,0x00000000}},	//   _elyk, _پرتق, _вчив,
  { {0x661602f0,0x64470df9,0x99dd004a,0x00000000}},	//   _flyk, roji, plňt,
  { {0x64473a62,0xa01b00ea,0x52143a63,0x00000000}},	//   soji, _etöl, одст,
  { {0xb05b0024,0xcf9b0635,0x64473a64,0x00000000}},	// [6710] _opät, вје_, poji,
  { {0x3ea7006d,0x601201e1,0xdff4005e,0x00000000}},	//   ánto_, _dæmo, опуњ,
  { {0x6e2b00d1,0x2fe40021,0xdd910021,0x00000000}},	//   tigb, تكلف, كوا_,
  { {0x7d0b01e3,0x25b90026,0x249f2c46,0x00000000}},	//   tygs, ngsl_, šumu_,
  { {0xe9ff008b,0xddce003b,0x3d29005d,0x00000000}},	//   hoản_, _subţ, دتای_,
  { {0xda780240,0x60cf0089,0x0c240086,0x00000000}},	//   _buď_, _ipcm, омін,
  { {0x2ef5005e,0x3a980085,0x7a3e0023,0x00000000}},	//   _узвр, атыю_, zīte,
  { {0xb05b00fe,0x3f81002b,0x53380063,0x00000000}},	//   _epät, lchu_, ינון_,
  { {0x6e290035,0x7c2d0025,0x39590829,0x00000000}},	//   _imeb, éars, åss_,
  { {0x6d5b003b,0xb5fb004c,0x7aed008f,0x00000000}},	//   _izua, umán, āatb,
  { {0x660400fe,0xa6b40121,0xb5fb3a65,0x00000000}},	//   _poik, осящ, rmán,
  { {0xf40911b4,0x2d9d0c63,0xa01b0137,0x00000000}},	//   _אפ_, nawe_, _stöl,
  { {0x7c28001f,0x660401cf,0xe8ee05ac,0x00000000}},	//   _ymdr, _voik, _эл_,
  { {0xb5fb007a,0x6e3b01a6,0x2d9d0474,0x00000000}},	//   lmál, _ljub, hawe_,
  { {0x3ce60024,0xb5fb3a66,0x6abc00a5,0x00000000}},	//   zvov_, omál, _ärft,
  { {0x661607e6,0x3f98017e,0xb5fb0014,0x00000000}},	//   _ulyk, _seru_, nmál,
  { {0x51560795,0x3f9806e9,0x74ea030b,0x00000000}},	// [6720] ству, _peru_, _сдпг_,
  { {0x33d50054,0x5436005d,0xc9520063,0x00000000}},	//   _діют, _دربر, למן_,
  { {0xe9ff0013,0x6d45004d,0x69cb004d,0x00000000}},	//   _ngắm_, ßhan, _obge,
  { {0xb05b3a67,0x2d9d00e8,0xee3a066e,0x00000000}},	//   _spät, gawe_, ыне_,
  { {0xdd990024,0x61e4005b,0xa91d0078,0x00000000}},	//   _deň_, mdil, pažy,
  { {0x69cb0199,0x3f813a68,0x61e41f4a,0x00000000}},	//   _abge, cchu_, ldil,
  { {0x61e40019,0xfba90086,0x2ef80063,0x00000000}},	//   odil, ртій_, _דִּב,
  { {0xd7f8003b,0xb5fb0014,0xa5bb0139,0x00000000}},	//   rmăm_, gmál, mhóg,
  { {0xd90e006a,0x9f580058,0x60c43a69,0x00000000}},	//   عیت_, _borç_, ntim,
  { {0x60c41404,0x61e400fe,0x7c28004d,0x00000000}},	//   itim, hdil, _umdr,
  { {0x60c40449,0xe7580054,0xd5b10044,0x00000000}},	//   htim, рині_, وفد_,
  { {0x0f570063,0x6b9a006f,0x60c43a6a,0x00000000}},	//   מיים_, _hetg, ktim,
  { {0x61e4001f,0x3f813a6b,0x00000000,0x00000000}},	//   ddil, ychu_,   ,
  { {0x395900bd,0x7c3800ac,0x23740021,0x00000000}},	//   üsse_, nnvr, كافح,
  { {0x60c400eb,0x1b7b0047,0x6b9a090d,0x00000000}},	//   etim, רטלע, _metg,
  { {0x53343629,0xdb18004d,0xa2670062,0x00000000}},	//   чест, bevö, съгл,
  { {0x625313db,0x60f90766,0x307b00de,0x00000000}},	// [6730] nçoi, шная_, احرة_,
  { {0xdb180019,0x249f001c,0x6b9a3a6c,0x00000000}},	//   levõ, šums_, _netg,
  { {0x3ed50021,0x602f0006,0x61e400cd,0x00000000}},	//   تقار, _rėmė, bdil,
  { {0x645500bd,0xdb18004b,0x998d3a6d,0x00000000}},	//   llzi, nevõ, kneš_,
  { {0xeb990259,0xfe70007e,0x60c418b4,0x00000000}},	//   аил_, ردم_, ctim,
  { {0xb05b0072,0xa5bb108e,0x998d0066,0x00000000}},	//   _epär, gnóz, dneš_,
  { {0xf9910021,0xda6505fb,0xa5bb0051,0x00000000}},	//   وبة_, овки, niós,
  { {0x6e290035,0x7c38006f,0x2eee00b9,0x00000000}},	//   _umeb, anvr, æffe_,
  { {0x6d5b003b,0x78390002,0xdb18004b,0x00000000}},	//   _uzua, иџот_, devõ,
  { {0xd825019d,0xa7fc005b,0x5c04000d,0x00000000}},	//   ідни, smın, _няха,
  { {0xb04c0041,0x61e40075,0xda09005d,0x00000000}},	//   רעיִ, ydil, _پيشه_,
  { {0xb9e40054,0x60c43a6e,0x3ced3a6f,0x00000000}},	//   _нічи, ytim, _krev_,
  { {0x955601a7,0x25a9001f,0x69c93a70,0x00000000}},	//   تخدا, _ddal_, mfee,
  { {0xf1bf006d,0x68e906a5,0xc7b70054,0x00000000}},	//   _acá_, mved, _уґо_,
  { {0x68e93a71,0x60c40c7a,0xdb010066,0x00000000}},	//   lved, wtim, _odlí,
  { {0x60c43a72,0x69c93a73,0x68e93a74,0x00000000}},	//   ttim, nfee, oved,
  { {0x7a3e008f,0xe9ff0013,0xc0061657,0x00000000}},	// [6740] nīta, _ngậm_, опак,
  { {0xe29a0138,0xb05b0d88,0x60c43a75,0x00000000}},	//   _као_, _spär, rtim,
  { {0x60c43a76,0xdc2a005d,0xa5bb3a77,0x00000000}},	//   stim, یسته_, ciós,
  { {0x6b9a00cd,0xe1ff3a78,0x27150013,0x00000000}},	//   _setg, _chód_, ín_,
  { {0x973c007d,0x4c940121,0xe8e0008d,0x00000000}},	//   maće, чилс, _đỏi_,
  { {0x7a3e003d,0x2aaa0001,0xddc9000c,0x00000000}},	//   dīta, атио_, _pieţ,
  { {0x6b9a0104,0xad9d0022,0x3ced3a79,0x00000000}},	//   _vetg, _koźl, _erev_,
  { {0xddc9000c,0x6b9a0173,0x5e470002,0x00000000}},	//   _vieţ, _wetg, _дпсм_,
  { {0xd7fa0fec,0x49b70049,0xb5fb004c,0x00000000}},	//   аун_, زايد_, umám,
  { {0x62530003,0xe1ff0025,0x7e7c3a7a,0x00000000}},	//   rçoi, _thóg_, _kurp,
  { {0xdb180004,0xa01b0026,0x7bca001f,0x00000000}},	//   tevõ, _stök, mffu,
  { {0xa4d50086,0x7e7c3a7b,0x7bca00a3,0x00000000}},	//   помі, _murp, lffu,
  { {0xa9260021,0x2715008b,0xe4e40636,0x00000000}},	//   _بعضه, án_, мірн,
  { {0x7bd80019,0xf76f007e,0xdb183a7c,0x00000000}},	//   nevu, عای_, sevõ,
  { {0x7bca2355,0x17f700de,0x00000000,0x00000000}},	//   iffu, _ذروة_,   ,
  { {0xd6280001,0x973c007d,0xdb18013d,0x00000000}},	//   _моје_, gaće, ggvé,
  { {0xa01b00c7,0x64403a7d,0x7d040050,0x00000000}},	// [6750] _utök, émic, äisl,
  { {0x2007007a,0x7bd80080,0x74280021,0x00000000}},	//   ðni_, jevu, _وكيف_,
  { {0x443101f7,0x68e93a7e,0xddc90078,0x00000000}},	//   miz_, zved, _aieš,
  { {0xdb03004d,0x44313a7f,0xe61f00be,0x00000000}},	//   rgnü, liz_, nhô_,
  { {0xe0df0290,0xddc9001c,0xde58000d,0x00000000}},	//   _usò_, _cieš, цаці_,
  { {0x443104ab,0x7bd80004,0x68e9051e,0x00000000}},	//   niz_, gevu, vved,
  { {0x60d9005b,0xb5fb00ea,0x69c90d1e,0x00000000}},	//   şamı, rmáj, tfee,
  { {0x7a3e001c,0xdce80051,0x2cb00058,0x00000000}},	//   tīta, _śląs, üldü_,
  { {0x4431005b,0x69c915a4,0x68e9005f,0x00000000}},	//   kiz_, rfee, uved,
  { {0x7bd8051e,0x87253629,0xb5fb00ea,0x00000000}},	//   cevu, змож, lmáh,
  { {0x68e931aa,0x7a3e008f,0x44313a80,0x00000000}},	//   sved, sīta, diz_,
  { {0x3ebe00d1,0x9f51013d,0x44310023,0x00000000}},	//   _åtte_, _hozó_, eiz_,
  { {0x443130a7,0x973c007d,0x26c501c8,0x00000000}},	//   fiz_, vaće, stlo_,
  { {0x74160044,0xa32a00de,0xb7d900de,0x00000000}},	//   أوسا, مأزق_, _طوعا_,
  { {0x366a0001,0x3f9c0014,0x24560014,0x00000000}},	//   _лако_, ðvum_, næmi_,
  { {0x44313a81,0xd5ed0013,0x15463a82,0x00000000}},	//   aiz_, _già, _нейм,
  { {0x973c017f,0x55bb0063,0x7bc13a83,0x00000000}},	// [6760] raće, _המפו, _oclu,
  { {0x7e7c0034,0x98af0006,0xddc916ff,0x00000000}},	//   _purp, _lygį_, _rieš,
  { {0x41c00121,0x644e3a84,0x42ea093d,0x00000000}},	//   _а́ет, mobi, _умно_,
  { {0xddc93a85,0x24560026,0x7afc00cd,0x00000000}},	//   _pieš, dæmi_, _àrti,
  { {0x2017000f,0x7bd824b7,0xf1b3009a,0x00000000}},	//   áció_, tevu, _אסר_,
  { {0x7e7c003d,0x61e601f7,0xddc90006,0x00000000}},	//   _turp, _hakl, _vieš,
  { {0x61e6295a,0x501b009a,0x00000000,0x00000000}},	//   _kakl, _פולו,   ,
  { {0xddc9003d,0x2d800024,0x7f3b014e,0x00000000}},	//   _tieš, žieb_, _העלו,
  { {0x61e63a86,0x4431005b,0x644e3a87,0x00000000}},	//   _makl, yiz_, kobi,
  { {0x7d0d00fe,0x7bc10025,0x3cfa0053,0x00000000}},	//   äase, _gclu, ्हीं_,
  { {0x61e63a88,0x644e14d5,0x20c60013,0x00000000}},	//   _oakl, dobi, hôi_,
  { {0xcb1300b5,0x6012007a,0x200a2e25,0x00000000}},	//   _אלע_, _dæmi, _lobi_,
  { {0x2ca600a4,0x44313a89,0xa9c5007e,0x00000000}},	//   nsod_, tiz_, _آزمو,
  { {0xb3470016,0x4431039f,0x7bc13a8a,0x00000000}},	//   _naçõ, uiz_, _xclu,
  { {0x44313a8b,0x64402abf,0x7a3e008f,0x00000000}},	//   riz_, émia, nīto,
  { {0x4431005b,0x754800ea,0x76bb0063,0x00000000}},	//   siz_, észé, _המהפ,
  { {0x61e6017f,0x83870076,0xd5ed008b,0x00000000}},	// [6770] _dakl, _ныне, _giá,
  { {0xdb1a0331,0x9054005e,0x61e6004e,0x00000000}},	//   _actí, евуц, _eakl,
  { {0x3ea7000f,0x200a082a,0xe1ff0013,0x00000000}},	//   ént_, _dobi_, _chóc_,
  { {0x9f4a017d,0x7bc10290,0x7a3e001c,0x00000000}},	//   _robô_, _sclu, dīto,
  { {0x2ca600a4,0xed4e3a8c,0xc17425ef,0x00000000}},	//   gsod_, то_, _плющ,
  { {0x61e60a97,0xe0fa0063,0x764f2a5a,0x00000000}},	//   _zakl, _ולשל, hocy,
  { {0x61e601f7,0xe45f00fe,0xcb66026b,0x00000000}},	//   _yakl, ytön_, маше_,
  { {0x644e23b6,0x24560014,0x6c850021,0x00000000}},	//   zobi, ræmi_, _يلزم,
  { {0x629a00ea,0x320b0051,0xe8f90086,0x00000000}},	//   átoz, _mocy_, іло_,
  { {0xb9050042,0xf8ae005d,0xbc3b0043,0x00000000}},	//   _पन_, شکه_, _اسرا_,
  { {0x644e017f,0xfb150021,0x68e201f4,0x00000000}},	//   vobi, _تواج, _esod,
  { {0xcb12014e,0x320b0051,0xc915005e,0x00000000}},	//   _שלא_, _nocy_, _одећ,
  { {0xdddc0006,0x644e3a8d,0xa8eb0044,0x00000000}},	//   _surū, tobi, _دعاك_,
  { {0xb4ce0053,0x61e63a8e,0xe45f00fe,0x00000000}},	//   _रही_, _sakl, stön_,
  { {0xe45f0026,0x61e63a8f,0x78bb0066,0x00000000}},	//   mtöl_, _pakl, luuv,
  { {0x27e7007a,0x2d9f0199,0x69db00bd,0x00000000}},	//   _hann_, _neue_, neue,
  { {0x27e70199,0x80aa0086,0x62830003,0x00000000}},	// [6780] _kann_, ював_, _énon,
  { {0x973c017f,0x2ca600c2,0x61e605b3,0x00000000}},	//   laća, vsod_, _wakl,
  { {0x27e7069e,0x171a0047,0x61e60ba1,0x00000000}},	//   _mann_, ֿונע, _takl,
  { {0x3ea7003b,0x3eba3a90,0xa3c80042,0x00000000}},	//   ânta_, rupt_, ोजक_,
  { {0x3cfa0161,0x25a00019,0xd5e4001b,0x00000000}},	//   ्हें_, _meil_, _chỉ,
  { {0xb5fb0027,0x2d9f00ac,0xdb03017d,0x00000000}},	//   rmái, _eeue_, manê,
  { {0xa6e10026,0x25a000f4,0x69db004d,0x00000000}},	//   óðle, _oeil_, feue,
  { {0xe1ff001b,0x7a3e001c,0x25a03a91,0x00000000}},	//   _khóa_, rīto, _neil_,
  { {0x7a3e001c,0xdb0101e1,0x27e70206,0x00000000}},	//   sīto, _ndlæ, _bann_,
  { {0x3958001c,0x9b930044,0xc7b00044,0x00000000}},	//   ārs_, _للكت, دّد_,
  { {0x27e70199,0x5c370149,0x69e70072,0x00000000}},	//   _dann_, _קרבן_, öreä,
  { {0xa01b00c7,0x64400003,0x27ee0022,0x00000000}},	//   _utöv, émin, _żoną_,
  { {0x27e73a92,0x7d0400fe,0x68e2118f,0x00000000}},	//   _fann_, äish, _usod,
  { {0xdb03017d,0x24800229,0x2a870013,0x00000000}},	//   danê, _duim_, _hđba_,
  { {0x25a00031,0x6adc0161,0x69c000ac,0x00000000}},	//   _feil_, _मनोर, ogme,
  { {0x69c03a93,0xe2540044,0x00000000,0x00000000}},	//   ngme, نَّخ,   ,
  { {0x2a66001f,0x27e70003,0x31343a94,0x00000000}},	// [6790] _mhob_, _yann_, ветр,
  { {0x2d810080,0x25a000ca,0x268a009d,0x00000000}},	//   ěhem_, _zeil_, ַנְּ,
  { {0x4fc40062,0x53350002,0xe8d90013,0x00000000}},	//   ъста, _чент, _ơị_,
  { {0xdb030016,0x2ddb0021,0x625303ea,0x00000000}},	//   banê, تبطة_, rços,
  { {0x2ca90027,0x69c00034,0x2d9f006c,0x00000000}},	//   éad_, dgme, _veue_,
  { {0xc7ce001b,0x2005004b,0x69ce013d,0x00000000}},	//   _sống_, _õli_, őbel,
  { {0xfeb8007e,0x69db00bd,0x6023004c,0x00000000}},	//   _يافت_, teue, růmě,
  { {0x3ebe00c7,0xd5e40013,0x69c000df,0x00000000}},	//   _åtta_, _thỉ, ggme,
  { {0x2919000f,0xb4ce0053,0x973c007d,0x00000000}},	//   ása_, _रहे_, vaća,
  { {0x24803a95,0xddc90066,0x25a03a96,0x00000000}},	//   _ruim_, _dieť, _seil_,
  { {0x27e73a97,0x24800025,0x98ab005b,0x00000000}},	//   _vann_, _suim_, ğlık_,
  { {0x98ab005b,0x27e73a98,0xc7ce008b,0x00000000}},	//   şlık_, _wann_, _uống_,
  { {0x973c007d,0x660d0360,0x25a03a99,0x00000000}},	//   raća, _doak, _veil_,
  { {0x25a00199,0x33d51c15,0x7d0400fe,0x00000000}},	//   _weil_, кіст, äisi,
  { {0x78a90994,0x25a03a9a,0x2cbd006f,0x00000000}},	//   lsev, _teil_, huwd_,
  { {0x6e2200ac,0x79893a9b,0xdb0300be,0x00000000}},	//   xhob, ncew, tanê,
  { {0x78a90031,0x888c00b5,0xe0850032,0x00000000}},	// [67a0] nsev, ַראַ, نجلي,
  { {0x2cbd006f,0x78a90f68,0xb5fb011b,0x00000000}},	//   duwd_, isev, umáv,
  { {0x2cbd006f,0x44443a9c,0xe1fa0062,0x00000000}},	//   euwd_, _ij_, _егн_,
  { {0xa01b00c7,0xdb0300cd,0x645c0323,0x00000000}},	//   _stöt, manè, llri,
  { {0x64410080,0x62810080,0x22403a9d,0x00000000}},	//   čliv, ílov, mnik_,
  { {0x22401361,0x79890089,0xed59004c,0x00000000}},	//   lnik_, ecew, _dyž_,
  { {0x63a30019,0xddc90024,0x2a66001f,0x00000000}},	//   _õnne, _sieť, _phob_,
  { {0x9e66007e,0xfce627c8,0x69c03a9e,0x00000000}},	//   _سازن, _побо, ugme,
  { {0xd7f00021,0xdd8f03eb,0x2240004b,0x00000000}},	//   لكة_, _طول_, inik_,
  { {0x3ea6001c,0x3a3f00e5,0x22403a9f,0x00000000}},	//   ņotu_, anup_, hnik_,
  { {0x2cb000eb,0xdb06024a,0x65953aa0,0x00000000}},	//   žodį_, ämäl, кану,
  { {0x44443aa1,0xb5fb00ea,0x22401228,0x00000000}},	//   _aj_, ilág, jnik_,
  { {0x22403aa2,0x44443aa3,0xba290044,0x00000000}},	//   dnik_, _bj_, _تسلم_,
  { {0x3e670019,0xe45f0014,0x44443aa4,0x00000000}},	//   mõte_, mtök_, _cj_,
  { {0x2456007a,0xdb080080,0x66e3018e,0x00000000}},	//   væmt_, _oddí, _боја,
  { {0x7a3e003d,0x44443aa5,0xb5fb0460,0x00000000}},	//   dītk, _ej_, gmát,
  { {0xe1ff0025,0xb9ca0013,0xe45f0014,0x00000000}},	// [67b0] _fhón_, _sưị_, ntök_,
  { {0x44440031,0xdb0300cd,0xfd65008b,0x00000000}},	//   _gj_, banè, _thuẫ,
  { {0x22400198,0xdd910032,0xfe71007e,0x00000000}},	//   bnik_, لوا_, لگر_,
  { {0xee380086,0x91790013,0x4433008d,0x00000000}},	//   ннє_, hẩm_, _hmx_,
  { {0x61fd3aa6,0x765d000e,0x61ed3aa7,0x00000000}},	//   _insl, ilsy, mdal,
  { {0x212900e3,0x61ed000f,0x7c94006a,0x00000000}},	//   mzah_, ldal, اشنا,
  { {0x9f350086,0x60cd3aa8,0x61ed0b2c,0x00000000}},	//   _реві, ltam, odal,
  { {0x78a93aa9,0x9975005e,0x61ed3aaa,0x00000000}},	//   tsev, купш, ndal,
  { {0x9f430080,0x5c7502a9,0xe45f0026,0x00000000}},	//   _mají_, _алат, gtök_,
  { {0x61ed1039,0xbb840021,0x22401cca,0x00000000}},	//   hdal, _ملكي, znik_,
  { {0xb5fb0080,0x60cd0213,0x44443aab,0x00000000}},	//   klád, htam, _rj_,
  { {0x19950086,0x44210035,0x78a90019,0x00000000}},	//   _радя, _alh_, psev,
  { {0x271c00aa,0x224001b3,0x8884000d,0x00000000}},	//   ản_, vnik_, _бліж,
  { {0x22400045,0x61fd02f0,0x7bc33aac,0x00000000}},	//   wnik_, _ansl, ngnu,
  { {0x22403aad,0x78660014,0x444435b1,0x00000000}},	//   tnik_, uðve, _vj_,
  { {0x78660026,0x61ed3aae,0xdb080003,0x00000000}},	//   rðve, gdal, élép,
  { {0xf3f1001b,0x60cd3aaf,0x9f430080,0x00000000}},	// [67c0] ộc_, gtam, _dají_,
  { {0xa01b35e8,0x61ed3ab0,0x224004d9,0x00000000}},	//   _stör, adal, snik_,
  { {0x2240231f,0xdb03006d,0x44383ab1,0x00000000}},	//   pnik_, bané, mir_,
  { {0x7c210626,0x44383ab2,0x7e693457,0x00000000}},	//   _allr, lir_, _chep,
  { {0x44383ab3,0x60cd3ab4,0x7e7b0150,0x00000000}},	//   oir_, ctam, _diup,
  { {0xdb18000f,0x3e670019,0x1d070001,0x00000000}},	//   egvá, võte_, тељи_,
  { {0x7a3e001c,0xbae30021,0xdbdf0014,0x00000000}},	//   līti, لكوي, ríðu,
  { {0xdbdf007a,0x26140016,0x44383ab5,0x00000000}},	//   síðu, _mãos_, hir_,
  { {0xfce322c1,0x0a67005a,0x443815e2,0x00000000}},	//   _кото, ърши_, kir_,
  { {0xd7f708a6,0x765d006f,0x61ed17cf,0x00000000}},	//   вую_, wlsy, zdal,
  { {0x44383ab6,0xe45f0014,0x61ed3ab7,0x00000000}},	//   dir_, stök_, ydal,
  { {0x7c383ab8,0x44383ab9,0x60cd0022,0x00000000}},	//   livr, eir_, ytam,
  { {0x9f470024,0x44383aba,0xdb03004a,0x00000000}},	//   ľné_, fir_, vané,
  { {0x7a3e003d,0x9f470512,0x44383abb,0x00000000}},	//   dīti, žné_, gir_,
  { {0x6a650025,0x7bc82832,0x63a71aea,0x00000000}},	//   lófa, _mcdu, rajn,
  { {0x60cd3abc,0x61ed001f,0x69dc00ea,0x00000000}},	//   ttam, udal, őref,
  { {0xe7cf0161,0x44380d5c,0xf8b10063,0x00000000}},	// [67d0] त्वप, bir_, ֶשׁ_,
  { {0x4438048e,0x60cd027b,0x7e693abd,0x00000000}},	//   cir_, rtam, _shep,
  { {0xd371006a,0x64550282,0x60cd3abe,0x00000000}},	//   _دهد_, mozi, stam,
  { {0x6455036e,0x60cd3abf,0xadef0042,0x00000000}},	//   lozi, ptam, ज़ाइन_,
  { {0x91ba014e,0xd83800c3,0xdb180146,0x00000000}},	//   _אמרי, kič_, ngvæ,
  { {0xbfb8006a,0xd83800c3,0x6a650139,0x00000000}},	//   _لطفا_, jič_, dófa,
  { {0x62853ac0,0x7bc3007d,0x4993007e,0x00000000}},	//   _juho, rgnu, لیار,
  { {0x63a500bd,0xaa560001,0x44383ac1,0x00000000}},	//   _lehn, лију_, zir_,
  { {0xe1ff001b,0x7d0400fe,0x601200b9,0x00000000}},	//   _nhóm_, äist, _kæmp,
  { {0x661d069f,0xd83800c2,0x443813be,0x00000000}},	//   eksk, gič_, xir_,
  { {0x7a3e001c,0x38ca007e,0xddcb0022,0x00000000}},	//   zīti, وایی_, mogł,
  { {0x44380185,0xe8f50032,0xdb013ac2,0x00000000}},	//   wir_, _مستخ, _relè,
  { {0x4438160e,0x2c69017d,0xdb0100cd,0x00000000}},	//   tir_, aúde_, _selè,
  { {0x44380027,0x64553ac3,0x628500a4,0x00000000}},	//   uir_, gozi, _buho,
  { {0xdb01000f,0x44383ac4,0x232a0925,0x00000000}},	//   _belé, rir_, хови_,
  { {0x443806ec,0x7a3e001c,0xdb010114,0x00000000}},	//   sir_, tīti, _celé,
  { {0x4127065b,0x11d70021,0x645500dd,0x00000000}},	// [67e0] гото_, طولة_, bozi,
  { {0xdb010268,0x7a3e008f,0x201100dd,0x00000000}},	//   _telè, rīti, _cozi_,
  { {0xdb0100ea,0x2d80001c,0xbe850021,0x00000000}},	//   _felé, žiem_, لجنو,
  { {0xe1ff0027,0x52d70047,0x17560047,0x00000000}},	//   _gnó_, _גוטע_, אסער_,
  { {0x7a3e001c,0x7c383ac5,0x321e0078,0x00000000}},	//   nūte, tivr, ūtys_,
  { {0x7c380003,0xc4d30063,0x3f9a005d,0x00000000}},	//   uivr, צגו_, _سپرد_,
  { {0xdddc000c,0x3f6700d7,0xd83806b1,0x00000000}},	//   _curţ, _биро_, vič_,
  { {0x64550009,0x611a001c,0xd5e4008b,0x00000000}},	//   zozi, _tālā, _nhì,
  { {0x02e10053,0xc7ca0121,0x59d30021,0x00000000}},	//   _पन्न, ныне_, صغير,
  { {0x998d0006,0x6a650026,0x7aed0022,0x00000000}},	//   rieš_, rófa, łata,
  { {0xeb97015a,0xd83816a9,0x6aa1002b,0x00000000}},	//   _сих_, rič_, _gwlf,
  { {0x98a60079,0xb5fb1994,0x27ea001c,0x00000000}},	//   _биде, dlác, _šinī_,
  { {0x661d3ac6,0x645500ea,0x62853ac7,0x00000000}},	//   rksk, tozi, _suho,
  { {0x262f004c,0x7aed0023,0xb5fb3ac8,0x00000000}},	//   vřou_, āatv, flác,
  { {0x443f017f,0x20110089,0xa7fc005b,0x00000000}},	//   đu_, _rozi_, rlıd,
  { {0x645500bd,0x95cb0601,0xc0ab043e,0x00000000}},	//   sozi, _чука_, فائل_,
  { {0x6455154c,0xbf1d0053,0xb03534ba,0x00000000}},	// [67f0] pozi, पन्न_, анаш,
  { {0x628500fe,0x27ee0026,0xa5bb013d,0x00000000}},	//   _tuho, _jafn_, skód,
  { {0xdb0102dd,0xdb180137,0x998d00a8,0x00000000}},	//   _telé, ngvä, vnež_,
  { {0xd5e4008b,0x8c9515ce,0x7bde004e,0x00000000}},	//   _khí, аркі, õpun,
  { {0xfaf8003d,0x9e95007e,0x41680002,0x00000000}},	//   _arī_, _چارچ, _бјрм_,
  { {0x27ee007a,0x2fc506a5,0x3ab5005e,0x00000000}},	//   _nafn_, _ølg_, аљит,
  { {0x1b49005a,0xac16005e,0x7d040072,0x00000000}},	//   ъзки_, роју_, äisr,
  { {0x61ef0089,0x99f50054,0x5f4414d7,0x00000000}},	//   _jacl, рякі, _انفل,
  { {0xdb033ac9,0xd8250062,0xd9450a1f,0x00000000}},	//   maní, идии, репи,
  { {0x66db00fe,0x99990051,0x7a3e001c,0x00000000}},	//   _näkö, ósł_, dītu,
  { {0xbb840032,0xdb180137,0x9f5e0013,0x00000000}},	//   _المي, ggvä, _ôtô_,
  { {0xdb030066,0xf3f10013,0xdddc2401,0x00000000}},	//   naní, ộn_, _kurš,
  { {0xd5e4001b,0x5967005a,0x98b8000c,0x00000000}},	//   _chí, _съжа, ără_,
  { {0x03a33aca,0x9f5c013d,0xe7873acb,0x00000000}},	//   жиро, űvé_, _судо,
  { {0xdb030066,0x68fc008f,0x883a009a,0x00000000}},	//   kaní, ārde, _שתצו,
  { {0xc4863acc,0x93430054,0x8506005d,0x00000000}},	//   _клик, інте, _نوبن,

  { {0xddc9003d,0x2d800024,0xdb032ac0,0x00000000}},	// [6800] _biež, žiek_, daní,
  { {0xcef60001,0x9f580014,0xaf9602d8,0x00000000}},	//   ичењ, _borð_, ршај,
  { {0x539b0063,0x0d863acd,0x9fa30046,0x00000000}},	//   _שיטו, ален, ríði_,
  { {0xfcaa0021,0xadb70044,0x76460046,0x00000000}},	//   ناتو_, لهما_, nnky,
  { {0x61e43ace,0x76460072,0xddb70085,0x00000000}},	//   meil, inky, ргіі_,
  { {0x69d900bd,0xa7fc005b,0x201c013d,0x00000000}},	//   _abwe, zlıb, övid_,
  { {0x7f43148d,0x7aed0051,0x6da60086,0x00000000}},	//   _держ, łatn, _виба,
  { {0xd90d007e,0x27ee0026,0x99970062,0x00000000}},	//   کیه_, _safn_, акът_,
  { {0x973c017f,0x094a0062,0xed5a0002,0x00000000}},	//   maći, ъчки_, _роа_,
  { {0x7d28005b,0xa9670002,0x973c007d,0x00000000}},	//   ırsı, шиња_, laći,
  { {0x61e4024a,0x442a0027,0x7e6208f3,0x00000000}},	//   keil, dhb_, olop,
  { {0xd5e4008b,0xd5ed0013,0x68f9002b,0x00000000}},	//   _phí, _khả, _frwd,
  { {0xb8940032,0xa5bb017d,0x4615007e,0x00000000}},	//   _التع, nhói, لوگر,
  { {0xb4d70161,0x76460006,0x7cda001c,0x00000000}},	//   _सही_, anky, mārā,
  { {0xdb1a006d,0xf1a72f16,0x7cda001c,0x00000000}},	//   _actú, иран, lārā,
  { {0xd5e4001b,0x7e6200b9,0xe1ff008b,0x00000000}},	//   _thí, jlop, _khói_,
  { {0xdb03034d,0x60c43acf,0x7bda3ad0,0x00000000}},	// [6810] vaní, guim, _obtu,
  { {0x3a2600cd,0x61e40025,0x7e620137,0x00000000}},	//   _llop_, aeil, elop,
  { {0xdb010146,0x6447017f,0x99840006,0x00000000}},	//   _udlø, mnji, nimų_,
  { {0x973c007d,0x7e623ad1,0x1e84071f,0x00000000}},	//   gaći, glop, ілім,
  { {0x7afa01f7,0x50f4000d,0x25a91c94,0x00000000}},	//   _artt, _дзят, _meal_,
  { {0x99840006,0x7e623ad2,0xd01b0002,0x00000000}},	//   kimų_, alop, _рфм_,
  { {0x998400eb,0x6ef000ea,0x60130080,0x00000000}},	//   jimų_, róbá, _výmě,
  { {0x7e623ad3,0x99840006,0xdddc00c3,0x00000000}},	//   clop, dimų_, _turš,
  { {0xa5bb0025,0xe1ff0013,0x64470734,0x00000000}},	//   chói, _chói_, knji,
  { {0x998d0024,0x7c2a0359,0x08d4000d,0x00000000}},	//   dieť_, chfr, іцыя,
  { {0x644701a6,0x9179008d,0x99840078,0x00000000}},	//   dnji, hầm_, gimų_,
  { {0x25a90025,0x08f9014d,0xfd640013,0x00000000}},	//   _ceal_, _مرتب_, _nguộ,
  { {0xd9450001,0x61e43ad4,0x915e008b,0x00000000}},	//   _ћели, veil, _mặc_,
  { {0x61e40199,0x7e6200ea,0x99840078,0x00000000}},	//   weil, zlop, bimų_,
  { {0x68e90185,0xddc90045,0xb5fb0025,0x00000000}},	//   lwed, _bież, mlán,
  { {0x78c40026,0x60c41703,0xb5fb02fc,0x00000000}},	//   _útví, tuim, llán,
  { {0x998d0066,0x68e91e40,0x66043ad5,0x00000000}},	// [6820] cieť_, nwed, _inik,
  { {0x60c40173,0x68e9001f,0x7e62006f,0x00000000}},	//   ruim, iwed, wlop,
  { {0xd00f0021,0x68e9330b,0x61e43ad6,0x00000000}},	//   علم_, hwed, peil,
  { {0xd5ed001b,0xa5bb0025,0x63ae00a4,0x00000000}},	//   _phả, thói, labn,
  { {0x27e50502,0x4176007e,0x7e62029a,0x00000000}},	//   keln_, _دادس, rlop,
  { {0x68e90185,0x26c5002c,0x7e623ad7,0x00000000}},	//   dwed, kulo_, slop,
  { {0x629c3ad8,0x99d60021,0x27e50e77,0x00000000}},	//   npro, متظا, deln_,
  { {0x998400eb,0xe45f00c7,0x26c53ad9,0x00000000}},	//   vimų_, ntör_, dulo_,
  { {0xdca31705,0xf98f0021,0x27e5004d,0x00000000}},	//   _нати, ربي_, feln_,
  { {0x6e220031,0x99840006,0x25a9010e,0x00000000}},	//   lkob, timų_, _seal_,
  { {0x81040161,0x25a90019,0xeb970063,0x00000000}},	//   रमुख_, _peal_, _הדבר_,
  { {0x99840006,0x6672007e,0xe1ff0013,0x00000000}},	//   rimų_, وگير, _thói_,
  { {0x27e50502,0x68e9001f,0x443a3ada,0x00000000}},	//   beln_, cwed, _bmp_,
  { {0x998d0024,0x7d0d00fe,0x99840006,0x00000000}},	//   rieť_, äasi, pimų_,
  { {0x752f0045,0x26c51e1a,0x998d0024,0x00000000}},	//   szcz, culo_, sieť_,
  { {0x9f51017d,0x6447007d,0x27ea0078,0x00000000}},	//   _fazê_, snji, šinį_,
  { {0x7c3a3adb,0x63ae003e,0x764d0035,0x00000000}},	// [6830] _omtr, babn, _ijay,
  { {0x64400164,0xddc90051,0x66040051,0x00000000}},	//   émit, _wież, _znik,
  { {0xdb0102dd,0x4f6b0cb2,0x68e90022,0x00000000}},	//   _pelí, ушам_, zwed,
  { {0x68e9001f,0x31c70edd,0x6e2200d1,0x00000000}},	//   ywed, _усов, gkob,
  { {0x067c0047,0x224900ea,0x3c2b05a5,0x00000000}},	//   אנאל, mnak_, _løve_,
  { {0x2249000f,0xdb0113ce,0x973c007d,0x00000000}},	//   lnak_, _relâ, laću,
  { {0x69c90122,0x6e2204aa,0xce6b0062,0x00000000}},	//   tgee, bkob, _брад_,
  { {0x2249000f,0x68e900bd,0x7c283adc,0x00000000}},	//   nnak_, twed, _eldr,
  { {0x786f05dd,0x68e9002c,0x26c500ac,0x00000000}},	//   høve, uwed, wulo_,
  { {0x26c5112b,0x69c90760,0x68e930bd,0x00000000}},	//   tulo_, sgee, rwed,
  { {0x2249000f,0x68e91767,0x68fc001c,0x00000000}},	//   knak_, swed, ārda,
  { {0xb5fb3add,0x443a00f3,0x27e500bd,0x00000000}},	//   slán, _smp_, seln_,
  { {0x645e0089,0xb5fb1089,0xe945007e,0x00000000}},	//   _pkpi, plán, _برای,
  { {0x6e29032a,0x629c1ecd,0xb5fb013d,0x00000000}},	//   _lleb, tpro, llál,
  { {0x63ae0198,0x366a28fd,0xd36f0021,0x00000000}},	//   rabn, _како_, َهُ_,
  { {0x9fa3007a,0x2249000f,0x3a3f0089,0x00000000}},	//   _síðu_, gnak_, niup_,
  { {0x7bdc0026,0x10050053,0xdb0a0014,0x00000000}},	// [6840] _örug, रांश_, ínút,
  { {0x6e290024,0x22490397,0x443a3ade,0x00000000}},	//   _aleb, anak_, _ump_,
  { {0x6e2200d1,0x9182008b,0x645c1b69,0x00000000}},	//   tkob, iểm_, mori,
  { {0x645c1ae3,0x6e22007d,0x6da312b9,0x00000000}},	//   lori, ukob, дица,
  { {0x9f470024,0x6e22136a,0x645c078c,0x00000000}},	//   ľná_, rkob, oori,
  { {0x62830164,0x6e223adf,0x9f472f42,0x00000000}},	//   _énor, skob, žná_,
  { {0x60d61405,0x645c3ae0,0xdb033ae1,0x00000000}},	//   ltym, iori, taná,
  { {0xbae50086,0x60d6001f,0x645c3ae2,0x00000000}},	//   яцій, otym, hori,
  { {0x60d63079,0xdb030240,0x645c3ae3,0x00000000}},	//   ntym, raná, kori,
  { {0x60d600eb,0xb5fb000f,0x2249000f,0x00000000}},	//   itym, alál, znak_,
  { {0x2249005b,0x60d60072,0x645c3ae4,0x00000000}},	//   ynak_, htym, dori,
  { {0xe5a40002,0x20183ae5,0x2a87013d,0x00000000}},	//   миџи, _lori_, _főbb_,
  { {0x938b005a,0x61f6001f,0x645c3ae6,0x00000000}},	//   исва_, ddyl, fori,
  { {0x20183ae7,0x786f00d1,0x9faf005b,0x00000000}},	//   _nori_, tøve, _işçi_,
  { {0x2249000f,0x9294000d,0xb5fb00ea,0x00000000}},	//   tnak_, дасц, llám,
  { {0x645c0290,0x786f06a5,0x0638005d,0x00000000}},	//   aori, røve, _وسيع_,
  { {0xdcea0080,0x765d21bd,0x2f8b005e,0x00000000}},	// [6850] čnět, mosy, аљен_,
  { {0x224900ea,0x20180290,0xcf9b02d8,0x00000000}},	//   snak_, _cori_, рја_,
  { {0x2018000c,0x224900ea,0x9ed916fc,0x00000000}},	//   _dori_, pnak_, смет_,
  { {0xb5fb000f,0x5cf5000d,0xe1ff0013,0x00000000}},	//   klám, зяку, _chót_,
  { {0x20180290,0x9f05007e,0xeb992254,0x00000000}},	//   _fori_, _کوزو, бил_,
  { {0x9f430024,0x2018074f,0xdb0313a3,0x00000000}},	//   _majú_, _gori_, nanç,
  { {0x68e21493,0xdb01013d,0x63ba0022,0x00000000}},	//   _apod, _belá, ótni,
  { {0x645c0bee,0x6dc40076,0x7a3e001c,0x00000000}},	//   zori, _осуж, sūtn,
  { {0x645c260e,0xb17b00b9,0xa3dc0053,0x00000000}},	//   yori, _ubåd, ण्ड_,
  { {0xdb0300cd,0xa7fc0058,0x32190cb6,0x00000000}},	//   janç, slın, _losy_,
  { {0xdb0303d9,0xb5fb3ae8,0x645c064f,0x00000000}},	//   danç, mláj, vori,
  { {0x765d00bb,0x60d600fe,0xddc200c2,0x00000000}},	//   gosy, ytym, zmož,
  { {0x2bd20161,0x28060080,0xdb080164,0x00000000}},	//   _सामा, ávní_, _redé,
  { {0x645c00fe,0x9f430024,0xa7fc005b,0x00000000}},	//   uori, _dajú_, nlıl,
  { {0x64400003,0x232724dc,0x479a0063,0x00000000}},	//   émiq, пори_, _פיקס,
  { {0x60d6024a,0x23970080,0x2bd20053,0x00000000}},	//   ttym, tějí_, _साभा,
  { {0x2018001f,0x22400019,0xd259000d,0x00000000}},	// [6860] _pori_, riik_, ццё_,
  { {0xdb030016,0x60d63079,0xceea000d,0x00000000}},	//   canç, rtym, йдзе_,
  { {0x1ee8007e,0xbd8a007e,0xdfcf01fb,0x00000000}},	//   توای_, منان_, ايم_,
  { {0x60d60051,0xdd8f002a,0x34b3005d,0x00000000}},	//   ptym, هوم_, _تمیز,
  { {0x127b00b5,0x6286002c,0xac970021,0x00000000}},	//   _לאטע, _iiko, كننا_,
  { {0xdb030e7b,0xddc20022,0x8aa63ae9,0x00000000}},	//   kanä, lmoż, прид,
  { {0x62860035,0x68e23aea,0xf3f1008b,0x00000000}},	//   _kiko, _spod, ội_,
  { {0xa9c3019d,0x8cc40161,0xdb03005b,0x00000000}},	//   нськ, _रिपो, zanç,
  { {0xdb0137c9,0x68fc008f,0x7a3e008f,0x00000000}},	//   _velá, ārdo, sūto,
  { {0x2cb70080,0x60c43aeb,0x2d800078,0x00000000}},	//   ředí_, irim, žies_,
  { {0xe1ff0025,0x6a6500ea,0x63a3004b,0x00000000}},	//   _mhór_, zófi, _õnni,
  { {0xae02024c,0xdb0101e1,0x62863715,0x00000000}},	//   _रोमन_, _belæ, _niko,
  { {0x68e2040d,0xdb030858,0x248d00be,0x00000000}},	//   _upod, tanç, êem_,
  { {0x765d002c,0x62863aec,0xddc20051,0x00000000}},	//   sosy, _aiko, emoż,
  { {0x60c40004,0xdb033aed,0x27f70080,0x00000000}},	//   erim, ranç, řená_,
  { {0x32640817,0xd7f8000c,0xdb0300f4,0x00000000}},	//   етув, ldă_, sanç,
  { {0xdff50459,0x62860397,0x55bc0063,0x00000000}},	// [6870] мпањ, _diko, _המחו,
  { {0xd7f80529,0x44ef0051,0xe1ff3aee,0x00000000}},	//   ndă_, _iż_, _phós_,
  { {0x2dd50376,0x4fc4000d,0x6a650460,0x00000000}},	//   джер, эста, sófi,
  { {0x60c43aef,0xb5fb004c,0x00000000,0x00000000}},	//   brim, dlák,   ,
  { {0x60c43af0,0x51fa0063,0xed580054,0x00000000}},	//   crim, _והרצ, пої_,
  { {0x6f01017d,0xdb0600dd,0x7c84005e,0x00000000}},	//   _álco, ămîn, нује,
  { {0x6f640076,0xa7fc0058,0xbd0200ca,0x00000000}},	//   _звёз, rlıl, _ééni,
  { {0x68fb0019,0xd5ed008d,0xb905012c,0x00000000}},	//   tvud, _nhà, дзик,
  { {0x68fb00c7,0xa7fc0058,0xb5fb013d,0x00000000}},	//   uvud, lmıy, mláh,
  { {0xb8d50161,0x8afc0045,0xa5bb0026,0x00000000}},	//   _जब_, _częs, skól,
  { {0x44ef0051,0xa7fc005b,0xe0200053,0x00000000}},	//   _aż_, nmıy, _मकसद_,
  { {0xd7f8000c,0xd5ed008b,0x9959003b,0x00000000}},	//   adă_, _chà, _câţi_,
  { {0x628600fe,0xdb010058,0xcdb60063,0x00000000}},	//   _riko, _belç, ופרה_,
  { {0x60c401f7,0x442c08fb,0xa7fc0058,0x00000000}},	//   vrim, ód_, kmıy,
  { {0x232a06da,0xe61a0002,0x62863af1,0x00000000}},	//   цови_, _мдк_, _piko,
  { {0x60c43af2,0x7aed0022,0x91060be8,0x00000000}},	//   trim, łatw, мпбе,
  { {0x75460086,0x21673af3,0x60c43af4,0x00000000}},	// [6880] _іноз, дити_, urim,
  { {0x2bd20235,0x4f950002,0x60c402e3,0x00000000}},	//   _साधा, ерцу, rrim,
  { {0xdb0800b9,0x62860ddd,0xdb0a0530,0x00000000}},	//   _uddø, _tiko, tafí,
  { {0xd5ed001b,0x29000006,0xd7f8000c,0x00000000}},	//   _khá, _šiam_, zdă_,
  { {0xdb0a02dd,0xa7fc005b,0x644e0d1e,0x00000000}},	//   rafí, rmız, onbi,
  { {0xdb0a0118,0x88bd0022,0x644e04a7,0x00000000}},	//   safí, zyśc, nnbi,
  { {0x15ee0053,0xb5fb0e7c,0x644e051c,0x00000000}},	//   ज़ार_, noác, inbi,
  { {0xf2d3014e,0x7d1600d1,0x7f3b0063,0x00000000}},	//   דעה_, øyss, _ועלו,
  { {0xd5ed008b,0x26c51ba2,0xd7c60121,0x00000000}},	//   _nhá, erlo_, мёно,
  { {0x629e017f,0xdb010502,0xd7f8003b,0x00000000}},	//   _otpo, _belä, udă_,
  { {0xd7f8000c,0xb5fb0139,0x88bd0022,0x00000000}},	//   rdă_, llái, tyśc,
  { {0xa5f90076,0x787400cd,0xdb012fb4,0x00000000}},	//   чему_, dàve, _selç,
  { {0x9564005a,0x26c52239,0xa7fc005b,0x00000000}},	//   върд, arlo_, nlık,
  { {0x3e750031,0x7d0400fe,0x3e6e0066,0x00000000}},	//   måte_, äisy, kýto_,
  { {0xd5ed001b,0xb5fb0025,0xdb0100bd,0x00000000}},	//   _thà, hlái, _gelä,
  { {0x9099005a,0xa7fc005b,0x644e006f,0x00000000}},	//   зват_, klık, anbi,
  { {0x682d0025,0x10750121,0x44ef0022,0x00000000}},	// [6890] _húda, елаю, _uż_,
  { {0x44270013,0xe8110042,0xa7fc0058,0x00000000}},	//   _ôn_, ़ाया_, tmıy,
  { {0x26cc02dd,0xfd10007e,0xd251007e,0x00000000}},	//   nudo_, یجه_, _مند_,
  { {0x63b50226,0x60c20006,0x69dc00ea,0x00000000}},	//   lazn, šoma, őrej,
  { {0x3438007e,0xdb08017c,0xeb9922fa,0x00000000}},	//   _رسید_, _dedí, пил_,
  { {0xdb030026,0x62980003,0xa7fc0058,0x00000000}},	//   manú, _évoc, pmıy,
  { {0x60cd024a,0x999f0024,0x6a65013d,0x00000000}},	//   luam, hnuť_, zófu,
  { {0x999f0024,0x61ed121f,0x634e013d,0x00000000}},	//   knuť_, neal, lőné,
  { {0x63b53af5,0xdb030014,0x60cd2a64,0x00000000}},	//   kazn, nanú, nuam,
  { {0x26cc001f,0xe61b085a,0xe739005e,0x00000000}},	//   fudo_, _češč, зео_,
  { {0x61ed3af6,0xadc3008d,0xdb011778,0x00000000}},	//   keal, _hoằn, _belå,
  { {0xd5ed001b,0x998d0051,0xf1bf0139,0x00000000}},	//   _phá, nież_, _ndá_,
  { {0xa5bb0014,0x629e00a8,0x61ed3af7,0x00000000}},	//   rhóp, _stpo, deal,
  { {0xa9220026,0x26c500c2,0x26cc3af8,0x00000000}},	//   _óþar, prlo_, budo_,
  { {0x67d2000a,0x26cc04a6,0x91e63a63,0x00000000}},	//   _соју, cudo_, нове,
  { {0xd5ed001b,0x787400cd,0x2cad00e5,0x00000000}},	//   _thá, ràve, _owed_,
  { {0x2bd20053,0x63b5007d,0x60cd3af9,0x00000000}},	// [68a0] सलमा, bazn, guam,
  { {0xf3f1001b,0x25dc0053,0x3c2b000e,0x00000000}},	//   ột_, ग्री_, _søvn_,
  { {0xf09f051e,0x2bc9016a,0xdb08006d,0x00000000}},	//   _età_, _राजा, _pedí,
  { {0xe29b0063,0xa7fc0058,0x61ed020b,0x00000000}},	//   _משטר, tlık, ceal,
  { {0x621b0047,0x6a650026,0x8c460962,0x00000000}},	//   _זוכק, hófs, неде,
  { {0x3e580024,0xa7fc005b,0xf1bf0240,0x00000000}},	//   dčte_, rlık, _zdá_,
  { {0xb5fb3afa,0x6a650014,0xf1bf0014,0x00000000}},	//   slái, jófs, _slái_,
  { {0x998d0051,0xa7fc0058,0x28a60054,0x00000000}},	//   cież_, plık, ншог,
  { {0x29023afb,0xfce30062,0x7e620130,0x00000000}},	//   íka_, _йото, moop,
  { {0xdb060529,0x26cc0016,0x7e622a8b,0x00000000}},	//   ămân, tudo_, loop,
  { {0xd5ed008b,0x28c20053,0x63b52539,0x00000000}},	//   _nhã, _शिवि, vazn,
  { {0x999f0024,0x26c238e6,0x7e62085b,0x00000000}},	//   tnuť_, čko_, noop,
  { {0x61ed0034,0x28f80076,0x645a0240,0x00000000}},	//   veal, _цель_, čtin,
  { {0x9f470024,0xaad40053,0x76460006,0x00000000}},	//   ľnú_, _धमाक, aiky,
  { {0x9f470024,0xc1a70002,0x61ed3afc,0x00000000}},	//   žnú_, ејзи, teal,
  { {0xfd26001b,0xa3d60053,0x60cd3afd,0x00000000}},	//   _đình_, _हाथ_, tuam,
  { {0x7c2a0031,0x7e623afe,0x63b500c2,0x00000000}},	// [68b0] kkfr, doop, pazn,
  { {0x61ed3aff,0x60cd004b,0xc0580454,0x00000000}},	//   seal, ruam, ніх_,
  { {0x660d23d7,0x61ed3b00,0xc7b30063,0x00000000}},	//   _knak, peal, רבע_,
  { {0x7a3e0006,0x64473b01,0xadbc0086,0x00000000}},	//   būti, liji, зацi,
  { {0x999f0051,0x244d0066,0xeb8e0002,0x00000000}},	//   ykuł_, eľmi_, ии_,
  { {0x3e670019,0x64473b02,0xef670062,0x00000000}},	//   võtu_, niji, _зъбо,
  { {0x2bd20053,0x660d3b03,0x998d0022,0x00000000}},	//   _सारा, _onak, pież_,
  { {0x682400cd,0xaa56005e,0xdb0a0014,0x00000000}},	//   _mòdu, кију_, kafæ,
  { {0xac95005a,0x0b8b0002,0xdb0a002b,0x00000000}},	//   _разш, _есеи_, rafá,
  { {0x7c2a00c7,0x660d1324,0x6c840044,0x00000000}},	//   ckfr, _anak, _ملقم,
  { {0x9182008b,0xe5a60854,0x764606f8,0x00000000}},	//   iếm_, кини, tiky,
  { {0xddc20734,0x9f43013d,0x25e90042,0x00000000}},	//   ološ, _hajó_, ज़गी_,
  { {0x76460050,0x2a8e0022,0x49b800de,0x00000000}},	//   riky, _dębu_, _ساند_,
  { {0x660d3b04,0x4463005a,0x764600fe,0x00000000}},	//   _enak, ивяв, siky,
  { {0xc64a0021,0xfbd20063,0x2a6d004c,0x00000000}},	//   _يجعل_, יתם_, oleb_,
  { {0x29000006,0xdb080066,0xddc23b05,0x00000000}},	//   _šiai_, _jedá, kloš,
  { {0x7bc10117,0xe123005e,0xd1860054,0x00000000}},	// [68c0] _odlu, амти, тлай,
  { {0xddc2017f,0x9f58006d,0x8fa60054,0x00000000}},	//   dloš, _haré_, таже,
  { {0x44443b06,0x7a3e001c,0x68fc001c,0x00000000}},	//   _im_, sūti, ārdi,
  { {0x471a0047,0x78bb065c,0xdb08004a,0x00000000}},	//   וועג, ksuv, _nedá,
  { {0x44443b07,0x7e62047f,0x3e670019,0x00000000}},	//   _km_, roop, võtt_,
  { {0xdca30001,0x682d0024,0xb5fb013d,0x00000000}},	//   шаљи, _súdn, llát,
  { {0x7c2a0014,0x99d60593,0x44443b08,0x00000000}},	//   rkfr, نتظا, _mm_,
  { {0x7bc100b9,0xda090053,0x44443b09,0x00000000}},	//   _edlu, वागत_, _lm_,
  { {0x8e550086,0x44441baa,0xd1050042,0x00000000}},	//   _стрі, _om_, रियण_,
  { {0x6e20048e,0x88bd0045,0x660d3b0a,0x00000000}},	//   _homb, myśl, _snak,
  { {0x61e61cf1,0x6447007d,0x3e750137,0x00000000}},	//   _obkl, viji, låta_,
  { {0x29110027,0x6e200150,0x44443b0b,0x00000000}},	//   ónaí_, _jomb, _am_,
  { {0x6447017f,0x44443b0c,0x9f580331,0x00000000}},	//   tiji, _bm_, _daré_,
  { {0x6e203b0d,0x2a643b0e,0x61e6004d,0x00000000}},	//   _lomb, lomb_, _abkl,
  { {0x6e2000b0,0xc3480062,0x9f5800cd,0x00000000}},	//   _oomb, вяте_, _faré_,
  { {0x44443b0f,0xe5e9024a,0x6e203b10,0x00000000}},	//   _em_, ämää, _nomb,
  { {0x44443b11,0x64470078,0xd658009a,0x00000000}},	// [68d0] _fm_, piji, _שיחת_,
  { {0x26de01cc,0x4ea70002,0x44443b12,0x00000000}},	//   otto_, врда, _gm_,
  { {0x4255007e,0xdd910021,0x6e203b13,0x00000000}},	//   _مندر, موا_, _bomb,
  { {0x29060137,0x74aa0053,0x26de0072,0x00000000}},	//   _oroa_, जीकृ, itto_,
  { {0x44440185,0x44211880,0xb5fb00ea,0x00000000}},	//   _ym_, _koh_, llás,
  { {0xbc640088,0x27fc02ab,0x913a0047,0x00000000}},	//   авік, _navn_, _טערק,
  { {0x2a6d0019,0x3cef0053,0xb5fb00ea,0x00000000}},	//   tleb_, _इनके_, nlás,
  { {0x6e20000f,0x2a6d0019,0xddc23b14,0x00000000}},	//   _gomb, uleb_, ploš,
  { {0x212900f3,0x0e44000d,0xb5fb027d,0x00000000}},	//   nyah_, _тэрм, hlás,
  { {0x44213b15,0xb5fb013d,0x1db30042,0x00000000}},	//   _noh_, klás, ुणवत,
  { {0x44440c64,0x69cf00cd,0x7c210025,0x00000000}},	//   _rm_, òces, _iolr,
  { {0x212900e3,0x61fd3b16,0x629a004a,0x00000000}},	//   kyah_, _nasl, ítom,
  { {0x26de051e,0x44443b17,0x7a3505d5,0x00000000}},	//   atto_, _pm_, _cáte,
  { {0xdb010307,0xd4550086,0x27fc05b9,0x00000000}},	//   _belø, атсь, _gavn_,
  { {0x96f60002,0x69c2002b,0x44440e6c,0x00000000}},	//   _бејт_, _ydoe, _vm_,
  { {0x443300cd,0xe8110042,0x44443b18,0x00000000}},	//   _elx_, ़ावा_, _wm_,
  { {0xb5fb013d,0x3fe63b19,0x6e202fb3,0x00000000}},	// [68e0] rlát, лжав, _romb,
  { {0x44443b1a,0xb5fb3b1b,0xdb030026,0x00000000}},	//   _um_, slát, danþ,
  { {0x0dca0055,0xb5fb3b1c,0x224900ea,0x00000000}},	//   елей_, clás, biak_,
  { {0xed5a0055,0x6e650086,0xb5fb00ea,0x00000000}},	//   ное_, атіж, llár,
  { {0x61e43b1d,0x7d020072,0xdb18004d,0x00000000}},	//   mfil, uvos, ngvö,
  { {0x70560021,0x61fd15df,0x1016000d,0x00000000}},	//   _إنسا, _zasl, _сьмя,
  { {0x6e2007bd,0x2ca62061,0x7d020078,0x00000000}},	//   _tomb, spod_, svos,
  { {0xb5fb0027,0x29062321,0x61e43b1e,0x00000000}},	//   hlár, _proa_, nfil,
  { {0x61e43845,0x7cfa00d1,0x38342254,0x00000000}},	//   ifil, _dørå, инир,
  { {0x803700b5,0xe45f086f,0x4c830141,0x00000000}},	//   ָנטע_, tröm_, _глув,
  { {0x9b93043b,0x26de3b1f,0xab930021,0x00000000}},	//   _المت, utto_, _المغ,
  { {0x443800bd,0x7a350080,0x21291496,0x00000000}},	//   ehr_, _páte, yyah_,
  { {0x673a00ea,0x78a23b20,0x61fd0a1a,0x00000000}},	//   sztj, _utov, _rasl,
  { {0xb4e50053,0x61e43b21,0x61fd2341,0x00000000}},	//   _नही_, efil, _sasl,
  { {0x62980164,0x61fd0d93,0x0cd10161,0x00000000}},	//   _évol, _pasl, _सम्म,
  { {0x53340c07,0x61e42f75,0xb5fb00ea,0x00000000}},	//   щест, gfil, rlás,
  { {0x4421028d,0xa5670032,0x7bda0876,0x00000000}},	// [68f0] _toh_, _حدثن, _octu,
  { {0xf1bf0027,0x61e40019,0x661d0add,0x00000000}},	//   _clár_, afil, ljsk,
  { {0x61fd005b,0xaca30013,0x8db501dd,0x00000000}},	//   _tasl, _trịn, аслі,
  { {0x61fd0025,0x661d01b3,0xddc20051,0x00000000}},	//   _uasl, njsk, mnoś,
  { {0x7c2100f3,0xddc20045,0xa7fc005b,0x00000000}},	//   _polr, lnoś, nlıs,
  { {0x628f0089,0xc49c009a,0x00000000,0x00000000}},	//   _hico, עשות,   ,
  { {0xf9910032,0xea590259,0xddc20051,0x00000000}},	//   يبة_, криј_, nnoś,
  { {0x60cd3b22,0x89a6005a,0x26c30066,0x00000000}},	//   oram, акъв_, ájom_,
  { {0x26cc02dd,0xa3d60053,0xe1ff00cd,0x00000000}},	//   erdo_, _हाल_, _maó_,
  { {0x3a2d021f,0xaae70032,0xd7090076,0x00000000}},	//   skep_, _مسؤو, вное_,
  { {0xddc20051,0x61e4243a,0x79f50062,0x00000000}},	//   jnoś, yfil, _взех,
  { {0xddc20045,0x64553b23,0x61e40137,0x00000000}},	//   dnoś, enzi, xfil,
  { {0x99830006,0x4438002b,0x26cc08c9,0x00000000}},	//   ėjų_, thr_, ardo_,
  { {0xdb030240,0x60cd3b24,0xddc20022,0x00000000}},	//   zaný, dram, fnoś,
  { {0x36d2000a,0x78a93b25,0x3e7c0240,0x00000000}},	//   _дојр, lpev, líte_,
  { {0x98a200eb,0x20110290,0x645534c5,0x00000000}},	//   šką_, _anzi_, anzi,
  { {0x9f470024,0xdb030512,0x60cd2934,0x00000000}},	// [6900] ľný_, vaný, gram,
  { {0x9f470240,0xf09f008b,0xddc20022,0x00000000}},	//   žný_, _tràn_, bnoś,
  { {0x628f0016,0x30750076,0xbd8a007e,0x00000000}},	//   _fico, сутс, چنان_,
  { {0x2d9200d1,0xa3d60053,0x5de6047e,0x00000000}},	//   øye_, _हाँ_, ржда,
  { {0xdb033b26,0x7d090e5c,0x62843b27,0x00000000}},	//   raný, _cres, mmio,
  { {0x8c43005e,0x63bc2e96,0x3e7c004a,0x00000000}},	//   жеље, narn, díte_,
  { {0x661d0051,0x7d093b28,0xb6a50013,0x00000000}},	//   yjsk, _eres, _quậ,
  { {0x0a6a005a,0x628f00cd,0xdb080137,0x00000000}},	//   ърли_, _xico, _nedå,
  { {0x9f5800cd,0xddc20051,0x63bc3b29,0x00000000}},	//   _marí_, znoś, karn,
  { {0x29000006,0xd7f00021,0x63bc3b2a,0x00000000}},	//   _šias_, أكد_, jarn,
  { {0x7d090051,0x63bc3b2b,0xeb970193,0x00000000}},	//   _zres, darn, _тих_,
  { {0x3e7c1994,0x6aaa004d,0x63bc3b2c,0x00000000}},	//   bíte_, mpff, earn,
  { {0x628f3b2d,0xdce0003d,0xe1ff0268,0x00000000}},	//   _rico, _izmē, _raó_,
  { {0xddc20051,0x6455051e,0x63bc3b2e,0x00000000}},	//   tnoś, unzi, garn,
  { {0x628f3b2f,0xa87b009a,0x753d013d,0x00000000}},	//   _pico, _שאור, szsz,
  { {0x60cd3b30,0xddc20051,0x63bc3b31,0x00000000}},	//   tram, rnoś, aarn,
  { {0xddc20051,0x5187293f,0x60cd1e39,0x00000000}},	// [6910] snoś, рува, uram,
  { {0x60cd0fca,0x7d090290,0x25e30042,0x00000000}},	//   rram, _rres, ट्री_,
  { {0x60cd3b32,0xf09f008b,0x3e7c004a,0x00000000}},	//   sram, _trào_, zíte_,
  { {0x7d0901e7,0x7a3c013d,0xdb010114,0x00000000}},	//   _pres, _hétf, _celý,
  { {0xaca3001b,0x787d0164,0x3c390003,0x00000000}},	//   _trọn, lève, _lève_,
  { {0x3e7c004a,0x7d09006f,0x8c670141,0x00000000}},	//   víte_, _vres, штед,
  { {0xad9d0051,0x7d0909b5,0x4ea4005e,0x00000000}},	//   _paźd, _wres, _мрта,
  { {0x05a7016a,0x61e90019,0x3e7c0240,0x00000000}},	//   _क्लब, _öeld, títe_,
  { {0x7d0900c3,0x787d0003,0x39780121,0x00000000}},	//   _ures, hève, исью_,
  { {0x3e7c0024,0x684508a6,0x18690002,0x00000000}},	//   ríte_, ённа, ѓани_,
  { {0x78a91c7b,0x3e7c0512,0x63bc3b33,0x00000000}},	//   spev, síte_, varn,
  { {0xb9950021,0x63bc07c9,0xdb26007e,0x00000000}},	//   _الإب, warn, _دومی,
  { {0x89960063,0x99850021,0x63bc3b34,0x00000000}},	//   _הכנס_, _الشو, tarn,
  { {0xe692007e,0x03a30e34,0x6c790041,0x00000000}},	//   _کليد, зиро, טאָפ,
  { {0x63bc3b35,0xd2990054,0xe29a0002,0x00000000}},	//   rarn, итті_, ѓаа_,
  { {0xd9f90053,0x63bc3b36,0x95960085,0x00000000}},	//   ्यित_, sarn, _ушкі,
  { {0x3ae1007a,0xdb183b37,0x63bc3b38,0x00000000}},	// [6920] hóp_, ravé, parn,
  { {0xdb01000f,0x60cb0026,0x95880022,0x00000000}},	//   _belü, ágma, _ciąż,
  { {0x93fb0047,0xdfa50021,0x67ba0047,0x00000000}},	//   _גליי, تحقي, רמעק,
  { {0x6d030161,0x644e3b39,0xddc20022,0x00000000}},	//   लिंग_, libi, wioł,
  { {0x61f6005b,0xbc4a030b,0x00000000,0x00000000}},	//   meyl, лчке_,   ,
  { {0x6fd5019d,0xdb01000f,0x644e3b3a,0x00000000}},	//   _місц, _felü, nibi,
  { {0x7bd8006f,0x539b0165,0xdb01004d,0x00000000}},	//   rgvu, ניקו, _gelü,
  { {0x648000fe,0xdb1f0080,0x644e3b3b,0x00000000}},	//   löid, ívát, hibi,
  { {0x3c390003,0x644e3b3c,0x1d073b3d,0x00000000}},	//   _sève_, kibi, _лети_,
  { {0x644e0035,0xdb010051,0x64800072,0x00000000}},	//   jibi, _celó, nöid,
  { {0xb05b0137,0x644e3b3e,0x61f60058,0x00000000}},	//   _ovän, dibi, keyl,
  { {0xb05b00c7,0x98c4005b,0x7a350139,0x00000000}},	//   _nvän, ştık_, _táta,
  { {0x9f5800cd,0x59f90047,0x644e3b3f,0x00000000}},	//   _larà_, _כּסד, fibi,
  { {0x3a260250,0x648000fe,0x22950062,0x00000000}},	//   _hoop_, jöid, живя,
  { {0x3a260250,0xe2f90054,0x31c70085,0x00000000}},	//   _koop_, шеві_, йсав,
  { {0x644e002c,0xf494007e,0x3a26006f,0x00000000}},	//   aibi, _کشيد, _joop_,
  { {0x32070080,0x644e3b40,0x7bc80014,0x00000000}},	// [6930] ěny_, bibi, _oddu,
  { {0x644e048e,0xddc90024,0x764f3b41,0x00000000}},	//   cibi, _zmeň, licy,
  { {0x3ea70250,0xa1951a5c,0x5f940062,0x00000000}},	//   ënt_, _манч, чихт,
  { {0xed51006a,0xdb0100ea,0x9f580290,0x00000000}},	//   وپا_, _velü, _darà_,
  { {0xccc40054,0xec6e0131,0xf1c4004c,0x00000000}},	//   збій, дп_, stší_,
  { {0x9f5819c9,0x7c94007e,0xd116009a,0x00000000}},	//   _farà_, سشها, _וקשה_,
  { {0xdb010016,0xdea4007e,0x6a850cd6,0x00000000}},	//   _reló, _فیلی, олка,
  { {0x200306a7,0x644e000c,0x7ae30066,0x00000000}},	//   _haji_, zibi, rtnt,
  { {0x20030397,0x3a260104,0x9f530003,0x00000000}},	//   _kaji_, _doop_, dexé_,
  { {0x9f5802dd,0x752f0051,0x644e0bdb,0x00000000}},	//   _hará_, dycz, xibi,
  { {0x86990079,0x20030009,0xbb55007e,0x00000000}},	//   јтот_, _maji_, _بناب,
  { {0x366a0001,0x20030072,0xa50a0330,0x00000000}},	//   рамо_, _laji_, аема_,
  { {0x644e3b42,0x2be00053,0xdb010331,0x00000000}},	//   tibi, _नामा, _teló,
  { {0xb05b00c7,0x69db3b43,0xdb010046,0x00000000}},	//   _svän, lgue, _aflé,
  { {0x644e3b44,0x69db1494,0x61f60058,0x00000000}},	//   ribi, ogue, teyl,
  { {0x3ebe007a,0x69db3b45,0x644e3b46,0x00000000}},	//   _ætti_, ngue, sibi,
  { {0x9f5802f6,0x80a6007e,0x7a3518a8,0x00000000}},	// [6940] _sarà_, زمان, _láto,
  { {0xdb080024,0x6604077d,0xdb1a00be,0x00000000}},	//   _vedú, _haik, _detê,
  { {0x660409ff,0x44e400fe,0x648000fe,0x00000000}},	//   _kaik, lö_, röid,
  { {0xf1bf001b,0xb76c0047,0x9f5801a8,0x00000000}},	//   _hoán_, נדאָ, _varà_,
  { {0x66040012,0xb05b0137,0x9f580460,0x00000000}},	//   _maik, _kväl, _dará_,
  { {0x660421be,0x2003053b,0xc0f900b5,0x00000000}},	//   _laik, _gaji_, _פּרט,
  { {0x752f0045,0x9f580016,0x7a3c000f,0x00000000}},	//   zycz, _fará_, _léte,
  { {0xa9c30086,0x660432ab,0x7a350066,0x00000000}},	//   мськ, _naik, _dáto,
  { {0x443a3b47,0x60c43b48,0x58860085,0x00000000}},	//   _olp_, nsim, жына,
  { {0x9f4a0164,0x69db3b49,0x60c43b4a,0x00000000}},	//   _abbé_, ague, isim,
  { {0x660428bb,0x752f0051,0x7c3a3b4b,0x00000000}},	//   _baik, wycz, _iltr,
  { {0x752f0045,0xdb180014,0xc985005d,0x00000000}},	//   tycz, naví, _کشمي,
  { {0x66040006,0x78ad0240,0x3ce63b4c,0x00000000}},	//   _daik, čový, ntov_,
  { {0x7a3c03b2,0xdb080d02,0x752f0051,0x00000000}},	//   _déte, _bedø, rycz,
  { {0x43943b4d,0x752f0051,0x3ce600c2,0x00000000}},	//   дарс, sycz, htov_,
  { {0xa3dd016a,0x3ce614d5,0x20030089,0x00000000}},	//   _डाव_, ktov_, _saji_,
  { {0xcf9b0138,0x7c3a051e,0x60c43b4e,0x00000000}},	// [6950] аје_, _oltr, gsim,
  { {0x7c28003d,0x69c03b4f,0x3ce62c7d,0x00000000}},	//   _nodr, hame, dtov_,
  { {0x69c01d36,0x629a00ea,0x9f58039f,0x00000000}},	//   kame, ítot, _pará_,
  { {0x7c3a1c58,0x6e2200ea,0x0dcb018e,0x00000000}},	//   _altr, gjob, ружи_,
  { {0xe45f0137,0x200305b3,0x69c01ea0,0x00000000}},	//   bröt_, _taji_, dame,
  { {0xb4fc0063,0xb09a0063,0x7c283b50,0x00000000}},	//   יפדי, _לישר, _codr,
  { {0x764d00fe,0x7c28027d,0xdb1a006c,0x00000000}},	//   _omay, _dodr, _jetè,
  { {0x69c03b51,0x69db3b52,0x7a35013d,0x00000000}},	//   game, ugue, _gátl,
  { {0xe8e0008b,0x6a640021,0x69db3b53,0x00000000}},	//   _đợi_, بطول, rgue,
  { {0x6e3b0080,0x69c0004b,0x69db1ca9,0x00000000}},	//   _hlub, aame, sgue,
  { {0x66040d68,0x6e3b3b54,0xdb23007e,0x00000000}},	//   _paik, _klub, _توضی,
  { {0x7c280122,0xb5fb017d,0xb05b0137,0x00000000}},	//   _zodr, zoáv, _sväl,
  { {0x9cd501f9,0x6e290c4f,0x66043b55,0x00000000}},	//   הוָה_, _moeb, _vaik,
  { {0x60c40058,0x7a3c013d,0x7bdc00a5,0x00000000}},	//   vsim, _véte, _örut,
  { {0x660400eb,0x44e400fe,0x6fe20053,0x00000000}},	//   _taik, sö_, _पाबं,
  { {0x7a3c00ea,0xa5bb0014,0x3ce60066,0x00000000}},	//   _téte, ljón, ytov_,
  { {0x60c400eb,0xf1bf001b,0xb146026b,0x00000000}},	// [6960] usim, _toán_, чнал,
  { {0x443a00f5,0x69c03b56,0xdb03004b,0x00000000}},	//   _ulp_, zame, lanõ,
  { {0x9f580268,0x60c43b57,0x26c5001f,0x00000000}},	//   _març_, ssim, nslo_,
  { {0x7c2800e8,0x6e3b161d,0x787401a8,0x00000000}},	//   _sodr, _club, ràvi,
  { {0x200c017d,0x69c03b58,0x10a30062,0x00000000}},	//   _ódio_, vame, _пиян,
  { {0x26c50006,0x69c009fe,0x629e3b59,0x00000000}},	//   kslo_, wame, _kupo,
  { {0xcb070021,0x645c051c,0x3ce63b5a,0x00000000}},	//   كيون_, inri, stov_,
  { {0xdb1a0003,0xaf5b0063,0x3ce62029,0x00000000}},	//   _jeté, _הכלכ, ptov_,
  { {0x98a40006,0xb17b04c7,0xa3dd0053,0x00000000}},	//   kymą_, _ubåt, _डाल_,
  { {0x69cb0034,0x69c03b5b,0x7c3a30a8,0x00000000}},	//   _edge, same, _ultr,
  { {0x98a40006,0xb5fb00ea,0x69c03b5c,0x00000000}},	//   dymą_, mláz, pame,
  { {0x0f57014e,0x6b7b0e2a,0x3ebe0026,0x00000000}},	//   ליים_, _פראנ, _ættu_,
  { {0x786f0093,0xed590734,0xab630022,0x00000000}},	//   røvr, _teže_, ężen,
  { {0x2903001c,0xe45f0075,0x78fb009a,0x00000000}},	//   ājat_, erör_, _לפדו,
  { {0x63be0150,0xddc221d5,0xcc770063,0x00000000}},	//   _depn, dlož, פעלה_,
  { {0xeb3b0047,0x645c002b,0x764d3b5d,0x00000000}},	//   זעלש, anri, _umay,
  { {0x236d0051,0x2007017d,0xdb1a017d,0x00000000}},	// [6970] łej_, ônio_, _deté,
  { {0x63870003,0x2f8b005e,0x6e2914a0,0x00000000}},	//   géné, бљен_, _soeb,
  { {0x02a40499,0xfe71005d,0xdb1a013d,0x00000000}},	//   _прям, نگر_, _feté,
  { {0x765d03b1,0xddc23564,0xdd9100f2,0x00000000}},	//   nnsy, alož, نوا_,
  { {0xdb01000f,0x3e7c0080,0xb114000d,0x00000000}},	//   _jelö, mítl_, _змяш,
  { {0x61ed3b5e,0x765d0244,0xad9d056c,0x00000000}},	//   lfal, hnsy, _gaźn,
  { {0x6e290983,0x32091516,0x25a9002b,0x00000000}},	//   _toeb, oday_, _ofal_,
  { {0x6e3b0051,0x61ed3b5f,0x291f01a8,0x00000000}},	//   _ulub, nfal, txua_,
  { {0xb5fb00ea,0xe7d50054,0x7c32013d,0x00000000}},	//   bláz, міню, ükrö,
  { {0x61ed004d,0x3a3f3b60,0x765d3b61,0x00000000}},	//   hfal, shup_, ensy,
  { {0x7bc313c0,0x63be1a55,0x320900e5,0x00000000}},	//   manu, _repn, kday_,
  { {0x26c500eb,0xdb010137,0x629e0460,0x00000000}},	//   rslo_, _belö, _rupo,
  { {0x2b5a0024,0x98a40006,0x61ed3b62,0x00000000}},	//   ĺpce_, tymą_, dfal,
  { {0xe29a1594,0x629e21e4,0xdb03004b,0x00000000}},	//   жав_, _pupo, sanõ,
  { {0xe7e20053,0x68e9000e,0x91e6130d,0x00000000}},	//   _खाता_, lted, мове,
  { {0x11da0021,0x61ed3392,0xdb01013d,0x00000000}},	//   تورة_, gfal, _felö,
  { {0xdb0100bd,0x68e93b63,0xe45f0137,0x00000000}},	// [6980] _gelö, nted, rrör_,
  { {0x7a3c0164,0x888a0047,0x61e9004b,0x00000000}},	//   _méta, ַרײַ, _öeln,
  { {0x441b00b5,0x68e90019,0x141b0047,0x00000000}},	//   _וויס, hted, _וויב,
  { {0x68e901f7,0xddc210f5,0x6387013d,0x00000000}},	//   kted, slož, séné,
  { {0x8c46005a,0x7bc33b64,0xfc660062,0x00000000}},	//   меде, fanu, мъкн,
  { {0x93c5008b,0x2ca912c7,0x7bc33b65,0x00000000}},	//   _nhằ, íada_, ganu,
  { {0xddc6288b,0x160e0053,0xdb01003b,0x00000000}},	//   _обви, ियार_, _aflâ,
  { {0x68e905dd,0x7bc3112c,0x7a3c01ca,0x00000000}},	//   fted, aanu, _béta,
  { {0xf967000d,0x68e900b9,0x765d00d1,0x00000000}},	//   дрэй_, gted, vnsy,
  { {0x7a3c03b2,0xac830088,0x7a353b66,0x00000000}},	//   _déta, _агул, _láth,
  { {0x61ed01f7,0x6d670006,0xdc8b0063,0x00000000}},	//   yfal, ąraš, _וְאָ,
  { {0xa4d501dd,0x68e900e5,0xb604011b,0x00000000}},	//   номі, bted, ynář,
  { {0x09360021,0x765d1df5,0xca370063,0x00000000}},	//   _تراج, rnsy, _קנדה_,
  { {0x3e7504c7,0x7c38006f,0x61ed00e5,0x00000000}},	//   lått_, nkvr, wfal,
  { {0x61ed13f3,0xa5bb0014,0xf539004c,0x00000000}},	//   tfal, ljóm, šť_,
  { {0x7bc33b67,0x60d600a3,0x61ed0244,0x00000000}},	//   zanu, frym, ufal,
  { {0x60d60185,0x32090034,0xe9ff008b,0x00000000}},	// [6990] grym, rday_, hiến_,
  { {0xdb18000f,0xdb0800bd,0x61ed3b68,0x00000000}},	//   zavá, _bedü, sfal,
  { {0x2cad02ab,0x64553b69,0x9df92b4f,0x00000000}},	//   _sted_, mizi, знет_,
  { {0x200702e2,0x64800072,0x7bc313cb,0x00000000}},	//   žni_, nöin, wanu,
  { {0x7bc33b6a,0x4fc71321,0xfe700021,0x00000000}},	//   tanu, _осва, جدل_,
  { {0x7a3c0164,0x68e90024,0x6298017d,0x00000000}},	//   _réta, vted, _évor,
  { {0xdab9000d,0x2be00053,0x7bc33b6b,0x00000000}},	//   чылі_, _नारा, ranu,
  { {0x3e7502f0,0x68e93b6c,0x64553b6d,0x00000000}},	//   gått_, tted, hizi,
  { {0x2d58015a,0xe8f6014c,0xdd120058,0x00000000}},	//   _жить_, елы_, müşt,
  { {0x68e93b6e,0x9c6b005e,0x6455004d,0x00000000}},	//   rted, _прaв, jizi,
  { {0x64553b6f,0x7a350026,0x29020026,0x00000000}},	//   dizi, _láti, ækar_,
  { {0xdd12005b,0x64550023,0xeaf80044,0x00000000}},	//   nüşt, eizi, _تركت_,
  { {0x64550199,0x7bc10397,0x98e50021,0x00000000}},	//   fizi, _kelu, _أكتو,
  { {0xfcb20024,0x443e000f,0xe8d60063,0x00000000}},	//   ýšiť_, ót_, _נוצר_,
  { {0x7bc1053b,0x232a005a,0x2216000d,0x00000000}},	//   _melu, чови_, нфар,
  { {0x60d608eb,0x7bc13b70,0xe1ff3b71,0x00000000}},	//   trym, _lelu, _skór_,
  { {0x64550290,0xe0da3b72,0x708601e4,0x00000000}},	// [69a0] bizi, ява_, егаз,
  { {0x64553b73,0x3fe30002,0x7bc100dd,0x00000000}},	//   cizi, лжув, _nelu,
  { {0xdb1a01e1,0xed5900a8,0x88bd0022,0x00000000}},	//   _udtø, _reža_, zyśp,
  { {0x4d663b74,0x7a353b75,0xf7720047,0x00000000}},	//   нкев, _fáti, נקא_,
  { {0x7bc1014f,0x62980164,0xc19b0aeb,0x00000000}},	//   _belu, _évoq, _משכי,
  { {0x7bc13b76,0xdee62c9e,0x9f580139,0x00000000}},	//   _celu, _поги, _marú_,
  { {0x3e750c4a,0x7bc13b77,0xed590066,0x00000000}},	//   tått_, _delu, _veža_,
  { {0x7bc1004b,0x3f7b0041,0xa9c6005d,0x00000000}},	//   _eelu, _זאלס, رزبو,
  { {0x0d860138,0xed59085a,0x7bc13b78,0x00000000}},	//   _члан, _teža_, _felu,
  { {0x6aa11c9f,0x7bc13b79,0x39590014,0x00000000}},	//   _fulf, _gelu, ússa_,
  { {0x64553b7a,0x64800072,0x3e750137,0x00000000}},	//   vizi, töin, pått_,
  { {0x200a001c,0x8b3b0063,0xdb1801e1,0x00000000}},	//   _labi_, _מתבצ, tavæ,
  { {0x64553b7b,0x648000fe,0x94ab0330,0x00000000}},	//   tizi, röin, ятна_,
  { {0x200a06a7,0xd498032d,0x8c3d003b,0x00000000}},	//   _nabi_, ерс_, _iuşc,
  { {0x64553b7c,0xb05b0137,0x7a350e7c,0x00000000}},	//   rizi, _kväv, _sáti,
  { {0x645502f6,0xa3dd0161,0x7a3c04a6,0x00000000}},	//   sizi, _डाक_, _méto,
  { {0x90990062,0x64553b7d,0x200a373e,0x00000000}},	// [69b0] дват_, pizi, _babi_,
  { {0xd251006a,0xb8810080,0x78a23b7e,0x00000000}},	//   _چند_, _říze, _muov,
  { {0x26de3b7f,0x78a200fe,0x7bc13b80,0x00000000}},	//   nuto_, _luov, _relu,
  { {0x7bc108f0,0x26de0290,0x7a35017d,0x00000000}},	//   _selu, iuto_, _táti,
  { {0x78a202f6,0x7bc10397,0x200a3b81,0x00000000}},	//   _nuov, _pelu, _fabi_,
  { {0x200a002c,0xdb1817cb,0x3e7c0025,0x00000000}},	//   _gabi_, kavä, híth_,
  { {0x7bc1007a,0xdb18112c,0x69c20229,0x00000000}},	//   _velu, javä, _beoe,
  { {0x26de3b82,0x7a3c0164,0x7a35013d,0x00000000}},	//   duto_, _déto, _látv,
  { {0xf865000a,0x7bc13b83,0x2b5a0024,0x00000000}},	//   квио, _telu, ĺpca_,
  { {0x26de0009,0x320b18c0,0xe7391dd0,0x00000000}},	//   futo_, _lacy_, део_,
  { {0x26de01f4,0xdbf90022,0x366a0084,0x00000000}},	//   guto_, _włók, дано_,
  { {0xe7360086,0x69c23b84,0x3ead004c,0x00000000}},	//   тею_, _geoe, _četl_,
  { {0xd4f5000d,0x26de0bda,0xab5c0023,0x00000000}},	//   ляры, auto_, _ieļa,
  { {0x987900b5,0xb5fb0080,0x26de0fbe,0x00000000}},	//   _קאַט, tnác, buto_,
  { {0x200a3b85,0x321a005d,0x42d51cdf,0x00000000}},	//   _rabi_, ويسد_, літу,
  { {0x200a00a4,0xb5fb3b86,0xe9ea0046,0x00000000}},	//   _sabi_, rnác, mbúð_,
  { {0xdb1a0331,0x200a002b,0x71a30456,0x00000000}},	// [69c0] _retí, _pabi_, рауз,
  { {0x1476005d,0xe0430062,0x937a0044,0x00000000}},	//   _جابج, ануи, _يصدر_,
  { {0x200a00c2,0x64800072,0x3e7c013d,0x00000000}},	//   _vabi_, nöim, líti_,
  { {0xed5a0076,0xee3a126b,0xab5c001c,0x00000000}},	//   мое_, ьне_, _neļa,
  { {0x200a215e,0x3e7c00ea,0x5ce30121,0x00000000}},	//   _tabi_, níti_, ающа,
  { {0x61e401f7,0x8fa6000a,0xdb1a017d,0x00000000}},	//   lgil, _јаве, _retâ,
  { {0x7a3510ba,0x61e4004b,0xf1bf0013,0x00000000}},	//   _látu, ogil, _soái_,
  { {0x26de02f6,0x61e43b87,0x8c3d003b,0x00000000}},	//   vuto_, ngil, _puşc,
  { {0x6c060001,0x2d84007d,0x61e43b88,0x00000000}},	//   _изаз, _uzme_, igil,
  { {0x25a00150,0x26de313e,0xdb181fdb,0x00000000}},	//   _agil_, tuto_, tavä,
  { {0xdb0100b9,0x7e623b89,0xfc460066,0x00000000}},	//   _aflæ, onop, žísk_,
  { {0x26de3b8a,0x78a20072,0x7e6204aa,0x00000000}},	//   ruto_, _tuov, nnop,
  { {0x3e7c00ea,0xdb18078c,0x26de3b8b,0x00000000}},	//   gíti_, savä, suto_,
  { {0xe45f00c7,0x7a3518a8,0x26de3b8c,0x00000000}},	//   msök_, _dátu, puto_,
  { {0x7e620438,0xf1a7000a,0xdcc8008b,0x00000000}},	//   knop, врзн, hỉ_,
  { {0xdb1a00cd,0xdde100c2,0x61e43b8d,0x00000000}},	//   _metà, _žuže, ggil,
  { {0x7a350026,0x660d00a4,0x68e0005b,0x00000000}},	// [69d0] _gátu, _iaak, numd,
  { {0xc1040032,0x7e6200b9,0x660d3b8e,0x00000000}},	//   ؤولي, enop, _haak,
  { {0x53350cb5,0x660d3b8f,0x7a350066,0x00000000}},	//   _сент, _kaak, _zátu,
  { {0x68e0008f,0x660d0656,0xd251005d,0x00000000}},	//   kumd, _jaak, _چنگ_,
  { {0x660d3b90,0xd7f1008b,0x7a350014,0x00000000}},	//   _maak, hĩa_, _mátt,
  { {0x69c6007a,0x7a353b91,0x6f150022,0x00000000}},	//   ðken, _látt, _trzc,
  { {0x629d3b92,0xe45f00c7,0x9be40086,0x00000000}},	//   _kiso, esök_, річк,
  { {0x200100e3,0x60cd3b93,0x7a350014,0x00000000}},	//   lehi_, osam, _nátt,
  { {0x3d94019d,0x60cd3b94,0x629d162d,0x00000000}},	//   _витр, nsam, _miso,
  { {0x7d090019,0x7b0800fe,0x25a0001f,0x00000000}},	//   _ises, ästä, _sgil_,
  { {0x6d68000c,0x2bc8000a,0xe73912b9,0x00000000}},	//   ăsaţ, _шуто_, хен_,
  { {0x20cf001c,0x64800072,0x68e03b95,0x00000000}},	//   kļi_, röim, bumd,
  { {0xd6ce007e,0x61e40058,0x00000000,0x00000000}},	//   يقی_, vgil,   ,
  { {0x60cd03cd,0x3e7c013d,0xa2e6173e,0x00000000}},	//   dsam, ríti_, логд,
  { {0x629d055b,0x61e41a0e,0x3e7c00ea,0x00000000}},	//   _biso, tgil, síti_,
  { {0x442a0089,0x3e7c013d,0xb5fb013d,0x00000000}},	//   sjb_, píti_, lnán,
  { {0x76440009,0x60cd3b96,0xdb1a391b,0x00000000}},	// [69e0] _iliy, gsam, _metá,
  { {0x84060086,0x660d0051,0x629d001f,0x00000000}},	//   _спож, _zaak, _eiso,
  { {0x44443b97,0x7d0915a1,0x7644002c,0x00000000}},	//   _il_, _ases, _kliy,
  { {0x5d6a0055,0xb05b0024,0x27760047,0x00000000}},	//   нием_, _svät, אגען_,
  { {0x7a3500ea,0x7e623b98,0x44443b99,0x00000000}},	//   _láts, rnop, _kl_,
  { {0x444400f3,0x7e6200fe,0x4c940121,0x00000000}},	//   _jl_, snop, шилс,
  { {0xb5fb0080,0xb05b00fe,0x9f4a00fe,0x00000000}},	//   dnán, _eväs, äjän_,
  { {0xdd08034d,0x44441d8d,0x2be00053,0x00000000}},	//   môže, _ll_, _नाका,
  { {0xdbf90051,0x660d3b9a,0xb05b0137,0x00000000}},	//   głów, _raak, _tvät,
  { {0x444402b0,0xe45f01e3,0x68e001f7,0x00000000}},	//   _nl_, rsök_, rumd,
  { {0xc0770047,0xddcb00c2,0x7bca0046,0x00000000}},	//   רגיז_, logš, mafu,
  { {0xd6d70076,0xdb0800c7,0x44441ce0,0x00000000}},	//   ыть_, _bedö, _al_,
  { {0x629d3b9b,0x44443b9c,0xdca60021,0x00000000}},	//   _riso, _bl_, تى_,
  { {0x7bca3b9d,0x629d1b20,0xd7f8003b,0x00000000}},	//   nafu, _siso, onăm_,
  { {0x7792007e,0xb05b0137,0x43951f30,0x00000000}},	//   _دیدا, _ovär, равс,
  { {0xf12722c1,0x44443b9e,0x53980086,0x00000000}},	//   льзо, _el_, увся_,
  { {0x90550088,0xd49b3b9f,0x60cd00bd,0x00000000}},	// [69f0] авац, _про_, usam,
  { {0x60cd3ba0,0x44443ba1,0x64800072,0x00000000}},	//   rsam, _gl_, jöih,
  { {0x629d00c3,0x60cd3ba2,0x7a35009c,0x00000000}},	//   _tiso, ssam, _mátr,
  { {0xb5fb0080,0x787d00cd,0x60cd3ba3,0x00000000}},	//   znán, rèvi, psam,
  { {0xb05b0137,0x644b0078,0x200100c2,0x00000000}},	//   _dvär, _įgij, pehi_,
  { {0x26d10024,0xe29f0026,0xab5c001c,0x00000000}},	//   ázok_, _hið_, _ceļo,
  { {0xb5fb0080,0x3f87004b,0xdd050058,0x00000000}},	//   vnán, ünud_, ısız,
  { {0x4df90047,0x4421066d,0xe8f93ba4,0x00000000}},	//   _שפּא, _lnh_, вли_,
  { {0x7a3c0164,0x22490397,0x44210150,0x00000000}},	//   _méth, ihak_, _onh_,
  { {0xc7950121,0x69c9004b,0xb8fd0053,0x00000000}},	//   ирны, saee, _तट_,
  { {0x69cf006d,0xb5fb3ba5,0xf6263ba6,0x00000000}},	//   óces, rnán, адно,
  { {0x4421001b,0x7ae33ba7,0xdb1a05b9,0x00000000}},	//   _anh_, munt, _betæ,
  { {0x44333ba8,0x7ae303db,0x64a60349,0x00000000}},	//   _box_, lunt, рага,
  { {0x7ae304ff,0x99840021,0xc9640086,0x00000000}},	//   ount, _الهو, _увій,
  { {0xb77900b5,0xe29f0026,0x366a0fe2,0x00000000}},	//   _באַש, _bið_, _иако_,
  { {0x76440035,0x7ae33ba9,0xceb80078,0x00000000}},	//   _uliy, iunt, _įę_,
  { {0x7bca3baa,0x394d3bab,0x443303e1,0x00000000}},	// [6a00] yafu, nzes_, _fox_,
  { {0x44443bac,0x7ae3024a,0xb05b00c7,0x00000000}},	//   _ul_, kunt, _svär,
  { {0x7ae31bb7,0x645c3bad,0xaf061fa4,0x00000000}},	//   junt, miri, рпел,
  { {0x13a8007e,0xb5fb00ea,0x645c3bae,0x00000000}},	//   _جنگی_, jnál, liri,
  { {0x7bca10ca,0x64800072,0x7ae30370,0x00000000}},	//   tafu, töih, eunt,
  { {0x394d001c,0xa5bb0014,0x7ae308c9,0x00000000}},	//   dzes_, ljót, funt,
  { {0xb05b00c7,0x7ae30f54,0x0b180021,0x00000000}},	//   _tvär, gunt, اقبة_,
  { {0x645c3baf,0x64800072,0x61f63bb0,0x00000000}},	//   hiri, söih, nfyl,
  { {0x7ae33bb1,0x645c3bb2,0x8c3d0058,0x00000000}},	//   aunt, kiri, _kuşl,
  { {0x7a3c0164,0x645c3bb3,0xb5fb0240,0x00000000}},	//   _méti, jiri, anál,
  { {0x645c3bb4,0xcb671340,0x00000000,0x00000000}},	//   diri, _кафе_,   ,
  { {0x8c3c01f7,0x645c3bb5,0xe7e20053,0x00000000}},	//   _diğe, eiri, _खाका_,
  { {0x7bc8014f,0x61f600b9,0x645c3bb6,0x00000000}},	//   _kedu, dfyl, firi,
  { {0xd7ef0021,0x645c3bb7,0xad640013,0x00000000}},	//   _يكن_, giri, _đừn,
  { {0x22490150,0x61f6002b,0xd5bb0a91,0x00000000}},	//   thak_, ffyl, _исп_,
  { {0x645c0025,0x61d80076,0xd9f80053,0x00000000}},	//   airi, имся_, ्जित_,
  { {0xe29f0ac6,0x2249014f,0x765d0868,0x00000000}},	// [6a10] _við_, rhak_, misy,
  { {0x2fc700aa,0xb5fb3bb8,0x62880268,0x00000000}},	//   úng_, znál, ïdor,
  { {0xcef5005e,0x753d013d,0xb5fb017c,0x00000000}},	//   спећ, lysz, doáz,
  { {0xf1ab007e,0x7a3c0b6d,0x765d3bb9,0x00000000}},	//   _جاده_, _féti, nisy,
  { {0x9f58032a,0x7bc80518,0xdca501d5,0x00000000}},	//   _baró_, _bedu, щали,
  { {0x01360063,0x7bc83bba,0xec780086,0x00000000}},	//   _הרשת_, _cedu, апі_,
  { {0x8b94005a,0x7ae300fe,0x3e7c00ea,0x00000000}},	//   оръч, uunt, gíts_,
  { {0x7e7b3bbb,0x394d3bbc,0xed59082a,0x00000000}},	//   _ukup, tzes_, _leži_,
  { {0x20110009,0x26de3bbd,0x2919017d,0x00000000}},	//   _kazi_, erto_, ísa_,
  { {0x7ae33bbe,0x7bc8036d,0xdb1a0c38,0x00000000}},	//   punt, _gedu, _betä,
  { {0x394d000f,0x4426008b,0x915e008b,0x00000000}},	//   szes_, _đo_, _mắc_,
  { {0x7d1b3bbf,0x645c001f,0x64800072,0x00000000}},	//   _krus, wiri, nöiv,
  { {0xba740032,0x753d00ea,0xca740021,0x00000000}},	//   _بالت, gysz, _بالغ,
  { {0x765d0006,0x1707007e,0x7a3c0003,0x00000000}},	//   aisy, _نفتی_, _réti,
  { {0x765d002c,0x7a3c1560,0x53150062,0x00000000}},	//   bisy, _séti, офту,
  { {0x645c0812,0x7a3c0003,0x28c40053,0x00000000}},	//   siri, _péti, लीवि,
  { {0x61f60026,0x20113bc0,0x41270002,0x00000000}},	// [6a20] rfyl, _bazi_, бото_,
  { {0x224000e8,0x61f62221,0x66063bc1,0x00000000}},	//   skik_, sfyl, lekk,
  { {0x1ea90032,0x2d80001c,0x25ad00c2,0x00000000}},	//   لاني_, ļiem_, žele_,
  { {0x8c3d003b,0x7d1b1304,0x7bc83bc2,0x00000000}},	//   _duşm, _brus, _sedu,
  { {0x7bc8014f,0x8c3d005b,0x2011027c,0x00000000}},	//   _pedu, _tuşl, _fazi_,
  { {0x69dd0026,0x765d005b,0x9f5801f4,0x00000000}},	//   ósen, zisy, _darò_,
  { {0x753d0045,0xb21b00b9,0x7bc83bc3,0x00000000}},	//   zysz, _ihær, _vedu,
  { {0x66060ca9,0x26180053,0x9f580290,0x00000000}},	//   jekk, _बोली_, _farò_,
  { {0x765d00e3,0x7bc80150,0xed460095,0x00000000}},	//   visy, _tedu, _унап,
  { {0x6b81007a,0x6aa8002b,0x26de00c2,0x00000000}},	//   _fylg, _tudf, trto_,
  { {0xbb860021,0x2717008b,0x765d3bc4,0x00000000}},	//   _الاي, _căn_, tisy,
  { {0xdb1a00fe,0x660600ea,0x2446008d,0x00000000}},	//   _vetä, gekk, _rôma_,
  { {0x765d00bb,0xb9960032,0x67d43bc5,0x00000000}},	//   risy, _الشب, _долу,
  { {0x765d00bb,0x26de00c2,0x62843bc6,0x00000000}},	//   sisy, prto_, elio,
  { {0x765d3bc7,0x27e30022,0x66063bc8,0x00000000}},	//   pisy, ójne_, bekk,
  { {0x628402f6,0x915e0013,0x68e000ca,0x00000000}},	//   glio, _sắc_, ormd,
  { {0xc035000a,0x26d10024,0x5187293f,0x00000000}},	// [6a30] онај, ázov_, сува,
  { {0x62843bc9,0x68e0008f,0x00000000,0x00000000}},	//   alio, irmd,   ,
  { {0x5e87000d,0xde35000d,0x9f580290,0x00000000}},	//   будз, жэль, _sarò_,
  { {0x20110035,0xb5fb013d,0xf127066e,0x00000000}},	//   _wazi_, liáb, _льго,
  { {0x915e008b,0x64800072,0xbbe90021,0x00000000}},	//   _tắc_, röiv, لرغم_,
  { {0xb5fb013d,0x6606013d,0x9be7071f,0x00000000}},	//   niáb, zekk, сідк,
  { {0x447c0047,0x6aa23bca,0x7a3c0014,0x00000000}},	//   אנגע, _biof, _létu,
  { {0x648000fe,0x8c3d0058,0x27170013,0x00000000}},	//   löit, _kuşk, _răn_,
  { {0xaca3008b,0x6aa22599,0x27170013,0x00000000}},	//   _trốn, _diof, _săn_,
  { {0x66060983,0xddc20022,0x64800072,0x00000000}},	//   wekk, choł, nöit,
  { {0xdb0800b9,0x89d9007e,0x6284001f,0x00000000}},	//   _afdæ, _نوار_, ylio,
  { {0x2717001b,0x28f90076,0x78bb0213,0x00000000}},	//   _văn_, _ведь_, ppuv,
  { {0xa5bb007a,0x66063bcb,0xdb0100b9,0x00000000}},	//   tjór, rekk, _aflø,
  { {0x2d8d0035,0x648000fe,0x66061925,0x00000000}},	//   _mzee_, jöit, sekk,
  { {0x03a3101a,0x69cb3bcc,0x78ab0014,0x00000000}},	//   диро, _kege, _hugv,
  { {0x69cb3bcd,0x62843bce,0x26d10124,0x00000000}},	//   _jege, ulio, ázou_,
  { {0x2d8d0035,0x2b5a0024,0x69cb3bcf,0x00000000}},	// [6a40] _nzee_, ĺpci_, _mege,
  { {0x57cc00b5,0x6fd5000d,0x69cb3bd0,0x00000000}},	//   ָמאַ, зіцц, _lege,
  { {0x78a33bd1,0x78ab00ac,0xeda62c9e,0x00000000}},	//   _minv, _lugv, ошло,
  { {0x69cb3bd2,0x5bb40042,0x0d860d4e,0x00000000}},	//   _nege, ुर्व, олен,
  { {0xc27b014e,0xf6530063,0xb5fb0066,0x00000000}},	//   _כרטי, וצא_, liác,
  { {0x8c430076,0xdfd2006a,0x7f76000d,0x00000000}},	//   мече, _زير_, _дубц,
  { {0x69cb1b28,0x291d00a4,0x64800072,0x00000000}},	//   _bege, _arwa_, löis,
  { {0xe45f00c7,0xb5fb10fd,0x6edc003b,0x00000000}},	//   nsör_, rnák, răbă,
  { {0xed5a0079,0x69d9001f,0x9997005a,0x00000000}},	//   _тоа_, _ddwe, окът_,
  { {0x29da0013,0x6d37009d,0x00000000,0x00000000}},	//   ừa_, _וטמא_,   ,
  { {0x69cb2667,0xd7f8003b,0x76aa0131,0x00000000}},	//   _fege, rfă_, јтов_,
  { {0xa5f90076,0x69cb3bd3,0x64800072,0x00000000}},	//   щему_, _gege, köis,
  { {0xb5fb0025,0x7e9b01f9,0xb865007e,0x00000000}},	//   nnái, יסטו, _کانو,
  { {0x69cb006f,0x3ea400d1,0xaaa90053,0x00000000}},	//   _zege, _limt_, _चूँक,
  { {0x3a260a53,0xb5fb3bd4,0xd25b1ac1,0x00000000}},	//   _knop_, riáb, аца_,
  { {0xb21b00b9,0x78a3006f,0xdb1f013d,0x00000000}},	//   _skæb, _zinv, övér,
  { {0x3fab0138,0x25a90019,0xc6940047,0x00000000}},	// [6a50] ањем_, _igal_, _קאפ_,
  { {0x644e0359,0x7a3c00ea,0x24b80063,0x00000000}},	//   chbi, _kéts, _והזן_,
  { {0xb5fb0024,0x648000fe,0x10480054,0x00000000}},	//   ciác, röit, цяти_,
  { {0x9f580026,0x7bda013d,0x2d9901d1,0x00000000}},	//   _varð_, _adtu, _úsek_,
  { {0x69cb3bd5,0x320900a4,0xdb1a017d,0x00000000}},	//   _rege, meay_, _getú,
  { {0x113a01f9,0x69cb3bd6,0x61ed3bd7,0x00000000}},	//   _התשל, _sege, lgal,
  { {0x78a30290,0x69cb3bd8,0xeb990b3f,0x00000000}},	//   _rinv, _pege, щик_,
  { {0xefc8008b,0x61ed3bd9,0x88c90131,0x00000000}},	//   _đỉnh_, ngal, блив_,
  { {0x7a3c007a,0x69cb3bda,0xb5fb0066,0x00000000}},	//   _rétt, _vege, ziác,
  { {0x69cb0995,0x1bf20053,0xa2dc0053,0x00000000}},	//   _wege, _घायल_, _फिल्,
  { {0x69cb3bdb,0x1e950063,0xed593bdc,0x00000000}},	//   _tege, ּכָל_, _vežu_,
  { {0x63b50051,0x291d0051,0xaca3008b,0x00000000}},	//   eczn, _trwa_, _trồn,
  { {0x28f8000d,0x04b6042c,0x03a60001,0x00000000}},	//   _мець_, ясня, зиго,
  { {0xa5070001,0x25a93bdd,0x2ab10014,0x00000000}},	//   џера_, _egal_, _káb_,
  { {0xdb1a00be,0x68e90072,0x28120021,0x00000000}},	//   _setú, lued, _سويس,
  { {0xcb1200b5,0x61ed2a43,0x673c01a5,0x00000000}},	//   עלן_, ggal, ärje,
  { {0xb5fb0066,0x41270601,0x2ab1009c,0x00000000}},	// [6a60] siác, пото_, _láb_,
  { {0x3ea4000c,0x61ed18a1,0xe45f0137,0x00000000}},	//   _simt_, agal, ssör_,
  { {0xe45700b5,0xc43b0063,0x645e3bde,0x00000000}},	//   _זייט_, _התיי, _impi,
  { {0x7a3c000f,0x443a3bdf,0x00000000,0x00000000}},	//   _létr, _hop_,   ,
  { {0x443a0179,0x2ca52063,0x661600a4,0x00000000}},	//   _kop_, _bild_, _mayk,
  { {0xb5fb0405,0x68e9002b,0x1eaa0021,0x00000000}},	//   rnái, dued, _هاري_,
  { {0xaab8007e,0xc879003b,0x60d60244,0x00000000}},	//   زگار_, cuşi_, lsym,
  { {0xe9e3130d,0xeaaf0021,0x98b83121,0x00000000}},	//   нцьо, دعو_, олит_,
  { {0x63b50045,0x68e9001f,0xb5fb017d,0x00000000}},	//   yczn, gued, onáv,
  { {0x2ca50026,0x7e623be0,0x60d60078,0x00000000}},	//   _gild_, liop, isym,
  { {0x7a3c0164,0xab7a007e,0x9f5800cd,0x00000000}},	//   _détr, _امضا_, _obrí_,
  { {0x645e051e,0x8c3d000c,0x60d62931,0x00000000}},	//   _ampi, _ruşi, ksym,
  { {0xab5c008f,0xd90e007e,0x6d420859,0x00000000}},	//   _ceļv, _صید_, nyoa,
  { {0x443a0994,0xdb1a02ab,0x60d63be1,0x00000000}},	//   _cop_, _betø, dsym,
  { {0x1dcc0053,0xb5fb004a,0x443a3be2,0x00000000}},	//   ारात, dnáv, _dop_,
  { {0x62343be3,0xe2840002,0x645e2308,0x00000000}},	//   несу, еѓун, _empi,
  { {0x61ed3be4,0x1007000d,0x7e623be5,0x00000000}},	// [6a70] rgal, зяем, diop,
  { {0xc8790529,0x7c3a3be6,0x61ed2545,0x00000000}},	//   tuşi_, _notr, sgal,
  { {0x2cad00e5,0x7e6201e1,0xfeb80021,0x00000000}},	//   _sued_, fiop, كانت_,
  { {0x7c282453,0xb6a40013,0xc879003b,0x00000000}},	//   _andr, _nhẫ, ruşi_,
  { {0xc879000c,0xd5fc0047,0x2ab100ed,0x00000000}},	//   suşi_, מפאר, _sáb_,
  { {0xf1c4027d,0xa0a4000d,0xc879003b,0x00000000}},	//   prší_, _паўд, puşi_,
  { {0x764d005b,0xfbd03be7,0x7a3c0003,0x00000000}},	//   _olay, اته_, _rétr,
  { {0x7c280d96,0xca06005a,0x3ebc0024,0x00000000}},	//   _endr, днъж_, ívte_,
  { {0x2cad0019,0x7a3c3be8,0x7aea004d,0x00000000}},	//   _uued_, _pétr, auft,
  { {0xefc8001b,0x103a0047,0x2ab10139,0x00000000}},	//   _định_, ַגרע, _táb_,
  { {0xc7a50002,0xddc2007d,0x764d3be9,0x00000000}},	//   ќинк, lnoš, _blay,
  { {0x2b4f01f7,0xdbcc007a,0x60d600fe,0x00000000}},	//   ımcı_, lóði, ysym,
  { {0x68e92f7e,0x443a3bea,0x2a6d004b,0x00000000}},	//   qued, _pop_, mneb_,
  { {0x93c3003b,0x6e3b006c,0x2a6d004b,0x00000000}},	//   _ţărm, _loub, lneb_,
  { {0x64a30088,0x63833beb,0xb5fb004a,0x00000000}},	//   тара, вгра, vnáv,
  { {0xe1fa000d,0x2a6d004b,0xb659000d,0x00000000}},	//   ўга_, nneb_, _ншых_,
  { {0xdbcc0014,0xddc2007d,0x10a601a4,0x00000000}},	// [6a80] kóði, jnoš, диан,
  { {0x6d420035,0xb05b0024,0xddc2007d,0x00000000}},	//   vyoa, _zväz, dnoš,
  { {0x287a0047,0x6e3b33fb,0xdfcf01fb,0x00000000}},	//   קנעמ, _boub, شين_,
  { {0x93ee0161,0xdd8a0330,0x6e3b3bec,0x00000000}},	//   _जाँच_, обед_, _coub,
  { {0x6e3b3bed,0x7c3a3bee,0xc8790058,0x00000000}},	//   _doub, _potr, luşu_,
  { {0x7c830076,0x2a6d004b,0x6e293bef,0x00000000}},	//   куще, eneb_, _eneb,
  { {0x7c3a0c6e,0x212200e3,0xce4a000d,0x00000000}},	//   _votr, _hrkh_, _дзве_,
  { {0x20180397,0x38b2002b,0xb5fb0014,0x00000000}},	//   _hari_, _pâr_, nnát,
  { {0x93ee0053,0x67d41406,0x20183bf0,0x00000000}},	//   _जांच_, нопу, _kari_,
  { {0x6c030001,0x8b26000a,0x764d1a8d,0x00000000}},	//   _изуз, _одзе, _slay,
  { {0x764d3bf1,0x26d80003,0xd5ed0013,0x00000000}},	//   _play, éro_, _nhạ,
  { {0x20180397,0x39460932,0x3dc63bf2,0x00000000}},	//   _lari_, _онег, nbow_,
  { {0x94ab000d,0x25ad0266,0x3ce60066,0x00000000}},	//   ютна_, želo_, nrov_,
  { {0x36d40086,0x3ce600c2,0xb5fb240a,0x00000000}},	//   _зокр, irov_, cián,
  { {0xd5ed001b,0x02a724ad,0xddc20130,0x00000000}},	//   _chạ, драм, znoš,
  { {0x764d0009,0x2018002c,0x9294000d,0x00000000}},	//   _ulay, _aari_, васц,
  { {0xdb1a0026,0x6e3b3bf3,0x20183bf4,0x00000000}},	// [6a90] _netþ, _roub, _bari_,
  { {0x6e3b0080,0xdfd10032,0x2a64000c,0x00000000}},	//   _soub, ايا_, himb_,
  { {0x2018014f,0x2a6d001f,0x3f870014,0x00000000}},	//   _dari_, yneb_, ænu_,
  { {0xb05b089f,0xddc2007d,0x539a0063,0x00000000}},	//   _städ, tnoš, _מיתו,
  { {0xe3a5007e,0x6e2900c2,0xddc2008f,0x00000000}},	//   _تشکی, _vneb, unoš,
  { {0x20180035,0x6b880022,0xddc2218f,0x00000000}},	//   _gari_, _bydg, rnoš,
  { {0xb5fb029c,0x1b4901d5,0xddc22341,0x00000000}},	//   vián, язки_, snoš,
  { {0x5f9400d7,0xc2120063,0x3ce616a9,0x00000000}},	//   _рист, ָ֔ה_, brov_,
  { {0x201800a4,0x7a35008d,0x5c751f1d,0x00000000}},	//   _yari_, _mátx, _злат,
  { {0x2a6d0019,0xc0520047,0x32190022,0x00000000}},	//   sneb_, ָזט_, _lasy_,
  { {0xb5fb3bf5,0x96660092,0x22490075,0x00000000}},	//   jnás, екне, kkak_,
  { {0xb21b00b9,0xfb1a0063,0xf65200f2,0x00000000}},	//   _skæn, _מועמ, ائد_,
  { {0xe1ff0014,0x2a3600de,0x00000000,0x00000000}},	//   _ljós_, _سكود_,   ,
  { {0x8c3d005b,0xd5ed008b,0x6f150051,0x00000000}},	//   _tuşu, _phạ, _oszc,
  { {0x2018235d,0xe29a0156,0x6f020022,0x00000000}},	//   _rari_, зав_, łocz,
  { {0x20183bf6,0xdb1a0061,0x68fb002b,0x00000000}},	//   _sari_, _netý, otud,
  { {0x20183bf7,0x26d80024,0x68fb3bf8,0x00000000}},	// [6aa0] _pari_, árov_, ntud,
  { {0x68fb0019,0x32193bf9,0x291f0072,0x00000000}},	//   itud, _easy_, ivua_,
  { {0x68fb0004,0x20183bfa,0xb5fb1d6b,0x00000000}},	//   htud, _vari_, cnás,
  { {0xee3a3bfb,0x68fb00b9,0x3ce6160f,0x00000000}},	//   яне_, ktud, trov_,
  { {0xb5fb0836,0x2372001c,0xac1800da,0x00000000}},	//   onár, šajā_, долу_,
  { {0x60c43bfc,0xc4d30063,0x7e600022,0x00000000}},	//   mpim, נגו_, _wmmp,
  { {0x68fb13b3,0xddc2004c,0xfaa60505,0x00000000}},	//   etud, zhoř, ншин,
  { {0x75241386,0x3ce63bfd,0x60c40072,0x00000000}},	//   _oriz, prov_, opim,
  { {0x68fb00ea,0x3f8a001f,0xc866012d,0x00000000}},	//   gtud, _hybu_, етни,
  { {0x60c400eb,0x66040019,0x2a6a00ea,0x00000000}},	//   ipim, _abik, őbb_,
  { {0x291f0072,0x75243bfe,0xf8030085,0x00000000}},	//   avua_, _ariz, учын,
  { {0x2120017f,0x75243bff,0xb5fb3c00,0x00000000}},	//   kvih_, _briz, ciál,
  { {0x7524000c,0xdb0800b9,0x758b0121,0x00000000}},	//   _criz, _afdø, ясов_,
  { {0x62863c01,0x38cb007e,0xddc9007d,0x00000000}},	//   _akko, _راهی_, _mješ,
  { {0x60c433ab,0x75240331,0xddc9007d,0x00000000}},	//   epim, _eriz, _lješ,
  { {0xa7fc0058,0xdddb007d,0xb5fb3887,0x00000000}},	//   anıt, _okuš, rnás,
  { {0x60f917ab,0x067c0063,0x660f004a,0x00000000}},	// [6ab0] ьная_, _מנהל, meck,
  { {0xcf9b000a,0x628600ea,0x661d02e0,0x00000000}},	//   пје_, _ekko, ldsk,
  { {0x661d00e8,0xdb1a0024,0xc88500bd,0x00000000}},	//   odsk, _metó, äßig_,
  { {0xddc9007d,0x660f3c02,0xdb18004b,0x00000000}},	//   _bješ, neck, navõ,
  { {0xed58148d,0x64480137,0xdd94000d,0x00000000}},	//   ної_, ödig, гацы,
  { {0xa49b00cd,0xdb18004b,0x660f3c03,0x00000000}},	//   stòf, havõ, heck,
  { {0xa49b01a8,0x61f601e1,0x6f150022,0x00000000}},	//   ptòf, _æglø, _uszc,
  { {0x628d00a4,0x661d32c3,0xe79a004c,0x00000000}},	//   nlao, jdsk, _běží,
  { {0x661d3c04,0xdb18004b,0xdb1a0066,0x00000000}},	//   ddsk, davõ, _betó,
  { {0x661d00ac,0x68fb3086,0xf9820062,0x00000000}},	//   edsk, rtud, ргьо,
  { {0xdddb0080,0xf0920063,0x68fb3c05,0x00000000}},	//   _zkuš, שני_, stud,
  { {0x672300c2,0x6b84004d,0x6d590051,0x00000000}},	//   _vrnj, ßige, ozwa,
  { {0x69c93c06,0xd94502d8,0x99d40044,0x00000000}},	//   mbee, _јели, _إتما,
  { {0xa2e60076,0x661d3c07,0x69c90d13,0x00000000}},	//   когд, adsk, lbee,
  { {0xe739019d,0x68e93c08,0xb5fb3c09,0x00000000}},	//   _цей_, lred, rnár,
  { {0x26c50747,0x69c90717,0x628d119c,0x00000000}},	//   mplo_, nbee, glao,
  { {0x21673c0a,0x68e93c0b,0x50b60416,0x00000000}},	// [6ac0] вити_, nred, тсбу,
  { {0xddc9017f,0x60c43716,0x6d593c0c,0x00000000}},	//   _rješ, rpim, dzwa,
  { {0x7d090016,0x68e90185,0xdddb00c3,0x00000000}},	//   _apes, hred, _skuš,
  { {0x68e9060b,0xddc9007d,0x9e660062,0x00000000}},	//   kred, _pješ, ъвед,
  { {0x68e900b9,0x9cb30021,0xb5fb013d,0x00000000}},	//   jred, لمنت, fiáj,
  { {0xddc9017f,0xb5fb00ea,0x68e93c0d,0x00000000}},	//   _vješ, giáj, dred,
  { {0x69c90122,0x6aab1269,0x661d3c0e,0x00000000}},	//   fbee, _bigf, ydsk,
  { {0xf2d30063,0x68e93c0f,0x798b0e7f,0x00000000}},	//   בעה_, fred, _bygw,
  { {0x660f3c10,0x672100c2,0x25ad00c2,0x00000000}},	//   veck, evlj, želk_,
  { {0x660f3c11,0xeb9a005d,0x798b00a3,0x00000000}},	//   weck, _قضات_, _dygw,
  { {0x660f2433,0xb21b01e1,0x68e93c12,0x00000000}},	//   teck, _skæm, ared,
  { {0x3ce91253,0x68e91781,0x7bd83c13,0x00000000}},	//   šave_, bred, lavu,
  { {0x68e91e27,0x660f3c14,0x6721007d,0x00000000}},	//   cred, reck, avlj,
  { {0x26d800ea,0xdb18004b,0x7bd83c15,0x00000000}},	//   áros_, savõ, navu,
  { {0x3879000f,0x07f7007e,0xe5c73c16,0x00000000}},	//   ésre_, _شروع_, _испо,
  { {0x3547000d,0x62580139,0x765d0078,0x00000000}},	//   _ахов, _líof, ūryb,
  { {0x51873c17,0x7bd82e01,0xd49b1def,0x00000000}},	// [6ad0] тува, kavu, _оро_,
  { {0x7bd80024,0x69c900ca,0x25be004c,0x00000000}},	//   javu, zbee, ětle_,
  { {0xd251006a,0x7d093c18,0x7bd817c9,0x00000000}},	//   _هند_, _spes, davu,
  { {0xcf980635,0x68e93c19,0xa49b01a8,0x00000000}},	//   тју_, yred, stòd,
  { {0xb05b0072,0x865c009a,0x00000000,0x00000000}},	//   _etäa, ודאי,   ,
  { {0xdb1a00cd,0x6d593c1a,0x68e93c1b,0x00000000}},	//   _retò, rzwa, vred,
  { {0x9f34019d,0x8c420245,0x69c93c1c,0x00000000}},	//   _кері, сеще, tbee,
  { {0x68e93c1d,0x7bd80213,0xc334009a,0x00000000}},	//   tred, aavu, שוק_,
  { {0x69c90102,0x8cbb006a,0xde64005a,0x00000000}},	//   rbee, _آدرس_, _търп,
  { {0xc9840001,0x69c905e9,0x68e93c1e,0x00000000}},	//   јући, sbee, rred,
  { {0x68e93c1f,0x27ea0022,0x366a0131,0x00000000}},	//   sred, óbna_, еано_,
  { {0xcf920063,0x79590062,0x68e90d58,0x00000000}},	//   מטי_, _пиер_, pred,
  { {0x48e512b9,0xf484005d,0x00000000,0x00000000}},	//   _солв, لاسی,   ,
  { {0x3ead3c20,0x9725009e,0x16d90044,0x00000000}},	//   _liet_, _مفتو, _كذبة_,
  { {0xc8a8005a,0x91e63c21,0x7d1e008f,0x00000000}},	//   _ръце_, лове, āpsi,
  { {0x3ead0b7d,0xddc20022,0x7bd83c22,0x00000000}},	//   _niet_, zkoł, zavu,
  { {0x63c7011b,0xc00607ed,0x00000000,0x00000000}},	// [6ae0] írné, лпак,   ,
  { {0xc4d3009a,0x908a00de,0x251b009d,0x00000000}},	//   _הגז_, رناك_, _טופא,
  { {0x93fb0047,0xaf960259,0x7bd80078,0x00000000}},	//   _אליי, ушај, vavu,
  { {0x3ead0023,0x221638ff,0x4b34005d,0x00000000}},	//   _ciet_, _сфор, یکاس,
  { {0xa0760076,0x61f6002b,0x9bd4000d,0x00000000}},	//   _бывш, mgyl, ажлі,
  { {0xcb1a000a,0x61f6001f,0xb5fb013d,0x00000000}},	//   еќи_, lgyl, tiák,
  { {0x7aea004d,0x224209db,0x7bd83c23,0x00000000}},	//   urft, _kokk_, ravu,
  { {0x25ad38da,0xb5fb00ea,0x62580139,0x00000000}},	//   želi_, riák, _díog,
  { {0x644e00d1,0xc7b00021,0xa2bb0053,0x00000000}},	//   kkbi, يّة_, _शून्,
  { {0x3ead0122,0xe8df008b,0x27f8149c,0x00000000}},	//   _ziet_, uyền_, ürn_,
  { {0x80370047,0xf699005e,0xfd500013,0x00000000}},	//   אניע_, квој_, _nghẽ,
  { {0x9f65013d,0x6372013d,0xdb4f00de,0x00000000}},	//   ütés_, zűné, _عَن_,
  { {0x58d40094,0xf9920043,0xda4b009d,0x00000000}},	//   _толт, _ابا_, _אֲגָ,
  { {0x33870062,0xb9930044,0x63550054,0x00000000}},	//   губв, _الهب, авгу,
  { {0x5695011c,0x04640376,0xe2c9005d,0x00000000}},	//   _какт, стям, ئورو_,
  { {0xdb09006c,0x00000000,0x00000000,0x00000000}},	//   înée,   ,   ,
  { {0x3ead06aa,0x4fd518ea,0xa1581636,0x00000000}},	// [6af0] _riet_, ижат, гату_,
  { {0x26de3c24,0x3ead00ca,0x20070014,0x00000000}},	//   osto_, _siet_, ýni_,
  { {0x62580025,0x22950086,0x3ead3c25,0x00000000}},	//   _bíod, _виня, _piet_,
  { {0x51870fe2,0x9f5c0080,0x433a0047,0x00000000}},	//   _буга, ývá_, _סערב,
  { {0xd251007e,0x3ead3c26,0x11da009a,0x00000000}},	//   _هنگ_, _viet_, _שחשב,
  { {0xcb69018e,0x26de26c4,0x1be60062,0x00000000}},	//   кале_, ksto_, адши_,
  { {0x26de00c2,0x0b160021,0x00000000,0x00000000}},	//   jsto_, لقوة_,   ,
  { {0x2f180086,0xdd090024,0xdb2400ea,0x00000000}},	//   _щось_, môžt, ásáh,
  { {0x26de3c27,0xe9d90022,0x71d8009a,0x00000000}},	//   esto_, raź_, אוחד_,
  { {0x7d1b1900,0x7c870062,0xddc20051,0x00000000}},	//   _isus, _субе, akoń,
  { {0xb06400bd,0x6d4b3c28,0xfb15005d,0x00000000}},	//   lmäß, lyga, _خواج,
  { {0x27330013,0x366a218c,0x06071cdf,0x00000000}},	//   _ḷng_, тамо_, анюк_,
  { {0x69db00bd,0x2d8200d1,0xb064004d,0x00000000}},	//   maue, _øket_, nmäß,
  { {0xb05b35e8,0x7e6b002c,0xe3b20021,0x00000000}},	//   _stän, higp, ترح_,
  { {0xb064004d,0x20133c29,0x93430002,0x00000000}},	//   hmäß, dexi_, онре,
  { {0x69db1a14,0x75460b3f,0x27330013,0x00000000}},	//   naue, _вниз, _ạng_,
  { {0xa5b7014e,0x61f63c2a,0xe3b200f2,0x00000000}},	// [6b00] _דלפק_, rgyl, _ورد_,
  { {0x69db0221,0x38bb002b,0xc4c5005d,0x00000000}},	//   haue, _mêr_, _اتيو,
  { {0x38bb00e8,0x44443c2b,0xa49b00cd,0x00000000}},	//   _lêr_, _io_, stòc,
  { {0x44443c2c,0x7bc12269,0xcee70076,0x00000000}},	//   _ho_, _aflu, рдце_,
  { {0x69db00bd,0x44443c2d,0x55bb0063,0x00000000}},	//   daue, _ko_, דמנו,
  { {0x44443c2e,0xb5fb013d,0x26de0022,0x00000000}},	//   _jo_, riái, ysto_,
  { {0x44443c2f,0xdb1a000f,0xe3e90047,0x00000000}},	//   _mo_, _letö, אַפֿ,
  { {0x3ce9074f,0x44442f53,0x38bb002b,0x00000000}},	//   šava_, _lo_, _bêr_,
  { {0x4444002c,0x3eb800f6,0x7bc1002b,0x00000000}},	//   _oo_, _hurt_, _fflu,
  { {0x29d4006a,0xb8fe0161,0xe7260086,0x00000000}},	//   جيکس, _तब_, аємн,
  { {0x69db00bd,0x2fd8003b,0x7d023c30,0x00000000}},	//   baue, _merg_, ltos,
  { {0x444413a8,0x6e203c31,0x2d8200d1,0x00000000}},	//   _ao_, _jamb, _økes_,
  { {0x6e203c32,0x44443c33,0x3eb800d1,0x00000000}},	//   _mamb, _bo_, _lurt_,
  { {0x26de00d1,0xea01008b,0x7d023c34,0x00000000}},	//   psto_, _đẩy_, itos,
  { {0x3267000d,0x228b005e,0xe7570054,0x00000000}},	//   атав, вљао_, _вищі_,
  { {0x6e200009,0xb05b0072,0x200a01f4,0x00000000}},	//   _namb, _etäl, _abbi_,
  { {0xdb1a00bd,0x44443c35,0x2fd83c36,0x00000000}},	// [6b10] _getö, _fo_, _berg_,
  { {0xd7f80529,0x44443c37,0x60c20139,0x00000000}},	//   ngă_, _go_, íoma,
  { {0x7d0200fe,0x62580025,0x6e203c38,0x00000000}},	//   etos, _díob, _bamb,
  { {0x6e2012e8,0x44443c39,0xb064004d,0x00000000}},	//   _camb, _zo_, tmäß,
  { {0x44443c3a,0x442104b4,0x64453a61,0x00000000}},	//   _yo_, _kah_, _kohi,
  { {0x442104b4,0xb5fb017d,0xb064004d,0x00000000}},	//   _jah_, ciáv, rmäß,
  { {0xb06400bd,0x38bb001f,0x68e200c2,0x00000000}},	//   smäß, _sêr_, _avod,
  { {0x4421053b,0x6e200ff0,0x73780063,0x00000000}},	//   _lah_, _gamb, יגוד_,
  { {0x7e690035,0x97d90086,0x69db3bbc,0x00000000}},	//   _imep, льну_, raue,
  { {0x44213c3b,0x3eb81a8d,0x38bb017d,0x00000000}},	//   _nah_, _yurt_, _vêr_,
  { {0x9b950032,0x2d820031,0x44443c3c,0x00000000}},	//   _الات, _øker_, _ro_,
  { {0xb05b01e3,0x0656000d,0xd7f8000c,0x00000000}},	//   _stäl, стоў, agă_,
  { {0x69d900ac,0xc9870259,0x64453c3d,0x00000000}},	//   _iewe, _тужи, _bohi,
  { {0x6e22147d,0x2a6d2e70,0x44210089,0x00000000}},	//   zdob, lieb_, _cah_,
  { {0x4444034d,0x69d900f3,0x7d02000f,0x00000000}},	//   _vo_, _kewe, ztos,
  { {0x44440199,0x69d90359,0xf55a0044,0x00000000}},	//   _wo_, _jewe, _ملعب_,
  { {0x394d0994,0x3eb80268,0x44443c3e,0x00000000}},	// [6b20] nyes_, _surt_, _to_,
  { {0xa3d90161,0xd12f0032,0x69d93c3f,0x00000000}},	//   ारण_, عمل_, _lewe,
  { {0xb5fb0016,0x6e20002c,0x69d900ac,0x00000000}},	//   riáv, _pamb, _oewe,
  { {0x7d02051e,0x61e600b9,0x69d92d53,0x00000000}},	//   ttos, _udkl, _newe,
  { {0x7e7b02eb,0x44210509,0x6e220eec,0x00000000}},	//   _djup, _yah_, rdob,
  { {0x705600b3,0x6e223502,0x62580139,0x00000000}},	//   _انسا, sdob, _fíoc,
  { {0x69d93c40,0x644100fe,0x6e20100f,0x00000000}},	//   _bewe, ölii, _tamb,
  { {0x69d90150,0xac06005d,0x2252005f,0x00000000}},	//   _cewe, _گذرو, nkyk_,
  { {0x645c00e3,0x0266001b,0x3ebf007d,0x00000000}},	//   khri, _đến_, _čuti_,
  { {0xd7f8000c,0xe00b0053,0xd7f706c3,0x00000000}},	//   ugă_, स्पद_, бую_,
  { {0x69d90be9,0xd7f8000c,0x3aeb007e,0x00000000}},	//   _fewe, rgă_, _مبنی_,
  { {0xa5f90076,0x69d93c41,0x9f970063,0x00000000}},	//   шему_, _gewe, מדיה_,
  { {0x7bda17ba,0xb05b0502,0x68e2027c,0x00000000}},	//   _ketu, _stäm, _uvod,
  { {0x645c00e3,0x225200ac,0x3ea60072,0x00000000}},	//   ghri, ekyk_, hmot_,
  { {0xddc212bf,0x29040058,0x7bda3c42,0x00000000}},	//   dnož, ltma_, _metu,
  { {0x62580025,0xa49b00cd,0x44210b21,0x00000000}},	//   _ríoc, ctòn, _wah_,
  { {0x64450019,0x62580025,0x660d00a4,0x00000000}},	// [6b30] _tohi, _síoc, _ibak,
  { {0x7bda00eb,0x645c1d07,0x6aba3c43,0x00000000}},	//   _netu, chri, _outf,
  { {0x8db50086,0xcf9b0092,0x752d01c8,0x00000000}},	//   ослі, уја_, _hraz,
  { {0x7bda004b,0x7415005d,0x3d950121,0x00000000}},	//   _aetu, _اوگا, оиер,
  { {0x7bda1e3a,0x2a6d0066,0x69d90022,0x00000000}},	//   _betu, vieb_, _rewe,
  { {0x7bda2bfe,0x3ce900c3,0x60cd3c44,0x00000000}},	//   _cetu, šavo_, mpam,
  { {0x2a6d0024,0x9f5f00fe,0x7bda3c45,0x00000000}},	//   tieb_, ärän_, _detu,
  { {0x7e690035,0x752d1c35,0x08c50259,0x00000000}},	//   _umep, _oraz, обин,
  { {0xa3d90161,0x60cd00a4,0x2a6d13ef,0x00000000}},	//   ारा_, npam, rieb_,
  { {0x7bda0ac6,0x69d90509,0x60cd3c46,0x00000000}},	//   _getu, _wewe, ipam,
  { {0x225200ac,0x752d3c47,0x69d90229,0x00000000}},	//   ykyk_, _araz, _tewe,
  { {0xf5063c48,0x68ee005b,0x25be004c,0x00000000}},	//   озмо, ündü, ětlo_,
  { {0x37e52758,0x2bc60053,0x645c3c49,0x00000000}},	//   _долг, रुवा, thri,
  { {0x660d004b,0xe8840085,0x2bcf0042,0x00000000}},	//   _ebak, _егіп, _स्मा,
  { {0x645c0026,0xb05b0072,0x60cd3c4a,0x00000000}},	//   rhri, _etäk, epam,
  { {0x2176005e,0x765d004d,0x645c00e5,0x00000000}},	//   оузр, chsy, shri,
  { {0xb93600b5,0x752d23a0,0x645c0025,0x00000000}},	// [6b40] ֿרעג_, _graz, phri,
  { {0xb5fb0331,0xa49b01a8,0x10a63ae9,0x00000000}},	//   siát, ntòl, цизн,
  { {0x11d60021,0x7bda0cc8,0xddc20124,0x00000000}},	//   _وتحد, _retu, rnož,
  { {0xb5fb3c4b,0x7bda3c4c,0x1ea900f2,0x00000000}},	//   chád, _setu, ماني_,
  { {0x7bda003e,0xddc20022,0x3ea63c4d,0x00000000}},	//   _petu, mnoż, rmot_,
  { {0x98a60080,0x8c430001,0x3cd9000d,0x00000000}},	//   _proč_, деље, сьцю_,
  { {0x7bda3c4e,0x6c830044,0xdee60cf7,0x00000000}},	//   _vetu, بلوم, _фоби,
  { {0x98a600a8,0x58d40062,0xd2b7009a,0x00000000}},	//   _vroč_, поит, חלקת_,
  { {0x49740071,0x7bda1482,0x998d0058,0x00000000}},	//   ялис, _tetu, rdeş_,
  { {0xa7fc01f7,0xc8660021,0xf84a0054,0x00000000}},	//   lnız, تطبي, рчий_,
  { {0xb5fb017d,0x4fbb0149,0x29043c4f,0x00000000}},	//   diár, יציא, stma_,
  { {0xe6670086,0xa49b01a8,0x752d3c50,0x00000000}},	//   ітно, atòl, _praz,
  { {0x998f005f,0x2aaa0022,0x64b50042,0x00000000}},	//   _dogų_, róbę_, ंदेश,
  { {0xc1d30053,0xb5fb3c09,0x752d011b,0x00000000}},	//   तर्ग, giár, _vraz,
  { {0x9f4701f7,0x926b0002,0x026b0085,0x00000000}},	//   ünü_, араа_, ашай_,
  { {0x212900c3,0x95cb05fb,0xa75b0063,0x00000000}},	//   tvah_, _тука_, _כדור,
  { {0x50f50055,0x51f8000d,0xb5fb0460,0x00000000}},	// [6b50] язат, ўную_, siás,
  { {0xb5fb0016,0x60cd245f,0x75d5007e,0x00000000}},	//   ciár, rpam, _بيکا,
  { {0xceeb007e,0x60cd3c51,0x2bde0042,0x00000000}},	//   شران_, spam, _नज़ा,
  { {0xdcef00c2,0xa5bb0014,0x1df9007f,0x00000000}},	//   šečn, kdóm, седы_,
  { {0xddc20051,0xd83800a8,0x8d74005d,0x00000000}},	//   lkoś, amči_, واها,
  { {0x64550122,0x00ba009a,0x60d6009a,0x00000000}},	//   nkzi, _למשמ, _מושא_,
  { {0xf3f2009a,0xca75014b,0x00000000,0x00000000}},	//   ׂ֣ה_, зупы,   ,
  { {0x62580025,0x6aa23c52,0x7d0d00be,0x00000000}},	//   _líon, _chof, çass,
  { {0x2bcf0053,0x38ca007e,0x6e940054,0x00000000}},	//   _स्था, یایی_, _циту,
  { {0xf7190085,0xddc2056c,0xfc3014d7,0x00000000}},	//   бімы_, kkoś, _لحم_,
  { {0xb5fb0827,0xe8480044,0xcc56009a,0x00000000}},	//   viár, تجين_, _צבעי_,
  { {0xfbcf0053,0xa49b00cd,0xddc20022,0x00000000}},	//   _स्तम, stòl, dkoś,
  { {0x62580027,0xdddb00c2,0xb05b0072,0x00000000}},	//   _bíon, _okuž, _etäi,
  { {0xb5fb00ea,0xddc9007d,0x580400de,0x00000000}},	//   gháb, _njež, _يونك,
  { {0x82a60054,0x6aa9004b,0xb5fb013d,0x00000000}},	//   завж, omef, riár,
  { {0xb21b010a,0x56930699,0xc2430121,0x00000000}},	//   _skær, _пајт, ннск,
  { {0x6aa90035,0xddc9007d,0x15fb0063,0x00000000}},	// [6b60] imef, _bjež, _ההפע,
  { {0xb4d80235,0x6aa9004d,0x6b84004d,0x00000000}},	//   ाठी_, hmef, ßigk,
  { {0x0dca0086,0x41dc0042,0x2d9a0022,0x00000000}},	//   були_, बरदस, ępem_,
  { {0x9e65002a,0xce69012c,0x00000000,0x00000000}},	//   وانن, орід_,   ,
  { {0x200700cd,0xe3b2007e,0xacf8013c,0x00000000}},	//   ònic_, _ترک_, інку_,
  { {0x6aa23c53,0xdceb0075,0x3ced0042,0x00000000}},	//   _shof, şiği, _घिरे_,
  { {0x8b23005e,0xa0a30cf7,0x00000000,0x00000000}},	//   едје, _чард,   ,
  { {0xdb010026,0x9f58017d,0x201a00b2,0x00000000}},	//   _uglý, _ecrã_, lepi_,
  { {0xd90e006a,0x15e30053,0x2efa0244,0x00000000}},	//   ایت_, _ख़बर_, lupf_,
  { {0x6aa90035,0xa5bb3c54,0x47780054,0x00000000}},	//   amef, rdóm, жбою_,
  { {0x2127001b,0x3e7501da,0x62580139,0x00000000}},	//   ̉nh_, sťte_, _ríon,
  { {0xbb3b009a,0x3abb009a,0xe9d200de,0x00000000}},	//   _לעבי, _המאנ, _أغا_,
  { {0xb05b00fe,0x62580025,0x69340083,0x00000000}},	//   _itäv, _píon, _інку,
  { {0x201a007d,0xd4910013,0x7ea3004e,0x00000000}},	//   jepi_, ồ_, mõpe,
  { {0xb8ff016a,0x92950c0b,0x7ea3004b,0x00000000}},	//   धी_, давц, lõpe,
  { {0xb5fb0139,0xc29902fe,0xd5c10042,0x00000000}},	//   sháb, іках_, _एलिज,
  { {0x212f0025,0x6441004b,0x85740062,0x00000000}},	// [6b70] ígh_, ölis, _плъх,
  { {0x2fc7001b,0x4fc40085,0x1fa70af0,0x00000000}},	//   ùng_, есца, прег,
  { {0xddc9007d,0x7f1901fb,0xb5fb01c8,0x00000000}},	//   _vjež, تياز_, chác,
  { {0x7d9904ef,0x00000000,0x00000000,0x00000000}},	//   овес_,   ,   ,
  { {0xf1ab006a,0xece80086,0x69dd0026,0x00000000}},	//   _داده_, зділ_, ðsem,
  { {0x5fe10161,0x224b30a7,0x201a00dd,0x00000000}},	//   _फ़िल, _hock_, cepi_,
  { {0x6e670062,0x3c2d00ea,0x224b00a5,0x00000000}},	//   _етаж, jövő_, _kock_,
  { {0x224b1098,0x88c90a39,0xe9a60043,0x00000000}},	//   _jock_, олив_, ژگون_,
  { {0x3ddf006f,0x2aa100ea,0x224b00e5,0x00000000}},	//   _ieuw_, tóbb_, _mock_,
  { {0x224b375e,0x6fdd0042,0xfc640094,0x00000000}},	//   _lock_, यरिं, _пъхн,
  { {0x224b00ca,0xa754030b,0x2aa1013d,0x00000000}},	//   _oock_, етящ, róbb_,
  { {0x2cbf0019,0x7afc0137,0xf3e90063,0x00000000}},	//   _kuud_, _årta, _כף_,
  { {0x62580025,0xc9f400de,0x00000000,0x00000000}},	//   _díol, _أسمع,   ,
  { {0x2cbf0004,0x68fb0213,0xe8d60063,0x00000000}},	//   _muud_, muud, _חוסר_,
  { {0xa2e60062,0x23272046,0x27f80022,0x00000000}},	//   ьовд, мори_, órne_,
  { {0xcb120063,0x224b3c55,0xe0da0263,0x00000000}},	//   כלל_, _cock_, жва_,
  { {0x224b0924,0x201a0089,0x404a005e,0x00000000}},	// [6b80] _dock_, tepi_, опао_,
  { {0x394200fe,0x75243c56,0xf1b10044,0x00000000}},	//   äksi_, _isiz, اءِ_,
  { {0x62580025,0x200700cd,0x201a0ad5,0x00000000}},	//   _híom, ònia_, repi_,
  { {0xf2d3014e,0x64920146,0x68fb0656,0x00000000}},	//   _שער_, pæis, kuud,
  { {0x68fb0659,0x61e43c57,0x0caa0a1f,0x00000000}},	//   juud, mail, отки_,
  { {0x3ddf0122,0xc0e3005e,0x76880058,0x00000000}},	//   _eeuw_, _јорк, lıyd,
  { {0xaec3000d,0xab77009b,0xf413009a,0x00000000}},	//   _абсл, ومها_, דפו_,
  { {0x8fa30088,0x752401f4,0x61e43c58,0x00000000}},	//   _расе, _osiz, nail,
  { {0x60c20027,0x2bcf0161,0xec7a0f30,0x00000000}},	//   íomh, _स्वा, _дпа_,
  { {0x62580025,0x61e43c59,0x0c26013c,0x00000000}},	//   _síol, hail, _імен,
  { {0x61e4315d,0x8c430635,0x7c3a2b63,0x00000000}},	//   kail, _шефе, _intr,
  { {0x7c283c5a,0x7c2a3c5b,0x443a3c5c,0x00000000}},	//   _hadr, ldfr, _anp_,
  { {0xb956007e,0x443a3c5d,0x98a90058,0x00000000}},	//   _تئات, _bnp_, _çağ_,
  { {0xa5bb0139,0x7c28064f,0x7c2a27a1,0x00000000}},	//   idói, _jadr, ndfr,
  { {0x7c281b69,0x61e43c5e,0x04640054,0x00000000}},	//   _madr, fail, ттям,
  { {0x645e00f3,0x61e40006,0x7c280419,0x00000000}},	//   _elpi, gail, _ladr,
  { {0xa2940086,0x661d3c5f,0x7e6235bd,0x00000000}},	// [6b90] таті, mesk, dhop,
  { {0xcf9b0138,0x61e40213,0x2cbf2281,0x00000000}},	//   оје_, aail, _ruud_,
  { {0x833500b5,0x03d6014e,0x61e40025,0x00000000}},	//   _װאָס_, _אותם_, bail,
  { {0x28df0394,0x7c280004,0x61e40027,0x00000000}},	//   पीडि, _aadr, cail,
  { {0x64680019,0x644e00c2,0xed580086,0x00000000}},	//   _äriü, žniš, мої_,
  { {0x7c283c60,0x68fb00fe,0x7c84005e,0x00000000}},	//   _cadr, vuud, кује,
  { {0x661d3c61,0xa5bb0139,0xbef80021,0x00000000}},	//   kesk, adói, _يرفض_,
  { {0xdb0e0080,0x68fb021e,0xb05b0072,0x00000000}},	//   ádán, tuud, _etät,
  { {0x39590026,0x661d3c62,0x7c281795,0x00000000}},	//   áss_, desk, _fadr,
  { {0x6258018d,0x20012811,0x661d0019,0x00000000}},	//   _ríom, nghi_, eesk,
  { {0x68fb024a,0x6e290019,0xd6ce007e,0x00000000}},	//   suud, _kaeb, یقی_,
  { {0x661d3c63,0x68fb0019,0x7c281bdb,0x00000000}},	//   gesk, puud, _zadr,
  { {0x61e43c64,0x443a2edf,0x05b60085,0x00000000}},	//   vail, _pnp_, эсоў,
  { {0x7c28017d,0x68e90058,0x61ef3c65,0x00000000}},	//   _xadr, msed, _adcl,
  { {0xb5fb0027,0xa696041d,0x68e93c66,0x00000000}},	//   mhán, _приј, lsed,
  { {0x69c93c67,0x200101f4,0x62580139,0x00000000}},	//   ncee, eghi_, _tíom,
  { {0x68e93c68,0x75240035,0x60dd001f,0x00000000}},	// [6ba0] nsed, _usiz, _cwsm,
  { {0x68e90fc8,0x0446005e,0x76880058,0x00000000}},	//   ised, _чеон, sıyd,
  { {0xdfcf0021,0x68e9005b,0xe3b20021,0x00000000}},	//   صين_, hsed, _حرة_,
  { {0x7c280117,0xcd06036a,0x61460d34,0x00000000}},	//   _sadr, ечки, _зема,
  { {0x7c28256b,0x201700cd,0x7e620137,0x00000000}},	//   _padr, ïció_, rhop,
  { {0x69cb0102,0x7e623c69,0xa5bb0025,0x00000000}},	//   _afge, shop, rdói,
  { {0x68e90198,0x8fa306b4,0x27e500a4,0x00000000}},	//   esed, _баре, daln_,
  { {0x5a34071a,0x41bb0047,0x893811ec,0x00000000}},	//   тнит, ּציע, дпис_,
  { {0x4c86000d,0x661d3c6a,0xb05b0072,0x00000000}},	//   _злав, vesk, _itär,
  { {0xb5fb0080,0x9982004c,0xbc6a0593,0x00000000}},	//   ghán, žků_, _عمان_,
  { {0x661d2d3b,0x2eaa0063,0xa5f9143c,0x00000000}},	//   tesk, ּשָּ, мену_,
  { {0x69c9233a,0xea01001b,0xff7b0aeb,0x00000000}},	//   ccee, _đầy_, לטימ,
  { {0x94ab000d,0x15a80062,0x661d3c6b,0x00000000}},	//   зтва_, еъри_, resk,
  { {0x661d3c6c,0xb5fb3c6d,0x493b009a,0x00000000}},	//   sesk, chán, _מגדו,
  { {0x82a70076,0xd25b3c6e,0x43950505,0x00000000}},	//   ешае, пца_, тавс,
  { {0xc6a70054,0xa79b009a,0xa29416f2,0x00000000}},	//   _ярли, _משוח, гасі,
  { {0x2cff0161,0xddc9003b,0x69dd0046,0x00000000}},	// [6bb0] _ईमेल_, _aleş, ðsei,
  { {0x6e3b3c6f,0x50640131,0xa98b009a,0x00000000}},	//   _snub, лтха, הָבִ,
  { {0x20010290,0xf4120063,0xe1d90086,0x00000000}},	//   rghi_, _דפי_, _одні_,
  { {0xa3d90053,0x68e9002b,0xdce20605,0x00000000}},	//   ारक_, ysed, azoč,
  { {0xddc90683,0x7c290002,0x2d580086,0x00000000}},	//   _eleş, долг_, ниць_,
  { {0x22493c70,0x68e900a5,0x00f603c3,0x00000000}},	//   ljak_, vsed, _במשך_,
  { {0xdde300ea,0x626c3039,0x2bac0042,0x00000000}},	//   űről, rşov, टेला,
  { {0x68e90019,0x22493c71,0x25ed0042,0x00000000}},	//   tsed, njak_, _आएगी_,
  { {0x87f9000d,0x22492326,0x69c900ca,0x00000000}},	//   мэнт_, ijak_, rcee,
  { {0x68e91366,0x69c9006f,0x00000000,0x00000000}},	//   rsed, scee,   ,
  { {0x68e90b9f,0x6b84004d,0x44ed0066,0x00000000}},	//   ssed, ßigt, eľ_,
  { {0x8cd80042,0xa5bb013d,0x68e90075,0x00000000}},	//   नीको, deób, psed,
  { {0xceb200b5,0xb5fb0405,0xe945005d,0x00000000}},	//   ייט_, mhál, _جرای,
  { {0x2249053b,0xdb0d0026,0x64a6082d,0x00000000}},	//   ejak_, _þjóf, тага,
  { {0x44ed0024,0xe29a0156,0xe2960002,0x00000000}},	//   aľ_, дав_, враќ,
  { {0xb5fb004c,0x0676012c,0x00000000,0x00000000}},	//   nhál, _шуля,   ,
  { {0x290d3c72,0x625101e1,0xe29700fb,0x00000000}},	// [6bc0] ntea_, _påor, тат_,
  { {0xb21b010a,0x22490150,0xb05b0832,0x00000000}},	//   _hjæl, ajak_, _stär,
  { {0x52aa0138,0xb21b00d1,0x645c02e0,0x00000000}},	//   _овом_, _kjæl, mkri,
  { {0xedf4007e,0x75360022,0x645c1475,0x00000000}},	//   ايشگ, _kryz, lkri,
  { {0xb5fb0139,0x645c0077,0x00000000,0x00000000}},	//   dhál, okri,   ,
  { {0x201e0014,0x645c3c73,0x63a9004c,0x00000000}},	//   _úti_, nkri, řene,
  { {0xbae30088,0x645c3c74,0xb05b0072,0x00000000}},	//   ацый, ikri, _itäp,
  { {0xddc7003b,0xb5fb013d,0xc7b80130,0x00000000}},	//   ălţa, ghál, jeđa_,
  { {0xac0a000a,0xfe91007e,0x4c16007e,0x00000000}},	//   _онаа_, _اینج, _لباس,
  { {0xea01008b,0x60d6005f,0x00000000,0x00000000}},	//   _đấy_, ipym,   ,
  { {0xb5fb0025,0x3ffb0063,0x661b0019,0x00000000}},	//   bhál, ופיע, õuko,
  { {0xab7900b5,0xcf930063,0x7b790047,0x00000000}},	//   _אָנז, יטת_, _אָנצ,
  { {0xda07007e,0xda6501a7,0xe9180054,0x00000000}},	//   _شيوه_, _حالي, _чолі_,
  { {0x645c3c75,0x1fe10042,0xe80e0082,0x00000000}},	//   gkri, _फ़ेड, ़्शा_,
  { {0x13b40032,0x200700cd,0x9484000d,0x00000000}},	//   لصفح, ònim_, рыяд,
  { {0x32640472,0xddc90066,0x645c3c76,0x00000000}},	//   атув, _omeš, akri,
  { {0xdddb007d,0x75361634,0x0574005d,0x00000000}},	// [6bd0] _njuš, _gryz, _پايد,
  { {0xc0580088,0x1fd80021,0x25a40058,0x00000000}},	//   кіх_, نظمة_, ümle_,
  { {0x9df90635,0x9ed90e5e,0x2ef512a7,0x00000000}},	//   енет_, хмет_, узер,
  { {0x20d70021,0xb05b0072,0x20070022,0x00000000}},	//   _لتسج, _etäp, żni_,
  { {0x96160047,0x645a004d,0x76880058,0x00000000}},	//   רקױף_, ötig, nıya,
  { {0xc1b8126b,0xfc051528,0x4d640054,0x00000000}},	//   _шлях_, упко, шків,
  { {0xb5fb1a34,0xeb961e1b,0x5c04030b,0x00000000}},	//   thál, лиш_, ряча,
  { {0x0b160032,0x645c358c,0xf2d40047,0x00000000}},	//   اقية_, zkri, בעק_,
  { {0x290d000c,0x291900cd,0xe8f60085,0x00000000}},	//   utea_, ïsa_, глы_,
  { {0x290d0529,0xb21b0d02,0x6d590051,0x00000000}},	//   rtea_, _sjæl, mywa,
  { {0x290d0529,0xfc300021,0xd5e62b4f,0x00000000}},	//   stea_, _بحق_, лжни,
  { {0x98ad00c3,0x290d000c,0x75360022,0x00000000}},	//   mveč_, ptea_, _pryz,
  { {0x6d5912cc,0xa3f60121,0x645c3c77,0x00000000}},	//   nywa, лявш, tkri,
  { {0x98790047,0x765d0022,0x232a0da2,0x00000000}},	//   _ראַט, aksy, ноги_,
  { {0x645c39cc,0xe7390121,0x68fb01e1,0x00000000}},	//   rkri, _чей_, lrud,
  { {0x645c06a3,0x68fb3c78,0xdb0a0003,0x00000000}},	//   skri, orud, énét,
  { {0x645c0006,0x25d70063,0x3f8f0058,0x00000000}},	// [6be0] pkri, _גופן_, şgul_,
  { {0x6d590051,0x7bc10139,0xf8c80013,0x00000000}},	//   dywa, _nglu, _hức_,
  { {0x98ad0198,0x50b50002,0x7d1b003b,0x00000000}},	//   jveč_, рсту, _apus,
  { {0xe8130053,0x1ea90021,0xa49b00cd,0x00000000}},	//   त्ता_, ناني_, stòt,
  { {0xf8c8001b,0x68fb09b0,0x61e6008f,0x00000000}},	//   _mức_, jrud, _iekl,
  { {0x626c000c,0xddc900c2,0x62840051,0x00000000}},	//   cşor, _vmeš, lnio,
  { {0x1fb50055,0x26050053,0xf0630086,0x00000000}},	//   _встр, _वाली_, _укрп,
  { {0x6d590051,0x7bc1001f,0x61e600c2,0x00000000}},	//   bywa, _eglu, _jekl,
  { {0x61e60418,0x20180150,0xddc9082a,0x00000000}},	//   _mekl, _kbri_, _umeš,
  { {0xb5fb007a,0x80aa0161,0x7d020006,0x00000000}},	//   rhám, _जीमे, muos,
  { {0xb8cb0053,0xf8c8008b,0x60c60150,0x00000000}},	//   _की_, _bức_, _lukm,
  { {0x69dd007a,0x68fb0c23,0xe5b50121,0x00000000}},	//   ðset, brud, ийны,
  { {0x55070088,0x62840045,0x4a7b00b5,0x00000000}},	//   ычна, dnio, _אראב,
  { {0x62840045,0xd7ef0001,0x200a0edc,0x00000000}},	//   enio, _ћу_, _ncbi_,
  { {0x6d590045,0x61e63c79,0xa7370044,0x00000000}},	//   zywa, _bekl, _مثير_,
  { {0x60c63c7a,0x20183c7b,0x8237014d,0x00000000}},	//   _bukm, _abri_, درسا,
  { {0x7d020006,0x6e223c7c,0x61e63c7d,0x00000000}},	// [6bf0] juos, deob, _dekl,
  { {0xa49b00cd,0xa068005e,0x38ab01e1,0x00000000}},	//   atòr, гађа_, rørg_,
  { {0x6d593c7e,0x645a00fe,0x200f0051,0x00000000}},	//   wywa, ötie, ęgi_,
  { {0xcf9820cf,0xa49b0268,0x6d590051,0x00000000}},	//   ују_, ctòr, tywa,
  { {0x7d020078,0xc6940041,0xade80044,0x00000000}},	//   guos, זאף_, افهم_,
  { {0x442306ce,0xb5fb00ea,0x6d5912cc,0x00000000}},	//   nej_, nkáb, rywa,
  { {0x6d590051,0x44230022,0x4431008f,0x00000000}},	//   sywa, iej_, idz_,
  { {0x442301d9,0x7f840021,0x98ad00c2,0x00000000}},	//   hej_, _الفن, rveč_,
  { {0x44233c7f,0x0d67005a,0xf8650002,0x00000000}},	//   kej_, _съвм, ивио,
  { {0xa8550fe2,0xe7390001,0xf8c8001b,0x00000000}},	//   ртиј, вео_, _sức_,
  { {0x38ab0031,0x62840a8d,0x68fb2640,0x00000000}},	//   jøre_, ynio, srud,
  { {0x44313c80,0x68fb3c81,0x7c233c82,0x00000000}},	//   edz_, prud, lenr,
  { {0x9f430331,0x62960003,0x61e63c83,0x00000000}},	//   _dejé_, voyo, _rekl,
  { {0x38ab0831,0x0527018e,0xe3b20021,0x00000000}},	//   føre_, јорк_, قرأ_,
  { {0x38ab0146,0xf8c8001b,0x60c60397,0x00000000}},	//   gøre_, _tức_, _sukm,
  { {0xb226000a,0x768801f7,0xb3470016,0x00000000}},	//   јмал, mıyo, _seçõ,

  { {0x4423040d,0x7688005b,0x6296068f,0x00000000}},	// [6c00] bej_, lıyo, royo,
  { {0xa49b0994,0x26c7028d,0x629600a4,0x00000000}},	//   stòr, _kuno_, soyo,
  { {0x61e601f7,0x768801f7,0x78a10137,0x00000000}},	//   _tekl, nıyo, illv,
  { {0x60c6002c,0x7d023c84,0xed5a3c85,0x00000000}},	//   _tukm, tuos, кое_,
  { {0x1bd4005a,0x6e22118f,0x76400072,0x00000000}},	//   боля, reob, ömyy,
  { {0x5c73019d,0x7688005b,0x2d570121,0x00000000}},	//   оліт, kıyo, ришь_,
  { {0xb5fb2bc0,0x6f1c0080,0x26c7017d,0x00000000}},	//   nkác, _uprc, _nuno_,
  { {0x6cd60021,0xeb97005e,0x44233c86,0x00000000}},	//   _نقرا, јић_, zej_,
  { {0x62580139,0x7c233c87,0xd943005e,0x00000000}},	//   _híos, benr, жењи,
  { {0xb5fb0027,0x00760063,0x0b1a0044,0x00000000}},	//   mhái, יתִי_, _لقطة_,
  { {0x44230024,0x27e70199,0x3ead00df,0x00000000}},	//   vej_, _denn_, _yhet_,
  { {0x44230045,0x6f030268,0x62580139,0x00000000}},	//   wej_, ànci, _míos,
  { {0x442306ce,0x7688005b,0x24983c88,0x00000000}},	//   tej_, mıyl, form_,
  { {0x29043c89,0xb5fb013d,0x6288006c,0x00000000}},	//   muma_, ukáb, édon,
  { {0x44233c8a,0x29043c8b,0x4431008f,0x00000000}},	//   rej_, luma_, rdz_,
  { {0xf8ad006a,0xd7bb014e,0x44233c8c,0x00000000}},	//   _يکی_, _בצור, sej_,
  { {0x29043c8d,0xf1dc0082,0x00000000,0x00000000}},	// [6c10] numa_, बरजन,   ,
  { {0xb5fb0139,0x764f00a5,0x859c009a,0x00000000}},	//   dhái, ljcy, _בשחו,
  { {0x29043c8e,0x64a40002,0x7c231a62,0x00000000}},	//   huma_, _фаќа, venr,
  { {0xfe70007e,0x62580025,0xf2d20063,0x00000000}},	//   ودن_, _díos, _מעט_,
  { {0x2904003d,0xa5da00b5,0x3a2400ac,0x00000000}},	//   juma_, אַצי, demp_,
  { {0x29040009,0xa3be0161,0x61ed01cf,0x00000000}},	//   duma_, ुँच_, laal,
  { {0x27e73c8f,0x3ead3c90,0x660d0058,0x00000000}},	//   _renn_, _thet_, _ocak,
  { {0xb5fb0027,0x32093c91,0x61ed395a,0x00000000}},	//   bhái, ngay_, naal,
  { {0xb5fb3c92,0xe939007e,0x29043c93,0x00000000}},	//   chái, اسبت_, guma_,
  { {0x7688005b,0x61ed3c94,0x26c73c95,0x00000000}},	//   tıyo, haal, _puno_,
  { {0x27e70031,0x2498166f,0x2bdd0053,0x00000000}},	//   _venn_, vorm_, _न्या,
  { {0x27e70199,0x2129053b,0x7688005b,0x00000000}},	//   _wenn_, kwah_, cıyl,
  { {0x1e3a0047,0x29043c96,0x61ed3c97,0x00000000}},	//   אגרא, cuma_, daal,
  { {0x62580027,0x43f90076,0x4d7a0047,0x00000000}},	//   _níor, ихся_, אָלא,
  { {0xe79a0080,0x21290089,0x26c70656,0x00000000}},	//   _těší, ewah_, _uuno_,
  { {0x5756014e,0xe8130161,0x6d5600d1,0x00000000}},	//   _לבצע_, त्रा_, øyak,
  { {0x41aa0e6b,0x614322c4,0xb5fb0061,0x00000000}},	// [6c20] уван_, пета, skác,
  { {0x320900a4,0xf5370063,0x629d3c98,0x00000000}},	//   agay_, _פריז_, _ekso,
  { {0x20b90076,0x320900a4,0x44443c99,0x00000000}},	//   рыть_, bgay_, _in_,
  { {0x29040035,0xb5fb0025,0xdee50021,0x00000000}},	//   yuma_, thái, تأكي,
  { {0x62580025,0xfff8007e,0x44443c9a,0x00000000}},	//   _fíor, _نکات_, _kn_,
  { {0x29043c9b,0x44443c9c,0xead80085,0x00000000}},	//   vuma_, _jn_, амкі_,
  { {0x907b00b5,0x3ed80063,0x44443c9d,0x00000000}},	//   _עטלי, _כַּא, _mn_,
  { {0xb5fb3c9e,0x764400a4,0x29043c9f,0x00000000}},	//   phái, _nniy, tuma_,
  { {0x768801f7,0x44440fed,0xc7c60086,0x00000000}},	//   rıyl, _on_, йсни,
  { {0x7688005b,0x082a026b,0x44443ca0,0x00000000}},	//   sıyl, уции_, _nn_,
  { {0xdd12001c,0xab960021,0xda0a0021,0x00000000}},	//   kļūt, _الضغ, _مياه_,
  { {0x44443ca1,0x38a20026,0x7e623ca2,0x00000000}},	//   _an_, iðri_, nkop,
  { {0x44441761,0xb05b004d,0x61ed10a0,0x00000000}},	//   _bn_, _quäk, vaal,
  { {0x656f0051,0x7644005b,0x200e01a8,0x00000000}},	//   rzch, _eniy, òfil_,
  { {0x7e621d8c,0x61ed3ca3,0xa87b0063,0x00000000}},	//   kkop, taal, _תאור,
  { {0x63a90080,0x7e62006f,0x44443ca4,0x00000000}},	//   řeno, jkop, _en_,
  { {0x10d80021,0xc0d5007e,0x7e622e9f,0x00000000}},	// [6c30] مبلغ_, زياب, dkop,
  { {0x21290509,0x61ed0213,0x2aa100be,0x00000000}},	//   rwah_, saal, róbi_,
  { {0x61ed3ca5,0x2c6b05b9,0xff04000d,0x00000000}},	//   paal, _jøde_, зячн,
  { {0x2c6b05b9,0x7e620760,0xf8c80053,0x00000000}},	//   _møde_, gkop, रदाय,
  { {0x44443ca6,0xccfb0001,0x62580025,0x00000000}},	//   _yn_, уће_, _tíor,
  { {0x4c84000d,0x8c4225b6,0xb5fb01c2,0x00000000}},	//   плів, деше, cháv,
  { {0xfcb20024,0x44333ca7,0xb21b01e1,0x00000000}},	//   úšať_, _max_, _djæv,
  { {0x9f430080,0x3ce0000c,0xdab9000d,0x00000000}},	//   _její_, ţiva_, шылі_,
  { {0xdc270075,0x88c902f8,0x39450054,0x00000000}},	//   _göğs, јлов_, іног,
  { {0xa8740076,0x64570168,0x998b011b,0x00000000}},	//   зующ, _noxi, žců_,
  { {0xdb1f00fe,0xf6263ca8,0xddc0005b,0x00000000}},	//   äväs, одно, _komş,
  { {0x2c6b02ab,0x9f4a0016,0x44443ca9,0x00000000}},	//   _døde_, _bebê_, _sn_,
  { {0x64572d20,0x62883caa,0x1c1e0042,0x00000000}},	//   _boxi, édom, _मॉडल_,
  { {0x2c6b06a5,0x66e50713,0xe7390c45,0x00000000}},	//   _føde_, _дока, _век_,
  { {0xa3b40053,0x44443cab,0xe27a0062,0x00000000}},	//   जें_, _vn_, ащаш_,
  { {0x44333cac,0x44441542,0xb5fb2f90,0x00000000}},	//   _eax_, _wn_, lkán,
  { {0x394d3170,0x44333cad,0x01d70021,0x00000000}},	// [6c40] nxes_, _fax_, توقع_,
  { {0xa3eb016a,0x394d00cd,0xf8bb0042,0x00000000}},	//   मरण_, ixes_, ैदिय,
  { {0x7e6227b4,0x27f80022,0xdee60054,0x00000000}},	//   tkop, órni_, іоди,
  { {0xf3f1001b,0x6146006e,0x7e620006,0x00000000}},	//   ực_, _дема, ukop,
  { {0xbc4a0001,0x1ea90021,0x7e623831,0x00000000}},	//   ичке_, حالي_, rkop,
  { {0x7e623cae,0x7e693caf,0x653b0047,0x00000000}},	//   skop, _elep, יענד,
  { {0xbb430002,0x7e623cb0,0xcb67005e,0x00000000}},	//   дејк, pkop, жаје_,
  { {0x2c6b02ab,0x1fa70086,0x0ab30021,0x00000000}},	//   _røde_, _єкти_, وحيد,
  { {0x2c6b01e1,0x7faa0082,0xbe1314d7,0x00000000}},	//   _søde_, _करुँ, _توقع,
  { {0x7e690a63,0x3ea63cb1,0xd83800c2,0x00000000}},	//   _zlep, llot_, koče_,
  { {0xd83800c3,0xf0930047,0x64573cb2,0x00000000}},	//   joče_, ונז_, _roxi,
  { {0x645a004b,0xd83802f7,0x7d0207f2,0x00000000}},	//   ötin, doče_, oros,
  { {0xb05b0072,0x26d8005f,0x44333cb3,0x00000000}},	//   _etäy, ūro_, _pax_,
  { {0x2813005d,0x7faa0042,0x7d023cb4,0x00000000}},	//   _يونس, _करूँ, iros,
  { {0xd8380198,0x44331b15,0x3ea600a5,0x00000000}},	//   goče_, _vax_, klot_,
  { {0x4789126b,0x443300e5,0x44f51c09,0x00000000}},	//   _усім_, _wax_, _епис,
  { {0x44330034,0x3ea600ca,0x661b004b,0x00000000}},	// [6c50] _tax_, dlot_, õuku,
  { {0x7e693cb5,0x30a7000d,0xd83800c2,0x00000000}},	//   _slep, ірав, ločb_,
  { {0x7d023cb6,0x40841501,0x7e69005f,0x00000000}},	//   eros, футб, _plep,
  { {0x38ab0093,0x3ea63cb7,0x7eb100a5,0x00000000}},	//   jørn_, glot_, kåpe,
  { {0x61e202dd,0x7d023cb8,0xee38000d,0x00000000}},	//   ñole, gros, ўні_,
  { {0xec780054,0x7e690022,0x91ba009a,0x00000000}},	//   опі_, _wlep, _למרי,
  { {0x7d023cb9,0x00000000,0x00000000,0x00000000}},	//   aros,   ,   ,
  { {0x394d0268,0x7e690051,0x98af0130,0x00000000}},	//   txes_, _ulep, đače_,
  { {0x7d023cba,0x527c0047,0x5c750062,0x00000000}},	//   cros, ינהא, _елат,
  { {0x394d3cbb,0xd7090121,0xe61f002b,0x00000000}},	//   rxes_, бное_, snôl_,
  { {0x786d007a,0x38ab00b9,0x628f0022,0x00000000}},	//   _núve, børn_, _ojco,
  { {0xeaae0086,0xe1ff0026,0xb5fb3cbc,0x00000000}},	//   _їй_, _blóm_, skán,
  { {0xe79a0080,0x2f150137,0xd9450713,0x00000000}},	//   _měří, håg_, _хели,
  { {0xa7fc005b,0x52b40042,0x493a009a,0x00000000}},	//   lkın, ंग्स, _לגנו,
  { {0x03390086,0x290b0066,0xb5fb3cbd,0x00000000}},	//   оїть_, žiaľ_, okál,
  { {0xb5fb00ea,0x7afc01e1,0x02c30e82,0x00000000}},	//   nkál, _ærte, ейсо,
  { {0xd83800c2,0xdfd200f2,0xb5fb336c,0x00000000}},	// [6c60] soče_, فيذ_, rhát,
  { {0xf3f10013,0x62810003,0x2bdd0053,0x00000000}},	//   ựa_, élor, नुमा,
  { {0xa7fc01f7,0xef1a0001,0xd00f0593,0x00000000}},	//   kkın, сме_, الم_,
  { {0x442a2719,0x7d023cbe,0xb5fb013d,0x00000000}},	//   leb_, tros, lhár,
  { {0x61e43cbf,0x3ea63cc0,0xb2bb0063,0x00000000}},	//   mbil, rlot_, _למטר,
  { {0x442a3cc1,0x7eb100d1,0x44383cc2,0x00000000}},	//   neb_, våpe, ndr_,
  { {0x61e40100,0xeb470085,0x4438002b,0x00000000}},	//   obil, зчык_, idr_,
  { {0x442a0019,0x61e41bf6,0x9f4a01a8,0x00000000}},	//   heb_, nbil, _rebè_,
  { {0xb21b07e6,0x61e40b10,0x6e930044,0x00000000}},	//   _kjær, ibil, _ألقا,
  { {0x98730be6,0x645a00fe,0x7dd10025,0x00000000}},	//   ельц, ötil, _tósó,
  { {0x7bdb014e,0x442a0185,0x9f4a05d5,0x00000000}},	//   _הקבו, deb_, _bebé_,
  { {0x673a00d1,0x442a004b,0x44383cc3,0x00000000}},	//   rvtj, eeb_, edr_,
  { {0x442a002b,0x61e43cc4,0xd94301ce,0x00000000}},	//   feb_, dbil, _пеци,
  { {0x27e9001b,0xb8e00235,0xd7fa000a,0x00000000}},	//   _đang_, ंग_, _ѓул_,
  { {0x926b0002,0x8557007e,0x75243cc5,0x00000000}},	//   браа_, زیگر_, _epiz,
  { {0x61e4002c,0x6d403cc6,0xfbdf008b,0x00000000}},	//   gbil, _orma, _đêm_,
  { {0xd49b019d,0xb5fb0025,0xdb01004c,0x00000000}},	// [6c70] _грн_, shás, _vylé,
  { {0x2f150137,0x61e43cc7,0xd8b90047,0x00000000}},	//   tåg_, abil, ַצײכ,
  { {0xde35000d,0x61e43601,0x7c2a3cc8,0x00000000}},	//   дэль, bbil, defr,
  { {0xdbf70042,0x63c3011b,0x8d740043,0x00000000}},	//   ील्ड_, ětně, کاما,
  { {0xc7b80117,0x2f1500c7,0xe79a0080,0x00000000}},	//   među_, såg_, _věří,
  { {0x9203001c,0xb21b00d1,0x998d3cc9,0x00000000}},	//   žādu, _gjær, jdeš_,
  { {0x64550122,0x29040089,0x6d403cca,0x00000000}},	//   ijzi, erma_, _erma,
  { {0xac77006a,0x628d0019,0x9e340121,0x00000000}},	//   _کارش, nnao, _песч,
  { {0x9f4a00cd,0x61ef005b,0x62880003,0x00000000}},	//   _rebé_, _mecl, édoi,
  { {0x27ee001f,0xa3bf0053,0xa7fc0058,0x00000000}},	//   _cefn_, ेशा_, skın,
  { {0xa49b00cd,0x752f0051,0x29043ccb,0x00000000}},	//   tròn, ewcz, arma_,
  { {0x61ef003b,0x442a02d4,0x60c700ca,0x00000000}},	//   _necl, web_, _lijm,
  { {0x442a3ccc,0xe577000d,0xe8ee0062,0x00000000}},	//   teb_, дзя_, _шл_,
  { {0x27ee001f,0x60c71c79,0x2918003b,0x00000000}},	//   _gefn_, _nijm, ărat_,
  { {0x03a30071,0x44210150,0xa6960856,0x00000000}},	//   виро, _dbh_, _ориј,
  { {0xd2aa000d,0x442a3ccd,0x96950085,0x00000000}},	//   ікае_, seb_, _прыш,
  { {0xd83800c3,0x442a0019,0x61ef095c,0x00000000}},	// [6c80] loča_, peb_, _decl,
  { {0x61e43cce,0x6aa90244,0xc4830fdc,0x00000000}},	//   sbil, hlef, _альк,
  { {0x69cb051e,0x69d90122,0xee3a27b5,0x00000000}},	//   _ogge, _ofwe, жне_,
  { {0x61ef0194,0x7c2a001f,0x9e66000d,0x00000000}},	//   _gecl, wefr, ьвед,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x69d90250,0x69cb3ccf,0x8d630062,0x00000000}},	//   _afwe, _agge, ъвче,
  { {0xd83800c3,0x7d0b143b,0xa5bb00be,0x00000000}},	//   joča_, augs, reói,
  { {0x6aa90203,0xa7fc0058,0x9966030b,0x00000000}},	//   glef, akıl, дтол,
  { {0x6d402331,0x6440008f,0x26dc0244,0x00000000}},	//   _urma, ēmij, _stvo_,
  { {0x29fe008b,0x69cb11b9,0x6c8601fb,0x00000000}},	//   ịa_, _egge, _غلام,
  { {0xd8380198,0xb5fb004c,0x78a800e5,0x00000000}},	//   goča_, skám, rldv,
  { {0x2bcc0082,0xeef7009a,0x8cc60082,0x00000000}},	//   ाशवा, ומטר_, ादको,
  { {0x61ef0469,0x661d3cd0,0xa7fc0058,0x00000000}},	//   _recl, rfsk, lkım,
  { {0x26ce01f4,0x61ef00e5,0x3d060042,0x00000000}},	//   _tufo_, _secl, _हटने_,
  { {0xd25b0001,0x7d0b3024,0x60c700ca,0x00000000}},	//   оца_, zugs, _rijm,
  { {0x6aa000c7,0x96fb0063,0xe5c7032d,0x00000000}},	//   nomf, _ולהת, _оспо,
  { {0x61e2006d,0x4a5b0063,0x51870054,0x00000000}},	// [6c90] ñola, קדמו, фува,
  { {0x31c40001,0xa7fc005b,0x32c7002b,0x00000000}},	//   ђств, kkım, _gŵyn_,
  { {0x61ef2aac,0x91c00082,0x00000000,0x00000000}},	//   _tecl, लेबै,   ,
  { {0x7bda3cd1,0x5fdf0053,0x61fd00b9,0x00000000}},	//   _aftu, _प्रल, _udsl,
  { {0xece80086,0xa7fc0058,0x60dd3cd2,0x00000000}},	//   дділ_, tkıl, _utsm,
  { {0x44ed0080,0x7d0b2dc0,0x62880260,0x00000000}},	//   iž_, rugs, édov,
  { {0xa7fc0058,0xfaa50133,0x6cc20085,0x00000000}},	//   rkıl, нако, ыйша,
  { {0xa3b40161,0xa49b01a8,0x7d040139,0x00000000}},	//   जेट_, dròm, áisc,
  { {0xa7fc0058,0xf8650054,0xb5fb011b,0x00000000}},	//   akım, евпо, akák,
  { {0x44ed017f,0xd83800c2,0xd7090121,0x00000000}},	//   dž_, toča_, пное_,
  { {0x44ed3cd3,0x0c840085,0x7c84242b,0x00000000}},	//   ež_, _рытм, _руте,
  { {0x26c90290,0xd8383cd4,0x7e79005b,0x00000000}},	//   _ciao_, roča_, _çapı,
  { {0xf484005d,0x2a56009a,0xceb2009a,0x00000000}},	//   ناسی, _רבנן_, טיט_,
  { {0xe1ff00ea,0x3a2d357e,0x28150044,0x00000000}},	//   _adó_, leep_, _أوغس,
  { {0x366a16fc,0x6ed40042,0x787a009a,0x00000000}},	//   _нако_, _बंधु, _צָדו,
  { {0x26c9001b,0xe0da3b72,0x3d000053,0x00000000}},	//   _giao_, зва_, _रिले_,
  { {0x41270431,0xd5b204f6,0x6284004e,0x00000000}},	// [6ca0] ното_, _حفظ_, riio,
  { {0xfe0d0053,0x80a60049,0xf1c401c8,0x00000000}},	//   _हाउस_, رمان, epší_,
  { {0x3a2d3cd5,0x6441006c,0x7ed50054,0x00000000}},	//   keep_, ôlie, вічч,
  { {0x443a001f,0x2bdd0053,0x78a10760,0x00000000}},	//   _hap_, नुसा, holv,
  { {0xb7bc001c,0x61f6005b,0x443a3cd6,0x00000000}},	//   reģi, mayl, _kap_,
  { {0x61f6005b,0x645e3cd7,0x645a0072,0x00000000}},	//   layl, _jopi, ötih,
  { {0xc27a0063,0x443a3cd8,0x7ac602b6,0x00000000}},	//   ּרִי, _map_, нсие,
  { {0x443a000f,0x61f6005b,0xb5fb013d,0x00000000}},	//   _lap_, nayl, rkák,
  { {0x7e970021,0x9998004c,0x7ac30121,0x00000000}},	//   _أنقر_, ěrů_, ысше,
  { {0x443a00ea,0x645e154f,0x44ed00c2,0x00000000}},	//   _nap_, _nopi, vž_,
  { {0xaae60044,0xd7940094,0x49ca066f,0x00000000}},	//   _أسطو, тинъ, _елен_,
  { {0x443a006f,0x7688005b,0xa4d50054,0x00000000}},	//   _aap_, dıys, комі,
  { {0x7c3a003d,0x443a3cd9,0xb5fb013d,0x00000000}},	//   _katr, _bap_, nkái,
  { {0x443a0994,0x69dc0045,0x78a1006f,0x00000000}},	//   _cap_, śred, colv,
  { {0x443a00e3,0x27e0008b,0x083b0149,0x00000000}},	//   _dap_, _đinh_, _מעגל,
  { {0x32c7001f,0x7c3a3cda,0x61f60058,0x00000000}},	//   _gŵyl_, _latr, gayl,
  { {0x764d3c32,0x443a002b,0x7ea3004b,0x00000000}},	// [6cb0] _inay, _fap_, dõpp,
  { {0x7c3a3cdb,0x645e00f1,0x443a0305,0x00000000}},	//   _natr, _gopi, _gap_,
  { {0x3f15130d,0x61f63cdc,0xa022004e,0x00000000}},	//   тдес, bayl, ööal,
  { {0xa2d60161,0x78a1000c,0x7ea3004b,0x00000000}},	//   _मंत्, zolv, gõpp,
  { {0xc1f6014e,0x443a2f70,0xd83800c2,0x00000000}},	//   _במרץ_, _yap_, jočo_,
  { {0x7c3a3cdd,0xd83800c2,0x538b0063,0x00000000}},	//   _catr, dočo_, ּנֵ֣,
  { {0x764d3cde,0x78a13cdf,0x7c3a001f,0x00000000}},	//   _onay, volv, _datr,
  { {0xde46005d,0x0b8800de,0x5338009d,0x00000000}},	//   _لیمو_, عضوي_, תאהב_,
  { {0xdb080080,0x3a2d30c0,0x78a1013d,0x00000000}},	//   _vzdá, reep_, tolv,
  { {0x7c3a00f3,0x290301a6,0x78860003,0x00000000}},	//   _gatr, čja_, _révè,
  { {0x6e3b0004,0x78860003,0x78a100ea,0x00000000}},	//   _kaub, _sévè, rolv,
  { {0x645e3ce0,0x443a3ce1,0x7c3a3ce2,0x00000000}},	//   _sopi, _sap_, _zatr,
  { {0x290d006d,0x6e3b3ce3,0x645e0ab3,0x00000000}},	//   quea_, _maub, _popi,
  { {0x232a0086,0x68fb3ce4,0x6e3b3ce5,0x00000000}},	//   моги_, msud, _laub,
  { {0x68fb0146,0xf8c8001b,0x61f6005b,0x00000000}},	//   lsud, _cứu_, tayl,
  { {0x69db02dd,0x6e3b00a4,0x443a3ce6,0x00000000}},	//   ncue, _naub, _wap_,
  { {0x68fb00b9,0xd5af0021,0x443a3ce7,0x00000000}},	// [6cc0] nsud, _وفى_, _tap_,
  { {0x443a0150,0x6489007d,0x3fe33ce8,0x00000000}},	//   _uap_, ržic, ижув,
  { {0x7eb100d1,0x6e3b0206,0xdfcf013a,0x00000000}},	//   råpn, _baub, زين_,
  { {0x68fb1aee,0x64890078,0x7c3a3ce9,0x00000000}},	//   ksud, mžia, _satr,
  { {0xdd8f0032,0x786d00cd,0x7c3a3cea,0x00000000}},	//   يوم_, _núvo, _patr,
  { {0x64890024,0x68fb3ceb,0x69db0e1a,0x00000000}},	//   ožia, dsud, ecue,
  { {0x7c3a0df3,0x6e3b1caa,0xab270092,0x00000000}},	//   _vatr, _faub, воја_,
  { {0xcc88008b,0x2f1c013d,0xf96a0121,0x00000000}},	//   iới_, míg_, дрой_,
  { {0x7e600027,0xb21b00b9,0x67d4055d,0x00000000}},	//   _iomp, _omæn, лопу,
  { {0x6e3b00bd,0xf8c80013,0x7e600072,0x00000000}},	//   _zaub, _nứt_, _homp,
  { {0x7e603cec,0x68fb004b,0x98a30131,0x00000000}},	//   _komp, asud, риќе,
  { {0x648900eb,0x69db0164,0x6b7b0047,0x00000000}},	//   džia, ccue, _קראנ,
  { {0x39400027,0x66de001c,0xe61f0066,0x00000000}},	//   _éis_, _sīkd, dnôt_,
  { {0xdddb01f7,0xd7ef0095,0x80d60053,0x00000000}},	//   _oluş, _њу_, _बढ़े,
  { {0xf8c8008b,0x248d007d,0xd6cf0062,0x00000000}},	//   _dứt_, đem_, _ът_,
  { {0x764d0009,0x201801f4,0xbb3b0063,0x00000000}},	//   _unay, _acri_, ועלי,
  { {0x2ba90161,0x3a260089,0x6e3b004d,0x00000000}},	// [6cd0] _चुना, _mbop_, _raub,
  { {0x6e3b3ced,0x2f8b005e,0x200f0078,0x00000000}},	//   _saub, мљен_, ėgio_,
  { {0x2fc701e3,0x201c00cd,0x7e600290,0x00000000}},	//   äng_, òvia_, _bomp,
  { {0x44313cee,0x38b90003,0x7e600da1,0x00000000}},	//   lez_, mère_, _comp,
  { {0x38b90164,0x867c0063,0x7e603cef,0x00000000}},	//   lère_, וראו, _domp,
  { {0x6738017f,0x44313cf0,0x30790047,0x00000000}},	//   _osvj, nez_, _טאָנ,
  { {0x6d420469,0x3ec70088,0x39460185,0x00000000}},	//   avoa, _асаб, _aros_,
  { {0x44312370,0x68fb3cf1,0x38b9006c,0x00000000}},	//   hez_, tsud, ière_,
  { {0x38b90164,0x69db0153,0x88c90002,0x00000000}},	//   hère_, rcue, нлив_,
  { {0x39460185,0x69db0d0f,0x44313cf2,0x00000000}},	//   _dros_, scue, jez_,
  { {0x44313cf3,0x3eaf361e,0xeb090021,0x00000000}},	//   dez_, olgt_, _أقصى_,
  { {0x38b90164,0xddc2001c,0xa50a0a74,0x00000000}},	//   dère_, lkoš, нема_,
  { {0x39463cf4,0x69da0041,0x80d30042,0x00000000}},	//   _gros_, _אַוו, _भूले,
  { {0x44313525,0x26d1017d,0x38b90003,0x00000000}},	//   gez_, ízos_, fère_,
  { {0x38b90164,0x291f00fe,0xe2ba005e,0x00000000}},	//   gère_, ltua_, ећај_,
  { {0x64890024,0x3ce60066,0x59c00042,0x00000000}},	//   ržia, ypov_, शेवर,
  { {0x6604002c,0x3a3f003e,0xb4db00cd,0x00000000}},	// [6ce0] _idik, idup_, lvàn,
  { {0x6489146a,0x44310164,0x38b90003,0x00000000}},	//   lžin, cez_, bère_,
  { {0x441b00b5,0xa5bb006d,0x291f00fe,0x00000000}},	//   _אויס, nfón, htua_,
  { {0xb5fb0080,0x4ea50086,0x23650137,0x00000000}},	//   skáv, аріа, älje_,
  { {0xadf30086,0x127b0041,0xac183cf5,0x00000000}},	//   спіш, _טאטע, волу_,
  { {0xdca30086,0x3eaf06a5,0x75370047,0x00000000}},	//   бачи, algt_, טאנד_,
  { {0x291f0360,0x7eb81494,0xfaa60062,0x00000000}},	//   etua_, gípc, лшин,
  { {0x44310045,0x6f930021,0x5f930021,0x00000000}},	//   zez_, _الفض, _الفئ,
  { {0xa9c3019d,0x443103b2,0x212000c2,0x00000000}},	//   йськ, yez_, ntih_,
  { {0x3ea6056f,0xb8dc0053,0x628100ea,0x00000000}},	//   loot_, _आठ_, éloz,
  { {0x62862d2c,0x44313cf6,0xe6550054,0x00000000}},	//   _omko, vez_, авнь,
  { {0x3ea6016d,0x38b90003,0x212000c2,0x00000000}},	//   noot_, vère_, ktih_,
  { {0x9c8300c3,0x44313cf7,0x212000c2,0x00000000}},	//   _ščit, tez_, jtih_,
  { {0x38b90164,0x3ea63cf8,0x44313a7d,0x00000000}},	//   tère_, hoot_, uez_,
  { {0x44313cf9,0x212000c2,0x66e3007b,0x00000000}},	//   rez_, etih_, _лоја,
  { {0x443103b2,0x38b90003,0x7d0b0014,0x00000000}},	//   sez_, rère_, yrgs,
  { {0x38b90003,0x4431146d,0xf485007e,0x00000000}},	// [6cf0] sère_, pez_, _نادی,
  { {0x38b92614,0x7d1d004b,0x2240004b,0x00000000}},	//   père_, _ässi, adik_,
  { {0x6368005a,0x63a900bd,0x6ee70021,0x00000000}},	//   _бряг_, ßend, اسئل,
  { {0x3ea600f5,0x765d0137,0x63a90058,0x00000000}},	//   goot_, njsy, ğend,
  { {0x61ed3cfa,0xed580086,0x067c0047,0x00000000}},	//   mbal, лої_, ענדל,
  { {0xa3d8016a,0x61ed0122,0x6b653cfb,0x00000000}},	//   िशय_, lbal, икла,
  { {0xb5fb00ea,0x3ea63cfc,0x2a6d004b,0x00000000}},	//   nkás, boot_, tkeb_,
  { {0x291f0f22,0x752d08ea,0xddc2007d,0x00000000}},	//   ttua_, _opaz, skoš,
  { {0x291f00fe,0xe8f608a6,0x6e2900a4,0x00000000}},	//   utua_, алы_, _ibeb,
  { {0xb5fb2de9,0x648900eb,0x291f3cfd,0x00000000}},	//   cház, džio, rtua_,
  { {0x291f00fe,0xab84000d,0x61ed3cfe,0x00000000}},	//   stua_, _луцк, kbal,
  { {0x61ed0122,0x6d493cff,0xa6de008b,0x00000000}},	//   jbal, _krea, _trưn,
  { {0x38ab0307,0x6967007e,0x61ed376f,0x00000000}},	//   ført_, _حداق, dbal,
  { {0x1866131b,0x2ca700a4,0x44150062,0x00000000}},	//   _ваши_, nond_, йфст,
  { {0xd8b8007e,0x07d80021,0x6e2900a5,0x00000000}},	//   _صدها_, _إذهب_, _obeb,
  { {0x61ed002c,0x2ca7006f,0x171a0041,0x00000000}},	//   gbal, hond_, _סופע,
  { {0x2ca70004,0xdb0100fe,0x21200089,0x00000000}},	// [6d00] kond_, _hylä, utih_,
  { {0xf00b001b,0x68e90268,0xb5fb0080,0x00000000}},	//   _đảng_, iped, skát,
  { {0x212005c9,0xe29a0088,0x6d493d00,0x00000000}},	//   stih_, _аан_, _area,
  { {0x6d49057a,0xa116007e,0xb5fb00ea,0x00000000}},	//   _brea, _پوست, lkár,
  { {0x3ea60250,0x2bb5008b,0x6d491b69,0x00000000}},	//   root_, _ác_, _crea,
  { {0x290d3d01,0x23ba0053,0x6d493d02,0x00000000}},	//   drea_, _इराद, _drea,
  { {0x8bc3005a,0x290d23d8,0xe4570047,0x00000000}},	//   осъд, erea_, ייסט_,
  { {0x6d490027,0xd83800c3,0x7f3b0063,0x00000000}},	//   _frea, moči_, _בעלו,
  { {0x6296002c,0xd83800c3,0x6d49057a,0x00000000}},	//   inyo, loči_, _grea,
  { {0x2ca704bc,0xc86605fb,0xc7c61b8b,0x00000000}},	//   cond_, ртии, исни,
  { {0x752d051e,0xa2d60161,0x290d0529,0x00000000}},	//   _spaz, _मूल्, area_,
  { {0xe6950076,0x7aea00bd,0x0a6700e1,0x00000000}},	//   симы, mpft, _врши_,
  { {0x95380062,0xc98301ce,0x093602da,0x00000000}},	//   азят_, _муши, _خراج,
  { {0xd838085a,0x62963d03,0xb8ea0053,0x00000000}},	//   koči_, enyo, लग_,
  { {0xe2870079,0xd83800c3,0x83f80be6,0x00000000}},	//   аѓан, joči_, ресс_,
  { {0x2777014e,0x2ca709fe,0xd83808ed,0x00000000}},	//   _כגון_, zond_, doči_,
  { {0x2ca70034,0x63a900bd,0xf8ba0053,0x00000000}},	// [6d10] yond_, ßenb, _उठाय,
  { {0x61ed1203,0x78a800c2,0xae140053,0x00000000}},	//   sbal, nodv, _डाउन_,
  { {0xd83800c3,0x2ca7006f,0x61ed00ac,0x00000000}},	//   goči_, vond_, pbal,
  { {0x2ca7006f,0xb5fb00ea,0x7eb801a8,0x00000000}},	//   wond_, ljáb, típa,
  { {0x2ca70122,0x5cf40121,0x68e93d04,0x00000000}},	//   tond_, оящу, xped,
  { {0x7eb80024,0x6d49000c,0x290d01f4,0x00000000}},	//   rípa, _vrea, vrea_,
  { {0x2ca70173,0xa3d80053,0x6d4900e5,0x00000000}},	//   rond_, िशत_, _wrea,
  { {0x6da5007e,0x6d492eca,0x2ca707fc,0x00000000}},	//   _همزم, _trea, sond_,
  { {0x2ca70164,0x6d99000d,0xb5fb3d05,0x00000000}},	//   pond_, _сваё_, kjáb,
  { {0xa8550095,0x290d3d06,0x66de008f,0x00000000}},	//   стиј, rrea_, _sīka,
  { {0xa5bb0026,0xe945007e,0x2c790003,0x00000000}},	//   sfól, _گرای, _cède_,
  { {0x68e918d2,0x290d0ac2,0xcf92009a,0x00000000}},	//   pped, prea_, לטי_,
  { {0xe945007e,0x67210077,0xb5fb28be,0x00000000}},	//   _درای, stlj, tkár,
  { {0x261a0042,0xb5fb013d,0xc952009a,0x00000000}},	//   _भावी_, gjáb, _ממד_,
  { {0xa3b40053,0x786d01a8,0x66de008f,0x00000000}},	//   ड़ें_, _núvi, _tīka,
  { {0x569300e1,0x23653d07,0xb5fb004c,0x00000000}},	//   _најт, älja_, skár,
  { {0xa6170063,0x2fd60021,0xe526012c,0x00000000}},	// [6d20] _הקפד_, متاح, _удпп,
  { {0x26d20009,0x6aa90173,0x2f560376,0x00000000}},	//   _hiyo_, hoef, йтес,
  { {0x64370041,0x6aa92939,0x20c90044,0x00000000}},	//   _פאטא_, koef, شبكي_,
  { {0x290200eb,0x786d0016,0xd83800c3,0x00000000}},	//   škai_, _dúvi, roči_,
  { {0x64893d08,0xdb08004c,0x361b0aeb,0x00000000}},	//   džij, _vydí, רונד,
  { {0x6a75006d,0x3ead00ea,0x653b0047,0x00000000}},	//   _ráfa, _eket_, טענד,
  { {0xbc190086,0x6aa900ac,0x26c03d09,0x00000000}},	//   річі_, foef, _ohio_,
  { {0x25ad0045,0x6e960032,0x26d2002c,0x00000000}},	//   żeli_, _الرا, _niyo_,
  { {0x9f5a017d,0xdb24007e,0xd83e0066,0x00000000}},	//   dapé_, _ژوئی, účom_,
  { {0x7c650021,0x7d0236a1,0x290a1ed1,0x00000000}},	//   _والل, msos, čba_,
  { {0xcb090086,0x38ab04aa,0x7d0200b8,0x00000000}},	//   _вхід_, tørr_, lsos,
  { {0xa7fc0058,0x648916fe,0x8f9b089e,0x00000000}},	//   tkıs, ržim, ריטי,
  { {0x395900bd,0x261a0053,0x7d023d0a,0x00000000}},	//   ässt_, _भारी_, nsos,
  { {0xf484005a,0x648901da,0x629a0003,0x00000000}},	//   пусн, mžik, éton,
  { {0xd904007e,0xa7fc0058,0xe1d90054,0x00000000}},	//   کی_, skıs, идві_,
  { {0x7d023d0b,0x657a006c,0x2a66004b,0x00000000}},	//   ksos, êché, _joob_,
  { {0x786d0024,0xb5fb013d,0xc1e80085,0x00000000}},	// [6d30] _súvi, pjáb, сьсе_,
  { {0x2a6600bb,0x3ebf0034,0x5f95005a,0x00000000}},	//   _loob_, _shut_, оизт,
  { {0x2c6b00b9,0xfe71007e,0x273a008f,0x00000000}},	//   _mødt_, وگر_, _jūn_,
  { {0xd838007d,0x22420014,0xe787004c,0x00000000}},	//   moču_, _gakk_, náší,
  { {0xdca1000d,0xed590ae8,0x656f3d0c,0x00000000}},	//   мскi_, рол_, nych,
  { {0xc05b0086,0x2c6b05dd,0x64890d29,0x00000000}},	//   _сім_, _nødt_, džik,
  { {0x6aa9006f,0x7d0200a4,0xa7fc005b,0x00000000}},	//   toef, asos, ykır,
  { {0x88e50330,0xe9d9012d,0x2c4f0023,0x00000000}},	//   ожие, шки_, _sēdē_,
  { {0x6aa9006f,0x4c950456,0x7d02013d,0x00000000}},	//   roef, _диас, csos,
  { {0x26d20035,0x656f3d0d,0x6802004c,0x00000000}},	//   _siyo_, dych, víjí,
  { {0x2ca0177f,0x38ca005d,0xab9504a0,0x00000000}},	//   éide_, جايی_, _بلاغ,
  { {0xe7360505,0x8f1a009a,0x9ae8009a,0x00000000}},	//   цею_, סורת, _הַסִ,
  { {0x2c6b02ab,0x15ba000d,0x224204aa,0x00000000}},	//   _født_, рыны_, _rakk_,
  { {0x7d040025,0xb5fb0014,0x7bf90041,0x00000000}},	//   áisi, skáp, יפֿצ,
  { {0x4343005a,0x324606f0,0x27e9008d,0x00000000}},	//   мерв, оевг, _đanh_,
  { {0xd6d20021,0x656f004c,0x63a9004d,0x00000000}},	//   _تقع_, bych, ßena,
  { {0x80660c0b,0x33d60636,0x656f3d0e,0x00000000}},	// [6d40] оваж, _мінт, cych,
  { {0x1fb60086,0x6ecc005b,0xe3b20021,0x00000000}},	//   осер, _işbi, _يرد_,
  { {0x224226d0,0xddc00080,0x44443d0f,0x00000000}},	//   _takk_, _pomů, _ia_,
  { {0x76460acd,0x44380d7d,0x44443d10,0x00000000}},	//   ndky, ler_, _ha_,
  { {0x8cf30088,0x61e4005b,0x44383d11,0x00000000}},	//   дзіц, mcil, oer_,
  { {0x61e4005b,0x44443d12,0x9f580331,0x00000000}},	//   lcil, _ja_, _leré_,
  { {0x9f4302dd,0x2c6b02ab,0x656f0051,0x00000000}},	//   _dejó_, _rødt_, zych,
  { {0xead30055,0x44383d13,0x61e43d14,0x00000000}},	//   мощь, her_, ncil,
  { {0x44383d15,0x44443d16,0x79a30085,0x00000000}},	//   ker_, _oa_, дрэе,
  { {0x7e62017f,0x6d403534,0x44383d17,0x00000000}},	//   ljop, _isma, jer_,
  { {0x673a006f,0x2a660019,0x4438206b,0x00000000}},	//   uwtj, _toob_, der_,
  { {0x443804c6,0x7e6200c7,0x656f0051,0x00000000}},	//   eer_, njop, tych,
  { {0x443804bf,0x7c2a01f4,0x44443d18,0x00000000}},	//   fer_, offr, _ba_,
  { {0x6a7c0164,0x44443d19,0x61e600b9,0x00000000}},	//   _défe, _ca_, _afkl,
  { {0x7c2a0137,0x9f410290,0x44443d1a,0x00000000}},	//   iffr, cchè_, _da_,
  { {0xd8381a39,0xa49b00cd,0x444428e9,0x00000000}},	//   leč_, rròq, _ea_,
  { {0x44440116,0x44383d1b,0x142b2049,0x00000000}},	// [6d50] _fa_, ber_, _кіно_,
  { {0xdb010024,0x44443d1c,0x661d01f2,0x00000000}},	//   _vylú, _ga_, lgsk,
  { {0x9f410025,0x6d402e25,0x44213d1d,0x00000000}},	//   lbhú_, _asma, _ich_,
  { {0x9f41175f,0x22590032,0x29040019,0x00000000}},	//   nché_, _الحد_, ksma_,
  { {0x44443d1e,0x644500bb,0x61fd001c,0x00000000}},	//   _ya_, _kahi, _iesl,
  { {0xd8380117,0x644700e8,0x7c380162,0x00000000}},	//   ječ_, ndji, gevr,
  { {0x64453d1f,0x6d402393,0x20010150,0x00000000}},	//   _mahi, _esma, mahi_,
  { {0x60d501f7,0x44210027,0x64453d20,0x00000000}},	//   _hizm, _lch_, _lahi,
  { {0x44212ddc,0x443804bc,0x60dd0089,0x00000000}},	//   _och_, yer_, _jusm,
  { {0x26dc00eb,0x66de003d,0x200100f3,0x00000000}},	//   _buvo_, _tīkl, nahi_,
  { {0x66e80080,0x44443d21,0xe73903d6,0x00000000}},	//   _někd, _ra_, щен_,
  { {0x4421018d,0x44443d22,0x9f410290,0x00000000}},	//   _ach_, _sa_, rchè_,
  { {0x20013d23,0x290200ea,0xa49b00cd,0x00000000}},	//   kahi_, ákat_, tròp,
  { {0x200107b7,0xb4b60053,0x64451825,0x00000000}},	//   jahi_, जते_, _cahi,
  { {0x44443d24,0x64a30088,0x64453d25,0x00000000}},	//   _va_, хара, _dahi,
  { {0x444410ca,0x9f410290,0x60d5001c,0x00000000}},	//   _wa_, cché_, _aizm,
  { {0x61fd2269,0x7c2a001f,0x64452422,0x00000000}},	// [6d60] _desl, yffr, _fahi,
  { {0x61e402f6,0x8fa6011c,0x44443d26,0x00000000}},	//   scil, пазе, _ua_,
  { {0x7d19006f,0x69d9002b,0x33db009a,0x00000000}},	//   euws, _ogwe, _לחיד,
  { {0x0dca0076,0x61fd3d27,0x69d9001f,0x00000000}},	//   блей_, _gesl, _ngwe,
  { {0xa25b00aa,0x64450035,0x3eba001c,0x00000000}},	//   _khôn, _yahi, ēpt_,
  { {0x69d9001f,0x70190086,0x7e7b004b,0x00000000}},	//   _agwe, _міст_, _elup,
  { {0xd83800c3,0xb5fb00ea,0x5e9604f6,0x00000000}},	//   več_, dján, _فلسط,
  { {0xb954019d,0x7e7b007d,0x290421ef,0x00000000}},	//   двищ, _glup, tsma_,
  { {0x6d40017e,0x2d8201e9,0x48aa0065,0x00000000}},	//   _usma, _åke_, йтом_,
  { {0xf8060086,0x6c8608aa,0x7d7b0063,0x00000000}},	//   ччин, _علام, _הנמו,
  { {0x64453d28,0xd838085a,0x35a50053,0x00000000}},	//   _rahi, reč_, _गुज़,
  { {0xd6d70b62,0x64453d29,0x2a7f0333,0x00000000}},	//   ять_, _sahi, chub_,
  { {0x64450273,0x9f413d2a,0x661d3d2b,0x00000000}},	//   _pahi, rché_, rgsk,
  { {0x753d0045,0x26dc02dd,0x290200eb,0x00000000}},	//   rwsz, _tuvo_, škas_,
  { {0x64473d2c,0x64453d2d,0x24910426,0x00000000}},	//   rdji, _vahi, rizm_,
  { {0x200125e5,0x644523bd,0x4421002b,0x00000000}},	//   wahi_, _wahi, _wch_,
  { {0x64453d2e,0x7e690179,0x44213d2f,0x00000000}},	// [6d70] _tahi, _roep, _tch_,
  { {0x66de003d,0x7e7b3d30,0x27150013,0x00000000}},	//   _rīkj, _slup, úng_,
  { {0x7e7b3d31,0x200114d1,0x61fd2c6a,0x00000000}},	//   _plup, rahi_, _tesl,
  { {0xddd00078,0x3d9502b6,0xbdf80044,0x00000000}},	//   _šešt, миер, كرها_,
  { {0x8c4505d2,0x6d463d32,0x1d090a55,0x00000000}},	//   деле, _škar, цели_,
  { {0x69d9001f,0xa022004b,0xa3b10042,0x00000000}},	//   _sgwe, öötl, टअप_,
  { {0x9f34019d,0x7e6903a8,0x660d3d33,0x00000000}},	//   _пері, _toep, _odak,
  { {0x22490e53,0x660d005b,0x7e7b0cc6,0x00000000}},	//   ndak_, _ndak, _ulup,
  { {0x224908f0,0x21290397,0x7d040025,0x00000000}},	//   idak_, ntah_, áist,
  { {0x660d0397,0xa889013c,0x2a7f3d34,0x00000000}},	//   _adak, ійна_, shub_,
  { {0x628f0089,0x2a7f0150,0xfb35000d,0x00000000}},	//   _omco, phub_, _індэ,
  { {0x49750472,0x7bc1007d,0x150a0044,0x00000000}},	//   _олес, _izlu, يْجٍ_,
  { {0xa25b008b,0xaa880021,0x63a90058,0x00000000}},	//   _phôn, _عنهم_, şenl,
  { {0x02c60042,0x660d3d35,0xb8e10042,0x00000000}},	//   लग्न, _edak, ंत_,
  { {0x394d0037,0x91e63d36,0x98a2019c,0x00000000}},	//   lves_, добе, _шише,
  { {0x648900eb,0x7d093b1f,0xc7b20063,0x00000000}},	//   džiu, _oves, _שבה_,
  { {0xa25b00aa,0x41270189,0xad9d0022,0x00000000}},	// [6d80] _thôn, мото_, _jeźd,
  { {0xb5fb0014,0x22460066,0x394d1574,0x00000000}},	//   hjál, žok_, ives_,
  { {0x7d093d37,0x72c60612,0x21293d38,0x00000000}},	//   _aves, _обоз, atah_,
  { {0x7d0900c2,0x11d60021,0xdddb004c,0x00000000}},	//   _bves, _يتحد, _kouř,
  { {0xb21b0146,0x6489007c,0x6a7c006c,0x00000000}},	//   _slæg, rživ, _néfa,
  { {0x394d00ea,0x718b0063,0x7d091cd2,0x00000000}},	//   dves_, _וְלַ, _dves,
  { {0x2ac60001,0x64890240,0xdee6005e,0x00000000}},	//   мљив, mžit, _цоби,
  { {0xb21b0146,0x2a7d001f,0xa27b0047,0x00000000}},	//   _glæd, _clwb_, ַװיז,
  { {0xdb0800fe,0x6489011b,0x0c263d39,0x00000000}},	//   _sydä, ožit, _оман,
  { {0x6a7c0164,0x60db00cd,0x2cb80139,0x00000000}},	//   _défa, _èume, _órd_,
  { {0x7d090a80,0x7bdb0063,0xe7580054,0x00000000}},	//   _zves, _וקבו, чині_,
  { {0x787f0164,0xdddb0080,0x2a7d001f,0x00000000}},	//   _rêve, _bouř, _glwb_,
  { {0x63a90058,0xb5fb004c,0x47d4005d,0x00000000}},	//   ğenm, okáz, بيگر,
  { {0xa9670001,0xa5bb017d,0x61f60080,0x00000000}},	//   _циља_, egóc, ebyl,
  { {0xa4d4019d,0x46a70055,0x628100eb,0x00000000}},	//   торі, _ошиб, ūlom,
  { {0xe0df02f6,0xd6c3007e,0x660d0035,0x00000000}},	//   _può_, _جمعی, _udak,
  { {0x7eb80016,0xf1940071,0x9055000d,0x00000000}},	// [6d90] cípi, вить, нвац,
  { {0x60b504a0,0x00000000,0x00000000,0x00000000}},	//   رمائ,   ,   ,
  { {0x7d09017f,0x21293764,0xc4d2009a,0x00000000}},	//   _sves, stah_, _תגי_,
  { {0xb21b0146,0xc33200b5,0x8de50044,0x00000000}},	//   _emær, _גוט_, ركته,
  { {0x427a0041,0xddc2011b,0xf1c50042,0x00000000}},	//   _זארג, akož, लेखन,
  { {0x351c0063,0xf1bf004c,0xa0c50044,0x00000000}},	//   קוונ, _dbát_, _سيزو,
  { {0x1ee7007e,0x7e78008f,0x1df9030b,0x00000000}},	//   _آوری_, īvpr, _невы_,
  { {0xb5fb0061,0xcdf40044,0xe8f92184,0x00000000}},	//   akáz, _لأكث, пли_,
  { {0x9f410025,0xb5fb0026,0x394d3d3a,0x00000000}},	//   ichí_, rjál, uves_,
  { {0xb5fb3d3b,0x394d3d3c,0x6a7500be,0x00000000}},	//   ckáz, rves_, _máfi,
  { {0x69c20122,0x394d3d3d,0xdddb0080,0x00000000}},	//   _ezoe, sves_, _souř,
  { {0x7eb83d3e,0x6f7a0063,0xda67005d,0x00000000}},	//   típi, לְכו, _تائي,
  { {0xa25b0003,0x7ae13d3f,0x6abb0244,0x00000000}},	//   _chôm, _hult, mluf,
  { {0xc7a53ce8,0x9817005d,0x7ae13d40,0x00000000}},	//   _пилк, _آبشا, _kult,
  { {0x7ae10db3,0x42563d41,0x03a30456,0x00000000}},	//   _jult, нтат, гиро,
  { {0x7ae109ee,0xb21b0014,0x60ea0085,0x00000000}},	//   _mult, _smær, змам_,
  { {0x9f583d42,0x56370047,0x66063d43,0x00000000}},	// [6da0] _verí_, _טאקע_, makk,
  { {0x66063d44,0x64890114,0x3e4c0013,0x00000000}},	//   lakk, užit, _ớt_,
  { {0x44e6008b,0xdef9000d,0x6fd5000d,0x00000000}},	//   _hô_, дыі_, віцц,
  { {0x629a00cd,0x66063d45,0xc224007e,0x00000000}},	//   ètod, nakk, _جکسو,
  { {0x629601f7,0x62840025,0xdb01005b,0x00000000}},	//   miyo, mhio, _eylü,
  { {0x629619f4,0x44e6001b,0x6aa201e1,0x00000000}},	//   liyo, _mô_, _sjof,
  { {0x7ae103e1,0x44e63d46,0xa0a33d47,0x00000000}},	//   _cult, _lô_, _сард,
  { {0x62963a8e,0x66063d48,0xba540141,0x00000000}},	//   niyo, jakk, твиј,
  { {0x66063d49,0x44e61f2e,0x6da319b6,0x00000000}},	//   dakk, _nô_, _бита,
  { {0x629600bb,0xd7f717ab,0x67d43ce8,0x00000000}},	//   hiyo, ную_, копу,
  { {0x62961a11,0xe8210053,0x7ae10023,0x00000000}},	//   kiyo, _मारा_, _gult,
  { {0x6606014f,0x6e223d4a,0xe6950121,0x00000000}},	//   gakk, ngob, тимы,
  { {0x44e6001b,0x6296005b,0xe4a70071,0x00000000}},	//   _cô_, diyo, ерво,
  { {0x66060072,0x6a750516,0x672b013d,0x00000000}},	//   aakk, _ráfi, éljá,
  { {0xd7f8000c,0x66063d4b,0xa2c7005e,0x00000000}},	//   mbă_, bakk, ељак,
  { {0x67bb014e,0x66062d6f,0xd7f8003b,0x00000000}},	//   _ממוק, cakk, lbă_,
  { {0x68e20006,0x51870a36,0x44e6008d,0x00000000}},	// [6db0] _juod, хува, _gô_,
  { {0x68e2024a,0x5455030b,0x1fa7012c,0x00000000}},	//   _muod, _рвот, нрег,
  { {0x68e2024a,0x83670021,0xd7f8003b,0x00000000}},	//   _luod, _أدخل, ibă_,
  { {0x62843d4c,0x39463d4d,0xc7b30041,0x00000000}},	//   chio, _osos_, אבע_,
  { {0x44e6008b,0x7ae11157,0x68e20078,0x00000000}},	//   _xô_, _sult, _nuod,
  { {0xd7f8003b,0xd116089e,0xfb59005e,0x00000000}},	//   jbă_, _בקשה_, дрић_,
  { {0x66063d4e,0x63a9004d,0x0ebb0049,0x00000000}},	//   yakk, ßenh, _فارغ_,
  { {0x6a7c0003,0x7ae13d4f,0x224b1014,0x00000000}},	//   _défo, _vult, _jack_,
  { {0x20030360,0x66061925,0x88c90062,0x00000000}},	//   _keji_, vakk, млив_,
  { {0x224b0034,0xeafb007e,0x6abb252f,0x00000000}},	//   _lack_, _فرصت_, sluf,
  { {0x394602dd,0x07a50726,0x660623f3,0x00000000}},	//   _esos_, танн, takk,
  { {0xd7f8003b,0xa8020058,0x44e63d50,0x00000000}},	//   abă_, çırm, _pô_,
  { {0x7d19001f,0x62960058,0x660628c6,0x00000000}},	//   nrws, viyo, rakk,
  { {0x44e6001b,0x660628d8,0x7eb812e2,0x00000000}},	//   _vô_, sakk, lípt,
  { {0x629601f7,0xc2b60001,0x224b06b8,0x00000000}},	//   tiyo, вљањ, _back_,
  { {0x44e6008b,0x3a3f00e5,0xf59600de,0x00000000}},	//   _tô_, neup_, _للعج,
  { {0x9f580268,0x629601f7,0xe0da0818,0x00000000}},	// [6dc0] _serà_, riyo, два_,
  { {0x629628c0,0x628406b8,0x0396026c,0x00000000}},	//   siyo, shio, _армя,
  { {0x40330086,0x3a3f0288,0x660413b8,0x00000000}},	//   реєс, keup_, _keik,
  { {0x6a7c0164,0x644e3d51,0xb5fb013d,0x00000000}},	//   _réfo, ldbi, gjáh,
  { {0x6a7c006c,0xa7fc0075,0xa1930085,0x00000000}},	//   _défl, akıy, _ваўч,
  { {0x66043d52,0x3a26000c,0xdb1a00ea,0x00000000}},	//   _leik, _scop_, _aztá,
  { {0x68e2024a,0xa03700ff,0x749b0041,0x00000000}},	//   _suod, _שאלה_, ויספ,
  { {0x66040026,0x249800bd,0x7eb800ea,0x00000000}},	//   _neik, hirm_, típu,
  { {0x58d8042c,0x6b690078,0x60dc3d53,0x00000000}},	//   ндия_, _rūgš, _kirm,
  { {0x68e2024a,0x26c93d54,0x63a918ad,0x00000000}},	//   _vuod, _shao_, şeni,
  { {0xdc9b0063,0xd7f8000c,0x60dc3d55,0x00000000}},	//   _קיבל, rbă_, _mirm,
  { {0x6f0313f8,0x68e200fe,0xeb970063,0x00000000}},	//   ânci, _tuod, _בדבר_,
  { {0xceb311b4,0x66de001c,0x39460530,0x00000000}},	//   שיר_, _rīku, _usos_,
  { {0x60dc24af,0xf7540021,0x224b3d56,0x00000000}},	//   _nirm, _منتج, _sack_,
  { {0x35c70161,0x66e3000a,0x26c9008b,0x00000000}},	//   रेज़, _која, _thao_,
  { {0x442d0080,0x200300c2,0xd6270021,0x00000000}},	//   ře_, _seji_, _شعبي,
  { {0x6a7c0164,0x6a750014,0x7c23002b,0x00000000}},	// [6dd0] _réfl, _gáfu, ygnr,
  { {0x9f580fac,0x155a0063,0xdc1c0042,0x00000000}},	//   _será_, _נכתב, नलोड_,
  { {0x224b01e3,0x764d002c,0x92953d57,0x00000000}},	//   _tack_, _kaay, _банц,
  { {0xfe70006a,0x271c008b,0x12790047,0x00000000}},	//   يدن_, ảng_, _נאָע,
  { {0xed58019d,0x721a014e,0x764d002c,0x00000000}},	//   кої_, _אורח, _maay,
  { {0x66e80080,0x0c240086,0x60dc01f7,0x00000000}},	//   _něko, имін, _girm,
  { {0x9f580016,0xeb35007e,0x5b350021,0x00000000}},	//   _terá_, ارتخ, اعتر,
  { {0x4a450001,0x764d00a4,0x61ed3d58,0x00000000}},	//   унив, _naay, ncal,
  { {0x66043d59,0x60dc0058,0x6e2913cd,0x00000000}},	//   _reik, _yirm, _iceb,
  { {0x79890051,0x91bc0063,0x6d493d5a,0x00000000}},	//   rzew, ומחי, _isea,
  { {0x66043d5b,0xd7090088,0x79890051,0x00000000}},	//   _peik, энне_, szew,
  { {0x8afa009a,0x4a74014b,0x8b88009d,0x00000000}},	//   _נהני, _вышт, _בָנֶ,
  { {0x65c10024,0x22400006,0xdb0805b9,0x00000000}},	//   _náhľ, veik_, _sydø,
  { {0x399a11b4,0xd8790021,0x644e3d5c,0x00000000}},	//   _אינד, _سمعت_, udbi,
  { {0x66043d5d,0x387800c7,0x8883007e,0x00000000}},	//   _teik, örre_, _میکن,
  { {0x6d4900e8,0x20070014,0x6604005f,0x00000000}},	//   _osea, ðnin_, _ueik,
  { {0x463b00b5,0x22403d5e,0x60dc1867,0x00000000}},	// [6de0] _טעקע, reik_, _pirm,
  { {0x6e290331,0x645e1a30,0xceea04ef,0x00000000}},	//   _aceb, _unpi, едже_,
  { {0x6d493d5f,0xc3560062,0x28960047,0x00000000}},	//   _asea, _съпъ, נדען_,
  { {0x127a0032,0xdfcf01a7,0x61ed3d60,0x00000000}},	//   _أحدث_, سين_, ccal,
  { {0xa49b00cd,0x63a9004d,0x63be1f40,0x00000000}},	//   rsòv, ßenv, _hypn,
  { {0x672123f4,0xafe31ece,0xf537009d,0x00000000}},	//   kulj, _горл, רנסי_,
  { {0x290d006d,0x67210130,0xab271313,0x00000000}},	//   esea_, julj, гоја_,
  { {0xc914005e,0xf65f01e1,0x39140e48,0x00000000}},	//   адић, mlæg_, амир,
  { {0x9806000d,0xf65f00b9,0x99970062,0x00000000}},	//   лянд, llæg_, лкът_,
  { {0x764d00a4,0x61ed006d,0x7eb807a8,0x00000000}},	//   _saay, zcal, cípr,
  { {0xf65f0146,0x30db0047,0x764d0072,0x00000000}},	//   nlæg_, ײַזע, _paay,
  { {0x7bc8007d,0x61ed3d61,0x45d50794,0x00000000}},	//   _izdu, xcal, ионс,
  { {0xb21b01e1,0xd90e005d,0x94ab04f2,0x00000000}},	//   _blæn, _عید_, етва_,
  { {0x98a3065b,0x67d40861,0x67210130,0x00000000}},	//   _личе, _колу, bulj,
  { {0xa3d50054,0xb5fb013d,0xddc9003b,0x00000000}},	//   ровч, djáv, _oneş,
  { {0xf65f010a,0x31a50044,0x9294014b,0x00000000}},	//   dlæg_, لمزف, басц,
  { {0x0596007e,0x61ed3d62,0xd01b030b,0x00000000}},	// [6df0] _پايگ, rcal, ефе_,
  { {0x212a007e,0xf00b008b,0x61ed3d63,0x00000000}},	//   ئيلی_, _đẳng_, scal,
  { {0x2fc701e3,0x201c017d,0xf65f01e1,0x00000000}},	//   ång_, óvia_, glæg_,
  { {0x5d5500da,0x200e0014,0x9e350054,0x00000000}},	//   икет, ófir_, редч,
  { {0x2cd50121,0x2d580054,0x8d6504d6,0x00000000}},	//   аждё, лиць_, рвле,
  { {0x1ee7007e,0xc19a009f,0xeb9906da,0x00000000}},	//   _موسی_, _ישרי, кил_,
  { {0x7c840001,0x3cf800a8,0xda650727,0x00000000}},	//   ључе, _črve_, ивки,
  { {0x6d490025,0x6f03003b,0x6ce70054,0x00000000}},	//   _tsea, âncu, _біже,
  { {0x6d49024a,0x186901ce,0x25f40082,0x00000000}},	//   _usea, вапи_, ंडसी_,
  { {0x5d840032,0x76960006,0x67210734,0x00000000}},	//   _الكل, ršym, tulj,
  { {0x5ba70cb5,0x966606f0,0x290d099f,0x00000000}},	//   _сраз, акне, ssea_,
  { {0xc4c90063,0x290d00dd,0x7aee0061,0x00000000}},	//   _חג_, psea_, žité,
  { {0x9f5800cd,0xb21b01e1,0x92080023,0x00000000}},	//   _terç_, _plæn, ntāž,
  { {0xd5470001,0xd7e7000d,0x67213d64,0x00000000}},	//   јпре_, _сідо, pulj,
  { {0xe29a3d65,0x889a3997,0x289a009a,0x00000000}},	//   вав_, _בבסי, _שיצא,
  { {0x63be0240,0xd2a70074,0xd132013a,0x00000000}},	//   _vypn, аксе_, يمز_,
  { {0x7696005f,0xb5fb009c,0x11d70044,0x00000000}},	// [6e00] yšyj, tjáv, لوفة_,
  { {0x2f56184a,0x757b0047,0x7e601c62,0x00000000}},	//   итес, _סטיפ, _snmp,
  { {0x661602f4,0xd4370047,0xee0a02b6,0x00000000}},	//   _kdyk, _דריק_, веел_,
  { {0xb17b00c7,0xd838007d,0x00000000,0x00000000}},	//   _igån, miče_,   ,
  { {0xe3b2007e,0xafe60002,0x62863d66,0x00000000}},	//   _درک_, _вогл, _ilko,
  { {0x62810078,0xcf26007e,0x63bb004d,0x00000000}},	//   ūlot, _پرسي, ßung,
  { {0x8fa32aeb,0xddc9003b,0x2d803d67,0x00000000}},	//   _даре, _poeţ, šie_,
  { {0x7bc8004a,0xcb67005e,0x6a7c0331,0x00000000}},	//   _vzdu, раће_, _kéfi,
  { {0x5c16007e,0xd90d007e,0x76960078,0x00000000}},	//   _نظار, فین_, ašyk,
  { {0x9da5007e,0x98c60002,0x6a7c0003,0x00000000}},	//   _اصفه, јсил, _méfi,
  { {0x7bc8007d,0x62860072,0x8b960092,0x00000000}},	//   _uzdu, _olko, _трач,
  { {0x3ea63d68,0x443a0301,0xd8383d69,0x00000000}},	//   nnot_, _abp_, diče_,
  { {0x443a00f5,0x59d20042,0x3ea63d6a,0x00000000}},	//   _bbp_, देशर, inot_,
  { {0x68ed0025,0xb5fb013d,0x62863d6b,0x00000000}},	//   _éada, eját, _alko,
  { {0x443a00e3,0xd2d70021,0x66e8004c,0x00000000}},	//   _dbp_, لغرب, _měkk,
  { {0x32640f30,0xf00b008b,0x88bd0051,0x00000000}},	//   отув, _đằng_, puśc,
  { {0x30151a02,0xa0c50021,0x21780766,0x00000000}},	// [6e10] йдар, ميرو, айты_,
  { {0x6a7c03b2,0xd5ed001b,0x63a9004d,0x00000000}},	//   _défi, _hoà, ßens,
  { {0xed590130,0xdb230058,0x9df93d6c,0x00000000}},	//   _srž_, ürük, гнет_,
  { {0x63bb01f7,0x4ea40088,0xa283007e,0x00000000}},	//   ğund, орча, _بیرو,
  { {0x067c0047,0xbd6b0062,0x63bb0058,0x00000000}},	//   כנאל, ърже_, şund,
  { {0x30850021,0x7ae80246,0xddc2008f,0x00000000}},	//   _السف, _budt, ujoš,
  { {0xa3d70161,0x26c20051,0x2a7f0019,0x00000000}},	//   िधि_, ylko_, tkub_,
  { {0x769600eb,0xadbd0085,0xdb0e004c,0x00000000}},	//   ršyk, _забi, ídán,
  { {0xe9d90076,0x02950013,0xbb55005d,0x00000000}},	//   ыки_, _đếm_, _گناب,
  { {0x7c2d017f,0xac740032,0xa3d70053,0x00000000}},	//   đars, _والش, िधा_,
  { {0xe7390001,0x38ca007e,0x387800a5,0x00000000}},	//   ћем_, دايی_, örra_,
  { {0xceb20a7a,0x99860130,0x26c2005f,0x00000000}},	//   ִים_, šiše_, ulko_,
  { {0x1827007e,0x959a167b,0x38ca005d,0x00000000}},	//   _نقشی_, утну_, ضایی_,
  { {0xa95600b5,0xd838017f,0x68fb1f08,0x00000000}},	//   _לינק_, tiče_, mpud,
  { {0xf719000d,0xe7390e82,0x06f50021,0x00000000}},	//   _сілы_, _сей_, _استج,
  { {0x27312679,0xd838007d,0xe2973d6d,0x00000000}},	//   mán_, riče_, бас_,
  { {0x2b490051,0x27313d6e,0x63a9004d,0x00000000}},	// [6e20] łach_, lán_, ßenr,
  { {0x2731008b,0x6f180066,0x76463d6f,0x00000000}},	//   oán_, ávco, leky,
  { {0x6d5b0004,0x54770063,0xd5ed0013,0x00000000}},	//   _arua, _הגיע_, _hoá,
  { {0x6286024a,0xdddb0755,0xb5fb00ea,0x00000000}},	//   _ulko, _sluš, ljár,
  { {0x27310027,0x32570063,0x6d5b3d70,0x00000000}},	//   hán_, _הסכם_, _crua,
  { {0x21200150,0xb5fb00ea,0x6d5b00f1,0x00000000}},	//   mrih_, njár, _drua,
  { {0x7f860032,0x2731000f,0x66df0006,0x00000000}},	//   _الأن, ján_, _būkl,
  { {0x7bc1001f,0x4a530062,0xdd920021,0x00000000}},	//   _dylu, зкъс, _فوز_,
  { {0xed573d71,0xda770094,0x0d863d72,0x00000000}},	//   _лот_, сящ_, _улан,
  { {0x7ae800ea,0xbc190054,0xa714005e,0x00000000}},	//   _tudt, _віці_, одољ,
  { {0xb8ef0161,0x291f0035,0xf803000d,0x00000000}},	//   _वी_, arua_, ччын,
  { {0x7c2a0205,0x2715008b,0x657d0072,0x00000000}},	//   lgfr, ính_, tysh,
  { {0xb5fb0014,0xd943210d,0xfd67009a,0x00000000}},	//   fjár, _неци, ֶ֑ךָ_,
  { {0xc9170063,0x201c0871,0x21200734,0x00000000}},	//   _פחות_, óvil_, drih_,
  { {0xd5ed001b,0x273102fc,0x7ae23d73,0x00000000}},	//   _toà, cán_, _kiot,
  { {0x6d400122,0x46a402a9,0x22940076,0x00000000}},	//   _opma, _најв, пися,
  { {0x22580076,0x90993d74,0x7ae23d75,0x00000000}},	// [6e30] щиты_, ават_, _miot,
  { {0x7ae20025,0xb21b01e1,0xa068005e,0x00000000}},	//   _liot, _klæk, бађа_,
  { {0x6d40001c,0x64473d76,0x75280051,0x00000000}},	//   _apma, meji, ądze,
  { {0x64473d77,0x212002f7,0x7c2a013d,0x00000000}},	//   leji, brih_, egfr,
  { {0x2715008b,0x628d0025,0x27313d78,0x00000000}},	//   ánh_, mhao, zán_,
  { {0x2731006d,0xf00b0013,0x7ae20072,0x00000000}},	//   yán_, _đặng_, _aiot,
  { {0x15f90053,0x64551e57,0x78ba0130,0x00000000}},	//   ंडार_, idzi, dotv,
  { {0x27313d79,0x44ef0019,0x539c0149,0x00000000}},	//   ván_, _oü_, טיוו,
  { {0x3ebf003e,0x4438001f,0x2731006d,0x00000000}},	//   _ikut_, yfr_, wán_,
  { {0x48790c07,0x64550051,0x27313d7a,0x00000000}},	//   рсия_, jdzi, tán_,
  { {0xe73925f8,0xd5ed008b,0x660f01bb,0x00000000}},	//   шен_, _soá, fack,
  { {0x9f580521,0x27313d7b,0x7ae23d7c,0x00000000}},	//   _perú_, rán_, _giot,
  { {0x27312669,0x99dd0066,0x76460078,0x00000000}},	//   sán_, meňo, reky,
  { {0x6a7c0003,0x2731086a,0x64550022,0x00000000}},	//   _défu, pán_, gdzi,
  { {0x200a0268,0x44ef0019,0x63a9004d,0x00000000}},	//   _rebi_, _eü_, ßenp,
  { {0x68e33d7d,0xd5ed001b,0x200a01b3,0x00000000}},	//   _hind, _toá, _sebi_,
  { {0x20180150,0xb5fb00ea,0x68e30708,0x00000000}},	// [6e40] _pdri_, pjár, _kind,
  { {0x68e30080,0x28cf0053,0x3ebf2a80,0x00000000}},	//   _jind, _सीमि, _akut_,
  { {0x68eb3d7e,0x63bb0058,0xe3b2007e,0x00000000}},	//   _lugd, ğunc, _زرد_,
  { {0x68e33d7f,0x628d0917,0x44ef092a,0x00000000}},	//   _lind, chao, _yü_,
  { {0x2d580086,0x8afc0051,0x200a08ed,0x00000000}},	//   силь_, _kręg, _tebi_,
  { {0x6ce30086,0x3ead00b9,0x68e33d80,0x00000000}},	//   міще, _ejet_, _nind,
  { {0x7ae20051,0xa5bb0025,0x62840078,0x00000000}},	//   _piot, rgói, okio,
  { {0x68e303d9,0x64550051,0x6aa9000e,0x00000000}},	//   _aind, zdzi, gnef,
  { {0xfe43019d,0xf2d30063,0xb86a0001,0x00000000}},	//   _інфо, ועה_, ајне_,
  { {0x6a7c0164,0x395d001f,0x0b1a0021,0x00000000}},	//   _réfu, _drws_, _نقطة_,
  { {0x68e33d81,0x9f580290,0x660f2e83,0x00000000}},	//   _dind, _perù_, tack,
  { {0x64550045,0x68e33d82,0x48e60002,0x00000000}},	//   wdzi, _eind, _додв,
  { {0xd6d8019d,0x1fb70053,0xfad70047,0x00000000}},	//   ють_, _अड्ड, _וואך_,
  { {0x660f3d83,0x64553d84,0xf8630094,0x00000000}},	//   sack, udzi, _овчо,
  { {0x64550045,0x628d0139,0x64473d85,0x00000000}},	//   rdzi, thao, reji,
  { {0x44ef0019,0xd319005e,0x68e33d86,0x00000000}},	//   _tü_, _цeнт, _zind,
  { {0x628d001f,0x518709c2,0x3ebf3d87,0x00000000}},	// [6e50] rhao, цува, _rkut_,
  { {0x660d0019,0x62840072,0x00000000,0x00000000}},	//   _heak, akio,   ,
  { {0x660d017e,0x6728007d,0xaca3008d,0x00000000}},	//   _keak, nudj, _luợn,
  { {0x9c7c3d88,0xfe71005d,0xf773009a,0x00000000}},	//   _riča, رگز_, וקע_,
  { {0x63ad003d,0x248c0006,0x6aa906a5,0x00000000}},	//   šinā, šimų_, vnef,
  { {0x317a014e,0x6d5d0026,0x660d12a9,0x00000000}},	//   _הרשמ, _ásam, _leak,
  { {0x68e33d89,0x672800c2,0x6cc2000d,0x00000000}},	//   _rind, judj, эйша,
  { {0x6721017f,0x68e33d8a,0x09050121,0x00000000}},	//   vrlj, _sind, ппин,
  { {0x68e33d8b,0x6aa93d8c,0x99dd0066,0x00000000}},	//   _pind, rnef, reňo,
  { {0x6abb006c,0x2707013d,0x00000000,0x00000000}},	//   souf, tőn_,   ,
  { {0x68e33d8d,0x27e90058,0x660d3d8e,0x00000000}},	//   _vind, _şans_, _beak,
  { {0x64900019,0x68e3375e,0xe7360505,0x00000000}},	//   _käig, _wind, чею_,
  { {0x68e33d8f,0x95830121,0x660d3d90,0x00000000}},	//   _tind, еляе, _deak,
  { {0x9c7c017f,0x6728024a,0x443e0080,0x00000000}},	//   _ličn, budj, ýt_,
  { {0x935901dd,0x9814007e,0x67d202d8,0x00000000}},	//   орту_, _آبها, _пољу,
  { {0x660d00e8,0xc7b20063,0xf65f00b9,0x00000000}},	//   _geak, _רבה_, llæn_,
  { {0x66e80080,0x61431122,0x394d002b,0x00000000}},	// [6e60] _děku, нета, nwes_,
  { {0x90c30055,0x76960006,0x62843d91,0x00000000}},	//   ебуе, ašyt, skio,
  { {0x7d09133f,0xfe460121,0x547b009a,0x00000000}},	//   _awes, знео, _הטיו,
  { {0x2129014f,0xddcf08cf,0xa5bb009c,0x00000000}},	//   buah_, _šeše, rgóv,
  { {0x78a1007a,0x7d090185,0x1288007e,0x00000000}},	//   kilv, _cwes, _همگی_,
  { {0x653b0047,0x394d00ac,0x6da30044,0x00000000}},	//   מענד, dwes_, عموم,
  { {0x394d00ac,0x3af10013,0x0ef9000d,0x00000000}},	//   ewes_, _cáp_, _мэты_,
  { {0x8f37009a,0x00000000,0x00000000,0x00000000}},	//   _מאלו_,   ,   ,
  { {0x7d09001f,0xfe43000d,0x6490004b,0x00000000}},	//   _gwes, _янто, _käid,
  { {0xb0be0053,0x611e000c,0x8afc0051,0x00000000}},	//   ्तिग, călţ, _pręd,
  { {0x66e80080,0x660d3d92,0x99e60ac5,0x00000000}},	//   _někt, _peak, _ежед,
  { {0x9169008d,0x368b1528,0x00000000,0x00000000}},	//   sửa_, ссон_,   ,
  { {0x3ea700ea,0x20be0042,0x660d004e,0x00000000}},	//   énti_, ्ताध, _veak,
  { {0x660d0034,0xb9db014e,0x6490047f,0x00000000}},	//   _weak, _החדש, _näid,
  { {0x75280045,0x083b0132,0x883b009a,0x00000000}},	//   ądza, _העול, _התוו,
  { {0xe8df001b,0x21290150,0xd1bb0021,0x00000000}},	//   ược_, tuah_, ماذا_,
  { {0x22490034,0x76960006,0x9c7c0066,0x00000000}},	// [6e70] reak_, ršyt, _ničo,
  { {0x212900e3,0x4f6b0076,0x6490004b,0x00000000}},	//   ruah_, йшем_, _räig,
  { {0x212900e3,0x3f87027d,0x6e190021,0x00000000}},	//   suah_, ánu_, قياس_,
  { {0x3f8f0045,0x7d0900a4,0x66df0006,0x00000000}},	//   ągu_, _pwes, _būki,
  { {0x3f87017f,0x3af10013,0x78a1013d,0x00000000}},	//   šnu_, _sáp_, yilv,
  { {0xd7e60032,0x8c420121,0xfbc50141,0x00000000}},	//   _لك_, веше, мбло,
  { {0x6a7c0003,0x64573d93,0x9e150054,0x00000000}},	//   _réfr, _maxi, _одві,
  { {0xbe650044,0xe8f9231a,0x00000000,0x00000000}},	//   _تهري, оли_,   ,
  { {0xdb1a01c2,0xdd9402dc,0x78a13d94,0x00000000}},	//   _vytá, _заты, tilv,
  { {0x9f5a006d,0x76562357,0x5d541224,0x00000000}},	//   capó_, _sayy, _якут,
  { {0x7e7b0080,0xdb080137,0x00000000,0x00000000}},	//   _koup, _sydö,   ,
  { {0x29d50021,0x78a11b81,0xe5a617f2,0x00000000}},	//   _قياس, silv, дими,
  { {0xd8380066,0x78a101cf,0x6b833d95,0x00000000}},	//   cičo_, pilv, lyng,
  { {0x98f40021,0x94d3000d,0x645703cc,0x00000000}},	//   _أثنا, коўц, _caxi,
  { {0xd3b50076,0xa3d80053,0x76563d96,0x00000000}},	//   есть, ़ें_, _tayy,
  { {0x443300be,0x452a04ef,0x221502fa,0x00000000}},	//   _ecx_, _джин_, еффр,
  { {0x00e60088,0x6b83001f,0x645700be,0x00000000}},	// [6e80] джан, hyng, _faxi,
  { {0xeb0d0053,0x44f40050,0x96f9009a,0x00000000}},	//   _सबूत_, _iä_, ַלְת,
  { {0x64900019,0xdd8f007e,0x44f40ef1,0x00000000}},	//   _väid, یوم_, _hä_,
  { {0x7e7b0399,0xe1f201fb,0x44f40050,0x00000000}},	//   _coup, _جسد_, _kä_,
  { {0x64900019,0x4103005a,0xbea3005e,0x00000000}},	//   _täid, _изяв, њачк,
  { {0x6b830185,0x44f40072,0x6fd60042,0x00000000}},	//   fyng, _mä_, _भरपू,
  { {0x64900019,0x44f400c7,0x6b83001f,0x00000000}},	//   _käib, _lä_, gyng,
  { {0x5a34005a,0xf1bf0025,0x3860000c,0x00000000}},	//   хнит, _gcás_, _şir_,
  { {0xbea31fa2,0x44f43d97,0x09030085,0x00000000}},	//   _ратк, _nä_, кчэм,
  { {0x9c7c007d,0x7d0207b9,0x7e690061,0x00000000}},	//   _kičm, mpos, _znep,
  { {0xf76f0021,0x7d023d98,0x7526030c,0x00000000}},	//   لاَ_, lpos, erkz,
  { {0x7d0200a8,0x98ae0058,0x4992005d,0x00000000}},	//   opos, ınıp_, _لیبر,
  { {0xb4e90235,0x7d023d99,0x99340044,0x00000000}},	//   यदे_, npos, _أفتت,
  { {0xd7ef0259,0x00000000,0x00000000,0x00000000}},	//   _ју_,   ,   ,
  { {0x43950054,0x4c9b009a,0xd7730044,0x00000000}},	//   хавс, קבלו, _لايع,
  { {0xd7f8000c,0x5187005e,0x8afc0022,0x00000000}},	//   lcă_, муза, _zręc,
  { {0x7e7b3d9a,0x44f40137,0x27383d9b,0x00000000}},	// [6e90] _roup, _gä_, lén_,
  { {0xd7f8000c,0x291900ea,0x7e7b3d9c,0x00000000}},	//   ncă_, ásai_, _soup,
  { {0x2fc70146,0x7e7b3d9d,0xd7f8003b,0x00000000}},	//   æng_, _poup, ică_,
  { {0xdde20077,0x92950092,0x00000000,0x00000000}},	//   _šušt, _чамц,   ,
  { {0x8498006a,0x1d0907fe,0x7d023d9e,0x00000000}},	//   _رئیس_, чели_, gpos,
  { {0x64900004,0x673a0829,0x2738013d,0x00000000}},	//   _täie, kttj, kén_,
  { {0xce95005a,0x2738000f,0xb0be0053,0x00000000}},	//   _завъ, jén_, ्तरग,
  { {0x7d022c59,0x7df0005f,0x6b833d9f,0x00000000}},	//   bpos, tėsž, ryng,
  { {0x22593da0,0x8afc0022,0xf9910044,0x00000000}},	//   _mask_, _pręc, طبة_,
  { {0x7d1b0072,0x44f401e9,0x13fb0042,0x00000000}},	//   _ivus, _rä_, ्रोह_,
  { {0x3946021f,0x20110080,0x273800ea,0x00000000}},	//   _epos_, _mezi_, gén_,
  { {0xd7f80529,0x63bb005b,0x28cf0053,0x00000000}},	//   acă_, ğunl, _सीरि,
  { {0x394600e8,0xd914000d,0x3eaf0d23,0x00000000}},	//   _gpos_, _адчы, ingt_,
  { {0x273805ab,0x628f3da1,0x442d0130,0x00000000}},	//   bén_, _alco, јe_,
  { {0x7d020c22,0xb6a60062,0x22593da2,0x00000000}},	//   zpos, _пикл, _bask_,
  { {0x44f400fe,0x7d020051,0x8e20000d,0x00000000}},	//   _tä_, ypos, зiн_,
  { {0x95560032,0x98a4001c,0x7d02210b,0x00000000}},	// [6ea0] _أخبا, lumā_, xpos,
  { {0xb21b05b9,0x628f0f20,0x888c0041,0x00000000}},	//   _blæs, _elco, ֿראַ,
  { {0x645c3da3,0x395f004b,0x03a60541,0x00000000}},	//   mdri, hvus_, _чино,
  { {0x20070026,0x7d023da4,0x644e3da5,0x00000000}},	//   ðnir_, tpos, lebi,
  { {0x645c3709,0x271c0013,0x127b0047,0x00000000}},	//   odri, ảnh_, _זאכע,
  { {0x644e3da6,0x7d023da7,0x98a4001c,0x00000000}},	//   nebi, rpos, kumā_,
  { {0x98a4003d,0x44443da8,0x644e1308,0x00000000}},	//   jumā_, _mb_, iebi,
  { {0x6564002c,0xdb1a00b9,0x273800ea,0x00000000}},	//   _orih, _nytå, vén_,
  { {0x44443da9,0x644e3daa,0xdcfa0021,0x00000000}},	//   _ob_, kebi, _رفضت_,
  { {0x644e017f,0x645c006f,0x31370063,0x00000000}},	//   jebi, jdri, ענים_,
  { {0xd7f8000c,0x644e3dab,0xf98f007e,0x00000000}},	//   rcă_, debi, لبی_,
  { {0xd7f80529,0x44443dac,0x644e004b,0x00000000}},	//   scă_, _ab_, eebi,
  { {0x673a0c4a,0x22591c87,0x273811ba,0x00000000}},	//   sttj, _rask_, sén_,
  { {0x273800ea,0xdb1a0072,0x644e06ad,0x00000000}},	//   pén_, _tytä, gebi,
  { {0x44443dad,0x32670088,0x22402da7,0x00000000}},	//   _db_, нтав, ffik_,
  { {0x656406a3,0x645c2264,0x9c7c00a8,0x00000000}},	//   _frih, adri, _bičk,
  { {0x2b520051,0x644e3dae,0xb21b05a5,0x00000000}},	// [6eb0] łych_, bebi, _blær,
  { {0x644e0016,0x765d0917,0x44443daf,0x00000000}},	//   cebi, ldsy, _gb_,
  { {0x22590592,0x752f0051,0x20113db0,0x00000000}},	//   _task_, lucz, _vezi_,
  { {0x9f580a6b,0x765d0146,0x395f0006,0x00000000}},	//   _però_, ndsy, yvus_,
  { {0x44441a23,0x760c00b5,0x44210066,0x00000000}},	//   _yb_, פּאַ, _kdh_,
  { {0x21290360,0x7d1c008f,0x753d3db1,0x00000000}},	//   mrah_, _ārst, itsz,
  { {0xb21b00b9,0x9f41006d,0xdfd40085,0x00000000}},	//   _ulæs, rchó_, _боры,
  { {0x6d5d0006,0x644e0e70,0x98a4008f,0x00000000}},	//   _šsau, zebi, vumā_,
  { {0x644e01f7,0xb6040080,0x44210139,0x00000000}},	//   yebi, ndář, _odh_,
  { {0x98a4001c,0x21291472,0x44211648,0x00000000}},	//   tumā_, irah_, _ndh_,
  { {0x3209002c,0x6c7a0047,0x644e3aa7,0x00000000}},	//   kbay_, _קרעד, vebi,
  { {0x98a4001c,0x44443db2,0x6564064f,0x00000000}},	//   rumā_, _sb_, _prih,
  { {0xd497008b,0x21290397,0x26c23db3,0x00000000}},	//   ằng_, jrah_, roko_,
  { {0x2ca7000c,0x61fd3db4,0x98a4001c,0x00000000}},	//   nind_, _afsl, pumā_,
  { {0x644e1a8d,0x2ca7003b,0x21290360,0x00000000}},	//   rebi, iind_, erah_,
  { {0x7afc000f,0x2ca713af,0xb21b0026,0x00000000}},	//   _érte, hind_, _slær,
  { {0x3ea600fe,0x44443db5,0x6f1c004c,0x00000000}},	// [6ec0] viot_, _tb_, _svrc,
  { {0x44443db6,0x9f580014,0x7aeb3db7,0x00000000}},	//   _ub_, _berð_, _ligt,
  { {0x22a8005b,0xee3a2d76,0x21291d4c,0x00000000}},	//   aşka_, дне_, arah_,
  { {0x26c30117,0x787e0080,0xdddb004c,0x00000000}},	//   čkog_, _závě, _dluž,
  { {0x2ca70618,0xf5ad0063,0x64580014,0x00000000}},	//   find_, ּבוּ, _óvis,
  { {0x3ea600fe,0x9f580026,0x2ca73db8,0x00000000}},	//   siot_, _ferð_, gind_,
  { {0x9f580026,0x3ea60072,0xdddb008f,0x00000000}},	//   _gerð_, piot_, _gluž,
  { {0x69cb3db9,0xcb67005e,0x5a46000d,0x00000000}},	//   _byge, ђање_, тэка,
  { {0x7aeb3dba,0x9c7c00b2,0xda770062,0x00000000}},	//   _digt, _liči, тящ_,
  { {0x2ca70025,0x2bbb0042,0x29040075,0x00000000}},	//   cind_, _ऊँचा, rpma_,
  { {0x320900bb,0xd8380b59,0x9c7c3dbb,0x00000000}},	//   ybay_, niči_, _niči,
  { {0x752f0051,0x44213dbc,0x91690013,0x00000000}},	//   tucz, _sdh_, hứa_,
  { {0x765d3566,0x3857005d,0x6d5d013d,0x00000000}},	//   rdsy, رشید_, _ásat,
  { {0x98a3000a,0x3af83dbd,0x9c7c0078,0x00000000}},	//   _киче, _kép_, _biči,
  { {0xa3dd0053,0xd4980156,0x753d3310,0x00000000}},	//   तें_, тря_, stsz,
  { {0x21291c80,0x2ca73dbe,0x3af80013,0x00000000}},	//   trah_, zind_, _mép_,
  { {0xdddb3dbf,0x21290360,0x3af80437,0x00000000}},	// [6ed0] _služ, urah_, _lép_,
  { {0x66df276c,0x99dd3dc0,0x91e4005e,0x00000000}},	//   _tūks, meňt, рође,
  { {0x2ca73dc1,0xdb1e0164,0x6d493dc2,0x00000000}},	//   vind_, _évèn, _spea,
  { {0x212900f3,0x6458007a,0x9f580026,0x00000000}},	//   prah_, _óvir, _verð_,
  { {0x7aeb3dc3,0x2ca7003b,0x9e340086,0x00000000}},	//   _rigt, tind_, речч,
  { {0x64900019,0x7aeb102b,0x69cb01e1,0x00000000}},	//   _läin, _sigt, _ryge,
  { {0x447c00b5,0x69cb00b9,0x98a4003b,0x00000000}},	//   ונגע, _syge, zumă_,
  { {0x2ca70529,0x66d600ea,0xb4db00cd,0x00000000}},	//   sind_, káka, ntàb,
  { {0x7aeb010a,0x2d9900d1,0x52dc0047,0x00000000}},	//   _vigt, _åse_, וקהײ,
  { {0xd7090055,0x69cb0240,0x2eed00ca,0x00000000}},	//   нное_, _vyge, _hief_,
  { {0x69cb0051,0x16aa3dc4,0x3af8013d,0x00000000}},	//   _wyge, евни_, _gép_,
  { {0xb8030042,0x69cb3dc5,0xa5f7005e,0x00000000}},	//   _श्रम_, _tyge, леџу_,
  { {0x5e560047,0x28080066,0x1994000d,0x00000000}},	//   נישע_, ätná_, _каця,
  { {0xc9520063,0x2eed24f5,0x6aa919cd,0x00000000}},	//   _למד_, _lief_, lief,
  { {0x78ad011b,0xa6f9009a,0xa2840043,0x00000000}},	//   čivě, _אִ֥י, لیدو,
  { {0xb2950001,0x66d600ea,0x6aa91c8b,0x00000000}},	//   ајућ, báka, nief,
  { {0x4127071a,0x7d04001c,0x79892f71,0x00000000}},	// [6ee0] лото_, ģisk, nyew,
  { {0x07170053,0x66160058,0x6aa91eca,0x00000000}},	//   _दबाव_, _heyk, hief,
  { {0xe45700b5,0x443a2322,0x3f8e3dc6,0x00000000}},	//   _גייט_, _icp_, áfu_,
  { {0xdb1e0164,0x98a40006,0x6aa93dc7,0x00000000}},	//   _évén, mumą_, jief,
  { {0x63b6003d,0x98a40006,0x6aa92cb0,0x00000000}},	//   šanā, lumą_, dief,
  { {0x6adc0161,0x30760086,0xd8381035,0x00000000}},	//   मग्र, _сумс, piči_,
  { {0x69dd007a,0xb5fb01d9,0x201a0455,0x00000000}},	//   ýsen, ndác, mapi_,
  { {0x6f030268,0x201a002c,0x6aa900ac,0x00000000}},	//   ínce, lapi_, gief,
  { {0x99dd004c,0xd7f00044,0xa112014b,0x00000000}},	//   deňs, يكة_, ацiл,
  { {0x31570063,0x8d930021,0xfce63852,0x00000000}},	//   ניין_, _الكش, _созо,
  { {0xb866007e,0x2902001c,0x64900072,0x00000000}},	//   ناگو, ūka_, _päin,
  { {0x6028001c,0x66d6013d,0x443a2d20,0x00000000}},	//   līmē, táka, _acp_,
  { {0x201a014f,0x645e0150,0xe1ff0051,0x00000000}},	//   kapi_, _bapi, _znów_,
  { {0x9405007e,0x44f40002,0x645e0749,0x00000000}},	//   شوره, спрс, _capi,
  { {0x201a0974,0x98a40006,0x645e0150,0x00000000}},	//   dapi_, gumą_, _dapi,
  { {0x68ed0025,0x92580152,0x66dd013d,0x00000000}},	//   _éadr, ласт_, dékg,
  { {0x2eed00bd,0x7c3a3dc8,0x645e002b,0x00000000}},	// [6ef0] _rief_, _octr, _fapi,
  { {0x201a00f3,0x98a40006,0x645e3dc9,0x00000000}},	//   gapi_, bumą_, _gapi,
  { {0x23fa0063,0x20d400fe,0x14b80021,0x00000000}},	//   _בהתא, päin_, _حديث_,
  { {0x645e3dca,0xd838007d,0xdbff0042,0x00000000}},	//   _zapi, miču_, ॉर्ड_,
  { {0xddc5257e,0xb7b5008d,0x645e0058,0x00000000}},	//   јбли, oạc, _yapi,
  { {0x201a0089,0x64900659,0x2eed0089,0x00000000}},	//   capi_, _näil, _wief_,
  { {0x3f870019,0x2eed00bd,0x6aa93dcb,0x00000000}},	//   änud_, _tief_, tief,
  { {0xca850062,0xa8020058,0xb7b5008d,0x00000000}},	//   ргий, çınm, hạc,
  { {0xe9d9005a,0x66163dcc,0x394b006c,0x00000000}},	//   ъки_, _reyk, ïcs_,
  { {0xa3b50053,0x6d5b3dcd,0x6aa93dce,0x00000000}},	//   जपा_, _isua, sief,
  { {0xe7390138,0x799b004d,0x645e3dcf,0x00000000}},	//   њем_, szuw, _rapi,
  { {0x6b7a00b5,0x98a40006,0x4875007e,0x00000000}},	//   _ברענ, vumą_, ادکس,
  { {0x6020004c,0x443a20c5,0x645e3dd0,0x00000000}},	//   námí, _pcp_, _papi,
  { {0x98a40006,0x2aba001c,0x37e50054,0x00000000}},	//   tumą_, mība_, _колг,
  { {0x2aba001c,0xa3a90053,0x43750086,0x00000000}},	//   lība_, _खेद_, бутт,
  { {0x6028003d,0x645e14ce,0x98a40006,0x00000000}},	//   zīmē, _wapi, rumą_,
  { {0x201a0397,0x644100cd,0x2aba001c,0x00000000}},	// [6f00] tapi_, òlic, nība_,
  { {0x64900019,0xa494007e,0x7f460121,0x00000000}},	//   _käim, _ایست, иезж,
  { {0x201a014f,0x547b0063,0x41d50053,0x00000000}},	//   rapi_, _סטטו, _दरअस,
  { {0x201a002c,0xdfcf0032,0x291f00fe,0x00000000}},	//   sapi_, ذين_, ksua_,
  { {0x2aba008f,0x8d560782,0x6d5b009c,0x00000000}},	//   jība_, ртеч, _csua,
  { {0xd0071321,0x66dd00ea,0x2aba001c,0x00000000}},	//   _вере_, méke, dība_,
  { {0x66dd00ea,0x8cc50053,0x20183dd1,0x00000000}},	//   léke, ाक़ो, _ieri_,
  { {0xe8df001b,0x6490047f,0x20183dd2,0x00000000}},	//   ước_, _säil, _heri_,
  { {0x20183dd3,0x7c3a271b,0x66d63dd4,0x00000000}},	//   _keri_, _tctr, tákn,
  { {0x61e00080,0x6d42003b,0x7e60374b,0x00000000}},	//   _úmlu, mtoa, _hamp,
  { {0xb8fd0161,0x20183dd5,0x501b0063,0x00000000}},	//   _थी_, _meri_, כויו,
  { {0x2018005b,0x4438001f,0x7bda001c,0x00000000}},	//   _leri_, egr_, _iztu,
  { {0x7e600397,0x2aba001c,0x6d420f8c,0x00000000}},	//   _mamp, cība_, ntoa,
  { {0x442d0199,0x20183dd6,0xd838007d,0x00000000}},	//   ße_, _neri_, tiču_,
  { {0x92a70001,0x24180076,0x602000ea,0x00000000}},	//   ајал, росы_, zámí,
  { {0x7e60035e,0x442d1c93,0x201801a8,0x00000000}},	//   _namp, şe_, _aeri_,
  { {0x661d3dd7,0x201823c1,0x7e6204ad,0x00000000}},	// [6f10] mask, _beri_, ddop,
  { {0xdb1a0164,0x661d3209,0x212a007e,0x00000000}},	//   _exté, lask, ايلی_,
  { {0x46bb0161,0x2120003e,0x2aba001c,0x00000000}},	//   _उदाह, asih_, zība_,
  { {0x64553dd8,0x44fd008b,0xf65f00b9,0x00000000}},	//   lezi, _kì_, mlæs_,
  { {0x63bb01f7,0x4e18007e,0x7e603dd9,0x00000000}},	//   ğunu, شتند_, _damp,
  { {0x201805a2,0x64551611,0x63bb005b,0x00000000}},	//   _geri_, nezi, şunu,
  { {0x2f180088,0x64550290,0x44fd3dda,0x00000000}},	//   _вось_, iezi, _lì_,
  { {0x7e601cb6,0x291f00fe,0x661d3ddb,0x00000000}},	//   _gamp, tsua_, jask,
  { {0xe9a9006a,0x6ea8005a,0x1c0b0053,0x00000000}},	//   دگان_, _търг_, _स्थल_,
  { {0x20013ddc,0x7e602ae4,0x2aba001c,0x00000000}},	//   nchi_, _zamp, rība_,
  { {0x291f017d,0x66dd10fd,0x2aba001c,0x00000000}},	//   ssua_, zéke, sība_,
  { {0xa9270006,0x6b6000ea,0xf65f00b9,0x00000000}},	//   _pažį, ságá, dlæs_,
  { {0x64550290,0xddcb0051,0x7529007d,0x00000000}},	//   fezi, legł, šezn,
  { {0x22950147,0x44fd3ddd,0x64550717,0x00000000}},	//   _råka_, _dì_, gezi,
  { {0x68f9006f,0xe2960002,0x66e63dde,0x00000000}},	//   _huwd, браќ, _лока,
  { {0x20180228,0x66dd000f,0x272301f7,0x00000000}},	//   _seri_, téke, mın_,
  { {0x44fd001b,0x2723005b,0x32190370,0x00000000}},	// [6f20] _gì_, lın_, _desy_,
  { {0x64550c99,0xf65f0146,0xb4db0268,0x00000000}},	//   cezi, slæt_, ltàn,
  { {0x272304ab,0x2a7f0150,0x201805a7,0x00000000}},	//   nın_, kjub_, _veri_,
  { {0xc333014e,0xb4db0268,0x6d4207ba,0x00000000}},	//   _צור_, ntàn, ttoa,
  { {0x763b00b5,0x7bda0051,0x66040035,0x00000000}},	//   רענג, _sztu, _mfik,
  { {0x20010a07,0x272301f7,0x6ab20161,0x00000000}},	//   cchi_, kın_, ुक्र,
  { {0x628615c0,0x29060035,0x7e60035d,0x00000000}},	//   _koko, _stoa_, _tamp,
  { {0x2723005b,0xd83800c2,0x20d4004b,0x00000000}},	//   dın_, ihče_, käik_,
  { {0xdee30055,0xf65f00d1,0x661d3ddf,0x00000000}},	//   _хоти, klær_, vask,
  { {0x661d0397,0x415b0047,0xc1730063,0x00000000}},	//   wask, נדיג, פחת_,
  { {0x44fd051e,0x7bda001c,0x64553de0,0x00000000}},	//   _sì_, _uztu, vezi,
  { {0x6286087a,0x6455006f,0xddc9003b,0x00000000}},	//   _noko, wezi, _uneţ,
  { {0xa3e60053,0x66dd00ea,0xf1bf0331,0x00000000}},	//   बेस_, tékb, _adán_,
  { {0x44fd001b,0x661d2bfe,0x6604017f,0x00000000}},	//   _vì_, sask, _efik,
  { {0xf8bf0164,0xd7f8000c,0x645504df,0x00000000}},	//   éée_, ndăm_, rezi,
  { {0xb4db00cd,0x7afa3de1,0x64553de2,0x00000000}},	//   ctàn, _mutt, sezi,
  { {0x764d002c,0x7afa3de3,0xe1f00021,0x00000000}},	// [6f30] _ibay, _lutt, فسك_,
  { {0x649000fe,0x7afa3de4,0x26cb3b47,0x00000000}},	//   _näih, _outt, loco_,
  { {0x2001051e,0x7afa0b05,0x628600ea,0x00000000}},	//   rchi_, _nutt, _foko,
  { {0x20010a07,0x7c280465,0x656d25e8,0x00000000}},	//   schi_, _addr, _krah,
  { {0x272301f7,0x7afa024a,0x764d0035,0x00000000}},	//   zın_, _autt, _mbay,
  { {0x272304ab,0x251c0047,0x7afa1360,0x00000000}},	//   yın_, נווא, _butt,
  { {0x7afa0034,0x2b93008b,0x543c0047,0x00000000}},	//   _cutt, ục_, טעגא,
  { {0x64900019,0xdb20004c,0xf78a0058,0x00000000}},	//   _päik, ítán, _maçı_,
  { {0xc9850021,0xe8f6014c,0x6e293de5,0x00000000}},	//   تشغي, олы_, _ideb,
  { {0x64900004,0x7d04003d,0x272301f7,0x00000000}},	//   _väik, ģist, tın_,
  { {0x7524051e,0x7afa3de6,0x656d0397,0x00000000}},	//   _sviz, _gutt, _arah,
  { {0x272304ab,0x3eaf0337,0x9208008f,0x00000000}},	//   rın_, nigt_, orāž,
  { {0xdce00529,0xb4db0268,0x272301f7,0x00000000}},	//   _urmă, rtàn, sın_,
  { {0xb4db0268,0x62863de7,0x2723005b,0x00000000}},	//   stàn, _soko, pın_,
  { {0x6e2903a4,0x290d3de8,0xaca30013,0x00000000}},	//   _odeb, lpea_, _huỳn,
  { {0x07d80032,0x28dd0053,0x6e290474,0x00000000}},	//   _اذهب_, _नीति, _ndeb,
  { {0x3eaf3de9,0x7d090290,0x708602a1,0x00000000}},	// [6f40] digt_, _ntes, огаз,
  { {0x3eaf350d,0x66d6013d,0xd0260054,0x00000000}},	//   eigt_, kákk, імей,
  { {0x62863dea,0x7d093deb,0xdddb011b,0x00000000}},	//   _toko, _ates, _rouš,
  { {0x8236006a,0x3eaf0583,0xfee90021,0x00000000}},	//   _بردا, gigt_, معنى_,
  { {0xadb70021,0x7d093dec,0x64900072,0x00000000}},	//   يهما_, _ctes, _päih,
  { {0x6e2901f7,0xcf2f005b,0x7afa212e,0x00000000}},	//   _edeb, üşüm_, _putt,
  { {0xddc900c3,0x3eaf01e1,0x46ca0042,0x00000000}},	//   _vneš, bigt_, रवाह,
  { {0xd7f8003b,0xee37013c,0x80ba0053,0x00000000}},	//   rdăm_, _мнс_, ्ववे,
  { {0x26cb0290,0xad66005d,0x1d073ded,0x00000000}},	//   voco_, _بازه, _мети_,
  { {0x7afa02f6,0x7c280146,0xb7b5008b,0x00000000}},	//   _tutt, _uddr, rạn,
  { {0x7afa024a,0xe7580086,0x78bd013d,0x00000000}},	//   _uutt, щині_, ésva,
  { {0xc7b8017f,0xc6a70086,0x56940156,0x00000000}},	//   gađa_, ірни, дают,
  { {0x19b60021,0xfaf8001c,0x26cb306b,0x00000000}},	//   _بحاج, _trīs_, roco_,
  { {0x14cb0076,0x3eaf006f,0x656d01c8,0x00000000}},	//   рыми_, zigt_, _vrah,
  { {0x69d6076c,0x7ae23dee,0xc6d70021,0x00000000}},	//   _øyeb, _khot, _وتعت,
  { {0x764d07d5,0x656d3def,0x61f90085,0x00000000}},	//   _ubay, _trah, снаў_,
  { {0x7ae20139,0x7ce401a8,0xef2f0013,0x00000000}},	// [6f50] _mhot, mòrf, _đựoc_,
  { {0x44b40076,0x6f6b005e,0x7ae23df0,0x00000000}},	//   _обыс, ијев_, _lhot,
  { {0x7d093df1,0xa7fc005b,0x3eaf3df2,0x00000000}},	//   _stes, ydın, tigt_,
  { {0x7f450034,0x9f980026,0x9f4a00ea,0x00000000}},	//   rthq, ráða_, áján_,
  { {0x41e70726,0x3eaf1374,0x427a0063,0x00000000}},	//   _фіна, rigt_, _הארג,
  { {0x4c840088,0x3eaf18a4,0xf53800ff,0x00000000}},	//   млів, sigt_, קטור_,
  { {0x7ae20139,0xb18600a5,0x2b57005d,0x00000000}},	//   _bhot, _tvåå, تیاد_,
  { {0x6e2900b9,0x7ae23df3,0xb3bc0063,0x00000000}},	//   _udeb, _chot, ימוכ,
  { {0xf2d400b5,0x7d090a2e,0xa7fc005b,0x00000000}},	//   ועק_, _utes, rdın,
  { {0x48790055,0xa49b00cd,0x7ae2008f,0x00000000}},	//   ссия_, ipòs, _ehot,
  { {0x64900019,0x7ae20025,0x3ead0077,0x00000000}},	//   _käiv, _fhot, _kmet_,
  { {0x869a0817,0x98ad00c3,0x64900072,0x00000000}},	//   стот_, mreč_, _jäiv,
  { {0x7ae93df4,0xc7b8007d,0x18693df5,0x00000000}},	//   mmet, rađa_, _гали_,
  { {0xa7fc0058,0xb5fb013d,0x3ebf0130,0x00000000}},	//   ndıl, ndáj, _ljut_,
  { {0xa3e60161,0xe296000a,0xccf2014e,0x00000000}},	//   बें_, праќ, תכם_,
  { {0xe61f0024,0xe29a0062,0x7afe09aa,0x00000000}},	//   skôr_, щаб_, ípti,
  { {0x8ffa0021,0x7ae91345,0x27e20022,0x00000000}},	// [6f60] مرار_, imet, ękne_,
  { {0x3ead0019,0x3ebf3df6,0xd12f0067,0x00000000}},	//   _amet_, _ajut_, امل_,
  { {0x7ae93df7,0xd4c50067,0x4fa60002,0x00000000}},	//   kmet, _تغيي, џиев,
  { {0x7ae91cf1,0xdfcf013a,0xde031527,0x00000000}},	//   jmet, ديم_, епци,
  { {0x7ae91f72,0x8e470044,0xddb8014b,0x00000000}},	//   dmet, سلوك_, ўглі_,
  { {0x7ae23df8,0xdca33df9,0x2bb80042,0x00000000}},	//   _shot, начи, इपला,
  { {0x7ae23dfa,0xe81f0042,0xa09b069a,0x00000000}},	//   _phot, _मज़ा_, _פילט,
  { {0x7ae93dfb,0x629603d4,0xbae30085,0x00000000}},	//   gmet, nkyo, нцый,
  { {0x3ea70438,0x62840035,0xada30062,0x00000000}},	//   ënte_, ijio, _затл,
  { {0x26c31181,0x7ae90019,0x27f801f2,0x00000000}},	//   čkom_, amet, ørn_,
  { {0x7ae90016,0x7a36005b,0x16351254,0x00000000}},	//   bmet, gütü, меня,
  { {0xba170032,0xfaa3000d,0xeb970063,0x00000000}},	//   _فيما_, _пахо, _מדבר_,
  { {0xb4db01a8,0xb5fb013d,0xdddb0022,0x00000000}},	//   stàm, ldák, _zauł,
  { {0xe72f007e,0x3ae10024,0x6e220139,0x00000000}},	//   خصی_, rópe_, haob,
  { {0x67d30651,0x2a66004b,0x2572008d,0x00000000}},	//   _пошу, _kaob_, _pôlô_,
  { {0xd7bb0063,0x32640086,0xb5fb00ea,0x00000000}},	//   _לצור, нтув, zdáj,
  { {0xdce900c3,0x64480268,0x66dd00ea,0x00000000}},	// [6f70] _sreč, òdic, léko,
  { {0x7ae901f7,0xdce93dfc,0x66d6013d,0x00000000}},	//   zmet, _preč, váki,
  { {0x649009ff,0x7afc013d,0x44233dfd,0x00000000}},	//   _päiv, _érth, maj_,
  { {0xdce900c2,0xcf98005e,0x02a71b06,0x00000000}},	//   _vreč, чју_, _хром,
  { {0xdd94000d,0x249e0006,0x9d450a3a,0x00000000}},	//   нацы, šymų_, фелд,
  { {0xdce90006,0x66dd01c2,0x2c6d00ea,0x00000000}},	//   _treč, kéko, ködő_,
  { {0x26c3017f,0x66dd00ea,0x7ae93dfe,0x00000000}},	//   čkoj_, jéko, tmet,
  { {0x7ae9090c,0x66dd00ea,0x917a0013,0x00000000}},	//   umet, déko, _hấp_,
  { {0x442336a2,0x64900004,0x6efa0080,0x00000000}},	//   kaj_, _käit, _vůbe,
  { {0x44231228,0x7ae93951,0x290b008f,0x00000000}},	//   jaj_, smet, īca_,
  { {0x229c007a,0xb9040053,0x3f470019,0x00000000}},	//   _líka_, _भी_, nõu_,
  { {0x7a36005b,0x7c23390b,0x917a008d,0x00000000}},	//   rütü, lanr, _lấp_,
  { {0x95830055,0xa3e00053,0x20bf0053,0x00000000}},	//   вляе, _तरह_, ्वाध,
  { {0x673a0268,0x6490047f,0x629d2493,0x00000000}},	//   butj, _näit, _also,
  { {0x6e2217e9,0x3f47004b,0x82f60085,0x00000000}},	//   yaob, jõu_, дчац,
  { {0x7c2300e3,0x79960051,0x00000000,0x00000000}},	//   hanr, _żywi,   ,
  { {0x442312bf,0xb5fb013d,0x7c230050,0x00000000}},	// [6f80] baj_, zdák, kanr,
  { {0x917a001b,0x4423158e,0x51b9000d,0x00000000}},	//   _cấp_, caj_, чыся_,
  { {0x645c3dff,0xdfcf0021,0xb4da0053,0x00000000}},	//   meri, ليك_, ़ती_,
  { {0xc04900b5,0x645c2de1,0x6463008f,0x00000000}},	//   יז_, leri, ītiņ,
  { {0xfe790080,0x224000b9,0xfee90021,0x00000000}},	//   _dnů_, mgik_, أعلى_,
  { {0x64900019,0x645c3e00,0x7d1b0022,0x00000000}},	//   _täiu, neri, _dwus,
  { {0x645c3e01,0x50430893,0x3c4b005d,0x00000000}},	//   ieri, _шерб, تثنی_,
  { {0xa7fc01f7,0x64900019,0xafe30156,0x00000000}},	//   rdım, _käis, _росл,
  { {0xa80201f7,0x44443e02,0xdd8f007e,0x00000000}},	//   _çıka, _oc_, _پول_,
  { {0xb17b00b5,0x66dd00ea,0xf74a0086,0x00000000}},	//   קטיר, téko, оїми_,
  { {0x2c140235,0x6e20014f,0x44232968,0x00000000}},	//   _न्यू_, _kemb, vaj_,
  { {0x44443e03,0x6e2000f3,0x44230051,0x00000000}},	//   _ac_, _jemb, waj_,
  { {0x649000fe,0x6e2027e3,0x224000b9,0x00000000}},	//   _näis, _memb, dgik_,
  { {0x6e202933,0x645c1baa,0x3a242af9,0x00000000}},	//   _lemb, geri, lamp_,
  { {0x44233e04,0x828b0085,0x66dd013d,0x00000000}},	//   raj_, осаб_, lékm,
  { {0x44230bfb,0x05aa0042,0x44443e05,0x00000000}},	//   saj_, _चेकब, _ec_,
  { {0x44230198,0x645c281f,0x90990062,0x00000000}},	// [6f90] paj_, beri, пват_,
  { {0xc8d900b5,0x645c3e06,0xfe70007e,0x00000000}},	//   ִקײט, ceri, یدن_,
  { {0x3ae1007a,0x6490065c,0x2d9200d1,0x00000000}},	//   hópa_, _väit, øyen_,
  { {0x76f900b5,0x765d39eb,0x6e203e07,0x00000000}},	//   פּעצ, nesy, _cemb,
  { {0x64900004,0xb5fb0139,0x7aed0195,0x00000000}},	//   _täit, meád, ňatk,
  { {0x8c43003b,0x6490065c,0x6c35007e,0x00000000}},	//   ăşoa, _häir, رفعا,
  { {0x4421001f,0x66c80058,0x765d3e08,0x00000000}},	//   _meh_, lıke, kesy,
  { {0xc334014e,0x6e20053b,0x67280137,0x00000000}},	//   דוק_, _gemb, dsdj,
  { {0x6445000c,0xd84e008b,0x753d3310,0x00000000}},	//   _ochi, _vọng_, jusz,
  { {0xa8740076,0x64450035,0xe7390001,0x00000000}},	//   вующ, _nchi, пео_,
  { {0x69d60031,0x765d005b,0x645c3e09,0x00000000}},	//   _øyen, fesy, veri,
  { {0xeb9600b5,0x645c29b4,0x44443e0a,0x00000000}},	//   _אדער_, weri, _sc_,
  { {0x26de001c,0x2d49006d,0x7e6900a4,0x00000000}},	//   ēto_, núe_, _maep,
  { {0x6d4b3e0b,0xb4da0053,0x7c21013d,0x00000000}},	//   itga, ़ते_, _jelr,
  { {0x44213e0c,0x645c0d2c,0x69d9001f,0x00000000}},	//   _deh_, reri, _hywe,
  { {0x64450529,0x645c3e0d,0x75460086,0x00000000}},	//   _echi, seri, _зниз,
  { {0x65640035,0x444408cd,0x224001e1,0x00000000}},	// [6fa0] _usih, _tc_, rgik_,
  { {0x6e203e0e,0x5f060121,0x7d003e0f,0x00000000}},	//   _semb, езжа, _rums,
  { {0x6e20014f,0x7d003e10,0xe4c90044,0x00000000}},	//   _pemb, _sums, _تبين_,
  { {0x64900019,0x171a0047,0x21290240,0x00000000}},	//   _täis, פונע, bsah_,
  { {0x69d900e8,0x6fd00053,0xe2970eaf,0x00000000}},	//   _nywe, _तुरं, _чая_,
  { {0x765d0051,0xcb34005a,0xfb66005e,0x00000000}},	//   zesy, векъ, ењим,
  { {0x6e2003d7,0x7c213e11,0x6d4b24bf,0x00000000}},	//   _temb, _delr, atga,
  { {0x69d900e8,0x7e7b01a8,0xb5fb3e12,0x00000000}},	//   _bywe, _gnup, ldáv,
  { {0x3a243e13,0x7af9002b,0x69d9002b,0x00000000}},	//   ramp_, _diwt, _cywe,
  { {0x69d90185,0xb5fb2ec9,0x7c211c40,0x00000000}},	//   _dywe, ndáv, _gelr,
  { {0x2129004a,0x80370047,0xeb970062,0x00000000}},	//   zsah_, ענטע_, _пиф_,
  { {0x6f033e14,0xb4db00cd,0x64453e15,0x00000000}},	//   ínci, ntàv, _schi,
  { {0x765d3e16,0x66dd013d,0xba170044,0x00000000}},	//   resy, lékk, _أيها_,
  { {0x753d0051,0x67280137,0x765d3e17,0x00000000}},	//   rusz, psdj, sesy,
  { {0x765d002c,0x753d0022,0xa3d52047,0x00000000}},	//   pesy, susz, товч,
  { {0x753d101d,0xe7db0063,0x4421004d,0x00000000}},	//   pusz, _מקוש, _weh_,
  { {0x44213e18,0x60f90895,0x64453e19,0x00000000}},	// [6fb0] _teh_, дная_, _tchi,
  { {0x2aba001c,0x7e691848,0x2129004d,0x00000000}},	//   mību_, _saep, rsah_,
  { {0x2aba001c,0x7aed0066,0xbfab0062,0x00000000}},	//   lību_, ňati, чтае_,
  { {0x2d490331,0xd7b70047,0x6d4b2c0e,0x00000000}},	//   túe_, עהאט_, ttga,
  { {0x2aba001c,0x8d650076,0x6d4b04aa,0x00000000}},	//   nību_, твле, utga,
  { {0x0136014e,0x6d4b2f7b,0x229c0014,0x00000000}},	//   _ברשת_, rtga, _líkl_,
  { {0x4c920138,0x7bda001f,0x9f4700fe,0x00000000}},	//   ријс, _cytu, änä_,
  { {0xb5fb000f,0x6f090114,0x7bda0022,0x00000000}},	//   ldáu, _čech, _dytu,
  { {0xdce9003b,0x69d600d1,0xaa56005e,0x00000000}},	//   _creă, _øyel, тињу_,
  { {0xd7090be6,0x2aba008f,0x2ba7005e,0x00000000}},	//   мное_, dību_, _пјев,
  { {0x7bda001f,0x7af9002b,0xddc2008f,0x00000000}},	//   _gytu, _tiwt, mdoš,
  { {0x969600e1,0xe1ff0013,0x628f2786,0x00000000}},	//   трош, _ngó_, _noco,
  { {0x05633e1a,0x29d2007e,0x290f00d1,0x00000000}},	//   авян, _پيوس, _utga_,
  { {0x2a6d001f,0xf770007e,0xd132007e,0x00000000}},	//   ldeb_, _گاه_, یمز_,
  { {0x628f0397,0xddc2001c,0x394d3e1b,0x00000000}},	//   _boco, idoš, ltes_,
  { {0x2a6d001f,0x628f3e1c,0x2aba001c,0x00000000}},	//   ndeb_, _coco, bību_,
  { {0x412706cb,0x2aba001c,0x394d3e1d,0x00000000}},	// [6fc0] кото_, cību_, ntes_,
  { {0x394d3e1e,0x13060590,0x66d6013d,0x00000000}},	//   ites_, _изом, cákr,
  { {0x394d3e1f,0x03a60086,0x649b0e2a,0x00000000}},	//   htes_, _рино, _חסיד,
  { {0x3ea000ea,0x2492001c,0xe1260121,0x00000000}},	//   óit_, žamā_, _имми,
  { {0x7bda0051,0x11f8005d,0x00000000,0x00000000}},	//   _sytu, _سوسک_,   ,
  { {0x61e63e20,0xb5fb0025,0xdd93000d,0x00000000}},	//   _izkl, leác, рашы,
  { {0x2d800469,0x2aba001c,0xfe460002,0x00000000}},	//   ţie_, zību_, _инво,
  { {0xdce2007d,0x628f032a,0xdee60ef3,0x00000000}},	//   kvoć, _xoco, _роби,
  { {0x394d3e21,0xb5fb3e22,0xd83a0183,0x00000000}},	//   gtes_, ndát, мэн_,
  { {0x7bda0045,0xa786007e,0x26c206ce,0x00000000}},	//   _tytu, نشجو, enko_,
  { {0x752d3e23,0x69c40078,0x394d3e24,0x00000000}},	//   _svaz, _žied, ates_,
  { {0x2aba003d,0xc7b8017f,0x394d3e25,0x00000000}},	//   tību_, nađi_, btes_,
  { {0x394d3e26,0x98c6253f,0x628f3e27,0x00000000}},	//   ctes_, _искл, _roco,
  { {0x2aba001c,0x09e304e3,0x628f3e28,0x00000000}},	//   rību_, _точн, _soco,
  { {0x628f3789,0x2aba001c,0xc6a70002,0x00000000}},	//   _poco, sību_, _арпи,
  { {0x660d2dd6,0x673a00a8,0xb5fb013d,0x00000000}},	//   _ufak, mrtj, reáb,
  { {0xb5fb00ea,0xd904007e,0xd53e0013,0x00000000}},	// [6fd0] gdát, تی_, _tất,
  { {0x6aa2001f,0x26c3004a,0x673a00ca,0x00000000}},	//   _llof, čkou_, ortj,
  { {0xfaf8001c,0x628f25a1,0x6aa200a5,0x00000000}},	//   _drīz_, _toco, _olof,
  { {0x394d104d,0xdbdc0014,0x9f34012c,0x00000000}},	//   ytes_, _ráði, реці,
  { {0x394d3e29,0x4c950141,0x51841a6b,0x00000000}},	//   xtes_, лидс, _кура,
  { {0xb5fb00ea,0xd5da0047,0x9f050049,0x00000000}},	//   ldás, ײַנש, _موسو,
  { {0xe0d200b5,0xddc2001c,0x6aa20934,0x00000000}},	//   _הײם_, rdoš, _blof,
  { {0x6f0302dd,0x394d3e2a,0xb5fb00ea,0x00000000}},	//   íncu, ttes_, ndás,
  { {0x2a6d001f,0x394d3e2b,0xb4db078d,0x00000000}},	//   rdeb_, utes_, ntàs,
  { {0xddc90734,0x8c190044,0x394d3e2c,0x00000000}},	//   _knež, _أيار_, rtes_,
  { {0x5b150431,0x394d3e2d,0x6b15005e,0x00000000}},	//   _смет, stes_, _смеђ,
  { {0x394d3e2e,0x26c20072,0x6aa200a3,0x00000000}},	//   ptes_, unko_, _glof,
  { {0xf5070121,0x673a3e2f,0x2902011b,0x00000000}},	//   лнял_, artj, íkat_,
  { {0x657600ac,0xf74505ce,0xf7710043,0x00000000}},	//   _vryh, _беко, _هاب_,
  { {0x61e60022,0x42563e30,0x03a329c2,0x00000000}},	//   _szkl, лтат, биро,
  { {0x3636007e,0xb7da0047,0x86460e34,0x00000000}},	//   _صربس, _אקצי, _сниж,
  { {0x95560021,0x11e6005e,0x91ee0042,0x00000000}},	// [6fe0] _إخبا, ужам, चेंज_,
  { {0x60de006f,0xb4662dc1,0x61e600a8,0x00000000}},	//   ulpm, _скол, _vzkl,
  { {0xef1a011c,0xb4c00235,0x7ce400cd,0x00000000}},	//   хме_, ंची_, fòrn,
  { {0xb4db3e31,0xcd2a0076,0x442a3e32,0x00000000}},	//   gràf, ежде_, lab_,
  { {0x61e6003d,0x270c004c,0xbea302d8,0x00000000}},	//   _uzkl, _měna_, љачк,
  { {0x442a0004,0x40950d34,0x6aa2001f,0x00000000}},	//   nab_, _крст, _slof,
  { {0x8fa63e33,0x20071035,0x6aa200ac,0x00000000}},	//   _саве, žnic_, _plof,
  { {0xcb67000a,0xb4db00cd,0xaae60021,0x00000000}},	//   ѓање_, ntàr, دستو,
  { {0x442a3e34,0x6e930067,0x5e930021,0x00000000}},	//   kab_, _القا, _القط,
  { {0x442a3e35,0x7e623e36,0x7874013d,0x00000000}},	//   jab_, leop, küvő,
  { {0xda6f0088,0x442a3e37,0x27f80137,0x00000000}},	//   _ля_, dab_, ärn_,
  { {0x442a0019,0x7e623e38,0x7c2a3e39,0x00000000}},	//   eab_, neop, lafr,
  { {0x95c81e1b,0x00000000,0x00000000,0x00000000}},	//   гура_,   ,   ,
  { {0x673a00c3,0x442a1ab2,0x44251079,0x00000000}},	//   prtj, gab_, úl_,
  { {0x7e6200d1,0x389b0047,0x7c2a002b,0x00000000}},	//   keop, _איגנ, iafr,
  { {0x78ba082a,0x442a0019,0xadf60053,0x00000000}},	//   litv, aab_, ेशान_,
  { {0x442a3e3a,0xd491008b,0x2127007e,0x00000000}},	// [6ff0] bab_, ừ_, ايطی_,
  { {0xdddb3e3b,0x78ba00c3,0x64410516,0x00000000}},	//   _použ, nitv, ólid,
  { {0x7ced00ed,0x7c2a3e3c,0x00d801f3,0x00000000}},	//   lúrg, dafr, ابقت_,
  { {0xdce9017f,0xb4db00cd,0x7e620c3d,0x00000000}},	//   _kreć, ctàr, geop,
  { {0xdb030080,0x070b0053,0x628d004b,0x00000000}},	//   rzní, _संभव_, mjao,
  { {0x78ba00c3,0x6455004d,0x113a0063,0x00000000}},	//   jitv, nfzi, _בתשל,
  { {0x78ba3e3d,0xd4980063,0xb4fc0047,0x00000000}},	//   ditv, רכות_, גלגר,
  { {0x3eb90137,0x442a3e3e,0xc7b8007d,0x00000000}},	//   _öst_, zab_, nađu_,
  { {0xb5fb0445,0x628d004e,0x3c4714d7,0x00000000}},	//   zdár, ijao, _مضاف,
  { {0x7c2a3e3f,0x661d004d,0x00000000,0x00000000}},	//   cafr, ebsk,   ,
  { {0x442a0019,0x29020026,0xcc7a0041,0x00000000}},	//   vab_, íkar_, _שװער,
  { {0x442a0e53,0xfd4c001b,0x6e2b002c,0x00000000}},	//   wab_, _nhiề, nagb,
  { {0x78ba00c3,0x442a0c76,0x5e560047,0x00000000}},	//   bitv, tab_, סישע_,
  { {0xb4c00235,0x78ba00ac,0x6b7c003b,0x00000000}},	//   ंचे_, citv, _făgă,
  { {0x6b7c003b,0x442a3e40,0x753d0022,0x00000000}},	//   _găgă, rab_, arsz,
  { {0xfd4c008b,0x442a3e35,0xf5390066,0x00000000}},	//   _chiề, sab_, šťa_,

  { {0x7c2a001f,0x61460071,0x442a004b,0x00000000}},	// [7000] yafr, реза, pab_,
  { {0x130a0121,0xb4db01a8,0xaca3008d,0x00000000}},	//   _иной_, stàr, _duịn,
  { {0xa7fc01f7,0x09e20053,0x643b0063,0x00000000}},	//   ldır, _पर्य, _בעינ,
  { {0x2eed3e41,0x17560047,0xcd2a005d,0x00000000}},	//   _chef_, יסער_, نستن_,
  { {0xa7fc01f7,0xb5fb0025,0x20070066,0x00000000}},	//   ndır, heán, žnia_,
  { {0x7e620a43,0xb4db01a8,0x6d4238ec,0x00000000}},	//   seop, rràg, ruoa,
  { {0xf76704de,0x78ba0198,0xe7870114,0x00000000}},	//   _با_, vitv, yšší,
  { {0xb5fb0025,0xf1bf0025,0xa3e90042,0x00000000}},	//   deán, _meán_, _बरस_,
  { {0x78ba00c3,0x4c863e42,0x58d80094,0x00000000}},	//   titv, _клав, лдия_,
  { {0xec770a39,0x3157009a,0xc61f0042,0x00000000}},	//   _кпу_, סיין_, पर्य_,
  { {0x78ba0198,0xdce9017f,0x7c28008f,0x00000000}},	//   ritv, _sreć, _iedr,
  { {0xdce9007d,0x3b95005e,0x7ced0e1f,0x00000000}},	//   _preć, _ујут, túrg,
  { {0x2a640198,0x09e3018e,0x78ba00c2,0x00000000}},	//   memb_, _доцн, pitv,
  { {0x66c8005b,0x3944001c,0x7c28082a,0x00000000}},	//   lıkl, mums_, _jedr,
  { {0xb5fb0025,0x7c281370,0xfd4c008b,0x00000000}},	//   ceán, _medr, _phiề,
  { {0xdce9017f,0x26c90035,0x66c8005b,0x00000000}},	//   _treć, _ujao_, nıkl,
  { {0x3944001c,0x7c28001f,0x59a60053,0x00000000}},	// [7010] nums_, _oedr, गनिर,
  { {0x656d002c,0x8504007e,0x628d0019,0x00000000}},	//   _isah, _گوین, sjao,
  { {0xfd4c0013,0x7fb9002a,0xddcb013d,0x00000000}},	//   _thiề, دهار_, vegő,
  { {0x3944003d,0x63ad003d,0xcd350021,0x00000000}},	//   kums_, ģinā, مرتب,
  { {0x3944003d,0x68e100c7,0x66c8005b,0x00000000}},	//   jums_, ylld, dıkl,
  { {0x229c0026,0x6f0700c2,0x3944008f,0x00000000}},	//   _ríki_, _tujc, dums_,
  { {0x6e2b002c,0xa7fc005b,0xe4580047,0x00000000}},	//   pagb, zdır, ייגט_,
  { {0x22490089,0x26d900f8,0xa7fc0058,0x00000000}},	//   ngak_, joso_, ydır,
  { {0x7c28001f,0x3944001c,0x26d906c5,0x00000000}},	//   _fedr, gums_, doso_,
  { {0x9183001b,0x7c28301a,0x6aa906ac,0x00000000}},	//   _xếp_, _gedr, shef,
  { {0x7ced02dd,0x3ae10026,0x656d3e43,0x00000000}},	//   gúre, hópi_, _asah,
  { {0x7d0101bc,0x1f5a0047,0x26d93e44,0x00000000}},	//   _hils, נדרא, goso_,
  { {0xf1bf0025,0x6e2909fe,0x3944008f,0x00000000}},	//   _seán_, _meeb, cums_,
  { {0x7d09048e,0xb5fb3e45,0x6e29004b,0x00000000}},	//   _mues, peán, _leeb,
  { {0x03a30cb5,0xb8dd0053,0x26d93e46,0x00000000}},	//   пиро, ीच_, boso_,
  { {0x224900f3,0x7d090164,0x26d93e47,0x00000000}},	//   ggak_, _oues, coso_,
  { {0x7d09048e,0xb5fb0025,0x644130f4,0x00000000}},	// [7020] _nues, neál, ólic,
  { {0x7d013e48,0xdb0a013d,0x6f001014,0x00000000}},	//   _nils, szfé, _simc,
  { {0xa3bc0053,0x6e291e50,0x7c2828fb,0x00000000}},	//   _अधि_, _beeb, _redr,
  { {0x52860032,0xcf250021,0xdfcf08aa,0x00000000}},	//   _الحك, تركي, رين_,
  { {0x7d0902dd,0xa2f70063,0x7c280b16,0x00000000}},	//   _cues, _למטה_, _pedr,
  { {0xd5ed001b,0x3944001c,0x26d90331,0x00000000}},	//   _hoạ, vums_, zoso_,
  { {0x7c283e49,0x26d92133,0x66c80058,0x00000000}},	//   _vedr, yoso_, tıkl,
  { {0x7d093e4a,0x7c2800ac,0x6da6018e,0x00000000}},	//   _fues, _wedr, _либа,
  { {0x7e970032,0x7d013e4b,0x7d092a9b,0x00000000}},	//   _انقر_, _fils, _gues,
  { {0xdb0303e8,0xd5ed001b,0x98a40006,0x00000000}},	//   szná, _loạ, ksmą_,
  { {0x7ced017d,0x39443e4c,0x26d93e4d,0x00000000}},	//   búrb, sums_, toso_,
  { {0xb5fb00ea,0x368b0239,0xcf930063,0x00000000}},	//   beál, усон_, לטת_,
  { {0xb5fb0025,0x26d91189,0xe9ff0013,0x00000000}},	//   ceál, roso_, _trạm_,
  { {0x7bc6004c,0xa9a301ce,0x66dd009c,0x00000000}},	//   _ěkuj, _хиљд, téks,
  { {0x443f01f7,0x26d93e4d,0xd7ef3e4e,0x00000000}},	//   ğu_, poso_, _ху_,
  { {0x97c50021,0x443f1638,0x5215014b,0x00000000}},	//   _بتهم, şu_, ідзт,
  { {0x656d3e4f,0x86380063,0x5187005e,0x00000000}},	// [7030] _usah, _הרחב_, љуба,
  { {0x51f80895,0x6e293e50,0x61f80085,0x00000000}},	//   сную_, _seeb, снуў_,
  { {0xf709001b,0xb4db00cd,0x984c001c,0x00000000}},	//   _lần_, aràc, dēļu_,
  { {0x7d0902dd,0xde590086,0x51873e51,0x00000000}},	//   _pues, раді_, _луга,
  { {0x6e290004,0x7d01003d,0x7d09055b,0x00000000}},	//   _veeb, _pils, _ques,
  { {0xcc89006a,0x7d0902dd,0x2d9d00ac,0x00000000}},	//   شنبه_, _vues, rywe_,
  { {0x7d013e52,0x547a0041,0xc49c009a,0x00000000}},	//   _vils, ינװײ, רשות,
  { {0xb5fb0025,0x7f4300cd,0xdce9007d,0x00000000}},	//   teál, ànqu, _iseč,
  { {0xf709001b,0x7d0131d4,0x7d090019,0x00000000}},	//   _cần_, _tils, _uues,
  { {0xd90c006a,0xf709008b,0x47c5013c,0x00000000}},	//   دیو_, _dần_, жбов,
  { {0x27170013,0xe9a8005d,0xd7050a1f,0x00000000}},	//   _măng_, لدین_, юзни,
  { {0x27170013,0x1959000d,0x442e0078,0x00000000}},	//   _lăng_, _вады_, _žf_,
  { {0xf709001b,0xf8bf0003,0x66dd013d,0x00000000}},	//   _gần_, éés_, tékr,
  { {0x2717001b,0x229c0026,0xd5ed0013,0x00000000}},	//   _năng_, _líkt_, _soạ,
  { {0x232a0086,0xe2ba0001,0x6fd90042,0x00000000}},	//   роби_, аћај_, _बुलं,
  { {0x98a40078,0x24960078,0x200701d1,0x00000000}},	//   rsmą_, _žemą_, žnil_,
  { {0x2717008b,0x1538005d,0x91e30f9a,0x00000000}},	// [7040] _băng_, _ازبک_, доте,
  { {0x2717008b,0x2056000d,0x701a0054,0x00000000}},	//   _căng_, ўтар, ріат_,
  { {0xb4d60161,0xf1c50078,0x8e0a0601,0x00000000}},	//   िकी_, višų_, анев_,
  { {0x7ce40268,0xa75a0041,0x443a01c8,0x00000000}},	//   mòri, ידער, _hdp_,
  { {0x7ce400cd,0x62863e53,0x8237007e,0x00000000}},	//   lòri, _inko, _برپا,
  { {0xccb70086,0x5cb70085,0xdca31579,0x00000000}},	//   огії_, оліў_, мачи,
  { {0x2aaa0092,0xc27a009a,0x9e6604a0,0x00000000}},	//   итио_, ֹרִי, _وارن,
  { {0x5a340afc,0x2705008f,0xda7a2763,0x00000000}},	//   чнит, _lēns_, ряк_,
  { {0x09e30001,0x6e2236a1,0xcc8a007e,0x00000000}},	//   моћн, mbob, _پناه_,
  { {0xf709008b,0x27170013,0x443a3e54,0x00000000}},	//   _vần_, _xăng_, _ndp_,
  { {0x6d420034,0xa714000d,0x7536005f,0x00000000}},	//   lroa, ямні, _avyz,
  { {0xf709008b,0x98ab008f,0xe9da005e,0x00000000}},	//   _tần_, ālāk_, _кке_,
  { {0x443a1648,0x55070085,0x35b40085,0x00000000}},	//   _bdp_, ючна, дбяр,
  { {0xdc08003d,0x443a0034,0x62860c23,0x00000000}},	//   rēķi, _cdp_, _anko,
  { {0x27170013,0x7ce401a8,0x43950054,0x00000000}},	//   _răng_, gòri, чавс,
  { {0xeb910063,0x443a01a8,0xc1050021,0x00000000}},	//   עָם_, _edp_, كوري,
  { {0x35b4005a,0x200701b3,0x443a1c2a,0x00000000}},	// [7050] _обър, žnim_, _fdp_,
  { {0x67350026,0x62863e55,0x443a3e56,0x00000000}},	//   _ófjö, _enko, _gdp_,
  { {0x44310f3a,0xe9ff008b,0x27170013,0x00000000}},	//   maz_, _trầm_, _văng_,
  { {0x44313e57,0xdce2007d,0x3ea9008d,0x00000000}},	//   laz_, dvođ, óat_,
  { {0x2717001b,0xdd94000d,0x644806b2,0x00000000}},	//   _tăng_, мацы, ódig,
  { {0x44313c2b,0x251c0149,0x98aa011b,0x00000000}},	//   naz_, סווא, čbě_,
  { {0x7ced006d,0x2d9200d1,0xeb991213,0x00000000}},	//   gúra, øyer_, сий_,
  { {0x7f84007e,0x6d423e58,0x44313e59,0x00000000}},	//   _تلفن, broa, haz_,
  { {0x8d77006a,0x4431280f,0x6d423e5a,0x00000000}},	//   _بازا, kaz_, croa,
  { {0x78a90138,0x29030db4,0x44313e5b,0x00000000}},	//   ског_, öja_, jaz_,
  { {0xbb480032,0xe7390001,0xeb090021,0x00000000}},	//   _ولكن_, љем_, _اقصى_,
  { {0x99800066,0x64410014,0x443a3e5c,0x00000000}},	//   _žiť_, ólin, _sdp_,
  { {0x44313e5d,0x38ca005d,0x66dd013d,0x00000000}},	//   faz_, شایی_, rékp,
  { {0x7ce40268,0xf7090013,0x44313e5e,0x00000000}},	//   tòri, _hầm_, gaz_,
  { {0x07a5295f,0x638313da,0xb6a601ce,0x00000000}},	//   _хайн, нгра, _никл,
  { {0x2801004c,0x1303130d,0x57a40085,0x00000000}},	//   ěrně_, езсм, _юшча,
  { {0xb1460088,0x26c20035,0xe29717f4,0x00000000}},	// [7060] янал, miko_, чат_,
  { {0xb0630024,0xf709008b,0x26c23e5f,0x00000000}},	//   jväč, _lầm_, liko_,
  { {0xb4e80053,0x9e661240,0x649b009a,0x00000000}},	//   बती_, звед, _הסיד,
  { {0x26c203d5,0x645c3e60,0x69c40006,0x00000000}},	//   niko_, lfri, _žiem,
  { {0x3ae1007a,0x2ee60438,0x6e220150,0x00000000}},	//   hóps_, rlof_, rbob,
  { {0x6ef100b9,0x75370047,0x644e3e61,0x00000000}},	//   våbe, לאנד_, ngbi,
  { {0x7d1b024a,0x645c3e62,0x26c20168,0x00000000}},	//   _etus, ifri, kiko_,
  { {0x34c90235,0x60de3e63,0x4a53005a,0x00000000}},	//   _रद्द, lopm, екъс,
  { {0xd90d006a,0x26c20c55,0x4431005b,0x00000000}},	//   لین_, diko_, yaz_,
  { {0x7c3a010a,0xe29f0026,0xb19b0047,0x00000000}},	//   _udtr, _miða_, צייכ,
  { {0x61e60026,0x656420ea,0xf0930063,0x00000000}},	//   _lykl, _apih, תנת_,
  { {0x6443005b,0xb5fb0025,0x76ab2977,0x00000000}},	//   _öniz, leái, стов_,
  { {0x44313e64,0x3ea61fdc,0x61e600b8,0x00000000}},	//   taz_, ikot_, _nykl,
  { {0xb5fb0025,0x26c20006,0xa5040603,0x00000000}},	//   neái, aiko_, еясл,
  { {0x20071b7e,0x44313e65,0x08770047,0x00000000}},	//   žnik_, raz_, _מעגט_,
  { {0x92940088,0x644e002c,0x66e4041d,0x00000000}},	//   насц, agbi, _поја,
  { {0x443104a6,0x9099093d,0xddc20022,0x00000000}},	// [7070] paz_, оват_, ngoń,
  { {0x3944001c,0xb21b00b9,0x3ea60023,0x00000000}},	//   irms_, _knæk, ekot_,
  { {0xa3d50062,0x656f00a3,0x68e83e66,0x00000000}},	//   _цонч, lwch, ildd,
  { {0x3ea60150,0x20180014,0x1e140054,0x00000000}},	//   gkot_, _efri_, емця,
  { {0xf7090013,0x527a009a,0x661b0046,0x00000000}},	//   _rầm_, _ונרא, ðuky,
  { {0x26c23e67,0xf709008d,0xc0580054,0x00000000}},	//   ziko_, _sầm_, _ніс_,
  { {0x39443e68,0xb3d60053,0x61e618a3,0x00000000}},	//   erms_, _मुफ़्, _zykl,
  { {0x68e80104,0x6e3b007d,0x26c23e69,0x00000000}},	//   eldd, _udub, xiko_,
  { {0x7d1b00e3,0x645c3e6a,0x3ead0058,0x00000000}},	//   _utus, yfri, _ilet_,
  { {0xb5fb0027,0xb4bc0053,0x47590062,0x00000000}},	//   ceái, _आगे_, ормя_,
  { {0x6d4b3e6b,0xf709008b,0x26c23e6c,0x00000000}},	//   luga, _tầm_, tiko_,
  { {0x291f0072,0xfa900058,0xa5bb1008,0x00000000}},	//   ppua_, çütü_, rbón,
  { {0xb4db00cd,0x200702e2,0x9967005e,0x00000000}},	//   rràn, žnih_, _хтел,
  { {0x3ead00cd,0x6d593e6d,0x7ae93e6e,0x00000000}},	//   _llet_, itwa, llet,
  { {0x3ead024a,0x26c2002c,0x6d4b0c35,0x00000000}},	//   _olet_, piko_, huga,
  { {0x6d593e6f,0x3ead00ac,0x672100c2,0x00000000}},	//   ktwa, _nlet_, mplj,
  { {0x290f014f,0x29073e70,0x644e00a4,0x00000000}},	// [7080] _juga_, _kina_, pgbi,
  { {0x29070009,0x7ae904bf,0x25fe0053,0x00000000}},	//   _jina_, hlet, रेणी_,
  { {0xe29a0138,0x212b0185,0x61e60045,0x00000000}},	//   _дан_, _ewch_, _wykl,
  { {0x29070035,0x7ae900ea,0x3ea60072,0x00000000}},	//   _lina_, jlet, ukot_,
  { {0xb5fb0025,0x6d4b014f,0x6d5900ac,0x00000000}},	//   teái, guga, gtwa,
  { {0x7ae20ade,0x29073e71,0x7ae93e72,0x00000000}},	//   _skot, _nina_, elet,
  { {0xb5fb0025,0x66090014,0x7ae93e73,0x00000000}},	//   reái, þekk, flet,
  { {0x290724d4,0x2b4000c3,0xb5fb0025,0x00000000}},	//   _aina_, čic_, seái,
  { {0xb5fb0027,0x29073d81,0xc19b0047,0x00000000}},	//   peái, _bina_, ַשטי,
  { {0x7afb0019,0x290739e9,0x290f3e74,0x00000000}},	//   amut, _cina_, _duga_,
  { {0x29072ddc,0x7ae93e75,0x291d0199,0x00000000}},	//   _dina_, blet, _etwa_,
  { {0x290f3ad9,0x29073e76,0x7ae93e77,0x00000000}},	//   _fuga_, _eina_, clet,
  { {0xe4e70086,0x9608000d,0x29073e78,0x00000000}},	//   дівн, дэра_, _fina_,
  { {0x67d43629,0x29073e79,0x7ae0013d,0x00000000}},	//   _полу, _gina_, lomt,
  { {0x7d083e7a,0x386c002b,0xe2f90054,0x00000000}},	//   _mids, medr_, зеві_,
  { {0x29073e7b,0x66c800ea,0x7d083e7c,0x00000000}},	//   _zina_, tűke, _lids,
  { {0x644806b2,0x645a00cd,0x660d0019,0x00000000}},	// [7090] ódic, òtic, _igak,
  { {0x3ead010a,0x29070268,0x7ae9000f,0x00000000}},	//   _slet_, _xina_, zlet,
  { {0x3ead3e7d,0x7ae931cc,0x7ae0017c,0x00000000}},	//   _plet_, ylet, komt,
  { {0x64430016,0x752d3e7e,0x6d4b3e7f,0x00000000}},	//   _ônib, _kwaz, tuga,
  { {0x212b0185,0x7ae9005b,0x721a0063,0x00000000}},	//   _uwch_, vlet, _מורח,
  { {0x66c8005b,0xdce9007d,0x290f3e80,0x00000000}},	//   lıkt, _pređ, _ruga_,
  { {0x6d4b3e81,0x7ae93e82,0x29073e83,0x00000000}},	//   suga, tlet, _rina_,
  { {0x9f050021,0x29073e84,0x660d0150,0x00000000}},	//   _أورو, _sina_, _ngak,
  { {0x2bdf0161,0x7ae93e85,0x79823e86,0x00000000}},	//   _पुरा, rlet, _crow,
  { {0x7d08021f,0x7ae93e87,0x7afb3e88,0x00000000}},	//   _gids, slet, smut,
  { {0xdce90117,0x7ae93e89,0x57e90065,0x00000000}},	//   _uređ, plet, ядом_,
  { {0x6721017f,0x7ae00edc,0x629d3e8a,0x00000000}},	//   rplj, comt, _noso,
  { {0x79820034,0x66c80779,0xb4db00cd,0x00000000}},	//   _grow, dıkt, aràm,
  { {0x443e0003,0x6aa90093,0x27e73e8b,0x00000000}},	//   ût_, lkef, _tynn_,
  { {0x7c3e03d9,0x629d2cb2,0x394d3624,0x00000000}},	//   ópri, _boso, lues_,
  { {0xe2970138,0x6f0906ce,0x68e100ea,0x00000000}},	//   нас_, _niec, lold,
  { {0x394d34a4,0x68e1004b,0x21670193,0x00000000}},	// [70a0] nues_, oold, нити_,
  { {0x68e13e8c,0x23db0042,0x9c7c01c8,0x00000000}},	//   nold, _मुकद, _akčn,
  { {0x6aa90831,0xf45700ff,0x7ae0013d,0x00000000}},	//   kkef, _אייר_, yomt,
  { {0x7d08010a,0x629d0185,0x68e13e8d,0x00000000}},	//   _sids, _goso, hold,
  { {0x6f093e8e,0x2d580121,0x66c80058,0x00000000}},	//   _diec, филь_, lıks,
  { {0x653b00b5,0x68e1000e,0x629d0445,0x00000000}},	//   לענד, jold, _zoso,
  { {0x6f090529,0x7d080203,0x394d3e8f,0x00000000}},	//   _fiec, _vids, eues_,
  { {0x79820045,0x6ee30019,0xafe33e90,0x00000000}},	//   _prow, sõbr, _сосл,
  { {0xf9920242,0x7d081bbc,0xdceb005b,0x00000000}},	//   ابع_, _tids, aygı,
  { {0x68e100ea,0x6ef100b9,0x81570041,0x00000000}},	//   gold, nåbn, עסיע_,
  { {0x9cb30032,0x752d3e91,0x7b19004d,0x00000000}},	//   _حملت, _swaz, räuß,
  { {0x7982001f,0x29110025,0x7b19004d,0x00000000}},	//   _trow, únaí_, säuß,
  { {0x9634000d,0x1874000d,0x18a6000d,0x00000000}},	//   ыняц, _агля, _падм,
  { {0x629d3303,0xd7940044,0xe853005d,0x00000000}},	//   _soso, _للتخ, _منهد,
  { {0x629d39c7,0xe2870002,0xc2c50021,0x00000000}},	//   _poso, нѓан, نيسي,
  { {0x2d843e92,0x9f63013d,0xa2d40044,0x00000000}},	//   _orme_, _ívét_, هيّت,
  { {0x629d006d,0xfe71007e,0x6f093e93,0x00000000}},	// [70b0] _voso, یگر_, _riec,
  { {0x6f090045,0x673a004b,0xdb0a004d,0x00000000}},	//   _siec, ostj, lzfä,
  { {0xdfd10021,0x9f550121,0x6f093e94,0x00000000}},	//   جيا_, твеч, _piec,
  { {0x6ee70032,0x52a70021,0xb2a70021,0x00000000}},	//   رسال, _أصدق, _أحده,
  { {0x41680002,0x2a6d004b,0xa7fc0075,0x00000000}},	//   _пјрм_, veeb_, rdıy,
  { {0xe1040088,0x6f090051,0x394d0003,0x00000000}},	//   _бясп, _wiec, vues_,
  { {0x20120024,0x673a006f,0xdea1007e,0x00000000}},	//   ániť_, jstj, _پیشی,
  { {0xaa56005e,0x673a02e0,0x68e100ca,0x00000000}},	//   вићу_, dstj, wold,
  { {0xe9d9019d,0xe8f90076,0x6aa917c5,0x00000000}},	//   ьки_, мли_, rkef,
  { {0x7e7b0199,0x673a0026,0x6c74007e,0x00000000}},	//   _haup, fstj, _مطمئ,
  { {0x394d0cfc,0x7e7b3e95,0x8c3c0058,0x00000000}},	//   sues_, _kaup, _doğd,
  { {0x68e13e96,0x7cf6003b,0x99850021,0x00000000}},	//   sold, râre, _للصو,
  { {0x7e7b00f3,0x394d3e97,0x68e13e98,0x00000000}},	//   _maup, ques_, pold,
  { {0x98a2018b,0x7e7b3e99,0xd9420a3a,0x00000000}},	//   _више, _laup, _теши,
  { {0x6ef80080,0xe29f0026,0x6ef101e1,0x00000000}},	//   líbe, _boð_, våbn,
  { {0xe2860062,0xc2433e9a,0x95860081,0x00000000}},	//   ълби, инск, _алие,
  { {0x26d90331,0xe6110063,0x7ced0066,0x00000000}},	// [70c0] éroe_, _לִי_, gúrk,
  { {0xe5370041,0xd0230054,0x44330168,0x00000000}},	//   _שטיט_, имуй, _gex_,
  { {0x63a70045,0xe0d5019d,0xb4c00053,0x00000000}},	//   cyjn, ують, ूची_,
  { {0xb21b00b9,0x0dca007f,0x44383e9b,0x00000000}},	//   _snæv, млей_, lar_,
  { {0x4438000c,0xbea3018e,0xdce0001c,0x00000000}},	//   oar_, јачк, _apmā,
  { {0x237f0022,0x55bb0063,0x44383e9c,0x00000000}},	//   łuje_, ומנו, nar_,
  { {0xdca30001,0xf70a008b,0x6d5b3e9d,0x00000000}},	//   раји, _hầu_, _equa,
  { {0x44382ae5,0x7e7b00d1,0xc3330063,0x00000000}},	//   har_, _gaup, בוה_,
  { {0xbea305fb,0x20070080,0x984a0878,0x00000000}},	//   _татк, žnit_, мяна_,
  { {0x7e7b00c3,0x673a007a,0x443806ec,0x00000000}},	//   _zaup, tstj, jar_,
  { {0xa5bb0025,0xfd4e008b,0xf70a0013,0x00000000}},	//   mbói, _ngoặ, _lầu_,
  { {0x7c3803d9,0x443d0051,0x673a0026,0x00000000}},	//   lavr, _św_, rstj,
  { {0x44383e9e,0x673a0026,0xdb1a008d,0x00000000}},	//   far_, sstj, _extô,
  { {0x7d1d0268,0x7c383e9f,0x673a0d1a,0x00000000}},	//   _ésse, navr, pstj,
  { {0xd6db000a,0x2418000d,0x25ad08c4,0x00000000}},	//   _оти_, тосы_, šel_,
  { {0x44380ac8,0xf70a001b,0x63a70051,0x00000000}},	//   aar_, _bầu_, ryjn,
  { {0xf70a001b,0x63a70051,0x60f927b8,0x00000000}},	// [70d0] _cầu_, syjn, еная_,
  { {0x2edb0161,0x44383ea0,0xf70a008b,0x00000000}},	//   यक्त, car_, _dầu_,
  { {0xf412014e,0x200700fe,0x6d5b3e9d,0x00000000}},	//   _לפי_, äni_, _squa,
  { {0x4ea7011c,0x753d00ea,0xa2952049,0x00000000}},	//   ърза, ossz, _самі,
  { {0x628f25cb,0xd8383d08,0x6d443000,0x00000000}},	//   _inco, kač_, šian,
  { {0x753d000f,0xd838074f,0xec190043,0x00000000}},	//   issz, jač_, رآتش_,
  { {0x9f340086,0x4c92005e,0x7e7b3ea1,0x00000000}},	//   _весі, сијс, _taup,
  { {0x44382025,0xdce9017f,0x20070078,0x00000000}},	//   zar_, _oseć, žnis_,
  { {0x38ca006a,0x4438240f,0x10170053,0x00000000}},	//   کايی_, yar_, _तलाश_,
  { {0x38750001,0x44381c30,0x6ef83ea2,0x00000000}},	//   ућит, xar_, ríbe,
  { {0x44383ea3,0xa6ca0c91,0x38a9017d,0x00000000}},	//   var_, елна_, _júri_,
  { {0xba3900b5,0x44383ea4,0xcb120063,0x00000000}},	//   _װײַט, war_, _הלא_,
  { {0x44380955,0xd9453ea5,0xe8ee1a02,0x00000000}},	//   tar_, _сели, _гл_,
  { {0x628f02f6,0x2a7f0019,0x44383ea6,0x00000000}},	//   _anco, ldub_, uar_,
  { {0x6d4b004d,0xf70a0013,0x44383ea7,0x00000000}},	//   hrga, _sầu_, rar_,
  { {0x2a7f0019,0x44381a5a,0x7c383741,0x00000000}},	//   ndub_, sar_, zavr,
  { {0x753d000f,0x443837f7,0x395f3083,0x00000000}},	// [70e0] cssz, par_, ntus_,
  { {0x395f2c3c,0x3f5c0014,0x628f11eb,0x00000000}},	//   itus_, tíu_, _enco,
  { {0x395f0019,0x6d4b3ea8,0x6f153ea9,0x00000000}},	//   htus_, erga, _cuzc,
  { {0xd838007d,0x395f276c,0xf70a0013,0x00000000}},	//   zač_, ktus_, _tầu_,
  { {0x6f03006f,0xdca6157c,0x444420ce,0x00000000}},	//   ïnca, лади, _kd_,
  { {0xfce30086,0xdb030066,0x44443eaa,0x00000000}},	//   бочо, rzný, _jd_,
  { {0xe0d7000a,0x2a7d001f,0x44443eab,0x00000000}},	//   _свр_, _bawb_, _md_,
  { {0x76440035,0xdee62758,0x7c38007d,0x00000000}},	//   _ndiy, _соби, savr,
  { {0x6b83000e,0xed63004c,0x6d5e003b,0x00000000}},	//   avng, ěží_, ăpas,
  { {0x2ee60179,0x44443eac,0x76440cc6,0x00000000}},	//   loof_, _nd_, _adiy,
  { {0x2a660017,0xd8380ecf,0x395f3ead,0x00000000}},	//   _бълг, rač_, atus_,
  { {0x44443eae,0x6f02006d,0xd8381235,0x00000000}},	//   _ad_, nmoc, sač_,
  { {0x7644002b,0xd8383eaf,0x44443eb0,0x00000000}},	//   _ddiy, pač_, _bd_,
  { {0x6aa20ac8,0x764401f7,0x7ced3eb1,0x00000000}},	//   _hoof, _ediy, túri,
  { {0xb865006a,0xc3480062,0x44443eb2,0x00000000}},	//   _خانو, ляте_, _dd_,
  { {0x44443eb3,0x7ced01a8,0x673c013d,0x00000000}},	//   _ed_, rúri, árju,
  { {0x26cb313e,0xf1940071,0x40873eb4,0x00000000}},	// [70f0] mico_, бить, лужб,
  { {0x26cb1095,0x656d00a4,0x7ced00cd,0x00000000}},	//   lico_, _ipah, púri,
  { {0x6d4000c7,0x3f873eb5,0xe29f0014,0x00000000}},	//   _avma, ínu_, _liði_,
  { {0x628f0034,0x26cb3eb6,0x395f0006,0x00000000}},	//   _unco, nico_, ytus_,
  { {0xb23a0047,0x44443eb7,0xf53f04aa,0x00000000}},	//   _בערז, _yd_, nså_,
  { {0x2129053b,0x251c00b5,0x26cb1928,0x00000000}},	//   mpah_, עווא, hico_,
  { {0x2a7d001f,0x26cb00c2,0xeb990928,0x00000000}},	//   _pawb_, kico_, тий_,
  { {0xf53f01e3,0x290e0290,0x34d20053,0x00000000}},	//   kså_, _aifa_, _सद्द,
  { {0x20240026,0x26cb0fbe,0x6aa200f5,0x00000000}},	//   _árið_, dico_, _doof,
  { {0x229c0080,0xa765019b,0xf8b80013,0x00000000}},	//   _díky_, акод, ghĩ_,
  { {0x395f3eb8,0x26cb2bbd,0x44443eb9,0x00000000}},	//   stus_, fico_, _rd_,
  { {0x44443eba,0x26cb313e,0x64451381,0x00000000}},	//   _sd_, gico_, _adhi,
  { {0xf53f0831,0xe5771dd6,0x6ef81795,0x00000000}},	//   gså_, азя_, níba,
  { {0x7ae40f32,0x6f023ebb,0x19ba009a,0x00000000}},	//   čite, zmoc, _שמסב,
  { {0x394d00f3,0xdc08001c,0x26cb3ebc,0x00000000}},	//   lres_, mēģi, bico_,
  { {0x394d3ebd,0x64450150,0x26cb19a8,0x00000000}},	//   ores_, _edhi, cico_,
  { {0xb69b000c,0x61ef1823,0x394d3ebe,0x00000000}},	// [7100] omân, _cycl, nres_,
  { {0x4444010a,0x394d03b2,0xdb18000f,0x00000000}},	//   _ud_, ires_, szvé,
  { {0x394d00bd,0xee3a3ebf,0x6fd5000d,0x00000000}},	//   hres_, вне_, біцц,
  { {0x394d0051,0xeda60076,0x6d440006,0x00000000}},	//   kres_, ишло, šiam,
  { {0x6aa229b4,0x394d01e1,0x6f023ec0,0x00000000}},	//   _roof, jres_, rmoc,
  { {0x1d19000d,0x394d0fdf,0x2ee62af9,0x00000000}},	//   уюць_, dres_, soof_,
  { {0x9f5c024a,0x394d3ec1,0x8b2301ce,0x00000000}},	//   ävä_, eres_, одје,
  { {0xc3330063,0x290e0035,0x8c3c005b,0x00000000}},	//   קוח_, _sifa_, _doğa,
  { {0x9997005a,0x26cb3ec2,0x394d3ec3,0x00000000}},	//   икът_, vico_, gres_,
  { {0x61eb004d,0x78a3138a,0xa8a60121,0x00000000}},	//   ügli, _conv, ррик,
  { {0x3ea402b0,0x26cb0ec0,0x394d3ec4,0x00000000}},	//   _komt_, tico_, ares_,
  { {0xbad5000d,0x394d3ec5,0xf53f2a8f,0x00000000}},	//   _лічы, bres_, tså_,
  { {0x26cb3134,0x394d109a,0x74a7007b,0x00000000}},	//   rico_, cres_, ајве,
  { {0x14cb0076,0x26cb3ec6,0x79bb0aeb,0x00000000}},	//   тыми_, sico_, _שֶׁה,
  { {0x26cb3ec7,0xb4db00cd,0xb17b1310,0x00000000}},	//   pico_, dràt, _nyår,
  { {0x68e8002b,0x963505ce,0xa79b009a,0x00000000}},	//   lodd, _униц, _ישוח,
  { {0x26c9017f,0x5187000a,0x656d0089,0x00000000}},	// [7110] _imao_, јуба, _upah,
  { {0xe4eb006a,0x64450035,0x68e8001f,0x00000000}},	//   _جعبه_, _udhi, nodd,
  { {0x394d009c,0xbe150044,0xd0183ec8,0x00000000}},	//   zres_, مواع, рфу_,
  { {0x22950032,0x68e80185,0x99840006,0x00000000}},	//   _الحس, hodd, namų_,
  { {0x27e20022,0x8c3c0058,0xcdc701ce,0x00000000}},	//   ękny_, _soğa, јљеп,
  { {0x394d3ec9,0xb4db0268,0x6ef8130c,0x00000000}},	//   vres_, cràt, ríba,
  { {0x3f850164,0x7ced0139,0x394d002b,0x00000000}},	//   _élu_, dúrt, wres_,
  { {0x99840006,0x394d3e0e,0xaae4007e,0x00000000}},	//   jamų_, tres_, يسيو,
  { {0xdc08001c,0x68e8002b,0x394d3eca,0x00000000}},	//   tēģi, fodd, ures_,
  { {0x248100bd,0x4879005a,0x26d90003,0x00000000}},	//   _nahm_, усия_, éron_,
  { {0xd70a0076,0xb69b0a50,0x78a3013d,0x00000000}},	//   лное_, rmân, _vonv,
  { {0x394d3ecb,0x869a000a,0x7b150080,0x00000000}},	//   pres_, утот_, _všud,
  { {0x45490121,0x2ca501e1,0x7ae900ca,0x00000000}},	//   ичём_, _kold_, moet,
  { {0x1423000a,0x78ba102c,0xf8ab0053,0x00000000}},	//   здрм, chtv, _छविय,
  { {0x8af90041,0x2ca5357e,0xb5fb013d,0x00000000}},	//   ָפּק, _mold_, nfáj,
  { {0xdb1200ea,0x7ae90550,0x6abb3797,0x00000000}},	//   ógép, noet, nhuf,
  { {0x6d920014,0x10160021,0xe1fa04f2,0x00000000}},	// [7120] iðað, مباد, уга_,
  { {0x3ae10066,0x6d440066,0xa494005d,0x00000000}},	//   rópy_, šiak, _بیست,
  { {0xe47b0047,0x7ae93ecc,0xa0670062,0x00000000}},	//   _גריכ, koet, саха_,
  { {0x443a3ecd,0x3ec50054,0x25bd0058,0x00000000}},	//   _hep_, осіб, _özlü_,
  { {0x443a00ac,0x2023017c,0x9cca05ac,0x00000000}},	//   _kep_, érií_, лыка_,
  { {0x2ca50034,0x62843ece,0xba3d004c,0x00000000}},	//   _cold_, ldio, chůz,
  { {0x7ae9001f,0x2ca50137,0xb4db00cd,0x00000000}},	//   foet, _dold_, oràr,
  { {0x443a00c3,0xd00f0021,0xd3570063,0x00000000}},	//   _lep_, _ألف_, ציפי_,
  { {0x9c5a007e,0xe29b0047,0x2ca500e5,0x00000000}},	//   _مجاز_, רשפר, _fold_,
  { {0x2ca52e38,0xb17b0047,0x98ad0066,0x00000000}},	//   _gold_, נטיר, ateľ_,
  { {0x68e80185,0xbb86007e,0x99840078,0x00000000}},	//   rodd, _دلاي, tamų_,
  { {0x6e2200f3,0xfaa3184a,0x29050137,0x00000000}},	//   ncob, _нахо, amla_,
  { {0x62840c70,0x7c3a1f38,0x6d423ecf,0x00000000}},	//   ddio, _ketr, nsoa,
  { {0xdcfb007d,0x443a3dae,0x8c3c0058,0x00000000}},	//   _vruć, _cep_, _moğo,
  { {0x98a3005e,0x443a3ed0,0x628400ca,0x00000000}},	//   _хије, _dep_, fdio,
  { {0x443a3ed1,0x41e7000d,0x7c3a3ed2,0x00000000}},	//   _eep_, біза, _letr,
  { {0xdb0a00ea,0x61150086,0x51870cdf,0x00000000}},	// [7130] gyfé, іджу, щува,
  { {0x69c0005b,0x10070062,0x7c3a3ed3,0x00000000}},	//   izme, бяем, _netr,
  { {0x83670021,0xc1040021,0x2fd914d7,0x00000000}},	//   _ادخل, أولي, جواد_,
  { {0x2ca50034,0xa159000d,0xbdf51313,0x00000000}},	//   _sold_, _каму_, опеј,
  { {0x5d67005a,0xee3801dd,0x7ae900ca,0x00000000}},	//   стез, сні_, voet,
  { {0x61fd003d,0x547c0047,0x7c3a3ed4,0x00000000}},	//   _izsl, ָנהײ, _cetr,
  { {0x7ae936eb,0x2ca506a5,0x69c03ed5,0x00000000}},	//   toet, _vold_, ezme,
  { {0x3949005e,0x7c3a004b,0x26d9006c,0x00000000}},	//   азио_, _eetr, érol_,
  { {0x2ca50034,0x6d920026,0x7ae93c1c,0x00000000}},	//   _told_, rðað, roet,
  { {0x7ae40ecf,0x29050035,0x6abb2322,0x00000000}},	//   čita, umla_, shuf,
  { {0xe7390138,0x69c01253,0x443a3ed6,0x00000000}},	//   јем_, azme, _rep_,
  { {0x7d1b003a,0x443a3ed7,0xc8780058,0x00000000}},	//   _kuus, _sep_, doğu_,
  { {0xaca30013,0x443a1025,0xe29f0014,0x00000000}},	//   _huốn, _pep_, _liðs_,
  { {0x38bb00e8,0x69dc005b,0x7d1b065c,0x00000000}},	//   _bêre_, ğret, _muus,
  { {0xd2aa005e,0xdce00078,0xb4db01a8,0x00000000}},	//   акве_, _esmė, tràr,
  { {0x6e3b33ec,0xa22a0002,0x6d440078,0x00000000}},	//   _neub, ржаа_, šiai,
  { {0x7d1b00e8,0x443a3ed8,0x291f0003,0x00000000}},	// [7140] _nuus, _tep_, nqua_,
  { {0x6ab900a3,0x70f6012c,0xbfb602da,0x00000000}},	//   _llwf, ічає, يحات,
  { {0x2d8d051e,0xf42a0072,0x25641929,0x00000000}},	//   _aree_, _elää_, löl_,
  { {0xcfa90021,0xa3e30042,0x645c2f7b,0x00000000}},	//   حاكم_, _फुट_, lgri,
  { {0x2d8d14d3,0x6e220dde,0x6e2d006d,0x00000000}},	//   _cree_, rcob, ñaba,
  { {0x6e2213a3,0x645c3ed9,0x4d390086,0x00000000}},	//   scob, ngri, сяця_,
  { {0x6d4203d9,0x7c3a3eda,0xa2c10053,0x00000000}},	//   ssoa, _vetr, रोक्,
  { {0x2d8d0034,0x22403e3e,0xf4130063,0x00000000}},	//   _free_, naik_, ופו_,
  { {0x25640026,0x69c0007d,0x26d90066,0x00000000}},	//   jöl_, uzme, érom_,
  { {0x25640378,0x6cd60021,0x6f1c0022,0x00000000}},	//   döl_, _بقطا, _kurc,
  { {0xd7940062,0x3b8601ce,0xd6d10044,0x00000000}},	//   чинъ, _флег, فقد_,
  { {0x6f1c2321,0xa96a3161,0x645c030c,0x00000000}},	//   _murc, _вида_, egri,
  { {0x291f0a02,0x672d0130,0x25640058,0x00000000}},	//   cqua_, _čaje, göl_,
  { {0x645c00f3,0x1867005e,0x6f1c3edb,0x00000000}},	//   ggri, _даљи_, _ourc,
  { {0xaca3001b,0x93883150,0x92a70856,0x00000000}},	//   _xuốn, оста_, ојал,
  { {0x645c3edc,0x9294000d,0x73040054,0x00000000}},	//   agri, масц, дчуж,
  { {0xa2c10053,0x4177005d,0xe4a70131,0x00000000}},	// [7150] रोग्, غارس, _дрно,
  { {0xddc9000c,0xb5fb0026,0x6f1c3edd,0x00000000}},	//   _aceş, tgáf, _burc,
  { {0x2fc7001b,0x2240053b,0xddc9004c,0x00000000}},	//   àng_, baik_, _zdeň,
  { {0x6f1c0cd4,0xef180088,0x3946017d,0x00000000}},	//   _durc, імі_, _ovos_,
  { {0x38c40078,0x61fd0023,0x429a009a,0x00000000}},	//   _kūrė_, _uzsl, _הסרב,
  { {0xbd180086,0x66d600c2,0x7c84005e,0x00000000}},	//   іції_, mške, дуће,
  { {0x7ae400c2,0xeab10021,0xf65f0046,0x00000000}},	//   čitn, فعة_, mhæf_,
  { {0x2d8d015e,0xdddb003b,0x63a80093,0x00000000}},	//   _tree_, _cauţ, ødni,
  { {0x3a3f0150,0x66d600a8,0xcd3400de,0x00000000}},	//   raup_, nške, _يركب,
  { {0x6d59028d,0x291f0003,0x28990002,0x00000000}},	//   muwa, rqua_, стиќ_,
  { {0xc5e901f9,0xf7710242,0x6d593ede,0x00000000}},	//   _עד_, راد_, luwa,
  { {0x19590088,0x9f520003,0x25640014,0x00000000}},	//   _гады_, édée_, töl_,
  { {0xb4db00cd,0x75d6007e,0x645c3edf,0x00000000}},	//   tràp, سيسا, tgri,
  { {0xa50a0581,0xb4db00cd,0xd46a005e,0x00000000}},	//   сега_, ssàn, љиве_,
  { {0x291d0009,0x232a0086,0xf7490021,0x00000000}},	//   _huwa_, соби_, _البي_,
  { {0x291d0009,0x645c0185,0xdbd70d68,0x00000000}},	//   _kuwa_, sgri, määr,
  { {0x865b0063,0xa5bb00f8,0x6f1c387c,0x00000000}},	// [7160] _הדפי, ncól, _surc,
  { {0xe45a0088,0x6f1c2b71,0xe3660062,0x00000000}},	//   _ужо_, _purc, _екои,
  { {0x27210026,0xaca30013,0xdbd70bda,0x00000000}},	//   _jón_, _luồn, näär,
  { {0x27213ee0,0x471a0047,0x171a0041,0x00000000}},	//   _món_, צונג, צונע,
  { {0x6d5900a4,0x568d0047,0x27210139,0x00000000}},	//   guwa, יטאַ, _lón_,
  { {0x6f1c3ee1,0xdbd701cf,0x41270062,0x00000000}},	//   _turc, käär, _хоро_,
  { {0x628605c9,0x27210013,0x6d590022,0x00000000}},	//   _kako, _nón_, auwa,
  { {0x62860a9b,0xaca30013,0x5fdb009a,0x00000000}},	//   _jako, _buồn, _החלק,
  { {0xdee30086,0x62863ee2,0xe1ff0139,0x00000000}},	//   _чоти, _mako, _gcód_,
  { {0x62862294,0x38c8007e,0xed5f0078,0x00000000}},	//   _lako, تابی_, ėžta_,
  { {0x29190014,0xf0930063,0xdc8b009a,0x00000000}},	//   ísar_, גנת_, _לְאָ,
  { {0xa9a6000a,0x62863ee3,0xa3cd0053,0x00000000}},	//   _ниед, _nako, _शेष_,
  { {0xf1bf006d,0x6f030003,0xe8df0013,0x00000000}},	//   _afán_, ïnci, guồn_,
  { {0x27210025,0xe5040021,0xa9c5005d,0x00000000}},	//   _fón_, ّبِي, _غزنو,
  { {0x62863ee4,0xe1ff00ea,0xada30066,0x00000000}},	//   _bako, _szó_, _zlúč,
  { {0xdddb008f,0x92b70044,0xf8bc0082,0x00000000}},	//   _lauš, أحسا, _ऋतुप,
  { {0x764d0089,0xaca30013,0xb115005e,0x00000000}},	// [7170] _iday, _xuồn, дмаш,
  { {0x55bc0063,0x66d600c2,0x04590021,0x00000000}},	//   _למחו, rške, _بلدة_,
  { {0x5f790cac,0xf8b3009d,0x00000000,0x00000000}},	//   تماس_, עשע_,   ,
  { {0x7c28016d,0x6d5900a4,0x6ee70021,0x00000000}},	//   _afdr, tuwa, أسئل,
  { {0xdce20124,0x2c6f0058,0xef200022,0x00000000}},	//   atoč, yıdı_, ężar_,
  { {0x62863ee5,0x319a0063,0xeb9905bd,0x00000000}},	//   _zako, _ובשנ, жик_,
  { {0xdca20612,0x6d59194c,0x62863ee6,0x00000000}},	//   тащи, suwa, _yako,
  { {0xdbd7021e,0x6ef100b9,0xfbd00021,0x00000000}},	//   väär, råbs, دته_,
  { {0x27210994,0xcda90032,0x3855005a,0x00000000}},	//   _són_, _بهذه_, мънс,
  { {0x764d005b,0x917a0013,0x6d493ee7,0x00000000}},	//   _aday, _hập_, _ivea,
  { {0x6d440006,0x9a9d0085,0xa146008f,0x00000000}},	//   šiat, _вулi, _zeķē,
  { {0xb4db01a8,0x64410014,0xaca3008d,0x00000000}},	//   ssàl, ðlin, _tuồn,
  { {0x1994000d,0xe8ee0afc,0x62860574,0x00000000}},	//   _паця, _ал_, _rako,
  { {0x917a001b,0x443e008b,0xdce20066,0x00000000}},	//   _lập_, út_, ytoč,
  { {0x62863ee8,0xccf2009a,0x00000000,0x00000000}},	//   _pako, דכם_,   ,
  { {0xdb24000f,0x7cf6003b,0x6e2d0331,0x00000000}},	//   éséh, râri, ñabl,
  { {0x3f830019,0x6724007d,0x6aa60137,0x00000000}},	// [7180] _asju_, _čiji, ökfi,
  { {0x6aab0146,0xc0590086,0xf506000d,0x00000000}},	//   _logf, зії_, _ізно,
  { {0x1eca000a,0x6d4906c6,0x62862b91,0x00000000}},	//   олжи_, _avea, _tako,
  { {0x917a001b,0xc333009a,0x7e9a00de,0x00000000}},	//   _cập_, _שור_, تنصر_,
  { {0xdce23ee9,0xdc740085,0xdddb011b,0x00000000}},	//   stoč, еглы, _pauš,
  { {0x3e4e001b,0x6143005e,0x6da3005e,0x00000000}},	//   ột_, _јера, тиља,
  { {0x6aab00b9,0xeb970141,0xe2ab0046,0x00000000}},	//   _bogf, диј_, _úðð_,
  { {0x3e8600eb,0xdb23013d,0xed5a3acb,0x00000000}},	//   _būtų_, úrák, _моб_,
  { {0xbc660001,0x6aab001f,0x6f03000c,0x00000000}},	//   _овак, _dogf, înce,
  { {0xd90d006a,0xb4bd0053,0x47342f9e,0x00000000}},	//   مین_, _आते_, ннос,
  { {0x90570165,0x752d0282,0xf98f007e,0x00000000}},	//   וסיף_, _staz, هبی_,
  { {0x3ea60150,0x56940376,0x6ef800be,0x00000000}},	//   njot_, вают, fíbi,
  { {0x2d840080,0x6ef80025,0xfe370063,0x00000000}},	//   _jsme_, ríbh, ורכי_,
  { {0x26c20198,0xf9fb009d,0x79fb009d,0x00000000}},	//   ahko_, _והדמ, _ולדח,
  { {0x2cac0185,0x7ae200b2,0xf70a0013,0x00000000}},	//   _modd_, _kjot, _lầy_,
  { {0xa7fc0075,0xae0e0042,0xcb8b009d,0x00000000}},	//   rgıd, िधान_, חְמֹ,
  { {0x34953eea,0xf70a0013,0x752d3eeb,0x00000000}},	// [7190] _запр, _nầy_, _utaz,
  { {0x4427005b,0x3169017d,0xd91b0063,0x00000000}},	//   _ün_, rtaz_, קובל,
  { {0xdfd10032,0x31690089,0x6d49103f,0x00000000}},	//   ديا_, staz_, _svea,
  { {0xf70a0013,0xdd910021,0x62080058,0x00000000}},	//   _bầy_, ُوا_, örlü,
  { {0x41e70086,0xf70a0013,0x2cac32e9,0x00000000}},	//   _ціна, _cầy_, _bodd_,
  { {0xab650062,0xf70a0013,0x66d60078,0x00000000}},	//   евкл, _dầy_, iška,
  { {0x917a008b,0x2cac3eec,0xe452009a,0x00000000}},	//   _tập_, _dodd_, רֶד_,
  { {0xff07000d,0x6e94047e,0xdb030066,0x00000000}},	//   _цягн, _иису, lynú,
  { {0x2cac001f,0xe9d90156,0x9d55007e,0x00000000}},	//   _fodd_, яки_, _سنات,
  { {0xa3c10053,0x77c9107a,0x3ebf0014,0x00000000}},	//   ्छा_, злог_, _hlut_,
  { {0x66d60006,0x3ebf0023,0xdb230043,0x00000000}},	//   eška, _klut_, _شوشی,
  { {0xb4e8016a,0x0bb60041,0xcf560063,0x00000000}},	//   यक्_, _אלעם_, עברת_,
  { {0x3ead0102,0x249a0150,0xc6430044,0x00000000}},	//   _moet_, _pnpm_, طَّي,
  { {0x37e51c9b,0x7afb3eed,0xb956009a,0x00000000}},	//   _полг, llut, _ניצח_,
  { {0xd5b8003d,0x645a01a8,0x66d60078,0x00000000}},	//   ņā_, òtiq, aška,
  { {0xef190045,0x171a00b5,0x05660086,0x00000000}},	//   _niż_, _צופע, _звин,
  { {0x26c00035,0x7afb0b4f,0x3056005e,0x00000000}},	// [71a0] _ilio_, ilut, еђет,
  { {0x7afb007a,0xdcfb017f,0x660400ac,0x00000000}},	//   hlut, _oruđ, _izik,
  { {0x3ebf00bd,0xc43b0063,0x44380731,0x00000000}},	//   _blut_, _מתיי, mbr_,
  { {0x3ead00cd,0x92b60021,0x3ea6001c,0x00000000}},	//   _coet_, _أحدا, ujot_,
  { {0x3ead0122,0x26c00035,0x86370047,0x00000000}},	//   _doet_, _mlio_, גאנג_,
  { {0x224200d1,0xa7fc0058,0x672d0077,0x00000000}},	//   _hekk_, ngıc, _čajn,
  { {0x26c0104e,0x7afb252f,0x3ebf004d,0x00000000}},	//   _olio_, flut, _flut_,
  { {0x3ead006f,0xdbd2004b,0x7afb210b,0x00000000}},	//   _goet_, müür, glut,
  { {0x63b50051,0xc86622f2,0x2cac3eee,0x00000000}},	//   zyzn, нтни, _todd_,
  { {0xd6fb0161,0x29183eef,0x3ead006f,0x00000000}},	//   ृष्ठ_, öra_, _zoet_,
  { {0x64410026,0x7afb004d,0x290c0058,0x00000000}},	//   ðlim, blut, rmda_,
  { {0x7d1a002c,0xf803000d,0x7afb04cf,0x00000000}},	//   _hits, ычын, clut,
  { {0x8e200088,0x7d1a3ef0,0x6aa60137,0x00000000}},	//   вiк_, _kits, ökfu,
  { {0x26c017c2,0x764600a4,0x66040051,0x00000000}},	//   _elio_, aaky, _dzik,
  { {0x27f3004a,0xf76f01fb,0x76660072,0x00000000}},	//   čané_, _هاي_, ätyö,
  { {0x7d1a0019,0x32643279,0xe4140054,0x00000000}},	//   _lits, лтув, удсь,
  { {0x645a06b2,0x22420e41,0xddc93d32,0x00000000}},	// [71b0] ótic, _dekk_, _obeš,
  { {0x90280088,0x3ebf1374,0x8fe70062,0x00000000}},	//   ецца_, _slut_, нцед,
  { {0x3ead3ef1,0x6447001c,0xa8570063,0x00000000}},	//   _poet_, maji, תיבה_,
  { {0x7e6200d1,0x22420026,0x22870141,0x00000000}},	//   ggop, _gekk_, _џунг,
  { {0x3ead0983,0xf204000d,0x3135005e,0x00000000}},	//   _voet_, _бяро, _јегр,
  { {0x64473ef2,0x71d6009a,0x91ba009a,0x00000000}},	//   naji, _יורד_, _חמשי,
  { {0x7cf6003b,0x672d01c8,0xd498009a,0x00000000}},	//   vârt, _čajo, תכות_,
  { {0x644700f3,0x628d39b9,0x7afb3d2d,0x00000000}},	//   haji, ndao, ulut,
  { {0x2d580121,0x4438002b,0x2b40007d,0x00000000}},	//   _пить_, ybr_, ćica_,
  { {0x7afb3ef3,0x64471964,0x8c3c0058,0x00000000}},	//   slut, jaji, _boğu,
  { {0x6f1b05b3,0x38ca007e,0xf0920063,0x00000000}},	//   _kiuc, بايی_, בני_,
  { {0x8c3c005b,0x6d5912bc,0x869a0131,0x00000000}},	//   _doğu, orwa, фтот_,
  { {0x958301e8,0xb8950021,0x18690141,0x00000000}},	//   аляе, _للإع, _жали_,
  { {0x764600eb,0x39560063,0x395f0072,0x00000000}},	//   saky, _ישנם_, muus_,
  { {0xccf20063,0xa7fc0058,0x6d591165,0x00000000}},	//   יכך_, rgıc, hrwa,
  { {0x26c00035,0x6aa916af,0xd5b2014d,0x00000000}},	//   _ulio_, njef, _نفع_,
  { {0x64470228,0x4223000a,0x224200d1,0x00000000}},	// [71c0] baji, рдув, _vekk_,
  { {0x888c00b5,0x7ae4017f,0x8c3c005b,0x00000000}},	//   ּראַ, čiti, _yoğu,
  { {0x7d1a007a,0x75240122,0x67231472,0x00000000}},	//   _rits, _huiz, _junj,
  { {0x444403e9,0x66d60ed9,0x67230401,0x00000000}},	//   _he_, iško, _munj,
  { {0x44443ef4,0x752404fc,0x6f1b0360,0x00000000}},	//   _ke_, _juiz, _diuc,
  { {0x8cf3000d,0x752400ca,0x444405ff,0x00000000}},	//   азіц, _muiz, _je_,
  { {0x7d1a3ef5,0x67230089,0xa5bb0139,0x00000000}},	//   _vits, _nunj, rcói,
  { {0x44443ef6,0x237a0089,0x66d600a2,0x00000000}},	//   _le_, _mppj_, dško,
  { {0x66d600eb,0xf2d301f9,0x8c3c005b,0x00000000}},	//   eško, יעה_, _soğu,
  { {0x7d1a0ac8,0x6c4a0021,0x44443ef7,0x00000000}},	//   _uits, _آلاف_, _ne_,
  { {0x6e470137,0x64473ef8,0xb0b70063,0x00000000}},	//   _örbä, vaji, דפיס_,
  { {0x6447003e,0x44441f36,0x7524006f,0x00000000}},	//   waji, _ae_, _buiz,
  { {0x44443ef9,0x64473efa,0xa954000d,0x00000000}},	//   _be_, taji, _склі,
  { {0xa4e40088,0x75240122,0x44443efb,0x00000000}},	//   аўск, _duiz, _ce_,
  { {0xe795007e,0x444414dd,0xa5c70014,0x00000000}},	//   _مايک, _de_, _bróð,
  { {0x44443efc,0x64473efd,0x6d4b002b,0x00000000}},	//   _ee_, saji, ysga,
  { {0x44440c70,0x26d93efe,0x8cb30053,0x00000000}},	// [71d0] _fe_, miso_, _अवलो,
  { {0x44443eff,0x26d93f00,0xc034005e,0x00000000}},	//   _ge_, liso_, инуј,
  { {0xce33007e,0x6e9509c2,0x15f4007e,0x00000000}},	//   لواک, лижу, _مسیح,
  { {0xf77300b5,0x629d0034,0x26d90006,0x00000000}},	//   יקע_, _unso, niso_,
  { {0x22492ac2,0x64453f01,0x6d4b004d,0x00000000}},	//   maak_, _kehi, usga,
  { {0x395f00fe,0x44443f02,0x40342b0f,0x00000000}},	//   vuus_, _xe_, _верс,
  { {0xfc64005a,0xdce0001c,0x64453f03,0x00000000}},	//   ръчн, _apmē, _mehi,
  { {0x395f00fe,0xf4140063,0x64453f04,0x00000000}},	//   tuus_, ספק_, _lehi,
  { {0x26d93f05,0x291c007d,0x99dd004a,0x00000000}},	//   diso_, _biva_, raňo,
  { {0x6aa600c7,0x61fd108f,0x69c9006f,0x00000000}},	//   ökfr, _mysl, rzee,
  { {0x395f024a,0x75243f06,0x291c3f07,0x00000000}},	//   suus_, _suiz, _diva_,
  { {0x6ef8017d,0x66d6007d,0xb5fb3f08,0x00000000}},	//   líbr, rško, rgán,
  { {0x44440469,0x75243f09,0x64453f0a,0x00000000}},	//   _pe_, _quiz, _behi,
  { {0x67230397,0x6445003b,0x291c0137,0x00000000}},	//   _tunj, _cehi, _giva_,
  { {0xb5fb03e8,0x7ae400c3,0x394d3f0b,0x00000000}},	//   lgál, čitv, lses_,
  { {0x16660001,0x9f9b0019,0x26d93b58,0x00000000}},	//   _свим, _määr_, ciso_,
  { {0x44443f0c,0xa7fc0058,0x394d2308,0x00000000}},	// [71e0] _te_, ngın, nses_,
  { {0x7e69048e,0x6026000d,0x6445050c,0x00000000}},	//   _acep, уджа, _gehi,
  { {0xe8d6009a,0xa78c009d,0x00000000,0x00000000}},	//   נוער_, ֽאדֹ,   ,
  { {0x394d3f0d,0x7e693f0e,0x64450058,0x00000000}},	//   kses_, _ccep, _zehi,
  { {0xdcb1008b,0x463b0047,0x763b0041,0x00000000}},	//   _bỏ_, גענע, גענג,
  { {0x0b8a065b,0x26d900ac,0x55770047,0x00000000}},	//   есии_, ziso_, רעסן_,
  { {0x291c3f0f,0xb5fb00ea,0x394d3f10,0x00000000}},	//   _riva_, egál, eses_,
  { {0xd7f8000c,0x8c3c005b,0x291c3f11,0x00000000}},	//   ugăm_, _coğr, _siva_,
  { {0x8c3c01f7,0x26d9051e,0xc27b0063,0x00000000}},	//   _doğr, viso_, גרפי,
  { {0x2249006f,0x2886005e,0x6b8d0022,0x00000000}},	//   zaak_, ућив, łaga,
  { {0x64451395,0x394d221f,0x2902001c,0x00000000}},	//   _rehi, ases_, ēka_,
  { {0x6445014f,0x2f970047,0x645a0014,0x00000000}},	//   _sehi, אכטן_, ótin,
  { {0x25bf000f,0x76b8130d,0x656f066d,0x00000000}},	//   ául_, уляр_, utch,
  { {0x838705ac,0x656f3f12,0x833501ce,0x00000000}},	//   лыбе, rtch, ингх,
  { {0x7792006a,0xd6d108aa,0x61fd23c9,0x00000000}},	//   _ایجا, _وقت_, _sysl,
  { {0xa6ab0242,0xb5a7130d,0xc2c50021,0x00000000}},	//   _سابق_, _брой, جيري,
  { {0x64450019,0x22490173,0x60f9093e,0x00000000}},	// [71f0] _tehi, raak_, вная_,
  { {0x61fd004a,0x224902a8,0x7e691db6,0x00000000}},	//   _vysl, saak_, _scep,
  { {0x80071254,0x61fd0022,0x672d3f13,0x00000000}},	//   учае, _wysl, _čajk,
  { {0x66f70053,0xcf88000d,0xa7fc0058,0x00000000}},	//   ीतिक_, ысуд_, ygın,
  { {0xada5015a,0xa2ba0053,0x628f1408,0x00000000}},	//   ралл, _एकत्, _iaco,
  { {0x6b550062,0x394d004b,0x9ce7014b,0x00000000}},	//   атих, vses_, ыцел,
  { {0xeab10021,0xfaa50121,0xdcb10013,0x00000000}},	//   قعة_, иако, _vỏ_,
  { {0x394d25d2,0x628f13b6,0x9f9b004b,0x00000000}},	//   tses_, _jaco, _väär_,
  { {0xf1b20047,0xa9250002,0x394d3f14,0x00000000}},	//   ַסט_, јдол, uses_,
  { {0x3f98001f,0xb8f20021,0x394d089c,0x00000000}},	//   _yrru_, يكيب, rses_,
  { {0x394d15ae,0xf745005e,0xb5fb013d,0x00000000}},	//   sses_, јемо, sgál,
  { {0x89d6007e,0xe1ff006d,0x26c4006d,0x00000000}},	//   اویر_, _oyó_, ómo_,
  { {0xcb12014e,0xa9690062,0xa7fc0058,0x00000000}},	//   _ולא_, _рила_, lgıl,
  { {0xa50a11f7,0xd4f60121,0x04430131,0x00000000}},	//   тега_, рямы, жерн,
  { {0x98f40021,0x628f2a42,0xb7d6005d,0x00000000}},	//   _اثنا, _baco, _پويا_,
  { {0xd1320021,0x8e20014b,0x00000000,0x00000000}},	//   قمر_, вiн_,   ,
  { {0x225d0051,0x69060014,0x4127019c,0x00000000}},	// [7200] ówka_, iðen, иото_,
  { {0xe3ba0097,0xbebd0078,0xa5bb0516,0x00000000}},	//   _або_, _liūd, rcót,
  { {0x628f051e,0x7e260174,0xb4c20042,0x00000000}},	//   _faco, адеж, ंसी_,
  { {0x539b014e,0x27760047,0xad660021,0x00000000}},	//   _סיכו, יגען_, لاته,
  { {0xc8780058,0xfa900058,0x7aed0130,0x00000000}},	//   liğe_, çümü_, čatl,
  { {0x614306b4,0xcb540044,0x3cd30054,0x00000000}},	//   _фера, منتظ, ожіс,
  { {0x69dd0024,0x7b050014,0x798b002b,0x00000000}},	//   úsen, róun, _asgw,
  { {0x5a34005a,0x02b60063,0x8f370063,0x00000000}},	//   щнит, יהֶם_, _כאלו_,
  { {0x8d2a0086,0x63bc08e9,0x6f023f15,0x00000000}},	//   _розв_, hyrn, mloc,
  { {0x6f0231a2,0x20070051,0x8c66007e,0x00000000}},	//   lloc, żnie_, _خطرن,
  { {0x627e0051,0xeb9a0002,0x6f020dd2,0x00000000}},	//   _złoż, _јие_, oloc,
  { {0x7bdb0063,0x6f023f16,0xfaa33f17,0x00000000}},	//   _בקבו, nloc, _махо,
  { {0x628f05d7,0x6f020066,0x9934002a,0x00000000}},	//   _raco, iloc, _افتت,
  { {0x628f3a8a,0xc8780058,0x19bb089e,0x00000000}},	//   _saco, fiğe_, _במדב,
  { {0x628f0016,0x6f02351a,0x2259030b,0x00000000}},	//   _paco, kloc, ливы_,
  { {0x798b001f,0x6f02000c,0xa3193f18,0x00000000}},	//   _ysgw, jloc, ужбу_,
  { {0x51872ff2,0xc1050049,0xf1940121,0x00000000}},	// [7210] шува, موري, оить,
  { {0x3168000a,0xa7fc005b,0x89370047,0x00000000}},	//   јшто_, ygıl, ירמע_,
  { {0x339501a7,0x6aa23f19,0xb60801c8,0x00000000}},	//   _الجز, _onof, _tuší,
  { {0x6284017d,0x139a0047,0x539a00ff,0x00000000}},	//   ceio, _עברע, _עירו,
  { {0x127a0047,0x6b9a004d,0x66c6013d,0x00000000}},	//   _גארע, _artg, _jóka,
  { {0x8c4205fb,0xfbc5030b,0x4431208d,0x00000000}},	//   пеше, йбло, ncz_,
  { {0xde67005a,0x6f023f1a,0x627e0022,0x00000000}},	//   _възп, bloc, _włoż,
  { {0x3a980076,0xa7fc005b,0xb5fb013d,0x00000000}},	//   атью_, rgıl, rgáj,
  { {0xe8f9015a,0x627e0022,0xc8780075,0x00000000}},	//   лли_, _ułoż, ziğe_,
  { {0x66d600c2,0x77390062,0xdb030022,0x00000000}},	//   mški, лямс_, tynó,
  { {0x30fa0042,0x3cfa0041,0xa088009a,0x00000000}},	//   ्ततः_, _עלענ, בְרִ,
  { {0x66c60026,0x0f7a0047,0x5b150d34,0x00000000}},	//   _bóka, נארב, _умет,
  { {0x59c40021,0x66080051,0xdddb0078,0x00000000}},	//   _ويمك, ędko, _lauž,
  { {0x66d60006,0x3a3f0150,0x2dda0041,0x00000000}},	//   iški, lbup_, אַלב,
  { {0x78a30031,0xdce2007d,0x9735014d,0x00000000}},	//   _innv, stoć, _اعتص,
  { {0xc878005b,0x395f0346,0x66d62c46,0x00000000}},	//   riğe_, orus_, kški,
  { {0x955604de,0xe2970905,0xa5bb039f,0x00000000}},	// [7220] _اخبا, щат_, scór,
  { {0xb4660138,0xb4db0268,0xb69b017d,0x00000000}},	//   _укол, ssàr, nlân,
  { {0x61ef3f1b,0x644e3f1c,0xee3a0336,0x00000000}},	//   _excl, mabi, гне_,
  { {0x644e3f1d,0x61e93f1e,0x395f0078,0x00000000}},	//   labi, _žele, krus_,
  { {0x1dd20053,0x22403f1f,0x26c23f20,0x00000000}},	//   _देखत, mbik_, ikko_,
  { {0xdb090024,0x644e3f21,0x6f023f22,0x00000000}},	//   ľnýc, nabi, sloc,
  { {0x9183001b,0xdb090240,0x395f1c86,0x00000000}},	//   _tệp_, žnýc, erus_,
  { {0x656600ac,0xeb97005e,0x32020072,0x00000000}},	//   kukh, сић_, _kyky_,
  { {0xd91a3f23,0x644e3f24,0xdddb25ba,0x00000000}},	//   льо_, kabi, _zauž,
  { {0xd90d007e,0xe7860f9a,0xab2a02fe,0x00000000}},	//   نین_, бумо, _божа_,
  { {0x395f014f,0x644e3f25,0xda7a005a,0x00000000}},	//   arus_, dabi, _бял_,
  { {0xb5fb0405,0x6aa200e5,0x60de3f26,0x00000000}},	//   lgái, _unof, hipm,
  { {0xb5fb0025,0xb69b003b,0x644e3f27,0x00000000}},	//   ogái, blân, fabi,
  { {0xb5fb0025,0x644e3f28,0xe4e70054,0x00000000}},	//   ngái, gabi, сімн,
  { {0xf8db0063,0x44311ae4,0x2419082d,0x00000000}},	//   _תחומ, rcz_, ровы_,
  { {0x65660089,0x66d60078,0x83380121,0x00000000}},	//   bukh, yški, счёт_,
  { {0xdce20024,0x644e3f29,0x64410014,0x00000000}},	// [7230] dvoľ, babi, ðlis,
  { {0x764f0051,0x644e364a,0x90550086,0x00000000}},	//   lacy, cabi, івец,
  { {0xdea1007e,0x7bde12c7,0x2240013d,0x00000000}},	//   ویسی, úpul, bbik_,
  { {0x57fb0063,0x395f18a1,0xd7fb0047,0x00000000}},	//   נלאו, yrus_, נהאל,
  { {0x9cf50086,0x7415007e,0x66d6005f,0x00000000}},	//   озді, _دوگا, uški,
  { {0xd01b005a,0x66d617b8,0xab3502d8,0x00000000}},	//   _бфб_, rški, охиј,
  { {0x764f0051,0x66e4013d,0x00000000,0x00000000}},	//   kacy, lőke,   ,
  { {0x644e3f2a,0x395f2228,0xdcfb008f,0x00000000}},	//   zabi, trus_, _kruī,
  { {0x644e01f7,0x7e640025,0xb69b017d,0x00000000}},	//   yabi, óipe, tlân,
  { {0x212b0034,0xf771002a,0x395f3f2b,0x00000000}},	//   _much_, واج_, rrus_,
  { {0x644e3ec2,0x06ea015a,0x212b0139,0x00000000}},	//   vabi, имок_, _luch_,
  { {0x98aa003d,0x224b0969,0x6f03003b,0x00000000}},	//   āmām_, _neck_, înch,
  { {0x26c200fe,0xa50a00a0,0x7afb1219,0x00000000}},	//   rkko_, иема_, mout,
  { {0x2eb60161,0x7ae93f2c,0x7afb1426,0x00000000}},	//   _अक्त, lnet, lout,
  { {0x212b0cd4,0x644e3f2d,0x690f00b9,0x00000000}},	//   _auch_, rabi, røed,
  { {0x212b00bd,0x316006b2,0x7ae93f2e,0x00000000}},	//   _buch_, triz_, nnet,
  { {0x224b0780,0x7ae93f2f,0x29053f30,0x00000000}},	// [7240] _deck_, inet, olla_,
  { {0xd5e00053,0x7ae93c02,0x7afb3f31,0x00000000}},	//   _पेयज, hnet, hout,
  { {0x29051258,0x212b00bd,0x7ae9068a,0x00000000}},	//   illa_, _euch_, knet,
  { {0x7afb0164,0x57ca0047,0xeef5000d,0x00000000}},	//   jout, סמײַ, пячэ,
  { {0xddc80051,0x7afb07c1,0x3f860024,0x00000000}},	//   _żołn, dout, ňou_,
  { {0x31230086,0x764f0051,0x20070022,0x00000000}},	//   _одяг, zacy, żnia_,
  { {0xf76704de,0x7afb006f,0x7ae900bd,0x00000000}},	//   _تا_, fout, fnet,
  { {0x29053f32,0xeaf7007e,0x7afb3f33,0x00000000}},	//   ella_, يريت_, gout,
  { {0x764f0122,0x68fa000c,0xef170054,0x00000000}},	//   vacy, totd, _єму_,
  { {0x1d0a011c,0xb17b0047,0x66d60078,0x00000000}},	//   _тези_, סטיר, išku,
  { {0x660d000f,0x66e410fd,0xb5fb017d,0x00000000}},	//   _szak, zőke, ngáv,
  { {0x7afb3f34,0x29053f35,0xd6db3f36,0x00000000}},	//   cout, alla_, рто_,
  { {0x764f0045,0xe9cf007e,0x67240089,0x00000000}},	//   racy, _لغو_, _diij,
  { {0xd5b80088,0x212b13e4,0xdce2005f,0x00000000}},	//   іся_, _ruch_, kuoč,
  { {0x212b0037,0x57f3041d,0x98a30001,0x00000000}},	//   _such_, _општ, _ције,
  { {0x25a600c3,0xb8820080,0x66e400ea,0x00000000}},	//   _šole_, řídi, tőke,
  { {0x660d005b,0xd52d008b,0x69c017ec,0x00000000}},	// [7250] _uzak, _dựn, nyme,
  { {0xcf9b20cf,0x7aed0024,0x2eed00d1,0x00000000}},	//   ије_, čati, _sjef_,
  { {0x764d0089,0x7afb0a11,0x69c00616,0x00000000}},	//   _keay, yout, hyme,
  { {0x23fa0063,0x79820051,0x212b004d,0x00000000}},	//   _להתא, _opow, _tuch_,
  { {0x29053f37,0x7ae90093,0x752d00be,0x00000000}},	//   ylla_, vnet, _juaz,
  { {0xccfb0001,0x91ba0063,0x752d3f38,0x00000000}},	//   шће_, _המשי, _muaz,
  { {0x447c00b5,0x7e640025,0x7afb3f39,0x00000000}},	//   ינגע, óipc, tout,
  { {0xfbd0006a,0x66e400ea,0x7ae00078,0x00000000}},	//   خته_, zőkb, gimt,
  { {0x290500cd,0x2d99006d,0x69c0001f,0x00000000}},	//   tlla_, _ése_, gyme,
  { {0x29053f3a,0x18690001,0x7afb3d7e,0x00000000}},	//   ulla_, љани_, sout,
  { {0xd62a0076,0xb8e30053,0x78bc3f3b,0x00000000}},	//   йоне_, _एक_, örva,
  { {0x6a940086,0xa5c20014,0x6b7a009a,0x00000000}},	//   _оріє, _þókn, _לרענ,
  { {0x6b500025,0x28f90054,0xa9a50893,0x00000000}},	//   _tógá, _ледь_, _хилд,
  { {0xe6170121,0x2a6d004b,0xddc91536,0x00000000}},	//   ядя_, lgeb_, _obež,
  { {0x03a30076,0x7cf6000c,0x68e13f3c,0x00000000}},	//   ниро, târz, mild,
  { {0x2a6d0019,0x61e93f3d,0x6e293f3e,0x00000000}},	//   ngeb_, _žela, _ngeb,
  { {0xdb0a00ea,0xa6e20014,0xa2cd0042,0x00000000}},	// [7260] ínés, æðue, _सतर्,
  { {0xb466093e,0x41033ce8,0x68e13f3f,0x00000000}},	//   _экол, езув, nild,
  { {0xdee60054,0x94bb0063,0x69c00673,0x00000000}},	//   пожи, _המית, zyme,
  { {0x25a03214,0x68e13f40,0x3f9e3f41,0x00000000}},	//   _kril_, hild, _átum_,
  { {0x4c940612,0x2d9f0003,0x1d0a032d,0x00000000}},	//   дилс, _crue_, беди_,
  { {0xdce2005f,0xeb4a02fa,0x00000000,0x00000000}},	//   puoč, бчик_,   ,
  { {0x79820045,0xf65f0146,0x68e1005b,0x00000000}},	//   _spow, mhæv_, dild,
  { {0x78b80290,0x66c60026,0x7ae03f42,0x00000000}},	//   _sovv, _bókm, uimt,
  { {0x39140076,0xddc900c2,0x2d9f006c,0x00000000}},	//   ммир, _zbež, _grue_,
  { {0x68e10026,0x2d570063,0xd90e007e,0x00000000}},	//   gild, _משמש_, دیت_,
  { {0xdc3b01f9,0xa09b0047,0xdb240139,0x00000000}},	//   _העבר, זייט, úsói,
  { {0x69060026,0xcb8b009a,0xfa540043,0x00000000}},	//   iðei, _לְדֹ, _آراگ,
  { {0x79820051,0x18a63f43,0x2b40007d,0x00000000}},	//   _upow, _надм, ćicu_,
  { {0x99dd0080,0xf53f3b9c,0x65600139,0x00000000}},	//   raňt, rpå_, ámha,
  { {0x187b0063,0x987b0165,0xa87b0063,0x00000000}},	//   _הטוב, _האוט, _האור,
  { {0x97c50044,0x00000000,0x00000000,0x00000000}},	//   _تتهم,   ,   ,
  { {0xc2c40032,0xa6e30014,0x6e29004d,0x00000000}},	// [7270] ريكي, öðus, _rgeb,
  { {0xdb030003,0x66f2008f,0x3fc9005d,0x00000000}},	//   lynô, māka, يدای_,
  { {0x2fc700aa,0x6d490034,0x66f2001c,0x00000000}},	//   áng_, _swea, lāka,
  { {0x2d9f3f44,0xde580054,0x7d1d013d,0x00000000}},	//   _prue_, заці_, _éssz,
  { {0x7e870006,0x66f2008f,0xacf9013c,0x00000000}},	//   _įspė, nāka, онду_,
  { {0x2fc7001b,0x4e18007e,0xddc9003b,0x00000000}},	//   ơng_, ستند_, _aceţ,
  { {0xfc460080,0xddc900c2,0x3f830023,0x00000000}},	//   _říci_, _ubež, _upju_,
  { {0x2d9f0034,0xcf920063,0x68e121b4,0x00000000}},	//   _true_, _בטל_, wild,
  { {0x2f18015a,0xac273f45,0x89a90054,0x00000000}},	//   _хоть_, _ефек, іков_,
  { {0x9f880026,0x57e90076,0x68e13f46,0x00000000}},	//   _kóða_, ждом_, uild,
  { {0x68e101f7,0xc0520063,0x2c5f008f,0x00000000}},	//   rild, כזי_, rādē_,
  { {0x257600b9,0xdce20058,0x9f64006c,0x00000000}},	//   tæl_, otoğ, étée_,
  { {0x68e11867,0x66f2001c,0x7afc013d,0x00000000}},	//   pild, gāka, _írta,
  { {0xa25b0013,0xa3df0042,0xe8f8046e,0x00000000}},	//   _xlôv, _देह_, _елі_,
  { {0xe852007e,0x46f60da9,0xa50707d8,0x00000000}},	//   _شنيد, _очит, фера_,
  { {0x257600b9,0x66f2001c,0x130a000d,0x00000000}},	//   pæl_, bāka, інай_,
  { {0x7bc30114,0x27330013,0xf1de0053,0x00000000}},	// [7280] hynu, _hãn_, _नेशन,
  { {0xdcfb017f,0x25bf004d,0xa3df0042,0x00000000}},	//   _osuđ, äule_, _देव_,
  { {0x78fa0041,0xd6d70043,0x00000000,0x00000000}},	//   קלעפ, _رویش_,   ,
  { {0x2733008b,0x6e2d00c2,0x7ed5000d,0x00000000}},	//   _mãn_, žabn, нічч,
  { {0x471b0047,0xdc390058,0xb5fb3f47,0x00000000}},	//   קונג, _açıd, lgár,
  { {0x236500c3,0x40950d34,0x4438002b,0x00000000}},	//   šlje_, _прст, ncr_,
  { {0x60230088,0x9f580829,0x66f2001c,0x00000000}},	//   _адра, _byrå_, zāka,
  { {0x63a10137,0x44383f48,0xbae30085,0x00000000}},	//   ålni, hcr_, кцый,
  { {0xa3c2016a,0xadba0021,0x645e3f49,0x00000000}},	//   ्नड_, _بهذا_, _odpi,
  { {0x66f2008f,0xb5fb013d,0x66e4013d,0x00000000}},	//   vāka, zgás, vőka,
  { {0x1bf2024c,0x69c600d1,0x65660089,0x00000000}},	//   _अखिल_, økeb, erkh,
  { {0x25a600c3,0x66f2001c,0x19c62d7b,0x00000000}},	//   _šola_, tāka, _обем,
  { {0xceb30063,0x25bf003b,0x99d30044,0x00000000}},	//   דיר_, âul_, _لتوا,
  { {0x66f2003d,0xf76f007e,0x61e9085a,0x00000000}},	//   rāka, دای_, _želo,
  { {0xa3df0235,0x6566147f,0x25ad003b,0x00000000}},	//   _देश_, arkh, ţel_,
  { {0x2bb60053,0x32640a36,0x44280083,0x00000000}},	//   _अपना, ктув, ьцям_,
  { {0xa3df0053,0xb1151225,0xb5fb013d,0x00000000}},	// [7290] _देर_, емаш, rgás,
  { {0x2ec70161,0x39590014,0x439506b6,0x00000000}},	//   लस्त, ássi_, _заос,
  { {0x64553f4a,0x66c60014,0x20070014,0x00000000}},	//   mazi, _bókh, æni_,
  { {0x64553f4b,0x7c3a25b9,0xa25b0003,0x00000000}},	//   lazi, _aftr, _clôt,
  { {0xdd94000d,0x6d44003b,0xfd48000d,0x00000000}},	//   кацы, ţian, дзік_,
  { {0x645502f6,0xd13e0045,0x8b9514cd,0x00000000}},	//   nazi, żące_, ерич,
  { {0x780d0053,0x6d42003b,0x0c360021,0x00000000}},	//   _हरेक_, apoa, ركية_,
  { {0xa3c20053,0x64553f4c,0x628d00dd,0x00000000}},	//   ्नत_, hazi, neao,
  { {0x64553f4d,0x68ef006d,0x7bce004d,0x00000000}},	//   kazi, écdo, _übun,
  { {0x64550035,0xb881004a,0x57450121,0x00000000}},	//   jazi, _číse, нноб,
  { {0x64553f4e,0x628d0050,0x6d590285,0x00000000}},	//   dazi, keao, lswa,
  { {0xeaae000d,0x7ac42758,0x645501f4,0x00000000}},	//   _ёй_, _исче, eazi,
  { {0x64553f4f,0x6d591520,0xfa56007e,0x00000000}},	//   fazi, nswa, _سرنگ,
  { {0xbebd00eb,0x6d590035,0x6455071d,0x00000000}},	//   _siūl, iswa, gazi,
  { {0x63831a5c,0xa34a0062,0x66e60481,0x00000000}},	//   лгра, язва_, _пока,
  { {0x443a373a,0x66f2008f,0xa7fc0058,0x00000000}},	//   _wfp_, māko, rgıt,
  { {0xe1ff0025,0x64553f50,0x66f2008f,0x00000000}},	// [72a0] _scór_, bazi, lāko,
  { {0x645502f6,0xc059019d,0xc1060021,0x00000000}},	//   cazi, дії_, رواي,
  { {0x66f2001c,0x9e660f55,0xc209069a,0x00000000}},	//   nāko, евед, צה_,
  { {0x481600b5,0xddc00080,0x66c60026,0x00000000}},	//   ײַבן_, _zemř, _bóki,
  { {0x6d59004d,0x6da30794,0xe8df0013,0x00000000}},	//   gswa, лица, ýớc_,
  { {0xdb0a0014,0x6f03003b,0x00000000,0x00000000}},	//   eyfð, încr,   ,
  { {0x7ac60055,0x6d593f51,0x61290078,0x00000000}},	//   еспе, aswa, _užla,
  { {0x2f1500b9,0x7e530021,0x64550534,0x00000000}},	//   tåge_, _منفص, zazi,
  { {0x66e4000f,0x6d590035,0xa7fc0058,0x00000000}},	//   tőkn, cswa, ygıs,
  { {0xdce200c3,0xa3c20053,0xeb9a018e,0x00000000}},	//   oroč, ्ना_, _низ_,
  { {0x64553f52,0xa3df0053,0x36d50002,0x00000000}},	//   vazi, _दें_, вонр,
  { {0x7c46001c,0x212a0025,0x64550035,0x00000000}},	//   ūrrē, _libh_, wazi,
  { {0x64553f53,0x7ae20130,0x00000000,0x00000000}},	//   tazi, _imot,   ,
  { {0xdb1f0026,0xdce20240,0x7ae20240,0x00000000}},	//   ðvör, kroč, _hmot,
  { {0x64553f54,0xa7370021,0x291e0014,0x00000000}},	//   razi, _كثير_, mmta_,
  { {0xdce20198,0x92590002,0x9294000d,0x00000000}},	//   droč, ќаат_, ласц,
  { {0x64553f55,0x94ab005e,0x916d0013,0x00000000}},	// [72b0] pazi, _етна_, _bốt_,
  { {0xdb180072,0x656f3f56,0x25d8009a,0x00000000}},	//   lyvä, much, _רוזן_,
  { {0x6d44000c,0x291e3f57,0x6d403f58,0x00000000}},	//   ţial, imta_, _atma,
  { {0xf4120063,0x8f34000d,0x6d593f59,0x00000000}},	//   _כפי_, уецц, tswa,
  { {0x22490397,0xdce200b2,0x657d3f5a,0x00000000}},	//   mbak_, aroč, ntsh,
  { {0xdb180072,0x657d02d2,0x7ae23f5b,0x00000000}},	//   hyvä, itsh, _amot,
  { {0xdb18024a,0x2fc500b9,0x656f3f5c,0x00000000}},	//   kyvä, _ælg_, huch,
  { {0x22490122,0xada60024,0xeab10032,0x00000000}},	//   nbak_, _slúž, شعب_,
  { {0xa3e8016a,0x61e90add,0x22490150,0x00000000}},	//   _मेन_, _želj, ibak_,
  { {0x656f0a63,0x4d98000d,0xa3d10053,0x00000000}},	//   duch, _якую_, वना_,
  { {0x366a3f5d,0x656f3f5e,0x207c0041,0x00000000}},	//   мано_, euch, לאזא,
  { {0x66f2001c,0xdb013f5f,0x7ae200c2,0x00000000}},	//   rāko, _orlé, _gmot,
  { {0x3ebf1a05,0xdce200b2,0x66f2008f,0x00000000}},	//   _mout_, zroč, sāko,
  { {0x7d033f60,0xb4db00cd,0x7ae20c22,0x00000000}},	//   nons, spàn, _zmot,
  { {0xe7b2007e,0x657d3f61,0x29070058,0x00000000}},	//   _نمود, atsh, _ikna_,
  { {0x2365000f,0x212a0025,0x3ead00d1,0x00000000}},	//   álja_, _sibh_, _nnet_,
  { {0x656f02dd,0x88c5004c,0x7d031d13,0x00000000}},	// [72c0] cuch, aměř, kons,
  { {0x7d030031,0xe043018e,0x4fa6005e,0x00000000}},	//   jons, инуи, кизв,
  { {0x224900ea,0x3ebf3f62,0x31693f63,0x00000000}},	//   bbak_, _bout_, araz_,
  { {0xcfa90032,0x3ead3f64,0x3ebf3f65,0x00000000}},	//   عالم_, _cnet_, _cout_,
  { {0x916d008b,0xf53f102d,0x290c0f49,0x00000000}},	//   _tốt_, rvåg_, ylda_,
  { {0x7d033f66,0xdce221e4,0x50431567,0x00000000}},	//   gons, proč, _верб,
  { {0x3ebf0102,0xc0e31de2,0x25e90042,0x00000000}},	//   _fout_, _торк, _चेनी_,
  { {0x49743f67,0xeb970001,0xb9980690,0x00000000}},	//   глис, тић_, евих_,
  { {0xc878005b,0xeef5000d,0x0d77007e,0x00000000}},	//   liği_, _сярэ, _لینک_,
  { {0x52bf0161,0x1be30053,0x3ebf006f,0x00000000}},	//   _एक्स, _केवल_, _zout_,
  { {0xdb1800fe,0x656f004d,0x316900b2,0x00000000}},	//   tyvä, wuch, zraz_,
  { {0x7c27000f,0x657d08a9,0x31690022,0x00000000}},	//   _újra, ttsh, yraz_,
  { {0xb8960021,0x3e7d013d,0x35e41313,0x00000000}},	//   _للشع, látó_, ацрв,
  { {0xdb1800fe,0x6286004d,0x657d2f44,0x00000000}},	//   syvä, _abko, rtsh,
  { {0x656f0199,0x68e83f68,0xdfe10053,0x00000000}},	//   such, midd, _गेंद_,
  { {0xc878005b,0x656f22de,0x66c60014,0x00000000}},	//   diği_, puch, _bóku,
  { {0x52150095,0x3ebf00e5,0xa1583f69,0x00000000}},	// [72d0] удат, _rout_, кату_,
  { {0xc878005b,0x3ebf00f5,0x316900be,0x00000000}},	//   fiği_, _sout_, rraz_,
  { {0x672d0035,0xf0270002,0x7d033f6a,0x00000000}},	//   _kiaj, тќан, vons,
  { {0x8d79005e,0x31690058,0x66c6336c,0x00000000}},	//   ељку_, praz_, _fóku,
  { {0x7d033f6b,0xadbc0086,0x3ebf00ac,0x00000000}},	//   tons, мацi, _vout_,
  { {0x629d000f,0x3ead0022,0x69320022,0x00000000}},	//   _haso, _wnet_, _złeg,
  { {0x3ebf03b2,0x69c60031,0x7d031312,0x00000000}},	//   _tout_, øken, rons,
  { {0xb8820080,0x66eb0051,0x66f2008f,0x00000000}},	//   říli, ięks, tākm,
  { {0x660d0035,0x629d3f6c,0xbdf50259,0x00000000}},	//   _nyak, _maso, _спај,
  { {0xe8f60121,0x629d3f6d,0x6616056c,0x00000000}},	//   ллы_, _laso, _rzyk,
  { {0xab940086,0x660d005b,0x28d90053,0x00000000}},	//   _вихі, _ayak, योगि,
  { {0x9666000d,0x1db70053,0x629d3f6e,0x00000000}},	//   ыкме, _आपात, _naso,
  { {0x7ae90024,0x672d0397,0x68e83f6f,0x00000000}},	//   miet, _diaj, bidd,
  { {0x7ae93a85,0x64a60001,0x6abb00c2,0x00000000}},	//   liet, ћава, ljuf,
  { {0xd838000d,0x29053f70,0x82f60085,0x00000000}},	//   _рэч_, mola_, гчац,
  { {0x290500f3,0xe2973f71,0x7ae93f72,0x00000000}},	//   lola_, лас_, niet,
  { {0x3f8a0150,0x69db3f73,0x33202e62,0x00000000}},	// [72e0] _spbu_, nzue, rmix_,
  { {0xc878005b,0x7ae93f74,0x29053f75,0x00000000}},	//   tiği_, hiet, nola_,
  { {0x78bc00a5,0xa2e63f76,0x69c90050,0x00000000}},	//   örvi, _бонд, hyee,
  { {0xc878005b,0x7ae9001c,0x66c60026,0x00000000}},	//   riği_, jiet, _tóku,
  { {0x7ae93f77,0x29053f78,0x6c543f79,0x00000000}},	//   diet, kola_, аклу,
  { {0x2f1500c7,0x629d0051,0x628401f4,0x00000000}},	//   råga_, _zaso, lfio,
  { {0x29053f7a,0x68e8011d,0x7ae93f7b,0x00000000}},	//   dola_, vidd, fiet,
  { {0x69c60031,0x61e916ea,0x5a34026b,0x00000000}},	//   økeo, _želi, шнит,
  { {0x6284001f,0x88ea0002,0x2bb60053,0x00000000}},	//   ifio, еќна_, _अपवा,
  { {0x29053f7c,0x3942001c,0xbd5b009a,0x00000000}},	//   gola_, īks_, _נכבש,
  { {0x7ae93f7d,0x3773000d,0xa6f50121,0x00000000}},	//   biet, быўс, изош,
  { {0x68e83f7e,0xfa360021,0x7ae90641,0x00000000}},	//   sidd, _إراد, ciet,
  { {0x672d06b2,0x629d3f7f,0x29053f80,0x00000000}},	//   _viaj, _raso, bola_,
  { {0x660d0035,0x66c60026,0x29053f81,0x00000000}},	//   _vyak, _bóks, cola_,
  { {0xa3df0161,0xa3d40086,0x629d3f82,0x00000000}},	//   _देख_, борч, _paso,
  { {0x8c1b0063,0x6d550022,0x00000000,0x00000000}},	//   תולי, _łzam,   ,
  { {0xdcfb017f,0xb06b3f83,0x629d05d1,0x00000000}},	// [72f0] _upuć, ереж_, _vaso,
  { {0x629d0035,0x25a900a4,0x95840051,0x00000000}},	//   _waso, _iral_, żący,
  { {0x629d00fe,0x5f9506be,0x7a2b005b,0x00000000}},	//   _taso, риет, _kötü,
  { {0x29053f84,0x7ae900e5,0x25a90058,0x00000000}},	//   zola_, xiet, _kral_,
  { {0x69c60031,0x7ae93f85,0x64400051,0x00000000}},	//   økel, viet, śmie,
  { {0x7ae90045,0xdca51599,0xcb69005e,0x00000000}},	//   wiet, раки, ваке_,
  { {0x2fc700c7,0x29053f86,0x7ae93f87,0x00000000}},	//   ängd_, vola_, tiet,
  { {0x69c900fe,0x2bb60053,0x66f2008f,0x00000000}},	//   tyee, _अपरा, rākk,
  { {0x8c3c005b,0x6abb00ca,0xc8b50895,0x00000000}},	//   _bağd, rjuf, асны,
  { {0x290507a0,0xa8050062,0xd1980063,0x00000000}},	//   uola_, изпл, רכזי_,
  { {0x7ae93f88,0x25a93f89,0x29053f8a,0x00000000}},	//   piet, _aral_, rola_,
  { {0x3f81001f,0x0656000d,0x29053f8b,0x00000000}},	//   ithu_, штоў, sola_,
  { {0x29053f8c,0x645700be,0x66f2008f,0x00000000}},	//   pola_, _bexi, nāki,
  { {0xccf200b5,0xf5070076,0x20f40053,0x00000000}},	//   ַכן_, инял_, _आदेश_,
  { {0x7e7b1bb7,0xe29f0014,0xa927008f,0x00000000}},	//   _ocup, _bað_, rdžī,
  { {0xd7fa0165,0x7a2b005b,0x9814007e,0x00000000}},	//   _בהצל, _götü, _ابها,
  { {0xe2970174,0x3f81001f,0x62843f8d,0x00000000}},	// [7300] шат_, ethu_, rfio,
  { {0x66c60026,0x66f2008f,0xe0d73f8e,0x00000000}},	//   _tóks, dāki, аву_,
  { {0x645c3f8f,0x200e0014,0x0eba0085,0x00000000}},	//   mari, æfi_, куды_,
  { {0x645c3f90,0x644e004d,0x395f3f91,0x00000000}},	//   lari, lbbi, ksus_,
  { {0x2d96015a,0x40960002,0x66f2008f,0x00000000}},	//   ррес, _крвт, gāki,
  { {0x69c600d1,0x645c3f92,0xfb660001,0x00000000}},	//   økem, nari, ањим,
  { {0x645c07a8,0x31600075,0x395f3f93,0x00000000}},	//   iari, lsiz_, esus_,
  { {0x2fc700bd,0x645c3f94,0x8f9b0149,0x00000000}},	//   änge_, hari, _בילי,
  { {0x645c3f95,0x31600058,0xee0a06b4,0x00000000}},	//   kari, nsiz_, _реал_,
  { {0x645c3f96,0x28a60161,0xdbdc0114,0x00000000}},	//   jari, _कोशि, lším,
  { {0x395f00f3,0x10370063,0x80370047,0x00000000}},	//   asus_, יטים_, יניע_,
  { {0x28a60053,0x64573f97,0x3160005b,0x00000000}},	//   _कोरि, _sexi, ksiz_,
  { {0xe5c4042c,0x645c35f1,0x395f002b,0x00000000}},	//   осро, fari, csus_,
  { {0x3f81002b,0x3946005f,0x645c3f98,0x00000000}},	//   ythu_, _itos_, gari,
  { {0xd3a40002,0x64571dba,0x2ba90042,0x00000000}},	//   ортп, _vexi, किया,
  { {0x66e4000a,0x645c3f99,0x31600058,0x00000000}},	//   _моја, aari, fsiz_,
  { {0x645c0551,0xe29f0026,0x765d03f9,0x00000000}},	// [7310] bari, _vað_, masy,
  { {0x44990b62,0x765d3f9a,0x645c2443,0x00000000}},	//   _свою_, lasy, cari,
  { {0x32070051,0x656f3f9b,0x2fc73f9c,0x00000000}},	//   łny_, lrch, âng_,
  { {0x765d3f9d,0x3f81264c,0x25a600c2,0x00000000}},	//   nasy, rthu_, _šoli_,
  { {0x6da5019d,0x8c450c8d,0xf6780047,0x00000000}},	//   сила, беле, שײדט_,
  { {0x66f2001c,0x395f0019,0x656f0b92,0x00000000}},	//   rāki, vsus_, irch,
  { {0x765d28c0,0x3946017d,0x66e400ea,0x00000000}},	//   kasy, _atos_, sőki,
  { {0x395f0004,0xc3340063,0x765d0089,0x00000000}},	//   tsus_, חוק_, jasy,
  { {0xf9910032,0x645c18b1,0x44240013,0x00000000}},	//   سبة_, yari, ̀m_,
  { {0x71d80063,0x645c1997,0x395f3f9e,0x00000000}},	//   יוחד_, xari, rsus_,
  { {0x395f2464,0x39460150,0x69d60058,0x00000000}},	//   ssus_, _etos_, _üyen,
  { {0x765d04d2,0x2b810051,0x6d4b00b9,0x00000000}},	//   gasy, móc_, opga,
  { {0x7afe11ba,0xa9690713,0x26de0078,0x00000000}},	//   épte, _сила_, ėto_,
  { {0x984b0076,0x644e0d2e,0x645c053c,0x00000000}},	//   _ряда_, ubbi, uari,
  { {0x645c3f9f,0xf789006c,0xdb03017c,0x00000000}},	//   rari, _deçà_, evné,
  { {0x3160005b,0x645c3fa0,0x39400139,0x00000000}},	//   tsiz_, sari, _éisc_,
  { {0x645c3fa1,0x80662049,0x22593fa2,0x00000000}},	// [7320] pari, йваж, _desk_,
  { {0x316001f7,0x20ca0044,0x98c9009d,0x00000000}},	//   rsiz_, دبري_, נֶּ֥,
  { {0x44440034,0xbbb60053,0xa85a0047,0x00000000}},	//   _if_, _अपेक, רדעכ,
  { {0xe8e0008b,0x69c600d1,0x539b0063,0x00000000}},	//   _thủy_, økek, _עיכו,
  { {0x2cea0055,0xa3c20042,0xdbdc01d1,0x00000000}},	//   лько_, ्नक_, rším,
  { {0x3ea00080,0x765d01f7,0x44443fa3,0x00000000}},	//   žit_, zasy, _jf_,
  { {0x44443fa4,0x66f2001c,0x765d0058,0x00000000}},	//   _mf_, lāku, yasy,
  { {0x656f0185,0xdee60001,0xc3330063,0x00000000}},	//   yrch, _уоби, הוה_,
  { {0x44443fa5,0x66f2003d,0x38c8006a,0x00000000}},	//   _of_, nāku, لادی_,
  { {0xdd8f007e,0x765d00a4,0x656f027d,0x00000000}},	//   _سوم_, wasy, vrch,
  { {0xa3e80161,0x765d28c0,0x6f0d00dd,0x00000000}},	//   _मेल_, tasy, _încî,
  { {0x44443fa6,0xdb0e0072,0x66f20023,0x00000000}},	//   _af_, äjäk, kāku,
  { {0x394600a4,0x7d0a00ac,0x656f20df,0x00000000}},	//   _utos_, oofs, urch,
  { {0x765d002c,0x98a30cb5,0x897b0063,0x00000000}},	//   sasy, _ниче, _ערוצ,
  { {0x765d002c,0xdceb003b,0xed5f0078,0x00000000}},	//   pasy, lugă, ėžia_,
  { {0x44443fa7,0x2ba90161,0xd258000d,0x00000000}},	//   _ef_, किता, йцу_,
  { {0x64400022,0x44443fa8,0x66f20023,0x00000000}},	// [7330] śmia, _ff_, gāku,
  { {0x88bc0080,0x39820026,0xa0a7005e,0x00000000}},	//   změn, iðs_, љшал,
  { {0x6235000a,0xa227007e,0xdb08013d,0x00000000}},	//   _мену, _گرده, _erdé,
  { {0x66f2001c,0x6aa20139,0xbbe9005d,0x00000000}},	//   bāku, _naof, یرغم_,
  { {0xbebd0078,0xa69c0041,0x7d6b13a2,0x00000000}},	//   _siūs, טשאפ, ушев_,
  { {0xdb090066,0x98a700dd,0x4f5b0593,0x00000000}},	//   ľníc, _mină_, _مجرد_,
  { {0xfd1000b3,0x8c3c0058,0xaed50054,0x00000000}},	//   رجه_, _sağc, _довш,
  { {0x6d4b00d1,0x527c0047,0x66f2001c,0x00000000}},	//   ppga, ָנזא, nākt,
  { {0x69d601f7,0x49950054,0x99dd01c8,0x00000000}},	//   _üyel, ішит, ybňu,
  { {0xe6c5017f,0x1869018e,0xdd0e005b,0x00000000}},	//   _češć, јани_, mışl,
  { {0xa3e80053,0x6d44000c,0x66f2008f,0x00000000}},	//   _में_, ţiat, zāku,
  { {0xd62a0184,0x44443fa9,0x60c70075,0x00000000}},	//   ионе_, _sf_, _lojm,
  { {0xdd0e005b,0x44443faa,0x98a700dd,0x00000000}},	//   nışl, _pf_, _cină_,
  { {0x394d3fab,0x6aa20022,0x8c3c0058,0x00000000}},	//   mpes_, _zaof, _kağa,
  { {0xd3720032,0x394d0530,0xd3b90054,0x00000000}},	//   ظهر_, lpes_, буті_,
  { {0x25b502dd,0x8c3c005b,0x98af003b,0x00000000}},	//   ñaló_, _mağa, _fugă_,
  { {0x64a60088,0x78a31fdc,0x463b0047,0x00000000}},	// [7340] _дапа, _kanv, _דעפע,
  { {0x66f2001c,0x78a33fac,0xe8e0008b,0x00000000}},	//   rāku, _janv, _thụy_,
  { {0x66f2001c,0xee3a3fad,0x4fea0002,0x00000000}},	//   sāku, ане_, јмен_,
  { {0x2fc700c7,0x249800cd,0x88bc004c,0x00000000}},	//   änga_, lerm_, eměl,
  { {0x22650080,0x78a30137,0x7d0a00f5,0x00000000}},	//   řský_, _oanv, tofs,
  { {0x6d490027,0x361b0047,0xa7fc0058,0x00000000}},	//   _dtea, בונד, rgız,
  { {0xdfd20067,0x3d090053,0x66f2008f,0x00000000}},	//   _غير_, ाक़े_, nāks,
  { {0x78a30102,0x24980122,0xff070002,0x00000000}},	//   _aanv, herm_, _деск_,
  { {0x249800e8,0x78a3181a,0x00000000,0x00000000}},	//   kerm_, _banv,   ,
  { {0x236500c3,0x39820026,0x78a3233a,0x00000000}},	//   šlji_, rðs_, _canv,
  { {0x2a66005a,0x394d3fae,0x3ea63faf,0x00000000}},	//   _дълг, apes_, odot_,
  { {0x3ea63fb0,0xd6d90051,0xb9c60044,0x00000000}},	//   ndot_, ół_, _وتشه,
  { {0x2d8600e8,0x3ea6001c,0x26070086,0x00000000}},	//   ntoe_, idot_, ючог,
  { {0x3ea6024a,0x98a7003b,0x96340085,0x00000000}},	//   hdot_, _vină_, ьняц,
  { {0x290c0dd1,0x92c70edb,0xd25b202f,0x00000000}},	//   moda_, ощад, ица_,
  { {0x290c001c,0xdd0e0058,0x236d3fb1,0x00000000}},	//   loda_, yışl, čej_,
  { {0x2d8600ac,0x60c70ffc,0x91750085,0x00000000}},	// [7350] jtoe_, _pojm, ягац,
  { {0x3ea600fe,0x66f2001c,0x290c3fb2,0x00000000}},	//   edot_, sākt, noda_,
  { {0xc49a0063,0x6d493fb3,0x649a009a,0x00000000}},	//   _השתת, _stea, _הסתד,
  { {0xfba90161,0xd7bb0047,0xdd0e005b,0x00000000}},	//   किसम, יצבר, tışl,
  { {0xdd9b0690,0x81680062,0x8c3c0058,0x00000000}},	//   рше_, _мррб_, _sağa,
  { {0xece80086,0x113a0063,0xaaa30053,0x00000000}},	//   оділ_, _לתשל, _खोजक,
  { {0x78a33fb4,0x290c3fb5,0x600802dc,0x00000000}},	//   _ranv, doda_, _днём_,
  { {0x93fc0063,0x26c900dd,0x88bc004c,0x00000000}},	//   ילוי, _noao_, směl,
  { {0x394d03b2,0x9915000d,0x78a30066,0x00000000}},	//   upes_, зьні, _panv,
  { {0x394d3fb6,0x290c3fb7,0xedb40044,0x00000000}},	//   rpes_, goda_, _تحفظ,
  { {0x9f45024a,0xaa950086,0xd70a007f,0x00000000}},	//   _älä_, _нижч, йное_,
  { {0x66da005a,0x394d0b40,0x8c1a009a,0x00000000}},	//   сьор_, ppes_, _הועי,
  { {0xf3f7008b,0x2ca505b9,0x24983fb8,0x00000000}},	//   ộng_, _kald_, term_,
  { {0x7afb3fb9,0x27f6004c,0x1dac0042,0x00000000}},	//   lnut, ádná_, चितत,
  { {0x69c600d1,0xe8d6009f,0x74160043,0x00000000}},	//   økev, _מוסר_, سورا,
  { {0x3636007e,0xf65f00b9,0x66f2001c,0x00000000}},	//   _عربس, skær_, rāks,
  { {0xe0da005a,0x867b0063,0xdb0100c7,0x00000000}},	// [7360] бва_, _הרפו, _irlä,
  { {0x7afb01d9,0x3ea406a3,0xa0a3019c,0x00000000}},	//   hnut, _samt_, науд,
  { {0x7afb04c8,0x645e3fba,0x643b009a,0x00000000}},	//   knut, _iepi, _לעינ,
  { {0x290c007c,0x3ea6008f,0x4ea302dc,0x00000000}},	//   zoda_, udot_, ерша,
  { {0x1ea90021,0x645e3fbb,0x2ca50359,0x00000000}},	//   تالي_, _kepi, _bald_,
  { {0xeaf60161,0x2d860173,0x361b0047,0x00000000}},	//   ुक्त_, rtoe_, זונד,
  { {0x290c1ba3,0x690f01e1,0x273a005f,0x00000000}},	//   voda_, yøer, _kūne_,
  { {0x645e3fbc,0x7afb017f,0x290c0022,0x00000000}},	//   _lepi, gnut, woda_,
  { {0x2ca50146,0x61e43fbd,0x290c3fbe,0x00000000}},	//   _fald_, nzil, toda_,
  { {0x645e003d,0x4c830062,0x290c0b4e,0x00000000}},	//   _nepi, _плув, uoda_,
  { {0xd7f70076,0x290c3fbf,0x7afb3fc0,0x00000000}},	//   зуя_, roda_, bnut,
  { {0x7e62006f,0xaa570021,0x5b570047,0x00000000}},	//   naop, _فلما_, _זשאן_,
  { {0x690f00b9,0x61e4013d,0x290c3fc1,0x00000000}},	//   røer, jzil, poda_,
  { {0x690f00b9,0xdb0100bd,0x29370047,0x00000000}},	//   søer, _erlä, _זאגן_,
  { {0x7e620035,0x026b000d,0x98a3005e,0x00000000}},	//   kaop, йшай_, _чије,
  { {0x381701f9,0xba3d0080,0x82a40085,0x00000000}},	//   _מקום_, jdůl, ншуе,
  { {0x3ced0053,0xf1940b3f,0x777a01a8,0x00000000}},	// [7370] _अगले_, нить, lutx,
  { {0x66f2008f,0x91e4005e,0xd8b90041,0x00000000}},	//   lākp, хође, ֿצײכ,
  { {0xdb080331,0x7afb017c,0x75d5005d,0x00000000}},	//   _ardí, ynut, _ريگا,
  { {0xa9230006,0x7d18000e,0xbdf502d8,0x00000000}},	//   ėžim, elvs, мпеј,
  { {0x69c60072,0x71a40085,0xdca50c46,0x00000000}},	//   äkel, _заўз, дали,
  { {0x88bc0080,0xdb03004c,0x8e080054,0x00000000}},	//   směj, rvní, чнів_,
  { {0x2ca53fc2,0x786900ea,0x7afb041a,0x00000000}},	//   _vald_, _jövő, tnut,
  { {0x61220164,0x2ca500bd,0xfe6e007e,0x00000000}},	//   rôle, _wald_, _نگه_,
  { {0x68ef00cd,0x6f19002b,0xd6e00022,0x00000000}},	//   ècdo, mlwc, ółmi_,
  { {0x6f190185,0x7afb3fc3,0xe1ff013d,0x00000000}},	//   llwc, snut, _adók_,
  { {0x645e1ffa,0x443a0150,0x7afb004a,0x00000000}},	//   _repi, _rgp_, pnut,
  { {0x6ab4000d,0x645e3fc4,0x443a3fc5,0x00000000}},	//   _псіх, _sepi, _sgp_,
  { {0x1869295e,0x69c600d1,0x443a3fc6,0x00000000}},	//   _дали_, øket, _pgp_,
  { {0x2a7f3fc7,0x6aa93fc8,0x61e40058,0x00000000}},	//   lgub_, ldef, vzil,
  { {0xdc450006,0x672400ca,0x645e004c,0x00000000}},	//   jūči, _thij, _vepi,
  { {0x6aa93fc9,0xe57a0330,0xd808009a,0x00000000}},	//   ndef, _дзи_, _מִפָ,
  { {0x8c3c01f7,0x7989006f,0x645e3fca,0x00000000}},	// [7380] _bağl, ntew, _tepi,
  { {0x61e43dbe,0x6f19002b,0x79890022,0x00000000}},	//   rzil, elwc, itew,
  { {0x6f19001f,0x8c3c005b,0x6fd5000d,0x00000000}},	//   flwc, _dağl, ніцц,
  { {0xf42a024a,0x7989006f,0xfe720044,0x00000000}},	//   _enää_, ktew, ئدا_,
  { {0x7e620093,0x6aa93fcb,0xdd9001fb,0x00000000}},	//   raop, ddef, اوت_,
  { {0x6aa92864,0x6f19002b,0x69c60ef1,0x00000000}},	//   edef, alwc, äkem,
  { {0x8f750086,0xf767007e,0xbb470021,0x00000000}},	//   _путі, _جا_, ولون_,
  { {0xf96a0076,0x6aa900ca,0xff24005d,0x00000000}},	//   орой_, gdef, _سبزی,
  { {0x7989021f,0xf53f00d1,0x7e6025b5,0x00000000}},	//   gtew, rvåk_, _iemp,
  { {0x41bb0047,0x7e603fcc,0x6ab9002b,0x00000000}},	//   קציע, _hemp, _enwf,
  { {0x7e602a53,0xd83802e2,0x6d4003e1,0x00000000}},	//   _kemp, ječe_, _huma,
  { {0xd83800c3,0x7e60299c,0x69c600d1,0x00000000}},	//   deče_, _jemp, økes,
  { {0x7e600e53,0x94ab0062,0x6d403fcd,0x00000000}},	//   _memp, отва_, _juma,
  { {0x777a01a8,0x7e60090b,0x28a60042,0x00000000}},	//   putx, _lemp, _कोचि,
  { {0x6d403fce,0xa2950088,0x3d160053,0x00000000}},	//   _luma, наві, _पीछे_,
  { {0x8c3c01f7,0x9294000d,0xa294014b,0x00000000}},	//   _sağl, касц, касі,
  { {0x26d900eb,0x914b0062,0x6d403fcf,0x00000000}},	// [7390] ūros_, ючва_, _numa,
  { {0x6e3b002b,0x2a7f00a8,0x628d002b,0x00000000}},	//   _sgub, zgub_, sfao,
  { {0x8cc20042,0x6d401775,0xe610005d,0x00000000}},	//   लानो, _auma, _مشی_,
  { {0x6d4000bb,0x7e600089,0x2455005d,0x00000000}},	//   _buma, _cemp, _تنگس,
  { {0x657d3839,0x6d403fd0,0x7e603fd1,0x00000000}},	//   nush, _cuma, _demp,
  { {0x6d403fd2,0xee380054,0xdcbb030b,0x00000000}},	//   _duma, фні_, юще_,
  { {0x657d0035,0xfc640062,0xeb91007e,0x00000000}},	//   hush, тъчн, اظت_,
  { {0x657d0035,0x7e60003e,0x63a800b9,0x00000000}},	//   kush, _gemp, ædni,
  { {0x6d400273,0xee84000d,0x6aa93fd3,0x00000000}},	//   _guma, _шыро, rdef,
  { {0x47c50076,0x7b31001c,0x657d004b,0x00000000}},	//   ебов, _jāuz, dush,
  { {0x69c60031,0x6d40004d,0x7e6000ac,0x00000000}},	//   øker, _zuma, _yemp,
  { {0x68e6008f,0x7e603fd4,0x3a540085,0x00000000}},	//   īkda, _xemp, _акцё,
  { {0x58d50bed,0x15ba000d,0x657d3fd5,0x00000000}},	//   _подт, чыны_, gush,
  { {0x09f60063,0x26d93fd6,0x98a20002,0x00000000}},	//   _אמנם_, akso_, _бише,
  { {0xd8381253,0x232a058f,0x08760041,0x00000000}},	//   teče_, зови_, _טעסט_,
  { {0x97d80032,0x8c3c005b,0x657d1f51,0x00000000}},	//   _تظهر_, _rağm, bush,
  { {0xd3350088,0x7e603fd7,0xe0da0062,0x00000000}},	// [73a0] тэры, _remp, пва_,
  { {0x6d400397,0x7e603fd8,0x63bb004c,0x00000000}},	//   _ruma, _semp, ácný,
  { {0x6d403fd9,0x7e603fda,0x4f7a0121,0x00000000}},	//   _suma, _pemp, ящая_,
  { {0x6d4000bb,0x040b001b,0x9daa0062,0x00000000}},	//   _puma, _lượn, зъка_,
  { {0xe2a60014,0x7e600072,0xb5fb0046,0x00000000}},	//   öðun_, _vemp, jaál,
  { {0xdc870062,0xeb180042,0x10160085,0x00000000}},	//   есъл_, दत्त_, _зьбя,
  { {0x91032c47,0x7e603fdb,0xc4d30063,0x00000000}},	//   _спре, _temp, רגו_,
  { {0x6d403e6b,0x657d0d7c,0xada63fdc,0x00000000}},	//   _tuma, yush, _пабл,
  { {0xb9970055,0x6d400ddd,0x828b0063,0x00000000}},	//   евых_, _uuma, הְיֶ,
  { {0x49730088,0x657d004b,0x58d40121,0x00000000}},	//   ыльс, vush, тоот,
  { {0x273a0006,0x5cf50086,0x9cd7009a,0x00000000}},	//   _būna_, _ряту, _רובה_,
  { {0x09e6018e,0x657d003a,0x7bdb0063,0x00000000}},	//   _поен, tush, _מקבו,
  { {0x1af70047,0x5507000d,0xe9730049,0x00000000}},	//   _אמאל_, ечва, _مهند,
  { {0x62860137,0x93c3003b,0x657d3fdd,0x00000000}},	//   _acko, ţămi, rush,
  { {0x25bf000c,0xad1b0063,0xb5fb0014,0x00000000}},	//   ţul_, פולר, maám,
  { {0x41e70097,0x78aa0137,0x32190072,0x00000000}},	//   ніза, _hafv, _pysy_,
  { {0x8b03004c,0x60ce002b,0x69c60072,0x00000000}},	// [73b0] ířil, _bobm, äkeh,
  { {0xd564005a,0x1007047e,0x52140086,0x00000000}},	//   _стъп, няем, удут,
  { {0xc1040032,0xb5fb00ea,0x7fb904a0,0x00000000}},	//   دولي, zaál, بهار_,
  { {0x61220003,0xb1840061,0xd3560063,0x00000000}},	//   rôla, šťas, _שירי_,
  { {0xada5014c,0xee2e0366,0x6da50888,0x00000000}},	//   талл, рн_, тила,
  { {0xd3780117,0x3ea90130,0x8b95030b,0x00000000}},	//   šće_, žat_, врич,
  { {0xeab10044,0xe4ac009a,0xac1601ce,0x00000000}},	//   لعة_, לֹהָ, кољу_,
  { {0x9f340054,0x7b44007e,0x8f343fde,0x00000000}},	//   _бесі, دئول, _бесц,
  { {0x69c60031,0xf400000c,0x2f1500c7,0x00000000}},	//   økep, ăţii_, sågs_,
  { {0x2903004b,0xadf4007b,0x8e380044,0x00000000}},	//   õja_, _спуш, _أسفر_,
  { {0x040b0013,0x38780014,0x656d004e,0x00000000}},	//   _vượn, órra_, _avah,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x040b001b,0x38ca005d,0xe9ce2047,0x00000000}},	//   _tượn, سایی_, _тк_,
  { {0xe9d80097,0x64a60001,0x3afa008f,0x00000000}},	//   _які_, њава, rūpe_,
  { {0x58f60063,0x63860062,0x398b01f2,0x00000000}},	//   _במסע_, ъгва, løs_,
  { {0x06f6006a,0xe29701f6,0x00000000,0x00000000}},	//   _جستج, кас_,   ,
  { {0x61430062,0xa5263fdf,0x21671f88,0x00000000}},	// [73c0] иета, _имид, кити_,
  { {0x62330001,0x6aab08e9,0x00e30085,0x00000000}},	//   ређу, _lagf, ажун,
  { {0xdd1c0024,0xb47900b5,0x44770047,0x00000000}},	//   _nášh, _אָרי, _בעיל_,
  { {0xad660021,0x6aad0014,0x00000000,0x00000000}},	//   ناته, _óafh,   ,
  { {0xcd2a007e,0x5de60062,0xdee30002,0x00000000}},	//   وستن_, ъжда, шоци,
  { {0x2b5e0089,0x60260085,0x98a7011b,0x00000000}},	//   _pwtc_, _адга, _vině_,
  { {0x8bc3005a,0x62840d49,0x9c450085,0x00000000}},	//   исъд, ogio, ухіл,
  { {0xd83800c2,0x6284206f,0x2b55007e,0x00000000}},	//   ječa_, ngio, ایند_,
  { {0xbd8a006a,0xd83800c2,0x49380121,0x00000000}},	//   _زنان_, deča_, нзию_,
  { {0xd7fa0817,0x88bc004c,0x6f021959,0x00000000}},	//   дум_, jmět, lnoc,
  { {0x88bc0080,0x6f0204d0,0x6aab01f2,0x00000000}},	//   dmět, onoc, _fagf,
  { {0x6f023fe0,0xd5ed0013,0x2cac013d,0x00000000}},	//   nnoc, _nbạ, _hadd_,
  { {0x6f023fe1,0x272b008d,0xe8943fe2,0x00000000}},	//   inoc, hùng_, _баль,
  { {0x6f023fe3,0x7ae22198,0x62843fe4,0x00000000}},	//   hnoc, _hlot, egio,
  { {0x2418014c,0xf7430002,0x44250246,0x00000000}},	//   воры_, _кејо, ål_,
  { {0x628402f6,0x69d6005b,0x6aa000b9,0x00000000}},	//   ggio, _üyes, nemf,
  { {0x7bd80006,0x2ee6004d,0x2aea0053,0x00000000}},	// [73d0] hyvu, dhof_, जोएँ_,
  { {0x273b0006,0x62840453,0x7ae200cd,0x00000000}},	//   _kūno_, agio, _llot,
  { {0xa3d5000a,0x291e00fe,0xe1ff013d,0x00000000}},	//   _сонч, ilta_, _adót_,
  { {0x612b0019,0x522701f8,0x8f142049,0x00000000}},	//   külg, _афга, афіч,
  { {0x6aab002b,0xa91d3fe5,0xc332009a,0x00000000}},	//   _ragf, stži, _לוט_,
  { {0xe7c20042,0x3eba008f,0xe80b0042,0x00000000}},	//   षमाप, ēpta_, _सुझा_,
  { {0x30a40062,0x7ae23fe6,0x7c840084,0x00000000}},	//   _тряв, _blot, руче,
  { {0xdd1c034d,0x7ae20034,0x88bc0080,0x00000000}},	//   _vášh, _clot, změt,
  { {0xd83800c3,0xa91d0080,0x7c94005d,0x00000000}},	//   veča_, huže, _چشما,
  { {0x7ae23a62,0xddc9003b,0x07a5005e,0x00000000}},	//   _elot, _edeţ, гаон,
  { {0xc7b8000d,0x25a91324,0x6284001f,0x00000000}},	//   вёў_, _asal_, ygio,
  { {0xa91d017f,0xa6830ac5,0x291e3fe7,0x00000000}},	//   duže, блюд, alta_,
  { {0x55f6093e,0xd83800a8,0x5a440085,0x00000000}},	//   учну, reča_, _тэха,
  { {0xdce91035,0x612b0058,0x7ae23fe8,0x00000000}},	//   _oveč, nüld, _zlot,
  { {0xdb010016,0x7d0317d3,0xb69b003b,0x00000000}},	//   _islâ, inns, mnân,
  { {0xe355000d,0x9c7c017c,0x612b0244,0x00000000}},	//   ртрэ, _mlča, hüld,
  { {0x612b000f,0xb69b003b,0x6d44003b,0x00000000}},	// [73e0] küld, onân, ţiaz,
  { {0x3ebf0150,0x61220003,0x26d20331,0x00000000}},	//   _anut_, rôlo, _hoyo_,
  { {0x2cac001f,0xd12f0021,0x58f60047,0x00000000}},	//   _radd_, أمل_, נצען_,
  { {0x2bb5008b,0x26d20150,0x91e60854,0x00000000}},	//   _ích_, _joyo_, _боме,
  { {0x78a13fe9,0x2ee60518,0x645c3fea,0x00000000}},	//   kelv, rhof_, obri,
  { {0x7bd800eb,0xfbaa0076,0x2ee63feb,0x00000000}},	//   tyvu, етий_, shof_,
  { {0x2d8f0268,0xafe60940,0x645c3fec,0x00000000}},	//   atge_, _совл, ibri,
  { {0x79800009,0x7d033fed,0x3ead00ca,0x00000000}},	//   tumw, anns, _gaet_,
  { {0x88bc0080,0xdce900b2,0x7ae20229,0x00000000}},	//   dměr, _zveč, _vlot,
  { {0x78a128ac,0xb69b00be,0xa3c50082,0x00000000}},	//   gelv, gnân, _ऎपल_,
  { {0x645c1bb0,0x6ecb0053,0x7ae2002b,0x00000000}},	//   dbri, _सचमु, _tlot,
  { {0x7c2500bd,0xa6350086,0x7ae234cf,0x00000000}},	//   ühre, инні, _ulot,
  { {0xab630051,0xd7c7007e,0x645c252f,0x00000000}},	//   ążen, نویه_, fbri,
  { {0xa91d017f,0xc9530063,0x97a618ea,0x00000000}},	//   tuže, _המס_, _брил,
  { {0x2419014c,0x612b0b91,0xf76f00de,0x00000000}},	//   товы_, nüle, _فاي_,
  { {0xddc00080,0xa91d164c,0xdb01017d,0x00000000}},	//   _nemů, ruže, _islã,
  { {0x394600eb,0x645c051e,0x612b00bd,0x00000000}},	// [73f0] _juos_, bbri, hüle,
  { {0xd3780117,0x3d0e0053,0x656f0c84,0x00000000}},	//   šća_, ाकों_, msch,
  { {0x656f0c84,0x332001a8,0x92953fee,0x00000000}},	//   lsch, blix_, _канц,
  { {0x7d1a0004,0xde950001,0x628a00ea,0x00000000}},	//   _akts, радњ, őfor,
  { {0x656f1d07,0x9e640086,0x78a100ea,0x00000000}},	//   nsch, свід, yelv,
  { {0xd83800c3,0x88bc0080,0x656f3fef,0x00000000}},	//   ječo_, změr, isch,
  { {0x656f00bd,0x612b3ff0,0xd83800c2,0x00000000}},	//   hsch, rüld, dečo_,
  { {0x645c02e2,0x656f0d13,0x2fc7004b,0x00000000}},	//   zbri, ksch, ängu_,
  { {0x656f006f,0x7e6b00a4,0x9c870242,0x00000000}},	//   jsch, magp, _مشاه,
  { {0x656f28e7,0x7e6b3e6d,0x78a13ff1,0x00000000}},	//   dsch, lagp, uelv,
  { {0xa91d017f,0x26d20089,0x78a1032e,0x00000000}},	//   tužb, _poyo_, relv,
  { {0x7e6b00a4,0x61ed006f,0x656f0c84,0x00000000}},	//   nagp, kzal, fsch,
  { {0x7ae90e3f,0x95830076,0x656f102c,0x00000000}},	//   mhet, оляе, gsch,
  { {0x7afb0006,0x88bc0080,0x6b83075a,0x00000000}},	//   liut, směr, oung,
  { {0x660d0502,0x26d20089,0x6b833ff2,0x00000000}},	//   _exak, _toyo_, nung,
  { {0x656f00bd,0x6b8305cc,0x7ae93522,0x00000000}},	//   bsch, iung, nhet,

  { {0x6b833ff3,0x216a0a36,0x612b0580,0x00000000}},	// [7400] hung, тизи_, züle,
  { {0x6b83028d,0x290500d1,0xf34a0002,0x00000000}},	//   kung, nnla_, _ипол_,
  { {0x6b830812,0x444400ea,0x747b0063,0x00000000}},	//   jung, _ig_, _בניג,
  { {0x6b833ff4,0x3eba008f,0x232a005e,0x00000000}},	//   dung, ēpto_, _јоми_,
  { {0x6f09017f,0x61ed0051,0x7ae90ed5,0x00000000}},	//   _djec, czal, dhet,
  { {0x6b8310ca,0x6f093789,0x7ae900ea,0x00000000}},	//   fung, _ejec, ehet,
  { {0x7afb051e,0x6d5900ac,0x2fc7089f,0x00000000}},	//   fiut, apwa, ängt_,
  { {0x7ae90707,0x7c2800c3,0x44440019,0x00000000}},	//   ghet, _vzdr, _lg_,
  { {0xe1ff3ff5,0x0c76007e,0x09060086,0x00000000}},	//   _león_, _نداد, ичом,
  { {0x4444099b,0x6b831b18,0x672d0035,0x00000000}},	//   _ng_, bung, _shaj,
  { {0x7d180a63,0xe7270086,0x61ed24b2,0x00000000}},	//   movs, иємн, zzal,
  { {0x4444016f,0x656f1d07,0x39460006,0x00000000}},	//   _ag_, tsch, _tuos_,
  { {0xd9540242,0x656f00bd,0x249a0089,0x00000000}},	//   _انتخ, usch, _bbpm_,
  { {0x656f2b9a,0xa4e40088,0xdb0d00fe,0x00000000}},	//   rsch, оўск, äköi,
  { {0x656f3ff6,0x32670169,0x44443ff7,0x00000000}},	//   ssch, итав, _dg_,
  { {0xd258131b,0x083b0063,0xf2c40086,0x00000000}},	//   ицу_, _בעול, осун,
  { {0x6b833ff8,0x9099005a,0x399000cd,0x00000000}},	// [7410] zung, лват_, nàs_,
  { {0x7ae900ea,0x6b830150,0xb69b017d,0x00000000}},	//   zhet, yung, inâm,
  { {0x7e6b00bb,0x7ae900cf,0x5f950cb2,0x00000000}},	//   tagp, yhet, сиет,
  { {0xb5fb017d,0xa3d00053,0xdb010124,0x00000000}},	//   mbáb, _वॅट_, _oslá,
  { {0x444430ff,0x1eea007e,0x612b00ea,0x00000000}},	//   _yg_, دونی_, rülb,
  { {0x7d183ff9,0x2fc70137,0xdc980054,0x00000000}},	//   govs, ängs_, ивчі_,
  { {0x7e6b00bb,0xee870076,0x6f090137,0x00000000}},	//   pagp, _вызо, _tjec,
  { {0x6f1b017f,0x6b833ffa,0x386c002b,0x00000000}},	//   _ukuc, rung, eadr_,
  { {0x7ae93ffb,0xdce90240,0x6b833ffc,0x00000000}},	//   rhet, _uveď, sung,
  { {0x6445001b,0x6b833ffd,0xfce4005e,0x00000000}},	//   _nghi, pung, _дођо,
  { {0x6d41002c,0x7e691293,0xe73a05c5,0x00000000}},	//   _iila, _keep, лео_,
  { {0xe5a6005a,0x6d411366,0x64453ffe,0x00000000}},	//   бими, _hila, _aghi,
  { {0x399000cd,0x6d413fff,0x19940085,0x00000000}},	//   càs_, _kila, _маця,
  { {0xdff90053,0xe1ff006d,0x6f19001f,0x00000000}},	//   ्पाद_, _peón_, howc,
  { {0xd3b50055,0x6d414000,0x6f190051,0x00000000}},	//   ость, _mila, kowc,
  { {0x44440051,0x61e90051,0x23090021,0x00000000}},	//   _wg_, _żela, لتقي_,
  { {0xf1aa007e,0x80c40053,0x9f490066,0x00000000}},	// [7420] دازه_, राले, ľkým_,
  { {0x6d4103f7,0x60d5003b,0x44444001,0x00000000}},	//   _nila, _cozm, _ug_,
  { {0xa25b017d,0x8236007e,0x0019000d,0x00000000}},	//   _inôn, _گردا, аўцы_,
  { {0x6d414002,0xddc0003b,0x6f190022,0x00000000}},	//   _aila, _nemţ, gowc,
  { {0x6d4118ab,0x7ce6007a,0x471b0047,0x00000000}},	//   _bila, _aðra, נונג,
  { {0xdcb1001b,0xb5fb0080,0x5c97000d,0x00000000}},	//   _cả_, lbác, йкія_,
  { {0x6d410397,0xcec30080,0x7d184003,0x00000000}},	//   _dila, áří_, rovs,
  { {0xa3b90235,0x39900268,0x6d414004,0x00000000}},	//   चित_, tàs_, _eila,
  { {0xdb1f00ea,0x6d4108c9,0xab630051,0x00000000}},	//   ívás, _fila, ążan,
  { {0x39900268,0x19a7005a,0xd8f80086,0x00000000}},	//   ràs_, стъп_, рної_,
  { {0xf98f006a,0x61300e77,0xb09b009a,0x00000000}},	//   وبی_, mäld, ניטר,
  { {0xa91d017f,0xa25b017d,0xf1bf00ea,0x00000000}},	//   ruža, _anôn, _szám_,
  { {0x2fc700aa,0xb5fb0566,0xda650044,0x00000000}},	//   ̣ng_, dbác, _ذاني,
  { {0x4427001b,0x38c8007e,0x612b066b,0x00000000}},	//   _ơn_, _خاصی_, küla,
  { {0x60d523d3,0x7af9002b,0x78b3004c,0x00000000}},	//   _rozm, _ymwt, řevá,
  { {0x92590079,0x612b0075,0x3fc9005d,0x00000000}},	//   раат_, düla, یدای_,
  { {0x60f90088,0x3ea60659,0xa3ce0053,0x00000000}},	// [7430] аная_, deot_, _शपथ_,
  { {0x7e694005,0x612b004b,0x44990200,0x00000000}},	//   _seep, füla, _твою_,
  { {0x6d41158d,0x2fc7008b,0x44274006,0x00000000}},	//   _rila, ãng_, _án_,
  { {0x6d410351,0x52a70021,0x3ea64007,0x00000000}},	//   _sila, _اصدق, geot_,
  { {0x6f191246,0xa91d007d,0x7e69004b,0x00000000}},	//   rowc, dužn, _veep,
  { {0x7e6900e5,0x7c870239,0xcd03004c,0x00000000}},	//   _weep, суде, _oběť_,
  { {0xd52d008b,0x7e69004b,0x6d414008,0x00000000}},	//   _mừn, _teep, _vila,
  { {0x6d410397,0xce94005a,0x788300ea,0x00000000}},	//   _wila, _насъ, kívü,
  { {0x6d41024a,0x4424001b,0xdcb1008b,0x00000000}},	//   _tila, ́m_, _tả_,
  { {0xb902000d,0xe8f91dd0,0xb5fb011b,0x00000000}},	//   дзьк, рло_, zbác,
  { {0x628f051e,0x25a01c23,0xed59007d,0x00000000}},	//   _occo, _spil_, _drže_,
  { {0xa91d4009,0x2ca7400a,0xc4c90063,0x00000000}},	//   drže, lend_, _בג_,
  { {0x2732008b,0x04b601d5,0xe6170e82,0x00000000}},	//   háng_, освя, ждя_,
  { {0x628f400b,0xdb1a109c,0x2ca71855,0x00000000}},	//   _acco, _artè, nend_,
  { {0x7d040025,0xd52d008b,0x443e0072,0x00000000}},	//   éisi, _dừn, ät_,
  { {0x2ca7400c,0x0326013c,0x4424008f,0x00000000}},	//   hend_, ідан, ām_,
  { {0xdb01092e,0x2ca70479,0xb5fb400d,0x00000000}},	// [7440] _islä, kend_, rbác,
  { {0x505a0088,0xddc000c3,0x2ca7400e,0x00000000}},	//   ршая_, _nemš, jend_,
  { {0x232a019d,0x61300137,0x2ca7400f,0x00000000}},	//   _вони_, väld, dend_,
  { {0xaec6000d,0x6130004d,0x479a0041,0x00000000}},	//   юбел, wäld, ייעס,
  { {0xc27b0063,0x2ca7081b,0x8236005d,0x00000000}},	//   _דרכי, fend_, _گرگا,
  { {0x6ca3005a,0x2ca72e38,0xcf5a0a91,0x00000000}},	//   дръж, gend_, _врач_,
  { {0x8236006a,0xe749008b,0x613000c7,0x00000000}},	//   _درگا, _sẵn_, räld,
  { {0xe0430054,0xed5a0002,0x2732013d,0x00000000}},	//   _інти, _воа_, nánd_,
  { {0x2ca700bd,0x6f0300cd,0x6e930021,0x00000000}},	//   bend_, ènce, _تلقا,
  { {0x20070051,0x2ca700e5,0x9c7c011b,0x00000000}},	//   źnie_, cend_, _mlčk,
  { {0x4c060021,0x612b013d,0xb5fb0046,0x00000000}},	//   _بِال, küln, jaár,
  { {0xdb1a00d1,0xb9c6014d,0xa91d4010,0x00000000}},	//   _orté, _وقاي, vrže,
  { {0xd6270021,0x6a9b009a,0x00000000,0x00000000}},	//   تعدي, _כשאנ,   ,
  { {0x3959017d,0x99fb0063,0xa91d004c,0x00000000}},	//   ísse_, _דפדפ, trže,
  { {0x926b000a,0xd52d0013,0xdb1a22e5,0x00000000}},	//   ираа_, _cứn, _arté,
  { {0xd8380117,0x25b0024a,0x2ca710ce,0x00000000}},	//   ječi_, ällä_, zend_,
  { {0xd52d008b,0xf194015a,0xd838085a,0x00000000}},	// [7450] _từn, мить, deči_,
  { {0x16010042,0x51f80085,0x9fe70043,0x00000000}},	//   _लेयर_, цную_, يساه,
  { {0x2ca74011,0xb4e70053,0x33ab0062,0x00000000}},	//   vend_, पसी_, _тъпо_,
  { {0x2ca70250,0x15ff0053,0x61300072,0x00000000}},	//   wend_, _उधार_, väle,
  { {0x7cef000e,0xa3b90053,0xddab02b3,0x00000000}},	//   _jørg, चिव_, ртел_,
  { {0x11da014e,0xf1bf1088,0x7d760021,0x00000000}},	//   _החשב, _irá_, أمور_,
  { {0x8c42000a,0x2ca73bd5,0xf1bf0066,0x00000000}},	//   неше, rend_, _hrá_,
  { {0xdd95000d,0x20c90053,0x05cb0053,0x00000000}},	//   _набы, रावध, ामाब,
  { {0xceb24012,0x2ca70c2e,0xdb0100b9,0x00000000}},	//   _אין_, pend_, _nslå,
  { {0xddcd0078,0x8bb70044,0x612b013d,0x00000000}},	//   škųj, _وإضا, züln,
  { {0x16010042,0x00000000,0x00000000,0x00000000}},	//   _लेबर_,   ,   ,
  { {0x68ea006f,0x6b9c004b,0x6d5b4013,0x00000000}},	//   _elfd, _ärga, _ktua,
  { {0x63be1aa5,0x6aa901f4,0x69dd004b,0x00000000}},	//   _srpn, meef, äsed,
  { {0x6aa90983,0xa8790047,0x395f374b,0x00000000}},	//   leef, _האַר, mpus_,
  { {0x7e7b007d,0x66e60769,0xe73a0af0,0x00000000}},	//   _odup, _нока, _лек_,
  { {0xdb01004d,0xf1bf0014,0x9343015b,0x00000000}},	//   _erlö, _brá_, енсе,
  { {0x612b00ea,0xd83800c2,0xa5f7005e,0x00000000}},	// [7460] rüln, veči_, _нећу_,
  { {0x15fb014e,0x395f4014,0xf6170063,0x00000000}},	//   _להפע, ipus_, _מחפש_,
  { {0x6d5b03d9,0xc2c60021,0x7c25004d,0x00000000}},	//   _atua, _فيدي, ührl,
  { {0xf1bf007a,0x2fc700c7,0xee3a293a,0x00000000}},	//   _frá_, ånga_, бне_,
  { {0x6d5b153e,0xd83802f7,0x69dd01e1,0x00000000}},	//   _ctua, reči_, øsel,
  { {0xd83800c3,0x64432025,0x6d5b0025,0x00000000}},	//   seči_, _únic, _dtua,
  { {0xb60600c2,0xab384015,0xa91d00c2,0x00000000}},	//   lošč, опку_, ružl,
  { {0x6aa94016,0x612b004d,0x2aaa080a,0x00000000}},	//   geef, hüll, стко_,
  { {0x612b0b42,0xe9e6082d,0x00000000,0x00000000}},	//   küll, яцко,   ,
  { {0x47780086,0x6f024017,0x7e7b0022,0x00000000}},	//   обою_, lioc, _zdup,
  { {0x7cef02ab,0x3f780368,0x78a806b1,0x00000000}},	//   _sørg, nču_, redv,
  { {0x6f024018,0xb60600a8,0x600b009a,0x00000000}},	//   nioc, košč, מִכְ,
  { {0x612b00bd,0xd7f8003b,0x2558004c,0x00000000}},	//   füll, mbăm_, vělý_,
  { {0xb60600c2,0x24580121,0x612b0075,0x00000000}},	//   došč, зарь_, güll,
  { {0x290c1310,0x291e08c9,0xdceb0078,0x00000000}},	//   mnda_, mota_, augė,
  { {0x53980086,0x291e4019,0xc2990085,0x00000000}},	//   явся_, lota_, ўках_,
  { {0x7cef02ab,0x63bc00c3,0x6f0224ae,0x00000000}},	// [7470] _høre, avrn, dioc,
  { {0x7cef0146,0x04670076,0x6b83001f,0x00000000}},	//   _køre, _этим, yrng,
  { {0x290c401a,0xc9170063,0x6d5b401b,0x00000000}},	//   inda_, לחמת_, _stua,
  { {0x6f02401c,0x9f4c00ea,0xb60600c2,0x00000000}},	//   gioc, álás_, bošč,
  { {0x3f78001c,0xdd9b0062,0x291e401d,0x00000000}},	//   aču_, сше_, kota_,
  { {0x69d60058,0x6aa900ca,0x291e401e,0x00000000}},	//   _üyey, weef, jota_,
  { {0xeb990055,0x612b0058,0xdbf1004c,0x00000000}},	//   ций_, nülm, přím,
  { {0xa91d04c9,0x290c401f,0x61300137,0x00000000}},	//   drža, enda_, mäla,
  { {0x6aa90d1e,0xe9a9007e,0xed580044,0x00000000}},	//   reef, تگان_, _فشلت_,
  { {0xd378007d,0x1e32007e,0xac940002,0x00000000}},	//   šći_, _شکنج, _пауш,
  { {0x395f000c,0xa91d00c2,0x16aa0e48,0x00000000}},	//   spus_, lužk, овни_,
  { {0x98a2001c,0xd838007d,0x7cef01f2,0x00000000}},	//   ēkā_, ječu_, _døre,
  { {0xdce9007d,0x7d030139,0xba740049,0x00000000}},	//   _cveć, oins, _سانت,
  { {0x58d40245,0x7cef31d4,0xb60600c2,0x00000000}},	//   _почт, _føre, vošč,
  { {0x7cef00b9,0x99e3017c,0x15434020,0x00000000}},	//   _gøre, ľňuj, терм,
  { {0x3947007a,0x99e3027d,0xdb010025,0x00000000}},	//   _hins_, žňuj, _bplé,
  { {0x50960001,0x45364021,0x7d034022,0x00000000}},	// [7480] дређ, _охот, kins,
  { {0xb60600c3,0x26c9007d,0x3947017e,0x00000000}},	//   rošč, _znao_, _jins_,
  { {0x4f7a0076,0xdc3c0066,0x3947243f,0x00000000}},	//   ющая_, _páči, _mins_,
  { {0xeda60086,0x4ea30d34,0xc7d60047,0x00000000}},	//   дшко, врша, וועי_,
  { {0x291e1fd2,0x290c161b,0x7bc1002b,0x00000000}},	//   yota_, ynda_, _arlu,
  { {0x2b46001f,0xdb0a06a5,0x7d034023,0x00000000}},	//   _sioc_, lvfø, gins,
  { {0x612b0019,0xe2080051,0x2b460139,0x00000000}},	//   külj, _wróć_, _pioc_,
  { {0xf27b0047,0x7cef000e,0x60dc1606,0x00000000}},	//   ֿריש, _røre, _horm,
  { {0x7d034024,0x7d040003,0x7cef06a5,0x00000000}},	//   bins, éiss, _søre,
  { {0xfbc6047e,0x290c4025,0x33200003,0x00000000}},	//   _обзо, unda_, hoix_,
  { {0x39470994,0xdce9017f,0xda7a005a,0x00000000}},	//   _dins_, _sveć, _дял_,
  { {0x3947007a,0x6d484026,0x386e002b,0x00000000}},	//   _eins_, _hida, _wefr_,
  { {0x39474027,0x60dc00ac,0x6d481964,0x00000000}},	//   _fins_, _oorm, _kida,
  { {0x60dc4028,0x612b0058,0x67244029,0x00000000}},	//   _norm, tülm, _ekij,
  { {0x6d480004,0x98a30001,0xdb01266a,0x00000000}},	//   _mida, _рије, _splé,
  { {0x26c90035,0x612b005b,0x753c00c2,0x00000000}},	//   _unao_, rülm, amrz,
  { {0xda0e0053,0xdce9007d,0xde8f0013,0x00000000}},	// [7490] ापित_, _uveć, hịch_,
  { {0x27320dcc,0x78ba061f,0x6d4806fb,0x00000000}},	//   mána_, ndtv, _nida,
  { {0xdb1a0814,0x7d03402a,0x2d86006f,0x00000000}},	//   _artí, vins, eroe_,
  { {0xff25007e,0x6d48402b,0x7d03402c,0x00000000}},	//   ربای, _aida, wins,
  { {0x6d48014f,0x61300137,0x2d860150,0x00000000}},	//   _bida, mäln, groe_,
  { {0x6d4803d9,0x7c2800e8,0x60dc402d,0x00000000}},	//   _cida, _bydr, _gorm,
  { {0x6d48402e,0x7c28002b,0x394700be,0x00000000}},	//   _dida, _cydr, _rins_,
  { {0x764d00bb,0x39470034,0x69c2402f,0x00000000}},	//   _ngay, _sins_, _broe,
  { {0xc9a60055,0x69c20185,0x7d032748,0x00000000}},	//   евые_, _croe, pins,
  { {0x27320080,0xa91d0240,0x6724007d,0x00000000}},	//   dána_, ouži, _skij,
  { {0x78b80290,0x3947109c,0x7c28002b,0x00000000}},	//   _davv, _vins_, _gydr,
  { {0x3947015e,0xf2df002b,0x6d484030,0x00000000}},	//   _wins_, _siân_, _zida,
  { {0x69c24031,0x612b00ea,0xa91d0066,0x00000000}},	//   _groe, rülj, huži,
  { {0x399932c9,0x7ae902ea,0x61e40050,0x00000000}},	//   mès_, lket, vyil,
  { {0x03a30076,0x39990110,0x46a60054,0x00000000}},	//   лиро, lès_, _зайв,
  { {0x67240035,0x61e400fe,0xa91d007d,0x00000000}},	//   _ukij, tyil, duži,
  { {0x656d0185,0x39991b84,0x6e290150,0x00000000}},	// [74a0] _gwah, nès_, _nyeb,
  { {0x42230f30,0xb5f70063,0x29054032,0x00000000}},	//   удув, _נציג_, nila_,
  { {0x4095005a,0xd00f0021,0x60dc4033,0x00000000}},	//   ъртт, ملك_, _vorm,
  { {0x6d484034,0x29054035,0xee3a180e,0x00000000}},	//   _sida, hila_, пне_,
  { {0x6d480551,0x29054036,0x867b0063,0x00000000}},	//   _pida, kila_, פרסו,
  { {0xd378017f,0xa91d4037,0x39990005,0x00000000}},	//   šću_, držo, dès_,
  { {0x6d484038,0x27320080,0x78b80290,0x00000000}},	//   _vida, zána_, _ravv,
  { {0x69c24039,0x39990813,0x8f9b0ee1,0x00000000}},	//   _proe, fès_, _מילי,
  { {0x6d480397,0x39990110,0x7c2812cc,0x00000000}},	//   _tida, gès_, _wydr,
  { {0x273202f4,0x69c20162,0x7c2802a8,0x00000000}},	//   vána_, _vroe, _tydr,
  { {0x28d20053,0xa09b0047,0x656d403a,0x00000000}},	//   ताबि, הייט, _swah,
  { {0x6aa20035,0x7ae9403b,0x69c2403c,0x00000000}},	//   _ubof, cket, _troe,
  { {0x916d00aa,0x95cb0138,0x39992203,0x00000000}},	//   _một_, чуна_, cès_,
  { {0x2732403d,0x2905403e,0xa91d01d1,0x00000000}},	//   rána_, cila_, yuži,
  { {0xd7ef20cf,0x9f470240,0x97a30085,0x00000000}},	//   _су_, šné_, _брыл,
  { {0xe60500de,0x00000000,0x00000000,0x00000000}},	//   _لِعَ,   ,   ,
  { {0x02e10235,0x657b0066,0x96b8005e,0x00000000}},	// [74b0] _नवीन, ýchľ, _чују_,
  { {0xa91d007d,0x6d4f0003,0x200700be,0x00000000}},	//   tuži, _écai, únio_,
  { {0x6130024a,0x2d800024,0x5f9506be,0x00000000}},	//   mäll, šiel_, тиет,
  { {0xa91d02e2,0x916d008b,0x2905403f,0x00000000}},	//   ruži, _cột_, zila_,
  { {0x7f491558,0xa91d0078,0x7ae90075,0x00000000}},	//   _vieq, suži, vket,
  { {0x7c84005e,0x399900c6,0x61300072,0x00000000}},	//   гуће, vès_, näll,
  { {0x6114005a,0x2905115a,0x7ae94040,0x00000000}},	//   _сдру, vila_, tket,
  { {0x63ba0146,0x39990110,0x290514ce,0x00000000}},	//   ætni, tès_, wila_,
  { {0x61301924,0x7ae9210c,0x29054041,0x00000000}},	//   käll, rket, tila_,
  { {0x3999155d,0x613000fe,0x3eaf4042,0x00000000}},	//   rès_, jäll, legt_,
  { {0x2d8f0117,0x8ae70086,0x2d8202fb,0x00000000}},	//   luge_, _підл, _åker_,
  { {0x399900cd,0x29054043,0x612b013d,0x00000000}},	//   pès_, sila_, sülh,
  { {0xd7f80529,0x613035e8,0xc8f5005a,0x00000000}},	//   ază_, fäll, _издъ,
  { {0x7c24095a,0x27f50044,0x6d88009d,0x00000000}},	//   şire, _لأبح, עָרְ,
  { {0xb8f50235,0x25a900e3,0xb4b20161,0x00000000}},	//   हा_, _epal_, _ऐसी_,
  { {0x2ed00053,0x2d8f004b,0x7c2c013d,0x00000000}},	//   _सचेत, kuge_, _önrő,
  { {0x9c7c00c3,0xdddb000c,0x434308ac,0x00000000}},	// [74c0] _hoče, _reuş, ретв,
  { {0xf0630001,0x9c7c29ef,0xd0590603,0x00000000}},	//   икуп, _koče, ерці_,
  { {0x2732004c,0x7bc7005f,0x8f760e74,0x00000000}},	//   náno_, _šjun, тузі,
  { {0x2d80001c,0x69c40006,0x9c7c00c2,0x00000000}},	//   šiem_, _šiem, _moče,
  { {0x9c7c00c3,0x7cef1262,0xada3027d,0x00000000}},	//   _loče, _søra, _naúč,
  { {0xed570138,0x27390024,0x61eb05b9,0x00000000}},	//   њој_, méne_, øgle,
  { {0x9c7c00c2,0xfce30002,0x1b770021,0x00000000}},	//   _noče, ројо, نصية_,
  { {0x27320080,0x2fc705b9,0x2b77005d,0x00000000}},	//   dáno_, ænge_, ئینگ_,
  { {0x645c006f,0xada60002,0x443f0013,0x00000000}},	//   kcri, _јазл, ̀u_,
  { {0x777a4044,0x98c60054,0x27160023,0x00000000}},	//   tstx, тсил, vāna_,
  { {0x6130024a,0x25a94045,0xeb9a0854,0x00000000}},	//   väll, _spal_, _цие_,
  { {0x0f7b0063,0x9c7c007c,0xb5fb0139,0x00000000}},	//   ורטל, _doče, lbái,
  { {0x613001e3,0x5963005a,0xceb30063,0x00000000}},	//   täll, _къща, ביר_,
  { {0x2716001c,0x612b00ea,0x89d70cac,0x00000000}},	//   rāna_, lülv, _جوهر_,
  { {0x68e70137,0x61300072,0x2458000d,0x00000000}},	//   öjde, räll, тась_,
  { {0x6130024a,0xdb08004d,0x32641ba1,0x00000000}},	//   säll, _erdö, итув,
  { {0x25a900a8,0x13a7005d,0xb5a40183,0x00000000}},	// [74d0] _upal_, رچگی_, _крэй,
  { {0x3eaf00bd,0xb147005d,0x00000000,0x00000000}},	//   wegt_, ئیسم_,   ,
  { {0x7cef00b9,0xdfa70021,0xfe73005d,0x00000000}},	//   _børn, ضحاي, لدش_,
  { {0x2d8f004b,0x97570aeb,0xa2640094,0x00000000}},	//   tuge_, דיאו_, _върл,
  { {0x27320080,0x3eaf04a7,0x7bde004b,0x00000000}},	//   záno_, regt_, äpun,
  { {0x2d8f4046,0x3e71008b,0x3eaf008f,0x00000000}},	//   ruge_, ạt_, segt_,
  { {0xac090088,0xeab10032,0x7cf400cd,0x00000000}},	//   энка_, معة_, _bàrb,
  { {0x273202f4,0x61300bda,0x8afc056c,0x00000000}},	//   váno_, jälj, _rtęc,
  { {0xdb1a00b9,0x6ca70021,0xca74005d,0x00000000}},	//   _ortæ, _لصال, شچنک,
  { {0xb4b20161,0x9c7c073e,0x798900ca,0x00000000}},	//   _ऐसे_, _poče, rrew,
  { {0xd70a0088,0xc5e90063,0x66e64047,0x00000000}},	//   енне_, _צד_, гона,
  { {0x7c2500bd,0x7cf400cd,0x2732011b,0x00000000}},	//   ühru, _vàre, ráno_,
  { {0xf9850062,0x29100014,0x98a505f1,0x00000000}},	//   _сгло, ðlað_, _биле,
  { {0x9c7c1035,0xa91d007d,0x7cf400cd,0x00000000}},	//   _toče, tužu, _tàre,
  { {0x29360047,0x6383000d,0x833a1a5c,0x00000000}},	//   _גאסן_, йгра, ечат_,
  { {0xa91d4048,0x82f50085,0x645c4049,0x00000000}},	//   ružu, ачуц, scri,
  { {0x645c006f,0x171b0041,0xa116005d,0x00000000}},	// [74e0] pcri, _רופע, هورت,
  { {0xa91d00c2,0x27390066,0x601a02d8,0x00000000}},	//   držk, réne_, нцер_,
  { {0x2055315e,0xa91d011b,0x90360e74,0x00000000}},	//   ртур, lužs, ухач,
  { {0xdb240058,0x6b9c004b,0x3f860445,0x00000000}},	//   örüy, _ärgi, čou_,
  { {0xfce60499,0x69dd0072,0xd1750766,0x00000000}},	//   лодо, äsel, _высы,
  { {0x412a0086,0x7bde00fe,0x672600ca,0x00000000}},	//   _чого_, äpuo, hokj,
  { {0xec690054,0xeb4a079f,0xeb971313,0x00000000}},	//   трік_, нчик_, гиј_,
  { {0x6296404a,0x3af11077,0xaba70049,0x00000000}},	//   ngyo, _pápa_, اهيم_,
  { {0x6130404b,0x7f3b0047,0x612b013d,0x00000000}},	//   välj, _טעלו, rülv,
  { {0xc19b0063,0xdd8f014d,0x81b70063,0x00000000}},	//   עשיי, _روم_, נהיג_,
  { {0x7c2500bd,0x98c3026c,0xf0930063,0x00000000}},	//   ührt, ссыл, זנת_,
  { {0x56940054,0x6d5d0003,0x28d20042,0x00000000}},	//   бают, _ésac, ताहि,
  { {0x15a80062,0x09e60054,0xceb3089e,0x00000000}},	//   лъри_, _щодн, זיר_,
  { {0x613000c7,0xf983005e,0x7a370054,0x00000000}},	//   sälj, _угљо, _спір_,
  { {0x7ae2404c,0x926b0002,0x7aa10042,0x00000000}},	//   _koot, ерза_, क्वॅ,
  { {0x20070051,0x7ae2004b,0xdce201d1,0x00000000}},	//   źnik_, _joot, dpoč,
  { {0x9f470080,0x9099005a,0x533405fb,0x00000000}},	// [74f0] ání_, кват_, сетт,
  { {0x7ae20b34,0x7bc8404d,0x98a70130,0x00000000}},	//   _loot, _ordu, čiću_,
  { {0x9f470080,0x7cef00d1,0xdcea004c,0x00000000}},	//   šní_, _søro, žnět,
  { {0xf1ca0066,0xef0e013c,0x7ae2404e,0x00000000}},	//   _stáť_, ім_, _noot,
  { {0x127a00b5,0xed4e000d,0xdce210f5,0x00000000}},	//   _בארע, жо_, apoč,
  { {0x612b00bd,0x55780047,0xbd450021,0x00000000}},	//   gült, רעגן_, جنتي,
  { {0x2bc50053,0x4c920001,0x7ae2404f,0x00000000}},	//   विधा, цијс, _boot,
  { {0xff07071f,0x59851902,0x7ae20168,0x00000000}},	//   _сягн, алиб, _coot,
  { {0x88d50088,0x2d8b0080,0x61300137,0x00000000}},	//   аўні, _íce_, fälh,
  { {0xa85500d7,0x3ebf4050,0xe9a80cac,0x00000000}},	//   штиј, _haut_, ادين_,
  { {0x7ae20399,0x3ebf3840,0xddc200c2,0x00000000}},	//   _foot, _kaut_, mboš,
  { {0x7ae206f8,0x79c90044,0x9f96009a,0x00000000}},	//   _goot, _لوصف_, סדרה_,
  { {0xdce20512,0x3ebf0397,0x8699000d,0x00000000}},	//   zpoč, _maut_, ытэт_,
  { {0x3ebf3ffc,0xdce20195,0xe45200de,0x00000000}},	//   _laut_, ypoč, تضح_,
  { {0xed59027c,0x7cef00d1,0x0446137a,0x00000000}},	//   _drži_, _rørl, ревн,
  { {0x68e34051,0xe3550088,0x16010053,0x00000000}},	//   _hond, стрэ, _लेकर_,
  { {0x26d200bb,0xa91d0006,0x68e34052,0x00000000}},	// [7500] _inyo_, erži, _kond,
  { {0x2739004a,0x68e304aa,0xa06a0930,0x00000000}},	//   ména_, _jond, тажа_,
  { {0x3ebf004d,0x68e307b9,0x31691358,0x00000000}},	//   _baut_, _mond, apaz_,
  { {0xbea6000d,0x3ebf003b,0xdb1a017d,0x00000000}},	//   радк, _caut_, _estê,
  { {0x26c00016,0x7ae2010e,0x8236007e,0x00000000}},	//   _maio_, _root, _خردا,
  { {0x68e34053,0x7ae24054,0x6da3005e,0x00000000}},	//   _nond, _soot, циља,
  { {0x3ebf03b2,0x26d20035,0x3af80080,0x00000000}},	//   _faut_, _onyo_, _lépe_,
  { {0xbab81dcc,0x68e3017d,0x9c7c027d,0x00000000}},	//   угих_, _aond, _doča,
  { {0xdcfb017f,0xdb0100b9,0xed5a02a1,0x00000000}},	//   _zvuč, _oplæ, _роз_,
  { {0x26d200bb,0x2918004b,0x6130004d,0x00000000}},	//   _anyo_, õra_, fäli,
  { {0x7ae2326f,0x68e34055,0x00570063,0x00000000}},	//   _toot, _dond, ישית_,
  { {0x6d4f0164,0xf803000d,0x7c3a4056,0x00000000}},	//   _écar, ічэн, _iztr,
  { {0x6f030994,0x26c50080,0x68e34057,0x00000000}},	//   ènci, ělo_, _fond,
  { {0x248d00bd,0x2bbd0053,0x628605b9,0x00000000}},	//   ßem_, ्मचा, _adko,
  { {0x290c4058,0x38cb005d,0x09b60042,0x00000000}},	//   mida_, _جانی_, _अनुय,
  { {0x68e302b0,0x26c00290,0x8c1b0063,0x00000000}},	//   _zond, _gaio_, דולי,
  { {0x3ea60137,0xdddb007d,0x3ebf0360,0x00000000}},	// [7510] dfot_, _oduš, _raut_,
  { {0x20670001,0x3ebf0003,0x290c4059,0x00000000}},	//   рђав, _saut_, nida_,
  { {0x90280088,0xa0540086,0x290c004e,0x00000000}},	//   ацца_, івці, iida_,
  { {0x9df90002,0x2bbd0053,0x290c405a,0x00000000}},	//   лнет_, ्मघा, hida_,
  { {0x3ebf0164,0xadbc0086,0x9c7c085a,0x00000000}},	//   _vaut_, кацi, _soča,
  { {0x9c7c405b,0xd57a0047,0x61ed306a,0x00000000}},	//   _poča, אָקר, myal,
  { {0x69c600b9,0x290c00c5,0x68e3405c,0x00000000}},	//   æken, dida_, _rond,
  { {0x68e3405d,0x6130003a,0xfbd003eb,0x00000000}},	//   _sond, väli, بته_,
  { {0x6f090035,0x61ed366f,0x26c0017d,0x00000000}},	//   _imec, nyal, _raio_,
  { {0xe8f6026c,0x9c7c007d,0x290c1117,0x00000000}},	//   йлы_, _toča, gida_,
  { {0xfbd00032,0x26c0405e,0x68e3405f,0x00000000}},	//   _يتم_, _paio_, _vond,
  { {0x68e32f7b,0x2d8f4060,0x290c4061,0x00000000}},	//   _wond, orge_, aida_,
  { {0x9c7c00c3,0x290c4062,0x68e34063,0x00000000}},	//   _močn, bida_, _tond,
  { {0x69cb00bd,0x64a60001,0x290c0b24,0x00000000}},	//   _irge, љава, cida_,
  { {0xa8a40002,0xf7460f55,0x6f0900be,0x00000000}},	//   _фрчк, _леко, _omec,
  { {0x61e21a14,0x443a004c,0x61ed0058,0x00000000}},	//   äolo, _vzp_, fyal,
  { {0xd5b1008b,0xe0560021,0x612b013d,0x00000000}},	// [7520] ắc_, مخاب, vülr,
  { {0xd83e00c3,0x6f090035,0x27320080,0x00000000}},	//   ščem_, _amec, dáni_,
  { {0x7afb00ac,0x9c7c09a0,0x287a0047,0x00000000}},	//   khut, _bočn, רנעמ,
  { {0x6e930032,0x290c4064,0x628600b9,0x00000000}},	//   كلما, zida_, _udko,
  { {0x9f47266a,0x27320013,0x7c3a013d,0x00000000}},	//   áná_, ránh_, _sztr,
  { {0xed59007d,0x290c00cd,0x3e4b0078,0x00000000}},	//   _duž_, xida_, dėtį_,
  { {0x290c4065,0x69cb2305,0x9f47004a,0x00000000}},	//   vida_, _arge, šná_,
  { {0x7c3a00c2,0xb69b0003,0x60170063,0x00000000}},	//   _vztr, niât, _החלף_,
  { {0x290c4062,0x00000000,0x00000000,0x00000000}},	//   tida_,   ,   ,
  { {0x290c197c,0x41bb0047,0x610f0078,0x00000000}},	//   uida_, נציע, _gėlė,
  { {0xda6f0088,0x69cb0995,0x290c4066,0x00000000}},	//   _ня_, _erge, rida_,
  { {0x290c2023,0xdc3b0047,0xc7f70086,0x00000000}},	//   sida_, _געבר, снює_,
  { {0xeb140161,0x290c0764,0xdd080066,0x00000000}},	//   तचीत_, pida_, _môžn,
  { {0xa99b0063,0x55580782,0x985c008f,0x00000000}},	//   _עבור, саря_, nāļi_,
  { {0xdb1a0153,0xa87b0063,0x7cef04aa,0x00000000}},	//   _asté, _גאור, _sørk,
  { {0x27390080,0x672d0035,0x61ed00ac,0x00000000}},	//   méno_, _ukaj, tyal,
  { {0x9c7c1625,0x7cef01e1,0x315b0044,0x00000000}},	// [7530] _ročn, _førh, اجرة_,
  { {0x27320080,0x61ed1bfe,0x46a50053,0x00000000}},	//   váni_, ryal, ग्रह,
  { {0xdfd10021,0xdb1a2319,0x61ed4067,0x00000000}},	//   بيا_, _esté, syal,
  { {0x61ed01f7,0x7cef0093,0x8e74000d,0x00000000}},	//   pyal, _tørk, пушч,
  { {0x2d760051,0x3d8b0121,0x7c240058,0x00000000}},	//   głe_, ущен_, şirl,
  { {0x27324068,0x2708013d,0x4aa60042,0x00000000}},	//   ráni_, tőnk_, क्सव,
  { {0x7afb00ac,0x9c7c01b3,0x7cfd00cd,0x00000000}},	//   thut, _točn, _lèrg,
  { {0x6f090035,0x7afb21a8,0xdd95000d,0x00000000}},	//   _umec, uhut, _мабы,
  { {0xda09007e,0x44330d41,0x7afb4069,0x00000000}},	//   شيده_, _lyx_, rhut,
  { {0x7e7b006f,0xa3cc0053,0x16b20053,0x00000000}},	//   _heup, लिम_, ज़्ब,
  { {0x7e7b00e3,0xf092014e,0x6d41005b,0x00000000}},	//   _keup, וני_, _ihla,
  { {0x6f19001f,0x78820080,0x9c7c00c2,0x00000000}},	//   nnwc, tíví, _ločl,
  { {0xf6260086,0x69cb406a,0x7c2d0058,0x00000000}},	//   ідго, _urge, şard,
  { {0x6d5b00fe,0x18690499,0x2a7f004d,0x00000000}},	//   _muua, _таки_, laub_,
  { {0x6d5b004b,0x7a0b008f,0x69c91d47,0x00000000}},	//   _luua, sētī, lvee,
  { {0xf26a0245,0x613000bd,0x7a0b008f,0x00000000}},	//   риал_, hält, pētī,
  { {0xb5fb006d,0x69c91817,0x3d1a0053,0x00000000}},	// [7540] lcán, nvee, _बदले_,
  { {0x61300ef1,0x7cef05a5,0x614602b6,0x00000000}},	//   jält, _føri, цеза,
  { {0x14d70047,0x09b60053,0x6f19002b,0x00000000}},	//   _וויל_, _अन्य, fnwc,
  { {0x0dca0612,0x8d6a007b,0x6d411af7,0x00000000}},	//   илей_, ајка_, _ahla,
  { {0x3dcd0be9,0x6d26000d,0x61300d88,0x00000000}},	//   _crew_, оддз, fält,
  { {0x3dcd0034,0x9c570001,0x7e62406a,0x00000000}},	//   _drew_, ошћу_, scop,
  { {0x69c92af9,0x6aa900d1,0x2d760022,0x00000000}},	//   evee, ffef, słe_,
  { {0x63bc002b,0x19aa0085,0x2d760022,0x00000000}},	//   iwrn, атоп_, płe_,
  { {0x3dcd0034,0xaaa60053,0xb5fb0331,0x00000000}},	//   _grew_, क्षक, ecán,
  { {0x998000eb,0x6d410027,0xd8f80086,0x00000000}},	//   _šių_, _ghla, сної_,
  { {0xe0b70063,0x9208008f,0x6c57009a,0x00000000}},	//   חליט_, liāļ, _ויבא_,
  { {0xf76f007e,0x7cfd01a8,0x87070085,0x00000000}},	//   کای_, _pèrg, іяне,
  { {0x6b550006,0xe3b80058,0xa874012c,0x00000000}},	//   _išga, çın_, _еллі,
  { {0x4aa60053,0x7c2d1c93,0x645a0078,0x00000000}},	//   क्रव, şare, žtin,
  { {0xd7e601dd,0xe454000d,0x61300137,0x00000000}},	//   _філо, дкры, häls,
  { {0x26c5008f,0x72d40f0a,0x92590131,0x00000000}},	//   ēlos_, мосф, саат_,
  { {0x67ff00ea,0xf2df002b,0x273201c8,0x00000000}},	// [7550] _tájé, _rhâd_, gánu_,
  { {0x306b0699,0x7ae60137,0x6d5b0072,0x00000000}},	//   рјан_, öktj, _ruua,
  { {0x7e7b0164,0x7415007e,0x4427406b,0x00000000}},	//   _peup, _روحا, _ân_,
  { {0xf8b70053,0x7cfd0003,0x61300e77,0x00000000}},	//   _अस्प, _mère, wält,
  { {0xf1bf017d,0xbdf80021,0x6d41001f,0x00000000}},	//   _usá_, يرها_, _phla,
  { {0x7cf40268,0x9c7c007d,0x2716008f,0x00000000}},	//   _fàrm, _uočl, rāni_,
  { {0x4154000a,0x2a7f004d,0x61300050,0x00000000}},	//   _цврс, taub_, rält,
  { {0x6130024a,0x6d5b004b,0xa3cc0053,0x00000000}},	//   sält, _tuua, लित_,
  { {0xfc46007a,0x7cfd0268,0xf9910032,0x00000000}},	//   _þínu_, _pèrd, ربة_,
  { {0x48050086,0xe8f905f7,0x69c9406c,0x00000000}},	//   зпов, сло_, rvee,
  { {0xf09200b5,0x69c9004b,0xccf20063,0x00000000}},	//   ענט_, svee, _רכב_,
  { {0xd5b1008b,0xb5fb006d,0xa25b406d,0x00000000}},	//   ắn_, rcán, _saôn,
  { {0xcb12014e,0x4a5a009d,0x00000000,0x00000000}},	//   _אלא_, _הדנו,   ,
  { {0xd83e00c2,0xa7fc0058,0x2732004c,0x00000000}},	//   ščam_, mcın, vánu_,
  { {0x443e0137,0x395d002b,0x7cfd006c,0x00000000}},	//   åt_, _huws_, _gère,
  { {0x877a0047,0xd348005d,0x27320445,0x00000000}},	//   _פאפי, تیجه_, tánu_,
  { {0xa7fc005b,0xd6eb0063,0xe7170063,0x00000000}},	// [7560] ncın, _הַיָ, _מחקר_,
  { {0x505a0121,0x273201d1,0xa3cc0042,0x00000000}},	//   сшая_, ránu_, लिद_,
  { {0x447700b5,0x7bc10137,0x4abd0053,0x00000000}},	//   _מעיל_, _nslu, ्याव,
  { {0x794d0051,0x7c240058,0x6da6406e,0x00000000}},	//   _dźwi, şirk, зида,
  { {0x237f017f,0x20070014,0x3257009a,0x00000000}},	//   ćuje_, únir_, _מסכם_,
  { {0x61300137,0x7f5c406f,0xd1320021,0x00000000}},	//   räls, _turq, _أمس_,
  { {0x61300072,0x602305ef,0x2716008f,0x00000000}},	//   säls, _здра, lānu_,
  { {0x9c7c004c,0xada60257,0xfbcf0049,0x00000000}},	//   _kočk, _набл, اتو_,
  { {0xd7f8003b,0x49d80054,0x00000000,0x00000000}},	//   rcăm_, ідою_,   ,
  { {0x7cef00d1,0x7cfd0003,0x7bc101af,0x00000000}},	//   _sørv, _père, _fslu,
  { {0xd6d10044,0x4ccb009a,0x56954070,0x00000000}},	//   نقد_, _לֶאֱ, мант,
  { {0x7bdb014e,0xfaa60085,0x103b009a,0x00000000}},	//   _לקבו, _хадо, מגיע,
  { {0x2732000f,0x6d4a4071,0x69dd078c,0x00000000}},	//   vánt_, omfa, äset,
  { {0x48e317db,0xe4e40083,0x3f9a4072,0x00000000}},	//   _почв, нісн, kupu_,
  { {0x7cfd01a8,0x7cef05e7,0xf3f30021,0x00000000}},	//   _hèrc, _tørv, رأس_,
  { {0x78ba000f,0x7cef06a5,0xf4080021,0x00000000}},	//   letv, _hørt, سيقى_,
  { {0x442d0051,0x7cef00b9,0x672f0051,0x00000000}},	// [7570] łe_, _kørt, mocj,
  { {0x78ba0146,0xdb031d6b,0x51f80895,0x00000000}},	//   netv, rtné, чную_,
  { {0x8fb90021,0xdb03108e,0x3f8701c8,0x00000000}},	//   تهاء_, stné, énu_,
  { {0x644300cd,0x8db5000d,0xff040054,0x00000000}},	//   _úniq, дскі, нячн,
  { {0x68ea00ca,0xddab4073,0x6da51406,0x00000000}},	//   _oofd, стел_, фила,
  { {0x7cfd00cd,0x2127007e,0x2fc60022,0x00000000}},	//   _sèrb, _ريزی_, łoga_,
  { {0xdb1a16eb,0x672f0022,0x1ae50054,0x00000000}},	//   _estí, kocj, дойм,
  { {0x629f00ac,0x7bc100df,0x656d0509,0x00000000}},	//   ngqo, _vslu, _otah,
  { {0xceb20a7a,0xda64007e,0xdb0801e1,0x00000000}},	//   _בין_, رايي, _opdæ,
  { {0xecd5005d,0x78ba009c,0x6e2d056c,0x00000000}},	//   _تحرک, getv, żabs,
  { {0x7bc11181,0xdb0100b9,0x69c200ac,0x00000000}},	//   _uslu, _oplø, _esoe,
  { {0xa3cc0235,0xa7fc01f7,0x273200ea,0x00000000}},	//   लिस_, mcıl, váns_,
  { {0x7cef0831,0x6abb0290,0x443c0006,0x00000000}},	//   _ført, meuf, _šv_,
  { {0x613000c7,0xf2df001f,0x60c70631,0x00000000}},	//   jälp, _siâp_, _najm,
  { {0xa7fc005b,0x03a301d5,0xa35e0085,0x00000000}},	//   ncıl, киро, рэгi,
  { {0x7cef0146,0x9c7c027d,0x7aeb00ea,0x00000000}},	//   _kørs, _počk, _jogt,
  { {0x045a0021,0x2739013d,0xdb1a00a3,0x00000000}},	// [7580] _وجدت_, zénk_, _ystâ,
  { {0x61eb01bb,0x3f9a4074,0x2716008f,0x00000000}},	//   ägla, tupu_, rānu_,
  { {0xdee60002,0x443c0195,0xdff50085,0x00000000}},	//   можи, _áv_, няць,
  { {0x9c7c02e2,0x7aeb00f5,0x78ba00ea,0x00000000}},	//   _točk, _nogt, zetv,
  { {0x62844075,0xcd2a0044,0x11460044,0x00000000}},	//   maio, يستن_, _يَجُ,
  { {0x3f9a0089,0x2d8600ca,0x9c7c3d08,0x00000000}},	//   pupu_, rsoe_, _koči,
  { {0x7aeb00b9,0x290e0150,0x6d4a230d,0x00000000}},	//   _bogt, _rmfa_, rmfa,
  { {0x60c70051,0x7cef01f2,0x98be0078,0x00000000}},	//   _zajm, _børs, imtą_,
  { {0x9c7c00c3,0x7aeb00ac,0xcb070021,0x00000000}},	//   _loči, _dogt, بيين_,
  { {0x7c2d005b,0x7af7006f,0xd83e0066,0x00000000}},	//   şara, ëxtr, áčom_,
  { {0xd5b1001b,0x656d4076,0x78ba4077,0x00000000}},	//   ắm_, _stah, retv,
  { {0x7cef02ab,0x6595252a,0xab770044,0x00000000}},	//   _førs, наму, _آمنا_,
  { {0xdb1a03d9,0x7792006a,0xc9f60021,0x00000000}},	//   _estã, ریکا, _تساع,
  { {0x9f470139,0xd37b0054,0x672f0022,0x00000000}},	//   ánú_, жча_, socj,
  { {0x24580121,0x7cf401a8,0xf4340085,0x00000000}},	//   дарь_, _càri, верэ,
  { {0x9f470024,0x87270021,0x60c7007d,0x00000000}},	//   šnú_, _تعتم, _sajm,
  { {0x656d0035,0x86550054,0x60f90766,0x00000000}},	// [7590] _utah, _яких, пная_,
  { {0x272401f7,0xa1940062,0x31c4005e,0x00000000}},	//   mına_, тафч, њств,
  { {0x6f020025,0x291e4078,0xb60600c2,0x00000000}},	//   fhoc, inta_, anšč,
  { {0x7cef05b9,0xa7fc0058,0xfe70009e,0x00000000}},	//   _nørr, vcıl, لده_,
  { {0x60c7017f,0x2724005b,0xa159005e,0x00000000}},	//   _tajm, nına_, _хагу_,
  { {0x7cef1262,0xd13b000a,0x459c0047,0x00000000}},	//   _rørs, _фхм_, קסוע,
  { {0x7cef21e7,0xdb80000d,0xeb990499,0x00000000}},	//   _sørs, арыi_, чий_,
  { {0x2b460003,0x20140051,0x2ca9004c,0x00000000}},	//   _choc_, ócił_, řad_,
  { {0x7aeb4079,0xdbc7004b,0x27240058,0x00000000}},	//   _vogt, _nöör, jına_,
  { {0xdb1a0994,0x78a90138,0x2eed00e8,0x00000000}},	//   _està, чког_, _hoef_,
  { {0x7cef1262,0x645a0006,0x2d9d006f,0x00000000}},	//   _førr, žtik, luwe_,
  { {0x291e407a,0x27240058,0x3af8013d,0x00000000}},	//   anta_, fına_, _lépj_,
  { {0xdb030080,0x2d9d00ac,0x9c7c007d,0x00000000}},	//   ntní, nuwe_, _soči,
  { {0xb0ce0161,0xdb030025,0x9c7c407b,0x00000000}},	//   _होंग, itní, _poči,
  { {0xb6020080,0x38ca005d,0x78fa009d,0x00000000}},	//   _žádn, _راوی_, _מפסו,
  { {0x7cf400cd,0x2724005b,0x3f470019,0x00000000}},	//   _vàri, bına_, nõud_,
  { {0x79890f4e,0xc3550062,0xa2270062,0x00000000}},	// [75a0] nsew, търъ, ежта_,
  { {0x2d9d006f,0x6284017d,0x83c6000d,0x00000000}},	//   duwe_, saio, _збож,
  { {0x62840290,0x9c7c007d,0x2566002b,0x00000000}},	//   paio, _uoči, _hôl_,
  { {0x4444065f,0xdb1a0024,0x3f470019,0x00000000}},	//   _iz_, _ostá, jõud_,
  { {0x6441008f,0x798901e1,0x9c7c08ed,0x00000000}},	//   ļlie, jsew, _močv,
  { {0x6f020027,0xab940054,0x4444407c,0x00000000}},	//   shoc, викі, _kz_,
  { {0x27240058,0x50430ae8,0x6f021806,0x00000000}},	//   zına_, _берб, phoc,
  { {0xe6ca0053,0x2724005b,0xc2120063,0x00000000}},	//   ियोज, yına_, ָה֙_,
  { {0x2566001f,0x79890150,0x69c0006f,0x00000000}},	//   _nôl_, gsew, uwme,
  { {0xf2df001b,0x395800c7,0x4444407d,0x00000000}},	//   _nhân_, örs_, _oz_,
  { {0xdb1a0b2b,0x76440089,0x7cef06a5,0x00000000}},	//   _está, _aziy, _tørr,
  { {0xdbc70019,0x645e00a4,0x2724005b,0x00000000}},	//   _pöör, _agpi, tına_,
  { {0x444403e8,0x7c3a001f,0x7a490003,0x00000000}},	//   _az_, _hytr, rêté,
  { {0x272401f7,0x98a5000c,0xf2df001b,0x00000000}},	//   rına_, rolă_, _chân_,
  { {0x272401f7,0x9cd70063,0x68f5005b,0x00000000}},	//   sına_, עולה_, özde,
  { {0xdbc70019,0x443a407e,0x083b0063,0x00000000}},	//   _töör, _dyp_, _מעול,
  { {0x4444407f,0x2eed00ac,0x6d5a017d,0x00000000}},	// [75b0] _ez_, _roef_, _oita,
  { {0x6d5a0035,0x7694056c,0x32440044,0x00000000}},	//   _nita, rżył, انكف,
  { {0x44444080,0xbec80023,0x0f350043,0x00000000}},	//   _gz_, zgūš, نکرد,
  { {0x3ee4011c,0x6d5a0019,0xfe71007e,0x00000000}},	//   лючв, _aita, شگر_,
  { {0xa2a60053,0x9c7c00c2,0x6d5a4081,0x00000000}},	//   _छात्, _loču, _bita,
  { {0x2739004a,0xdb03004c,0x6d5a4082,0x00000000}},	//   ménu_, rtní, _cita,
  { {0x6d5a1813,0xdb030114,0xdce91dab,0x00000000}},	//   _dita, stní, _uteč,
  { {0x673d006f,0x6d5a4083,0x40340121,0x00000000}},	//   jlsj, _eita, _сесс,
  { {0x6d5a03cc,0x7cef000e,0xee3f0066,0x00000000}},	//   _fita, _førp, _áý_,
  { {0xd9450001,0x2566001f,0x6d5a4084,0x00000000}},	//   ђени, _rôl_, _gita,
  { {0x78bc004b,0xe9050013,0xf8ae0043,0x00000000}},	//   õrva, gượ, تکن_,
  { {0x7b740021,0x6d5a2475,0x443a00ac,0x00000000}},	//   _إطلا, _zita, _ryp_,
  { {0xf2df001b,0x7ae9017f,0x444411d2,0x00000000}},	//   _phân_, mjet, _sz_,
  { {0x7ae94085,0x7afb4086,0x44444087,0x00000000}},	//   ljet, lkut, _pz_,
  { {0x3f87003b,0x29050139,0xd3b90054,0x00000000}},	//   ânul_, mhla_, нуті_,
  { {0x61e400cd,0x7afb4088,0x61f60072,0x00000000}},	//   txil, nkut, tyyl,
  { {0xf2df001b,0x6e3b0035,0x7d014089,0x00000000}},	// [75c0] _thân_, _nyub, _olls,
  { {0x42552c9e,0x443a0471,0x4444408a,0x00000000}},	//   утст, _typ_, _tz_,
  { {0x6d5a3906,0x4444408b,0x7fd50086,0x00000000}},	//   _rita, _uz_, ліці,
  { {0x7d01408c,0x7cef1262,0x65641668,0x00000000}},	//   _alls, _sørp, _kuih,
  { {0x568d00b7,0x6d5a0117,0x7ae9408d,0x00000000}},	//   לטאַ, _pita, djet,
  { {0x656400fe,0xb5fb00ea,0xdb010066,0x00000000}},	//   _muih, tbáz, _vplý,
  { {0x2bc2016a,0x6d5a408e,0xb6070014,0x00000000}},	//   _वैशा, _vita, _kráð,
  { {0xab270079,0x3ea20031,0x7afb00f3,0x00000000}},	//   која_, _økt_, gkut,
  { {0x6d5a408f,0x7c3a0051,0x9c7c00a8,0x00000000}},	//   _tita, _wytr, _soču,
  { {0x6d5a000c,0x7afb0213,0xdca60002,0x00000000}},	//   _uita, akut, _јажи,
  { {0x2739000f,0xa09b00b5,0x5719000d,0x00000000}},	//   ként_, וייט, ежня_,
  { {0x7c240058,0x29050066,0x973d007d,0x00000000}},	//   şirs, ahla_, kuće,
  { {0x973d017f,0xceb30047,0x3af8013d,0x00000000}},	//   juće, סיש_, _népi_,
  { {0x973d007d,0x29051f25,0xa534012c,0x00000000}},	//   duće, chla_, иняч,
  { {0xb6070014,0xd7ef27c8,0xa2950500,0x00000000}},	//   _bráð, _ту_, лаві,
  { {0x7d184090,0xbebd0023,0x98a522b4,0x00000000}},	//   hivs, _ajūn, rolą_,
  { {0x973d017f,0xdb1a00c7,0x45d50dd5,0x00000000}},	// [75d0] guće, _istä, _сопс,
  { {0x7cf401a8,0xd01b0074,0x273901c8,0x00000000}},	//   _xàrt, мфе_, rénu_,
  { {0x6e3b0150,0x75354091,0x7afb0075,0x00000000}},	//   _syub, mozz, ykut,
  { {0xdb230019,0xb6070014,0xf2df0013,0x00000000}},	//   örüh, _gráð, _khâm_,
  { {0x41e40088,0x7ae94092,0xa184026c,0x00000000}},	//   _кіра, vjet, _высл,
  { {0x7ae90321,0xcd040002,0x70740021,0x00000000}},	//   wjet, ичји, _نافذ,
  { {0xa3cc0053,0x4fc40121,0x7ae90130,0x00000000}},	//   लिए_, _кста, tjet,
  { {0xdb1a0137,0x7535013d,0x7ae94093,0x00000000}},	//   _nstä, hozz, ujet,
  { {0x753500ea,0x9c7c027d,0x7ae94094,0x00000000}},	//   kozz, _počt, rjet,
  { {0x7ae94095,0x6f19001f,0xd7e90076,0x00000000}},	//   sjet, liwc, емое_,
  { {0x7ae9007d,0x65640072,0x69c601e1,0x00000000}},	//   pjet, _suih, æker,
  { {0x7aa40086,0xbc0c0047,0x6f191780,0x00000000}},	//   _виїз, _קהאָ, niwc,
  { {0xf2df0013,0x00000000,0x00000000,0x00000000}},	//   _châm_,   ,   ,
  { {0xdb1a024a,0x27390016,0xddc200c3,0x00000000}},	//   _estä, féns_, ncoš,
  { {0x273900ea,0x141a0044,0xb8920044,0x00000000}},	//   tént_, ريرة_, _طليع,
  { {0x04570044,0x77f6009a,0xf772009a,0x00000000}},	//   طلقة_, _תמקד_, _פקח_,
  { {0x6f190185,0x98ac001c,0x91e3026b,0x00000000}},	// [75e0] diwc, lodā_, боте,
  { {0x27390016,0x753504be,0xdb1a01e1,0x00000000}},	//   béns_, cozz, _istå,
  { {0xdb1a024a,0x6f19001f,0x9f470240,0x00000000}},	//   _ystä, fiwc, šný_,
  { {0x26c208a5,0x6f19002b,0x6e46014d,0x00000000}},	//   neko_, giwc, هنام,
  { {0xa3cc0394,0x6286003d,0x7d1817d5,0x00000000}},	//   लिक_, _ieko, tivs,
  { {0xac1824dc,0x6b81002b,0x98ac008f,0x00000000}},	//   колу_, _bwlg, kodā_,
  { {0x7d180137,0x628632b1,0x91030591,0x00000000}},	//   rivs, _keko, _упре,
  { {0x7cf40994,0x6f190185,0x26c2007d,0x00000000}},	//   _càrr, ciwc, jeko_,
  { {0xbef70063,0x273900be,0x62864096,0x00000000}},	//   _עצמו_, zéns_, _meko,
  { {0xd8f80086,0x62863284,0x5bc60021,0x00000000}},	//   тної_, _leko, _متصف,
  { {0x62860717,0xeb9a06da,0x3942001c,0x00000000}},	//   _oeko, _чие_, ēks_,
  { {0x7b17000c,0xa96a1849,0x62860dad,0x00000000}},	//   nţul, _зида_, _neko,
  { {0xf2df008b,0x7535013d,0x00000000,0x00000000}},	//   _giây_, tozz,   ,
  { {0xc8b20043,0x00000000,0x00000000,0x00000000}},	//   _طلبک,   ,   ,
  { {0x62864097,0x75353b28,0xdb1a05a5,0x00000000}},	//   _beko, rozz, _estå,
  { {0x7cf40268,0x80a70053,0x98a70080,0x00000000}},	//   _màrq, _चाहे, _okně_,
  { {0x9259000a,0x8237007e,0x62864098,0x00000000}},	// [75f0] таат_, ارزا, _deko,
  { {0x10074099,0xb375005d,0xdddb011b,0x00000000}},	//   ляем, _نگرش, _neuš,
  { {0x99760051,0x79820051,0x81c8008f,0x00000000}},	//   nęły_, _lwow, edēļ,
  { {0x62862d1a,0xa2640062,0x9474007e,0x00000000}},	//   _geko, _гърл, _پدیا,
  { {0x6f19001f,0x61300072,0xa91d005f,0x00000000}},	//   riwc, häly, aržy,
  { {0x6f190185,0x3ea6002c,0x7cfd00cd,0x00000000}},	//   siwc, agot_, _tèrm,
  { {0x6f19001f,0x1d060062,0x99760022,0x00000000}},	//   piwc, рещи_, jęły_,
  { {0xdab9000d,0x26c200ac,0xd5460013,0x00000000}},	//   тыкі_, xeko_, iến,
  { {0x31af01f7,0x09050086,0xfd610013,0x00000000}},	//   nüz_, ипин, huyế,
  { {0x290300ea,0xbc680021,0x26c200a4,0x00000000}},	//   ója_, _ممكن_, weko_,
  { {0x26c2146f,0x7b170529,0xe0d200b5,0x00000000}},	//   teko_, lţum, קײט_,
  { {0x1036009a,0xa036009a,0x6a6700de,0x00000000}},	//   יטתם_, יאתה_, _إطال,
  { {0x6b450024,0xd8f5007e,0x38ca007e,0x00000000}},	//   lógo, _پزشک, رایی_,
  { {0x4867005a,0x64a600d7,0x88bc0080,0x00000000}},	//   _съдб, јава, lněn,
  { {0x443e00b9,0x07a518f7,0x833a0054,0x00000000}},	//   æt_, _тайн, вчат_,
  { {0x4424409a,0x236b004c,0x973d0022,0x00000000}},	//   ăm_, _žijí_, erćf,
  { {0x6286409b,0xdc34017c,0x98a5056c,0x00000000}},	// [7600] _veko, _rúčk, wolę_,
  { {0xd5b1008b,0xb05a0021,0xdb03004b,0x00000000}},	//   ắt_, نشاط_, ltnä,
  { {0x34b7014e,0xc0590086,0x6286409c,0x00000000}},	//   _דפים_, гії_, _teko,
  { {0xf987006a,0x88bc0080,0x98a51748,0x00000000}},	//   _وب_, jněn, rolę_,
  { {0x88bc0080,0x7b17003b,0xb5fb0e7c,0x00000000}},	//   dněn, rţul, lcár,
  { {0x2bba0021,0x6bd60044,0xa06a02f8,0x00000000}},	//   ناعة_, لتعر, _јава_,
  { {0x69d90185,0xb5fb409d,0x9be60086,0x00000000}},	//   _arwe, ncár, рілк,
  { {0x2b93008b,0xbea3409e,0x539b009a,0x00000000}},	//   ịch_, _маск, דיקו,
  { {0x38c8007e,0x5ca60699,0x6c960021,0x00000000}},	//   هادی_, _визб, _نشاط,
  { {0x63be0031,0x61eb0832,0xd90e007e,0x00000000}},	//   _oppn, ägli, بیت_,
  { {0x4735409f,0x69d90199,0x60d900b5,0x00000000}},	//   йнос, _erwe, אַרג,
  { {0x88bc0080,0x31af0058,0x0a67007b,0x00000000}},	//   cněn, yüz_, _крши_,
  { {0x973d017f,0xceb30063,0x58d40002,0x00000000}},	//   guća, חיר_, _голт,
  { {0xd90e007e,0x31af0058,0xd4983ba4,0x00000000}},	//   _آید_, vüz_, ирс_,
  { {0xd7fa0001,0x27323544,0x926b0002,0x00000000}},	//   _јул_, hány_, врза_,
  { {0xdb1a03ea,0x63be0089,0xe705007e,0x00000000}},	//   _astú, _dppn, _دستی,
  { {0x20670001,0xb5fb40a0,0x408b005e,0x00000000}},	// [7610] ађев, rcás, вљем_,
  { {0x27320080,0x88bc0080,0x7bda40a1,0x00000000}},	//   dány_, zněn, _ortu,
  { {0xa267005a,0xa7fc0058,0x31af0058,0x00000000}},	//   _въгл, mcıs, süz_,
  { {0xdb1a00ed,0xa8570063,0x7ae240a2,0x00000000}},	//   _estú, ביבה_, _nnot,
  { {0x88bc0080,0xd0870076,0x6b6a0051,0x00000000}},	//   vněn, _выби, _węgl,
  { {0x7ae20f15,0xfbd10021,0xa7fc0058,0x00000000}},	//   _anot, كتب_, ncıs,
  { {0x4ea7000a,0x88bc004c,0x7f420003,0x00000000}},	//   _врза, tněn, bloq,
  { {0xcac90055,0x7cfd00cd,0xd5b90053,0x00000000}},	//   угие_, _mèri, ेबाज,
  { {0x88bc0080,0x7bdc0014,0xd996005d,0x00000000}},	//   rněn, _árun, منيت_,
  { {0x60c50199,0x7ae200c3,0x88bc0080,0x00000000}},	//   nehm, _enot, sněn,
  { {0xdab90088,0x88bc31b6,0xd90d005d,0x00000000}},	//   _былі_, mněl, ویچ_,
  { {0x98ac000c,0x6d4340a3,0xcb550001,0x00000000}},	//   todă_, llna, _увећ,
  { {0x7cfd00cd,0x69cb004d,0xdb03051c,0x00000000}},	//   _aèri, _usge, rtnä,
  { {0x7ae200c3,0xdb030137,0x07f90593,0x00000000}},	//   _znot, stnä, _مربع_,
  { {0x68e317d3,0x27320080,0x2bda0053,0x00000000}},	//   _innd, zány_, भिया,
  { {0x6aa940a4,0x27f8004b,0xadf90053,0x00000000}},	//   ngef, ärne_, ्नान_,
  { {0x9c820006,0x69c940a5,0xb5fb0331,0x00000000}},	// [7620] ščia, nwee, scár,
  { {0x273202f4,0x6aa900bd,0x26d20c55,0x00000000}},	//   vány_, hgef, _hayo_,
  { {0x26d20273,0x63be2d60,0xdb1a0024,0x00000000}},	//   _kayo_, _uppn, _vstú,
  { {0x69c90983,0xf7720063,0x6d430e46,0x00000000}},	//   kwee, פקד_, elna,
  { {0x26d240a6,0xb6060066,0xdd8f0593,0x00000000}},	//   _mayo_, bráť, فون_,
  { {0x26d2002c,0x69c91837,0xdb1a0066,0x00000000}},	//   _layo_, dwee, _ustú,
  { {0xb60600c3,0x973d017f,0x6aa907cf,0x00000000}},	//   lišč, dućn, fgef,
  { {0x29071262,0x26d20035,0xb60600c2,0x00000000}},	//   _alna_, _nayo_, oišč,
  { {0xb60600c2,0xdce2007d,0x1efb0047,0x00000000}},	//   nišč, spođ, _עלמע,
  { {0x973d0117,0xdd8f0032,0xa2da0053,0x00000000}},	//   gućn, _أول_, _पोस्,
  { {0x6f020066,0xa7fc0058,0x6aa90244,0x00000000}},	//   okoc, vcıs, bgef,
  { {0x25d90076,0x26d2006d,0x2d490331,0x00000000}},	//   аммы_, _cayo_, núen_,
  { {0x7cfd0268,0xb60600c2,0xe89409b3,0x00000000}},	//   _sèri, jišč, _даль,
  { {0xb60600c3,0xf76f007e,0x29020023,0x00000000}},	//   dišč, بای_, īkas_,
  { {0xd91b00b5,0x249f005b,0xf1bf0014,0x00000000}},	//   _גוגל, ğum_, _spá_,
  { {0x291e40a7,0x63780121,0x6b71008f,0x00000000}},	//   lita_, ссёр_, _jāga,
  { {0x6f020024,0x291e00fe,0xa4d50603,0x00000000}},	// [7630] dkoc, oita_, _допі,
  { {0x291e40a8,0x88bc0080,0x8319007e,0x00000000}},	//   nita_, kněm, _چقدر_,
  { {0x69c900ca,0xf53f0a3f,0x83190044,0x00000000}},	//   zwee, stås_, _نقدر_,
  { {0xb60600c3,0x9f560026,0x7d1a161a,0x00000000}},	//   bišč, ægðu_, _amts,
  { {0x291e0273,0xc6940041,0x3f8e0014,0x00000000}},	//   kita_, פאס_, áfur_,
  { {0x21ba0047,0xed590002,0xdb030003,0x00000000}},	//   _דזשא, шол_, muné,
  { {0x973d007d,0x6aa940a9,0x291e40aa,0x00000000}},	//   jućo, tgef, dita_,
  { {0x69c90037,0x7d0840ab,0xbd6b005e,0x00000000}},	//   twee, _elds, _брже_,
  { {0x26d2006d,0x88bc0080,0x291e40ac,0x00000000}},	//   _rayo_, mněj, fita_,
  { {0x6aa900bd,0x69c90250,0x26d240ad,0x00000000}},	//   sgef, rwee, _sayo_,
  { {0xb17b01e3,0x26d2002c,0x6aa90026,0x00000000}},	//   _fråg, _payo_, pgef,
  { {0x88bc0080,0x7b33000c,0xb17b01e1,0x00000000}},	//   nněj, dăug, _gråg,
  { {0x291e40ae,0xa904007e,0x15ba0085,0x00000000}},	//   bita_, زبین, шыны_,
  { {0x291e40af,0x6f09001f,0xb17b00df,0x00000000}},	//   cita_, _llec, _mråd,
  { {0x26d2002c,0xf53f0829,0x6f020066,0x00000000}},	//   _tayo_, ttår_, ykoc,
  { {0xb6060198,0x98ac00eb,0xa22a026b,0x00000000}},	//   tišč, rodą_, ажба_,
  { {0xdce0000c,0x88bc0080,0x256f005b,0x00000000}},	// [7640] _jumă, dněj, _gül_,
  { {0xb60600c3,0x888c0047,0xa2da0053,0x00000000}},	//   rišč, ָראַ, _पोर्,
  { {0x6f020066,0x634c004d,0x394540b0,0x00000000}},	//   tkoc, aßna, ills_,
  { {0x63a10024,0xb17b0137,0x224227e8,0x00000000}},	//   álne, _bråd, _tykk_,
  { {0xdce00529,0x444440b1,0xf2df001b,0x00000000}},	//   _numă, _hy_, _châu_,
  { {0xcc87005e,0x6f090725,0x5cc30062,0x00000000}},	//   обље_, _elec, дсъз,
  { {0x444410e9,0x88bc0080,0x6f0940b2,0x00000000}},	//   _jy_, bněj, _flec,
  { {0x3945368c,0x444440b3,0x291e0051,0x00000000}},	//   ells_, _my_, wita_,
  { {0x753c0045,0x291e40b4,0x444440b5,0x00000000}},	//   korz, tita_, _ly_,
  { {0xeb9a005a,0x64410019,0x6f090051,0x00000000}},	//   _виж_, ülik, _zlec,
  { {0x291e23f3,0x395900cd,0x44440d2c,0x00000000}},	//   rita_, ïssa_, _ny_,
  { {0x3869005b,0x291e40b6,0xdce0003b,0x00000000}},	//   _şart_, sita_, _fumă,
  { {0x44440273,0xdb030024,0x291e40b7,0x00000000}},	//   _ay_, ytnú, pita_,
  { {0x444440b8,0x660000b9,0xe4e40636,0x00000000}},	//   _by_, ømka, місн,
  { {0x987b0047,0x444440b9,0x59d20042,0x00000000}},	//   _דרוק, _cy_, तिकर,
  { {0x444440ba,0xf2df008d,0x657d00a5,0x00000000}},	//   _dy_, _nhât_, ppsh,
  { {0x88bc0080,0x764d0058,0x78ba1536,0x00000000}},	// [7650] vněj, _uzay, oftv,
  { {0x6f0902b0,0x44440185,0x7b17003b,0x00000000}},	//   _slec, _fy_, rţui,
  { {0x88bc0080,0x6f0940bb,0x444440bc,0x00000000}},	//   tněj, _plec, _gy_,
  { {0xdb0340bd,0x6d58006f,0xb69b11f5,0x00000000}},	//   stnú, emva, chât,
  { {0x237f017f,0x88bc004c,0x444440be,0x00000000}},	//   ćuju_, rněj, _zy_,
  { {0x88bc0080,0x656d0058,0x444440bf,0x00000000}},	//   sněj, _muah, _yy_,
  { {0xcfb4005a,0x4bd90088,0x656d0089,0x00000000}},	//   _обръ, сьля_, _luah,
  { {0xb17b1781,0xf2df0013,0x60d534ad,0x00000000}},	//   _tråd, _thâu_, _hazm,
  { {0x60d540c0,0x644501cf,0x99d2005d,0x00000000}},	//   _kazm, _lyhi, فقيت,
  { {0xdb1a0024,0x00f60063,0x973d007d,0x00000000}},	//   _istý, ִ֖ים_, sućl,
  { {0x6d410c64,0x753c2eb3,0x68fc0137,0x00000000}},	//   _ikla, vorz, örda,
  { {0x753c0045,0x27f80137,0x656d003e,0x00000000}},	//   worz, ärna_, _buah,
  { {0x444440c1,0x7cfd00cd,0x753c40c2,0x00000000}},	//   _sy_, _fèrt, torz,
  { {0xb97a0063,0x444440c3,0x98ac0022,0x00000000}},	//   _הנסי, _py_, kodę_,
  { {0xccf20047,0x63861915,0x987a016e,0x00000000}},	//   ײכן_, ягва, _פאקט,
  { {0xd7fa0063,0x444440c4,0x29051a59,0x00000000}},	//   _להצל, _vy_, lkla_,
  { {0x753c40c5,0x6b451a4e,0xf1a901fb,0x00000000}},	// [7660] porz, gógi, قاله_,
  { {0xb1430001,0xd24f0021,0x56370047,0x00000000}},	//   енул, انك_, _מאפע_,
  { {0x444440c6,0x0019000d,0x2126007d,0x00000000}},	//   _uy_, оўцы_, đoh_,
  { {0x6d4104d2,0x1eaa0044,0x59bd0042,0x00000000}},	//   _akla, صاصي_, ्बार,
  { {0x6284048e,0x26c00035,0x5de60062,0x00000000}},	//   mbio, _mbio_, яжда,
  { {0x98ac0022,0x55bb009d,0x00000000,0x00000000}},	//   bodę_, ממנו,   ,
  { {0x69c20162,0x68f803d4,0x443340c7,0x00000000}},	//   _spoe, _rovd, _xxx_,
  { {0x6d4140c8,0x79a60fc7,0x628440c9,0x00000000}},	//   _ekla, прое, nbio,
  { {0x60d5005b,0x6da340ca,0x5a340054,0x00000000}},	//   _yazm, _пита, ьнит,
  { {0x290a1504,0xe9180054,0x0217009a,0x00000000}},	//   óba_, іоні_, פחים_,
  { {0x656d1908,0x7cfd00cd,0x225c004c,0x00000000}},	//   _suah, _vèrt, ěvky_,
  { {0xb34700be,0x6d41004c,0xe7ed0042,0x00000000}},	//   _maçô, _zkla, _छपरा_,
  { {0x673d1bd1,0x62840022,0x7f3b016e,0x00000000}},	//   rosj, dbio, מעטו,
  { {0x290500c7,0x64450072,0x8cbf0042,0x00000000}},	//   ckla_, _pyhi, ल्पो,
  { {0x58bb014e,0x60d506bb,0x88bb009a,0x00000000}},	//   _המוצ, _razm, _המוז,
  { {0x60d50089,0xdb1a017d,0x2ae50042,0x00000000}},	//   _sazm, _istó, काएँ_,
  { {0xd234005a,0x60f9000d,0x22580121,0x00000000}},	// [7670] ентъ, оная_, зиты_,
  { {0x98ac0022,0x26cb0516,0x80c70042,0x00000000}},	//   todę_, leco_, रजें,
  { {0x628440cb,0xb3550363,0x68f50075,0x00000000}},	//   bbio, _окош, özdi,
  { {0x6d410648,0x200f0022,0x26cb1358,0x00000000}},	//   _skla, ągi_, neco_,
  { {0x200701b3,0x9f5c19bc,0x29050078,0x00000000}},	//   šni_, ává_, ykla_,
  { {0xee381c15,0x26cb0016,0x628f002b,0x00000000}},	//   чні_, heco_, _heco,
  { {0x628f0228,0x7af90051,0x41540001,0x00000000}},	//   _keco, _powt, _чврс,
  { {0x64410045,0x7cfd00cd,0xbed4005e,0x00000000}},	//   żliw, _pèrs, _посј,
  { {0xc27c0063,0x0b160021,0x290501c8,0x00000000}},	//   זרחי, بقية_, tkla_,
  { {0x4805019d,0x6d4140cc,0x628f14a4,0x00000000}},	//   дпов, _ukla, _leco,
  { {0x629d38da,0xf0920063,0xa6ca0ae8,0x00000000}},	//   _odso, כני_, олна_,
  { {0x628f000c,0xeab00021,0x2cfa0042,0x00000000}},	//   _neco, _معه_, ्सॅल_,
  { {0xe8f50021,0xe6170054,0xcb120063,0x00000000}},	//   _يستخ, ддя_, _בלא_,
  { {0xd82500e1,0x629d40cd,0xf992009a,0x00000000}},	//   _одли, _adso, _ירד_,
  { {0x628f0037,0xc9520063,0x98ac0080,0x00000000}},	//   _beco, _שמו_, hodě_,
  { {0x628f17c2,0x26c0007d,0x63a100ea,0x00000000}},	//   _ceco, _ubio_, álna,
  { {0x99680047,0xa09a0021,0x628440ce,0x00000000}},	// [7680] ִיאַ_, قضاء_, rbio,
  { {0xc0a90021,0x8cbf0053,0x629d00be,0x00000000}},	//   كامل_, ल्मो, _edso,
  { {0x628f0290,0x6b45013d,0x2d80008f,0x00000000}},	//   _feco, lógu, ģiem_,
  { {0x628f02b0,0x1fb50085,0xe80e0042,0x00000000}},	//   _geco, эсур, ानता_,
  { {0x7c250024,0xbf650043,0xe629009d,0x00000000}},	//   úhrn, ردمو, ּחוֹ_,
  { {0x7afd0137,0x3f68003b,0x6c540854,0x00000000}},	//   östn, _eşua_, нклу,
  { {0x69dd0146,0x629d00ac,0xfce30002,0x00000000}},	//   æsen, _ydso, тојо,
  { {0xdb0a0137,0xdee30121,0x98ac004c,0x00000000}},	//   xtfä, _иоси, bodě_,
  { {0xbebd0078,0xdceb0058,0xfe430789,0x00000000}},	//   _smūg, argı, _анто,
  { {0xc7ba0121,0x3dfb0aeb,0x57f405ce,0x00000000}},	//   оём_, _ולמד, епот,
  { {0x7c650021,0xdb0a0137,0x26cb0aaf,0x00000000}},	//   _كامل, ttfä, teco_,
  { {0xdb1a00cd,0x6d4a40cf,0xdb26005d,0x00000000}},	//   _estò, llfa, _کوچی,
  { {0xdb030024,0x6d4a0025,0x2768007e,0x00000000}},	//   ntný, olfa, _کشتی_,
  { {0x628f1130,0x26cb0331,0xdb0a0ae2,0x00000000}},	//   _seco, seco_, stfä,
  { {0x98be000c,0x628f40d0,0x224d027d,0x00000000}},	//   altă_, _peco, _šek_,
  { {0xe6670d34,0x973d007d,0xdb030066,0x00000000}},	//   _отпо, kući, ktný,
  { {0x973d017f,0x443f0051,0x115501d5,0x00000000}},	// [7690] jući, łu_, екаю,
  { {0x7b170529,0x973d007d,0x3cfa0053,0x00000000}},	//   nţur, dući, ्सों_,
  { {0x442701e3,0x5f940062,0x929540d1,0x00000000}},	//   _än_, вихт, _панц,
  { {0x8db5071f,0x6d4a2087,0x69dc008f,0x00000000}},	//   ескі, elfa, ārej,
  { {0x973d0117,0x31790047,0xee2e167b,0x00000000}},	//   gući, _מאָד, ун_,
  { {0xabd500e1,0x787100ea,0x4d640054,0x00000000}},	//   ециј, _művé, вків,
  { {0x9f050021,0x8d620121,0x7afd00a5,0x00000000}},	//   _كوسو, ывше, östo,
  { {0x290e40d2,0x4ea4000d,0x6d4a40d3,0x00000000}},	//   _alfa_, _арфа, alfa,
  { {0x1d35005a,0xdb1a00b9,0x09e5046e,0x00000000}},	//   _зная, _optæ, хопн,
  { {0xdb030139,0x5d5440d4,0x6c840044,0x00000000}},	//   irné, _акут, _للكم,
  { {0xb8d70042,0xeb900044,0x9cd6009a,0x00000000}},	//   _छा_, _نظن_, _רועה_,
  { {0x6448004b,0x290e40d5,0xe5a60481,0x00000000}},	//   üdim, _elfa_, ними,
  { {0xdb03003b,0xaa0701fb,0x98be00dd,0x00000000}},	//   punâ, _تظاه, ultă_,
  { {0x257400c7,0x98a5001c,0x80c10053,0x00000000}},	//   _väl_, rolē_, र्मे,
  { {0xdddb1bd4,0xd372013a,0xb8d30042,0x00000000}},	//   _neuž, اهر_, टल_,
  { {0x98a50023,0xdb0301c8,0x2ba70042,0x00000000}},	//   polē_, ytný, _गिना,
  { {0xcb120047,0x41aa0062,0x6d4a002b,0x00000000}},	// [76a0] אלן_, яван_, ylfa,
  { {0x61eb0137,0x973d007d,0x3d090042,0x00000000}},	//   ågla, vući, वसों_,
  { {0xa4b70063,0x66061177,0x88bc004c,0x00000000}},	//   _אליה_, lykk, mnět,
  { {0x3f860066,0x216a0499,0x67100053,0x00000000}},	//   ďou_, _ними_, ासिक_,
  { {0x629640d6,0x6e9301f3,0x63ae07f7,0x00000000}},	//   mayo, الها, lubn,
  { {0x629640d7,0xdb030066,0xace7005e,0x00000000}},	//   layo, rtný, емља_,
  { {0x1fb5060e,0xdb03027d,0xcec3004c,0x00000000}},	//   _истр, stný, íří_,
  { {0x62963c32,0xa6db0026,0x88bc0080,0x00000000}},	//   nayo, koða, hnět,
  { {0x88bc02f4,0x95ef0042,0x31c30023,0x00000000}},	//   knět, _चपेट_, cīzā_,
  { {0x7b151358,0x7e0b009a,0xfd97009a,0x00000000}},	//   _náuf, _מִבֶ, _נדבך_,
  { {0xf53f00c7,0x62960c55,0xeb9a0002,0x00000000}},	//   från_, kayo, _ѕид_,
  { {0x8a460021,0xca76000d,0x1dd40042,0x00000000}},	//   _كَان, _чужы, _धनात,
  { {0x49730085,0x8afb0063,0x6296017c,0x00000000}},	//   _бліс, _מהאי, dayo,
  { {0x25a4000f,0x63a14068,0x0568007b,0x00000000}},	//   ámla_, álno, ејси_,
  { {0xa2950088,0x63ae0130,0x2c34009a,0x00000000}},	//   каві, gubn, דָּם_,
  { {0xdb180024,0x6296002c,0x987800c3,0x00000000}},	//   ftvé, gayo, išči_,
  { {0x4ac20053,0xdb03006c,0x30a70084,0x00000000}},	// [76b0] व्यव, urné, ерев,
  { {0x6296002c,0xb17b00c7,0x337507b0,0x00000000}},	//   aayo, _från, _игор,
  { {0xbfab0085,0xdb18013d,0x230b0044,0x00000000}},	//   ятае_, atvé, _فتحي_,
  { {0xc7b30063,0x62960331,0x63a80066,0x00000000}},	//   טבע_, cayo, ádne,
  { {0xa69c0047,0x7afd0137,0xec6e38a5,0x00000000}},	//   לשאפ, östm, ип_,
  { {0x7c940062,0xe1ff008d,0x313505cf,0x00000000}},	//   гръц, _ngói_, _регр,
  { {0x7c94007e,0xf53f00a5,0xdce90075,0x00000000}},	//   اشها, yrån_, _eteğ,
  { {0x2d8d0ac8,0x7e7b0035,0x88bc004c,0x00000000}},	//   _twee_, _ufup, znět,
  { {0xa7fc0058,0xdb03017c,0x0edd0042,0x00000000}},	//   mcıy, guná, _नोएड,
  { {0xb0c7000d,0x66060072,0x245c004c,0x00000000}},	//   дпiс, vykk, námé_,
  { {0xab84000a,0xe73a40d8,0x3cfa0047,0x00000000}},	//   _бучк, ден_, _קלענ,
  { {0x66061177,0x6b6a0022,0xa7fc0058,0x00000000}},	//   tykk, _węgr, ncıy,
  { {0x6d430159,0xaa880021,0x88bc004c,0x00000000}},	//   oona, _أنهم_, tnět,
  { {0x660605dd,0x2b40082a,0x2b4d0813,0x00000000}},	//   rykk, čice_, llec_,
  { {0x62962e10,0x3f47004b,0x88bc004c,0x00000000}},	//   tayo, nõus_, rnět,
  { {0x2d800529,0x6d43053b,0xd467005e,0x00000000}},	//   ţiei_, hona, ђите_,
  { {0x88bc0080,0x973d017f,0x6d4340d9,0x00000000}},	// [76c0] pnět, guću, kona,
  { {0xb17b0137,0x6d4340da,0x629640db,0x00000000}},	//   _trån, jona, sayo,
  { {0x6296002c,0x3f9c0164,0xdb1800ea,0x00000000}},	//   payo, évu_, stvé,
  { {0x4f260062,0xdee30a29,0xbe660593,0x00000000}},	//   ъдеб, иохи, نهاي,
  { {0xdd8f0021,0xdb03002b,0x6d4340dc,0x00000000}},	//   قون_, ernï, fona,
  { {0x80c10161,0x6b550078,0x3076237c,0x00000000}},	//   र्दे, _išgy, _шумс,
  { {0x60dc0dcf,0xdea2005d,0x67240022,0x00000000}},	//   _iarm, _نیای, _omij,
  { {0x49d80121,0x8c43005e,0x9ad401ce,0x00000000}},	//   едию_, јеће, ужич,
  { {0x4d66000d,0x6b4500f8,0x6d4315ee,0x00000000}},	//   _акав, tógr, bona,
  { {0x998d0051,0x2b4d00c2,0x6d4340dd,0x00000000}},	//   dzeń_, alec_, cona,
  { {0x394c0b7a,0x60dc0791,0x645a0014,0x00000000}},	//   rlds_, _marm, ýtil,
  { {0x752702b0,0x60dc0164,0x7b33003b,0x00000000}},	//   wijz, _larm, năul,
  { {0x6f0303d9,0xcb67000a,0x236000c2,0x00000000}},	//   ênci, _раце_, dmij_,
  { {0x224b0137,0x06240330,0x7bdc013d,0x00000000}},	//   _ryck_, рфюм, _árus,
  { {0x18a300d7,0x75271df9,0x98a3005e,0x00000000}},	//   _тајм, rijz, _тије,
  { {0x237e00ea,0x53340856,0x6d4340ce,0x00000000}},	//   ítja_, аест, zona,
  { {0x998d0051,0x6d4340de,0x42740002,0x00000000}},	// [76d0] czeń_, yona, ргус,
  { {0x60dc193b,0x672410f5,0x50670044,0x00000000}},	//   _carm, _zmij, نطاق,
  { {0xd260001c,0x61e624fd,0x6d4340df,0x00000000}},	//   ļņas_, _erkl, vona,
  { {0x6d430dde,0x6d48330d,0x5ea40021,0x00000000}},	//   wona, _akda, لممل,
  { {0xddc53121,0x61e6007d,0x60dc22dc,0x00000000}},	//   убли, _grkl, _farm,
  { {0x6d4301f4,0x3f47004b,0x621a00ff,0x00000000}},	//   uona, tõus_, _טורק,
  { {0x8b94000d,0x5f942b51,0x6f000089,0x00000000}},	//   арыч, _вист, _fomc,
  { {0xe9d9247b,0x2eed006c,0x6d432283,0x00000000}},	//   еки_, _unef_, sona,
  { {0x764d0dac,0x6d4340e0,0x7c3a13cd,0x00000000}},	//   _nyay, pona, _extr,
  { {0x6724017f,0x08d50062,0x29110061,0x00000000}},	//   _smij, уция, óza_,
  { {0xd8253e42,0xaf910085,0x8afd004c,0x00000000}},	//   удни, авiл, emře,
  { {0x290c00a4,0xeef50063,0x7d0140e1,0x00000000}},	//   akda_, אמֹר_, _hols,
  { {0xaa0b0021,0x2d80003b,0x7d0140e2,0x00000000}},	//   _تزال_, ţiev_, _kols,
  { {0x998d0051,0x7afb40e3,0x7d010206,0x00000000}},	//   rzeń_, ljut, _jols,
  { {0xdce90066,0x998d0051,0x7d0140e4,0x00000000}},	//   _oveľ, szeń_, _mols,
  { {0x7afb06a7,0x6724007d,0x26de001c,0x00000000}},	//   njut, _umij, ētos_,
  { {0x60dc40e5,0x7d0140e6,0x236000c2,0x00000000}},	// [76e0] _parm, _ools, rmij_,
  { {0x7afb004b,0x98a50078,0x236000ca,0x00000000}},	//   hjut, rolė_, smij_,
  { {0x60dc40e7,0x68fc40e8,0xbeaa007e,0x00000000}},	//   _varm, ördi, فهان_,
  { {0x69cb03a8,0xee3a126b,0x7f5b006d,0x00000000}},	//   _opge, нне_, _chuq,
  { {0x7afb40e9,0x61e640ea,0x7d0140eb,0x00000000}},	//   djut, _urkl, _bols,
  { {0xfbd20021,0x7d010d2e,0x61e440ec,0x00000000}},	//   متع_, _cols, mvil,
  { {0x6f000fef,0x69d900ca,0x39453fae,0x00000000}},	//   _tomc, _aswe, dols_,
  { {0x61e40526,0x29030137,0x7afb087b,0x00000000}},	//   ovil, öjan_, gjut,
  { {0xcb670001,0xee37005a,0x25a001f2,0x00000000}},	//   ћање_, _бнт_, _nvil_,
  { {0x41bb00b5,0x91bb0149,0x7afb004b,0x00000000}},	//   עציע, עמיי, ajut,
  { {0x473512ad,0xac970021,0xd8e3000d,0x00000000}},	//   инос, _إنما_, сцып,
  { {0x7bda40ed,0xd6db2049,0x80370041,0x00000000}},	//   _istu, хто_, רנטע_,
  { {0x7d010058,0x466b0121,0x39453fae,0x00000000}},	//   _yols, эром_, bols_,
  { {0xdb1a017d,0x69c00006,0x61e440ee,0x00000000}},	//   _estô, mtme, dvil,
  { {0x25a00034,0xa9230080,0xd4980121,0x00000000}},	//   _evil_, ížej, ыря_,
  { {0x2bac0235,0x67bb0063,0x69c0006f,0x00000000}},	//   _घटना, _נמחק, otme,
  { {0x26c90035,0x69c040ef,0x765a0051,0x00000000}},	// [76f0] _ibao_, ntme, ętyc,
  { {0x31c40001,0x7bda40f0,0x9268042a,0x00000000}},	//   љств, _ostu, урса_,
  { {0x7d010229,0x69c0004b,0xb17b08a9,0x00000000}},	//   _rols, htme, _kråk,
  { {0x69c010ed,0x7d010e6c,0x5064013f,0x00000000}},	//   ktme, _sols, стуа,
  { {0xfda70001,0x7d0103a4,0x829a0047,0x00000000}},	//   ујем, _pols, _בױרק,
  { {0x7b210003,0x1bb9007e,0xfce5076a,0x00000000}},	//   nœuv, نابع_, роко,
  { {0x61140001,0x6e950086,0x2d84005b,0x00000000}},	//   _удру, _вибу, _etme_,
  { {0x7afb004b,0x49c90330,0xdb03004b,0x00000000}},	//   ujut, влин_, htnö,
  { {0x7afb0004,0xdb180080,0x39450268,0x00000000}},	//   rjut, ctví, tols_,
  { {0x2b401312,0xf840008b,0x661d001c,0x00000000}},	//   čica_, ườn_, dzsk,
  { {0x69c00034,0x61e4082a,0x7b1500f8,0x00000000}},	//   atme, zvil, _cáuc,
  { {0xd5e60076,0xf7461518,0x96660713,0x00000000}},	//   ажми, ремо, икне,
  { {0x394540f1,0x69c000e5,0xd7f8003b,0x00000000}},	//   pols_, ctme, axă_,
  { {0x69cc003b,0x7bda002b,0x2ed20042,0x00000000}},	//   âneş, _ystu, _सस्त,
  { {0xdb030019,0x232a0caa,0xe29a35d2,0x00000000}},	//   punä, вови_, кав_,
  { {0x25a000d1,0x27ea00b9,0x61e440f2,0x00000000}},	//   _tvil_, æbne_, tvil,
  { {0xc0760001,0x64a60336,0x61e41b1e,0x00000000}},	// [7700] аћењ, _капа, uvil,
  { {0x865b014e,0x11d70021,0x61e440f3,0x00000000}},	//   _בדפי, ؤولة_, rvil,
  { {0x61e440f4,0x98be008f,0x9c7c0130,0x00000000}},	//   svil, notā_, _jače,
  { {0x539b014e,0x9c7c3319,0x98ac008f,0x00000000}},	//   _ביטו, _mače, indā_,
  { {0xd83808ea,0x69c001bb,0x9c7c00c2,0x00000000}},	//   mače_, xtme, _lače,
  { {0x1d890021,0xd8381058,0x98be0023,0x00000000}},	//   ائني_, lače_, kotā_,
  { {0xed570001,0x9c7c3692,0x2bb70021,0x00000000}},	//   јој_, _nače, لاية_,
  { {0xa3e70161,0x6f19001f,0x7bda0114,0x00000000}},	//   पित_, chwc, _vstu,
  { {0xb99702dc,0x3f680058,0x00000000,0x00000000}},	//   авых_, _oğuz_,   ,
  { {0x57b40076,0xdde9007e,0x9c7c007d,0x00000000}},	//   ббот, _حرفه_, _bače,
  { {0x69c040f5,0x8c460a74,0xb17b00df,0x00000000}},	//   stme, _теже, _pråk,
  { {0xf53f0a2e,0x6b8a254c,0xb0c60053,0x00000000}},	//   pråk_, mpfg, र्तग,
  { {0x661d0080,0xef110047,0x95d80062,0x00000000}},	//   uzsk, פּט_, адят_,
  { {0xf8060086,0x661d0066,0x98be008f,0x00000000}},	//   _вчин, rzsk, botā_,
  { {0x68fc0019,0xe4e4000d,0xb17b0137,0x00000000}},	//   ördu, ціян, _tråk,
  { {0xd83800c3,0x27a90047,0xd3700021,0x00000000}},	//   gače_, _עספּ, ِهِ_,
  { {0x9c7c0198,0x94ab0002,0xcad7009a,0x00000000}},	// [7710] _zače, _итна_, סומת_,
  { {0x823400f2,0x2ba70042,0x87da0042,0x00000000}},	//   زرقا, _गिला, _बनाऊ,
  { {0xd4980088,0x2007000c,0x6f19002b,0x00000000}},	//   _тры_, âni_, thwc,
  { {0x63b500c2,0xf3fa0041,0xc7f7009a,0x00000000}},	//   muzn, _עִיל, יזבת_,
  { {0xa2f60063,0xd83800a8,0x9758009a,0x00000000}},	//   _המרה_, načb_, ביאו_,
  { {0x645a004d,0x8b951e1b,0x00000000,0x00000000}},	//   ütig, брич,   ,
  { {0xdb03006d,0x1d060062,0xdfd80062,0x00000000}},	//   erná, сещи_, _кът_,
  { {0xd4380165,0x9c7c00a8,0x2bb80042,0x00000000}},	//   יטוי_, _rače, _इमरा,
  { {0xd5ed001b,0x9c7c007d,0xceb203c3,0x00000000}},	//   _ngà, _sače, _מין_,
  { {0x2903007a,0x63b501f4,0x7b17003b,0x00000000}},	//   ðja_, kuzn, nţuz,
  { {0x382940f6,0x69ce00dd,0x57460062,0x00000000}},	//   ужно_, ăbea, йноб,
  { {0x273200c3,0xfb84007e,0x1ae40054,0x00000000}},	//   kšne_, _بگوی, _моєм,
  { {0xda78011c,0x4df900b5,0x99850032,0x00000000}},	//   _тях_, נפֿא, _التو,
  { {0xaa58005e,0x63a80260,0xa8790041,0x00000000}},	//   _тичу_, ádno, _גאַר,
  { {0x58f60063,0xd8380114,0x7bc33e13,0x00000000}},	//   _למסע_, tače_, ntnu,
  { {0xf7430a36,0x7bc30014,0xdb0a004c,0x00000000}},	//   _нещо, itnu, oufá,
  { {0x7bc3004b,0xdb030014,0x171b0063,0x00000000}},	// [7720] htnu, funú, _תופע,
  { {0x64481255,0x7bc308a9,0x5046007b,0x00000000}},	//   üdis, ktnu, безб,
  { {0xee86000d,0x44770063,0xd838007d,0x00000000}},	//   было, _לעיל_, pače_,
  { {0xbda60032,0xf487007e,0xdfcf00f2,0x00000000}},	//   محتو, _پایی, عين_,
  { {0xdee50032,0x7bc30066,0x1df80121,0x00000000}},	//   تألي, etnu, релы_,
  { {0xdce10078,0xf53f00a5,0xa11601f3,0x00000000}},	//   _kilę, rsåg_, _اوست,
  { {0xeb4a0062,0xeb9702f8,0x9be6046e,0x00000000}},	//   лчик_, биј_, сілк,
  { {0x2b4000c3,0xef91007e,0xe29f0026,0x00000000}},	//   čico_, _آیند, _koða_,
  { {0x7bc31207,0xed5a0142,0xee3a40f7,0x00000000}},	//   atnu, _боа_, _сна_,
  { {0x9d460121,0x00000000,0x00000000,0x00000000}},	//   _уезд,   ,   ,
  { {0xd6d5026c,0x6d4a00be,0xd787005d,0x00000000}},	//   ожны, mofa, ینیو_,
  { {0x3057014e,0x6d4a1964,0xab6640f8,0x00000000}},	//   משיך_, lofa, _увел,
  { {0xceb30063,0x8cbf0053,0x96340085,0x00000000}},	//   היר_, ल्को, зняц,
  { {0x6d4a40f9,0x80ca0042,0x49bb009d,0x00000000}},	//   nofa, स्मे, _עמוס,
  { {0x93880055,0x7ae20019,0x2418026c,0x00000000}},	//   йста_, _kaot, боры_,
  { {0x7ae20ff2,0xe29f0026,0xddc90051,0x00000000}},	//   _jaot, _boða_, _cześ,
  { {0x9099199c,0x6d4a40fa,0xa5bb013d,0x00000000}},	// [7730] иват_, kofa, szób,
  { {0x29c2007a,0x7bc30a63,0x672f0051,0x00000000}},	//   iða_, ytnu, licj,
  { {0x660f00c7,0x8fa40044,0xc7a9009d,0x00000000}},	//   lyck, كمله, ֹׁנָ,
  { {0xdb030024,0x672f0051,0x3f87008f,0x00000000}},	//   sunú, nicj, īnu_,
  { {0x660f0137,0x645a0014,0x644a0022,0x00000000}},	//   nyck, ýtiv, ęliś,
  { {0xdb1821ad,0x212a40fb,0x7c8401ce,0x00000000}},	//   ntvæ, _gmbh_, пуће,
  { {0x9b450593,0x29c20046,0xc058014b,0x00000000}},	//   ينتو, eða_, _гіт_,
  { {0xc9a9011c,0x3eb902ab,0x2f18000d,0x00000000}},	//   авие_, _øst_, _лось_,
  { {0x88d50088,0x29c20026,0x7bc30d7d,0x00000000}},	//   оўні, gða_, stnu,
  { {0x660f0080,0x6d4a0051,0x98a5008f,0x00000000}},	//   dyck, cofa, filā_,
  { {0x29c20026,0xe8f6013c,0xb17b0b2a,0x00000000}},	//   aða_, ілю_, _gråv,
  { {0xdb180146,0x68fc0504,0xe7370054,0x00000000}},	//   etvæ, ördr, жею_,
  { {0xdb1800b9,0x18a53343,0x98a505a1,0x00000000}},	//   ftvæ, _далм, _диле,
  { {0x98a5001c,0xddc90051,0xdd7a0047,0x00000000}},	//   bilā_, _sześ, יטשל,
  { {0x68e30035,0x9c7c007d,0xccf20063,0x00000000}},	//   _iand, _jača, וכם_,
  { {0x6d4a0009,0x25ad0080,0x6abb3845,0x00000000}},	//   zofa, šela_, nguf,
  { {0xd83800c3,0x6d4a0035,0x290740fc,0x00000000}},	// [7740] mača_, yofa, _kona_,
  { {0x68e3189e,0x290740fd,0xd83838d3,0x00000000}},	//   _jand, _jona_, lača_,
  { {0x68e315f3,0xdfa60044,0x9c7c0cff,0x00000000}},	//   _mand, تحذي, _nača,
  { {0x29c20026,0x645e40fe,0x68e340ff,0x00000000}},	//   yða_, _izpi, _land,
  { {0x6d4a4100,0x6da31b08,0x57b60082,0x00000000}},	//   tofa, дича, _अम्ह,
  { {0x7ae20025,0x68e34101,0x29074102,0x00000000}},	//   _saot, _nand, _nona_,
  { {0x26c0006d,0x62840e1a,0x6d4a209c,0x00000000}},	//   _ocio_, ocio, rofa,
  { {0x68e304c6,0x62841513,0x39a60086,0x00000000}},	//   _aand, ncio, ошов,
  { {0x29070268,0x68e34103,0x62844104,0x00000000}},	//   _bona_, _band, icio,
  { {0x29c2007a,0x7afd0db3,0xed5a0062,0x00000000}},	//   rða_, östr, _тоз_,
  { {0x7ae20004,0xc07b0047,0x69dd00b9,0x00000000}},	//   _taot, יטיש, æser,
  { {0x3f850003,0x660f0d45,0x80ca0053,0x00000000}},	//   _élue_, tyck, स्ते,
  { {0x7d080137,0x2907001c,0x68e34105,0x00000000}},	//   _kods, _fona_, _fand,
  { {0x660f2c30,0x32d5008b,0x62864106,0x00000000}},	//   ryck, _ấy_, _afko,
  { {0x7d080146,0x98be0078,0xdb1801e1,0x00000000}},	//   _mods, gotą_, rtvæ,
  { {0x68e31215,0x290704cf,0x53350054,0x00000000}},	//   _zand, _zona_, чебт,
  { {0x7d0800f5,0x291e0ff2,0x68e3005b,0x00000000}},	// [7750] _oods, ohta_, _yand,
  { {0xa5080001,0x98ac0006,0x62841814,0x00000000}},	//   _мења_, rodė_, acio,
  { {0x645a0026,0x9743007d,0x3cfe0053,0x00000000}},	//   ýtit, šćuj, लाने_,
  { {0x62843ab4,0xb17b00d1,0x26d919a8,0x00000000}},	//   ccio, _bråt, neso_,
  { {0xfe7004de,0x291e0089,0xcddb02d8,0x00000000}},	//   نده_, khta_, рње_,
  { {0xd838007d,0x3eba0078,0x8b954107,0x00000000}},	//   zača_, ėpta_, прич,
  { {0xeb990b0f,0xce95005a,0x29074108,0x00000000}},	//   щий_, _навъ, _rona_,
  { {0x273200c3,0x29074109,0x68e3410a,0x00000000}},	//   kšna_, _sona_, _sand,
  { {0xd838410b,0x68e30231,0x629d410c,0x00000000}},	//   vača_, _pand, _meso,
  { {0x2ba5003d,0x9c7c007d,0x7d082bec,0x00000000}},	//   pēc_, _tača, _gods,
  { {0x6f1b0045,0xd8381401,0x26d91928,0x00000000}},	//   _kluc, tača_, feso_,
  { {0xa6db0026,0x629d410d,0x68e3410e,0x00000000}},	//   koðu, _neso, _wand,
  { {0xe9ce410f,0x291e0025,0xd8380c61,0x00000000}},	//   _як_, bhta_, rača_,
  { {0x291e10c3,0x68e30cda,0xd838007d,0x00000000}},	//   chta_, _uand, sača_,
  { {0x629d4110,0x6f1b4111,0x78a118d2,0x00000000}},	//   _beso, _oluc, malv,
  { {0x26d94112,0x98a50529,0x672d00a8,0x00000000}},	//   ceso_, bilă_, _gmaj,
  { {0x28c20161,0x62843ab4,0x98a5003b,0x00000000}},	// [7760] _शामि, rcio, cilă_,
  { {0x20b9000d,0x62840b27,0x645a0014,0x00000000}},	//   жыць_, scio, ýtis,
  { {0x62841e4c,0x629d01a8,0x6f02003b,0x00000000}},	//   pcio, _feso, tjoc,
  { {0x629d4113,0xa6db0026,0x78a14114,0x00000000}},	//   _geso, boðu, halv,
  { {0x78a13d91,0x7d084115,0xed5a0505,0x00000000}},	//   kalv, _pods, бод_,
  { {0x6022000f,0xac970021,0x5cc30062,0x00000000}},	//   _címé, كنها_, есъз,
  { {0x7d084116,0x6f1b0a04,0x6e22013d,0x00000000}},	//   _vods, _fluc, szob,
  { {0x612001f7,0xdee3280d,0xa03b00b5,0x00000000}},	//   _bölg, _поси, _העלפ,
  { {0xdb0a0137,0x44444117,0x7999002b,0x00000000}},	//   ktfö, _lx_, _cwww,
  { {0x78a1109f,0x98a5003b,0x9c7c4118,0x00000000}},	//   galv, vilă_, _začn,
  { {0x80c10161,0x61200026,0x26d90290,0x00000000}},	//   र्टे, _tölf, teso_,
  { {0x9bfb0063,0x6120252f,0x98a5003b,0x00000000}},	//   _להבט, _höld, tilă_,
  { {0x69d5003b,0x26d932bb,0x78a1008f,0x00000000}},	//   ăzec, reso_, balv,
  { {0x26d900bb,0x629d4119,0x25640026,0x00000000}},	//   seso_, _seso, jöld_,
  { {0xd83800c3,0xccf80080,0x26d93e47,0x00000000}},	//   mačo_, _mně_, peso_,
  { {0x083b0063,0xc7d70063,0xd7bb0063,0x00000000}},	//   _לעול, _זוהי_, _הצהר,
  { {0x629d00c3,0x9f470025,0x71780141,0x00000000}},	// [7770] _veso, íní_, збур_,
  { {0x4444411a,0x6d58006f,0x612b0051,0x00000000}},	//   _fx_, jlva, ożli,
  { {0x6f09411b,0x629d08c9,0x25a901e1,0x00000000}},	//   _poec, _teso, _hval_,
  { {0x63b50198,0x3ce50290,0x25a90137,0x00000000}},	//   mrzn, _salv_, _kval_,
  { {0x6f1b0122,0xdef4000d,0x1d09150a,0x00000000}},	//   _vluc, эпцы, жели_,
  { {0xcfb50094,0x61ed411c,0xf3b7009a,0x00000000}},	//   _обгъ, mval, ִּ֔י_,
  { {0x9c7c017f,0x78a1047f,0x61ed411d,0x00000000}},	//   _tačn, valv, lval,
  { {0x7b150024,0x291c411e,0x6d5808c9,0x00000000}},	//   _záuj, _alva_, alva,
  { {0xe29f0ac6,0x3ead02ab,0x6120000f,0x00000000}},	//   _með_, _idet_, _föld,
  { {0xdb0a0137,0xdb030139,0x9835000d,0x00000000}},	//   xtfö, isné, дэмі,
  { {0x6d41006f,0x25a9411f,0x61ed4120,0x00000000}},	//   _ijla, _aval_, hval,
  { {0x291c334a,0xdb030024,0xda150002,0x00000000}},	//   _elva_, hrnú, _одењ,
  { {0x78a1024a,0xdb0a00c7,0x27220013,0x00000000}},	//   palv, ttfö, _lóng_,
  { {0x44444121,0xf8ce0013,0x61ed4122,0x00000000}},	//   _px_, _hứng_, dval,
  { {0x58d20635,0x2722008b,0x58940021,0x00000000}},	//   _ројт, _nóng_, _أجهز,
  { {0x7ae93495,0x69c94123,0xdb0a161b,0x00000000}},	//   ndet, otee, stfö,
  { {0x69c93c97,0x61ed4124,0x64450725,0x00000000}},	// [7780] ntee, gval, _exhi,
  { {0x7ae900fe,0x2722008b,0x2b4008ea,0x00000000}},	//   hdet, _bóng_, čici_,
  { {0x69c9024a,0x044603d6,0x33660095,0x00000000}},	//   htee, _ценн, _овог,
  { {0x69c91869,0xa25b0164,0x61ed001c,0x00000000}},	//   ktee, _icôn, bval,
  { {0x8d6a00d7,0x63bc0bad,0x7ae916c5,0x00000000}},	//   ојка_, lurn, ddet,
  { {0x273200c3,0x69c90019,0x63bc4125,0x00000000}},	//   kšno_, dtee, ourn,
  { {0x61200026,0x69c90466,0x273200c2,0x00000000}},	//   _völd, etee, jšno_,
  { {0x69c90034,0xf8ce008b,0x7ae94126,0x00000000}},	//   ftee, _cứng_, gdet,
  { {0x7b730021,0x49740002,0xf8ce008d,0x00000000}},	//   خطوا, нлис, _dứng_,
  { {0x7ae90891,0xd9170121,0x63bc4127,0x00000000}},	//   adet, дью_, kurn,
  { {0x3ead00b9,0x9c830114,0x8c3c005b,0x00000000}},	//   _ydet_, _účas, _beğe,
  { {0x63bc4128,0x872b000d,0x61ed1d13,0x00000000}},	//   durn, іўна_, yval,
  { {0x69c902b0,0x8c3c01f7,0x8a030062,0x00000000}},	//   ctee, _değe, _изце,
  { {0x63b50051,0x8e20000d,0x29030137,0x00000000}},	//   trzn, нiк_, öjat_,
  { {0x63bc0117,0xd7e60086,0x58bb0063,0x00000000}},	//   gurn, _ціло, _ומוצ,
  { {0xf8ce008b,0x2d5b017d,0x61ed4129,0x00000000}},	//   _xứng_, vêem_, tval,
  { {0x2722008b,0xd567412a,0x41790021,0x00000000}},	// [7790] _sóng_, _отоп, سماح_,
  { {0x3f870016,0x7ae900ea,0x7bca06f1,0x00000000}},	//   ínuo_, zdet, ktfu,
  { {0x7535051e,0x61ed412b,0x7ae9412c,0x00000000}},	//   mizz, sval, ydet,
  { {0x7535104f,0x26dc0047,0x69c900fe,0x00000000}},	//   lizz, ַקומ, ytee,
  { {0x69c90034,0xa3e70042,0x80ca0082,0x00000000}},	//   xtee, पिक_, _सॉके,
  { {0x7535051e,0x7bca3385,0x69c9004b,0x00000000}},	//   nizz, ftfu, vtee,
  { {0x4fc4082b,0x7bca01e1,0x7ae9412d,0x00000000}},	//   _иста, gtfu, tdet,
  { {0x69c9024a,0x753501f4,0x7ae9004a,0x00000000}},	//   ttee, hizz, udet,
  { {0x7ae903e8,0x69c90213,0xae590041,0x00000000}},	//   rdet, utee, _זכּר,
  { {0x7ae902ea,0x7bca00e5,0x6e45003b,0x00000000}},	//   sdet, btfu, ărbă,
  { {0xa5bb00ea,0x69c9412e,0x6be40021,0x00000000}},	//   szól, stee, _لكلم,
  { {0x69c9412f,0x612000ea,0xfc160047,0x00000000}},	//   ptee, _kölc, _אקעי_,
  { {0x6b810019,0x4a9a0047,0x29030137,0x00000000}},	//   _hulg, _זינג, öjas_,
  { {0x6b81004b,0xb6070014,0x59d80042,0x00000000}},	//   _kulg, _spáð, _बैटर,
  { {0xc878005b,0x6b814130,0xf8b2089e,0x00000000}},	//   teğe_, _julg, _עשה_,
  { {0x63bc0014,0xd83e004c,0x6b81016c,0x00000000}},	//   rurn, íčem_, _mulg,
  { {0x22460058,0x2aba0058,0x2247080b,0x00000000}},	// [77a0] çok_, lübü_, епти_,
  { {0x753502f6,0x63bc1d3d,0x22590051,0x00000000}},	//   cizz, purn, _dysk_,
  { {0x5436005d,0xa3e70042,0xb80f0042,0x00000000}},	//   _سردر, _मैप_, ाहिम_,
  { {0x26c2002c,0x73e30376,0x612000ea,0x00000000}},	//   ngko_, _союз, _bölc,
  { {0xed5a0138,0xf2d30041,0x2d960054,0x00000000}},	//   под_, _גער_, хрес,
  { {0x61e60117,0x7bca01bb,0x6b814131,0x00000000}},	//   _iskl, ttfu, _bulg,
  { {0x27220066,0x22590022,0x61433266,0x00000000}},	//   _zóne_, _zysk_, _сера,
  { {0x200d005b,0x63a1003b,0x61e605a5,0x00000000}},	//   çmiş_, âlni, _kskl,
  { {0x98ac008f,0xf98f007e,0x7bca4132,0x00000000}},	//   eidā_, یبی_, stfu,
  { {0x6b813c68,0x9c7c0648,0xf1b32177,0x00000000}},	//   _fulg, _mačk, נסת_,
  { {0x75350290,0x31370063,0x645a004b,0x00000000}},	//   vizz, תנים_, ütil,
  { {0xfaa60239,0x29030137,0x8c1b0063,0x00000000}},	//   _чадо, öjar_, _מובי,
  { {0x7535051e,0x4b370063,0xb714079f,0x00000000}},	//   tizz, _אראל_, удящ,
  { {0x2b40017f,0x22590137,0xe4e40636,0x00000000}},	//   čicu_, _rysk_, лісн,
  { {0x75354133,0x39570063,0xd90e005d,0x00000000}},	//   rizz, _רשום_, _نیک_,
  { {0x3f87007a,0x443f000c,0x9c7c10a9,0x00000000}},	//   ínum_, ău_, _bačk,
  { {0x75354134,0x80c20042,0xbb3b009a,0x00000000}},	// [77b0] pizz, _लाशे, פעמי,
  { {0x6aa20139,0x98be004c,0xf124030b,0x00000000}},	//   _leof, votě_, льхо,
  { {0x7b1c0164,0x442700c7,0xc435007e,0x00000000}},	//   _réun, _ån_, _شکست,
  { {0x225904b1,0xdb01004a,0x290e4135,0x00000000}},	//   _tysk_, _ovlá, _lofa_,
  { {0x6463017f,0x6b810019,0x1bf90042,0x00000000}},	//   štić, _sulg, ऍमऍल_,
  { {0x271e0053,0x6b814136,0xb8200042,0x00000000}},	//   _पत्र_, _pulg, मनाम_,
  { {0xfaf10021,0x1d060062,0xcb690044,0x00000000}},	//   لثة_, тещи_, ومته_,
  { {0xe29f0026,0x6b81253a,0x6120013d,0x00000000}},	//   _boði_, _vulg, _tölc,
  { {0x39450d64,0x6b810022,0xe9692338,0x00000000}},	//   книг, _wulg, маил_,
  { {0x3f83004b,0x6b81004b,0xcda80044,0x00000000}},	//   _kuju_, _tulg, _أهله_,
  { {0x9783007e,0x2ca71865,0x08d40085,0x00000000}},	//   دیبه, mand_, уцыя,
  { {0x81c3008f,0xeb980054,0x2ca74137,0x00000000}},	//   ģēju, _чиї_, land_,
  { {0x7aeb00b9,0xee32009a,0x00000000,0x00000000}},	//   _iagt, ֹֽר_,   ,
  { {0x32dc0013,0x2ca74138,0x00000000,0x00000000}},	//   _ậy_, nand_,   ,
  { {0xdb010114,0x03a30121,0x64a3296c,0x00000000}},	//   _zvlá, ииро, раса,
  { {0x78a30307,0x7aeb3456,0x2ca74139,0x00000000}},	//   _henv, _jagt, hand_,
  { {0x7aeb413a,0x98a50051,0x60ea0121,0x00000000}},	// [77c0] _magt, wilę_, ммам_,
  { {0x7aeb00c7,0x4f96000a,0x3123000d,0x00000000}},	//   _lagt, врду, адуг,
  { {0x98ac000c,0x934601d5,0xdff5071f,0x00000000}},	//   lidă_, _анне, ляць,
  { {0x7aeb00bb,0x9c7c017f,0xee3a413b,0x00000000}},	//   _nagt, _tačk, мне_,
  { {0x2ca700bd,0x5436007e,0x61e61ce6,0x00000000}},	//   fand_, _سرگر, _uskl,
  { {0x2ca7413c,0x5d530085,0x9c7c413d,0x00000000}},	//   gand_, акіт, _kači,
  { {0x9c7c007d,0x4fa30086,0x98ac003b,0x00000000}},	//   _jači, _висв, hidă_,
  { {0x9f4a00cd,0x25ad004c,0x2ca700ca,0x00000000}},	//   _urbà_, šeli_, aand_,
  { {0x78a3413e,0xcb670001,0xd838082a,0x00000000}},	//   _benv, њање_, mači_,
  { {0x61e400bd,0xd8380734,0x2ca7413f,0x00000000}},	//   iwil, lači_, cand_,
  { {0x61e41ac6,0x78a34140,0x2d844141,0x00000000}},	//   hwil, _denv, _hume_,
  { {0x9c7c065f,0x78a30173,0xd83802e2,0x00000000}},	//   _nači, _eenv, nači_,
  { {0xfb1b014e,0x61e4006f,0x25ad0003,0x00000000}},	//   _קודמ, jwil, éel_,
  { {0x78a30553,0x69c04142,0x7ae04143,0x00000000}},	//   _genv, mume, lemt,
  { {0x2d8406c6,0x24580121,0x61e44144,0x00000000}},	//   _lume_, варь_, ewil,
  { {0x3ea40146,0x395e0137,0x08570063,0x00000000}},	//   _nemt_, llts_, _שבהם_,
  { {0x2d840529,0x60f91485,0x395e3170,0x00000000}},	// [77d0] _nume_, нная_, olts_,
  { {0xdce80080,0x7bda017f,0x31c40dd5,0x00000000}},	//   _vidě, _optu, јств,
  { {0x442a0051,0x69c04145,0x2ca74146,0x00000000}},	//   czb_, hume, vand_,
  { {0x4e940032,0x2ca7050c,0x3cfe0150,0x00000000}},	//   لشهر, wand_, _antv_,
  { {0x7bda003d,0x4ed40086,0x2d84017d,0x00000000}},	//   _aptu, рюєт, _cume_,
  { {0x7aeb4147,0x3f8324ed,0x63ba2414,0x00000000}},	//   _sagt, _tuju_, štne,
  { {0x7aeb00bb,0x31340055,0x78a30164,0x00000000}},	//   _pagt, _терр, _renv,
  { {0x3ea40146,0x39e90001,0x7b150460,0x00000000}},	//   _gemt_, едио_, _náut,
  { {0x2ca70cfc,0x7aeb00b9,0x69c04148,0x00000000}},	//   pand_, _vagt, gume,
  { {0x7aeb4149,0x78a800ea,0x645a004b,0x00000000}},	//   _wagt, gadv, ütik,
  { {0x6ac80137,0x6bb40086,0x9815007e,0x00000000}},	//   ärfö, _всіє, ابخا,
  { {0x2ca537b2,0x7aeb05b9,0x69c0414a,0x00000000}},	//   _held_, _uagt, bume,
  { {0x6d43414b,0x9a840062,0x27320013,0x00000000}},	//   onna, _тухл, hơng_,
  { {0x27220268,0x3eba0006,0x26cf0137,0x00000000}},	//   _dóna_, ėpti_, _ögon_,
  { {0x9c7c00eb,0x2ca5414c,0x68e10421,0x00000000}},	//   _pači, _meld_, meld,
  { {0x28cf0161,0x98ac000c,0x273200c3,0x00000000}},	//   त्रि, pidă_, kšni_,
  { {0x62660079,0xd838267a,0x6724414d,0x00000000}},	// [77e0] уваа, vači_, _ilij,
  { {0x68e1414e,0x61e424f5,0xdcfb007d,0x00000000}},	//   neld, rwil, _otuđ,
  { {0x67240117,0x9c7c00eb,0x69c00d76,0x00000000}},	//   _klij, _tači, zume,
  { {0x68e1414f,0x9186007e,0x643b0063,0x00000000}},	//   held, _مجسم, _טעינ,
  { {0xdd8f0032,0x6724007d,0x4dd30021,0x00000000}},	//   كون_, _mlij, متوس,
  { {0x68e139c8,0xdb180026,0xd838007d,0x00000000}},	//   jeld, ruví, sači_,
  { {0xa0670079,0x68e10180,0x7ae04150,0x00000000}},	//   _бара_, deld, temt,
  { {0x69c04151,0x5b140174,0x6d434152,0x00000000}},	//   tume, рмит, anna,
  { {0x2ca500bd,0xdb0a0164,0x78a84153,0x00000000}},	//   _feld_, nsfé, tadv,
  { {0xdb0100c7,0x68e10fd6,0x69c04154,0x00000000}},	//   _avlä, geld, rume,
  { {0x672402b0,0x6ac6006a,0x815700b5,0x00000000}},	//   _blij, _مقام, רסיע_,
  { {0x39890026,0x37070002,0x67244155,0x00000000}},	//   _fús_, учов, _clij,
  { {0x68e14062,0xe5c70085,0x00000000,0x00000000}},	//   beld, ысно,   ,
  { {0x7e7d0024,0x67244156,0xe2a60014,0x00000000}},	//   _úspe, _elij, áðna_,
  { {0xf770007e,0xdb030014,0xb21b0046,0x00000000}},	//   تای_, runö, _nfær,
  { {0x57fb0063,0x6724006f,0x322b0454,0x00000000}},	//   _טלוו, _glij, нізм_,
  { {0x6d430185,0x41b5007e,0x291e0058,0x00000000}},	// [77f0] ynna, شمار, okta_,
  { {0x9a420013,0xc274005e,0x3eb8008f,0x00000000}},	//   _đằn, слуј, _ērta_,
  { {0xa2d00053,0x67240072,0x291e4157,0x00000000}},	//   _डॉक्, _ylij, ikta_,
  { {0x539a014e,0x256400c7,0x6d5a4158,0x00000000}},	//   _שירו, höll_, _akta,
  { {0xdbde007a,0x61200014,0xde050002,0x00000000}},	//   _síða, _köll, рпли,
  { {0x0bb50062,0x25640014,0x8b050051,0x00000000}},	//   ащия, jöll_, _mięś,
  { {0x2ca50173,0x68e14159,0x5f9405f4,0x00000000}},	//   _veld_, veld, _гист,
  { {0x09d50088,0x2ca50185,0x63a10024,0x00000000}},	//   ацоў, _weld_, álny,
  { {0x25640137,0x68e129bf,0xaa4508b9,0x00000000}},	//   föll_, teld, репл,
  { {0x67240117,0x7d79007e,0xdbde0014,0x00000000}},	//   _slij, _شمار_, _tíða,
  { {0x68e1415a,0x6c840032,0x69dc003b,0x00000000}},	//   reld, _المم, ărea,
  { {0x39890027,0xe73a415b,0x291e415c,0x00000000}},	//   _tús_, тем_, akta_,
  { {0x7b7404de,0xaa880021,0x68e1415d,0x00000000}},	//   _اطلا, _إنهم_, peld,
  { {0xdb0a00bd,0x291e0137,0x4a440454,0x00000000}},	//   zufü, ckta_, _унів,
  { {0x7bc3415e,0x61200058,0x7ce8009a,0x00000000}},	//   nunu, _döll, נַשֶ,
  { {0xc3230fe2,0x95863629,0x6724007d,0x00000000}},	//   омск, _клие, _ulij,

  { {0xb6060006,0x645e0051,0x7bc3415f,0x00000000}},	// [7800] ukšč, _wypi, hunu,
  { {0x7b33003b,0x41033ce8,0xb6060078,0x00000000}},	//   găuz, озув, rkšč,
  { {0x7bc34160,0x3fe612a5,0xafe64161,0x00000000}},	//   junu, ржев, роел,
  { {0x8f450086,0xe8060053,0xa6e20014,0x00000000}},	//   бхід, षमता_, áðhe,
  { {0xcd060c45,0xa5bb013d,0x61200072,0x00000000}},	//   ички, szóv, _yöll,
  { {0x7bc30026,0x21a31375,0x8e200054,0x00000000}},	//   funu, _фирм, нiв_,
  { {0x237f004a,0x9c7c004c,0xfba705ac,0x00000000}},	//   ňuje_, _načt, атый_,
  { {0x3f9a0072,0x7bf70062,0x00000000,0x00000000}},	//   mppu_, рнър_,   ,
  { {0x9c7c1847,0xacea000a,0x7bc34162,0x00000000}},	//   _raču, _имаа_, aunu,
  { {0x9c7c017f,0x7bc34163,0x291e0a10,0x00000000}},	//   _saču, bunu, ukta_,
  { {0x4c36000d,0xdb0300b9,0x291e220d,0x00000000}},	//   _тэат, dsnæ, rkta_,
  { {0x291e007d,0xdc3b0063,0x6d580f18,0x00000000}},	//   skta_, _בעבר, lova,
  { {0x8ccd016a,0x9f6500ea,0xb9940021,0x00000000}},	//   _सामो, ítés_, _التب,
  { {0x61200058,0x48e3005e,0x7c2b0075,0x00000000}},	//   _bölm, _мочв, _ömrü,
  { {0x6b880037,0x80aa0161,0x92a70540,0x00000000}},	//   _judg, टरने, ијал,
  { {0x6d584164,0xa87b0165,0x987b0149,0x00000000}},	//   hova, _באור, _ברוק,
  { {0x673d4165,0x6d580574,0x61f9000d,0x00000000}},	// [7810] misj, kova, ынаў_,
  { {0x6d580114,0x61200137,0x673d4166,0x00000000}},	//   jova, _hölj, lisj,
  { {0x7e6914e0,0x6d580d71,0x44260002,0x00000000}},	//   _szep, dova, _сo_,
  { {0x673d0031,0xbf580086,0x7bc34167,0x00000000}},	//   nisj, арії_, vunu,
  { {0x6d584168,0x8c3c0075,0x00000000,0x00000000}},	//   fova, _değm,   ,
  { {0x6d584169,0x7bc30bcd,0x6b88416a,0x00000000}},	//   gova, tunu, _budg,
  { {0x25640137,0x16a70042,0xbbf50044,0x00000000}},	//   följ_, _ख़ूब, إستث,
  { {0x7f5b00ac,0x7bc3416b,0x0ae90121,0x00000000}},	//   _ukuq, runu, удий_,
  { {0x673d0031,0x7bc32de1,0x6d58416c,0x00000000}},	//   disj, sunu, bova,
  { {0x6d58027d,0x673d00ca,0x7bc3416d,0x00000000}},	//   cova, eisj, punu,
  { {0xbb850032,0xdb180026,0x753c001c,0x00000000}},	//   _الصي, duvæ, virz,
  { {0xb8260200,0xb925005d,0x55e6012c,0x00000000}},	//   союз_, _گفتي, бомб,
  { {0x9878003d,0x612000c7,0xcb120063,0x00000000}},	//   kšķi_, _dölj, _מלא_,
  { {0xa5c70014,0xae5a0041,0xc9640054,0x00000000}},	//   _stóð, רכשר, _двій,
  { {0x612001e3,0x673d04aa,0xc7950049,0x00000000}},	//   _följ, bisj, _اشتب,
  { {0x935a416e,0xe7ec0053,0x6d583059,0x00000000}},	//   ургу_, _जनता_, zova,
  { {0x95c9000a,0xe0da0ae8,0xdb0e00ea,0x00000000}},	// [7820] _куќа_, лва_, ájék,
  { {0x6d580a63,0xd00a026b,0x98be008f,0x00000000}},	//   xova, лезе_, ontā_,
  { {0x6d583af5,0x7e600136,0xdfcf009e,0x00000000}},	//   vova, _symp, فيل_,
  { {0x3f9a00f3,0xdb030137,0x2e4a089d,0x00000000}},	//   rppu_, nsnä, ляло_,
  { {0x9c7c0198,0x6d5804a8,0x98ac0078,0x00000000}},	//   _načr, tova, aidę_,
  { {0x6d5807a0,0x40ab007e,0x00000000,0x00000000}},	//   uova, _مخفی_,   ,
  { {0x661d0051,0x2bb70021,0x6d58416f,0x00000000}},	//   zysk, ماية_, rova,
  { {0x6d5804c8,0x661d0072,0x7e604170,0x00000000}},	//   sova, yysk, _tymp,
  { {0x673d39c8,0x5e4a4171,0x6d58106b,0x00000000}},	//   visj, _спам_, pova,
  { {0x3f8a4172,0x57b40156,0x64400058,0x00000000}},	//   _kubu_, обот, şmiy,
  { {0xa3e70053,0x415b0047,0x515b0063,0x00000000}},	//   _मैं_, רדיג, רכיו,
  { {0xdb030137,0x661d4173,0x95cb0e48,0x00000000}},	//   gsnä, tysk, луга_,
  { {0x99d3014d,0x00000000,0x00000000,0x00000000}},	//   _فتوا,   ,   ,
  { {0x673d0031,0xea770063,0x3f98001c,0x00000000}},	//   sisj, _הגדר_, _otru_,
  { {0xb8de0235,0x9c7c00c2,0x673d00a8,0x00000000}},	//   ेल_, _začr, pisj,
  { {0x6b820035,0xd3700021,0x69c04174,0x00000000}},	//   _jiog, ّهِ_, orme,
  { {0x60870021,0xd7f8003b,0xb11504f2,0x00000000}},	// [7830] مشاك, lvă_, омаш,
  { {0xdb1801cf,0x69c04175,0x00000000,0x00000000}},	//   luvä, irme,   ,
  { {0x69c0004d,0xc1040021,0x7e990044,0x00000000}},	//   hrme, ثولي, لنار_,
  { {0xe2f90086,0xdb18004b,0x9df90320,0x00000000}},	//   _темі_, nuvä, инет_,
  { {0x69c000b9,0x2f740044,0xa22704a0,0x00000000}},	//   jrme, أطلس, _طرحه,
  { {0x2d8100bd,0xe3b0007e,0x3b95005e,0x00000000}},	//   öhe_, _تری_, ојит,
  { {0x251c00b5,0xeb990499,0x69c04176,0x00000000}},	//   רווא, ший_, erme,
  { {0x3f5c0014,0xaf340044,0x00000000,0x00000000}},	//   síur_, _فرقت,   ,
  { {0x6b82001f,0x3eaf00b9,0x799b00a4,0x00000000}},	//   _diog, magt_, upuw,
  { {0x3eaf02ea,0x78a90001,0xdca4005e,0x00000000}},	//   lagt_, шког_, _нађи,
  { {0xd70a0088,0x69c04177,0x186912d5,0x00000000}},	//   анне_, arme, рани_,
  { {0x61ef0025,0xa6db0026,0x61fd01f2,0x00000000}},	//   _oscl, eiðb, _orsl,
  { {0xdb0301e9,0xe9ce0054,0x2564013d,0x00000000}},	//   rsnä, _юк_, löli_,
  { {0x612000bd,0xdb0100d1,0xa6db0014,0x00000000}},	//   _völk, _avlø, viðe,
  { {0xa87900b5,0x98790047,0x61ef3fe1,0x00000000}},	//   _דאַר, _דאַט, _ascl,
  { {0xe29a000a,0x798300bd,0x3f8a4178,0x00000000}},	//   раа_, _hinw, _rubu_,
  { {0x6aab000f,0xa5bb013d,0x80aa3279,0x00000000}},	// [7840] _megf, szór, ивав_,
  { {0x6aab000f,0xb09a0054,0xe046030b,0x00000000}},	//   _legf, ртає_, онзи,
  { {0x61ef4179,0x7983002b,0x6ecd013d,0x00000000}},	//   _escl, _minw, zőbő,
  { {0x57cc00b5,0x9e66417a,0xdb0a00a5,0x00000000}},	//   רמאַ, овед, lufö,
  { {0x2ee60034,0x3f870014,0x4c940121,0x00000000}},	//   reof_, ínur_, пилс,
  { {0x412a0b62,0x98be003b,0xf53f01f2,0x00000000}},	//   _того_, intă_, lsår_,
  { {0xdcfa003d,0x6b820290,0x7ac63510,0x00000000}},	//   _citā, _piog, оспе,
  { {0x6ecd013d,0xa037009a,0x539b009a,0x00000000}},	//   tőbő, _ואלה_, ביקו,
  { {0x6ab9002b,0x69c000ca,0xc8780058,0x00000000}},	//   _ddwf, urme, meği_,
  { {0xdce8003d,0xdddb007d,0xc8780075,0x00000000}},	//   _vidē, _uguš, leği_,
  { {0x99e30024,0xf09301f9,0x79830093,0x00000000}},	//   ĺňaj, ונת_, _dinw,
  { {0x798300bd,0xd7f8000c,0xc878005b,0x00000000}},	//   _einw, rvă_, neği_,
  { {0x6d4a0290,0xdb18004b,0xceb30063,0x00000000}},	//   onfa, ruvä, ויר_,
  { {0x798300a4,0x6d4a417b,0xa3a702d8,0x00000000}},	//   _ginw, nnfa, жјак,
  { {0x68e8417c,0x2cac001f,0x4425417d,0x00000000}},	//   medd, _medd_, ál_,
  { {0x2cac0829,0x6d4a004d,0x249e0058,0x00000000}},	//   _ledd_, hnfa, ıtma_,
  { {0x8c3c04ab,0x2cac0c70,0xe72b007e,0x00000000}},	// [7850] _deği, _oedd_, _مسکو_,
  { {0x68e8001f,0xdb0a00bd,0x2cac001f,0x00000000}},	//   nedd, erfü, _nedd_,
  { {0xdb18004b,0x12950896,0xa295071f,0x00000000}},	//   ltvõ, _нинџ, _нані,
  { {0x68e8001f,0x98ac011b,0x5319009a,0x00000000}},	//   hedd, tidě_, _הוֹצ,
  { {0xed4e0001,0x80d80053,0xc3320047,0x00000000}},	//   ео_, न्हे, _טוט_,
  { {0x68e80031,0x3eaf417e,0x6d4a01e1,0x00000000}},	//   jedd, sagt_, gnfa,
  { {0x68e8417f,0xdb18004b,0x798300a3,0x00000000}},	//   dedd, htvõ, _rinw,
  { {0xc87801f7,0x6d4a1db9,0x7e7d01c8,0x00000000}},	//   ceği_, anfa, _úspo,
  { {0x68e8001f,0x7b1c0003,0x2cac002b,0x00000000}},	//   fedd, _réut, _fedd_,
  { {0x3ead0122,0x61ed3576,0x6aab004d,0x00000000}},	//   _heet_, iwal, _wegf,
  { {0x25a90397,0x3f850003,0xe8f60054,0x00000000}},	//   _awal_, _élus_, їлю_,
  { {0xd5b8003d,0x61ed4180,0x2cac0c5f,0x00000000}},	//   ņām_, kwal, _zedd_,
  { {0x7ae90019,0x3ead0112,0x98ac0058,0x00000000}},	//   meet, _meet_, aldı_,
  { {0x61ed4181,0x7ae94182,0x6a240044,0x00000000}},	//   dwal, leet, _تفهم,
  { {0x2d854183,0x69c94184,0x29074185,0x00000000}},	//   _mile_, luee, _inna_,
  { {0x2d850035,0x7ae9065c,0x2b910013,0x00000000}},	//   _lile_, neet, _mác_,
  { {0x63b5000f,0x229c0080,0x61ed4186,0x00000000}},	// [7860] aszn, jáků_, gwal,
  { {0x3f840009,0x2d85077d,0x7ae94187,0x00000000}},	//   _simu_, _nile_, heet,
  { {0xc878005b,0xa6db0026,0x7ae90019,0x00000000}},	//   teği_, liða, keet,
  { {0x2cac0cc7,0x2d854188,0x6d4a00e5,0x00000000}},	//   _sedd_, _aile_, wnfa,
  { {0x2d854189,0x61ed00ac,0x7ae9004b,0x00000000}},	//   _bile_, cwal, deet,
  { {0x2b91008b,0x2d850290,0x6d4a418a,0x00000000}},	//   _bác_, _cile_, unfa,
  { {0x2b9100aa,0x9c7c0198,0x3f84418b,0x00000000}},	//   _các_, _obče, _timu_,
  { {0x2d85018d,0x68e80185,0x93fb014e,0x00000000}},	//   _eile_, wedd, מלצי,
  { {0x2d85055b,0x68e8002b,0x2cac013d,0x00000000}},	//   _file_, tedd, _tedd_,
  { {0x29180026,0xfe45007e,0x2d85418c,0x00000000}},	//   ðra_, _تکمی, _gile_,
  { {0x7d081631,0x61ed0045,0x2b910013,0x00000000}},	//   _inds, zwal, _gác_,
  { {0x2d85418d,0x61ed0886,0x68e81972,0x00000000}},	//   _zile_, ywal, sedd,
  { {0x98be0006,0x7bca0026,0x7d1a418e,0x00000000}},	//   entą_, lufu, _kots,
  { {0x58d3000a,0x05840001,0x2d8500cd,0x00000000}},	//   _зошт, еусм, _xile_,
  { {0x2b91001b,0x63a9017f,0x7d1a0a2e,0x00000000}},	//   _xác_, ćeno, _mots,
  { {0xe1ff017d,0x61ed418f,0xe3b0013a,0x00000000}},	//   _pró_, twal, طرف_,
  { {0x61ed4190,0x7d080246,0x3ead21ef,0x00000000}},	// [7870] uwal, _onds, _reet_,
  { {0x395e003d,0x61ed4191,0x7bca4192,0x00000000}},	//   nots_, rwal, kufu,
  { {0x61ed0009,0x2d85003b,0x3d100053,0x00000000}},	//   swal, _rile_, ढाने_,
  { {0x2b91008b,0x2d8526a2,0x7bc3007d,0x00000000}},	//   _rác_, _sile_, vrnu,
  { {0xff500021,0x672d00c2,0x61ed00ac,0x00000000}},	//   دخل_, _mlaj, qwal,
  { {0x3ead0102,0x644e00c3,0x23690509,0x00000000}},	//   _weet_, šniš, llaj_,
  { {0x67260627,0x2d850009,0x395e003d,0x00000000}},	//   ykkj, _vile_, dots_,
  { {0x394c04ff,0x256400ea,0x2d8504ec,0x00000000}},	//   ends_, lölt_, _wile_,
  { {0x7ae9010e,0x1dd10053,0xedd5002a,0x00000000}},	//   reet, _समित, _زياد,
  { {0x2d850027,0x2b91001b,0x3eb8001c,0x00000000}},	//   _uile_, _tác_, _ērti_,
  { {0x6120007a,0x7ae90019,0x69c90229,0x00000000}},	//   _tölv, peet, suee,
  { {0x98ad01f7,0x38780014,0x6d434193,0x00000000}},	//   ının_, ýrra_, lina,
  { {0x6120000f,0x6f1b4194,0xdcfa003b,0x00000000}},	//   _költ, _mouc, _uită,
  { {0x6f1b4195,0xdce80006,0x29070c29,0x00000000}},	//   _louc, _didė, _unna_,
  { {0x3cf00053,0x6601001c,0x6f094196,0x00000000}},	//   _इससे_, ālka, _onec,
  { {0x6d433d23,0xa22a000a,0xa6db0026,0x00000000}},	//   hina, ожба_, liðn,
  { {0x6d434197,0x324306da,0x9f430072,0x00000000}},	// [7880] kina, ветг, _yrjö_,
  { {0x69c600c3,0xa6db0026,0x25640026,0x00000000}},	//   škeg, niðn, tölu_,
  { {0x6f1b1db7,0xc0590086,0x7f423436,0x00000000}},	//   _bouc, пії_, tioq,
  { {0x7d1a0004,0x6d4300eb,0xf4130a7a,0x00000000}},	//   _sots, eina, _ספר_,
  { {0x61200026,0x7d1a4198,0xdd8f0754,0x00000000}},	//   _sölu, _pots, لون_,
  { {0x6d4303e1,0x39924199,0x7bca00e0,0x00000000}},	//   gina, _râs_, tufu,
  { {0xfbcf0032,0x7bd8004b,0x6f1b0294,0x00000000}},	//   لتي_, utvu, _fouc,
  { {0x1b770032,0xa6db0026,0x7bca419a,0x00000000}},	//   وصية_, eiðn, rufu,
  { {0x395e001c,0x44230051,0x3ea600ea,0x00000000}},	//   tots_, zyj_, mbot_,
  { {0x394c0034,0x6120007a,0x7d08419b,0x00000000}},	//   unds_, _tölu, _unds,
  { {0xcb6a184a,0x395e001c,0x672d1c8a,0x00000000}},	//   _даже_, rots_, _plaj,
  { {0x3ea6419c,0x613200b9,0xba260c59,0x00000000}},	//   nbot_, _hæld, _одек,
  { {0x6664005a,0x672d0114,0x613201e1,0x00000000}},	//   върз, _vlaj, _kæld,
  { {0xb34703d9,0xe4e40086,0x95c400de,0x00000000}},	//   _opçõ, кісн, ضيفه,
  { {0x61e60006,0x3dc600e5,0x61320014,0x00000000}},	//   _apkl, hrow_, _mæld,
  { {0x68f80c8e,0x44230051,0x291c013d,0x00000000}},	//   _havd, ryj_, _hova_,
  { {0x83840076,0x2509007e,0x2127007e,0x00000000}},	// [7890] тыре, _فردی_, ويری_,
  { {0x257600b9,0x6f1b419d,0xceb90080,0x00000000}},	//   vælg_, _souc, _moře_,
  { {0x6f1b419e,0xa3e70161,0xa3d60053,0x00000000}},	//   _pouc, _मैच_, _समय_,
  { {0x6d43419f,0xdb0a0e77,0x291c0e21,0x00000000}},	//   wina, nsfä, _lova_,
  { {0xf485007e,0x6d4341a0,0x25b901db,0x00000000}},	//   _تاکی, tina, nssl_,
  { {0x0d84019d,0x691f00e8,0x3ea6002c,0x00000000}},	//   влін, _lêer, abot_,
  { {0x61320146,0x6f1b04bc,0x6d4341a1,0x00000000}},	//   _sælg, _touc, rina,
  { {0x6d4341a2,0x6120336c,0x6f0940c9,0x00000000}},	//   sina, _föls, _unec,
  { {0x6120000f,0x2734008b,0x613200b9,0x00000000}},	//   _tölt, _hãng_, _fæld,
  { {0x613241a3,0x63a90117,0x63ba00c3,0x00000000}},	//   _vælg, ćenj, štni,
  { {0x3f790047,0xbd68005e,0x31580041,0x00000000}},	//   ּאָס, _црте_, ויזן_,
  { {0xdb0a01e3,0x3f910058,0xebc4005e,0x00000000}},	//   gsfä, _muzu_, _шљун,
  { {0xa6db0026,0x27340013,0xdcb1008d,0x00000000}},	//   miðl, _lãng_, _kẻ_,
  { {0x613200b9,0x7afb004b,0x65770013,0x00000000}},	//   _kæle, ldut, _chxh,
  { {0x187500b5,0xf7460699,0x7afb099a,0x00000000}},	//   _אײַך_, _пеко, odut,
  { {0x7afb41a4,0x14170021,0xdcb1008b,0x00000000}},	//   ndut, ريقة_, _lẻ_,
  { {0x64620051,0x7afb0006,0x7e6941a5,0x00000000}},	// [78a0] _świę, idut, _nyep,
  { {0xb17b0093,0x394500cd,0x7afb0072,0x00000000}},	//   _upål, nils_, hdut,
  { {0xe1ff00ea,0x69db0213,0x14d70149,0x00000000}},	//   _szót_, htue, _אויל_,
  { {0xef1a07da,0x5437007e,0x660441a6,0x00000000}},	//   яме_, _سرپر, _krik,
  { {0x3ea641a7,0x39450026,0x0cd4123e,0x00000000}},	//   rbot_, kils_, волю,
  { {0x3dc641a8,0x3ebf0072,0x3eb8008f,0x00000000}},	//   rrow_, _edut_, _ērtu_,
  { {0x291c41a9,0xd47a0047,0x26c013c2,0x00000000}},	//   _rova_, האַל, _odio_,
  { {0x26c00009,0x66040137,0x5fdb0063,0x00000000}},	//   _ndio_, _orik, _מחלק,
  { {0x394541aa,0x25a00046,0xe94641ab,0x00000000}},	//   fils_, _ntil_, ехно,
  { {0x26c0001f,0x8afd0080,0x7afb0290,0x00000000}},	//   _adio_, voře, adut,
  { {0xe7590086,0x31370063,0xdb0a0ae2,0x00000000}},	//   дині_, גנים_, tsfä,
  { {0xd6db0121,0x660433c1,0xdb060072,0x00000000}},	//   что_, _brik, ämäm,
  { {0x6d410185,0x394541ac,0x69db41ad,0x00000000}},	//   _ymla, bils_, ctue,
  { {0x291c0290,0x394500cd,0x660401f2,0x00000000}},	//   _uova_, cils_, _drik,
  { {0x660441ae,0x2897009a,0x00000000,0x00000000}},	//   _erik, _אדון_,   ,
  { {0xdb0a0137,0x2b090053,0x66040807,0x00000000}},	//   arfö, वाएँ_, _frik,
  { {0xa6db0026,0x201c0072,0x60f9066e,0x00000000}},	// [78b0] niðm, ävin_, мная_,
  { {0x7d1e00a5,0x859a009a,0x00000000,0x00000000}},	//   öpsl, _קשתו,   ,
  { {0xaf980054,0x9ed91bc9,0x853c009a,0x00000000}},	//   етіх_, дмет_, _מגזי,
  { {0x798a0035,0xdcb1008b,0x27340013,0x00000000}},	//   _lifw, _sẻ_, _vãng_,
  { {0x69db3791,0x7ed4014d,0xa6db0014,0x00000000}},	//   xtue, ازما, viðl,
  { {0xfce541af,0x27340013,0xbebd0023,0x00000000}},	//   токо, _tãng_, _alūt,
  { {0xdcb1008b,0x4154005e,0x394541b0,0x00000000}},	//   _vẻ_, _сврс, vils_,
  { {0x7afb0072,0x64410022,0x69db41b1,0x00000000}},	//   udut, źliw, ttue,
  { {0x394503b2,0x7afb41b2,0x7c3800b2,0x00000000}},	//   tils_, rdut, azvr,
  { {0x6d4100bd,0x61320014,0xb9020054,0x00000000}},	//   _umla, _tæle, азьк,
  { {0xf09201f9,0x66040509,0x25a041b3,0x00000000}},	//   יני_, _srik, _stil_,
  { {0x660441b4,0x69db0cf2,0x394541b5,0x00000000}},	//   _prik, ptue, sils_,
  { {0xbb3a0047,0x394500e5,0x6aa90093,0x00000000}},	//   _קעני, pils_, mbef,
  { {0x629d41b6,0xbb440072,0x6b8b1a16,0x00000000}},	//   _afso, äävä, _higg,
  { {0x6b8b0146,0xd467005e,0x442c248c,0x00000000}},	//   _kigg, вире_, ád_,
  { {0x798a0035,0x69c941b7,0x26c0007d,0x00000000}},	//   _zifw, oree, _udio_,
  { {0x69c9051b,0x877b0047,0x25a03fe3,0x00000000}},	// [78c0] nree, _קאפי, _util_,
  { {0x64590045,0x45b70047,0x00c70062,0x00000000}},	//   _świe, _שפיל_, клук_,
  { {0x69c90122,0xd2aa0076,0xf78b0058,0x00000000}},	//   hree, _окне_, _üçü_,
  { {0x25ad000c,0xd00f0021,0x3eb8008f,0x00000000}},	//   ţele_, تلم_, _ērts_,
  { {0xf2d300b7,0xe1ff0051,0xa6970063,0x00000000}},	//   _דער_, _wzór_, דכנה_,
  { {0x6da30001,0xa0a341b8,0xa6db0026,0x00000000}},	//   шиља, _вард, viðm,
  { {0x6b8b41b9,0x69c941ba,0xddc9004c,0x00000000}},	//   _bigg, eree, _vzeš,
  { {0xac25000d,0x69c91e50,0x28d40042,0x00000000}},	//   ыфік, free, _दाहि,
  { {0x63a9017f,0xecd4007e,0x7de503eb,0x00000000}},	//   ćeni, _محاک, _مسلم,
  { {0xc27b00ff,0xf1b30063,0xddc90130,0x00000000}},	//   ורפי, ססת_, _uzeš,
  { {0x64480066,0x97a60062,0x26ee0042,0x00000000}},	//   údil, ърпл, ज़ूर_,
  { {0x69c941bb,0x2d8c41bc,0x16bf0053,0x00000000}},	//   bree, _hide_, ्लेब,
  { {0x69dc003b,0x15ec0053,0x69c941bd,0x00000000}},	//   ăres, फ़िगर_, cree,
  { {0x6b8b0168,0x8afd011b,0x00000000,0x00000000}},	//   _zigg, mořa,   ,
  { {0x2d8c29e9,0xc9770063,0x19570085,0x00000000}},	//   _mide_, _שגוי_, _шашы_,
  { {0x2d8c10c4,0x656e0025,0x682b009c,0x00000000}},	//   _lide_, albh, södö,
  { {0x8837001c,0x1167005d,0x42751eaf,0x00000000}},	// [78d0] ģēša, نلری_, угас,
  { {0x637a006f,0x644e013d,0x44f50a2f,0x00000000}},	//   eïnd, ániá, _спос,
  { {0xb4c10053,0x518441be,0x00000000,0x00000000}},	//   ुली_, рута,   ,
  { {0x2d8c03b2,0xceeb007e,0x66021273,0x00000000}},	//   _aide_, ظران_, _šoki,
  { {0xdcb1008b,0x5dd40121,0x6b8b32a8,0x00000000}},	//   _hỏi_, ающу, _rigg,
  { {0xbebd001c,0x69c90983,0x4d640054,0x00000000}},	//   _plūs, vree, аків,
  { {0xcb690001,0xa6db0014,0x6aa941bf,0x00000000}},	//   наке_, riðj, tbef,
  { {0x69c9326e,0x2b980003,0x2d8c3261,0x00000000}},	//   tree, _déc_, _eide_,
  { {0xc3340063,0x6aa941c0,0x69c905d4,0x00000000}},	//   יוק_, rbef, uree,
  { {0x7521172b,0xdcf6003b,0x69c941c1,0x00000000}},	//   ölzl, ăcăm, rree,
  { {0x7c25004d,0x69c905d4,0xdb23005d,0x00000000}},	//   ährd, sree, _پوشی,
  { {0x69c941c2,0xe5a622c4,0xbb440072,0x00000000}},	//   pree, лими, äätä,
  { {0x26de0051,0x3f8d003b,0x5df90041,0x00000000}},	//   ęto_, _mieu_, עפֿנ,
  { {0x3f8d03b2,0x98a20481,0xe980012c,0x00000000}},	//   _lieu_, _лише, _дачi_,
  { {0xb8f70235,0x2b980013,0x87260044,0x00000000}},	//   िल_, _xéc_, _معظم,
  { {0x3f8d00e8,0x64590022,0x7640011b,0x00000000}},	//   _nieu_, _świc, úmys,
  { {0x9f5e03b2,0x0206000d,0xa20602dc,0x00000000}},	// [78e0] _été_, ызан, ыпад,
  { {0x98be0529,0xd5b8001c,0x7981002b,0x00000000}},	//   mită_, ņās_, nmlw,
  { {0x98be000c,0x25b2001f,0x2d8c41c3,0x00000000}},	//   lită_, _hwyl_, _ride_,
  { {0x2d8c171d,0xbefa0044,0x5fc90042,0x00000000}},	//   _side_, عراض_, ांजल,
  { {0x3f8d03b2,0x2d8c02dd,0x98be000c,0x00000000}},	//   _dieu_, _pide_, nită_,
  { {0x6146026b,0xd1320044,0x00000000,0x00000000}},	//   _сега, _امس_,   ,
  { {0x2d8c41c4,0x0b8a1a5c,0xc4d30063,0x00000000}},	//   _vide_, нсии_, צגה_,
  { {0x2d8c0034,0x3cf00053,0xa0670141,0x00000000}},	//   _wide_, _इसके_, _саса_,
  { {0x442a027d,0x69340e5e,0x4cd6007e,0x00000000}},	//   hyb_, иниу, _مغاز,
  { {0xa6db0026,0x98be003b,0x61f6002b,0x00000000}},	//   miði, dită_, iwyl,
  { {0x7c930032,0xa6db0026,0x8afd0080,0x00000000}},	//   _المص, liði, mořn,
  { {0x7c2500bd,0x442a00b9,0x6d4a091c,0x00000000}},	//   ähre, dyb_, lifa,
  { {0xdb0a191f,0x291800c7,0xa6db0026,0x00000000}},	//   dsfø, öras_, niði,
  { {0xdb0100cd,0xe4c7000d,0x6d4a41c5,0x00000000}},	//   _atlè, ыёмн, nifa,
  { {0xf1bf0080,0xd37b04dc,0x78ba41c6,0x00000000}},	//   _svá_, еча_, matv,
  { {0x6d4a0009,0xa3d6016a,0x98be003b,0x00000000}},	//   hifa, _समर_, bită_,
  { {0x98be000c,0x6d4a0035,0x7c2a001f,0x00000000}},	// [78f0] cită_, kifa, hyfr,
  { {0x6d4a0035,0xf1c80021,0x78ba0078,0x00000000}},	//   jifa, اولى_, natv,
  { {0xa6db0026,0xdb0a01e1,0x7a48008f,0x00000000}},	//   eiði, bsfø, lītī,
  { {0x672f0045,0x61f6002b,0x7c2a002b,0x00000000}},	//   nkcj, bwyl, dyfr,
  { {0x9f5c0080,0x386e001f,0x9b45007e,0x00000000}},	//   ívá_, _lyfr_, ینتو,
  { {0x78ba00a8,0x98ac0078,0xdce8005f,0x00000000}},	//   jatv, midė_, _didį,
  { {0x98be000c,0x4ea70141,0x78ba013d,0x00000000}},	//   zită_, _брза, datv,
  { {0x8b250f9f,0xcc080cac,0x00000000,0x00000000}},	//   рдие, ازون_,   ,
  { {0xdce1001c,0x6d4a003b,0x78ba0014,0x00000000}},	//   _eklā, bifa, fatv,
  { {0xbb4400fe,0x98be000c,0xf8650699,0x00000000}},	//   äärä, vită_, ивпо,
  { {0x80dd016a,0xe73a06cb,0x2eff004d,0x00000000}},	//   _पाने, вен_, _kauf_,
  { {0x98be000c,0xfe670021,0x25b2002b,0x00000000}},	//   tită_, قد_, _pwyl_,
  { {0x63a50025,0x9676000d,0x8676000d,0x00000000}},	//   _athn, рыні, рынц,
  { {0x64590045,0x98be0529,0x18a50001,0x00000000}},	//   _świa, rită_, _такм,
  { {0x98be000c,0x8883007e,0xdb01391b,0x00000000}},	//   sită_, _دیدن, _atlé,
  { {0x6d4a0035,0x97c4007e,0x6abb00bd,0x00000000}},	//   zifa, _اتوم, nauf,
  { {0x4736006a,0x6d4a0089,0xe1fa0062,0x00000000}},	// [7900] _مرکز, yifa, ъга_,
  { {0x399b0016,0xf9920063,0x6abb41c7,0x00000000}},	//   _mês_, קרב_, hauf,
  { {0xd00f0021,0x6abb00bd,0xdb0a00d1,0x00000000}},	//   ولك_, kauf, psfø,
  { {0x7c2e00bd,0x98be0006,0x539b0063,0x00000000}},	//   _übri, mitą_, _שיכו,
  { {0x6d4a04b9,0x4df60121,0x6f06013d,0x00000000}},	//   tifa, ряет, jébő,
  { {0xebc60001,0x80dd0053,0xa6db0014,0x00000000}},	//   аљин, _पाये, riði,
  { {0x6d4a160e,0xb60600c2,0x672f0022,0x00000000}},	//   rifa, ljšč, ykcj,
  { {0x6d4a0228,0x98a50006,0x3ce9007d,0x00000000}},	//   sifa, filį_, đava_,
  { {0x3f980009,0xb60600a8,0x78ba013d,0x00000000}},	//   _huru_, njšč, tatv,
  { {0x3f98003d,0xdb180014,0x6f0200f1,0x00000000}},	//   _kuru_, msví, ldoc,
  { {0x3f98028d,0x65670024,0x78ba0026,0x00000000}},	//   _juru_, vojh, ratv,
  { {0x98be0006,0x6f0241c8,0x29f60022,0x00000000}},	//   ditą_, ndoc, _tła_,
  { {0x78ba0006,0x09e3000d,0x69960121,0x00000000}},	//   patv, _моцн, _трех,
  { {0x69c041c9,0xa5f8005e,0x7a790047,0x00000000}},	//   msme, јеру_, _גרױס,
  { {0x3f9805b3,0x48f90047,0x397b0047,0x00000000}},	//   _nuru_, _תּנא, _שטונ,
  { {0x394c368c,0x69c041ca,0xc6a70131,0x00000000}},	//   lids_, osme, _трки,
  { {0x926b0001,0x6d480fdf,0xf9930047,0x00000000}},	// [7910] трва_, _omda, ַרף_,
  { {0x2eff0164,0x31c4000d,0x6f0205e4,0x00000000}},	//   _sauf_, ўств, edoc,
  { {0x63a90130,0x69c00244,0xdb030046,0x00000000}},	//   ćens, hsme, msnö,
  { {0x6d480185,0x69c041cb,0x3f9800c2,0x00000000}},	//   _amda, ksme, _duru_,
  { {0xa3d30235,0xdef808a6,0xcddb005e,0x00000000}},	//   हूर_, рых_, тње_,
  { {0xa6db0026,0x0dc81168,0x61fd00b9,0x00000000}},	//   miðu, руци_, _issl,
  { {0x3f983e3a,0xa6db0026,0xadc3008b,0x00000000}},	//   _guru_, liðu, _trắn,
  { {0x394c001c,0x6f06013d,0x54580063,0x00000000}},	//   eids_, tébő, יבוב_,
  { {0x6abb00bd,0x3f980035,0xe2a60026,0x00000000}},	//   rauf, _zuru_, óðin_,
  { {0x9be7019d,0x6abb00bd,0x399b017d,0x00000000}},	//   _відк, sauf, _vês_,
  { {0xc6890063,0x2911005b,0x27fc008b,0x00000000}},	//   _נא_, ıza_, _csvn_,
  { {0xaa950021,0x291e1df2,0xe73a0895,0x00000000}},	//   _الإث, ajta_, уем_,
  { {0x2b4d0051,0x7d0141cc,0x98be0022,0x00000000}},	//   miec_, _kals, witą_,
  { {0xdce32ffb,0xa50a005e,0x2b4d008f,0x00000000}},	//   konč, ћева_, liec_,
  { {0x1dd10053,0x320b0c5f,0x7d0141cd,0x00000000}},	//   _समझत, _arcy_, _mals,
  { {0x2b4d06ce,0x98be0078,0xe5a60062,0x00000000}},	//   niec_, ritą_, _лиии,
  { {0x61320146,0x200a41ce,0x6f0019e7,0x00000000}},	// [7920] _fæll, _srbi_, _ramc,
  { {0x612041cf,0xb69b12a1,0xe03a0085,0x00000000}},	//   _hölz, ndân, ляеш_,
  { {0xdce300c2,0x6f0200ca,0x8f760054,0x00000000}},	//   gonč, tdoc, буді,
  { {0xee3a0138,0x7d0141d0,0x6f023094,0x00000000}},	//   лне_, _aals, udoc,
  { {0x7d0120ae,0x6f021950,0x7e7b056c,0x00000000}},	//   _bals, rdoc, _czup,
  { {0x3f960079,0x69c00137,0x61e40303,0x00000000}},	//   _граѓ, vsme, mtil,
  { {0xa1370047,0x7d011149,0x69c0002b,0x00000000}},	//   _פאלק_, _dals, wsme,
  { {0x5a340189,0x69c600c2,0x69c041d1,0x00000000}},	//   жнит, škem, tsme,
  { {0xcb670001,0x9998000a,0x69c041d2,0x00000000}},	//   љање_, јкот_, usme,
  { {0x6d480150,0x8e200085,0x61e441d3,0x00000000}},	//   _umda, мiж_, itil,
  { {0x9c7c03f5,0xab960021,0x2b4d0051,0x00000000}},	//   _obči, _الصغ, biec_,
  { {0x6d58001c,0xd5ed008b,0x2b4d0051,0x00000000}},	//   lnva, _ngạ, ciec_,
  { {0x8b650032,0xe6670245,0x394c233a,0x00000000}},	//   _بالم, стно, pids_,
  { {0x61e40203,0x2902008f,0x6d5841d4,0x00000000}},	//   dtil, ēkas_, nnva,
  { {0x6b9a00cd,0x2240082a,0x6d580050,0x00000000}},	//   _jutg, ezik_, inva,
  { {0xe61600c2,0xdb030137,0x753c004d,0x00000000}},	//   žišč, ssnö, ahrz,
  { {0x61320146,0x2240013d,0x25ac01c8,0x00000000}},	// [7930] _tæll, gzik_, čilý_,
  { {0x9f9f006f,0xa6db0014,0x6b9a23db,0x00000000}},	//   léén_, riðu, _outg,
  { {0x7e7b00ea,0x61e4066b,0xa2952049,0x00000000}},	//   _szup, atil, _мані,
  { {0xa6db007a,0x7d01157e,0x660d41d5,0x00000000}},	//   miðs, _sals, _krak,
  { {0x7d0113b8,0x2dcb0001,0xdb18004b,0x00000000}},	//   _pals, ућен_, nuvõ,
  { {0x2b4d0051,0xdce30066,0x799900ca,0x00000000}},	//   wiec_, ponč, _ruww,
  { {0xeab10032,0x98a50006,0xcda9007e,0x00000000}},	//   وعة_, nklą_, _چهره_,
  { {0x26c90150,0x6d5841d6,0xdb18004b,0x00000000}},	//   _ndao_, anva, kuvõ,
  { {0x7e7b0051,0x25a90f1b,0xdb18004b,0x00000000}},	//   _uzup, _ntal_, juvõ,
  { {0xbd6b005e,0x57e927c8,0x0dc8005e,0x00000000}},	//   _србе_, адом_, _ћути_,
  { {0x25a9001f,0xb69b13f8,0x200e004d,0x00000000}},	//   _atal_, rdân, äfix_,
  { {0x61e441d7,0x7bc341d8,0x660d41d9,0x00000000}},	//   ytil, msnu, _brak,
  { {0xe57a0071,0xdb18004b,0xa6db0046,0x00000000}},	//   изм_, guvõ, eiðs,
  { {0x6b5e008f,0x3f860260,0xa50a005e,0x00000000}},	//   mīga, zmou_, шега_,
  { {0x7bc341da,0x660d37d4,0x6b5e001c,0x00000000}},	//   nsnu, _erak, līga,
  { {0x163a0032,0x52aa005a,0xe29741db,0x00000000}},	//   _نسخة_, рвам_, жат_,
  { {0x61e40164,0x6b5e001c,0x22400089,0x00000000}},	// [7940] util, nīga, uzik_,
  { {0xb17b01e3,0x290541dc,0x61e441dd,0x00000000}},	//   _spår, ndla_, rtil,
  { {0x224000ea,0x61e441de,0x071e0053,0x00000000}},	//   szik_, stil, _बचाव_,
  { {0x64480066,0x7bc3102d,0xdb0a004d,0x00000000}},	//   údiu, dsnu, usfü,
  { {0x3f8641df,0xad660021,0xf2d30041,0x00000000}},	//   rmou_, ياته, _קעש_,
  { {0x613200b9,0x6b5e008f,0x5ba61702,0x00000000}},	//   _mælk, dīga, ориз,
  { {0xf1c50006,0x7ae941e0,0x6d5808a9,0x00000000}},	//   rašų_, ffet, rnva,
  { {0xdb010016,0xdddb005b,0x2fc7003b,0x00000000}},	//   _atlâ, _uyuş, ânge_,
  { {0xb997014c,0x9da50043,0xaa63014b,0x00000000}},	//   овых_, _فصله, дтэк,
  { {0x61200072,0x98a50078,0x0217009a,0x00000000}},	//   _pöly, yklą_, קחים_,
  { {0xeb9a0079,0x25a9027d,0x20050026,0x00000000}},	//   _тие_, _stal_, _álit_,
  { {0x660d41e1,0xa6db0026,0xdb18004b,0x00000000}},	//   _prak, eiðr, tuvõ,
  { {0x6b5e001c,0x95d80612,0x34950be6,0x00000000}},	//   cīga, одят_, загр,
  { {0xfa770063,0x660d41e2,0xdce3004c,0x00000000}},	//   _ועדת_, _vrak, dlně,
  { {0x734b0505,0xdb18004b,0xf4410054,0x00000000}},	//   ачав_, suvõ, ховi_,
  { {0x660d41e3,0xd5bb0062,0xc29922f5,0x00000000}},	//   _trak, _ксо_, сках_,
  { {0x7bd801e9,0xa2dc0053,0x25a941e4,0x00000000}},	// [7950] huvu, _फार्, _utal_,
  { {0xc1780086,0x7bd841e5,0x00000000,0x00000000}},	//   оїх_, kuvu,   ,
  { {0x28dd0235,0x5f95005a,0xb4fa0063,0x00000000}},	//   _मासि, чиет, _הפתי,
  { {0xdb1800b9,0x80dd0082,0x03d6009d,0x00000000}},	//   lsvæ, _पावे, _צורם_,
  { {0xe1ff006d,0xdca50a2f,0x20d70044,0x00000000}},	//   _usó_, пали, _وتسج,
  { {0x6b82006d,0xdb1800b9,0x25d80063,0x00000000}},	//   _ahog, nsvæ, קוון_,
  { {0x7bd8003d,0x9c7c00c3,0x6b820025,0x00000000}},	//   guvu, _obču, _bhog,
  { {0x6b820025,0x7bc30415,0x6b5e008f,0x00000000}},	//   _chog, rsnu, tīga,
  { {0x7c38017f,0x7ae941e6,0xdb0e013d,0x00000000}},	//   _čarš, rfet, ójáh,
  { {0x6b5e001c,0x7ae941e7,0xa2cb0053,0x00000000}},	//   rīga, sfet, तृत्,
  { {0x6b820025,0x2c740025,0xdb180583,0x00000000}},	//   _fhog, rúdú_, dsvæ,
  { {0x290302e2,0xdb1800b9,0xdc880063,0x00000000}},	//   žja_, esvæ, _וְנָ,
  { {0xdb180ac6,0x98be0080,0x61330058,0x00000000}},	//   fsvæ, nitě_, _kılı,
  { {0xdb1800b9,0x6b8900ea,0xb4d60053,0x00000000}},	//   gsvæ, lmeg, हले_,
  { {0x29360047,0xf990002a,0xd7c90043,0x00000000}},	//   _מאסן_, _شبه_, _اوبه_,
  { {0xf1c70053,0xc7a80044,0x00000000,0x00000000}},	//   _लिखन, _بدول_,   ,
  { {0x26c23630,0xdb1801e1,0xdce3008f,0x00000000}},	// [7960] mako_, bsvæ, zonā,
  { {0x41030086,0xb09a0086,0x26c241e8,0x00000000}},	//   нзув, стає_, lako_,
  { {0xdeef000d,0x7c25004d,0x397a0041,0x00000000}},	//   ны_, ährl, צטענ,
  { {0x6132007a,0xdce30080,0x26c20008,0x00000000}},	//   _mæli, plně, nako_,
  { {0xddcb01f7,0x6b8941e9,0xae030042,0x00000000}},	//   ğişi, dmeg, लिगन_,
  { {0xdb0100cd,0xdd990086,0x1e130085,0x00000000}},	//   _atlà, іші_, эмія,
  { {0x26c2074f,0x913b0047,0x21e60066,0x00000000}},	//   kako_, _פעלק, lôh_,
  { {0xd90d007e,0x6b8900ea,0xd00f0021,0x00000000}},	//   یین_, gmeg, _حلف_,
  { {0xadc3001b,0xa3d60053,0x7bd80bda,0x00000000}},	//   _trạn, _समझ_, suvu,
  { {0x3acc0013,0x27340013,0x69cf0516,0x00000000}},	//   ớp_, _hãnh_, ácea,
  { {0x37aa000a,0x6b820d17,0x443100ca,0x00000000}},	//   љтон_, _thog, xyz_,
  { {0x6c7b0047,0x26c200a4,0xcc570063,0x00000000}},	//   _פראד, gako_, _צבאי_,
  { {0x613301f7,0xdb1800b9,0x27340013,0x00000000}},	//   _yılı, tsvæ, _mãnh_,
  { {0x2734001b,0x8afd0080,0xa5f8005e,0x00000000}},	//   _lãnh_, voři, џеру_,
  { {0x26c20035,0xdb180026,0x613206a5,0x00000000}},	//   bako_, rsvæ, _gæli,
  { {0xb7db014e,0x926b0699,0xdb180014,0x00000000}},	//   _הקהי, брза_, ssvæ,
  { {0x64580014,0x671a0042,0x69bf0042,0x00000000}},	// [7970] _þvin, धारक_, लीपी,
  { {0xdb180137,0x98be004c,0x55bc0063,0x00000000}},	//   lsvä, vitě_, _המזו,
  { {0x98aa0051,0x67210053,0xe3a5007e,0x00000000}},	//   óbę_, यापक_, _تشخی,
  { {0xdb1800c7,0x8afd004c,0x21270043,0x00000000}},	//   nsvä, poři, _کيسی_,
  { {0x2fc7001b,0xed4e0259,0x28dd0053,0x00000000}},	//   ũng_, во_, _मालि,
  { {0x7ae205d5,0xac390054,0x98be004c,0x00000000}},	//   _acot, жчих_, ritě_,
  { {0xdb01006d,0xdb1800c7,0xbbe80021,0x00000000}},	//   _atlá, ksvä, كريم_,
  { {0xeeb916fc,0xdce300dd,0xc9a941ea,0x00000000}},	//   _флаш_, fonă, овие_,
  { {0xdb180137,0x26c2007d,0xef190022,0x00000000}},	//   dsvä, vako_, _inż_,
  { {0xdb1a0137,0x9f410139,0xdb180137,0x00000000}},	//   _avtä, ithí_, esvä,
  { {0xfbd000b3,0x6b5e001c,0x26c241eb,0x00000000}},	//   _متن_, cīgo, tako_,
  { {0xc4c90ee1,0x2d9f0019,0xdb1800a5,0x00000000}},	//   _כג_, _kuue_, gsvä,
  { {0x7bd2001c,0xa25b0066,0x3ebf006c,0x00000000}},	//   ījuš, _zdôv, _meut_,
  { {0xe29f007a,0x64a6000a,0x7afb1466,0x00000000}},	//   _raða_, ќава, leut,
  { {0x26c200c3,0x3ea600ca,0x64a31fa0,0x00000000}},	//   pako_, ycot_, таса,
  { {0x2907007a,0xc7d60063,0x7afb41ec,0x00000000}},	//   _hana_, _חוקי_, neut,
  { {0x2d850150,0x69c60078,0x6abd0014,0x00000000}},	// [7980] _ohle_, škev, ósfy,
  { {0x66040004,0x7afb00fe,0x2011017f,0x00000000}},	//   _isik, heut, _brzi_,
  { {0x251b00b5,0x1fa50086,0x7afb00fe,0x00000000}},	//   _וויא, еріг, keut,
  { {0x2fc7000c,0x290741ed,0x25a008a3,0x00000000}},	//   ânga_, _lana_, _kuil_,
  { {0x7afb0199,0x26c003d9,0x3ebf28b0,0x00000000}},	//   deut, _meio_, _deut_,
  { {0x29072bd8,0xdb0a00c7,0x7ae241ee,0x00000000}},	//   _nana_, nsfö, _scot,
  { {0x69cf0080,0x68fa00c2,0x3ebf0003,0x00000000}},	//   ácen, vetd, _feut_,
  { {0x539b0063,0x63ba0066,0x6b5e008f,0x00000000}},	//   חיקו, átny, rīgo,
  { {0xdb0a0137,0x64580078,0xdcea00a8,0x00000000}},	//   ksfö, _žvil, lofč,
  { {0x63ba0066,0xa9670002,0x290741ef,0x00000000}},	//   štny, миња_, _cana_,
  { {0xdb0a00c7,0x7d1a1a61,0x290741f0,0x00000000}},	//   dsfö, _ints, _dana_,
  { {0x274b0086,0x45d5018e,0xf0930063,0x00000000}},	//   ічно_, номс, כנת_,
  { {0xdb180838,0xceb30063,0x25ad00ca,0x00000000}},	//   rsvä, כיר_, ëel_,
  { {0xdb0a0137,0x29071f56,0xdb180504,0x00000000}},	//   gsfö, _gana_, ssvä,
  { {0x66040659,0x395e0137,0x26c02793,0x00000000}},	//   _esik, mnts_, _feio_,
  { {0x6132007a,0x2abb0047,0x25a00139,0x00000000}},	//   _mælu, ַמבא, _fuil_,
  { {0x7d1a04c6,0x29071a11,0x61d90121,0x00000000}},	// [7990] _onts, _yana_, ямая_,
  { {0xda08008b,0x7afb0244,0x7d080ffa,0x00000000}},	//   _mỏ_, zeut, _nads,
  { {0x3ebf03b2,0x25a000ca,0x395e1574,0x00000000}},	//   _peut_, _zuil_, ints_,
  { {0x69cf0235,0xf1a70053,0x93440002,0x00000000}},	//   _दिली, _कंपन, _анџе,
  { {0x3ebf0164,0x31a4005b,0x877c009a,0x00000000}},	//   _veut_, _göz_, קאדי,
  { {0xb6380063,0x672d004c,0x91ba089e,0x00000000}},	//   ורדס_, _loaj, _ממשי,
  { {0x7afb00fe,0x7d08001f,0x3ea038da,0x00000000}},	//   teut, _dads, žita_,
  { {0x7d1a0199,0xda08001b,0x395e41f1,0x00000000}},	//   _ents, _bỏ_, ents_,
  { {0xc955026c,0xda08008b,0x7afb41f2,0x00000000}},	//   етны, _cỏ_, reut,
  { {0x60c500bd,0x26c0017d,0x25a00229,0x00000000}},	//   nahm, _seio_, _ruil_,
  { {0x29070019,0x6d430025,0x61320026,0x00000000}},	//   _vana_, mhna, _gælu,
  { {0x395e41f3,0x29070035,0x660427cb,0x00000000}},	//   ants_, _wana_, _psik,
  { {0xf6520032,0x26c00016,0xdb0a00c7,0x00000000}},	//   ائج_, _veio_, tsfö,
  { {0xdb180137,0x25a000ca,0x63a8004c,0x00000000}},	//   rsvå, _vuil_, ídno,
  { {0x31a4005b,0x61320026,0xdb0a0137,0x00000000}},	//   _söz_, _mælt, rsfö,
  { {0x6aa941f4,0x232702a9,0xdb0a0137,0x00000000}},	//   ncef, носи_, ssfö,
  { {0xd1860076,0xdb0a0137,0x660414a3,0x00000000}},	// [79a0] елай, psfö, _usik,
  { {0x69c900fe,0x7cf3005b,0x6f1b01a8,0x00000000}},	//   isee, nırı, _anuc,
  { {0x6d430025,0x7d080206,0x6f0941f5,0x00000000}},	//   dhna, _rads, _baec,
  { {0x69c941f6,0x9ea7005e,0xdb2041f7,0x00000000}},	//   ksee, евца_, ötül,
  { {0x613200b9,0x7cf30058,0x257601e1,0x00000000}},	//   _bælt, kırı, bælt_,
  { {0x6d430027,0xa3d40053,0x69c91c1d,0x00000000}},	//   ghna, _हटा_, dsee,
  { {0x69c9024a,0x7cf3005b,0x7d0819e5,0x00000000}},	//   esee, dırı, _vads,
  { {0xff26005a,0xeb97007b,0x9f4a0ef1,0x00000000}},	//   _ямбо, ниј_, ömän_,
  { {0x8afd004c,0x7d080f4a,0xbc6a005d,0x00000000}},	//   vořt, _tads, _کمان_,
  { {0xda080013,0x6d4341f8,0x395e41f9,0x00000000}},	//   _vỏ_, chna, unts_,
  { {0x23600045,0xdd8f03eb,0x6bd6007e,0x00000000}},	//   knij_, _اول_, _ستار,
  { {0xda08008b,0x236000a8,0x0ab60044,0x00000000}},	//   _tỏ_, jnij_, _أحاد,
  { {0x23600022,0x56940200,0x98a50075,0x00000000}},	//   dnij_, лают, anlı_,
  { {0x69c60006,0x68460003,0x61320046,0x00000000}},	//   škes, _cédé, _mæls,
  { {0x998200eb,0x60c50150,0x236041fa,0x00000000}},	//   škų_, vahm, fnij_,
  { {0x7c2500bd,0x487b0063,0xdb0300cf,0x00000000}},	//   ähri, _מטוס, ppnå,
  { {0x68460164,0x290c002b,0x461500de,0x00000000}},	// [79b0] _fédé, odda_, _شودر,
  { {0x290c001f,0x7bca08a9,0x6846006c,0x00000000}},	//   ndda_, ksfu, _gédé,
  { {0xb4dd016a,0x60c52743,0x236000c2,0x00000000}},	//   डली_, rahm, bnij_,
  { {0x7bca102d,0x61e9003b,0x7cf30058,0x00000000}},	//   dsfu, _ţelu, zırı,
  { {0xdd9b0076,0x6d4313d5,0x22842785,0x00000000}},	//   чше_, thna, _бург,
  { {0x063800b5,0x6b99002b,0x61ed41fb,0x00000000}},	//   ענגט_, _siwg, mtal,
  { {0xdfd8011c,0x6c520001,0x6d430026,0x00000000}},	//   _път_, икљу, rhna,
  { {0x5f940459,0x69c9404b,0x61ed41fc,0x00000000}},	//   _бист, tsee, otal,
  { {0x7cf301f7,0x69c90ffd,0xa25b0066,0x00000000}},	//   tırı, usee, _zdôr,
  { {0x69c941fd,0x61ed41fe,0xfd1300f2,0x00000000}},	//   rsee, ital, _حجر_,
  { {0x69c911c8,0x08890121,0x7cf30058,0x00000000}},	//   ssee, ьбой_, rırı,
  { {0x23be0080,0x290c0137,0x61ed41ff,0x00000000}},	//   vůj_, adda_, ktal,
  { {0x69c60080,0xa2660024,0xcb360063,0x00000000}},	//   šker, omôž, _שאני_,
  { {0x23600051,0x61ed1b6b,0xa3bf0053,0x00000000}},	//   wnij_, dtal, ुओं_,
  { {0x33d50636,0x61ed4200,0x23600022,0x00000000}},	//   літт, etal, tnij_,
  { {0xdb0100c7,0x61ed4201,0xe36338a5,0x00000000}},	//   _utlä, ftal, акси,
  { {0x9586065b,0x23604202,0xa0a6000d,0x00000000}},	// [79c0] _илие, rnij_, вазд,
  { {0x7bca00ac,0x6d4100cd,0xf53f0137,0x00000000}},	//   ysfu, _nlla, spår_,
  { {0x838a019d,0x22490089,0x69cf004c,0x00000000}},	//   _обов_, azak_, ácej,
  { {0xa2660024,0xdb030066,0x637a0229,0x00000000}},	//   emôž, apnú, eïnv,
  { {0x290c4203,0xdee34204,0x61ed2a7f,0x00000000}},	//   ydda_, рочи, ctal,
  { {0x628600c3,0x6fb60021,0x6b5e008f,0x00000000}},	//   _izko, _لمسا, mīgi,
  { {0x9f5c00ea,0x6d410150,0x7e6901a8,0x00000000}},	//   ívó_, _dlla, _exep,
  { {0x6d414205,0xceea000d,0x7bca4206,0x00000000}},	//   _ella, _ідзе_, rsfu,
  { {0x7bca0037,0x4438001f,0xa25b017d,0x00000000}},	//   ssfu, hyr_, _leôn,
  { {0xd9170121,0x41da0042,0x00000000,0x00000000}},	//   вью_, यूएस,   ,
  { {0x290a0024,0x6d580213,0x31370165,0x00000000}},	//   ľba_, miva, דריך_,
  { {0x6d584207,0x44384208,0xbb440072,0x00000000}},	//   liva, dyr_, äädä,
  { {0x6d5800fe,0x9f470003,0xdb030066,0x00000000}},	//   oiva, îné_, ypnú,
  { {0xb4dd016a,0x61ed02f0,0x4438001f,0x00000000}},	//   डले_, vtal, fyr_,
  { {0xe2f90086,0x78fb0063,0x6d580cb0,0x00000000}},	//   неві_, _חלופ, iiva,
  { {0x66160829,0x61ed1c70,0x32070022,0x00000000}},	//   _fryk, ttal, łnym_,
  { {0x5215000d,0xa6e30026,0x20c70121,0x00000000}},	// [79d0] ыдат, íðut, всег,
  { {0x6d580117,0x61ed08d5,0x44380205,0x00000000}},	//   jiva, rtal, byr_,
  { {0x7d080006,0x6674007e,0x61ed4209,0x00000000}},	//   iūrė, _مدیر, stal,
  { {0x673d076c,0x61ed420a,0x6575013d,0x00000000}},	//   nksj, ptal, lozh,
  { {0x926b0dd5,0xdd2c0006,0x7d080006,0x00000000}},	//   _црна_, _dėžu, kūrė,
  { {0x6d583d07,0x63a5420b,0xa63c0063,0x00000000}},	//   giva, _kuhn, וגדר,
  { {0xbbf50021,0x7d080078,0x6ce40054,0x00000000}},	//   استث, dūrė, річе,
  { {0x657500ea,0x6d580072,0xbc180054,0x00000000}},	//   hozh, aiva, тіші_,
  { {0x657500ea,0x2bae0051,0x6d58420c,0x00000000}},	//   kozh, _ręce_, biva,
  { {0x25760146,0x6d58017f,0xd90f007e,0x00000000}},	//   jælp_, civa, زیع_,
  { {0x25b2420d,0x6b5e008f,0x9056009a,0x00000000}},	//   _styl_, zīgi, ָ֑יו_,
  { {0x6d460006,0xf74603d1,0x7c25004d,0x00000000}},	//   _įkai, уемо, ähru,
  { {0x44380185,0xcb12014e,0x6abb0035,0x00000000}},	//   wyr_, _ללא_, mbuf,
  { {0x39440088,0x4438420e,0x6abb1244,0x00000000}},	//   _кніг, tyr_, lbuf,
  { {0x62860045,0x443e420f,0x6e39002b,0x00000000}},	//   _szko, át_, hywb,
  { {0x6d580117,0x66160831,0xe7b2007e,0x00000000}},	//   ziva, _tryk, _اميد,
  { {0xdb18000e,0x443e007d,0x98a7008f,0x00000000}},	// [79e0] rsvø, št_, _zonā_,
  { {0x6d580268,0x11d70021,0x637a006f,0x00000000}},	//   xiva, اولة_, eïnt,
  { {0xdfcf0021,0xa8a80063,0x6d584210,0x00000000}},	//   كيل_, דֹנִ, viva,
  { {0x6d5800ac,0x69db01f2,0xfe460062,0x00000000}},	//   wiva, krue, лнео,
  { {0xfe720021,0x6d584211,0x20070014,0x00000000}},	//   حدا_, tiva, ænir_,
  { {0xde930001,0x6d584212,0xa0a301f6,0x00000000}},	//   љашњ, uiva, _гард,
  { {0x6d584213,0x2bb70021,0x7c66005d,0x00000000}},	//   riva, هاية_, داشل,
  { {0x6abb0031,0x6d584214,0x7c650044,0x00000000}},	//   gbuf, siva, جاهل,
  { {0x0e664215,0x6d580213,0x69db4216,0x00000000}},	//   _скан, piva, grue,
  { {0x3ea90066,0x6f022040,0x4dfb0041,0x00000000}},	//   ľate_, leoc, _אפמא,
  { {0x3ea92583,0x50db0047,0x2d9e0072,0x00000000}},	//   žate_, עקטא, _iite_,
  { {0xbaba0021,0x673d00d1,0x56950456,0x00000000}},	//   _أداء_, uksj, иант,
  { {0x6575013d,0x6b5b0041,0x69db1574,0x00000000}},	//   tozh, _אדאפ, crue,
  { {0x6f020139,0xd4070121,0xd49b0154,0x00000000}},	//   heoc, ляби, ерб_,
  { {0x7a48003d,0x27f70240,0x2d9e4217,0x00000000}},	//   sūtī, čená_, _mite_,
  { {0x290e007a,0x236d00c3,0x2d9e1f2c,0x00000000}},	//   _hafa_, čejo_, _lite_,
  { {0x41550088,0xccf80080,0xdb0a252f,0x00000000}},	// [79f0] авас, _obě_, ppfæ,
  { {0x26cb0e7c,0x6b5e008f,0x2d9e0168,0x00000000}},	//   laco_, mīgu, _nite_,
  { {0x6aa2002b,0x3ce80042,0x51844218,0x00000000}},	//   _ogof, च्छे_, сута,
  { {0x7ff40032,0x26cb24ae,0x6aa2002b,0x00000000}},	//   إسلا, naco_, _ngof,
  { {0x398b0205,0x2d9e4219,0x6b5e008f,0x00000000}},	//   løse_, _bite_, nīgu,
  { {0xabd5373c,0x11da014e,0x2d9e421a,0x00000000}},	//   ациј, _בחשב, _cite_,
  { {0x2d9e421b,0x6b61008f,0xf538009a,0x00000000}},	//   _dite_, lēgi, רטור_,
  { {0xb33b01f7,0x2d9e421c,0x69db421d,0x00000000}},	//   _hiçb, _eite_, true,
  { {0xcce7007e,0x6abb04aa,0x0b420085,0x00000000}},	//   _مساي, rbuf, іньн,
  { {0x69db0e1a,0x6abb069f,0xc27c0047,0x00000000}},	//   rrue, sbuf, ערזי,
  { {0x3ad5007e,0x7d031611,0x98be0078,0x00000000}},	//   _نياز, mens, antį_,
  { {0x61fd421e,0x69db006d,0xaa56007e,0x00000000}},	//   _opsl, prue, الیا_,
  { {0x7d030179,0xe5a6185b,0x91660013,0x00000000}},	//   oens, риги, hố_,
  { {0x60c70be1,0x7d03421f,0xfa34005d,0x00000000}},	//   _nejm, nens, _درمد,
  { {0x7d031466,0x98790047,0x26cb4220,0x00000000}},	//   iens, _באַט, baco_,
  { {0x26cb017d,0xa3d70042,0x7d034221,0x00000000}},	//   caco_, _सिर_, hens,
  { {0xdcfa0080,0x91e6055d,0xe29a4222,0x00000000}},	// [7a00] _chtě, розе, таа_,
  { {0x20180150,0x7981002b,0x6b5e008f,0x00000000}},	//   _prri_, nllw, līgt,
  { {0x98a7000c,0x7d034223,0x4fea4073,0x00000000}},	//   _zonă_, dens, тмен_,
  { {0x2d9e4224,0x40790121,0x91e60f2e,0x00000000}},	//   _site_, ущую_, _коме,
  { {0x6f024225,0x10a60505,0x7d0313cd,0x00000000}},	//   reoc, _вигн, fens,
  { {0xdd0e005b,0x7d034226,0x463b0047,0x00000000}},	//   _dışi, gens, כענע,
  { {0x2d9e4227,0x61e44228,0x6b5e008f,0x00000000}},	//   _vite_, luil, zīgu,
  { {0x60c70080,0x8fa30635,0xcfb70063,0x00000000}},	//   _zejm, _фате, _כללי_,
  { {0x7d030199,0xcb670001,0x26cb1088,0x00000000}},	//   bens, јање_, vaco_,
  { {0x2d9e003b,0xd91a0121,0x7d034229,0x00000000}},	//   _uite_, тьи_, cens,
  { {0xe7870002,0xdce1001c,0xb8ce0053,0x00000000}},	//   иумо, _eklē, _कल_,
  { {0x290e113c,0x7981001f,0x2fc700dd,0x00000000}},	//   _wafa_, allw, ângi_,
  { {0x26cb422a,0x0a16007e,0xdb0a004d,0x00000000}},	//   raco_, _خوشح, rpfä,
  { {0x6b5e003d,0x26cb017d,0x61e40072,0x00000000}},	//   rīgu, saco_, duil,
  { {0x61e40164,0xf2c7422b,0x09290044,0x00000000}},	//   euil, исан, _حسني_,
  { {0x442d0117,0x389b0063,0x61e40139,0x00000000}},	//   će_, _ביונ, fuil,
  { {0x443f003d,0x60f90121,0x61e4422c,0x00000000}},	// [7a10] ņu_, лная_, guil,
  { {0x2b460994,0x32d70013,0x68e8002b,0x00000000}},	//   _lloc_, ủy_, ngdd,
  { {0xc678007e,0x644e0051,0x36e10042,0x00000000}},	//   _محیط_, czbi, _काफ़ी_,
  { {0xdb010031,0x6b61003d,0x7d03422d,0x00000000}},	//   _utlø, lēgv, wens,
  { {0x25a9003e,0x7afd004b,0x7981002b,0x00000000}},	//   _jual_, õstm, yllw,
  { {0x660d0009,0x25a90150,0x6d4a2528,0x00000000}},	//   _msak, _mual_, ghfa,
  { {0x32090034,0x2b46422e,0x8d620121,0x00000000}},	//   lway_, _bloc_, явше,
  { {0x660d047f,0x99840006,0x7d03422f,0x00000000}},	//   _osak, kymų_, sens,
  { {0x7d034230,0x32094231,0xec15005d,0x00000000}},	//   pens, nway_, _گواد,
  { {0x998400eb,0x5d850032,0x6d4a071c,0x00000000}},	//   dymų_, _الطل, chfa,
  { {0x61e40035,0x320932ef,0x660d4232,0x00000000}},	//   zuil, hway_, _asak,
  { {0x25a90089,0x2bf60063,0x98be005f,0x00000000}},	//   _bual_, _למען_, kitė_,
  { {0x25a9048e,0xab740032,0x9b740032,0x00000000}},	//   _cual_, _بالإ, _بالص,
  { {0x61e4024a,0x9f580290,0x98a50062,0x00000000}},	//   vuil, _aprì_, _уике,
  { {0x29054233,0x3942003d,0x7ae90034,0x00000000}},	//   mela_, īkst_, oget,
  { {0x3ea00add,0x61e44234,0x3942001c,0x00000000}},	//   žiti_, tuil, ūkst_,
  { {0xd9f90053,0xdcf0004c,0xd5760054,0x00000000}},	// [7a20] ्बित_, _řečt, _гунь,
  { {0x61e4015c,0x4096101a,0x29054235,0x00000000}},	//   ruil, брет, nela_,
  { {0xdb01006c,0x290531d2,0x6b610023,0x00000000}},	//   _mulâ, iela_, lēgu,
  { {0x57ca0047,0x63a8004c,0x487a0047,0x00000000}},	//   רמײַ, ídnu, אטעס,
  { {0x61e44236,0x98a70078,0x6d4a002b,0x00000000}},	//   quil, _zoną_, thfa,
  { {0x29052061,0xa5db0047,0x8bc62377,0x00000000}},	//   jela_, אַהי, бсид,
  { {0x7ae900bd,0x343a0047,0x29054237,0x00000000}},	//   fget, טײַע, dela_,
  { {0x7ae94238,0x1f632530,0xeb470085,0x00000000}},	//   gget, _ексм, йчык_,
  { {0x733b0047,0xcf25005d,0x29054239,0x00000000}},	//   טעקס, _ظرفي, fela_,
  { {0x3cf10024,0x795816fc,0x7dfa008f,0x00000000}},	//   ľový_, риор_, rāsā,
  { {0x6c860032,0x660d0022,0x6d480137,0x00000000}},	//   _الام, _ssak, _ilda,
  { {0x99840006,0x3209423a,0x09e602e1,0x00000000}},	//   tymų_, yway_, _годн,
  { {0x25a9423b,0xa3cb0053,0xb33b00cd,0x00000000}},	//   _qual_, रीन_, _niça,
  { {0x660d0198,0xbd030066,0x9f41004c,0x00000000}},	//   _vsak, _gréč, ruhé_,
  { {0x395e423c,0x99840078,0xb8fc0042,0x00000000}},	//   mits_, symų_, तः_,
  { {0x672413d7,0x322b0500,0x395e423d,0x00000000}},	//   _gnij, лізм_, lits_,
  { {0x6d4803e8,0x660d0009,0xd1350001,0x00000000}},	// [7a30] _olda, _usak, онаћ,
  { {0x6b61001c,0x3209423e,0x98f5008b,0x00000000}},	//   lēgt, rway_, hỉn,
  { {0x3f15042c,0xe4ee0042,0x0596005d,0x00000000}},	//   ждес, _जाति_, _بايگ,
  { {0xc7b30047,0x2905423f,0x6d5a4240,0x00000000}},	//   לבע_, zela_, _amta,
  { {0xa195130d,0xdca504c3,0x5de5045b,0x00000000}},	//   _мамч, оали, іжка,
  { {0x0bb50062,0x527a0063,0xfe7001fb,0x00000000}},	//   ощия, _כנרא, ردن_,
  { {0x7ae94241,0x395e4242,0x2369003b,0x00000000}},	//   tget, dits_, onaj_,
  { {0xa3cb0161,0x7ae90340,0x29054243,0x00000000}},	//   रीय_, uget, wela_,
  { {0xc9a60076,0x290513a6,0x7ae94244,0x00000000}},	//   овые_, tela_, rget,
  { {0xf8af007e,0xdce3001c,0x67244245,0x00000000}},	//   رکت_, ilnī, _snij,
  { {0x6d4300d1,0xa3cb0053,0x7ae933f2,0x00000000}},	//   mkna, रीम_, pget,
  { {0xbf87008b,0x395e0003,0x29054246,0x00000000}},	//   _điền_, aits_, sela_,
  { {0x7cdb001c,0x2905305c,0x395e10c5,0x00000000}},	//   pārē, pela_, bits_,
  { {0x395e4247,0xaa880021,0x7e9a009f,0x00000000}},	//   cits_, _انهم_, יסרו,
  { {0x6d434248,0x64a3231b,0xf35a02d8,0x00000000}},	//   ikna, дара, ашај_,
  { {0x96ba0079,0x67244249,0xb3860085,0x00000000}},	//   _туку_, _unij, ілал,
  { {0xa3cb0053,0x13a8007e,0x6d433376,0x00000000}},	// [7a40] रीब_, _گنجی_, kkna,
  { {0x6d43006f,0x601a0481,0x28bf0082,0x00000000}},	//   jkna, ицер_, _श्मि,
  { {0x9eaa0002,0x600a424a,0xdeef0085,0x00000000}},	//   авеа_, рнем_, мы_,
  { {0x1e860079,0x63b301c2,0xdfcf013a,0x00000000}},	//   олем, žené, ئين_,
  { {0xdd8f007e,0x657c006f,0x80e60044,0x00000000}},	//   چون_, oorh, _وأسل,
  { {0xdd8f04f6,0x395e3170,0x8e200054,0x00000000}},	//   نون_, xits_, лiв_,
  { {0x395e424b,0xb6070014,0xfbcf0044,0x00000000}},	//   vits_, _kváð, نتي_,
  { {0xaf030259,0x5a3406b4,0x3ce00058,0x00000000}},	//   _опсл, знит, şiv_,
  { {0xa92a0088,0xf3f90529,0x8d66000a,0x00000000}},	//   аіне_, ăţi_, _двае,
  { {0xdb08424c,0x395e424d,0x6d43424e,0x00000000}},	//   _mudé, uits_, ckna,
  { {0x395e0da1,0x37aa0141,0x7793005d,0x00000000}},	//   rits_, јтон_, ویتا,
  { {0x395e233a,0x2b4d0003,0x2b5f00dd,0x00000000}},	//   sits_, chec_, ciuc_,
  { {0x657c05dd,0x94ab3f23,0x23690b59,0x00000000}},	//   forh, итва_, vnaj_,
  { {0x224000a4,0xa9230002,0x23690022,0x00000000}},	//   dyik_, _одчл, wnaj_,
  { {0x3f86004c,0x61f6056c,0x00000000,0x00000000}},	//   klou_, etyl,   ,
  { {0x7bdb014e,0x27f30066,0x730405ac,0x00000000}},	//   יקלו, žaní_, мчуж,
  { {0x657c0034,0x23690195,0x2127005d,0x00000000}},	// [7a50] borh, rnaj_, ييری_,
  { {0x349518ea,0x3f86011b,0x41740043,0x00000000}},	//   _напр, elou_, والس,
  { {0x6d430f8c,0x22520061,0x98b80022,0x00000000}},	//   vkna, azyk_, órę_,
  { {0xbf580086,0x63ba0025,0xcf580054,0x00000000}},	//   орії_, ítne, оріч_,
  { {0x7bc80185,0xdd140024,0x200e0014,0x00000000}},	//   _awdu, _dĺžk, æfir_,
  { {0x1d09005a,0xfe700021,0xf1c40053,0x00000000}},	//   секи_, خدم_, _लौटन,
  { {0x6d43424f,0x26c20051,0x3f86003b,0x00000000}},	//   rkna, ybko_, blou_,
  { {0x3f860268,0x6d430611,0x49c904c3,0x00000000}},	//   clou_, skna, блин_,
  { {0x5d554250,0x3ea00046,0x8d8701ce,0x00000000}},	//   _екат, þitt_, _дужд,
  { {0x9875005e,0x00000000,0x00000000,0x00000000}},	//   зумљ,   ,   ,
  { {0xdb01017d,0x9f950063,0x657c4251,0x00000000}},	//   _eulá, ּדָה_, vorh,
  { {0x98a50006,0xabfa0063,0x2d8700a5,0x00000000}},	//   yklė_, _להער, llne_,
  { {0xf5b60086,0x657c4252,0xae1e0053,0x00000000}},	//   ясню, torh, पियन_,
  { {0xa3d70042,0x7afb013d,0xdb08011b,0x00000000}},	//   _सिख_, lfut, _rudé,
  { {0xf7464253,0xdb0201a8,0x232a05ce,0x00000000}},	//   _неко, _bioè, бови_,
  { {0xd2aa0088,0x21f40019,0x52aa0062,0x00000000}},	//   скае_, täh_, свам_,
  { {0x7afb0035,0xe297026b,0x61f60078,0x00000000}},	// [7a60] ifut, зат_, utyl,
  { {0x660400a4,0x40960430,0xf8bd0042,0x00000000}},	//   _ipik, прет, ोरिय,
  { {0xdb0a0031,0xdb18007a,0xb53b0063,0x00000000}},	//   ppfø, msvö, _הגיש,
  { {0x2d874254,0x00000000,0x00000000,0x00000000}},	//   elne_,   ,   ,
  { {0x9e65007e,0xbb4400fe,0x539b009f,0x00000000}},	//   واهن, äämä, _ליטו,
  { {0xdce3008f,0xebc6005e,0x3f8601c8,0x00000000}},	//   donē, пљин, slou_,
  { {0x69dd034d,0x60260766,0x6bd60044,0x00000000}},	//   ásen, _эдва, ستغر,
  { {0x628600ac,0x2d874255,0x61e44256,0x00000000}},	//   _kyko, alne_, oril,
  { {0x05ac0053,0x6443005b,0x38c8007e,0x00000000}},	//   _टूलब, _üniv, يادی_,
  { {0x7afb0009,0x63a64257,0x753a00bd,0x00000000}},	//   afut, _likn, ötzl,
  { {0x66044258,0x66980041,0x61e40244,0x00000000}},	//   _apik, גאָרי, hril,
  { {0xa5f90076,0x61e402e2,0x39820014,0x00000000}},	//   оему_, kril, eðst_,
  { {0x62861c8d,0x95c84259,0x5fce0042,0x00000000}},	//   _nyko, зуса_, _हौसल,
  { {0xda65007e,0x61e43b2f,0x69c008d2,0x00000000}},	//   _تامي, dril, mpme,
  { {0xe2a60026,0x97ad005b,0x78fb0063,0x00000000}},	//   íðna_, üştü, _לפגו,
  { {0x6286425a,0xd7f8003b,0xb33b00be,0x00000000}},	//   _byko, mtă_, _viço,
  { {0xd7f8000c,0x63a60150,0xb1840124,0x00000000}},	// [7a70] ltă_, _dikn, _šťav,
  { {0x69c03bea,0xd7f8003b,0x63a60014,0x00000000}},	//   ipme, otă_, _eikn,
  { {0xd7f80529,0x61e4425b,0x661d0093,0x00000000}},	//   ntă_, aril, lvsk,
  { {0xd7f8000c,0x61e4425c,0x2bb5008f,0x00000000}},	//   ită_, bril, _nāca_,
  { {0x61e43711,0x5d790121,0xf2040085,0x00000000}},	//   cril, ойдя_, _пяро,
  { {0xc2120063,0x644800b9,0xf1b20063,0x00000000}},	//   _שהם_, ødig, _בסך_,
  { {0x3b95000a,0xf77f0075,0x64550244,0x00000000}},	//   мјит, koç_, nzzi,
  { {0x7988006f,0xdb18004b,0x49b501ce,0x00000000}},	//   eldw, ksvõ, мљоу,
  { {0x6609005b,0x2d8716bb,0x59750085,0x00000000}},	//   çekl, plne_, дыну,
  { {0x68450a3a,0xd99601f3,0x8e140085,0x00000000}},	//   дноа, ونيت_, _ядуц,
  { {0x6f19002b,0x6604425d,0xd764005d,0x00000000}},	//   odwc, _spik, فندی,
  { {0x501a0063,0xb75a0054,0x798818c0,0x00000000}},	//   קורו, ішнє_, aldw,
  { {0x6b890627,0xa3cb0235,0xd7f8000c,0x00000000}},	//   mleg, रीस_, ată_,
  { {0x61e4425e,0x6b89425f,0xe9180054,0x00000000}},	//   vril, lleg, _ночі_,
  { {0xd7f80529,0x443e02a4,0x63a64260,0x00000000}},	//   ctă_, ât_, _pikn,
  { {0x3787005a,0x6b894261,0x61e44262,0x00000000}},	//   _общо_, nleg, tril,
  { {0x6f190185,0x61e438c7,0x63a64263,0x00000000}},	// [7a80] ddwc, uril, _vikn,
  { {0x6286027d,0x93c5008b,0x61e40f15,0x00000000}},	//   _vyko, _khắ, rril,
  { {0x62860045,0x6b890026,0x7d0a0026,0x00000000}},	//   _wyko, kleg, vefs,
  { {0xddc20051,0x60ce4264,0x61e43c70,0x00000000}},	//   czoś, _webm, pril,
  { {0x6b894265,0xf2d3069a,0xbea30183,0x00000000}},	//   dleg, _בער_, вацк,
  { {0x6b821e79,0x4c940076,0x64410137,0x00000000}},	//   _skog, нилс, älig,
  { {0x93c5001b,0x6443005b,0x6b894266,0x00000000}},	//   _nhắ, _ünit, fleg,
  { {0x6b894267,0xda140001,0xdb0100a5,0x00000000}},	//   gleg, едињ, _nulä,
  { {0xf1bf0139,0x98be004c,0x58d40d4e,0x00000000}},	//   _grád_, chtě_, нопт,
  { {0xd8f8019d,0x3ade0013,0x69c000e5,0x00000000}},	//   чної_, ịp_, rpme,
  { {0x79880034,0x93c5008b,0x2d4b06a5,0x00000000}},	//   rldw, _chắ, _køen_,
  { {0xd7f80529,0x4a4606da,0x6b894268,0x00000000}},	//   rtă_, _онев, cleg,
  { {0xd7f80529,0xdb0802dd,0x56940156,0x00000000}},	//   stă_, _judí, кают,
  { {0xd7f8000c,0x661d0b2a,0x6b804269,0x00000000}},	//   ptă_, rvsk, lomg,
  { {0xe7e50053,0xdb1a0003,0x99990066,0x00000000}},	//   _किया_, _atté, ásť_,
  { {0x6b800ddc,0x442101b3,0x656e0139,0x00000000}},	//   nomg, _vrh_, anbh,
  { {0x92590002,0x290c00be,0xb33b0058,0x00000000}},	// [7a90] чаат_, oeda_, _hiçk,
  { {0xdb0100bd,0xddc20051,0x44210240,0x00000000}},	//   _zulä, szoś, _trh_,
  { {0xdb08175e,0xa3cb0042,0x518402d7,0x00000000}},	//   _audí, रीश_, тута,
  { {0x290c2f9a,0xc2eb0021,0xdb080061,0x00000000}},	//   heda_, _بعدم_, _budí,
  { {0xed4e014c,0x16220042,0xa3cb0042,0x00000000}},	//   го_, मियर_, रीर_,
  { {0x290c426a,0x61ed1ba5,0x6b890ac3,0x00000000}},	//   jeda_, mual, wleg,
  { {0x290c3716,0x6b80006f,0x6b89426b,0x00000000}},	//   deda_, fomg, tleg,
  { {0x6b9b00a4,0xdab9000d,0xddd2005f,0x00000000}},	//   umug, чыкі_, ūgšt,
  { {0x6b89064c,0x61ed053f,0x7bd801a9,0x00000000}},	//   rleg, nual, asvu,
  { {0x290c0019,0x6b89426c,0xd1020042,0x00000000}},	//   geda_, sleg, र्पण_,
  { {0x6b89426d,0x61ed426e,0x3cf80044,0x00000000}},	//   pleg, hual, _تعقد_,
  { {0x4426034d,0x61ed426f,0x394e090d,0x00000000}},	//   _čo_, kual, _elfs_,
  { {0x61ed07b7,0x290c4270,0xfaf9005f,0x00000000}},	//   jual, beda_, snūs_,
  { {0x290c4271,0x93c5008b,0x61ed4272,0x00000000}},	//   ceda_, _thắ, dual,
  { {0xf1bf018d,0x232a4273,0xc396005e,0x00000000}},	//   _atá_, пови_, ејањ,
  { {0xc7960076,0x3ead00a5,0xe73a0094,0x00000000}},	//   _ярлы, _nget_, _хеи_,
  { {0x61ed06d5,0x74ba0505,0x91e32a3b,0x00000000}},	// [7aa0] gual, _нунс_, лоте,
  { {0xdce30006,0x96570063,0x2d4b00b9,0x00000000}},	//   monė, _נשיא_, _søen_,
  { {0x505a01d5,0xdce30078,0x232a005e,0x00000000}},	//   чшая_, lonė, _еони_,
  { {0x60c3005b,0x7981001f,0xdfcf014d,0x00000000}},	//   ınma, holw, صيه_,
  { {0x61ed003e,0x79810051,0xbd87007e,0x00000000}},	//   cual, kolw, کنون_,
  { {0x3ead1781,0x26d202ae,0x237f0f18,0x00000000}},	//   _eget_, _leyo_, čuje_,
  { {0x290c4274,0x7981002b,0x0ba60054,0x00000000}},	//   veda_, dolw, ншим,
  { {0x2d8501f7,0x6ffb0063,0xdb08004c,0x00000000}},	//   _ekle_, _מפלג, _tudí,
  { {0xdee30054,0x49740320,0xdce3005f,0x00000000}},	//   _щоти, клис, jonė,
  { {0xccf80080,0x290c006d,0x6b8000ac,0x00000000}},	//   _změn_, ueda_, somg,
  { {0x61ed0529,0x31570047,0x290c4275,0x00000000}},	//   zual, גיין_, reda_,
  { {0x290c0198,0x7d1a4276,0x00000000,0x00000000}},	//   seda_, _hats,   ,
  { {0x290c00f3,0x7d1a0d68,0xbebd008f,0x00000000}},	//   peda_, _kats, _snūk,
  { {0xd90e007e,0xe4a73f17,0xba17009a,0x00000000}},	//   _اید_, ербо, _נחוץ_,
  { {0x23e40088,0xc88500bd,0x7d1a4277,0x00000000}},	//   літв, ößte_, _mats,
  { {0x3ea901b3,0x61ed03db,0x7d1a2f3d,0x00000000}},	//   žati_, tual, _lats,
  { {0x52150062,0x61ed0072,0xb69b006c,0x00000000}},	// [7ab0] ъдат, uual, geât,
  { {0xdb0100c7,0x7d1a4278,0x35f80021,0x00000000}},	//   _utlö, _nats, _أريد_,
  { {0xdcb1001b,0x7f190086,0x61ed09b7,0x00000000}},	//   _bản_, ділу_, sual,
  { {0x7d1a006f,0xdcb10013,0x61ed0050,0x00000000}},	//   _aats, _cản_, pual,
  { {0x61ed03a3,0xb33b0058,0x7d1a0b3c,0x00000000}},	//   qual, _niçi, _bats,
  { {0x398b00b9,0x7d1a4279,0x3ead04f9,0x00000000}},	//   røsk_, _cats, _wget_,
  { {0x2ef50540,0x8cd30042,0x00000000,0x00000000}},	//   _извр, डरबो,   ,
  { {0xb33b01f7,0x3eb9005b,0x6d4a133f,0x00000000}},	//   _biçi, _üst_, akfa,
  { {0xdb08017d,0x2955005a,0xf2d40047,0x00000000}},	//   _sudã, вънр, נעץ_,
  { {0x29030026,0x672d0035,0x98a522f3,0x00000000}},	//   ýja_, _anaj, кипе,
  { {0x798100f1,0xdcb1008d,0xb17b00a5,0x00000000}},	//   rolw, _hảo_, _tvåf,
  { {0x366a08a2,0x6616427a,0x6f1b427b,0x00000000}},	//   дамо_, _psyk, _jauc,
  { {0x06750062,0x7981427c,0xeab0005d,0x00000000}},	//   гуря, polw, _اعم_,
  { {0x6f1b003d,0x7dd80025,0x672d427d,0x00000000}},	//   _lauc, _húsá, _enaj,
  { {0xccf2089e,0x94793ba6,0x00000000,0x00000000}},	//   יכם_, есту_,   ,
  { {0x6f1b14e2,0xa2560043,0x00000000,0x00000000}},	//   _nauc, نپزش,   ,
  { {0x6567006f,0xdcf8003b,0x69db427e,0x00000000}},	// [7ac0] bijh, novă, nsue,
  { {0x25d700b5,0xd5b70161,0x672d427f,0x00000000}},	//   _שוין_, _इंतज, _znaj,
  { {0xc0590086,0x6f1b004d,0x4fa60062,0x00000000}},	//   нії_, _bauc, вижв,
  { {0xdcb1001b,0x69db4280,0x7d1a03d4,0x00000000}},	//   _bảo_, ksue, _sats,
  { {0x7d1a4281,0xa66d089e,0xfe720044,0x00000000}},	//   _pats, ּדוֹ, جدا_,
  { {0xde930001,0x8db50085,0x365b009a,0x00000000}},	//   јашњ, усці, וכננ,
  { {0x98be0006,0x6f1b3711,0xdb0800be,0x00000000}},	//   nktą_, _fauc, _audá,
  { {0x6f1b0164,0x5b1406b4,0x98be0078,0x00000000}},	//   _gauc, умит, iktą_,
  { {0x7d1a4282,0xb60600c2,0x3ea3030b,0x00000000}},	//   _tats, ndšč, _витг,
  { {0x672d2ee7,0x35dc0042,0x6da60043,0x00000000}},	//   _snaj, _बिज़, _شمام,
  { {0xd6d50121,0x6da30131,0x96f91006,0x00000000}},	//   лжны, _тифа, нент_,
  { {0x69db006d,0x6f02213a,0x98ac0078,0x00000000}},	//   bsue, nfoc, ykdė_,
  { {0x7bc1011b,0x8674012c,0xe6644283,0x00000000}},	//   _ztlu, илює, атро,
  { {0x7ae20072,0xda6501fb,0x19b90085,0x00000000}},	//   _hdot, _حامي, _чуць_,
  { {0x89370063,0x44250dcc,0x6567006f,0x00000000}},	//   _ברגע_, íl_, rijh,
  { {0x672d1964,0x97a4026c,0x3a264284,0x00000000}},	//   _unaj, _крыл, _krop_,
  { {0x291e00d1,0x291c0019,0x6f1b0221,0x00000000}},	// [7ad0] odta_, _kava_, _rauc,
  { {0x26d9116d,0x291e00ea,0x291c0849,0x00000000}},	//   laso_, ndta_, _java_,
  { {0x7ae2024a,0x6b5e003d,0x29c2008b,0x00000000}},	//   _odot, lūgu, hưa_,
  { {0xe3b0007e,0x8d84005d,0x291c4285,0x00000000}},	//   _گری_, یشون, _lava_,
  { {0xfce50619,0xdef80475,0x201e007d,0x00000000}},	//   голо, тых_, _štit_,
  { {0x7ae24286,0xe3b0007e,0x0d840500,0x00000000}},	//   _adot, _دری_, алін,
  { {0x26d94287,0x6f1b00bd,0xdb084288,0x00000000}},	//   kaso_, _tauc, _sudá,
  { {0xe4e30053,0xdce30006,0x3a150062,0x00000000}},	//   कृति_, minč, гьос,
  { {0x2249014f,0x39990003,0xdce34289,0x00000000}},	//   nyak_, hèse_, nonī,
  { {0x6ce40088,0x2249002c,0x69db155c,0x00000000}},	//   _віце, iyak_, rsue,
  { {0x3a260122,0x65e20047,0x69db428a,0x00000000}},	//   _erop_, יפּער, ssue,
  { {0xf0920063,0xdb0800ea,0x6d410364,0x00000000}},	//   מני_, _tudá, _hola,
  { {0x09e50076,0xdb0800b9,0x55f602dc,0x00000000}},	//   _солн, _budæ, ычну,
  { {0x2249428b,0xdce3127e,0x60d52fb7,0x00000000}},	//   dyak_, kinč, _nezm,
  { {0x6d41057a,0x5faf0042,0xa2e60d3b,0x00000000}},	//   _mola, _जंगल, ловд,
  { {0x8cca016a,0x26d93cb8,0x64410072,0x00000000}},	//   _स्नो, caso_, älia,
  { {0xb2260088,0x60d50db7,0xb77b0041,0x00000000}},	// [7ae0] ымал, _bezm, _ראפש,
  { {0x67050053,0x6b5e001c,0x6d411017,0x00000000}},	//   ष्ठक_, lūgt, _nola,
  { {0xdcb1001b,0xd46a290b,0x39990003,0x00000000}},	//   _cảm_, _чине_, cèse_,
  { {0xf1bf428c,0x236900a8,0x4f95428d,0x00000000}},	//   _irán_, ciaj_, арчу,
  { {0xdee3065b,0x290700a8,0x6d41428e,0x00000000}},	//   сочи, _obna_, _bola,
  { {0x645c0024,0x6d41428f,0x3f8f0019,0x00000000}},	//   ozri, _cola, algu_,
  { {0xab5c003d,0x69c2158f,0xfbaa0363,0x00000000}},	//   _atļa, _stoe, нтий_,
  { {0x6d41018d,0x291c003d,0x3a26368c,0x00000000}},	//   _eola, _sava_, _prop_,
  { {0x6d410025,0x26d90290,0xdd8f005d,0x00000000}},	//   _fola, vaso_, _کول_,
  { {0xa967000a,0xdb0b00cd,0x02170063,0x00000000}},	//   лиња_, _ligè, נחים_,
  { {0x31372177,0xb8dc0053,0x394c00a4,0x00000000}},	//   אריך_, _अल_, rkds_,
  { {0x3a2603b2,0x6d41006f,0xdb0b01a8,0x00000000}},	//   _trop_, _zola, _nigè,
  { {0xb5fb000f,0x26d94290,0xe66708ac,0x00000000}},	//   zzáf, raso_, утно,
  { {0x23690022,0x6d580046,0xf1bf011b,0x00000000}},	//   wiaj_, nhva, _brán_,
  { {0x26d94291,0x88bb0047,0x03d50054,0x00000000}},	//   paso_, _אזוי, ржбю,
  { {0xe3150001,0xdce34292,0x939700de,0x00000000}},	//   јмањ, vinč, اجسا,
  { {0x6b5e0023,0x62340054,0x5224012c,0x00000000}},	// [7af0] lūgs, бету, йффа,
  { {0x660d00bb,0x23690051,0x7c284293,0x00000000}},	//   _ipak, siaj_, _ordr,
  { {0x22490089,0x60d50114,0x6d414294,0x00000000}},	//   syak_, _vezm, _rola,
  { {0x743a00b5,0xdce30006,0x398b06a5,0x00000000}},	//   _סערװ, rinč, løst_,
  { {0x8e85000a,0xa91c0024,0x6d414295,0x00000000}},	//   јгле, voľn, _pola,
  { {0x660d0009,0xd5bc00b5,0x6448004d,0x00000000}},	//   _mpak, עזול, ädig,
  { {0xeab10021,0x4154005e,0x8cc10042,0x00000000}},	//   يعة_, _уврс, रुषो,
  { {0x61ed4296,0xdd050058,0x660d3561,0x00000000}},	//   oral, ısıy, _opak,
  { {0x5f4400b3,0x6d411cf4,0x7c28192a,0x00000000}},	//   _انقل, _tola, _erdr,
  { {0x61ed10ff,0x63af007d,0xaa080021,0x00000000}},	//   iral, _licn, ازيل_,
  { {0x660d4297,0x2d874298,0x61ed0066,0x00000000}},	//   _apak, mone_, hral,
  { {0x61ed35c7,0x6e294299,0x2d87429a,0x00000000}},	//   kral, _kreb, lone_,
  { {0x7f3a00b7,0x0ab4006a,0x2d870019,0x00000000}},	//   דערו, _احمد, oone_,
  { {0x20010222,0x2d87429b,0x61ed13a6,0x00000000}},	//   kthi_, none_, dral,
  { {0xdb0b0025,0x6f0903a4,0x2d8701f4,0x00000000}},	//   _aigé, _obec, ione_,
  { {0x2d8728b2,0x69c9004e,0x58940044,0x00000000}},	//   hone_, opee, _اجهز,
  { {0x42230076,0xdb0a0137,0x2d87429c,0x00000000}},	// [7b00] одтв, ppfö, kone_,
  { {0xe3ba0076,0xf1bf0013,0x6f09429d,0x00000000}},	//   _ибо_, _trán_, _abec,
  { {0x2d872672,0xf1bf01d1,0x46ba0042,0x00000000}},	//   done_, _hrál_, _इलाह,
  { {0x3f7802e2,0xf1bf0080,0x3eb200d1,0x00000000}},	//   ačun_, _král_, øyt_,
  { {0x2d87429e,0x6e29429f,0x63a40479,0x00000000}},	//   fone_, _creb, mmin,
  { {0xb5fb000f,0xcbe6026b,0x63a442a0,0x00000000}},	//   szág, ации, lmin,
  { {0x6ca3005a,0x69c90438,0x63a442a1,0x00000000}},	//   оръж, epee, omin,
  { {0xdb00006c,0x63a406ae,0x0b18005e,0x00000000}},	//   ommé, nmin, ужић_,
  { {0x998202f4,0x4d160121,0x238a0078,0x00000000}},	//   íků_, _вьет, mėję_,
  { {0x63a401f7,0x238a0078,0x2d8742a2,0x00000000}},	//   hmin, lėję_, cone_,
  { {0x63a40d93,0xb5fb013d,0xc0530041,0x00000000}},	//   kmin, zzád, ַזש_,
  { {0x7bca00bd,0xdce3001c,0x6f01013d,0x00000000}},	//   mpfu, minā, mábó,
  { {0xdce3003d,0x63a40b82,0x7bca42a3,0x00000000}},	//   linā, dmin, lpfu,
  { {0x63a442a4,0x61ed0c11,0x14c7005d,0x00000000}},	//   emin, vral, شهری_,
  { {0xdce3003d,0x6b55006d,0x398b069f,0x00000000}},	//   ninā, _hága, røst_,
  { {0xe7380138,0x23bc00ea,0x63b70137,0x00000000}},	//   _већ_, _díj_, _vuxn,
  { {0x2d870034,0xdcef0080,0x238a0078,0x00000000}},	// [7b10] yone_, _řeče, dėję_,
  { {0x61ed0449,0xdcf8001c,0x7988002b,0x00000000}},	//   rral, ilvē, nodw,
  { {0x63a442a5,0xdfa7000a,0x6f0100ea,0x00000000}},	//   bmin, ајдо, jábó,
  { {0x2d870250,0xdce3001c,0x20012389,0x00000000}},	//   wone_, dinā, rthi_,
  { {0xfe7003eb,0xf1a7000a,0xdcb10013,0x00000000}},	//   وده_, _врвн, _hải_,
  { {0x6b73003b,0xa5da0047,0xbebd008f,0x00000000}},	//   măgi, אַקי, _saūd,
  { {0x7afd00cd,0x2d8742a6,0xcb690a3a,0x00000000}},	//   òsto, rone_, лаке_,
  { {0x2d8742a7,0x44780063,0x6e2942a8,0x00000000}},	//   sone_, יעול_, _treb,
  { {0xaa490076,0x2d87252b,0x7988002b,0x00000000}},	//   уппа_, pone_, fodw,
  { {0x69c900fe,0xdce3001c,0x63a442a9,0x00000000}},	//   rpee, binā, zmin,
  { {0xdce3003d,0x644100fe,0x63a40bcf,0x00000000}},	//   cinā, älil, ymin,
  { {0x6b550025,0x69c90fef,0x97560092,0x00000000}},	//   _fága, ppee, стољ,
  { {0x4e790047,0x63a40075,0xa909005d,0x00000000}},	//   ראָצ, vmin, _ميشل_,
  { {0x0446032d,0x63a4002b,0x6b890335,0x00000000}},	//   бегн, wmin, loeg,
  { {0x63a40004,0x8579005a,0xdce8004c,0x00000000}},	//   tmin, рсят_, _ajdě,
  { {0xdcb1008b,0x6756007e,0x6b890983,0x00000000}},	//   _cải_, _دختر, noeg,
  { {0xdce3003d,0x78c600ea,0xdcb1008d,0x00000000}},	// [7b20] zinā, _érvé, _dải_,
  { {0x63a442aa,0xdb080137,0x05b50082,0x00000000}},	//   smin, _utdö, ंदरब,
  { {0xd8da0047,0xc0062282,0x63a4388f,0x00000000}},	//   רקער, спек, pmin,
  { {0x27fa0031,0x644e0006,0xd00f0021,0x00000000}},	//   _åpne_, mybi, علن_,
  { {0x656e0139,0x238a0078,0x644e33ca,0x00000000}},	//   oibh, rėję_, lybi,
  { {0xdce3001c,0x8e200086,0x6f0100ea,0x00000000}},	//   tinā, кiв_, tábó,
  { {0x61f6005b,0x644e0078,0x60de008f,0x00000000}},	//   luyl, nybi, mapm,
  { {0xdce3001c,0xf06308a6,0x90770047,0x00000000}},	//   rinā, _эксп, _העלא_,
  { {0xdce3003d,0x61f6005b,0x6f0100ea,0x00000000}},	//   sinā, nuyl, sábó,
  { {0x290a0024,0x644e0006,0xdce3001c,0x00000000}},	//   ýba_, kybi, pinā,
  { {0x23810006,0x2bca0a29,0x61f60168,0x00000000}},	//   lėje_, _слеп_, huyl,
  { {0x644e0006,0x29020080,0x7988001f,0x00000000}},	//   dybi, řka_, sodw,
  { {0x238100eb,0x8f9b0041,0xc66b2a92,0x00000000}},	//   nėje_, טיטי, ушне_,
  { {0x656e0025,0xdce3000c,0x6d5d0078,0x00000000}},	//   gibh, mină, _įsak,
  { {0x644e0078,0x6b55013d,0xf3970044,0x00000000}},	//   gybi, _mágn, مؤرخ,
  { {0xa91c0024,0x443f017f,0x5b7b00b5,0x00000000}},	//   koľk, ću_, ָרמא,
  { {0xdb080024,0xb5fb013d,0xf1bf01c8,0x00000000}},	// [7b30] _budú, száb, _irák_,
  { {0xba9b0063,0x32d70013,0xa25b002b,0x00000000}},	//   רסמי, ầy_, _ffôn,
  { {0x442742ab,0xdcb1001b,0x644e0ac3,0x00000000}},	//   _én_, _tải_, cybi,
  { {0xdddb016b,0xd7fb0047,0x60c90058,0x00000000}},	//   _využ, רהאל, _şemd,
  { {0x6b890a53,0x98a70051,0xf12742ac,0x00000000}},	//   voeg, _inną_, _льво,
  { {0x60de001c,0x3cfe1bef,0x629d008f,0x00000000}},	//   capm, _cctv_, _izso,
  { {0x8c42005a,0x6b8942ad,0xdcf8004c,0x00000000}},	//   деще, toeg, lově,
  { {0x39e942ae,0x1b4906da,0x23810078,0x00000000}},	//   адио_, рзии_, bėje_,
  { {0x4424008b,0x6b8942af,0xfaf9008f,0x00000000}},	//   ̉m_, roeg, rgū_,
  { {0x764f0051,0xb0c70085,0x6b840a10,0x00000000}},	//   dycy, апiс, čiga,
  { {0xe73a0189,0x8c190021,0xdcf8004c,0x00000000}},	//   аен_, _خيار_, hově,
  { {0xc4c90ee1,0x644e0078,0x16aa05ef,0x00000000}},	//   _יג_, vybi, ивни_,
  { {0x65a000bd,0x2bb5001c,0xdce3003b,0x00000000}},	//   höhe, _vācu_, cină,
  { {0xdcf80080,0x644e091b,0x7afb004b,0x00000000}},	//   dově, tybi, lgut,
  { {0xa34a42b0,0x442c0025,0x23810078,0x00000000}},	//   азва_, íd_, zėje_,
  { {0xfbe700aa,0x644e28d2,0xdb1a017d,0x00000000}},	//   _để_, rybi, _autê,
  { {0xb5fb0024,0x7afb004b,0xcb12089e,0x00000000}},	// [7b40] rzác, igut, ולן_,
  { {0x21a30079,0x67240009,0x50960001,0x00000000}},	//   диум, _haij, оређ,
  { {0x67260031,0xe0d50086,0x3cfe42b1,0x00000000}},	//   odkj, яють, _rctv_,
  { {0x23810006,0x672600d1,0x25b7007e,0x00000000}},	//   tėje_, ndkj, _دهید_,
  { {0xeda60259,0x672442b2,0x8d8601f3,0x00000000}},	//   ошко, _maij, يشتن,
  { {0x23810006,0x61e442b3,0xcd060054,0x00000000}},	//   rėje_, msil, ічли,
  { {0x6b5c0164,0x23810006,0x61e442b4,0x00000000}},	//   _lége, sėje_, lsil,
  { {0x23810006,0x60dc42b5,0x8cca0053,0x00000000}},	//   pėje_, _herm, _स्रो,
  { {0x61e41e27,0x60dc22bc,0x394742b6,0x00000000}},	//   nsil, _kerm, _bons_,
  { {0x60dc3c71,0x61e442b7,0x39580014,0x00000000}},	//   _jerm, isil, órs_,
  { {0x6d5a0072,0x60dc42b8,0x39472335,0x00000000}},	//   _ilta, _merm, _dons_,
  { {0xd6db42b9,0x61e40659,0x6d4810f5,0x00000000}},	//   што_, ksil, _hoda,
  { {0x394742ba,0x6b5c42bb,0x6d4842bc,0x00000000}},	//   _fons_, _végd, _koda,
  { {0xd5b80088,0x65a000fe,0x6b5c006c,0x00000000}},	//   ўся_, yöhe, _dége,
  { {0x29c0001b,0x61e604c7,0x2d4b00b9,0x00000000}},	//   _hòa_, _avkl, _køer_,
  { {0x6d4842bd,0x53341410,0xdce30022,0x00000000}},	//   _loda, мест, miną,
  { {0x60dc0e53,0x61e4002c,0x6d480019,0x00000000}},	// [7b50] _berm, gsil, _ooda,
  { {0xd7f8000c,0x60dc003e,0xdcf8004c,0x00000000}},	//   ouă_, _cerm, rově,
  { {0xd7f8000c,0x7ae0002c,0x60dc4208,0x00000000}},	//   nuă_, kamt, _derm,
  { {0xdcf80080,0xed590080,0x441a0063,0x00000000}},	//   pově, _muže_, _פורס,
  { {0xfe71007e,0x60dc42be,0x7dc40021,0x00000000}},	//   رگر_, _ferm, وتوك,
  { {0xabd5018e,0x8d6532ea,0x6d4842bf,0x00000000}},	//   пциј, явле, _coda,
  { {0x6d480a97,0x75250075,0x7afb0244,0x00000000}},	//   _doda, _mahz, tgut,
  { {0xb5fb000f,0x547c07e9,0xe9d90d82,0x00000000}},	//   zzáa, יטוו, бки_,
  { {0x394742c0,0x7afb42c1,0x60c5004d,0x00000000}},	//   _pons_, rgut, ochm,
  { {0x60c50359,0x395e27ff,0x6b5c01d4,0x00000000}},	//   nchm, ghts_, _rége,
  { {0x7d7a0047,0x661d0051,0x60c50206,0x00000000}},	//   _פרעג, ewsk, ichm,
  { {0x6d4802b0,0x6f19001f,0xed59017f,0x00000000}},	//   _zoda, newc, _duže_,
  { {0x45d3000d,0x442142c2,0xe8ee2377,0x00000000}},	//   ноўс, _ash_, _пл_,
  { {0x88bc0080,0x6b5c00ea,0x395e27a0,0x00000000}},	//   nděl, _vége, chts_,
  { {0x68e10004,0x6b55007a,0xb8ff016a,0x00000000}},	//   mald, _lágm, तर_,
  { {0x6b5c00ea,0x91b1008b,0x68e142c3,0x00000000}},	//   _tége, _đáp_, lald,
  { {0xd29a0086,0x50ba007e,0x60dc0764,0x00000000}},	// [7b60] стві_, مداد_, _perm,
  { {0x68e142c4,0x61e410a5,0x776d0066,0x00000000}},	//   nald, rsil, _zmax,
  { {0x351b0063,0x73e30121,0x14d70047,0x00000000}},	//   _פוטנ, _поэз, _מויל_,
  { {0x68e142c5,0x6d4842c6,0xc7d60063,0x00000000}},	//   hald, _soda, פוני_,
  { {0xf3f100aa,0x68e10425,0x6d4842c7,0x00000000}},	//   ợc_, kald, _poda,
  { {0x68e1138f,0x61e200c2,0x2d4b00b9,0x00000000}},	//   jald, šols, _søer_,
  { {0x7ae00537,0x6d4842c8,0xccf8004c,0x00000000}},	//   tamt, _voda, _směs_,
  { {0x7b630076,0x5a34026b,0xad66007e,0x00000000}},	//   етье, днит, _کاره,
  { {0x23810006,0x68e142c9,0x6d48095b,0x00000000}},	//   nėja_, fald, _toda,
  { {0x7ae042ca,0x68e142cb,0x6d480072,0x00000000}},	//   samt, gald, _uoda,
  { {0xa91c034d,0x7ae0017f,0x07e30054,0x00000000}},	//   koľv, pamt, нцям,
  { {0x29c0008b,0x68e11500,0xdc3b009a,0x00000000}},	//   _tòa_, aald, _לעבר,
  { {0xe81e016a,0xf1bf008b,0xc6a40121,0x00000000}},	//   _बनवा_, _trái_, ерри,
  { {0x5e5700b5,0x4a530086,0x68e10876,0x00000000}},	//   ליכע_, _якіс, cald,
  { {0x439542cc,0xdb1a006d,0x91790013,0x00000000}},	//   давс, _auté, _lận_,
  { {0x88bc0080,0xa87b0165,0xdc370047,0x00000000}},	//   zděl, _לאור, האלט_,
  { {0x248d0045,0x7afd00cd,0x23810078,0x00000000}},	// [7b70] łem_, òsti, gėja_,
  { {0x30a706b4,0x60cf008d,0x60c5004d,0x00000000}},	//   прев, ̀imơ, uchm,
  { {0xb4d90394,0xc9530047,0x8408013d,0x00000000}},	//   ारी_, עמע_, rdőí,
  { {0x60c500bd,0x91790013,0x9f55000d,0x00000000}},	//   schm, _bận_, ьвеч,
  { {0xe2ab006a,0x9179008b,0xb5fb00ea,0x00000000}},	//   _دادن_, _cận_, zzán,
  { {0x62800006,0x51871259,0xccf8004c,0x00000000}},	//   _žmog, _хума, _směr_,
  { {0x68e142cd,0xea00001b,0x3f670699,0x00000000}},	//   vald, _đại_, _етаб,
  { {0x68e140cd,0x49c924cc,0x88bc011b,0x00000000}},	//   wald, олин_, sděl,
  { {0x320900bb,0x80e10053,0x4ea702a9,0x00000000}},	//   ntay_, _फ़ाइ, _хрва,
  { {0x6e280063,0x57e90084,0x3f8f42ce,0x00000000}},	//   _מֵעַ, одом_, logu_,
  { {0x8cc8007e,0x088905ac,0x68e142cf,0x00000000}},	//   _رونق_, юбой_, rald,
  { {0x68e142d0,0xb5fb0331,0x7c940021,0x00000000}},	//   sald, rzán, _أشكا,
  { {0x68e142d1,0x69cb0137,0xb5fb00ea,0x00000000}},	//   pald, _utge, szán,
  { {0x64a642d2,0x19ba009a,0x00000000,0x00000000}},	//   дага, _ומסב,   ,
  { {0x3f8f0004,0xa5070121,0xb5fb013d,0x00000000}},	//   kogu_, ьера_, lzál,
  { {0x130a0088,0x03a342d3,0x23810078,0x00000000}},	//   ўнай_, висо, tėja_,
  { {0x2fcd017f,0xb5fb42d4,0xe297295e,0x00000000}},	// [7b80] _čega_, nzál, дат_,
  { {0x6b5c0003,0x23810078,0xc076005e,0x00000000}},	//   _méga, rėja_, мћењ,
  { {0x6b5c0164,0x409605fb,0x32092e10,0x00000000}},	//   _léga, фрат, atay_,
  { {0x9f5a00a5,0x2bc40042,0xdb1a117d,0x00000000}},	//   ktpå_, _लंबा, _tuté,
  { {0x6b5c0164,0xd176000d,0x2e470062,0x00000000}},	//   _néga, _жывы, дящо_,
  { {0xdfd20032,0xf1bf027d,0x9179008b,0x00000000}},	//   _ليس_, _práv_, _vận_,
  { {0xab94019d,0x1d19000d,0x55770047,0x00000000}},	//   никі, яюць_, ועסן_,
  { {0x9179008b,0x6b5c0003,0xdb02008d,0x00000000}},	//   _tận_, _béga, _khoé,
  { {0x8bb30032,0x2986014b,0x00000000,0x00000000}},	//   خصوص, дынг,   ,
  { {0x6b5c0003,0xdb0b017d,0xdce30078,0x00000000}},	//   _déga, _vigá, kinę,
  { {0xd0f70063,0x00f70165,0x9cd70063,0x00000000}},	//   ומית_, וזים_, _חובה_,
  { {0xa91c0024,0xf1bf01d9,0x61f61026,0x00000000}},	//   voľu, _krát_, kryl,
  { {0x99660ebc,0xb7d8007e,0x9c7c00c2,0x00000000}},	//   _откл, _کوبا_, _deče,
  { {0xb4d90161,0x88bc0080,0xd7fa000a,0x00000000}},	//   ारे_, zděj, _дуи_,
  { {0x734b0054,0xdce30022,0x349401d5,0x00000000}},	//   очав_, ginę, варр,
  { {0x799a001f,0x644300cd,0xed5904c9,0x00000000}},	//   lltw, _ànim, _muža_,
  { {0xf1bf001b,0x6d58069f,0x61f9000d,0x00000000}},	// [7b90] _quá_, kkva, янаў_,
  { {0x51f808a6,0x65a0004d,0x6d580d84,0x00000000}},	//   ьную_, löhn, jkva,
  { {0x32090509,0x6d5802c0,0x3f8f16fe,0x00000000}},	//   stay_, dkva, togu_,
  { {0x23810006,0x30a421f2,0xf1bf004c,0x00000000}},	//   mėjo_, трув, _brát_,
  { {0x23810006,0x63ad2936,0x645500e5,0x00000000}},	//   lėjo_, mman, lyzi,
  { {0x237f017f,0xdca51d7c,0x6b5c0003,0x00000000}},	//   čuju_, нали, _réga,
  { {0xaf07011c,0x23810078,0x63ad42d5,0x00000000}},	//   _очак, nėjo_, oman,
  { {0xeb990002,0xce950062,0x6b5c42d6,0x00000000}},	//   џии_, _забъ, _péga,
  { {0x443e001b,0x7d2800fe,0x9c7c01b3,0x00000000}},	//   ̣t_, össä, _reče,
  { {0x29030019,0x23810006,0x6b5542d7,0x00000000}},	//   üja_, kėjo_, _mági,
  { {0xa91c0024,0xb5fb00ea,0x63ad42d8,0x00000000}},	//   voľt, szál, kman,
  { {0x23810006,0x63ad42d9,0xdc03004a,0x00000000}},	//   dėjo_, jman, nčít,
  { {0x63630019,0xceb20047,0x7bc125ad,0x00000000}},	//   _mõnd, ָים_, _hulu,
  { {0x1869005a,0x7bc10aba,0x6b9b42da,0x00000000}},	//   _нали_, _kulu, llug,
  { {0xa8790047,0xe946007e,0x9c7c1333,0x00000000}},	//   _מאַר, _سروی, _teče,
  { {0x7bc1003e,0xc32300e1,0x63ad42db,0x00000000}},	//   _mulu, лмск, gman,
  { {0x7bc1003e,0xe1fa1915,0x877b0041,0x00000000}},	// [7ba0] _lulu, яга_, _מאקי,
  { {0x63ad42dc,0x23810078,0x7bc10072,0x00000000}},	//   aman, bėjo_, _oulu,
  { {0xdfcf0242,0xc0590086,0xf1bf017d,0x00000000}},	//   ميل_, мії_, _brás_,
  { {0xeaa7043b,0x5de618cc,0xed59007d,0x00000000}},	//   _مع_, ежда, _ruža_,
  { {0x6283004d,0xfe72002a,0x67050042,0x00000000}},	//   ßnot, ددا_, ष्टक_,
  { {0x7bc101f7,0xb60600c3,0x200700cd,0x00000000}},	//   _bulu, mešč, ànic_,
  { {0x6aa200ea,0x6d581a8a,0xb60600c2,0x00000000}},	//   _szof, rkva, lešč,
  { {0x67c80080,0x6b9b007a,0xa3e20161,0x00000000}},	//   _něja, glug, नीय_,
  { {0xa7fc005b,0xc3330063,0x6455056c,0x00000000}},	//   azıl, רוח_, zyzi,
  { {0x65a000bd,0x63ad1b68,0x7bc10150,0x00000000}},	//   wöhn, zman, _fulu,
  { {0x63ad42dd,0x7bc142de,0x96f90f50,0x00000000}},	//   yman, _gulu, мент_,
  { {0xb5fb000f,0x63630019,0x23810006,0x00000000}},	//   szám, _kõne, vėjo_,
  { {0xf710008b,0xdb0900ea,0x75e7000d,0x00000000}},	//   _tầng_, _önál, эўне,
  { {0x63630004,0xd5b80076,0xb5240475,0x00000000}},	//   _mõne, есс_, льск,
  { {0x63ad42df,0x291e42e0,0x24e4000d,0x00000000}},	//   tman, meta_, ыцяг,
  { {0x6b5542e1,0x291e42e2,0x23810006,0x00000000}},	//   _pági, leta_, rėjo_,
  { {0x2018354b,0x9f5a0003,0xb5fb00ea,0x00000000}},	// [7bb0] _apri_, cupé_, zzáj,
  { {0x291e1eee,0x6441065c,0x6f0230e7,0x00000000}},	//   neta_, älis, egoc,
  { {0x6b5c42e3,0x26cb0290,0x4ae00053,0x00000000}},	//   _négo, occo_, नराव,
  { {0x65a0004d,0x2d9c42e4,0xb60600a8,0x00000000}},	//   höhl, elve_, bešč,
  { {0xed4e0001,0x5e580086,0x291e42e5,0x00000000}},	//   ао_, ниця_, keta_,
  { {0x212a0027,0x7bc11320,0x7f98006d,0x00000000}},	//   _gabh_, _pulu, díqu,
  { {0xf1bf1cb1,0xac160001,0xd0840121,0x00000000}},	//   _trás_, воју_, _быти,
  { {0x6b5c0003,0x7f98006d,0xd7f800dd,0x00000000}},	//   _dégo, fíqu, dră_,
  { {0xdcbb0055,0xd7f8003b,0x291e1d88,0x00000000}},	//   _еще_, eră_, feta_,
  { {0x7bc142e6,0x6448004d,0xd7f8003b,0x00000000}},	//   _tulu, ädik, fră_,
  { {0xd7f8000c,0x8cca0053,0xf7720242,0x00000000}},	//   gră_, _स्टो, لاح_,
  { {0x6d53008f,0x1a65005d,0x7ae242e7,0x00000000}},	//   šdaļ, _لیبی_, _geot,
  { {0xd7f80529,0x291e42e8,0xa6830505,0x00000000}},	//   ară_, beta_, илюд,
  { {0x5e5600b5,0xb60600c3,0xdce30080,0x00000000}},	//   דישע_, vešč, vině,
  { {0x79a40635,0xf99001a7,0x68e30035,0x00000000}},	//   _срце, _ابن_, _iend,
  { {0x6b5c0164,0x68e342e9,0x27f80124,0x00000000}},	//   _négl, _hend, árne_,
  { {0x68e342ea,0x98bc0080,0xe81d0053,0x00000000}},	// [7bc0] _kend, _nově_, यौरा_,
  { {0x68e3028d,0x3ebf01a8,0xb5fb013d,0x00000000}},	//   _jend, _agut_, zzák,
  { {0x68e308f0,0xb69b003b,0xd12f00f2,0x00000000}},	//   _mend, ngân, تمل_,
  { {0x20070268,0x6363004b,0x7d0305a5,0x00000000}},	//   ània_, _põne, egns,
  { {0x33200268,0x212a0139,0x6b5c006c,0x00000000}},	//   meix_, _tabh_, _ségo,
  { {0x7ae20004,0x33200268,0x68e342eb,0x00000000}},	//   _seot, leix_, _nend,
  { {0x6b550026,0x291e2968,0xad6501fb,0x00000000}},	//   _lágu, veta_, دانه,
  { {0x33200268,0x8c430001,0x291e05b3,0x00000000}},	//   neix_, реће, weta_,
  { {0x68e30498,0x9c7c007d,0x442d0013,0x00000000}},	//   _bend, _deča, ̉e_,
  { {0xd7f80469,0xdbd90016,0x68e342ec,0x00000000}},	//   tră_, _açõe, _cend,
  { {0x013500b5,0x31570063,0x1c39000d,0x00000000}},	//   אָרט_, דיין_, _пяць_,
  { {0xa5f90076,0x68e33c1c,0x291e42ed,0x00000000}},	//   нему_, _eend, seta_,
  { {0x33200268,0x68e30305,0xcf930063,0x00000000}},	//   deix_, _fend, שטר_,
  { {0x68e33cbf,0xd8760021,0xd7f8003b,0x00000000}},	//   _gend, _لاعب, pră_,
  { {0x478b0001,0x647406c3,0xdc03004c,0x00000000}},	//   _осим_, агру, očát,
  { {0x33200994,0x68e31a84,0x68e842ee,0x00000000}},	//   geix_, _zend, ladd,
  { {0x6b5c0164,0x68e342ef,0x7d0300a5,0x00000000}},	// [7bd0] _régl, _yend, ygns,
  { {0x71990043,0xeab1009d,0x00000000,0x00000000}},	//   رناز_, זֹב_,   ,
  { {0x332000cd,0x2fe40021,0xb604008f,0x00000000}},	//   beix_, لكلف, ļšev,
  { {0x68e80075,0x11d70044,0x4f94012c,0x00000000}},	//   hadd, _لتسد, аріу,
  { {0xe3b200b5,0x6b5c00ea,0xdb020025,0x00000000}},	//   _לױט_, _végl, _choí,
  { {0x672d024a,0xc6940041,0x865c0063,0x00000000}},	//   _laaj, סאס_, ודדי,
  { {0x68e3316e,0x7d1e004b,0x61ed42f0,0x00000000}},	//   _rend, õpsa, lsal,
  { {0x3ebf0089,0x8c160021,0x61ed42f1,0x00000000}},	//   _ugut_, ايير_, osal,
  { {0x68e342ec,0x9c7c00c2,0x68e80e7f,0x00000000}},	//   _pend, _veča, fadd,
  { {0x3af3008b,0x70e10053,0x6e29172b,0x00000000}},	//   ợp_, _फ़ोल, _iseb,
  { {0x2001003e,0x9c7c08ea,0xdbd9017d,0x00000000}},	//   nuhi_, _teča, _pçõe,
  { {0x68e319cd,0x61ed42f2,0xb69b3ecf,0x00000000}},	//   _wend, ksal, rgân,
  { {0xfa34007e,0x68e31ecc,0x7ae942f3,0x00000000}},	//   _پرند, _tend, maet,
  { {0x7ae90185,0x68e80290,0x68e342f4,0x00000000}},	//   laet, cadd, _uend,
  { {0x33200994,0x63bd0e53,0x6b550027,0x00000000}},	//   teix_, _bisn, _fágt,
  { {0x6e290198,0x7ae90185,0xb5fb013d,0x00000000}},	//   _oseb, naet, zzái,
  { {0x33200994,0x61ed002c,0xd3870b0f,0x00000000}},	// [7be0] reix_, gsal, уйте_,
  { {0x6f09006d,0x290542f5,0x29c90013,0x00000000}},	//   _acec, ngla_, _múa_,
  { {0x29051663,0x61ed0bbf,0x20010150,0x00000000}},	//   igla_, asal, guhi_,
  { {0x2fd7007e,0x6db90066,0x42d501dd,0x00000000}},	//   اوند_, _dňam, _віру,
  { {0x7ae90185,0x629d001f,0x6b550014,0x00000000}},	//   daet, _gyso, _lágs,
  { {0x6c54000a,0x20010150,0x65360047,0x00000000}},	//   иклу, buhi_, ראַף_,
  { {0xcd27018e,0x7ae9001f,0x50b50499,0x00000000}},	//   ужје_, faet, _всту,
  { {0x29c9007a,0x7ae90185,0x68e83347,0x00000000}},	//   _búa_, gaet, wadd,
  { {0xee3a0088,0xb17b0137,0xdb1a0331,0x00000000}},	//   _яна_, _tvåt, _cutá,
  { {0x69cf0025,0x672d021e,0x2d96005e,0x00000000}},	//   ícea, _saaj, _србс,
  { {0x88bc0080,0x77640137,0x68e842f6,0x00000000}},	//   jdět, _blix, radd,
  { {0x80370047,0x70e10053,0xdb1a00ea,0x00000000}},	//   אנטע_, _फ़्ल, _futá,
  { {0x628000eb,0x9b930032,0x66640062,0x00000000}},	//   _žmon, _النت, бърз,
  { {0x63bd1643,0x66640062,0x629d025f,0x00000000}},	//   _sisn, съюз, _ryso,
  { {0x672d0072,0x63bd3972,0x9c7c017c,0x00000000}},	//   _taaj, _pisn, _mečo,
  { {0x25660164,0x4c9b0063,0x2d760022,0x00000000}},	//   _rôle_, גבלו, dłem_,
  { {0x63bd1bbc,0x9175000d,0x2d760022,0x00000000}},	// [7bf0] _visn, агац, ełem_,
  { {0x20010397,0x61ed42f7,0x629d016b,0x00000000}},	//   tuhi_, rsal, _vyso,
  { {0x629d0045,0x61ed42f8,0x7ae9002b,0x00000000}},	//   _wyso, ssal, yaet,
  { {0x3ce502ab,0x2001003e,0x6b5542f9,0x00000000}},	//   _selv_, ruhi_, _lágr,
  { {0x51870086,0x2d760051,0x20010052,0x00000000}},	//   _бува, ałem_, suhi_,
  { {0x6e290fbf,0x23690150,0xdd94000d,0x00000000}},	//   _vseb, lhaj_, бачы,
  { {0x7ae942fa,0xe057005d,0x1fa742fb,0x00000000}},	//   taet, _حیات_, _браг,
  { {0x7ae9001f,0x23690089,0xb17b0137,0x00000000}},	//   uaet, nhaj_, _tvås,
  { {0xde67005a,0x7ae9001f,0x692542fc,0x00000000}},	//   _съвп, raet, ампа,
  { {0xc8b50121,0x91820013,0xdcf80078,0x00000000}},	//   исны, _iện_, dovė,
  { {0x7786018e,0x98a50259,0x6d412e83,0x00000000}},	//   илоз, рине, _inla,
  { {0xc7b9000d,0x27f80061,0x80480063,0x00000000}},	//   лёў_, árna_, אֲשֶ,
  { {0xb5fb00ea,0xc6030121,0x2d7642fd,0x00000000}},	//   zzáv, озяй, złem_,
  { {0x3ea20031,0x2d760022,0x395e00a5,0x00000000}},	//   _økte_, yłem_, ckts_,
  { {0x63630004,0xf9920063,0xb97a009a,0x00000000}},	//   _sõna, _ורג_, _בנסי,
  { {0xdb02008b,0xc3260141,0x2b4d00a8,0x00000000}},	//   _khoá, јмак, njec_,

  { {0x6d4142fe,0x96950085,0x00e61135,0x00000000}},	// [7c00] _onla, _грэш, ижан,
  { {0xb17b00c7,0xf6570063,0x2d760022,0x00000000}},	//   _svår, _כספי_, ałej_,
  { {0x04460076,0xaec62125,0x53a6005e,0x00000000}},	//   _тенн, абел, _ванб,
  { {0x6d4142ff,0x9c7c00a8,0x23690318,0x00000000}},	//   _anla, _sečo, chaj_,
  { {0xdce1005b,0xa5bb0051,0x2d760051,0x00000000}},	//   _aklı, dwój, słem_,
  { {0xa193000d,0x91e3286c,0x00000000,0x00000000}},	//   _маўч, _форе,   ,
  { {0x7b6600a0,0xed5700e1,0xbce9007e,0x00000000}},	//   итие, рој_, ارهٔ_,
  { {0x6d410d0f,0x443a006c,0x5c030085,0x00000000}},	//   _enla, _mrp_, цяша,
  { {0x4efb0063,0x32120072,0x1ab30121,0x00000000}},	//   _שהמו, ntyy_, объя,
  { {0x8c7a0076,0x645c0006,0x29180026,0x00000000}},	//   _ищет_, kyri, ýra_,
  { {0x7afd0006,0x3f86017d,0x6b5c4300,0x00000000}},	//   ųsta, onou_, _légi,
  { {0xdcf80006,0x3f860114,0x290a0022,0x00000000}},	//   tovė, nnou_, żba_,
  { {0x7bc80009,0x443a4301,0x3f864302,0x00000000}},	//   _hudu, _arp_, inou_,
  { {0x3f860080,0x645c4303,0xdb0b069f,0x00000000}},	//   hnou_, fyri, _sigø,
  { {0xdcfa003d,0x7bc8014f,0x3f860080,0x00000000}},	//   _aktī, _judu, knou_,
  { {0x3f860114,0x8c1b0063,0x58bb0063,0x00000000}},	//   jnou_, כולי, _במוצ,
  { {0x3f860114,0x443a4304,0x20c7019c,0x00000000}},	// [7c10] dnou_, _erp_, асег,
  { {0x7c3a00b9,0x9c7c0080,0xdb090025,0x00000000}},	//   _ortr, _pečl, imeá,
  { {0x2fc7001b,0x2d760022,0x765d1e3d,0x00000000}},	//   êng_, ałek_, lysy,
  { {0x3f86017d,0x9c7c00c2,0x27f1013d,0x00000000}},	//   gnou_, _večl, ázni_,
  { {0x9294000d,0x98a7001c,0x27780047,0x00000000}},	//   _маюц, _manā_, סעדש_,
  { {0x200e0268,0x645a00bd,0xb5fb00ea,0x00000000}},	//   àfic_, ätig, lzás,
  { {0xf1b20063,0x765d002b,0x3f860114,0x00000000}},	//   _מסך_, hysy, bnou_,
  { {0x765d00fe,0x7bc80277,0xdcb10013,0x00000000}},	//   kysy, _dudu, _xảy_,
  { {0x7c3a050c,0xdb230014,0x997d0085,0x00000000}},	//   _ertr, _þrív, етнi,
  { {0x6d414305,0x9dab0062,0x97d920fb,0x00000000}},	//   _unla, _ръба_, льму_,
  { {0x657c00fe,0x31580047,0x8bd90062,0x00000000}},	//   virh, ייזן_, _смес_,
  { {0x321200fe,0xdb02008b,0x6363004b,0x00000000}},	//   ytyy_, _thoá, _sõnn,
  { {0x98a501f7,0x657c00a4,0x6441061f,0x00000000}},	//   rklı_, tirh, ålin,
  { {0xceb2014e,0x69db2cff,0x6b5c4306,0x00000000}},	//   פים_, mpue, _régi,
  { {0x64a6000d,0x2d874307,0x657c0014,0x00000000}},	//   сава, inne_, rirh,
  { {0x321200fe,0xed59007d,0x765d002b,0x00000000}},	//   ttyy_, _duži_, bysy,
  { {0x52aa05fb,0x443a0150,0x3f860114,0x00000000}},	// [7c20] увам_, _wrp_, vnou_,
  { {0x636a0026,0x321200fe,0x6b5c00ea,0x00000000}},	//   _sýnd, rtyy_, _végi,
  { {0x321200fe,0xe0d50086,0x3f86004a,0x00000000}},	//   styy_, юють, tnou_,
  { {0x66060072,0x672604aa,0x2d874308,0x00000000}},	//   oukk, nekj, enne_,
  { {0xf2d300b5,0xb148006a,0x7bc84309,0x00000000}},	//   _מער_, _پیام_, _sudu,
  { {0x63b60026,0x3f86430a,0x63a40fef,0x00000000}},	//   lmyn, snou_, llin,
  { {0x3d090053,0x672600d1,0x38c8005d,0x00000000}},	//   _सारे_, kekj, یادی_,
  { {0x2d870019,0xd9f80076,0xbf16007e,0x00000000}},	//   anne_, аниц_, _دورب,
  { {0x6e3b430b,0x7bc80089,0x6606430c,0x00000000}},	//   _grub, _wudu, jukk,
  { {0x7bc8430d,0xb5fb00ea,0x63b6002b,0x00000000}},	//   _tudu, zzás, hmyn,
  { {0x319b00b5,0xcb0a006a,0x63b60026,0x00000000}},	//   רבינ, _ميان_, kmyn,
  { {0xd6db0121,0x63a4430e,0x31af0058,0x00000000}},	//   ыто_, jlin, müze_,
  { {0x65a0004d,0xdb00013d,0xb5fb013d,0x00000000}},	//   höhu, jlmé, ezár,
  { {0xb69b003b,0xa4d40054,0x63a4430f,0x00000000}},	//   ngâi, зорі, elin,
  { {0x63a40ba3,0x31af0058,0x8bf80063,0x00000000}},	//   flin, nüze_, יִּפ,
  { {0x63b60026,0x66064310,0x62d9000d,0x00000000}},	//   gmyn, bukk, рмаў_,
  { {0xe8000053,0x9c7c007d,0x4155000d,0x00000000}},	// [7c30] लंका_, _bečk, овас,
  { {0x9c7c0198,0xf1c2001c,0xf77f2d42,0x00000000}},	//   _večj, jošā_, liç_,
  { {0x63a44311,0x9c7c02f7,0x628a004d,0x00000000}},	//   blin, _dečk, ßfor,
  { {0xceeb006a,0x645a024a,0x63a4055b,0x00000000}},	//   اران_, ätie, clin,
  { {0x67c80080,0x6440008f,0xdb230046,0x00000000}},	//   _ději, āmie, írík,
  { {0xabd500e1,0xdb09017d,0xdd94000d,0x00000000}},	//   оциј, omeç, пачы,
  { {0x7afd0460,0x44210089,0x1b494312,0x00000000}},	//   ósto, _jph_, изки_,
  { {0x88bc0080,0x2d9e4313,0x44214314,0x00000000}},	//   vděp, _ekte_, _mph_,
  { {0x7afd0006,0xb5fb00ea,0x4a450454,0x00000000}},	//   ųsto, zzár, інов,
  { {0x69db006d,0x63a40c1a,0x8f000054,0x00000000}},	//   rpue, zlin, дiї_,
  { {0x69db02dd,0xfd100021,0x63a403b1,0x00000000}},	//   spue, _سجل_, ylin,
  { {0x65a000bd,0xae0d0053,0x66064315,0x00000000}},	//   höht, _समान_, tukk,
  { {0xf3f1001b,0x3f9f0009,0x67264316,0x00000000}},	//   ận_, _mkuu_, rekj,
  { {0x63a44317,0xa50a0001,0xdb1f00d1,0x00000000}},	//   wlin, јева_, åvær,
  { {0x66061894,0x63a41dc0,0xf1bf0066,0x00000000}},	//   sukk, tlin, _fráz_,
  { {0x03670076,0x69cb00bd,0x69c30221,0x00000000}},	//   оиск_, _kuge, _hine,
  { {0x7aeb000f,0x69cb4318,0x63b608e9,0x00000000}},	// [7c40] _megt, _juge, rmyn,
  { {0x8506006a,0x6b9b0034,0x63a44319,0x00000000}},	//   _بودن, houg, slin,
  { {0x69cb0004,0x656e0027,0x9c7c00c3,0x00000000}},	//   _luge, mhbh, _večk,
  { {0x80da0161,0xee3a07f6,0x69c3177d,0x00000000}},	//   _प्रे, ине_, _line,
  { {0x6b890468,0x7988002b,0xf1c2008f,0x00000000}},	//   dneg, yndw, tošā_,
  { {0x69c30969,0xf3f1008b,0x463b0047,0x00000000}},	//   _nine, ợt_, יענע,
  { {0x69cb00bd,0x7bc200e5,0xddce0022,0x00000000}},	//   _auge, _piou, ódła,
  { {0x69cb0529,0xba540259,0x0b8a0095,0x00000000}},	//   _buge, звиј, јски_,
  { {0x1d0a0001,0x69c3431a,0x69cb003b,0x00000000}},	//   _вези_, _bine, _cuge,
  { {0x6b5c0164,0xad66007e,0xdc3e01da,0x00000000}},	//   _régu, _باره, líče,
  { {0x69d9006f,0x6b9b431b,0x6b89431c,0x00000000}},	//   _etwe, boug, bneg,
  { {0x69c3431d,0x2d9c027c,0x6b5c0e1a,0x00000000}},	//   _eine, love_, _pégu,
  { {0x3a3d0185,0xf77f005b,0x2918004b,0x00000000}},	//   _grwp_, riç_, õras_,
  { {0x2d9c1ce6,0x69c3431e,0x80da0053,0x00000000}},	//   nove_, _gine, _प्ले,
  { {0x69cb0199,0xe9670095,0xa7fc005b,0x00000000}},	//   _zuge, _фајл_, azır,
  { {0x56950bb3,0x2d9c01b3,0x386300b9,0x00000000}},	//   _найт, hove_, øjre_,
  { {0x2d9c1181,0xc1eb0076,0x69c30058,0x00000000}},	// [7c50] kove_, рьбе_, _yine,
  { {0x290c0627,0x69c300cd,0x98be0006,0x00000000}},	//   ngda_, _xine, nktį_,
  { {0x44210150,0x2d9c04c9,0x6b89002b,0x00000000}},	//   _uph_, dove_, yneg,
  { {0x6b5c00ea,0xdefb000d,0x9f550085,0x00000000}},	//   _mégs, рыж_, явеч,
  { {0x7bda02f6,0x6b890198,0x7aeb00e8,0x00000000}},	//   _attu, vneg, _regt,
  { {0x69cb10c4,0x6b890051,0x2d9c01b3,0x00000000}},	//   _ruge, wneg, gove_,
  { {0x6b89431f,0x69cb3e28,0x6b9b330e,0x00000000}},	//   tneg, _suge, toug,
  { {0x69c34320,0x69cb4321,0xf1af0053,0x00000000}},	//   _sine, _puge, _जीतन,
  { {0x6b9b4322,0xdb2100ea,0x6b894323,0x00000000}},	//   roug, _átír, rneg,
  { {0x290c00c7,0x48050121,0xf9910044,0x00000000}},	//   ggda_, ппов, عبة_,
  { {0xc7a60459,0x69c3406a,0xe73a0174,0x00000000}},	//   зинк, _vine, бен_,
  { {0x69cb1255,0xfb380021,0x69c34324,0x00000000}},	//   _tuge, _وأنت_, _wine,
  { {0x9c7c4325,0x69c34326,0x656e0139,0x00000000}},	//   _reči, _tine, thbh,
  { {0x2eed0104,0x89da009a,0x33d6012c,0x00000000}},	//   _leef_, _החסי, зіат,
  { {0x80aa0053,0x443e2194,0x98a212ab,0x00000000}},	//   _करें, ít_, _пише,
  { {0x57fa014e,0x2eed006f,0xd7fa0063,0x00000000}},	//   _הלקו, _neef_, _ההקל,
  { {0x9c7c0198,0x020608a6,0x32094327,0x00000000}},	// [7c60] _veči, язан, guay_,
  { {0xdce300eb,0x3cf70053,0xe1f70500,0x00000000}},	//   minė, ीलों_, ягу_,
  { {0xdce30006,0xf9920063,0x2d9c007d,0x00000000}},	//   linė, ערב_, vove_,
  { {0x0dca4328,0xa2630013,0x9c7c00a8,0x00000000}},	//   буки_, _khổ, _kečv,
  { {0xdce30006,0x67360150,0x290c00d1,0x00000000}},	//   ninė, _mayj, ygda_,
  { {0x2d9c0290,0x6b5c0003,0x237f0061,0x00000000}},	//   uove_, _négr, ďuje_,
  { {0xcb980021,0x2d9c4329,0x1d190085,0x00000000}},	//   ينتش_, rove_, ююць_,
  { {0x2eed02b0,0x67c80080,0xdce30006,0x00000000}},	//   _geef_, _mějt, kinė,
  { {0x0e660088,0x2d9c08ed,0x61f6432a,0x00000000}},	//   _экан, pove_, nsyl,
  { {0x49731485,0xdce30006,0xa9780086,0x00000000}},	//   ельс, dinė, ійну_,
  { {0x6b5c0003,0x6d481839,0xa3ac0042,0x00000000}},	//   _dégr, _inda, गता_,
  { {0x290201f7,0xf3f1008b,0xdce30006,0x00000000}},	//   şka_, ậm_, finė,
  { {0xda340076,0xdce30006,0x7981069f,0x00000000}},	//   _целы, ginė, bilw,
  { {0xe5c40076,0x6d5a00fe,0xca330001,0x00000000}},	//   ессо, _jota, _чешћ,
  { {0x6d5a432b,0xb33b0058,0x8937009a,0x00000000}},	//   _mota, _akça, _מרגע_,
  { {0x637101e3,0xdce30006,0x657e1f7d,0x00000000}},	//   _mång, binė, _emph,
  { {0x637100c7,0x6d5a0019,0xdce30006,0x00000000}},	// [7c70] _lång, _oota, cinė,
  { {0x63630019,0x6d5a432c,0x3eb9017c,0x00000000}},	//   _mõni, _nota, _ústi_,
  { {0x63710137,0x9c7c432d,0x7feb04a0,0x00000000}},	//   _nång, _keču, صراف_,
  { {0x6d48432e,0x5f940094,0xfe710043,0x00000000}},	//   _anda, нихт, پگر_,
  { {0x6d5a386b,0x433a009a,0x333a009d,0x00000000}},	//   _bota, _וערב, _ותרמ,
  { {0x4d640086,0x6d5a362f,0xdca50fec,0x00000000}},	//   нків, _cota, мали,
  { {0x6d5a432f,0x6b5c0003,0xdce30078,0x00000000}},	//   _dota, _régr, zinė,
  { {0x8d77007e,0x6d484330,0xa2b40053,0x00000000}},	//   _کارا, _enda, _आरम्,
  { {0x6d5a2688,0x7f494331,0x00000000,0x00000000}},	//   _fota, _ineq,   ,
  { {0x63713a03,0x115a00b5,0xdce30006,0x00000000}},	//   _fång, ַדרע, vinė,
  { {0x637100c7,0x6b5c000f,0x7c670021,0x00000000}},	//   _gång, _végr, _عائل,
  { {0xdce300eb,0x61f6001f,0xfe6703eb,0x00000000}},	//   tinė, ysyl, ند_,
  { {0x27e0017f,0x63710137,0x6d480014,0x00000000}},	//   _čine_, _månd, _ynda,
  { {0xdce30006,0xaa56005e,0x18691a08,0x00000000}},	//   rinė, _циљу_, _мали_,
  { {0xdce3091b,0x64a34332,0x65c30062,0x00000000}},	//   sinė, вара, тбра,
  { {0xdce30006,0x7afd0014,0x6d470046,0x00000000}},	//   pinė, ósth, _ójaf,
  { {0x3aba00b5,0x256f0019,0x6b5c013d,0x00000000}},	// [7c80] ַמענ, _süle_, _mégp,
  { {0x7e620035,0xf3f1008b,0x61f60731,0x00000000}},	//   vyop, ợp_, rsyl,
  { {0x6d5a4333,0x443c00ea,0x68fc017d,0x00000000}},	//   _rota, _év_, órdi,
  { {0x1e860076,0x6d5a3333,0xa2d6005d,0x00000000}},	//   млем, _sota, _زيست,
  { {0x637100c7,0x87ad0047,0x6d5a04b9,0x00000000}},	//   _sång, זשאַ, _pota,
  { {0x9c460086,0x66060072,0x00000000,0x00000000}},	//   дхил, irkk,   ,
  { {0xa2d50161,0x6d5a0e57,0xa2a20042,0x00000000}},	//   युक्, _vota, _कुत्,
  { {0x8c43005e,0x5a3405ef,0xd00f0593,0x00000000}},	//   ђење, енит, _خلف_,
  { {0x6d5a138a,0xedd30044,0x00000000,0x00000000}},	//   _tota, _ليقد,   ,
  { {0x6d4823f3,0x588627b8,0x7c2a05ac,0x00000000}},	//   _unda, дыма, _мозг_,
  { {0x660600fe,0x636a0014,0x7d1e004e,0x00000000}},	//   erkk, _nýno, õpsu,
  { {0x95cb0079,0x09e60086,0x63630019,0x00000000}},	//   жува_, _жодн, _tõni,
  { {0x9f650164,0x44330331,0xa5bb0022,0x00000000}},	//   étés_, _ssx_, dwór,
  { {0x637102ab,0x2245011b,0xe8944334,0x00000000}},	//   _måne, _člk_, _паль,
  { {0x660600fe,0x44250110,0x637106f1,0x00000000}},	//   arkk, ïl_, _låne,
  { {0x57fb0063,0x4425005f,0xe00d0082,0x00000000}},	//   _ולהו, įl_, ांसद_,
  { {0x7afd2234,0xd7f8003b,0xe1f000f2,0x00000000}},	// [7c90] ósti, lsă_, لسل_,
  { {0xf652009a,0xb06b0044,0x44a70044,0x00000000}},	//   _עצי_, يصال_, _يحدّ,
  { {0xd7f8000c,0x7afd0078,0x7f5b00be,0x00000000}},	//   nsă_, ųsti, _pouq,
  { {0x20df0161,0xb0df0053,0xd347005d,0x00000000}},	//   _प्रध, _प्रग, _تیره_,
  { {0x236900c2,0x5187012c,0xc2c5009b,0x00000000}},	//   mkaj_, _жува, _سيسي,
  { {0xee380304,0x7c650044,0x6ce7012c,0x00000000}},	//   ьні_, فاعل, фіде,
  { {0xdca20001,0x7c84005e,0x7cd601f3,0x00000000}},	//   лаши, куће, رويز_,
  { {0xdcf8003b,0x7f4900e5,0x66060072,0x00000000}},	//   tivă, _uneq, yrkk,
  { {0x9915000d,0x4b220121,0x9c7c004c,0x00000000}},	//   ньні, умыв, _sečt,
  { {0xa3b60161,0x7d79009b,0xa1c9012c,0x00000000}},	//   _चीन_, _عمار_, оцiа,
  { {0xe73a0ae8,0x29190022,0x6f0f013d,0x00000000}},	//   пен_, ęsa_, _öccs,
  { {0xf0920a7a,0x9c7c00c2,0x291e4335,0x00000000}},	//   רנט_, _večt, afta_,
  { {0xd7f8000c,0x66080051,0x8cc70053,0x00000000}},	//   asă_, ądko, ाशको,
  { {0x236900c3,0x63630019,0x25660066,0x00000000}},	//   ekaj_, _mõnu, _kôli_,
  { {0xa5bb0051,0x7afd0022,0xf89b005d,0x00000000}},	//   twór, óstw, _بخشش_,
  { {0x636a027d,0xdce3001c,0x02c614db,0x00000000}},	//   _výno, finī, ейбо,
  { {0x3f8e0014,0xe297050f,0x249f0075,0x00000000}},	// [7ca0] éfum_, еат_, ğuma_,
  { {0x236900c2,0x6fd40053,0x4096012c,0x00000000}},	//   akaj_, _बंदू, нрет,
  { {0xdce3001c,0xc483007f,0xc0a914d7,0x00000000}},	//   ainī, _блэк, وامل_,
  { {0x44444336,0x3cfe4337,0x7644008d,0x00000000}},	//   _ir_, _sdtv_, _kriy,
  { {0xb17b0666,0x44444338,0x2492008f,0x00000000}},	//   _ståe, _hr_, šamā_,
  { {0x3f8f0035,0xb8820080,0x61e44339,0x00000000}},	//   angu_, _říms, mpil,
  { {0x61e20025,0x67240f74,0x61e4433a,0x00000000}},	//   íolf, _obij, lpil,
  { {0x444404bf,0x7644433b,0x61e4433c,0x00000000}},	//   _mr_, _oriy, opil,
  { {0x6d4b0025,0x444401db,0x6d530014,0x00000000}},	//   álaí, _lr_, ýjað,
  { {0x44440cfc,0x61e400a4,0x3f86433d,0x00000000}},	//   _or_, ipil, liou_,
  { {0xe8940088,0xa7fc005b,0x645a00fe,0x00000000}},	//   тань, ayın, ätil,
  { {0xd7f8000c,0x93c7008b,0xa5bb00be,0x00000000}},	//   rsă_, _chặ, otóg,
  { {0x09e3005e,0x4444433e,0x6b82008e,0x00000000}},	//   _бочн, _ar_, _imog,
  { {0xd7f8000c,0x6d580137,0x4444433f,0x00000000}},	//   psă_, njva, _br_,
  { {0x7793007e,0x7bdc0003,0x2369007d,0x00000000}},	//   _میدا, _érud, tkaj_,
  { {0x6443006d,0x444418fe,0x23690384,0x00000000}},	//   _ánim, _dr_, ukaj_,
  { {0x69ca000f,0x61e4002c,0x764418ab,0x00000000}},	// [7cb0] _kife, gpil, _griy,
  { {0x7c284340,0x44444341,0x23694342,0x00000000}},	//   _opdr, _fr_, skaj_,
  { {0x6b8206bb,0x63630019,0x69ca05b3,0x00000000}},	//   _omog, _sõnu, _mife,
  { {0x661d4343,0x30a40817,0x69ca1568,0x00000000}},	//   otsk, урув, _life,
  { {0xf3640088,0x63ad04c5,0x7c28001c,0x00000000}},	//   _стэн, mlan, _apdr,
  { {0x44440c70,0x69ca0185,0xdb000164,0x00000000}},	//   _yr_, _nife, lomè,
  { {0x98a70080,0x63ad4344,0xeb994345,0x00000000}},	//   _daně_, olan, мик_,
  { {0x661d02fb,0x3f863c4b,0x0b450856,0x00000000}},	//   ktsk, ciou_, тнин,
  { {0x63ad4346,0x27e00734,0x6e940816,0x00000000}},	//   ilan, _čina_, _биту,
  { {0x7c2c006d,0x63ad4347,0x69ca0ff8,0x00000000}},	//   ñorí, hlan, _cife,
  { {0x2d871fc9,0x66e615d4,0x61e4003d,0x00000000}},	//   mine_, кона, zpil,
  { {0x61e400fe,0x69ca2087,0x76442108,0x00000000}},	//   ypil, _eife, _priy,
  { {0x2d870027,0x63ad0465,0x7afd0026,0x00000000}},	//   oine_, dlan, óstu,
  { {0x44444348,0x6b824349,0x7bcb2744,0x00000000}},	//   _pr_, _zmog, _higu,
  { {0x661d4149,0x61fd2330,0x7bcb0035,0x00000000}},	//   atsk, _avsl, _kigu,
  { {0x63ad434a,0x6724074f,0x7ae91ea3,0x00000000}},	//   glan, _ubij, nbet,
  { {0x3f860016,0x644500bd,0x7bcb177e,0x00000000}},	// [7cc0] viou_, _erhi, _migu,
  { {0x4444434b,0x7ae9005b,0x61e4070e,0x00000000}},	//   _tr_, hbet, rpil,
  { {0x2d87434c,0xe3ba0121,0x644100df,0x00000000}},	//   dine_, _обо_, ålit,
  { {0x63ad000c,0x61e40bcf,0x2d87434d,0x00000000}},	//   clan, ppil, eine_,
  { {0x7ae9010a,0x63a4434e,0x3c3c434f,0x00000000}},	//   dbet, moin, kává_,
  { {0x7bcb0bbd,0x2d874350,0x4c940121,0x00000000}},	//   _aigu, gine_, лилс,
  { {0x69ca02f6,0x3c3c0080,0x2fda007e,0x00000000}},	//   _rife, dává_, _آورد_,
  { {0xdb1a0268,0x63a40f3b,0x7ae92cdc,0x00000000}},	//   _autò, noin, gbet,
  { {0x7bcb0397,0x2d874351,0xb5fb013d,0x00000000}},	//   _digu, bine_, száz,
  { {0x637102eb,0x661d00c2,0x7bcb0014,0x00000000}},	//   _måna, vtsk, _eigu,
  { {0x63a400fe,0x7bcb4352,0x63ad4353,0x00000000}},	//   koin, _figu, ylan,
  { {0x673d0031,0x63a404bc,0x63ad1233,0x00000000}},	//   udsj, join, xlan,
  { {0x63ad2b4c,0x661d4354,0x673d03d4,0x00000000}},	//   vlan, utsk, rdsj,
  { {0x660f4355,0x58d3268f,0x661d4356,0x00000000}},	//   ruck, _кошт, rtsk,
  { {0x7bc04357,0x672f0051,0x645801a8,0x00000000}},	//   ommu, pecj, _àvil,
  { {0x63a44358,0x63ad4359,0x320900e5,0x00000000}},	//   goin, ulan, tray_,
  { {0xa7fc005b,0xc1b9435a,0x2d87005b,0x00000000}},	// [7cd0] zyıl, елах_, yine_,
  { {0xdb003465,0x3f840019,0xdcee0080,0x00000000}},	//   llmä, _ammu_, ěděl,
  { {0x7ae90779,0x63ad435b,0x2d871868,0x00000000}},	//   ybet, plan, vine_,
  { {0xa5bb017d,0x8f140086,0x6e990a29,0x00000000}},	//   stód, ифіч, нвер_,
  { {0x7bcb435c,0xfe7003eb,0xaf040086,0x00000000}},	//   _rigu, يده_, рпіл,
  { {0x2cac0185,0x7ae9001f,0x2d870139,0x00000000}},	//   _bydd_, wbet, uine_,
  { {0x3c3c0080,0x7ae9435d,0x2d87435e,0x00000000}},	//   vává_, tbet, rine_,
  { {0x2cac0185,0x2d872c6d,0x9c7c00c2,0x00000000}},	//   _dydd_, sine_, _večp,
  { {0x2d8722f1,0x7ae9435f,0x7bcb4360,0x00000000}},	//   pine_, rbet, _vigu,
  { {0x2cac0185,0x7ae6005b,0xa7fc005b,0x00000000}},	//   _fydd_, ıkta, ayım,
  { {0x63a40035,0x7afd0014,0xfb15002a,0x00000000}},	//   yoin, ósts, _مواج,
  { {0x7bcb4361,0x3c3c10c9,0xab841fc6,0x00000000}},	//   _uigu, sává_, _кучк,
  { {0x80aa016a,0x7988002c,0x63a44362,0x00000000}},	//   _जुने, bidw, voin,
  { {0x395800c7,0x2b9a008f,0xd348007e,0x00000000}},	//   örst_, rīce_, چیده_,
  { {0xf99a00b5,0x63a44363,0xe1ff017d,0x00000000}},	//   _אױסל, toin, _avó_,
  { {0x6b893c80,0x69c14364,0xdb00006c,0x00000000}},	//   nieg, lmle, tomé,
  { {0x637803d9,0x256f0004,0xc7a90242,0x00000000}},	// [7ce0] _líng, _küll_, _جدول_,
  { {0x63a44365,0xdb004366,0xdce3004c,0x00000000}},	//   soin, romé, rhně,
  { {0x6b890045,0xf3f1001b,0x4f0a042c,0x00000000}},	//   kieg, ật_, енен_,
  { {0xdfcf00b3,0x5f760021,0x20073887,0x00000000}},	//   سيه_, دائر, ánia_,
  { {0x2cac0185,0xef21003d,0x6b894367,0x00000000}},	//   _sydd_, daļā_, dieg,
  { {0x6da322c4,0xa7fc0058,0x443a00a5,0x00000000}},	//   бича, azıy, _ksp_,
  { {0x251b0063,0x27e000c2,0x443a4368,0x00000000}},	//   תוצא, _čino_, _jsp_,
  { {0x40930032,0x6b890051,0xe4570047,0x00000000}},	//   _الفر, gieg, טיצט_,
  { {0xb9980001,0x298a032d,0x443f008d,0x00000000}},	//   квих_, есно_, ̉u_,
  { {0x7afd1358,0x99d30044,0xaac00042,0x00000000}},	//   óstr, حتيا, शेषक,
  { {0xa3c40161,0x6b890051,0x98c60121,0x00000000}},	//   एगा_, bieg, ысил,
  { {0x68e4005b,0x7c3a4369,0xa3d80053,0x00000000}},	//   _şidd, _istr, ादन_,
  { {0x7afd0014,0x443a17b4,0xd90f005d,0x00000000}},	//   ðste, _asp_, _کیپ_,
  { {0xda7b0063,0x7c3a01e1,0x443a436a,0x00000000}},	//   _אנדר, _kstr, _bsp_,
  { {0xad620013,0x68fa0a52,0xd6db0062,0x00000000}},	//   _đựn, matd, _птп_,
  { {0x1dd40053,0xf1a40086,0x75d5007e,0x00000000}},	//   ददात, ґрун, _پيدا,
  { {0x50f505f1,0x32550074,0x443a2283,0x00000000}},	// [7cf0] изат, швар, _esp_,
  { {0x2fcd00bd,0xa5bb436b,0x256f004b,0x00000000}},	//   _sieg_, stób, _külm_,
  { {0xc035018e,0x7c3a18f5,0x10480062,0x00000000}},	//   рнеј, _nstr, ляци_,
  { {0xdce30078,0xe4480044,0x7ed4005d,0x00000000}},	//   tinį, _إلَى_, مزها,
  { {0x7c3a2ba5,0x6b89001c,0x69c1002b,0x00000000}},	//   _astr, vieg, ymle,
  { {0xe0d40001,0x3da90062,0x2fcd00ca,0x00000000}},	//   _горњ, ъкло_, _wieg_,
  { {0x636a007a,0x6b89436c,0x6db90066,0x00000000}},	//   _sýni, tieg, _kňaz,
  { {0x98aa0080,0x290a00ea,0x7c3a436d,0x00000000}},	//   žbě_, óban_, _dstr,
  { {0x63710147,0xc95501e8,0x3f9c0003,0x00000000}},	//   _låno, атны, évue_,
  { {0x636a0024,0x6b89436e,0x9179008d,0x00000000}},	//   _výni, sieg, _bẩn_,
  { {0x6b89436f,0x7e6b0137,0x91790013,0x00000000}},	//   pieg, lygp, _cẩn_,
  { {0xc7a60086,0x366a0001,0x290b095a,0x00000000}},	//   римк, вамо_, şca_,
  { {0x7afb024a,0x9f5c013d,0x443a4370,0x00000000}},	//   maut, évé_, _ssp_,
  { {0xb17b0137,0x7afb4371,0x63780025,0x00000000}},	//   _stån, laut, _míne,
  { {0x6378048e,0x69db4372,0x5497000d,0x00000000}},	//   _líne, lque, авёў_,
  { {0x7afb4373,0x69db01a8,0xb89a009a,0x00000000}},	//   naut, oque, _שבקש,
  { {0x69db41b0,0x2b9a008f,0x443a0022,0x00000000}},	// [7d00] nque, nīca_, _wsp_,
  { {0x69db2a7f,0x63780e57,0xc5fb07e9,0x00000000}},	//   ique, _sínd, _שפיט,
  { {0x7afb2418,0x6b5c00ea,0xc0590086,0x00000000}},	//   kaut, _végz, лії_,
  { {0xf8b20063,0x888c0047,0x7afb2c3c,0x00000000}},	//   חשב_, עראַ, jaut,
  { {0x44380185,0x7afb00cc,0x776401a8,0x00000000}},	//   lwr_, daut, _moix,
  { {0x100a0021,0xcd270054,0x7c3a4374,0x00000000}},	//   _لترى_, ижче_, _pstr,
  { {0x7afb0009,0x998d0051,0x4438001f,0x00000000}},	//   faut, steś_, nwr_,
  { {0xe4570047,0x7afb30ba,0x4438002b,0x00000000}},	//   שיקט_, gaut, iwr_,
  { {0x7c3a0051,0x4438001f,0x3f6706b6,0x00000000}},	//   _wstr, hwr_, _тито_,
  { {0xd90e006a,0x9f5a0290,0xf9920021,0x00000000}},	//   ذیب_, cupò_, تبع_,
  { {0x7c3a1c6b,0x7afb4375,0x776401a8,0x00000000}},	//   _ustr, baut, _boix,
  { {0x44380185,0x61e6017f,0x6ba5003b,0x00000000}},	//   dwr_, _otkl, ăugâ,
  { {0xdb004376,0x69db4377,0x68fa00a4,0x00000000}},	//   nomí, cque, patd,
  { {0x1a7b0063,0x4438001f,0x61e90058,0x00000000}},	//   _שְׁמ, fwr_, _çeli,
  { {0x61e6001c,0x99990024,0x4438001f,0x00000000}},	//   _atkl, ísť_, gwr_,
  { {0x68f80031,0x53980086,0x88770063,0x00000000}},	//   _hevd, ався_, _כתוב_,
  { {0x4438001f,0x3d170042,0xdb1b004d,0x00000000}},	// [7d10] awr_, _नाले_, hluß,
  { {0x9f58051e,0x2fd800bd,0x7afb00ea,0x00000000}},	//   _avrà_, _burg_, zaut,
  { {0x7afb0003,0x7bde0460,0x69db4378,0x00000000}},	//   yaut, ípul, zque,
  { {0x201c00cd,0x776400cd,0x75351873,0x00000000}},	//   àvia_, _xoix, lezz,
  { {0x69db2986,0x7afb1dc1,0x03560aeb,0x00000000}},	//   xque, vaut, _הירש_,
  { {0x75350290,0x290a436b,0x06380041,0x00000000}},	//   nezz, óbal_, ינדט_,
  { {0x6e223000,0x7afb136e,0x92a90022,0x00000000}},	//   atob, taut, bołó,
  { {0x7535051e,0xf1db0053,0x6e3b0b09,0x00000000}},	//   hezz, _बढान, _tsub,
  { {0x7535000f,0x8e850021,0x1e950047,0x00000000}},	//   kezz, _الذه, _הכּל_,
  { {0x7afb024a,0x69db4379,0x77640164,0x00000000}},	//   saut, rque, _soix,
  { {0x6d410228,0x69db437a,0x7ae2001f,0x00000000}},	//   _iala, sque, _ffot,
  { {0x6d41437b,0x20010035,0x6f19002b,0x00000000}},	//   _hala, ishi_, ngwc,
  { {0x6d41035d,0x254b0006,0x68f800c2,0x00000000}},	//   _kala, kėlė_, _fevd,
  { {0x6d410397,0xf1db0053,0xdcb10013,0x00000000}},	//   _jala, _बढ़न, _kỷ_,
  { {0xf3f1001b,0x6d41437c,0x69d9437d,0x00000000}},	//   ập_, _mala, _huwe,
  { {0x6d4103d5,0x44380185,0x69d9113e,0x00000000}},	//   _lala, rwr_, _kuwe,
  { {0xdb00017d,0x4438002b,0x69d913de,0x00000000}},	// [7d20] lomã, swr_, _juwe,
  { {0x865b014e,0x69d90035,0x6d41437e,0x00000000}},	//   _עדיי, _muwe, _nala,
  { {0xa2b40053,0x636a0014,0x80a6007e,0x00000000}},	//   _आरक्, _sýnu, حمان,
  { {0x6d41002c,0x660421ad,0xdb00437f,0x00000000}},	//   _aala, _kvik, tomí,
  { {0x471b00b5,0x69d900e8,0x61e6380f,0x00000000}},	//   רונג, _nuwe, _utkl,
  { {0x2fd80019,0xdb004380,0x6d414381,0x00000000}},	//   _turg_, romí, _cala,
  { {0x6d410cec,0x6fb6007e,0xdc2a00b3,0x00000000}},	//   _dala, _همسا, استه_,
  { {0x5f96043b,0xd0070138,0x6d410025,0x00000000}},	//   _الرئ, _ћете_, _eala,
  { {0x7afd007a,0x6d414382,0x386c001f,0x00000000}},	//   ðsta, _fala, wydr_,
  { {0xa3d80161,0xdb1a017d,0xad650021,0x00000000}},	//   ादा_, _autô, _واله,
  { {0x2c0b007e,0xdb00003b,0x75353b28,0x00000000}},	//   _معنی_, româ, vezz,
  { {0x80370047,0x6d414383,0xbfb60013,0x00000000}},	//   זנטע_, _zala, _điềm_,
  { {0x75352929,0x7bda0035,0x6d410058,0x00000000}},	//   tezz, _hutu, _yala,
  { {0x7bda4384,0xdceb007d,0x6604005f,0x00000000}},	//   _kutu, čići, _dvik,
  { {0x7aed0529,0x75354385,0x7bda0019,0x00000000}},	//   _întâ, rezz, _jutu,
  { {0x657c00bd,0xa5bb0460,0x7bda07b9,0x00000000}},	//   ahrh, ctón, _mutu,
  { {0x60f90121,0x98a50078,0x92590002,0x00000000}},	// [7d30] иная_, delę_, шаат_,
  { {0x7bda0016,0x2007027c,0xdb090139,0x00000000}},	//   _outu, šnim_, ileá,
  { {0x610b003d,0x20014386,0x99dd0066,0x00000000}},	//   vēlē, ushi_, yvňo,
  { {0x6378048e,0x764d0a9f,0x6d412dc7,0x00000000}},	//   _vínc, _kray, _sala,
  { {0x8f340088,0x7bda4387,0x2efd002b,0x00000000}},	//   яецц, _autu, rawf_,
  { {0x7bda00f3,0x6f19001f,0xdd9b0076,0x00000000}},	//   _butu, sgwc, ыше_,
  { {0x6d4312f5,0x61ed3b61,0x6d414388,0x00000000}},	//   rdna, lpal, _vala,
  { {0x69d900bb,0x6d4138c4,0x99e50076,0x00000000}},	//   _puwe, _wala, ожид,
  { {0x2ca90051,0x6d414389,0xa2a20053,0x00000000}},	//   ład_, _tala, _कुञ्,
  { {0x672d02dd,0x6378007a,0xdcb1008b,0x00000000}},	//   _abaj, _mína, _tỷ_,
  { {0x764d01f7,0x6604438a,0x63780014,0x00000000}},	//   _aray, _svik, _lína,
  { {0x22490122,0x69d90035,0xa5bb006d,0x00000000}},	//   kvak_, _tuwe, utón,
  { {0xe6170363,0xceb20063,0x99d70593,0x00000000}},	//   одя_, ֥ים_, _اتصا,
  { {0x1a9a0047,0xa5bb0046,0x7bda0075,0x00000000}},	//   _דינע, stón, _yutu,
  { {0x61ed438b,0xdb0011ba,0x9346438c,0x00000000}},	//   epal, lomá, онве,
  { {0x3f8f017f,0x224900ac,0x764d1276,0x00000000}},	//   jigu_, fvak_, _fray,
  { {0x61ed00bb,0x27e0017f,0x06830062,0x00000000}},	// [7d40] gpal, _čini_, _огън,
  { {0x6f09438d,0x3f8f143b,0xa1c3013c,0x00000000}},	//   _adec, eigu_, дбуд,
  { {0x61ed438e,0x397a0047,0x98a523a8,0x00000000}},	//   apal, סטענ, telę_,
  { {0x61ed12be,0x7bda438f,0xdce100a8,0x00000000}},	//   bpal, _rutu, _dolč,
  { {0x6f090185,0x63a1013d,0x3ea00058,0x00000000}},	//   _ddec, élne, çit_,
  { {0x6f09005b,0x63a903f5,0x98ac000c,0x00000000}},	//   _edec, čene, nedă_,
  { {0xdb000994,0xd00714cf,0x3f8f4390,0x00000000}},	//   tomà, _мере_, bigu_,
  { {0x63b60185,0xdb0939e2,0xc4d3089e,0x00000000}},	//   nlyn, tleá, וגו_,
  { {0xdb0000cd,0x63b6002b,0xed5a0131,0x00000000}},	//   romà, ilyn, _коа_,
  { {0x6f090051,0x7bda4391,0x5d780063,0x00000000}},	//   _zdec, _tutu, _פָּנ,
  { {0x63b600ac,0xdb090139,0x7bda0072,0x00000000}},	//   klyn, sleá, _uutu,
  { {0x764d0034,0xa5bb0460,0x478b4392,0x00000000}},	//   _pray, atól, рсом_,
  { {0x61e20025,0x25740137,0xe738000d,0x00000000}},	//   íoll, _täll_, цеў_,
  { {0x63b6002b,0x764d006c,0x98ac00dd,0x00000000}},	//   elyn, _vray, gedă_,
  { {0x63780026,0x938b0002,0x4615007e,0x00000000}},	//   _sína, асаа_, _کوخر,
  { {0xe5170161,0x22490122,0x764d4393,0x00000000}},	//   _ताकि_, tvak_, _tray,
  { {0xc175005a,0xbb3b0047,0xa7fc0058,0x00000000}},	// [7d50] плащ, סעמי, ayıt,
  { {0xa3d8016a,0xdb0900ac,0x3d040053,0x00000000}},	//   ादश_, toeë, रणों_,
  { {0x2249006f,0x8007026c,0xb6020080,0x00000000}},	//   svak_, ючае, řáte,
  { {0x7bc2006f,0x61ed17cb,0xdb0900ac,0x00000000}},	//   _nhou, ppal, roeë,
  { {0x3f8f0150,0xf7740063,0x63ad4394,0x00000000}},	//   rigu_, וקף_, moan,
  { {0x11da014e,0x63ad000c,0xdb00029c,0x00000000}},	//   _לחשב, loan, vomá,
  { {0x7afd0026,0xc57c0063,0x69c8004c,0x00000000}},	//   ðsto, שרות, dmde,
  { {0xdb004395,0x69c80983,0x6d5e069b,0x00000000}},	//   tomá, emde, öpar,
  { {0xdb0e0025,0x3eb90014,0x1eea0043,0x00000000}},	//   ódál, _ást_, _طولی_,
  { {0xdb002f90,0x8d77002a,0x888505f1,0x00000000}},	//   romá, _بارا, злож,
  { {0xa3bd0161,0xdb0000b9,0xa5bb0026,0x00000000}},	//   ेगा_, domæ, rtól,
  { {0x9179001b,0x7bc24396,0xa5bb4397,0x00000000}},	//   _lần_, _ghou, stól,
  { {0x200702e2,0xd4970013,0x7f3a0047,0x00000000}},	//   šnih_, ồng_, זערו,
  { {0xe4da007e,0x7d1c2957,0xaa420002,0x00000000}},	//   صورت_, _örst, _чешл,
  { {0x98790047,0x63ad003b,0x69c34398,0x00000000}},	//   _לאַט, foan, _ihne,
  { {0x3f9f0035,0xa7fc0058,0x98ac003b,0x00000000}},	//   _njuu_, ayıs, sedă_,
  { {0x171b014e,0x63b64399,0x70f60044,0x00000000}},	// [7d60] _הופע, rlyn, كسائ,
  { {0x9179001b,0x91b10013,0x69c3004d,0x00000000}},	//   _cần_, _đạp_, _jhne,
  { {0x91790013,0xb4d80042,0x63b6439a,0x00000000}},	//   _dần_, िशी_, plyn,
  { {0xf1a90047,0x63ad439b,0xdfcf00f2,0x00000000}},	//   אס_, coan, هيل_,
  { {0x69c8001f,0x69c3004d,0x9f03005d,0x00000000}},	//   ymde, _ohne, رووو,
  { {0x7bc20034,0x9179008b,0x70ca439c,0x00000000}},	//   _shou, _gần_, _гггг_,
  { {0x31570047,0x64581358,0x317b009a,0x00000000}},	//   _צילן_, _ávid, _פרלמ,
  { {0xaa54005a,0x309b0063,0x26c001f4,0x00000000}},	//   двиш, _השלמ, _ozio_,
  { {0x628402f6,0x257401e3,0xc3330063,0x00000000}},	//   nzio, _välj_, תוח_,
  { {0x63ad0009,0x62842890,0x63711310,0x00000000}},	//   zoan, izio, _våni,
  { {0x7bc20034,0x63ad0035,0x69c8006f,0x00000000}},	//   _thou, yoan, rmde,
  { {0xe6950076,0xa8a3000d,0xba2a007e,0x00000000}},	//   димы, эрык, _هستم_,
  { {0xbaba0021,0xdb0005b9,0x3cfe005f,0x00000000}},	//   _اداء_, tomæ, _ketv_,
  { {0xd5b1008b,0x201a2214,0x62840051,0x00000000}},	//   ố_, kupi_, dzio,
  { {0x63ad000c,0x6284439d,0x26c001f4,0x00000000}},	//   toan, ezio, _ezio_,
  { {0x201a0150,0x97a4000d,0x63680b69,0x00000000}},	//   dupi_, _прыл, пруг_,
  { {0xa2cd0053,0x6f02007d,0x63ad439e,0x00000000}},	// [7d70] _दृश्, daoc, roan,
  { {0x9327006a,0x291e0006,0x64580006,0x00000000}},	//   _کردن, ngta_, _švie,
  { {0x628402f6,0xf1c80021,0xf1bf0025,0x00000000}},	//   azio, أولى_, _spás_,
  { {0xdb002c17,0x6f022f93,0x27f801d1,0x00000000}},	//   nomä, gaoc, árny_,
  { {0x3254000d,0x7ed4000d,0x91790013,0x00000000}},	//   _звяр, нішч, _tần_,
  { {0xdd9108aa,0xee380636,0x361c009a,0x00000000}},	//   ضوع_, яні_, מודד,
  { {0xdbf10080,0x8c420612,0xdb000072,0x00000000}},	//   příj, веще, komä,
  { {0xdce1003d,0xdb4e0021,0x291e2b27,0x00000000}},	//   _dolā, لَى_, egta_,
  { {0xdb0000c7,0x7bc9439f,0x6b9b0014,0x00000000}},	//   domä, rmeu, rnug,
  { {0x98bc003d,0x644800b9,0x9f58013d,0x00000000}},	//   _savā_, ædik, özöl_,
  { {0x62840387,0x07a62fd7,0xc7a63a58,0x00000000}},	//   zzio, данн, динк,
  { {0x7d0343a0,0xd7ca0cac,0x00000000,0x00000000}},	//   lans, توجه_,   ,
  { {0x637843a1,0x69c3002b,0xaa4505f4,0x00000000}},	//   _síno, _thne, _целл,
  { {0x7d0343a2,0xa3b60042,0xe00d0042,0x00000000}},	//   nans, _चीज_, _हिंद_,
  { {0x98bc008f,0x5fd90053,0x33d60054,0x00000000}},	//   _tavā_, _बंगल, діат,
  { {0x7d032d4e,0x2eff0164,0x394706a3,0x00000000}},	//   hans, _neuf_, _hans_,
  { {0x39470173,0x6f02007d,0x7d031110,0x00000000}},	// [7d80] _kans_, vaoc, kans,
  { {0x628430b8,0x76440035,0x7d0343a3,0x00000000}},	//   rzio, _isiy, jans,
  { {0xdce30080,0x6f02007d,0x672443a4,0x00000000}},	//   skně, taoc, _kcij,
  { {0x62840290,0x9179001b,0x200743a5,0x00000000}},	//   pzio, _vấn_, ânia_,
  { {0x7d03001f,0x201a0150,0x644e069f,0x00000000}},	//   fans, supi_, lvbi,
  { {0x394736ae,0x91790013,0x2d570121,0x00000000}},	//   _nans_, _tấn_, дишь_,
  { {0x6724017f,0xebc6005e,0x44442494,0x00000000}},	//   _ocij, мљин, _js_,
  { {0x8c430001,0x6f66000d,0x7d0312f9,0x00000000}},	//   теће, _ўваз, aans,
  { {0xcb67000a,0x7d0343a6,0x444443a7,0x00000000}},	//   ќање_, bans, _ls_,
  { {0x7d0343a8,0x444443a9,0x7981002b,0x00000000}},	//   cans, _os_, ghlw,
  { {0x39470c6e,0xab2a0088,0x753c102c,0x00000000}},	//   _dans_, _можа_, derz,
  { {0x6d4843aa,0xbc790047,0x657e0238,0x00000000}},	//   _hada, _צװײט, _alph,
  { {0xa5bb0025,0xe4e70086,0x44443624,0x00000000}},	//   ltói, дібн, _as_,
  { {0x444443ab,0x7981001f,0x22400022,0x00000000}},	//   _bs_, chlw, dwik_,
  { {0x6d480465,0x236b0001,0x17f70021,0x00000000}},	//   _mada, ојао_, _قرية_,
  { {0x69d81beb,0x6d4843ac,0x645802f7,0x00000000}},	//   _hive, _lada, _švic,
  { {0x7d030009,0x444443ad,0xa5bb0139,0x00000000}},	// [7d90] yans, _es_, htói,
  { {0xca480013,0x661d18d5,0x6d5a04aa,0x00000000}},	//   _mờ_, musk, _nnta,
  { {0x69d8000f,0x6d4a001f,0xca480013,0x00000000}},	//   _mive, ddfa, _lờ_,
  { {0x7d03102e,0x644543ae,0x6d5a43af,0x00000000}},	//   wans, _ishi, _anta,
  { {0x8db50088,0x6d48167f,0x42790041,0x00000000}},	//   нскі, _bada, _זאָג,
  { {0x44441a5f,0x9179001b,0x6d4843b0,0x00000000}},	//   _ys_, _dẫn_, _cada,
  { {0x7d0343b1,0x6d4843b2,0xabd50d34,0x00000000}},	//   rans, _dada, нциј,
  { {0x394703b2,0xfa69000a,0x64450035,0x00000000}},	//   _sans_, заик_, _mshi,
  { {0x7d0343b3,0xca48008b,0x6d48155e,0x00000000}},	//   pans, _cờ_, _fada,
  { {0x661d0019,0x6d4843b4,0x69d843b5,0x00000000}},	//   dusk, _gada, _cive,
  { {0x673d43b6,0x7b670432,0x69d834a3,0x00000000}},	//   fesj, _отде, _dive,
  { {0x764400a4,0x70dc0053,0xc0520047,0x00000000}},	//   _psiy, _बल्ल, אזט_,
  { {0x3947021f,0xab18019d,0x661d0019,0x00000000}},	//   _tans_, _цієї_, gusk,
  { {0x7d01000f,0x69d843b7,0x753c27df,0x00000000}},	//   _jels, _give, uerz,
  { {0x661d43b8,0x7d0143b9,0x290543ba,0x00000000}},	//   ausk, _mels, mala_,
  { {0x290543bb,0x753c033f,0x38780831,0x00000000}},	//   lala_, serz, ørre_,
  { {0x7ae915da,0x44442523,0x6445007d,0x00000000}},	// [7da0] icet, _ws_, _eshi,
  { {0x7ae9004a,0x29050869,0xa91c0066,0x00000000}},	//   hcet, nala_, ohľa,
  { {0x4444233a,0xc7b9007d,0x251b0047,0x00000000}},	//   _us_, suđe_, _צוטא,
  { {0x6d481ad1,0x290543bc,0xdee643bd,0x00000000}},	//   _sada, hala_, ходи,
  { {0x7d0100ea,0x6d4843be,0x290543bf,0x00000000}},	//   _bels, _pada, kala_,
  { {0xcce6006a,0x9179008b,0x6d480222,0x00000000}},	//   رستي, _vẫn_, _qada,
  { {0x290543c0,0x20070080,0x7d010c68,0x00000000}},	//   dala_, ánit_, _dels,
  { {0x5a3427ad,0x6d481735,0x7d01004b,0x00000000}},	//   внит, _wada, _eels,
  { {0x7bd90397,0xa5bb0025,0xa91c0066,0x00000000}},	//   _diwu, stói, ehľa,
  { {0xf8ab001b,0x661d3845,0x290543c1,0x00000000}},	//   ười_, vusk, gala_,
  { {0x69d843c2,0x673d00ca,0x6c560054,0x00000000}},	//   _vive, tesj, _ятає,
  { {0x7ae90290,0x320943c3,0xca48008b,0x00000000}},	//   ccet, ysay_, _tờ_,
  { {0x69d803d9,0x95cb05fb,0x290543c4,0x00000000}},	//   _tive, зува_, bala_,
  { {0xceb30e2a,0x661d43c5,0xa9670062,0x00000000}},	//   ריש_, rusk, _пича_,
  { {0x43950086,0x661d35ef,0xf434000d,0x00000000}},	//   вавс, susk, лерэ,
  { {0x661d3d49,0x58bb0063,0x63a9081a,0x00000000}},	//   pusk, _ממוצ, čeno,
  { {0xdb1b0016,0x7afd0014,0xd5bb0094,0x00000000}},	// [7db0] fluê, ðsti, _нсо_,
  { {0x2007017d,0xe290009e,0x45d50854,0x00000000}},	//   ânio_, حذف_, _шопс,
  { {0x64450035,0x0596007e,0x49170063,0x00000000}},	//   _ushi, _جايگ, תקבל_,
  { {0x7d010831,0x29fd0066,0x290543c6,0x00000000}},	//   _sels, yňa_, zala_,
  { {0x7d013bcb,0xa91c0066,0x63a8004c,0x00000000}},	//   _pels, zhľa, édne,
  { {0xa91c034d,0x236900b2,0xb17b01e1,0x00000000}},	//   yhľa, ljaj_, _etår,
  { {0x7d0143c7,0x290531ca,0xcf8b0131,0x00000000}},	//   _vels, vala_, _есад_,
  { {0x660d017f,0x257400bd,0x290543c8,0x00000000}},	//   _ovak, _hält_, wala_,
  { {0x290543c9,0x7ae943ca,0x99dd0066,0x00000000}},	//   tala_, rcet, yvňu,
  { {0x290500e3,0x7ae943cb,0x99d50021,0x00000000}},	//   uala_, scet, ختبا,
  { {0x660d00c7,0xd7f80088,0x788643cc,0x00000000}},	//   _avak, нуў_, _révé,
  { {0x78860003,0x29fd0066,0x6836004d,0x00000000}},	//   _sévé, pňa_, _südö,
  { {0x290543cd,0x661a0051,0x2369007d,0x00000000}},	//   pala_, ątko, djaj_,
  { {0x290500ac,0x98bc0078,0x660d0f18,0x00000000}},	//   qala_, _savą_, _dvak,
  { {0x232a046a,0xd4150085,0x5fd10042,0x00000000}},	//   мови_, льты, तगाल,
  { {0xe6960044,0xd7ca005d,0x4a5b009d,0x00000000}},	//   _للعد, _توبه_, ּד֑ו,
  { {0xe29728f2,0x29c20026,0x788600ea,0x00000000}},	// [7dc0] ват_, iðan_, _tévé,
  { {0x91a7001b,0xd1830076,0x6378156f,0x00000000}},	//   _địa_, алуй, _míni,
  { {0x63780994,0x30860021,0x757b009a,0x00000000}},	//   _líni, خلاف, _חטיפ,
  { {0xa3c9016a,0xbf130021,0xdb0043ce,0x00000000}},	//   _लीप_, لومب, llmö,
  { {0x257400c7,0x3e340021,0x443a3d38,0x00000000}},	//   _fält_, افتر, _hpp_,
  { {0x29c20026,0x1ea90021,0xa5bb017d,0x00000000}},	//   eðan_, راني_, stóv,
  { {0x50c60053,0xed570095,0xab940086,0x00000000}},	//   _वरिष, тој_, ликі,
  { {0x443a15fb,0x60c3005b,0x29c20014,0x00000000}},	//   _mpp_, ünme, gðan_,
  { {0x63781912,0xdfa50021,0xaa630085,0x00000000}},	//   _cíni, _صحفي, атэк,
  { {0x443a1609,0x3f860016,0x1e830500,0x00000000}},	//   _opp_, lhou_, _тлум,
  { {0x660d0117,0x3f860080,0x6378017d,0x00000000}},	//   _svak, ohou_, _tính,
  { {0x3f8643cf,0x68f5005b,0x7c850001,0x00000000}},	//   nhou_, ızda, _суђе,
  { {0x443a43d0,0xd5bb0094,0xf628012c,0x00000000}},	//   _app_, дсв_, кіри_,
  { {0x443a0150,0xe8540021,0xfe080013,0x00000000}},	//   _bpp_, _منتد, iữ_,
  { {0xdb1b0268,0x984a005a,0x6b8200b9,0x00000000}},	//   fluè, _цяла_, _klog,
  { {0x6443017d,0xdb0008e9,0x443a373a,0x00000000}},	//   _ânim, almö, _dpp_,
  { {0x236900c2,0x64580014,0x6b82002b,0x00000000}},	// [7dd0] rjaj_, _ávin, _mlog,
  { {0x6b8243d1,0x3f8600ac,0x7c3a43d2,0x00000000}},	//   _llog, ehou_, _optr,
  { {0x43950a3d,0xdb00004e,0x301522e8,0x00000000}},	//   _банс, llmõ, удер,
  { {0x6b8202fd,0x289b0041,0xd4980085,0x00000000}},	//   _nlog, ויבא, _шры_,
  { {0x3ea90268,0xfe08008b,0x61e20139,0x00000000}},	//   çat_, gữ_, íolt,
  { {0x6b8243d3,0x067c07e9,0xddc2004c,0x00000000}},	//   _alog, ונדל, ovoř,
  { {0x63780027,0xa1941cb9,0x5bb5018e,0x00000000}},	//   _síni, _тарч, лсиф,
  { {0x29180014,0x6b823637,0x0c360044,0x00000000}},	//   óran_, _clog, اكية_,
  { {0x69ca0027,0x29c20014,0xe9d943d4,0x00000000}},	//   _bhfe, rðan_, нки_,
  { {0xd9450001,0x6b8212c7,0xe8f60e82,0x00000000}},	//   ћени, _elog, лль_,
  { {0x63a9055e,0x2d870025,0x9be70086,0x00000000}},	//   čenj, mhne_, _різк,
  { {0xeb74000d,0x29190058,0x645a0137,0x00000000}},	//   _вышэ, şsa_, åtim,
  { {0x64570994,0x63780026,0x7afb07f4,0x00000000}},	//   _arxi, _kínv, mbut,
  { {0x69ca0161,0xceb2014e,0x1a9a00b5,0x00000000}},	//   _सीपी, צים_, _אינע,
  { {0x3ceb0053,0xc7b9007d,0xa5bb0014,0x00000000}},	//   _चलने_, suđa_, króf,
  { {0x6e3b0051,0x25740137,0xb8760149,0x00000000}},	//   _opub, _päls_, _תתקס_,
  { {0xec09008b,0xdb1b006c,0xd1ca3958,0x00000000}},	// [7de0] hế_, rluè, елае_,
  { {0x61f608b3,0x2d8700c2,0x32170044,0x00000000}},	//   rpyl, jhne_, ايلد_,
  { {0x3f8600e8,0x443a43d5,0x200e0026,0x00000000}},	//   thou_, _upp_, éfi_,
  { {0x5f063731,0x29c20014,0x3f86004c,0x00000000}},	//   узда, eðal_, uhou_,
  { {0x63a437f7,0x3f8600ac,0x527606c9,0x00000000}},	//   mnin, rhou_, _суну,
  { {0x63a42ddc,0xbc4a0905,0x7afb43d6,0x00000000}},	//   lnin, ечие_, ebut,
  { {0x3f8600ac,0xef1a0002,0x6e3b43d7,0x00000000}},	//   phou_, _пмв_, _epub,
  { {0x7afb002c,0xe4570047,0xa5bb05d5,0x00000000}},	//   gbut, ריקט_, cróf,
  { {0xe8d9001b,0x3f840e53,0x6b8200c3,0x00000000}},	//   _đề_, _ilmu_, _vlog,
  { {0x63a401e3,0x7afb43d8,0x2d9801bb,0x00000000}},	//   hnin, abut, _öre_,
  { {0x63a43a92,0xa5bb0045,0x7dc400cd,0x00000000}},	//   knin, któr, lòso,
  { {0x6b82017f,0x63a443d9,0x7d0a006f,0x00000000}},	//   _ulog, jnin, lafs,
  { {0x63a443da,0x61e643db,0x6e22005f,0x00000000}},	//   dnin, _nukl, nuob,
  { {0xddc20080,0x7d0a16cb,0x637843dc,0x00000000}},	//   tvoř, nafs, _mínu,
  { {0x63780026,0x63a4438a,0x645812da,0x00000000}},	//   _línu, fnin, _ávil,
  { {0x63a4117c,0x7d0a4303,0xd7f8003b,0x00000000}},	//   gnin, hafs, mpă_,
  { {0xd7f800dd,0x753b0130,0x7bc043dd,0x00000000}},	// [7df0] lpă_, đuzb, ilmu,
  { {0xa5bb1a4e,0x61150086,0x63a40465,0x00000000}},	//   atór, рджу, anin,
  { {0x31c40076,0x63a443de,0x7d0a01e1,0x00000000}},	//   сств, bnin, dafs,
  { {0x7ae20150,0xa5bb00ed,0x6e3b00a4,0x00000000}},	//   _ngot, ctór, _ppub,
  { {0xaf04019d,0x2d870025,0x11d90021,0x00000000}},	//   спіл, thne_, _لوحة_,
  { {0x22591607,0x7ae243df,0xac390086,0x00000000}},	//   _irsk_, _agot, вчих_,
  { {0xa5bb0026,0x05780063,0x7afb1c83,0x00000000}},	//   próf, רגום_, tbut,
  { {0x543c0047,0x69ca0053,0x661d00a8,0x00000000}},	//   געהא, _सीबी, krsk,
  { {0xa3d60053,0x2d8743e0,0x7afb43e1,0x00000000}},	//   िगत_, phne_, rbut,
  { {0x661d1253,0xf241000d,0x8e840021,0x00000000}},	//   drsk, скiя_, _الكه,
  { {0x661d43e2,0xfd100021,0x6ca7047e,0x00000000}},	//   ersk, _رجل_, _сраж,
  { {0x9c820024,0x7bdc0003,0x63a40137,0x00000000}},	//   účen, _érup, xnin,
  { {0x63a402aa,0xd7f8003b,0x443143e3,0x00000000}},	//   vnin, apă_, etz_,
  { {0xa5bb0051,0x63780025,0x6d4343e4,0x00000000}},	//   wtór, _línt, nena,
  { {0x44230045,0xc3960001,0x6d4343e5,0x00000000}},	//   guj_, ајањ, iena,
  { {0x6b8900e8,0x661d00c3,0x6b9b43e6,0x00000000}},	//   nheg, brsk, niug,
  { {0x290743e7,0x6d432896,0xa5bb017d,0x00000000}},	// [7e00] _kena_, kena, rtór,
  { {0x44230051,0x63a4287a,0x6d4343e8,0x00000000}},	//   buj_, snin, jena,
  { {0x63780026,0x63a443e9,0x69c143ea,0x00000000}},	//   _sínu, pnin, ille,
  { {0x29070027,0x2d8543eb,0x64c5007e,0x00000000}},	//   _lena_, _alle_, _ديپل,
  { {0x7d0a3f96,0x2bdf0053,0x3dde00a3,0x00000000}},	//   tafs, _पंजा, _pitw_,
  { {0xdb1b00cd,0xd6570063,0x6d4343ec,0x00000000}},	//   fluï, יינת_, gena,
  { {0x6b89007a,0x3f9c0003,0xa0672377,0x00000000}},	//   fheg, évus_, _кара_,
  { {0x2d8503b2,0x27e0024a,0x7d0a43ed,0x00000000}},	//   _elle_, _niin_, safs,
  { {0x6d430397,0x442343ee,0x290743ef,0x00000000}},	//   bena, zuj_, _bena_,
  { {0x6d4343f0,0x63a943f1,0x27e700d1,0x00000000}},	//   cena, čeni, _bunn_,
  { {0xe8d900aa,0xd7f8000c,0x2d9c00c2,0x00000000}},	//   _để_, upă_, mive_,
  { {0x7ae20198,0x6b8943f2,0x2d9c43f3,0x00000000}},	//   _ugot, cheg, live_,
  { {0x799a0035,0x27e000a4,0x661d43f4,0x00000000}},	//   pitw, _diin_, ursk,
  { {0x442339f1,0x66040150,0x27e700d1,0x00000000}},	//   tuj_, _dwik, _funn_,
  { {0x98a50006,0xdb0905d5,0x290c2f6e,0x00000000}},	//   delė_, cleó, mada_,
  { {0x6d430016,0x44230051,0x290c0b16,0x00000000}},	//   zena, ruj_, lada_,
  { {0x44230045,0xdb00006d,0x60e70086,0x00000000}},	// [7e10] suj_, lomó, ацез,
  { {0xd49b32f0,0x2d9c02e2,0x7d080246,0x00000000}},	//   _арм_, jive_, _neds,
  { {0x5067000a,0x290c43f5,0x6d4339d9,0x00000000}},	//   штаа, iada_, vena,
  { {0x6d43014f,0x290c11de,0x1eea005d,0x00000000}},	//   wena, hada_, هومی_,
  { {0x7d080146,0xef18013c,0x69c143f6,0x00000000}},	//   _beds, рмі_, ylle,
  { {0x2d9c010a,0x63780865,0x7dcd0066,0x00000000}},	//   give_, _fíns, kúse,
  { {0x290743f7,0x6d430f0d,0x290c43f8,0x00000000}},	//   _rena_, rena, dada_,
  { {0xa6db007a,0x1b4943f9,0x290743fa,0x00000000}},	//   veðn, узии_, _sena_,
  { {0x69c10268,0x27e700d1,0x6d4343fb,0x00000000}},	//   tlle, _sunn_, pena,
  { {0x27e00004,0x8d740754,0x290c43fc,0x00000000}},	//   _siin_, _والا, gada_,
  { {0x69c10185,0x290743fd,0x764d06ed,0x00000000}},	//   rlle, _vena_, _asay,
  { {0x69c100cd,0x290c1a1e,0x290700ac,0x00000000}},	//   slle, aada_, _wena_,
  { {0x29070009,0x6fda0080,0x290c43fe,0x00000000}},	//   _tena_, _důch, bada_,
  { {0x290c1114,0x225e004c,0x27180013,0x00000000}},	//   cada_, _čtk_, ọn_,
  { {0x443e0268,0x63a80080,0x27ed0022,0x00000000}},	//   ït_, édno, ólną_,
  { {0x087600b5,0x38780137,0x2d9c43ff,0x00000000}},	//   _לעצט_, ärre_, zive_,
  { {0x98a50078,0xae1c0053,0x6604056c,0x00000000}},	// [7e20] telė_, _निधन_, _uwik,
  { {0x394518b9,0xa06a13ee,0x2d9c2a5a,0x00000000}},	//   nels_, лаза_, xive_,
  { {0x7ee60021,0x7d08055b,0x224900a4,0x00000000}},	//   مكان, _reds, awak_,
  { {0x290c0747,0x39450917,0x543b0047,0x00000000}},	//   zada_, hels_, _געטא,
  { {0x3945021f,0x2d9c4049,0x6eb60044,0x00000000}},	//   kels_, tive_, حصائ,
  { {0xa116006a,0x463b0047,0x290c4400,0x00000000}},	//   _دوست, רעסע, xada_,
  { {0x30860032,0xd47a0047,0xe4fb0053,0x00000000}},	//   _الأف, טאַל, ्रति_,
  { {0x7d080162,0x39450474,0x2d9c4401,0x00000000}},	//   _weds, eels_, sive_,
  { {0xdb1b1c3e,0x290c4402,0x6e960021,0x00000000}},	//   cluí, tada_, _الذا,
  { {0xa8140001,0x99980002,0xdb000460,0x00000000}},	//   одош, ркот_, tomó,
  { {0x290c4403,0x91bb0149,0x764d006c,0x00000000}},	//   rada_, רמיי, _ssay,
  { {0xe61f017d,0x32120072,0xdb00095e,0x00000000}},	//   trô_, ksyy_, romó,
  { {0x290c0c96,0x8f9b0063,0xfa33007e,0x00000000}},	//   pada_, ריכי, _فرود,
  { {0xdb000022,0x290c0059,0x39454404,0x00000000}},	//   pomó, qada_, cels_,
  { {0x84640062,0x65940777,0x1867005e,0x00000000}},	//   пъте, чару, _гаји_,
  { {0x07a40fe2,0x4394030b,0xdc8b009a,0x00000000}},	//   _најн, пасс, רְךָ,
  { {0x5215047e,0x7dcd3784,0xa5bb0046,0x00000000}},	// [7e30] юдат, núsc, rrób,
  { {0xdb090014,0x60e70085,0x27e101c8,0x00000000}},	//   hleð, сцаз, _činy_,
  { {0xa5bb1504,0x29c20046,0x9ee9043e,0x00000000}},	//   prób, rðah_, لفضل_,
  { {0x201c231d,0x394509fe,0x65770059,0x00000000}},	//   ávia_, zels_, _hoxh,
  { {0x7dcd0268,0x171c0047,0x1d090062,0x00000000}},	//   júsc, רודע, аели_,
  { {0xdb02007a,0xb4fb0161,0x39454405,0x00000000}},	//   _skoð, ्रिय_, xels_,
  { {0x39450706,0x7db40044,0xc0580e74,0x00000000}},	//   vels_, أصنا, _літ_,
  { {0x39454406,0x8f340085,0x9f34071f,0x00000000}},	//   wels_, _несц, _несі,
  { {0xdb0000cd,0x6e99000d,0x39450479,0x00000000}},	//   tomò, _твар_, tels_,
  { {0xe8df001b,0x39790076,0xdce80022,0x00000000}},	//   _giới_, рсию_, _podą,
  { {0x0cab005a,0xa3d90053,0x39452419,0x00000000}},	//   _стаи_, ाषा_, rels_,
  { {0x39454407,0x32120072,0x68fc0075,0x00000000}},	//   sels_, ysyy_, ırda,
  { {0x0556005a,0x70c60053,0x39454408,0x00000000}},	//   отвя, _वर्ल, pels_,
  { {0x98a5008f,0xa507180c,0x00000000,0x00000000}},	//   nelī_, жера_,   ,
  { {0xa5bb0051,0xe7320021,0x97c60044,0x00000000}},	//   wróc, _قصة_, _وتعم,
  { {0x27f8017c,0xe286030b,0x77644409,0x00000000}},	//   írne_, олби, _unix,
  { {0xccf8004c,0xe3b7046e,0xe2a90044,0x00000000}},	// [7e40] _sněm_, ібу_, ماكن_,
  { {0x0446167b,0x10a61585,0x60260e74,0x00000000}},	//   _деон, оизн, жджа,
  { {0xd12f0021,0x63780014,0xceea019c,0x00000000}},	//   ضمن_, _fínp, адее_,
  { {0xddc90045,0x7dcd006d,0x4fa30062,0x00000000}},	//   _treś, yúsc, михв,
  { {0x98be001c,0xde58000d,0x5e580054,0x00000000}},	//   ietā_, салі_, силя_,
  { {0x7c660593,0xdd900044,0x865b009d,0x00000000}},	//   قابل, عوث_, ידני,
  { {0x0b8a05fb,0x200700dd,0x705600de,0x00000000}},	//   исии_, ânit_, _بنزا,
  { {0x447b0041,0x00000000,0x00000000,0x00000000}},	//   ינצע,   ,   ,
  { {0x9f4d00bd,0x6f02440a,0xe9460121,0x00000000}},	//   _hieß_, mboc, охно,
  { {0x6d230001,0x7dcd0025,0x2fc62f15,0x00000000}},	//   _одуз, rúsc, llog_,
  { {0x81570047,0x6c4a002a,0x6f020022,0x00000000}},	//   קסטע_, _خلاف_, oboc,
  { {0x7dcd3709,0x6f02080f,0x290a0022,0x00000000}},	//   púsc, nboc, źba_,
  { {0xdb090199,0x9f4d00bd,0x8bd70047,0x00000000}},	//   ließ, _ließ_, _וואו_,
  { {0x26c5001c,0x6440000c,0x94ab0062,0x00000000}},	//   ālo_, ămin, атба_,
  { {0x7dcd0025,0xa5bb00ea,0xe8d9008b,0x00000000}},	//   núsa, gróa, _đệ_,
  { {0x6e22440b,0x48a90054,0x24e40085,0x00000000}},	//   krob, _утім_, ьцяг,
  { {0xdb0900bd,0x7dcd006d,0x623409c2,0x00000000}},	// [7e50] hieß, húsa, мету,
  { {0x6e224118,0x20c7019c,0x2fc600a3,0x00000000}},	//   drob, осег, elog_,
  { {0x6e22001c,0xf485007e,0x4427008b,0x00000000}},	//   erob, _رادی, _ên_,
  { {0x63a9004a,0x9327007e,0x2fc6440c,0x00000000}},	//   čens, _بردن, glog_,
  { {0x4e04000d,0x8d652328,0x51872a92,0x00000000}},	//   дзіб, звле, _дува,
  { {0xf2d20149,0xc27a0063,0x2fc6440d,0x00000000}},	//   _נעם_, _הרשי, alog_,
  { {0x2fc6440e,0x30a400e1,0x60180071,0x00000000}},	//   blog_, _жртв, _моря_,
  { {0x6e22440f,0x00000000,0x00000000,0x00000000}},	//   brob,   ,   ,
  { {0x6f1b2866,0x6e2211d3,0xaa45012c,0x00000000}},	//   _iduc, crob, чепл,
  { {0xacf4007e,0x7e6d0072,0xddc2056c,0x00000000}},	//   _قسمت, äapu, awoł,
  { {0x7c59006a,0xfc3004a0,0xc8d50082,0x00000000}},	//   _دلار_, _لحن_, डेंट,
  { {0x7b640c07,0xe73a137a,0x309a0063,0x00000000}},	//   _отче, щем_, משתמ,
  { {0x987700c3,0x55f6030b,0xb5aa00de,0x00000000}},	//   _išče_, ячну, ماسك_,
  { {0x386a0025,0x2fc601b3,0x6eba009a,0x00000000}},	//   óirí_, zlog_, מזרח,
  { {0x6e221ae4,0x14590085,0x3c89009d,0x00000000}},	//   zrob, ошты_, זָּ֑,
  { {0x6d86007a,0xb69b003b,0x66160078,0x00000000}},	//   _aðal, mbân, _tvyk,
  { {0xe8d9001b,0x52760002,0x997c008f,0x00000000}},	// [7e60] _độ_, чуву, _dāņu_,
  { {0x7dc40268,0x6f1b000c,0x201c017d,0x00000000}},	//   pòsi, _aduc, ávio_,
  { {0xd12f0021,0xdefa0121,0x757b0063,0x00000000}},	//   امم_, был_, _הטיפ,
  { {0x442a0004,0x98be000c,0x645c3a73,0x00000000}},	//   mub_, letă_, mvri,
  { {0x2fc60173,0x442a4410,0x44384411,0x00000000}},	//   rlog_, lub_, ltr_,
  { {0x645c0150,0x763b0047,0x98be003b,0x00000000}},	//   ovri, מענג, netă_,
  { {0x44380529,0x2fc6007d,0x6e224412,0x00000000}},	//   ntr_, plog_, srob,
  { {0x6e224413,0x7dcd0014,0x98be00dd,0x00000000}},	//   prob, rúsa, hetă_,
  { {0x442a4414,0x44444415,0x645c004b,0x00000000}},	//   hub_, _lp_, hvri,
  { {0x44444416,0x3f8601c2,0x442a4417,0x00000000}},	//   _op_, lkou_, kub_,
  { {0xdd8f0032,0x44440045,0x6d4a0035,0x00000000}},	//   _حول_, _np_, mefa,
  { {0x442a0019,0x3f86004a,0x6d584418,0x00000000}},	//   dub_, nkou_, ldva,
  { {0x645c005b,0xab270454,0xf1be0053,0x00000000}},	//   evri, _хоча_, ्तान,
  { {0xcaa503eb,0x39890139,0x444403a2,0x00000000}},	//   _تصمي, _túsa_, _bp_,
  { {0x69da0199,0xc9730021,0x442a4419,0x00000000}},	//   mmte, _ساوث, gub_,
  { {0x69c800c7,0x4444441a,0x3f860061,0x00000000}},	//   llde, _dp_, jkou_,
  { {0x4438001f,0x7179018e,0x35b50a36,0x00000000}},	// [7e70] atr_, обар_, _обир,
  { {0x6d58006f,0x442a344f,0x290e0331,0x00000000}},	//   jdva, bub_, _jefa_,
  { {0x69da006f,0x44382aa8,0x69c82beb,0x00000000}},	//   imte, ctr_, ilde,
  { {0x69da00bd,0x6d58006f,0xe0d00021,0x00000000}},	//   hmte, edva, ازك_,
  { {0xddc90529,0x0596007e,0x290e006f,0x00000000}},	//   _creş, _رایگ, _oefa_,
  { {0x7bc20117,0xd6580063,0xdd94000d,0x00000000}},	//   _akou, פיות_, начы,
  { {0xbc19000d,0x63ad277f,0xfd10002a,0x00000000}},	//   цілі_, onan, اجه_,
  { {0x2d8c005b,0x69c8190f,0x3f862f42,0x00000000}},	//   _elde_, elde, ckou_,
  { {0x6d4a02ab,0xddc9000c,0x3f8d001f,0x00000000}},	//   befa, _greş, _ileu_,
  { {0x6d4a441b,0xdb000014,0x6445441c,0x00000000}},	//   cefa, rnmá, _ophi,
  { {0x8af9011c,0x63ad4034,0x6d412118,0x00000000}},	//   _днес_, knan, _ibla,
  { {0x444430ff,0x69c817e9,0x69da441d,0x00000000}},	//   _rp_, alde, amte,
  { {0x2bb80021,0x4444441e,0x7bdb0cb0,0x00000000}},	//   _عامة_, _sp_, mmuu,
  { {0x7bc903b2,0x290e007a,0x7bc20080,0x00000000}},	//   lleu, _gefa_, _zkou,
  { {0x61fd0418,0x29051b84,0x04b5042c,0x00000000}},	//   _atsl, mbla_, естя,
  { {0x645c02b0,0x98be000c,0x6d58007d,0x00000000}},	//   rvri, setă_, zdva,
  { {0x61e70122,0x44383ccc,0x442a0019,0x00000000}},	// [7e80] _bijl, str_, sub_,
  { {0x7bc900bd,0x7dc400cd,0x4444441f,0x00000000}},	//   hleu, nòst, _tp_,
  { {0xa6db007a,0x7bc90162,0x3f8d0164,0x00000000}},	//   veði, kleu, _bleu_,
  { {0xddc90529,0x6d4a002b,0x6d413748,0x00000000}},	//   _preş, wefa, _abla,
  { {0x69c802ab,0x98a50006,0x7bc9001f,0x00000000}},	//   ylde, kelį_, dleu,
  { {0xf987006a,0x98be0006,0x20180150,0x00000000}},	//   _شب_, letą_, _tvri_,
  { {0x63a4006f,0x98a50006,0x6d4a4420,0x00000000}},	//   oiin, delį_, refa,
  { {0xaa5407fe,0x61e7006f,0xfc630062,0x00000000}},	//   евиш, _zijl, тъшн,
  { {0xc27b00b5,0xa5bb00ea,0x727b0047,0x00000000}},	//   ַרטי, rtóz, ַנטװ,
  { {0x69c80034,0x7bc90164,0x98a50078,0x00000000}},	//   ulde, aleu, gelį_,
  { {0x69c800c7,0x63a400fe,0x9f440003,0x00000000}},	//   rlde, kiin, _aimé_,
  { {0x25a3006f,0x29c20026,0x29054421,0x00000000}},	//   wijl_, gðar_, abla_,
  { {0xa3c90235,0x29180027,0x25a3006f,0x00000000}},	//   _लीग_, óras_, tijl_,
  { {0x63ad0051,0x7bc00b4e,0x63a4006f,0x00000000}},	//   wnan, lomu, eiin,
  { {0x63a4000c,0x69cb0053,0x04c90021,0x00000000}},	//   fiin, हतरी, سوري_,
  { {0x394c0137,0x63a44422,0x63ad4423,0x00000000}},	//   leds_, giin, unan,
  { {0xb6040080,0x61e70122,0xe4eb007e,0x00000000}},	// [7e90] tvář, _pijl, _وعده_,
  { {0xef190045,0x64930006,0x27e90089,0x00000000}},	//   _może_, ežiū, _hian_,
  { {0xfe70006a,0x27e9053b,0x31c405f7,0x00000000}},	//   یده_, _kian_, тств,
  { {0x660d0009,0x60c70080,0x46d30053,0x00000000}},	//   _kwak, _vyjm, _सराह,
  { {0x27e90027,0xdb00177f,0x61fd00df,0x00000000}},	//   _mian_, cimé, _utsl,
  { {0x660d0009,0xb5fb000f,0x6e2b3065,0x00000000}},	//   _mwak, ováb, rugb,
  { {0x6fca027d,0x6e2b00a4,0x55780047,0x00000000}},	//   kých, sugb, ועגן_,
  { {0x7c84005e,0xef190051,0x2d874424,0x00000000}},	//   ђује, _boże_, skne_,
  { {0xa5bb04a6,0x7bdb00fe,0x0dcb005e,0x00000000}},	//   tról, rmuu, _дужи_,
  { {0x2dd4257e,0xaa850080,0x7bdb0659,0x00000000}},	//   _ажур, jvýš, smuu,
  { {0x660d0b7a,0x7bc912fe,0x1869032d,0x00000000}},	//   _awak, pleu, чани_,
  { {0x29180026,0xe1ff00cd,0x7bc00764,0x00000000}},	//   órar_, _otó_, comu,
  { {0x29c2007a,0x394c1233,0x27e94425,0x00000000}},	//   rðar_, beds_, _dian_,
  { {0xdb00086f,0xc5d5046e,0x6b894426,0x00000000}},	//   anmä, вісь, lkeg,
  { {0xf8c60235,0x98be0006,0xdb000066,0x00000000}},	//   _रुपय, tetą_, pomô,
  { {0x27e9001b,0x69c14427,0x6b892e58,0x00000000}},	//   _gian_, lole, nkeg,
  { {0xe29a0002,0x69c14428,0x63a44429,0x00000000}},	// [7ea0] чаа_, oole, riin,
  { {0x63bb06bb,0xdb000164,0x7bc00035,0x00000000}},	//   čuna, rimé, zomu,
  { {0x660d006f,0x7bc00035,0xb5fb0331,0x00000000}},	//   _zwak, yomu, rváe,
  { {0xd00f01fb,0x27e9442a,0x69c1442b,0x00000000}},	//   صله_, _xian_, hole,
  { {0x649300eb,0x63a80080,0x7bc00072,0x00000000}},	//   ržiū, édnu, vomu,
  { {0x361b009d,0x00000000,0x00000000,0x00000000}},	//   לונד,   ,   ,
  { {0x69c1442c,0x7bc0442d,0xcbe60cb2,0x00000000}},	//   dole, tomu, нции,
  { {0x69c1002b,0xa3d00042,0xaa850566,0x00000000}},	//   eole, षति_, zvýš,
  { {0x394c0146,0x7fd700b5,0x69c1442e,0x00000000}},	//   teds_, _טולס_, fole,
  { {0x6b8900a8,0xd91a0121,0x7c961f1d,0x00000000}},	//   akeg, чьи_, _прец,
  { {0x27e900fe,0x660d0917,0xa3d00053,0x00000000}},	//   _pian_, _swak, षता_,
  { {0x60da00ea,0x6d5a442f,0x61be0042,0x00000000}},	//   _útmu, _hata, ्तुष,
  { {0xdb0000c7,0x6d5a4430,0x69c14431,0x00000000}},	//   rnmä, _kata, bole,
  { {0xdca60032,0x9f4a0290,0x6d5a4432,0x00000000}},	//   لى_, _subì_, _jata,
  { {0x6d5a43c8,0x657e00ac,0xf3f1008b,0x00000000}},	//   _mata, _doph, ệ_,
  { {0x660d0035,0x6d5a4433,0xe6950021,0x00000000}},	//   _twak, _lata, _للبد,
  { {0x660d0035,0xe1f301fb,0xa2940054,0x00000000}},	// [7eb0] _uwak, اسر_, гаті,
  { {0x6d5a4434,0x6b8900c2,0xe1ff0022,0x00000000}},	//   _nata, zkeg, _prób_,
  { {0x2bac0080,0xc3b50062,0x4427008d,0x00000000}},	//   pěch_, _айнщ, _ín_,
  { {0xa0c40021,0x141a0063,0x69c14435,0x00000000}},	//   ديمو, _קורב, zole,
  { {0x69c10035,0x6d5a4436,0x69d8004b,0x00000000}},	//   yole, _bata, _ohve,
  { {0xa6db0026,0x69d801e1,0xdca54437,0x00000000}},	//   leðs, _nhve, кали,
  { {0xe73f0004,0x69c10114,0x21640a36,0x00000000}},	//   lnõu_, vole, _стяг,
  { {0x69c10051,0x6d5a4438,0x69d80656,0x00000000}},	//   wole, _eata, _ahve,
  { {0x6d5a4439,0x69c1443a,0x6b8902c0,0x00000000}},	//   _fata, tole, rkeg,
  { {0xd9450001,0x6b89443b,0x69c100fe,0x00000000}},	//   њени, skeg, uole,
  { {0x69c1443c,0xd8250062,0xe72a443d,0x00000000}},	//   role, ъдни, монд_,
  { {0x7dcd0024,0x69c1010e,0xf0ee0053,0x00000000}},	//   kúsk, sole, _जल्द_,
  { {0x98b101f7,0x6d5a0b88,0xb9b50062,0x00000000}},	//   ızı_, _yata, _искъ,
  { {0x9f4a18fb,0x6845443e,0x7afb1950,0x00000000}},	//   _rubí_, _анка, lcut,
  { {0x69ca0161,0x98be0006,0x9835000d,0x00000000}},	//   _सीटी, ketę_, _рэлі,
  { {0xc323140f,0x9c8201d1,0xd6b60044,0x00000000}},	//   имск, účin, _لإخب,
  { {0xf506011c,0xcb120e2a,0x657e443f,0x00000000}},	// [7ec0] _изпо, ילן_, _toph,
  { {0x3cf00161,0x45d3007b,0x41030f59,0x00000000}},	//   _चलें_, _коњс, изув,
  { {0x98bc0078,0xf1c20078,0x6d5a4440,0x00000000}},	//   _davė_, _rašą_, _rata,
  { {0x287a0047,0x2d81004d,0x637801a8,0x00000000}},	//   ונעמ, öhen_, _nínx,
  { {0x6d5a4441,0x8e37014d,0xc33300ff,0x00000000}},	//   _pata, نسور_, _דור_,
  { {0x0dc70062,0x569b0047,0xf6530063,0x00000000}},	//   кущи_, וינצ, יצד_,
  { {0x6d5a005b,0xe8d90013,0x71a301ce,0x00000000}},	//   _vata, _đở_, _тарз,
  { {0x6d5a383a,0x6fd8017d,0x7b630121,0x00000000}},	//   _wata, fíce, атье,
  { {0x6d5a18ab,0x4e0b0042,0x3a730062,0x00000000}},	//   _tata, सीआई_, илър,
  { {0x1974000d,0x442a00c2,0x49741577,0x00000000}},	//   угоў, krb_, улос,
  { {0x7d184442,0xdcf8004c,0xdb4f3958,0x00000000}},	//   mavs, zkvě, _кю_,
  { {0x7d184443,0xab5d0022,0x7ac60896,0x00000000}},	//   lavs, rożc, _исле,
  { {0x95cb0079,0x07a40088,0x38c8005d,0x00000000}},	//   дува_, раўн, باکی_,
  { {0x7d183741,0x98be0022,0x8a17009a,0x00000000}},	//   navs, zetę_, _יחדו_,
  { {0x43950054,0x4992007e,0x2a6601c8,0x00000000}},	//   гавс, _میکر, _hrob_,
  { {0x63bb01a6,0x7d181c38,0x28490047,0x00000000}},	//   čuno, havs, _נעפּ,
  { {0x61d90be6,0x9f440139,0x442a0139,0x00000000}},	// [7ed0] емая_, _cimí_, arb_,
  { {0xdb000114,0x661d0196,0x315900f2,0x00000000}},	//   dimí, mssk, علاج_,
  { {0x661d4444,0xdef10021,0x7f42006c,0x00000000}},	//   lssk, مًا_, ffoq,
  { {0x4431005b,0xdcfa004c,0xdb1b0014,0x00000000}},	//   muz_, _dotč, sluú,
  { {0x661d2f75,0xdb000025,0x7afb005b,0x00000000}},	//   nssk, gimí, vcut,
  { {0xaac60053,0xbbcb0042,0x6fd8004c,0x00000000}},	//   _लड़क, ात्क, více,
  { {0x443101f7,0x00000000,0x00000000,0x00000000}},	//   nuz_,   ,   ,
  { {0x661d0b0c,0xddc20022,0x3869011b,0x00000000}},	//   kssk, owoś, _čar_,
  { {0x99150304,0x7afb4445,0xe8d90013,0x00000000}},	//   льні, rcut, _đố_,
  { {0x7dcd0024,0x7afb4446,0x661d3451,0x00000000}},	//   kúsi, scut, dssk,
  { {0x5fb70053,0x3cf00240,0xa7aa02b6,0x00000000}},	//   _अदाल, ňové_, екна_,
  { {0x44314447,0xddc90066,0x6f190051,0x00000000}},	//   duz_, _speň, nawc,
  { {0x63bb085a,0x661d0f8c,0xca080054,0x00000000}},	//   čunl, gssk, _аніж_,
  { {0x395c0137,0x44311c8a,0x2bcb0053,0x00000000}},	//   _gavs_, fuz_, ातका,
  { {0x28020080,0x5fb30042,0x18660094,0x00000000}},	//   ěrné_, ंचाल, _бащи_,
  { {0x2b5f003b,0xf3e64448,0xe73a01ce,0x00000000}},	//   nduc_, ужбо, _џеп_,
  { {0xe297011c,0x6f190045,0xb5fb4449,0x00000000}},	// [7ee0] гат_, dawc, lván,
  { {0x6604444a,0xdcfa007d,0x4431444b,0x00000000}},	//   _itik, _potč, buz_,
  { {0x80a6005d,0x600a0094,0x1139030b,0x00000000}},	//   دمان, хнем_, ъяты_,
  { {0xdb00444c,0x6d430026,0x7c3c004b,0x00000000}},	//   timí, efna, _ärri,
  { {0xde582049,0x7d18444d,0x997c0023,0x00000000}},	//   талі_, tavs, _rāžu_,
  { {0xa3be0053,0x2b910066,0x2b5f006c,0x00000000}},	//   ेतक_, _ráca_, educ_,
  { {0x6724007d,0xac94000d,0x7d18403f,0x00000000}},	//   _odij, райш, ravs,
  { {0x224000e3,0xdb001262,0x661d00d1,0x00000000}},	//   otik_, nnmø, yssk,
  { {0x2240014f,0x61ee1c80,0x7d1800a8,0x00000000}},	//   ntik_, _kibl, pavs,
  { {0x6e930032,0x44313267,0x32570063,0x00000000}},	//   _الكا, yuz_, נסים_,
  { {0xeaaf007e,0x6d480150,0xab5d0022,0x00000000}},	//   قعی_, _ibda, możn,
  { {0x2240223f,0x9cd70063,0x661d444e,0x00000000}},	//   ktik_, _גובה_, tssk,
  { {0x395c444f,0xc6a739c9,0x2240009c,0x00000000}},	//   _tavs_, урни, jtik_,
  { {0x2fc60122,0xe1ff0025,0x6b824450,0x00000000}},	//   hoog_, _brón_, _hoog,
  { {0xdb09017d,0x66042165,0xc4280121,0x00000000}},	//   lneá, _etik, люте_,
  { {0x443101f7,0x69d80235,0x6b82112c,0x00000000}},	//   ruz_, _नीती, _joog,
  { {0xc1150001,0x248d001c,0xdb090025,0x00000000}},	// [7ef0] имај, ņem_, nneá,
  { {0x61ee0164,0x672400c2,0x6b824451,0x00000000}},	//   _cibl, _zdij, _loog,
  { {0x84670062,0x2360006f,0x22400cc6,0x00000000}},	//   _съпе, bdij_, atik_,
  { {0x6d4800f3,0x28370047,0x547a009f,0x00000000}},	//   _abda, רנאך_, _סטרו,
  { {0xb5fb2f42,0x6f190022,0xb2870085,0x00000000}},	//   zván, rawc, _сынк,
  { {0x320900bb,0x7c650021,0x6d43004d,0x00000000}},	//   mpay_, لاعل, ufna,
  { {0xdca203d1,0x6d430026,0x91ba0063,0x00000000}},	//   жащи, rfna, _ימשי,
  { {0x44210093,0xdb09006f,0xba750021,0x00000000}},	//   _mvh_, mieë, لاخت,
  { {0x49990086,0x7f840021,0x32094452,0x00000000}},	//   втня_, _القن, npay_,
  { {0x66044453,0xb5fb013d,0xa9a54454,0x00000000}},	//   _rtik, tván, риод,
  { {0xe8d9001b,0x3a3f38e6,0x66044455,0x00000000}},	//   _đồ_, stup_, _stik,
  { {0x6b824456,0x7e694457,0x66e605ef,0x00000000}},	//   _goog, _krep, иона,
  { {0x24f6005e,0x96b917e2,0x28d10082,0x00000000}},	//   ичвр, гуру_, _हरकि,
  { {0xceb201f9,0x6b82006f,0xdce1001c,0x00000000}},	//   קים_, _zoog, _nolī,
  { {0x443e0164,0xb5fb00ea,0xdb0000be,0x00000000}},	//   ît_, lvál, limá,
  { {0x25aa001f,0x2240005b,0xdb09006f,0x00000000}},	//   sibl_, ttik_, dieë,
  { {0x79830045,0x57250032,0xb5fb29c7,0x00000000}},	// [7f00] _konw, _طريق, nvál,
  { {0xb5fb00ea,0xdb090104,0x645a0014,0x00000000}},	//   ivál, fieë, ætis,
  { {0xef1a0079,0xb5fb0512,0xdb09006f,0x00000000}},	//   вме_, hvál, gieë,
  { {0x7f460086,0xe1ff0051,0x9e664458,0x00000000}},	//   редж, _król_, ивед,
  { {0x5de62ab5,0x1ec72e2f,0x2fc6085b,0x00000000}},	//   ажда, алци_, roog_,
  { {0x7e694459,0x6b8200ac,0xdb09006f,0x00000000}},	//   _drep, _soog, bieë,
  { {0x20b90055,0xdb090240,0x2fc600f5,0x00000000}},	//   _быть_, šnýc, poog_,
  { {0x4f9600d7,0x63b60050,0xdcfa0023,0x00000000}},	//   _тргу, nnyn, _dotā,
  { {0xb5fb000f,0xcb670540,0x3a2d02fb,0x00000000}},	//   gvál, рање_, grep_,
  { {0x7983035a,0x3a09005d,0xdca6406e,0x00000000}},	//   _conw, اکنی_, _кази,
  { {0xdddb008f,0xd0f70063,0x3f84445a,0x00000000}},	//   _bruņ, ימית_, _komu_,
  { {0x3f840023,0xdc3b009a,0xf8af00de,0x00000000}},	//   _jomu_, _יעבר, بةً_,
  { {0xa5bb0022,0xdb000195,0x9634014b,0x00000000}},	//   krót, cimá, оняц,
  { {0xdb0900b9,0xd5b801d5,0x7983002b,0x00000000}},	//   gneæ, асс_, _gonw,
  { {0x69c8445b,0xd5b8005a,0xb97b0aeb,0x00000000}},	//   mode, рся_, _בנגי,
  { {0xdce1003d,0xa2f5000d,0x22590121,0x00000000}},	//   _solī, спач, либы_,
  { {0x764d028d,0x6754007e,0xb7dc0063,0x00000000}},	// [7f10] _upay, _ذخير, _בקהי,
  { {0x69c700c2,0x9174000d,0x69c8445c,0x00000000}},	//   čjeg, огуц, node,
  { {0x644100cd,0xc1e80121,0xdb00445d,0x00000000}},	//   àlid, рьте_, zimá,
  { {0xdb0902b0,0xe4560047,0x7e69445e,0x00000000}},	//   rieë, _פירט_, _prep,
  { {0x6db20045,0xd37a00b5,0xdb000512,0x00000000}},	//   kład, _ערשט, ximá,
  { {0xfd470088,0xdb090250,0x63ad445f,0x00000000}},	//   рэдн, pieë, lian,
  { {0x40950032,0x7dcd13a3,0x3f840035,0x00000000}},	//   _الأر, dúst, _fomu_,
  { {0x8f340088,0xb5fb00ea,0xa3d70053,0x00000000}},	//   _месц, tvál, िति_,
  { {0x69c80e4c,0x628d01a8,0x63ad4460,0x00000000}},	//   fode, nyao, iian,
  { {0x69c84461,0x7dcd017d,0x63ad4462,0x00000000}},	//   gode, gúst, hian,
  { {0x6ca70138,0xa3d70053,0x63ad4463,0x00000000}},	//   _траж, िता_, kian,
  { {0x2d850b7a,0x63ad0ebe,0x66000195,0x00000000}},	//   _hole_, jian, ímko,
  { {0xe8d9008b,0x69c84464,0xdb0901a8,0x00000000}},	//   _đổ_, bode, eneç,
  { {0x799a3848,0x69c8190f,0xf8a8005d,0x00000000}},	//   chtw, code, ادیه_,
  { {0xdcfa000c,0x63ad4465,0x232a17f5,0x00000000}},	//   _hotă, fian, лови_,
  { {0x96960726,0xa4570058,0x63ad4466,0x00000000}},	//   _грош, şağı_, gian,
  { {0x2d85030c,0x63b64467,0x6906013d,0x00000000}},	// [7f20] _oole_, rnyn, _érdé,
  { {0x42230086,0xe2b5000d,0x667b0047,0x00000000}},	//   ядув, істэ, _עטיק,
  { {0x27e0055f,0x7dcd0046,0x98a70075,0x00000000}},	//   _khin_, húss, _kanı_,
  { {0x645e4468,0x5e260021,0x69c84469,0x00000000}},	//   _ispi, معتق, zode,
  { {0xdfcf00b3,0x6b9b05a5,0x59c70042,0x00000000}},	//   ريه_, dhug, रकार,
  { {0x2d85446a,0xbbb20082,0x00000000,0x00000000}},	//   _cole_, ुक्क,   ,
  { {0x3f840114,0xb60600c2,0x0ba60121,0x00000000}},	//   _tomu_, lašč, йшим,
  { {0x69c80022,0x6db20022,0xdd040058,0x00000000}},	//   wode, wład, ğrıy,
  { {0x69c8446b,0xb99808ac,0x645e28ac,0x00000000}},	//   tode, ивих_, _lspi,
  { {0x645e446c,0x63ad446d,0x63bb01b3,0x00000000}},	//   _ospi, zian, čuni,
  { {0x69c80c04,0x317b0047,0x6fd83d3e,0x00000000}},	//   rode, ארימ, níco,
  { {0x69c80709,0x7d1a446e,0x6b9b0331,0x00000000}},	//   sode, _hets, chug,
  { {0x98b8005b,0xa5f90076,0x645e26c5,0x00000000}},	//   ırı_, регу_, _aspi,
  { {0x63ad0051,0x6f02446f,0xe894142a,0x00000000}},	//   wian, hcoc, _маль,
  { {0x7d1a4470,0xdb0005b9,0x63ad4471,0x00000000}},	//   _mets, rimæ, tian,
  { {0xdb090016,0x5215042c,0x7d1a4472,0x00000000}},	//   rneç, ждат, _lets,
  { {0x645e0e57,0xb60600c2,0xdb000656,0x00000000}},	// [7f30] _espi, gašč, mimä,
  { {0x63ad21ca,0x7d1a4473,0x291e4474,0x00000000}},	//   sian, _nets, nata_,
  { {0x66160051,0x63ad1ef2,0x2d854475,0x00000000}},	//   _zwyk, pian, _role_,
  { {0xdcee0080,0x2d85055b,0xf7740047,0x00000000}},	//   žděn, _sole_, ּקס_,
  { {0x28cf0161,0xdce800eb,0x2d854476,0x00000000}},	//   _सुनि, _kodė, _pole_,
  { {0xdb000019,0x7d1a0c5f,0x291e4477,0x00000000}},	//   himä, _cets, jata_,
  { {0xef190045,0x2fdf0025,0x6b9b0026,0x00000000}},	//   _też_, _thug_, thug,
  { {0xd4980063,0x6db20022,0x3b0901ce,0x00000000}},	//   מכות_, głab, јепо_,
  { {0x291e4478,0x2d85163f,0x7d1a0137,0x00000000}},	//   fata_, _tole_, _fets,
  { {0xc9a90076,0x291e4479,0x27e0057a,0x00000000}},	//   рвое_, gata_, _shin_,
  { {0xb9010161,0xb60600c2,0x9f4b0139,0x00000000}},	//   _दर_, zašč, _ómós_,
  { {0xe73a447a,0x291e0ff2,0x7d1a0130,0x00000000}},	//   шем_, aata_, _zets,
  { {0x44310051,0x291e447b,0x6f1b447c,0x00000000}},	//   erz_, bata_, _meuc,
  { {0x291e292a,0xb60600c3,0x29010019,0x00000000}},	//   cata_, vašč, _üha_,
  { {0x27e00034,0xe8d9008b,0x98a70058,0x00000000}},	//   _thin_, _đỗ_, _tanı_,
  { {0x130a000d,0x6f1b447d,0xb60600a8,0x00000000}},	//   рнай_, _neuc, tašč,
  { {0xd5e4001b,0x4226005a,0x645e0051,0x00000000}},	// [7f40] _trì, юдав, _wspi,
  { {0xa50a0001,0xb60643a4,0x644100cd,0x00000000}},	//   _њена_, rašč, àlic,
  { {0x645e017f,0x20b9000d,0xa0670062,0x00000000}},	//   _uspi, быць_, жаха_,
  { {0x44382b9d,0x3cef0053,0x7d1a447e,0x00000000}},	//   mur_, ेखने_, _sets,
  { {0x7d1a00bb,0x4438447f,0x291e2bc2,0x00000000}},	//   _pets, lur_, yata_,
  { {0x44384480,0xdb02004d,0x200700cd,0x00000000}},	//   our_, _bloß, ínic_,
  { {0x44384481,0x291e4482,0x6f1b4483,0x00000000}},	//   nur_, vata_, _feuc,
  { {0x9b6a000a,0x77640268,0x60970021,0x00000000}},	//   ршка_, _naix, _بنفس_,
  { {0x7d1a00ea,0x44384484,0x291e4485,0x00000000}},	//   _tets, hur_, tata_,
  { {0x4438447f,0x291e0035,0x2b910013,0x00000000}},	//   kur_, uata_, _lách_,
  { {0x26180161,0x7764302e,0x291e3bf7,0x00000000}},	//   बीसी_, _baix, rata_,
  { {0x77644486,0x291e4487,0x645c001f,0x00000000}},	//   _caix, sata_, dwri,
  { {0x291e4488,0x44384489,0x9f580003,0x00000000}},	//   pata_, eur_, _curé_,
  { {0x6d580004,0x4438448a,0x95cb08a7,0x00000000}},	//   neva, fur_, рума_,
  { {0x77640016,0x6fd800cd,0xd7950062,0x00000000}},	//   _faix, tícl, _никъ,
  { {0x2b91001b,0x6d58448b,0x442304aa,0x00000000}},	//   _cách_, heva, rsj_,
  { {0xdce800eb,0x44441bb2,0xdb11000f,0x00000000}},	// [7f50] _todė, _eq_, áfér,
  { {0x4438014f,0x6d5801a6,0x306b0001,0x00000000}},	//   bur_, jeva, ијен_,
  { {0x291c0268,0x8f75000d,0x44381121,0x00000000}},	//   _meva_, зулі, cur_,
  { {0x291c448c,0x6d4a0014,0x6d58004b,0x00000000}},	//   _leva_, effa, eeva,
  { {0x644700e8,0xee38013c,0x6d4a004d,0x00000000}},	//   ltji, жні_, fffa,
  { {0x2dcb0001,0x8d620121,0xdd94000d,0x00000000}},	//   шћен_, евше, мачы,
  { {0x644700e8,0xd838027c,0xeb910021,0x00000000}},	//   ntji, juč_, فظة_,
  { {0x61fd0acd,0x6d58004b,0x2b910013,0x00000000}},	//   _kusl, aeva, _xách_,
  { {0x6d5803cd,0x7c380003,0x4438448d,0x00000000}},	//   beva, auvr, zur_,
  { {0x291c000c,0x39790076,0x39450928,0x00000000}},	//   _ceva_, ссию_, чног,
  { {0x77641908,0x48b5005a,0xa5bb0014,0x00000000}},	//   _paix, ящит, vróp,
  { {0xf0920047,0xb69b000c,0x6db20051,0x00000000}},	//   גנט_, rcân, płac,
  { {0x44440034,0xa5bb448e,0x77640268,0x00000000}},	//   _sq_, rsón, _vaix,
  { {0x2b91001b,0x4438160e,0xa5bb18a8,0x00000000}},	//   _sách_, tur_, uróp,
  { {0x61fd00bd,0x4438448f,0x76463d30,0x00000000}},	//   _ausl, uur_, stky,
  { {0x9f4600e8,0x61f5001c,0x44384490,0x00000000}},	//   rmoë_, _aizl, rur_,
  { {0xa5bb017d,0xc73b0063,0x44384491,0x00000000}},	// [7f60] próp, _התפת, sur_,
  { {0x4444008b,0x44384492,0x20180150,0x00000000}},	//   _tq_, pur_, _pwri_,
  { {0x6d584493,0x2b91008b,0x6e39006f,0x00000000}},	//   veva, _tách_, euwb,
  { {0x20074494,0x6d414495,0xd47b0aeb,0x00000000}},	//   ínia_, _acla, _האטל,
  { {0x6fd80024,0xf1bf02fc,0x6d584496,0x00000000}},	//   líck, _iván_, teva,
  { {0x61f501f7,0x6d58006d,0x51550edd,0x00000000}},	//   _gizl, ueva, _отсу,
  { {0x6d4a1f36,0x6fd80066,0x291c00e5,0x00000000}},	//   rffa, níck, _reva_,
  { {0x291c4497,0x7bc40006,0x6d414498,0x00000000}},	//   _seva_, čiuo, _ecla,
  { {0x8d1a006a,0xaa530076,0xbc6a007e,0x00000000}},	//   _هزار_, евыш, _گمان_,
  { {0x644700ac,0x6d410025,0xd90d007e,0x00000000}},	//   ytji, _gcla, لیه_,
  { {0x07350086,0xdce80023,0xaab70043,0x00000000}},	//   меню, _modī, قدیر_,
  { {0x29070014,0x7ceb009a,0x48a701eb,0x00000000}},	//   _efna_, _הַדֶ, ятым_,
  { {0x291c0994,0x645a005b,0xe1ff0013,0x00000000}},	//   _teva_, çtin, _trói_,
  { {0x24670080,0x61fd4499,0x24910022,0x00000000}},	//   jímá_, _rusl, tyzm_,
  { {0x644700ac,0x58d3060c,0x98be008f,0x00000000}},	//   utji, _пошт, retē_,
  { {0x61fd0812,0x644700e8,0x656530c7,0x00000000}},	//   _pusl, rtji, _wahh,
  { {0xdd310078,0x6808004c,0x644700a8,0x00000000}},	// [7f70] _lęši, _děde, stji,
  { {0x660d26b2,0xd1310021,0x316b005e,0x00000000}},	//   _itak, ئما_, љшао_,
  { {0xf99300b5,0xe2f90086,0x672d00c2,0x00000000}},	//   ערע_, _мені_, _kdaj,
  { {0x2905006d,0x63bb082a,0x9ed9018e,0x00000000}},	//   zcla_, čuns, омет_,
  { {0xdef8000d,0x8d74007e,0x926b06da,0x00000000}},	//   чых_, کانا, _урна_,
  { {0xddc90051,0x660d0035,0xdce8008f,0x00000000}},	//   _speł, _mtak, _godī,
  { {0x2249449a,0x672d1f9e,0x23691ef9,0x00000000}},	//   ltak_, _odaj, odaj_,
  { {0xdfd10032,0x2369449b,0x660d449c,0x00000000}},	//   _شيء_, ndaj_, _otak,
  { {0x2249449d,0xd959000d,0x9dab0062,0x00000000}},	//   ntak_, ошні_, _лъжа_,
  { {0x2fcf02f0,0x6d41007d,0x48051b5f,0x00000000}},	//   logg_, _ucla, мпов,
  { {0x236900c2,0xa3bf0053,0x660d449e,0x00000000}},	//   kdaj_, ेवा_, _atak,
  { {0x2249449f,0x2905021a,0xbc380049,0x00000000}},	//   ktak_, scla_, _رسما_,
  { {0xd9450138,0xa50a005e,0x41bf0053,0x00000000}},	//   _жели, жега_, ्वास,
  { {0x224944a0,0xe1ff0045,0x236900c2,0x00000000}},	//   dtak_, _osób_, edaj_,
  { {0x22490150,0x660d44a1,0x6db20022,0x00000000}},	//   etak_, _etak, kłan,
  { {0xd8d60047,0xdce8008f,0x6b8b44a2,0x00000000}},	//   _קוקט_, _sodī, _jogg,
  { {0x68080080,0x9695000d,0x6fd80195,0x00000000}},	// [7f80] _věde, _зрэш, síck,
  { {0x6b8b0070,0x6fd8017d,0x6f0944a3,0x00000000}},	//   _logg, míci, _afec,
  { {0x6fd844a4,0x224944a5,0xdce10078,0x00000000}},	//   líci, atak_, _balč,
  { {0x6b8b00c7,0xb5fb00be,0xf4130063,0x00000000}},	//   _nogg, rváv, _שפר_,
  { {0x6fd844a6,0x5e5a0021,0x6da613a2,0x00000000}},	//   níci, تجاج_, мида,
  { {0x6db20045,0x6f0944a7,0x205600a0,0x00000000}},	//   ałan, _efec, _отбр,
  { {0x798a00ac,0x6ca30062,0x6f090003,0x00000000}},	//   _rofw, кръж, _ffec,
  { {0x2d81004d,0x2bac0022,0x6b8b0168,0x00000000}},	//   öher_, ości_, _cogg,
  { {0x6b8b44a8,0xfe4304c3,0xc333009a,0x00000000}},	//   _dogg, _инто, דוח_,
  { {0xb33b005b,0xc27b009f,0x6fd844a9,0x00000000}},	//   _ilçe, קריי, díci,
  { {0xe8df001b,0x313703c3,0x01370063,0x00000000}},	//   _thời_, ונים_, ורית_,
  { {0x2d8c00d1,0x6fd800c5,0x6b8b44aa,0x00000000}},	//   _hode_, fíci, _gogg,
  { {0x4ae20161,0x2d8c0f98,0xa6db0014,0x00000000}},	//   _परिव, _kode_, yfðu,
  { {0x2d8c00e8,0x28cf0161,0xa5bb0026,0x00000000}},	//   _jode_, _सुवि, msók,
  { {0xa4d40086,0x2d8c02a0,0x6db20022,0x00000000}},	//   ворі, _mode_, yłan,
  { {0x224944ab,0x69da44ac,0x2d8c44ad,0x00000000}},	//   ttak_, llte, _lode_,
  { {0xa3ab0161,0x45d5184a,0x660d10d2,0x00000000}},	// [7f90] कोष_, _поис, _utak,
  { {0x20070016,0x3ea6001c,0xe5e700f2,0x00000000}},	//   ínio_, dzot_, _تثبي,
  { {0x55760047,0x99840078,0x95830078,0x00000000}},	//   _װערן_, lumų_, žąsi,
  { {0x2d9e2d64,0x69da00bd,0x671f0042,0x00000000}},	//   _alte_, hlte, परिक_,
  { {0x1d090169,0x2d8c44ae,0x6b8b44af,0x00000000}},	//   пели_, _bode_, _rogg,
  { {0x7bc203b2,0x6b8b051e,0x6db20045,0x00000000}},	//   _ajou, _sogg, słan,
  { {0x2d8c006f,0x6fd818a8,0x6b8b24ab,0x00000000}},	//   _dode_, zíci, _pogg,
  { {0x69da24fd,0x99d5005d,0xea890363,0x00000000}},	//   elte, کتبا, збил_,
  { {0xddc9003b,0x3e350049,0x6e99030b,0x00000000}},	//   _creţ, _سفار, _эвар_,
  { {0x2d8c04b1,0xdd150044,0xe8850456,0x00000000}},	//   _gode_, _أواخ, егоп,
  { {0x2bcc0053,0xf74644b0,0x6b8b44b1,0x00000000}},	//   ावशा, нено, _togg,
  { {0x6fd813ff,0x2d8702e2,0x2bac0051,0x00000000}},	//   tíci, ljne_, yści_,
  { {0x98be0006,0xf6d50086,0x99840078,0x00000000}},	//   ketė_, віря, gumų_,
  { {0x6fd844b2,0x8a160002,0xb5fb013d,0x00000000}},	//   ríci, _џојс_, evás,
  { {0x64a60088,0x68080080,0x2d87006f,0x00000000}},	//   хава, _vědc, ijne_,
  { {0x86460086,0x6fd8017d,0x420a005e,0x00000000}},	//   _зниж, píci, знао_,
  { {0x211a0021,0x52aa0062,0x5a0c0047,0x00000000}},	// [7fa0] كتاب_, чвам_, ַלאַ,
  { {0x3f5a008d,0x2bac0022,0xb5fb44b3,0x00000000}},	//   _ẫu_, rści_, rvát,
  { {0xe8df008b,0x2d8c0625,0x3f8600ac,0x00000000}},	//   _khối_, _rode_, tjou_,
  { {0x6db20051,0x672644b4,0x03a62ba3,0x00000000}},	//   ałal, nakj, _чимо,
  { {0x2d8c03d9,0x76410006,0x69da08a9,0x00000000}},	//   _pode_, ąlyg, ylte,
  { {0x63b644b5,0x63a444b6,0x3ea644b7,0x00000000}},	//   liyn, lhin, rzot_,
  { {0x71d70063,0x2d8c04d9,0x3fc8005d,0x00000000}},	//   _נולד_, _vode_, _قدری_,
  { {0xddc9000c,0x69da00bd,0x63a439eb,0x00000000}},	//   _preţ, wlte, nhin,
  { {0x2d8c00bd,0x67260150,0x63a4058e,0x00000000}},	//   _tode_, dakj, ihin,
  { {0xddc9000c,0x442a0089,0xd9170121,0x00000000}},	//   _vreţ, ksb_, нью_,
  { {0x63a444b8,0xb5fb009c,0x610f009c,0x00000000}},	//   khin, jvár, lőlü,
  { {0xe8df008b,0x7c2a44b9,0x9984005f,0x00000000}},	//   _chối_, msfr, tumų_,
  { {0x63a40035,0xd6db247b,0x7c2a44ba,0x00000000}},	//   dhin, ято_, lsfr,
  { {0xa6db0026,0x63a40214,0x99840078,0x00000000}},	//   ggða, ehin, rumų_,
  { {0x6fd802dd,0xa96700e1,0xa3bf0053,0x00000000}},	//   lícu, _чија_, ेवल_,
  { {0xa3ab0161,0x7bc00031,0x7c330240,0x00000000}},	//   कों_, nnmu, _údrž,
  { {0x44380025,0x2d870051,0x8b570047,0x00000000}},	// [7fb0] arr_, yjne_, עימס_,
  { {0x63a4002c,0x395e44bb,0x6027009c,0x00000000}},	//   ahin, nets_, _némá,
  { {0x6fd802dd,0x8144007e,0x63a425be,0x00000000}},	//   hícu, انمن, bhin,
  { {0x2a660080,0x7c2a3385,0x395e1ecb,0x00000000}},	//   _osob_, dsfr, hets_,
  { {0x8e080086,0x9f5800cd,0xaf04000d,0x00000000}},	//   енів_, _durà_, упіл,
  { {0x395e0164,0x200e00cd,0x6fd83543,0x00000000}},	//   jets_, ífic_, dícu,
  { {0x395e314f,0x6fd8017d,0x7c2a3a1c,0x00000000}},	//   dets_, eícu, gsfr,
  { {0x27e90013,0x69c700c2,0x7d26008f,0x00000000}},	//   _nhan_, čjem, _ārsū,
  { {0x395e2986,0x8afd004c,0x2fdd002b,0x00000000}},	//   fets_, ndři, mlwg_,
  { {0x7bdb007a,0x7bc000fe,0x395e2f5a,0x00000000}},	//   sluu, anmu, gets_,
  { {0xddc9017f,0xe8df008b,0x07a624f2,0x00000000}},	//   _greš, _phối_, ванн,
  { {0x27e944bc,0x29180026,0x00f60063,0x00000000}},	//   _chan_, ðrar_, כמתך_,
  { {0x1663005a,0x9f46004d,0x6d4300ea,0x00000000}},	//   авям, hloß_, ogna,
  { {0x6d4300bb,0x26060016,0x2b5f01a8,0x00000000}},	//   ngna, _vôo_, leuc_,
  { {0xb5fb0024,0x63a444bd,0x6d4344be,0x00000000}},	//   tvár, thin, igna,
  { {0x6b8900c3,0x6fd80024,0x04430001,0x00000000}},	//   njeg, níct, јетн,
  { {0x63a40f4a,0xb5fb013d,0xb146019c,0x00000000}},	// [7fc0] rhin, rvár, кнал,
  { {0x69c144bf,0xd5af0032,0x63b60185,0x00000000}},	//   nnle, _وفي_, siyn,
  { {0x657e0025,0xcf8f00e1,0x69c144c0,0x00000000}},	//   _inph, ај_, inle,
  { {0x66040035,0x6d4344c1,0xd00f0049,0x00000000}},	//   _kuik, egna, زله_,
  { {0x9f580139,0x672444c2,0xfe430e5e,0x00000000}},	//   _stró_, _meij, инцо,
  { {0x6d4300c7,0xde930001,0xdd8f0067,0x00000000}},	//   ggna, рашњ, يون_,
  { {0x75e000ea,0x660400ca,0x644e44c3,0x00000000}},	//   vözl, _luik, ntbi,
  { {0x6fd80814,0xa5bb0025,0xafe60086,0x00000000}},	//   tícu, rsói, _робл,
  { {0x27e90185,0x6027000f,0x395e44c4,0x00000000}},	//   _rhan_, _témá, tets_,
  { {0xddc944c5,0x69c10026,0x395e00b9,0x00000000}},	//   _treš, gnle, uets_,
  { {0x6b89017f,0x27e90c08,0x395e44c6,0x00000000}},	//   bjeg, _phan_, rets_,
  { {0x6604006f,0x69c11ff4,0x75e00058,0x00000000}},	//   _buik, anle, sözl,
  { {0x395e44c7,0x00000000,0x00000000,0x00000000}},	//   pets_,   ,   ,
  { {0x224000e8,0xe5c40076,0x66041031,0x00000000}},	//   duik_, ассо, _duik,
  { {0x27e903ae,0xd4040245,0xb33b44c8,0x00000000}},	//   _than_, ияти, _alça,
  { {0x20030089,0x61fc4314,0xd8e50085,0x00000000}},	//   _ruji_, _airl, _сціп,
  { {0x61fc01f7,0xe5c744c9,0xd5ed0013,0x00000000}},	// [7fd0] _birl, _асно, _trà,
  { {0x20030360,0xb1140054,0x61bf0042,0x00000000}},	//   _puji_, имуш, ्वेष,
  { {0x6801001c,0x61fc44ca,0x351a0063,0x00000000}},	//   _pēdi, _dirl, _אותנ,
  { {0x6fd40086,0x224000f5,0x61fc002b,0x00000000}},	//   аціє, buik_, _eirl,
  { {0x69c14303,0x61fc3b71,0xdd95066e,0x00000000}},	//   ynle, _firl, лады,
  { {0xdce801f7,0x61fc0969,0xb6da00b5,0x00000000}},	//   _aldı, _girl, ײַנט,
  { {0x6b89366a,0x6f0400c2,0xfd44000d,0x00000000}},	//   tjeg, žica, рэчн,
  { {0xdfd50076,0x2d9c007d,0x9c7c00a8,0x00000000}},	//   _собы, akve_, _izčl,
  { {0x6e20002b,0x672444cb,0x6b8944cc,0x00000000}},	//   _gwmb, _reij, rjeg,
  { {0xef26004b,0x6b8944cd,0x69c10139,0x00000000}},	//   _üüri_, sjeg, unle,
  { {0x6aa900ea,0x660444ce,0x6845000d,0x00000000}},	//   szef, _suik, ынна,
  { {0x66040006,0x6ca4089a,0x9056009a,0x00000000}},	//   _puik, _труж, נברו_,
  { {0xdb0900a5,0x1a65005d,0xd764005d,0x00000000}},	//   rieä, _صیدی_, هنگی,
  { {0x26de001c,0x644e06fb,0x04460bd8,0x00000000}},	//   āto_, ttbi, легн,
  { {0x644e0137,0x64a344cf,0x26180042,0x00000000}},	//   utbi, бара, बीजी_,
  { {0x38780146,0xdcf8004c,0x6604078c,0x00000000}},	//   ærre_, ejvě, _tuik,
  { {0xade30161,0x3a2d0373,0x644e44d0,0x00000000}},	// [7fe0] गतान_, nsep_, stbi,
  { {0x224004c6,0xd5ed008b,0xc566006e,0x00000000}},	//   ruik_, _trá, _скок,
  { {0x94760021,0x7e6936b8,0xa99a0041,0x00000000}},	//   _إدخا, _asep, עבער,
  { {0xdd2f0080,0x8f450054,0xd0070085,0x00000000}},	//   měři, ихід, уеце_,
  { {0x9f4400cd,0x9476007e,0x61fc002b,0x00000000}},	//   _simó_, _شدگا, _tirl,
  { {0x61fc018d,0xdb00004b,0x60dc0072,0x00000000}},	//   _uirl, simü, _tyrm,
  { {0xa5bb44d1,0x2d9c08c4,0x07040042,0x00000000}},	//   msót, rkve_, रखाव_,
  { {0x5a3413ca,0x2d9c04d9,0xab94005e,0x00000000}},	//   анит, skve_, раиљ,
  { {0x6f930021,0xdee32785,0xaec6030b,0x00000000}},	//   _القض, _готи, _сбал,
  { {0x99660888,0x1d19014b,0x1a570044,0x00000000}},	//   утил, _аюць_, اشية_,
  { {0x68080080,0x23bf00fe,0x81570047,0x00000000}},	//   _vědo, näjä_, נסטע_,
  { {0xb8ec0053,0xdb00017d,0x5ba50054,0x00000000}},	//   _रख_, rimó, _кріз,
  { {0x96f8030b,0xba730044,0x0bd30043,0x00000000}},	//   леют_, _هاوت, _اينح,
  { {0xad9d0051,0x2bcc0042,0x8afb009a,0x00000000}},	//   _luźn, ावका, _נהגי,
  { {0xf4842ba3,0x4d7b0041,0x764f00a5,0x00000000}},	//   бутн, ערלע, stcy,
  { {0xc2c50032,0x28490047,0xe8df0013,0x00000000}},	//   ليزي, _סעפּ, _chổi_,
  { {0x8afd004c,0xd13b173e,0x75e0013d,0x00000000}},	// [7ff0] peře, ехе_, közh,
  { {0xf654009d,0x00000000,0x00000000,0x00000000}},	//   _הצץ_,   ,   ,
  { {0x6e3c008f,0x45fa0063,0x3d080042,0x00000000}},	//   _ārba, _שהתג, िखने_,
  { {0x0eb902dc,0x58bb0041,0xe8d7089e,0x00000000}},	//   кулы_, עמאצ, נואר_,
  { {0x623501ce,0xda660044,0x00000000,0x00000000}},	//   _његу, _بُ_,   ,
  { {0xed5944d2,0x7e6900a8,0x51872124,0x00000000}},	//   ток_, _vsep, _сума,
  { {0xfce50002,0x9626008f,0xbb450094,0x00000000}},	//   шоко, _ziņā, аейк,
  { {0x69c600ea,0x6fd80066,0xab62004e,0x00000000}},	//   éken, sícr, üüpi,
  { {0x49c9406e,0x00000000,0x00000000,0x00000000}},	//   клин_,   ,   ,
  { {0x49953e42,0x00000000,0x00000000,0x00000000}},	//   ршит,   ,   ,
  { {0xdd7a00b5,0xdb0000cd,0x38540121,0x00000000}},	//   _שטעל, rimò, бъяс,
  { {0xdd2f0080,0xe9ff0013,0xc5e9089e,0x00000000}},	//   věři, huẩn_, _חד_,
  { {0x959615ce,0xd876005d,0xa3e90082,0x00000000}},	//   ашві, همیت_, यतन_,
  { {0x6907000d,0x7ae60058,0xd94244d3,0x00000000}},	//   _сядз, ükte, _деши,
  { {0x07a6000d,0xe8df0013,0x232a0f55,0x00000000}},	//   _вайн, _phổi_, кови_,
  { {0xda08008b,0x02c60085,0xe4c30054,0x00000000}},	//   _hỏa_, айбо, ійти,

  { {0xe29701aa,0x6db20051,0x99dd01d9,0x00000000}},	// [8000] аат_, cław, stňu,
  { {0x23bf024a,0xdce10051,0x3c2c013d,0x00000000}},	//   täjä_, _zalą, _jóvá_,
  { {0xe8df0013,0x71730021,0x73e62b4f,0x00000000}},	//   _thổi_, تهلا, _вонз,
  { {0xdfcf01a7,0xe29f0014,0xf3ff0013,0x00000000}},	//   ويل_, _afðu_, _giã_,
  { {0x3ea044d4,0xe2300131,0xd337009a,0x00000000}},	//   áit_, атeн_, _דרכה_,
  { {0x6e360006,0xb4e00042,0x6c340044,0x00000000}},	//   šybo, _तरफ़_, مفتا,
  { {0x3ea00080,0xdc87005a,0x4c940076,0x00000000}},	//   šit_, исъл_, сийс,
  { {0xa5bb017d,0xe29f0014,0x201a0050,0x00000000}},	//   nsór, _efðu_, mppi_,
  { {0xe8d9001b,0xa9c639ed,0x2fc6007d,0x00000000}},	//   _đỡ_, исок, mnog_,
  { {0x2fc60117,0x645e3d98,0x98be001c,0x00000000}},	//   lnog_, _oppi, egtā_,
  { {0xab660b3f,0xdb24007e,0xdce10022,0x00000000}},	//   _ввел, _هوای, _palą,
  { {0x2fc6001f,0xcb6a0002,0x22521c6e,0x00000000}},	//   nnog_, _јаде_, ktyk_,
  { {0x645e2f13,0xa5070054,0xf98f005d,0x00000000}},	//   _appi, иявл, سبی_,
  { {0x2b980003,0xddc90066,0x95d80363,0x00000000}},	//   _vécu_, _treť, идят_,
  { {0x6db20051,0x89370063,0x66160051,0x00000000}},	//   sław, _כרגע_, _etyk,
  { {0x248d017f,0x7afd0024,0x2fc6017f,0x00000000}},	//   ćem_, ľstv, jnog_,
  { {0x2fc60117,0x6d5a0034,0x6b820add,0x00000000}},	// [8010] dnog_, _obta, _mnog,
  { {0xd5b80499,0x925844d5,0x11d4012c,0x00000000}},	//   _всю_, рафт_, оієр,
  { {0x6b82017f,0x997d004c,0x2fc644d6,0x00000000}},	//   _onog, zňů_, fnog_,
  { {0xdb0000cd,0xd8b90047,0x02d901fb,0x00000000}},	//   khmà, נצײכ, _موجب_,
  { {0x443100ea,0xdb09004c,0x201a165b,0x00000000}},	//   lsz_, áníc, appi_,
  { {0x69c600ea,0x645e00b9,0x6b82002b,0x00000000}},	//   ékel, _yppi, _anog,
  { {0x2fc6017f,0x4c920001,0xdb0901c2,0x00000000}},	//   bnog_, зијс, šníc,
  { {0xc17e0006,0xdfd4000d,0x2fc6007d,0x00000000}},	//   šėte_, _досы, cnog_,
  { {0x2918005b,0xe9d907b3,0x00000000,0x00000000}},	//   ıran_, лки_,   ,
  { {0xd9450001,0xa9690001,0x317107b9,0x00000000}},	//   љени, ћина_, _jazz_,
  { {0x661644d7,0xa3d70053,0xdb1b3887,0x00000000}},	//   _styk, ाका_, anuá,
  { {0x38780026,0x443100ea,0x6813003b,0x00000000}},	//   ærra_, dsz_, _năde,
  { {0xeab30032,0x9c7c0240,0xda080013,0x00000000}},	//   _بعض_, _vyče, _tỏa_,
  { {0x201a024a,0x2fc6017f,0xb21b00b9,0x00000000}},	//   yppi_, znog_, _kræf,
  { {0x443100ea,0x2fc600a3,0x3958013d,0x00000000}},	//   gsz_, ynog_, égső_,
  { {0x6813003b,0x73062007,0xf77204a0,0x00000000}},	//   _căde, спаз, _راب_,
  { {0x2fc60117,0xa3d70161,0x44310051,0x00000000}},	// [8020] vnog_, ाक़_, asz_,
  { {0xa5bb017d,0xe2450044,0x00000000,0x00000000}},	//   ssór, تخفي,   ,
  { {0x2fc6017f,0xef1a0001,0xc2090063,0x00000000}},	//   tnog_, гме_, תה_,
  { {0x43860032,0x7f46000d,0xdb240058,0x00000000}},	//   _الحق, седж, ürüy,
  { {0x2fc6017f,0x7e560086,0x529a0062,0x00000000}},	//   rnog_, стец, _съня_,
  { {0x2fc644d8,0xdb020003,0x7e7b44d9,0x00000000}},	//   snog_, _cloî, _drup,
  { {0x2fc6017f,0x3cf40053,0xdcfa008f,0x00000000}},	//   pnog_, ेखें_, _rotē,
  { {0x764600fe,0xa09b0047,0x201800c2,0x00000000}},	//   kuky, _גילט, _itri_,
  { {0x7e7b44da,0xcb670001,0xa92a000d,0x00000000}},	//   _grup, сање_, ліне_,
  { {0x44310051,0x6d5a44db,0x200a0734,0x00000000}},	//   ysz_, _ubta, _kubi_,
  { {0x224044dc,0x3bd620fb,0x291e09b6,0x00000000}},	//   hrik_, _людс, rbta_,
  { {0x65ab09ad,0x96f904e3,0x478b0201,0x00000000}},	//   _mühe, иент_, усом_,
  { {0x65ab0019,0x201801f4,0x8c43003b,0x00000000}},	//   _lühe, _ltri_, ăşen,
  { {0xe5c70076,0x443100ea,0xceb30047,0x00000000}},	//   ссмо, tsz_, ליר_,
  { {0x200a051e,0xe8d9001b,0x69c80137,0x00000000}},	//   _nubi_, _đủ_, mnde,
  { {0x69c800bd,0x69da44dd,0x67d40062,0x00000000}},	//   lnde, lote, _нощу,
  { {0x91b9005a,0x443100ea,0x672f0051,0x00000000}},	// [8030] агат_, ssz_, macj,
  { {0x64410268,0x672f0045,0x69c81841,0x00000000}},	//   àlis, lacj, nnde,
  { {0x63a3003b,0x644100ed,0x69c844de,0x00000000}},	//   _înno, álid, inde,
  { {0x672f0051,0x224044df,0xce19000d,0x00000000}},	//   nacj, brik_, ацкі_,
  { {0x63ad0027,0x867c0047,0x7ae20035,0x00000000}},	//   mhan, ָרוו, _nyot,
  { {0xb21b0146,0x63ad44e0,0xd6580063,0x00000000}},	//   _præf, lhan, ציות_,
  { {0x672f0045,0x69da44e1,0x200a0f74,0x00000000}},	//   kacj, dote, _gubi_,
  { {0xdb000004,0x69c844e2,0xeb9944e3,0x00000000}},	//   himõ, ende, рии_,
  { {0xbfa805fb,0x64471668,0x69da44e4,0x00000000}},	//   _утре_, huji, fote,
  { {0xb21b05b9,0x64470035,0x499903d6,0x00000000}},	//   _træf, kuji, ртия_,
  { {0xa3e90161,0x77ca018e,0x63ad44e5,0x00000000}},	//   यता_, илог_, khan,
  { {0xfe67006a,0x672f0045,0x8b6708aa,0x00000000}},	//   ود_, gacj, _دائم,
  { {0x75e000ea,0x6db20051,0x63ad44e6,0x00000000}},	//   közt, płat, dhan,
  { {0x22400058,0x69da44e7,0x98a50571,0x00000000}},	//   vrik_, cote, _миле,
  { {0xc3960001,0x63ad010b,0xe8850086,0x00000000}},	//   ојањ, fhan, _єгип,
  { {0x4226005a,0x7bc92614,0x63ad44e8,0x00000000}},	//   ждав, nneu, ghan,
  { {0x764b00bd,0xa3bb0053,0x27e00089,0x00000000}},	// [8040] _ägyp, _अगर_, _ikin_,
  { {0x65ab0019,0x4255047e,0x63ad44e9,0x00000000}},	//   _pühe, ятст, ahan,
  { {0x106a0076,0x13a8007e,0x63ad44ea,0x00000000}},	//   рией_, _هندی_, bhan,
  { {0x68e317d3,0x69da0035,0x63ad44eb,0x00000000}},	//   _mynd, zote, chan,
  { {0xa3d70053,0x69c600ea,0x69da44ec,0x00000000}},	//   ाकर_, ékek, yote,
  { {0x672f0045,0x64410024,0xddb7000d,0x00000000}},	//   zacj, šlie, огіі_,
  { {0x8fa60088,0xb21b00b9,0x6d4a252f,0x00000000}},	//   _даве, _præg, rgfa,
  { {0x7bc90164,0x63a40498,0x5b26000d,0x00000000}},	//   gneu, nkin, цька,
  { {0xaa660086,0x69da43a3,0x63a444ed,0x00000000}},	//   ітик, tote, ikin,
  { {0x7ae20009,0x27e00465,0xb2bb0063,0x00000000}},	//   _vyot, _akin_, ימפר,
  { {0x69c800bd,0x63ad0024,0x672f0051,0x00000000}},	//   rnde, yhan, tacj,
  { {0x63a40122,0x290700c7,0x64470035,0x00000000}},	//   jkin, _egna_, vuji,
  { {0x672f0045,0x69da44ee,0x63a444ef,0x00000000}},	//   racj, pote, dkin,
  { {0x63a444f0,0x68e31233,0x661d44f1,0x00000000}},	//   ekin, _fynd, rpsk,
  { {0x63ad018d,0x7bc00019,0x68e3002b,0x00000000}},	//   than, oimu, _gynd,
  { {0x52150bed,0x63a400a4,0x200444f2,0x00000000}},	//   здат, gkin, _nimi_,
  { {0xd6280001,0x64550717,0x3e5e001c,0x00000000}},	// [8050] _доње_, stzi, nātā_,
  { {0xddc20045,0x63a444f3,0x63ad44f4,0x00000000}},	//   rtoś, akin, shan,
  { {0x35f80021,0xddc20051,0x7bc01dc1,0x00000000}},	//   _بريد_, stoś, kimu,
  { {0x7bc000eb,0xb21b00b9,0x63a444f5,0x00000000}},	//   jimu, _præd, ckin,
  { {0xab5d0045,0xa77c0047,0x7bc003e0,0x00000000}},	//   niże, יראפ, dimu,
  { {0x98a50529,0xcddb0001,0x7bc9001f,0x00000000}},	//   nală_, шње_, wneu,
  { {0x6605004b,0x98a5003b,0xdd8e0021,0x00000000}},	//   _mihk, ială_, اوى_,
  { {0xb21b0146,0x672d003b,0x7bc044f6,0x00000000}},	//   _træd, _neaj, gimu,
  { {0x7bc944f7,0x3e5e008f,0x68e32c0a,0x00000000}},	//   rneu, gātā_, _synd,
  { {0x27e044f8,0x6605078c,0x89a90098,0x00000000}},	//   _skin_, _nihk, сков_,
  { {0x63a444f9,0xb33b0058,0x98a5003b,0x00000000}},	//   ykin, _elçi, dală_,
  { {0x3e5e001c,0xdce31035,0xf772013a,0x00000000}},	//   bātā_, nenč, راج_,
  { {0xddc906bb,0xa3c10053,0x98a500dd,0x00000000}},	//   _mrež, ्चन_, fală_,
  { {0xdb000016,0x98a5000c,0x68e32be1,0x00000000}},	//   rimô, gală_, _tynd,
  { {0x07a60001,0x2a6d05a9,0x69c144fa,0x00000000}},	//   _накн, lweb_, mile,
  { {0x130a000d,0x883a0063,0x63a444fb,0x00000000}},	//   снай_, _התקו, ukin,
  { {0x98a5003b,0x63a444fc,0xdb00004d,0x00000000}},	// [8060] bală_, rkin, chmä,
  { {0x98a5000c,0x63a444fd,0xab5d0051,0x00000000}},	//   cală_, skin, roży,
  { {0xa067005a,0x69c600ea,0x859b0063,0x00000000}},	//   заха_, ékei, _השיו,
  { {0xb21b0146,0x7bc044fe,0x69c144ff,0x00000000}},	//   _dræb, ximu, hile,
  { {0x7bc000eb,0x69c105a2,0xc7b30063,0x00000000}},	//   vimu, kile, עבד_,
  { {0x69c1005b,0x3e5e008f,0x29180058,0x00000000}},	//   jile, vātā_, ırak_,
  { {0x7bc04500,0x69c14501,0x9b9404ef,0x00000000}},	//   timu, dile, дийц,
  { {0xdb00024a,0x69c14502,0xb2220014,0x00000000}},	//   yhmä, eile, _óæsk,
  { {0xadc300aa,0xb21b00b9,0x6e29001f,0x00000000}},	//   _quản, _træe, _gweb,
  { {0x69c105a2,0x7bc04503,0x3e5e0023,0x00000000}},	//   gile, simu, rātā_,
  { {0x660d0006,0x7bc00ab6,0x98a5003b,0x00000000}},	//   _suak, pimu, vală_,
  { {0x65b000fe,0xeb971b79,0x69c119d9,0x00000000}},	//   _lähd, _них_, aile,
  { {0x98a5000c,0x8ae30086,0x69c14504,0x00000000}},	//   tală_, _пішл, bile,
  { {0x65b0024a,0xf9c4007e,0x69c14505,0x00000000}},	//   _nähd, _تحصی, cile,
  { {0x98a5000c,0x660501a9,0xe7e80042,0x00000000}},	//   rală_, _vihk, _टीका_,
  { {0x443f4506,0x4394030b,0x18190043,0x00000000}},	//   ču_, насс, _بروک_,
  { {0x98a5000c,0xc73c0063,0xe2f80086,0x00000000}},	// [8070] pală_, _התחת, зеті_,
  { {0x67d2001c,0xb1d400de,0x00000000,0x00000000}},	//   māja, ّيْث,   ,
  { {0x80140086,0xdce300a2,0xddc90d76,0x00000000}},	//   ефіц, tenč, _prež,
  { {0x69c14507,0x60f80054,0x63bd0046,0x00000000}},	//   zile, їнця_, _umsn,
  { {0x69c1005b,0xee38013c,0xdce30f18,0x00000000}},	//   yile, зні_, renč,
  { {0x8d540062,0xdb0900ca,0x7ed401f3,0x00000000}},	//   етъч, theï, رزنا,
  { {0x69c14508,0x8d74005d,0x224f005f,0x00000000}},	//   vile, عاها, šokę_,
  { {0x98a50006,0x67d2001c,0x69c10022,0x00000000}},	//   nalą_, kāja, wile,
  { {0x75e000ea,0x69c14509,0x5d551528,0x00000000}},	//   közp, tile, _окат,
  { {0x67d2001c,0xbe64005d,0x09f60044,0x00000000}},	//   dāja, _سهمي, وفية_,
  { {0x69c104ab,0xe3c201f7,0x4b55005a,0x00000000}},	//   rile, lmış_, _жълт,
  { {0x69c1450a,0x08d4000d,0x907a009a,0x00000000}},	//   sile, эцыя, קטרי,
  { {0x65b0450b,0xe3c201f7,0x78a12c55,0x00000000}},	//   _lähe, nmış_, sylv,
  { {0x9c7c00c3,0x65ab0019,0x7b06004c,0x00000000}},	//   _izčr, _püha, ýstř,
  { {0x660303d1,0x65b00b64,0x290e017c,0x00000000}},	//   тпра, _nähe, ájať_,
  { {0x25b40006,0x9f4600ac,0x67d2001c,0x00000000}},	//   _šalį_, rloë_, bāja,
  { {0x8afa0047,0x67d2008f,0xe6ac008f,0x00000000}},	// [8080] ַלעז, cāja, _ērķē,
  { {0x31a400ea,0x65ab004d,0xa0a6007b,0x00000000}},	//   _közi_, _hühn, мазд,
  { {0xb21b0146,0x65ab004d,0x98a50078,0x00000000}},	//   _præc, _kühn, balą_,
  { {0x201c001c,0xdfd2013a,0xa3e90042,0x00000000}},	//   īvi_, خيص_, यतः_,
  { {0x65b000fe,0x42d60054,0xaff70044,0x00000000}},	//   _tähd, _ціну, ذفها_,
  { {0x21ef004b,0x6cd60043,0xd6e9009d,0x00000000}},	//   püha_, وقشا, הַצָ,
  { {0x91030076,0x1d07005e,0x82fa005d,0x00000000}},	//   _апре, мељи_, _درگز_,
  { {0xda08001b,0x69cf0164,0x8aa60086,0x00000000}},	//   _hỏi_, écen, дрод,
  { {0x290a00c2,0x2614004b,0x65b0004d,0x00000000}},	//   žbam_, _näo_, _zähe,
  { {0x67d2001c,0xd90d007e,0x6e22450c,0x00000000}},	//   vāja, میه_, mpob,
  { {0x76400026,0x65ab004d,0xbca6007e,0x00000000}},	//   ámyn, _bühn, _تماي,
  { {0x67d2001c,0x8b230085,0xc7bb0085,0x00000000}},	//   tāja, _адце, іён_,
  { {0x443a450d,0x07a4000d,0xd6db0062,0x00000000}},	//   _avp_, таўн, юто_,
  { {0x58d40065,0xdb0b0005,0xdcfa008f,0x00000000}},	//   _полт, _algè, _notī,
  { {0x7c380122,0x9f580331,0xe3c20058,0x00000000}},	//   nsvr, _juró_, zmış_,
  { {0x466b1849,0x67d2008f,0xe3c20058,0x00000000}},	//   _дром_, pāja, ymış_,
  { {0xdce3001c,0x62340054,0xab5d0022,0x00000000}},	// [8090] ienā, кету, niża,
  { {0x2a6600e3,0x30eb0062,0x51f8066e,0x00000000}},	//   _mpob_, офен_, дную_,
  { {0x753517c2,0xda080013,0x7c3800ca,0x00000000}},	//   mazz, _cỏi_, jsvr,
  { {0x65b0047f,0x7535450e,0xa2950454,0x00000000}},	//   _vähe, lazz, _замі,
  { {0x59de0161,0x85b8007e,0x9f9c0014,0x00000000}},	//   नकार, _رایس_, ríð_,
  { {0x65b00004,0x62340001,0x7535123a,0x00000000}},	//   _tähe, _јеру, nazz,
  { {0xfce2000a,0xe0e4000d,0x75350a02,0x00000000}},	//   лошо, _аўто, iazz,
  { {0x9f58006d,0x6aca0053,0xe3c2005b,0x00000000}},	//   _duró_, ापूर, pmış_,
  { {0xc955026c,0xeab10021,0x9958004c,0x00000000}},	//   нтны, طعة_, láři_,
  { {0xf9910032,0xf1b20047,0x7bdc013d,0x00000000}},	//   ابة_, ָסט_, _írun,
  { {0xa3c10235,0xfc300032,0x99580080,0x00000000}},	//   ्चा_, _نحن_, náři_,
  { {0x24860066,0xe0d20047,0xd77600f2,0x00000000}},	//   _čom_, רײט_, راجع,
  { {0x23ae007a,0x6b8b1320,0x98c4001c,0x00000000}},	//   _nýja_, _ingg, ītām_,
  { {0x7535051e,0xceb2450f,0xf9c724f8,0x00000000}},	//   gazz, נים_, _ющен,
  { {0xdb0b4510,0xab62004b,0x9958004c,0x00000000}},	//   _algé, üügi, jáři_,
  { {0x24070141,0x67d2008f,0xae0f0042,0x00000000}},	//   енси_, mājo, ादान_,
  { {0xe8df001b,0x65ab00bd,0x2011003b,0x00000000}},	// [80a0] _khỏi_, _kühl, _auzi_,
  { {0x99e9009d,0x00000000,0x00000000,0x00000000}},	//   פַּ֥,   ,   ,
  { {0x25a500fe,0x65ab0378,0x645a01a8,0x00000000}},	//   ölle_, _mühl, àtid,
  { {0x38780026,0x644e001c,0xa3ba005d,0x00000000}},	//   ærri_, mubi, _راجر_,
  { {0x539b0063,0x645c4511,0x5e580121,0x00000000}},	//   _זיכו, ltri, филя_,
  { {0xb21b0146,0x6b8b014f,0x463b00b5,0x00000000}},	//   _kræn, _angg, לענע,
  { {0x9f580290,0x644e2546,0x6e221f22,0x00000000}},	//   _durò_, nubi, spob,
  { {0x7c3800f5,0x645c4512,0x67d2001c,0x00000000}},	//   rsvr, itri, dājo,
  { {0x645c4513,0x61fe4514,0x1af40062,0x00000000}},	//   htri, ompl, ъпия,
  { {0x6b8b014f,0x644e0035,0x9f5800cd,0x00000000}},	//   _engg, kubi, _turó_,
  { {0xd8f8019d,0xf1b3014e,0xdd8f0021,0x00000000}},	//   ьної_, רסת_, _دول_,
  { {0x644e4515,0x2fc60123,0x2ca10072,0x00000000}},	//   dubi, niog_, ähde_,
  { {0xe9a60088,0x2d9e0035,0x65ab00bd,0x00000000}},	//   _падп, _kote_, _fühl,
  { {0xb21b10c4,0x645c00bd,0xb8940021,0x00000000}},	//   _bræn, ftri, _للتع,
  { {0xa4d40086,0xdb090025,0x75354516,0x00000000}},	//   горі, mheá, razz,
  { {0x2d9e4517,0x61fe4518,0x9958004c,0x00000000}},	//   _lote_, empl, váři_,
  { {0x71790138,0x2d8c4519,0x75350290,0x00000000}},	// [80b0] мбар_, _onde_, pazz,
  { {0x77a6017d,0xb21b0014,0x645c271a,0x00000000}},	//   _róxi, _fræn, btri,
  { {0xb21b2f88,0x03f900d7,0x644e451a,0x00000000}},	//   _græn, _оној_, cubi,
  { {0x2d8c451b,0x201c451c,0x61fe451d,0x00000000}},	//   _ande_, ívia_, ampl,
  { {0x99580080,0x290a00c2,0x2d9e451e,0x00000000}},	//   sáři_, žbah_, _bote_,
  { {0x7bc23bed,0xdd9b0062,0x6448008f,0x00000000}},	//   _amou, яше_, šdie,
  { {0xabd50540,0x69cf0164,0x10480076,0x00000000}},	//   кциј, écem, _пяти_,
  { {0x2d8c4226,0x44210509,0x77a600f8,0x00000000}},	//   _ende_, _mth_, _tóxi,
  { {0x644e004d,0x67f6004c,0x7e2b2049,0x00000000}},	//   zubi, hájc, _хіба_,
  { {0x44210025,0xab66004b,0x999f003b,0x00000000}},	//   _oth_, _psüü, druţ_,
  { {0xb6040080,0x65b00019,0x200c0003,0x00000000}},	//   ntář, _näha, _édit_,
  { {0x2d9e0009,0x6b8b014f,0x2ca70026,0x00000000}},	//   _zote_, _ungg, mynd_,
  { {0x2d9e0009,0x31a400ea,0xd5b7008b,0x00000000}},	//   _yote_, _közt_, ắng_,
  { {0xdce80080,0x644e0380,0xdb090025,0x00000000}},	//   _nadě, tubi, cheá,
  { {0x22492d6f,0xc5f8001c,0x628b0137,0x00000000}},	//   erak_, ķē_, ågon,
  { {0x2c7c0080,0x645c451f,0x9f520058,0x00000000}},	//   ládá_, rtri, öyü_,
  { {0x644e0035,0x3ce80053,0x6d4138a3,0x00000000}},	// [80c0] subi, _चुने_, _odla,
  { {0x7aeb00eb,0x3f8d0268,0xb21b10c4,0x00000000}},	//   _mygt, _aneu_, _træn,
  { {0x2d9e4520,0x20330021,0x505a066e,0x00000000}},	//   _rote_, لفلس, ьшая_,
  { {0xdce80024,0x2249419f,0x6d41339c,0x00000000}},	//   _podľ, brak_, _adla,
  { {0x98ac003b,0xdee3005e,0x2d9e4521,0x00000000}},	//   oadă_, аоци, _pote_,
  { {0x2fc600eb,0x44210150,0x62863fc5,0x00000000}},	//   siog_, _yth_, _irko,
  { {0x6da30540,0x2ca70146,0x2d9e1e3e,0x00000000}},	//   рија, gynd_, _vote_,
  { {0x2d9e0009,0x65ab1255,0x3b660062,0x00000000}},	//   _wote_, _rühm, тъкв,
  { {0xcb670095,0x2d9e2c80,0x7d560054,0x00000000}},	//   тање_, _tote_, _атеї,
  { {0x2d8c0529,0x7aeb00b9,0x9c7c0078,0x00000000}},	//   _unde_, _dygt, _lyči,
  { {0x31370063,0x5c560092,0xe7590054,0x00000000}},	//   כנים_, _штаф, нині_,
  { {0x69c302ab,0xdb090025,0x68ea00ac,0x00000000}},	//   _emne, sheá, _vyfd,
  { {0xcb67005e,0xb866005d,0xdddb348d,0x00000000}},	//   _јаче_, راگو, _hruš,
  { {0xa3820019,0xdbd10014,0xdce1008f,0x00000000}},	//   öõnn, lýðs, _galē,
  { {0xd5b822c1,0x98a30001,0xb4ad0053,0x00000000}},	//   тся_, _вије, कने_,
  { {0x63b6001f,0x9cd70063,0x21ef004b,0x00000000}},	//   ghyn, דולה_, rühm_,
  { {0x27e9003e,0x69c800fe,0x63ba00ac,0x00000000}},	// [80d0] _ikan_, oide, ëtna,
  { {0x645a0268,0x4a5b0063,0x69c84522,0x00000000}},	//   àtic, ודמו, nide,
  { {0xc1e80076,0x69c80659,0x62860d90,0x00000000}},	//   тьте_, iide, _erko,
  { {0x69c834ee,0x48150047,0x22492864,0x00000000}},	//   hide, אַסן_, prak_,
  { {0x69c84523,0x3f810080,0x2509007e,0x00000000}},	//   kide, ěhu_, _ترکی_,
  { {0x7aeb00b9,0x8e080086,0x3f430013,0x00000000}},	//   _rygt, внів_, ựu_,
  { {0x25a10080,0x61e5004a,0x63ad00b8,0x00000000}},	//   _mohl_, mohl, okan,
  { {0xdddb055e,0xdb090016,0x99840006,0x00000000}},	//   _druš, nheç, ksmų_,
  { {0xdce1001c,0x63ad4524,0x69c84525,0x00000000}},	//   _palē, ikan, fide,
  { {0x27e9014f,0x3eda0047,0x6d4100b9,0x00000000}},	//   _akan_, _אַבא, _udla,
  { {0xbb55006a,0x65ab0019,0x98ac003b,0x00000000}},	//   _مناب, _tühj, vadă_,
  { {0x63ad4526,0xa5bb0022,0xebd90062,0x00000000}},	//   jkan, spól, _ядеш_,
  { {0x200d08c8,0xdddb0114,0x69c84527,0x00000000}},	//   _miei_, _zruš, bide,
  { {0x23a70019,0x6abb004d,0xcc120053,0x00000000}},	//   _mõju_, mzuf, _ढूँढ_,
  { {0x98ac000c,0x63ad00ac,0x63b631cc,0x00000000}},	//   radă_, fkan, thyn,
  { {0xa69602a9,0x7bc94528,0x63ad4529,0x00000000}},	//   _број, nieu, gkan,
  { {0x6abb00bd,0x98ac003b,0x61e5004d,0x00000000}},	// [80e0] nzuf, padă_, fohl,
  { {0x201c017d,0x65b0004d,0x63ad240f,0x00000000}},	//   ívio_, _zähn, akan,
  { {0x11d70021,0x9c7c1bd4,0x63ad12ca,0x00000000}},	//   دولة_, _tyči, bkan,
  { {0xe29a0905,0x63ad4081,0x69c80111,0x00000000}},	//   _зам_, ckan, zide,
  { {0x657e00ea,0xdddb007d,0x0ee70121,0x00000000}},	//   _kaph, _sruš, льши_,
  { {0xdddb00a8,0x6e87014d,0x3eb2008f,0x00000000}},	//   _pruš, انوف_, _čatā_,
  { {0xb5fb21e2,0x80780063,0xbcaa0021,0x00000000}},	//   ltác, _בְּה, عدتك_,
  { {0x7bc917bf,0xafe60edd,0x69c80d25,0x00000000}},	//   gieu, _собл, wide,
  { {0xb5fb452a,0x69c8452b,0x0d560044,0x00000000}},	//   ntác, tide, _مخاد,
  { {0xb33b452c,0x63ad452d,0xad65007e,0x00000000}},	//   _moça, zkan, _نامه,
  { {0x7bc9006f,0xbca603eb,0x0c260962,0x00000000}},	//   bieu, _حماي, _смен,
  { {0x7bc90164,0x6441003d,0xcb160021,0x00000000}},	//   cieu, šlik, _إذاع,
  { {0x78ba000f,0x69c8452e,0x88bc0080,0x00000000}},	//   sztv, pide, zběh,
  { {0x99840006,0x98a70078,0x3eb90058,0x00000000}},	//   rsmų_, _seną_, _üste_,
  { {0x24190076,0x69d8006f,0x657e452f,0x00000000}},	//   тобы_, _ijve, _daph,
  { {0x25a100bd,0x67f60024,0x99dd027d,0x00000000}},	//   _wohl_, pája, suňt,
  { {0x65ab0019,0x6d5a4530,0x63ad4531,0x00000000}},	// [80f0] _lühi, _octa, rkan,
  { {0xb5fb00ea,0x63ad4532,0xd29b0085,0x00000000}},	//   stáb, skan, лiвы,
  { {0x61e50080,0xdb000137,0x3f1507fe,0x00000000}},	//   rohl, lkmä, адес,
  { {0xa8570063,0xdb000137,0x6d5a2dd0,0x00000000}},	//   ריאה_, okmä, _acta,
  { {0xb5fb0e7c,0x7bc90003,0xef180054,0x00000000}},	//   ctác, vieu, умі_,
  { {0xdcfa01f7,0xdca52ab5,0x4d64012c,0x00000000}},	//   _altı, иали, йків,
  { {0x9f6b0088,0x7bc910a1,0x6b9b004d,0x00000000}},	//   _праз_, tieu, tjug,
  { {0x69d802f7,0x291e4533,0x747c0063,0x00000000}},	//   _ajve, ecta_, תנהג,
  { {0x7bc93104,0xdfd80062,0xdb00004d,0x00000000}},	//   rieu, _сър_, chmü,
  { {0x7bc903b2,0x79c50086,0xd9450001,0x00000000}},	//   sieu, рйоз, јени,
  { {0xe8f60071,0x6abb004d,0x8afd004c,0x00000000}},	//   иль_, szuf, teřs,
  { {0xe73a0076,0x6283001c,0x62840078,0x00000000}},	//   ъем_, ānoj, yvio,
  { {0x2bb80032,0x67d2001c,0xf9d5000d,0x00000000}},	//   _حالة_, nāji, _кодэ,
  { {0xc9870001,0xb33b017d,0x69dd013d,0x00000000}},	//   _људи, _roça, ésed,
  { {0xc9d4006a,0x9961008f,0x00000000,0x00000000}},	//   _دموک, tīņu_,   ,
  { {0x65b000bd,0xb21b00b9,0x67d2001c,0x00000000}},	//   _zähl, _græk, kāji,
  { {0x3116000d,0x130a000d,0x4223005a,0x00000000}},	// [8100] афес, тнай_, ждув,
  { {0x67d2001c,0xd24f0021,0xc0460021,0x00000000}},	//   dāji, بنك_, لخصو,
  { {0x7e7b0529,0x628400be,0xb5fb1c43,0x00000000}},	//   _asup, svio, stác,
  { {0x753c0051,0xdb000137,0x60230054,0x00000000}},	//   larz, lkmå, ідча,
  { {0x471b00b5,0xee770021,0xfe72007e,0x00000000}},	//   דונג, لصوت_, تدا_,
  { {0x644e4534,0x65ab004b,0x753c161f,0x00000000}},	//   orbi, _pühi, narz,
  { {0xddc20022,0x9f7a0131,0x4f961fc6,0x00000000}},	//   troł, _исаф_, _крау,
  { {0xafe329c9,0x67d2001c,0xfba70121,0x00000000}},	//   _досл, bāji, итый_,
  { {0x22400360,0x753c2761,0x999f003b,0x00000000}},	//   nsik_, karz, ârşi_,
  { {0x20181867,0x65ab0019,0x99980002,0x00000000}},	//   _kuri_, _tühi, укот_,
  { {0x753c0045,0xb21b00b9,0x20184069,0x00000000}},	//   darz, _præk, _juri_,
  { {0x65b000bd,0x22404535,0xdddb0051,0x00000000}},	//   _wähl, ksik_, _opuś,
  { {0x95cb0581,0x644e0bbf,0x7e624536,0x00000000}},	//   вува_, erbi, ntop,
  { {0x95cb0001,0x2735008b,0x6d584537,0x00000000}},	//   тума_, ấn_, ngva,
  { {0xb21b0146,0x20184538,0x44254539,0x00000000}},	//   _træk, _nuri_, ël_,
  { {0x7e620d02,0xf77f017d,0xdb1b0014,0x00000000}},	//   ktop, moço_, nnuð,
  { {0x224000a4,0xb0620072,0x673d453a,0x00000000}},	// [8110] gsik_, äänl, masj,
  { {0xdce100eb,0xa6db0026,0x673d453b,0x00000000}},	//   _galė, taðf, lasj,
  { {0x20181472,0x23b5005d,0xdb1b0046,0x00000000}},	//   _curi_, _همدس, knuð,
  { {0x673d076c,0x9f050032,0x67d2003d,0x00000000}},	//   nasj, موضو, tāji,
  { {0x6455453c,0xd2440121,0x67f60066,0x00000000}},	//   luzi, _мэри, zájo,
  { {0x6575453d,0x2b83008d,0xdd3a00dd,0x00000000}},	//   nezh, _ực_, răşi,
  { {0x673d453e,0x64550290,0xdb1b0026,0x00000000}},	//   kasj, nuzi, fnuð,
  { {0xdd3a000c,0xb33b017d,0x7e7b27e2,0x00000000}},	//   păşi, _moço, _tsup,
  { {0x657500ea,0x7e623140,0x673d3296,0x00000000}},	//   kezh, ctop, dasj,
  { {0x49950330,0x6455453f,0xdcfa004c,0x00000000}},	//   сшит, kuzi, _zatč,
  { {0xe73a4540,0x4998000d,0x480a0169,0x00000000}},	//   лен_, ртыя_, леон_,
  { {0x673d0031,0x22400bfc,0x64554541,0x00000000}},	//   gasj, ysik_, duzi,
  { {0xa9690c45,0x753c1758,0x6813003b,0x00000000}},	//   _била_, tarz, _rădu,
  { {0xf77f0016,0x657500ea,0x64a601dd,0x00000000}},	//   boço_, gezh, бага,
  { {0xa34a005a,0x6813000c,0x7bf90047,0x00000000}},	//   лзва_, _pădu, ָפּצ,
  { {0xd4670001,0x32190034,0x2240061e,0x00000000}},	//   љите_, _busy_, tsik_,
  { {0x1757014e,0x20183019,0x6d580137,0x00000000}},	// [8120] _הספר_, _suri_, ygva,
  { {0x6455051e,0x20184542,0xb5fb4543,0x00000000}},	//   buzi, _puri_, ltán,
  { {0x6455051e,0x224002d2,0x73e601e2,0x00000000}},	//   cuzi, ssik_, _гонз,
  { {0xb5fb4544,0xa3bc0053,0x7e624545,0x00000000}},	//   ntán, _अति_, ttop,
  { {0x0dca000a,0x44440ff2,0x7a120051,0x00000000}},	//   луки_, _hv_, _ołta,
  { {0x201800eb,0x62830051,0x7e624546,0x00000000}},	//   _turi_, łnoc, rtop,
  { {0x7e624547,0x20184548,0x67d2008f,0x00000000}},	//   stop, _uuri_, lāju,
  { {0xdce30080,0x44444549,0x7e62454a,0x00000000}},	//   leně, _mv_, ptop,
  { {0x67d2003d,0x2a6f454b,0x673d00d1,0x00000000}},	//   nāju, _cpgb_, vasj,
  { {0x7c2a0031,0x7bde0003,0x44440d76,0x00000000}},	//   ppfr, épub, _ov_,
  { {0x673d076c,0x645a00cd,0xd90d007e,0x00000000}},	//   tasj, àtil, نیه_,
  { {0xf77f017d,0xd0f7009a,0xda660044,0x00000000}},	//   roço_, ממית_, _هاتي,
  { {0x673d076c,0x44443f60,0x67d2008f,0x00000000}},	//   rasj, _av_, jāju,
  { {0xb21b010a,0x673d454c,0x6455454d,0x00000000}},	//   _kræv, sasj, tuzi,
  { {0xb06200fe,0x673d0f4e,0x44441c6c,0x00000000}},	//   ääll, pasj, _cv_,
  { {0x6455051e,0xb5fb006d,0x4444454e,0x00000000}},	//   ruzi, ctán, _dv_,
  { {0x67d2001c,0xd7f9003b,0x4444454f,0x00000000}},	// [8130] tājv, ntăm_, _ev_,
  { {0xf204000d,0x7674007f,0x64550244,0x00000000}},	//   пяхо, _эльф, puzi,
  { {0x72040044,0xac42014b,0x00000000,0x00000000}},	//   أولم, _дзiк,   ,
  { {0x6d480185,0x6fd40086,0xa2950085,0x00000000}},	//   _adda, пціє, _дамі,
  { {0x67d2001c,0x2c610051,0xa77c0047,0x00000000}},	//   cāju, wód_, טראפ,
  { {0x98ac0051,0x2bb10053,0x98a7004c,0x00000000}},	//   sadę_, जस्थ, _ceně_,
  { {0x65b0024a,0x4c920001,0xdca20062,0x00000000}},	//   _sähk, дијс, дащи,
  { {0x2c610051,0xa024004d,0xaba90062,0x00000000}},	//   ród_, stöß, рвиз_,
  { {0x60250006,0xb21b00b9,0x6813003b,0x00000000}},	//   _dėme, _usæd, _nădr,
  { {0x65ab004d,0x65b0004b,0x68450054,0x00000000}},	//   _mühs, _vähk, оноа,
  { {0x186923cb,0x98ac004c,0xb5fb013d,0x00000000}},	//   шани_, madě_, ttán,
  { {0x98ac004c,0x2a350085,0xd70a0505,0x00000000}},	//   ladě_, _дэкр, инне_,
  { {0x69cf0164,0xd7f9003b,0x8883007e,0x00000000}},	//   éces, ctăm_, زیکن,
  { {0x67d2003d,0xb5fb3d78,0x98ac004c,0x00000000}},	//   vāju, stán, nadě_,
  { {0x833a4550,0xb97a0063,0xb4b40053,0x00000000}},	//   ичат_, _כנסי, झने_,
  { {0x67d2003d,0x04570032,0xa7fd005b,0x00000000}},	//   tāju, تلفة_, ltın,
  { {0x9f5f008b,0x65b0003a,0xe29a0002,0x00000000}},	// [8140] _thuê_, _lähi, шаа_,
  { {0x44443da8,0xa7fd005b,0xb5fb4551,0x00000000}},	//   _tv_, ntın, ntál,
  { {0xdce1003d,0x6e29001f,0x67d2001c,0x00000000}},	//   _dalī, _ateb, sāju,
  { {0xf1bf000f,0xb5fb0025,0xe8ec0047,0x00000000}},	//   _után_, htál, נקאָ,
  { {0x6441034d,0x60250006,0x5de61335,0x00000000}},	//   šlit, _rėme, ожда,
  { {0x7bcb001f,0xdce1001c,0x26c200c2,0x00000000}},	//   _amgu, _galī, izko_,
  { {0x70570085,0x224f011b,0x67fd009c,0x00000000}},	//   _маёр_, ělků_, héja,
  { {0x79830162,0xdee63260,0x0b8a25f8,0x00000000}},	//   _aanw, _доби, рски_,
  { {0x22521c6e,0x29030014,0xed5a1326,0x00000000}},	//   nryk_, ýjan_, _воз_,
  { {0x6d480146,0x65b000bd,0x67fd424c,0x00000000}},	//   _udda, _fähi, déja,
  { {0x7c280ddc,0x69dd0003,0xe894000d,0x00000000}},	//   _utdr, ésea, чань,
  { {0xd7f9000c,0x3f864552,0xc7c70086,0x00000000}},	//   ptăm_, ndou_, існи,
  { {0x7983002b,0xe73f00be,0x0a940062,0x00000000}},	//   _fanw, raõ_, _халю,
  { {0x69ca00d0,0xa6db0026,0x7983001f,0x00000000}},	//   _umfe, taðb, _ganw,
  { {0xd83a000d,0x83cb0002,0x69da4553,0x00000000}},	//   _тэл_, аѓаа_, mnte,
  { {0xdce1001c,0x3f860080,0xd90f0043,0x00000000}},	//   _salī, jdou_, _جیپ_,
  { {0xdce1003d,0x23ae007a,0x1ddb0053,0x00000000}},	// [8150] _palī, _nýju_, _बदलत,
  { {0x69da4554,0x64414555,0x7afd4556,0x00000000}},	//   nnte, ális, ýsti,
  { {0x65ab0199,0x6e2900eb,0xdce3008f,0x00000000}},	//   _führ, _steb, rdnī,
  { {0xd47a00b5,0x69da00bd,0x50c8000d,0x00000000}},	//   _פארל, hnte, цыум_,
  { {0x1df90076,0x539a0063,0xddc900a8,0x00000000}},	//   беды_, _הירו, _vsež,
  { {0x0dc80086,0xd6580063,0x367c009a,0x00000000}},	//   олій_, קיות_, שְׁע,
  { {0xa5bb0026,0x9f35013c,0x21ef004d,0x00000000}},	//   lpós, _неві, bühr_,
  { {0x65b001a5,0x69da4557,0x6e380026,0x00000000}},	//   _vähi, ente, ðabú,
  { {0x798300f3,0x98ac0080,0x99f5000d,0x00000000}},	//   _panw, padě_, зяні,
  { {0x65b00019,0xfeb8007e,0x4999365e,0x00000000}},	//   _tähi, _بافت_, стия_,
  { {0xb5fb00ea,0x79830173,0xa7fd005b,0x00000000}},	//   rtál, _vanw, rtın,
  { {0x2d873663,0x2d854558,0x69da4559,0x00000000}},	//   ldne_, _hale_, ante,
  { {0x1995005a,0x2d85455a,0x65ab004d,0x00000000}},	//   _надя, _kale_, _rühr,
  { {0x2d872867,0xa7fd005b,0x67d2001c,0x00000000}},	//   ndne_, ltıl, tājs,
  { {0x64a6455b,0x291c0024,0x67f601c2,0x00000000}},	//   чава, ázať_, háji,
  { {0x22520146,0xa7fd01f7,0xa5bb0026,0x00000000}},	//   tryk_, ntıl, fpós,
  { {0x27e000f3,0xe29706b4,0xab5d0051,0x00000000}},	// [8160] _ijin_, пат_, liżs,
  { {0x225200ac,0x7646455c,0x3f84455d,0x00000000}},	//   rryk_, msky, _samu_,
  { {0xe1ff03d9,0xab5d0045,0x628f3f05,0x00000000}},	//   _após_, niżs, _erco,
  { {0x3f860080,0x76460240,0xa6db0026,0x00000000}},	//   udou_, osky, laða,
  { {0xa5bb0027,0x3f86455e,0x5f19000d,0x00000000}},	//   mpór, rdou_, іццё_,
  { {0xa6db007a,0x63b6007a,0x2d85455f,0x00000000}},	//   naða, lkyn, _cale_,
  { {0x3f84014f,0xc0e31915,0x8c960054,0x00000000}},	//   _tamu_, _зорк, ярді,
  { {0x69dd03b2,0xb21b06a5,0x63a44560,0x00000000}},	//   ésen, _græs, njin,
  { {0xc9860138,0x2d854561,0xa6db0026,0x00000000}},	//   пуни, _fale_, kaða,
  { {0x2d850498,0x7646061f,0xa7fd005b,0x00000000}},	//   _gale_, dsky, atıl,
  { {0x69da0bfc,0x76464562,0xa6db0046,0x00000000}},	//   rnte, esky, daða,
  { {0x3cfb009f,0xb5fb4563,0x8c1b009a,0x00000000}},	//   _פלאנ, rtám, _הואי,
  { {0xa6db0026,0x2d854564,0x63b6004c,0x00000000}},	//   faða, _yale_, dkyn,
  { {0x7afd1255,0xa6db0014,0x63a40066,0x00000000}},	//   üste, gaða, ejin,
  { {0x7988002b,0xe1ff0022,0xb5fb0046,0x00000000}},	//   mddw, _opór_, lták,
  { {0xa3bc0053,0xa295000d,0xab62004b,0x00000000}},	//   _अतः_, мабі, üühi,
  { {0x52150054,0x7988002b,0x765a0022,0x00000000}},	// [8170] ддат, oddw, ątyc,
  { {0xa5bb0026,0x38c20003,0x395e4565,0x00000000}},	//   rpós, _géré_, ngts_,
  { {0xb21b0146,0x7bdb0051,0x395e008f,0x00000000}},	//   _præs, ynuu, igts_,
  { {0x2d851e27,0x388c011b,0xa857009a,0x00000000}},	//   _sale_, _měr_, ליבה_,
  { {0x2d85077d,0xce6b12b9,0xceeb005d,0x00000000}},	//   _pale_, сред_, حران_,
  { {0x64554566,0x929a009a,0x7c9505e0,0x00000000}},	//   orzi, _וישת, дриц,
  { {0x6da2005a,0xb21b000e,0x2d854567,0x00000000}},	//   тища, _træs, _vale_,
  { {0x395e001c,0x2d851d03,0x7988001f,0x00000000}},	//   egts_, _wale_, eddw,
  { {0x2d854568,0xfe70007e,0xa7fd0058,0x00000000}},	//   _tale_, _مدل_, rtıl,
  { {0xb5fb000f,0x3ce80053,0x395e0137,0x00000000}},	//   stáj, _चुके_, ggts_,
  { {0x3cf0027d,0xa6db0014,0x6d434569,0x00000000}},	//   čové_, vaða, mana,
  { {0x2fdd001f,0x65b0037e,0x395e0137,0x00000000}},	//   nnwg_, _läht, agts_,
  { {0xb8f40053,0xa6db0026,0xdcfa000c,0x00000000}},	//   _से_, taða, _tată,
  { {0x7646456a,0x273c001b,0x36150086,0x00000000}},	//   rsky, ận_, еєст,
  { {0xdddb017f,0x764600c7,0x63a400c2,0x00000000}},	//   _oruž, ssky, tjin,
  { {0x6d43456b,0x63a40006,0x7646456c,0x00000000}},	//   hana, ujin, psky,
  { {0xdb0b02dd,0x63a4456d,0xa5bb05d5,0x00000000}},	// [8180] _algú, rjin, rpór,
  { {0xa5bb0025,0x5a0a0047,0x50ba01fb,0x00000000}},	//   spór, ַלײַ, يداد_,
  { {0x7bc700eb,0x628b0137,0x657c456e,0x00000000}},	//   _įjun, ågor, merh,
  { {0xdd8f007e,0x6d43456f,0x645c4570,0x00000000}},	//   یون_, eana, muri,
  { {0x6d430009,0x79880185,0xdddb08c4,0x00000000}},	//   fana, yddw, _druž,
  { {0x657c00bd,0x6d434571,0x60c9004c,0x00000000}},	//   nerh, gana, _řeme,
  { {0x657c0917,0x6b8900ac,0x7bc0103b,0x00000000}},	//   ierh, fdeg, thmu,
  { {0x69c1004d,0x657c004d,0x645c4572,0x00000000}},	//   ehle, herh, iuri,
  { {0x657c4573,0x53c60053,0x6d431162,0x00000000}},	//   kerh, रोएश, bana,
  { {0x645c4574,0x7988001f,0x6d434575,0x00000000}},	//   kuri, uddw, cana,
  { {0xad65007e,0x7988001f,0xb5fb00ea,0x00000000}},	//   _ساله, rddw, sták,
  { {0x6e200d74,0x9b930021,0x657c1a62,0x00000000}},	//   _kumb, _للمت, eerh,
  { {0xdce800eb,0x6e200009,0xb5fb0025,0x00000000}},	//   _padė, _jumb, ltái,
  { {0xceb311b4,0x6e204576,0xb5fb0025,0x00000000}},	//   דיש_, _mumb, otái,
  { {0xb5fb0027,0x6e2018fe,0x67d528dd,0x00000000}},	//   ntái, _lumb, _поку,
  { {0x6d432f70,0x62830022,0x321800e5,0x00000000}},	//   zana, łnom, _airy_,
  { {0x6d434577,0x657c4578,0xf6e4000d,0x00000000}},	// [8190] yana, berh, _ацэн,
  { {0x15e90053,0x765d0360,0xc1eb000d,0x00000000}},	//   _फ़ीचर_, musy, цьбе_,
  { {0xdddb13f2,0x765d002c,0x10480086,0x00000000}},	//   _pruž, lusy, дячи_,
  { {0x6d434579,0x6e20457a,0x69c1004c,0x00000000}},	//   wana, _bumb, zhle,
  { {0x6d43457b,0x65b0047f,0x69c10080,0x00000000}},	//   tana, _täht, yhle,
  { {0x6b89002b,0x4421457c,0x6e20457d,0x00000000}},	//   wdeg, _kuh_, _dumb,
  { {0x6d43457e,0x4421457f,0xfd440085,0x00000000}},	//   rana, _juh_, тэчн,
  { {0x65b000bd,0x6e20075a,0x6d434580,0x00000000}},	//   _jähr, _fumb, sana,
  { {0x6d434581,0x645c000c,0x6e2002e2,0x00000000}},	//   pana, zuri, _gumb,
  { {0xa6db0026,0x6b8901f4,0xa2f80063,0x00000000}},	//   taðn, sdeg, ומחה_,
  { {0xab950001,0x6e204582,0x4421189e,0x00000000}},	//   _пажљ, _zumb, _nuh_,
  { {0x657c25ca,0x6e200035,0x6d414583,0x00000000}},	//   werh, _yumb, _hela,
  { {0x3e690024,0x6d410397,0xe3c2005b,0x00000000}},	//   nút_, _kela, nlış_,
  { {0x6d4108f0,0x9aa403eb,0xdb0900fe,0x00000000}},	//   _jela, _جمهو, rkeä,
  { {0x6d4109e8,0xccf20047,0x39454584,0x00000000}},	//   _mela, ָכן_, mals_,
  { {0x6d41180b,0x765d00a4,0x645c4585,0x00000000}},	//   _lela, busy, ruri,
  { {0x2249002c,0x39451a84,0x9f5f0025,0x00000000}},	// [81a0] gsak_, oals_, _chuí_,
  { {0x3945233a,0xe889008b,0x645c4586,0x00000000}},	//   nals_, _kẻ_, puri,
  { {0x6e2008f0,0x21f400bd,0xdddb0051,0x00000000}},	//   _sumb, fähr_, _druż,
  { {0xe8890013,0xb21b01e1,0xfe46090f,0x00000000}},	//   _mẻ_, _træp, ендо,
  { {0xe889008b,0x224900ea,0x6d414587,0x00000000}},	//   _lẻ_, csak_, _bela,
  { {0xa7fd005b,0xdce1005b,0x62864588,0x00000000}},	//   ttık, _anlı, _isko,
  { {0xc5f30063,0x91e31902,0x6d414589,0x00000000}},	//   אדג_, _соре, _dela,
  { {0x6d410004,0xb5fb0027,0xdb1b0025,0x00000000}},	//   _eela, rtái, bhuí,
  { {0xb5fb2669,0x394500cd,0x6d41458a,0x00000000}},	//   stái, fals_, _fela,
  { {0x3945458b,0xb5fb00ea,0xa7fd005b,0x00000000}},	//   gals_, ltáv, ptık,
  { {0x81570047,0x22490058,0x8881005d,0x00000000}},	//   עסטע_, zsak_, لیون,
  { {0xfa8800aa,0xb5fb017d,0x765d458c,0x00000000}},	//   _từ_, ntáv, tusy,
  { {0xb5fb017d,0x996c008f,0x3945458d,0x00000000}},	//   itáv, vēņu_, bals_,
  { {0xc8f4005a,0x3945458e,0x9a870021,0x00000000}},	//   _излъ, cals_, _أَوْ_,
  { {0xd90e007e,0x6286458f,0x3e69013d,0x00000000}},	//   _دید_, _asko, zút_,
  { {0xdcfa0023,0x22494590,0xc2c50044,0x00000000}},	//   _antī, tsak_, نيزي,
  { {0x22490150,0x25a500a5,0xd25104a0,0x00000000}},	// [81b0] usak_, ölls_, شنا_,
  { {0x65b00199,0x442115b7,0x22494591,0x00000000}},	//   _währ, _tuh_, rsak_,
  { {0x6d414592,0xe8890013,0x224904aa,0x00000000}},	//   _rela, _xẻ_, ssak_,
  { {0x6d414593,0x3e690024,0x9e3502dc,0x00000000}},	//   _sela, tút_, ведч,
  { {0x69dd000f,0x6d414594,0x3945125a,0x00000000}},	//   ések, _pela, yals_,
  { {0xdce8003d,0xddab0062,0x3e694595,0x00000000}},	//   _gadī, ятел_, rút_,
  { {0x2fd20025,0x6d414596,0x3e69013d,0x00000000}},	//   úngú_, _vela, sút_,
  { {0x1adc0161,0x6d41001f,0xe889008b,0x00000000}},	//   मपंथ, _wela, _rẻ_,
  { {0x6d41014f,0xe889008b,0x39454597,0x00000000}},	//   _tela, _sẻ_, tals_,
  { {0x798a001f,0x6d5e01a8,0x69954598,0x00000000}},	//   _cafw, òpat, трих,
  { {0x39454599,0xb9020086,0x39580139,0x00000000}},	//   rals_, изьк, órsa_,
  { {0xe889008b,0xcb350062,0x39451a52,0x00000000}},	//   _vẻ_, _редъ, sals_,
  { {0x3945328b,0xe737005e,0xa969459a,0x00000000}},	//   pals_, ђер_, _жила_,
  { {0xceb201f9,0x798a001f,0xeab00021,0x00000000}},	//   סים_, _gafw, _دعم_,
  { {0xddc2003d,0xdce8001c,0x044302b6,0x00000000}},	//   ntoš, _radī, иерн,
  { {0x08760047,0x6286459b,0x6b8b459c,0x00000000}},	//   _יעצט_, _psko, _jagg,
  { {0x6b8b02f6,0x61e20164,0x798a0035,0x00000000}},	// [81c0] _magg, éolo, _yafw,
  { {0xb65b0149,0xa1c31fd8,0x00da0593,0x00000000}},	//   _קדיש, абуд, وبات_,
  { {0xdce8001c,0xb5fb013d,0x6286056c,0x00000000}},	//   _vadī, ttáv, _wsko,
  { {0x93c70529,0x7053006a,0x6b8b0178,0x00000000}},	//   _plăţ, شنها, _nagg,
  { {0x6286459d,0xddc2001c,0xb5fb459e,0x00000000}},	//   _usko, etoš, rtáv,
  { {0x8d630138,0xe626008b,0xb5fb0114,0x00000000}},	//   авље, _đôla_, stáv,
  { {0x6b8b41f4,0x3ea0000c,0x98be001c,0x00000000}},	//   _bagg, ţit_, katā_,
  { {0x61fe459f,0xdca3005e,0xcb67005e,0x00000000}},	//   llpl, раћи, ваће_,
  { {0xd00f0032,0xfaa3000d,0x63ab0014,0x00000000}},	//   _ذلك_, ашэн, ögni,
  { {0xb5fb0167,0x0c7a0044,0xfe37009d,0x00000000}},	//   ntát, _يصاب_, _סרבי_,
  { {0x2d9e2ddc,0x5fb60235,0x6b8b0d2e,0x00000000}},	//   _inte_, _अकाल, _fagg,
  { {0x2d8c45a0,0xe8e00013,0xb5fb017c,0x00000000}},	//   _hade_, _ngụy_, kuác,
  { {0xc9aa02a9,0xf77f005b,0x2d8c085b,0x00000000}},	//   _овде_, reç_, _kade_,
  { {0x7bc20080,0xa4d5013c,0xea770063,0x00000000}},	//   _hlou, гогі, _סגור_,
  { {0x2d8c0034,0x29230024,0x7bc23c07,0x00000000}},	//   _made_, árať_, _klou,
  { {0x6b800146,0x2d8c45a1,0xd4070121,0x00000000}},	//   nemg, _lade_, тяги,
  { {0xa344000d,0x2d9e00be,0x7bc2004c,0x00000000}},	// [81d0] рэсл, _onte_, _mlou,
  { {0x2d8c371c,0xc692009d,0x00000000,0x00000000}},	//   _nade_, _פאי_,   ,
  { {0x44270469,0x69dd000f,0xa3d50854,0x00000000}},	//   _în_, ései, _бонч,
  { {0x2d9e45a2,0xb4c10053,0x5f280054,0x00000000}},	//   _ante_, ्छी_, воїм_,
  { {0x6b8b02f6,0x4ea7011c,0x2d8c45a3,0x00000000}},	//   _ragg, ържа, _bade_,
  { {0xf2d20063,0x6b8b055b,0x1d090e34,0x00000000}},	//   _פעם_, _sagg, нели_,
  { {0x6b8b00bb,0xb5fb000f,0x6c350021,0x00000000}},	//   _pagg, ltás, دفعا,
  { {0x7bc21823,0x200c00cd,0x2d9e45a4,0x00000000}},	//   _clou, _èdip_, _ente_,
  { {0xb5fb000f,0x7bc20080,0xee84014c,0x00000000}},	//   ntás, _dlou, _выхо,
  { {0xdcbb011c,0x2d8c1244,0x7d74005d,0x00000000}},	//   _още_, _gade_, _نامط,
  { {0x2dd80032,0x7bc20cfc,0x6b8b11ae,0x00000000}},	//   _شبكة_, _flou, _tagg,
  { {0x62840cc4,0xf7720067,0x7ae410f5,0x00000000}},	//   ywio, حاد_, _žite,
  { {0xa6db0026,0xb5fb00ea,0x4433338a,0x00000000}},	//   naðh, jtás, _atx_,
  { {0x7bc2017f,0x69940062,0x29c00013,0x00000000}},	//   _zlou, _връх, _hòan_,
  { {0xa3ea005a,0xf8a80021,0x98790041,0x00000000}},	//   едва_, _لديه_, _טאַט,
  { {0x798100e8,0xb5fb0024,0x645a00cd,0x00000000}},	//   lelw, tuác, àtiq,
  { {0x798100ca,0x7bde006c,0xe2450044,0x00000000}},	// [81e0] oelw, épui, لخلي,
  { {0x6d450026,0x10a60086,0x7981002b,0x00000000}},	//   ðhal, лизн, nelw,
  { {0xdce300eb,0x98be000c,0x2d8c04c9,0x00000000}},	//   menė, mată_, _rade_,
  { {0x98be000c,0xd5ed001b,0x2d8c45a5,0x00000000}},	//   lată_, _trạ, _sade_,
  { {0x798100f5,0x98be45a6,0x2d8c45a7,0x00000000}},	//   kelw, oată_, _pade_,
  { {0x7bc20080,0x98be000c,0xb5fb00ea,0x00000000}},	//   _slou, nată_, ltár,
  { {0x6da300d7,0x98be000c,0x79812b09,0x00000000}},	//   сија, iată_, delw,
  { {0xb5fb45a8,0x798100f5,0x1faa0086,0x00000000}},	//   ntár, eelw, _якби_,
  { {0x6b802a69,0x7dc60014,0x798145a9,0x00000000}},	//   remg, _aðse, felw,
  { {0x644e0146,0x79810333,0xc8f40062,0x00000000}},	//   ksbi, gelw, изпъ,
  { {0x98be0529,0xd9170076,0x29183226,0x00000000}},	//   dată_, лью_, ära_,
  { {0xa6db0026,0x6d4a3397,0x69c3121d,0x00000000}},	//   laði, lafa, _elne,
  { {0x7bdb0047,0x75d5007e,0x7e62006f,0x00000000}},	//   _אקאו, ليحا, nuop,
  { {0x6d4a0035,0xb5fb1937,0x98be000c,0x00000000}},	//   nafa, etár, gată_,
  { {0x69da45aa,0xb4c10053,0x69c80139,0x00000000}},	//   mite, ्छे_, mhde,
  { {0xa3cf0053,0x3cfe0089,0x7e620072,0x00000000}},	//   वों_, _mytv_, kuop,
  { {0x98be000c,0x44380024,0x69c800fe,0x00000000}},	// [81f0] bată_, apr_, ohde,
  { {0x98be0529,0x645a04a6,0xb5fb10fd,0x00000000}},	//   cată_, átic, rtás,
  { {0xb5fb0460,0x69da0213,0x44380150,0x00000000}},	//   tráf, iite, cpr_,
  { {0x798100ac,0x661e00ac,0xb5fb00f8,0x00000000}},	//   zelw, _zipk, frág,
  { {0x6d4a0c75,0xa6db0026,0x63ab0014,0x00000000}},	//   fafa, faði, ögnu,
  { {0x63ad45ab,0xa1590121,0xa6db0014,0x00000000}},	//   ljan, _шагу_, gaði,
  { {0xa7fd01f7,0x63ad0006,0x765d0244,0x00000000}},	//   ntıs, ojan, hrsy,
  { {0x98be0529,0x79810185,0x69da00bd,0x00000000}},	//   zată_, welw, eite,
  { {0x7981392e,0x69c30024,0x69da45ac,0x00000000}},	//   telw, _plne, fite,
  { {0x27e900fe,0x69c80025,0xb5fb00ea,0x00000000}},	//   _ajan_, ghde, ztár,
  { {0x98be000c,0x765d002c,0x63ad0026,0x00000000}},	//   vată_, ersy, kjan,
  { {0x443800c2,0x69c80072,0xc6000053,0x00000000}},	//   vpr_, ahde, ोग्य_,
  { {0x98be0529,0xbb3a0047,0x69da45ad,0x00000000}},	//   tată_, _סעסי, bite,
  { {0x69c800bd,0x7bc90164,0x63ad355e,0x00000000}},	//   chde, lheu, ejan,
  { {0x98be0529,0x644e004d,0x765d00ca,0x00000000}},	//   rată_, usbi, arsy,
  { {0x7bc90164,0x98be000c,0x63ad10ba,0x00000000}},	//   nheu, sată_, gjan,
  { {0x661e02e2,0x98be003b,0x7bc90072,0x00000000}},	// [8200] _tipk, pată_, iheu,
  { {0x394745ae,0xb5fb10c9,0x63ad021e,0x00000000}},	//   _jens_, stár, ajan,
  { {0xa3ea000d,0xcf8f018e,0xb5fb00ea,0x00000000}},	//   _адна_, ој_, ptár,
  { {0x69da45af,0x63ad0022,0x200d45b0,0x00000000}},	//   zite, cjan, _chei_,
  { {0xe8e20161,0xa6db0026,0x6e940002,0x00000000}},	//   _पश्च, taði, силу,
  { {0x394700cd,0x444445b1,0x6d4a0139,0x00000000}},	//   _nens_, _kw_, uafa,
  { {0xa6db0026,0xdc55007e,0x6d4a45b2,0x00000000}},	//   raði, مريک, rafa,
  { {0x69da160c,0xa6db007a,0x444445b3,0x00000000}},	//   wite, saði, _mw_,
  { {0x39471908,0x49a60699,0x69c8002b,0x00000000}},	//   _bens_, ајна, thde,
  { {0x39470803,0x69da34bf,0x78ba0072,0x00000000}},	//   _cens_, uite, tytv,
  { {0x3b86000a,0x394702ab,0x58d80086,0x00000000}},	//   _влег, _dens_, удня_,
  { {0x39470179,0x7bc945b4,0xb5fb0124,0x00000000}},	//   _eens_, cheu, zrád,
  { {0x6d4808a4,0x87070062,0x2af60121,0x00000000}},	//   _keda, ряне, _тяжё,
  { {0x6d480117,0x44440035,0x394702a7,0x00000000}},	//   _jeda, _bw_, _gens_,
  { {0x63ad45b5,0x6d4845b6,0xf77f13a3,0x00000000}},	//   tjan, _meda, ança_,
  { {0x394c0146,0x63ad0006,0xf1bf006d,0x00000000}},	//   lads_, ujan, _cuán_,
  { {0xb5fb017d,0xc299093e,0x2418093e,0x00000000}},	// [8210] stáq, ыках_, роты_,
  { {0x6f090045,0x6d4845b7,0x645a0066,0x00000000}},	//   _rzec, _neda, štia,
  { {0x444445b8,0x6f0945b9,0x63ad013d,0x00000000}},	//   _gw_, _szec, pjan,
  { {0xb21b01e1,0x749a0041,0xfe710044,0x00000000}},	//   _spæd, _עירפ, كدت_,
  { {0x8db50088,0x69d845ba,0x42790047,0x00000000}},	//   йскі, _omve, _גאָג,
  { {0x44440c70,0xdef80088,0x7c2845bb,0x00000000}},	//   _yw_, шых_, _budr,
  { {0xa6db0026,0x6d4845bc,0xef670062,0x00000000}},	//   maðu, _deda, _възо,
  { {0x394745bd,0xa6db0014,0x7ae43741,0x00000000}},	//   _sens_, laðu, _žita,
  { {0x6d4845be,0x7bc945bf,0x3947125a,0x00000000}},	//   _feda, rheu, _pens_,
  { {0xa6db007a,0x7db40021,0x6d48301a,0x00000000}},	//   naðu, _وصلا, _geda,
  { {0xa3e80235,0x5dfa0047,0x394745c0,0x00000000}},	//   _बदल_, _עפענ, _vens_,
  { {0x7c2e0003,0x39470983,0x444445c1,0x00000000}},	//   _ébra, _wens_, _rw_,
  { {0xa7fd01f7,0x394745c2,0x4444075a,0x00000000}},	//   ttır, _tens_, _sw_,
  { {0x6e2100f3,0x3eda0047,0x6e29006d,0x00000000}},	//   _jilb, אַלא, _mueb,
  { {0xa7fd005b,0x69c100ca,0x98be005f,0x00000000}},	//   rtır, mkle, tatą_,
  { {0xf1bf008b,0xa7fd005b,0xf814007e,0x00000000}},	//   _quán_, stır, _بستگ,
  { {0xa7fd005b,0x69c145c3,0xa6db0014,0x00000000}},	// [8220] ptır, okle, faðu,
  { {0x01d70032,0xd1960001,0x98be0006,0x00000000}},	//   موقع_, љшањ, satą_,
  { {0x44440b7d,0x02190086,0x6d4845c4,0x00000000}},	//   _uw_, ріть_, _reda,
  { {0x68fc00bd,0x6d4845c5,0x6e213872,0x00000000}},	//   ürdi, _seda, _ailb,
  { {0x319f001c,0x6e2145c6,0x6d4845c7,0x00000000}},	//   _bāzē_, _bilb, _peda,
  { {0xc291007e,0x44220618,0x171b0047,0x00000000}},	//   _زیمب, _hik_, אונע,
  { {0xb5fb027d,0x394c008f,0x6d4845c8,0x00000000}},	//   duál, vads_, _veda,
  { {0x6f000051,0x8c43005e,0x649b0041,0x00000000}},	//   _tymc, чеће, ריקה,
  { {0x6d4845c9,0x4fbb0063,0x442200ea,0x00000000}},	//   _teda, _עצמא, _mik_,
  { {0xce370063,0x44222494,0x2a6445ca,0x00000000}},	//   _לאמת_, _lik_, rumb_,
  { {0x0dc90002,0x7bde0003,0x3e720003,0x00000000}},	//   _туѓи_, épus, lât_,
  { {0x4422203f,0x69dd0164,0x2902001c,0x00000000}},	//   _nik_, éser, āka_,
  { {0x95cb000a,0x645a0014,0x3e72006c,0x00000000}},	//   гува_, átin, nât_,
  { {0xf1bf02dd,0x3897003b,0x69c145cb,0x00000000}},	//   _cuál_, _făr_, ckle,
  { {0x7c220035,0x645a1aa5,0xdce3008f,0x00000000}},	//   _kior, štin, venī,
  { {0x442245cc,0xdc370047,0x33750085,0x00000000}},	//   _cik_, מאלט_, ўгар,
  { {0xa6db0026,0x9f4600ac,0x6595000d,0x00000000}},	// [8230] taðu, anoë_, _дапу,
  { {0x6e29006d,0xdb0b013d,0xe4e72049,0x00000000}},	//   _rueb, _jogá, _гімн,
  { {0x44220146,0xa91c0024,0x6e2945cd,0x00000000}},	//   _fik_, ieľo, _sueb,
  { {0x6e29048e,0xdb0b0027,0x44220d02,0x00000000}},	//   _pueb, _logá, _gik_,
  { {0x6e2945ce,0x6e2145cf,0x7d07013d,0x00000000}},	//   _queb, _pilb, _újsz,
  { {0xb5fb0167,0xa6db0014,0x628f45d0,0x00000000}},	//   xuál, laðs, _isco,
  { {0x0dc80001,0x63b800c2,0x7c2245d1,0x00000000}},	//   ључи_, žanš, _bior,
  { {0xa91c034d,0x7c2245d2,0x23c90053,0x00000000}},	//   teľn, _cior, रसिद,
  { {0x3e720529,0x6e2123f1,0x69c106aa,0x00000000}},	//   cât_, _tilb, tkle,
  { {0x8d77006a,0x3897003b,0xe9d90f55,0x00000000}},	//   _دارا, _păr_, рко_,
  { {0xd7ea0055,0x7c2221a4,0x999900ea,0x00000000}},	//   имое_, _fior, ésű_,
  { {0x7c223b9b,0xdd0e01f7,0x2d8745d3,0x00000000}},	//   _gior, lışm, lene_,
  { {0x3ffa0047,0x2d870983,0x26c4004c,0x00000000}},	//   שפרע, oene_, ámo_,
  { {0x2d8707e6,0x992b0076,0xdd0e005b,0x00000000}},	//   nene_, _сюда_, nışm,
  { {0x628f45d4,0x2d8745d5,0x442245d6,0x00000000}},	//   _asco, iene_, _pik_,
  { {0x2d8745d7,0xb5fb19e6,0x84060083,0x00000000}},	//   hene_, trác, іпаж,
  { {0x2d8745d8,0xb5fb088f,0xdd0e0058,0x00000000}},	// [8240] kene_, urác, kışm,
  { {0x93c7001b,0x2d87065f,0x442200a4,0x00000000}},	//   _hoặ, jene_, _wik_,
  { {0x2d8745d3,0x001a000d,0x442245d9,0x00000000}},	//   dene_, аўды_, _tik_,
  { {0x443a0051,0xb5fb004a,0x3e72290c,0x00000000}},	//   _itp_, prác, tât_,
  { {0xb21b00b9,0x2e47005a,0x7c220afd,0x00000000}},	//   _psæt, оящо_, _rior,
  { {0x443a0150,0x3e7202a4,0x2d8745da,0x00000000}},	//   _ktp_, rât_, gene_,
  { {0x7c2245db,0x2903004b,0xa6db0014,0x00000000}},	//   _pior, üjal_, naðr,
  { {0x3e72006c,0xaa880044,0x2bba00de,0x00000000}},	//   pât_, منعم_, شاعة_,
  { {0xa91c034d,0xa3cf0161,0xee37000a,0x00000000}},	//   teľo, वोट_, _мнт_,
  { {0x2d8745dc,0xa6db0014,0xb5fb0014,0x00000000}},	//   cene_, kaðr, kráa,
  { {0x09b70032,0x443a0fef,0x28f80500,0x00000000}},	//   تطيع_, _ntp_, сень_,
  { {0x5a46000d,0xc6a72254,0x3ea90066,0x00000000}},	//   _дэка, орги, ťate_,
  { {0x645a007c,0xf98f007e,0x29c0008d,0x00000000}},	//   štil, ربی_, _lòai_,
  { {0x63a60354,0x99d30021,0x383402d8,0x00000000}},	//   _ankn, _يتوا, _енкр,
  { {0xa6db0014,0x6672007e,0x69ca04a7,0x00000000}},	//   taðs, وگیر, _ilfe,
  { {0xe235005e,0x79881246,0xdbd0008d,0x00000000}},	//   знањ, ledw, _týõn,
  { {0x2d8725c5,0xa6db0026,0x24970078,0x00000000}},	// [8250] yene_, raðs, _žemė_,
  { {0x6d5a00b9,0xed880078,0x443a45dd,0x00000000}},	//   _ndta, šųjų_, _ftp_,
  { {0x2d873435,0x96180021,0xf8ca0053,0x00000000}},	//   vene_, _بغير_, ानिय,
  { {0x6d5a013d,0xf8b303c3,0xb4fa009a,0x00000000}},	//   _adta, ושע_, _לפתי,
  { {0x2d870031,0xdd0e005b,0x7c3a1130,0x00000000}},	//   tene_, tışm, _attr,
  { {0xa2ba0063,0xb2ba0063,0x7d050244,0x00000000}},	//   _המשט, _המשר, ühso,
  { {0x23bf016a,0x3ea9000c,0x2d8745de,0x00000000}},	//   _एकाद, ţat_, rene_,
  { {0x7e6200c3,0x5ba9447a,0x2d8723ba,0x00000000}},	//   brop, ским_, sene_,
  { {0x2d8745df,0xe9d919bb,0x7c3a45e0,0x00000000}},	//   pene_, йки_, _ettr,
  { {0xa7fd005b,0x645500ea,0x4a42000d,0x00000000}},	//   yrıc, kszi, эньв,
  { {0xdcfa001c,0x6d4345e1,0xfaf9008f,0x00000000}},	//   _datē, mbna, egūt_,
  { {0xe29f007a,0xfc640062,0x645a0066,0x00000000}},	//   _orð_, _цъфн, átim,
  { {0xb9020053,0x7988001f,0x6d5a00ac,0x00000000}},	//   _ने_, bedw, _ydta,
  { {0xceb20f6d,0x7c3a00c7,0x6b89224d,0x00000000}},	//   עים_, _yttr, leeg,
  { {0x645545e2,0x64a302fe,0xa50a0b69,0x00000000}},	//   gszi, нара, сева_,
  { {0xe8d60063,0x3a3f45e3,0x98be004c,0x00000000}},	//   _מוצר_, opup_, hatě_,
  { {0x2737008b,0x00000000,0x00000000,0x00000000}},	// [8260] _ủng_,   ,   ,
  { {0xa6db0014,0x7e6245e4,0x6455013d,0x00000000}},	//   paðr, vrop, bszi,
  { {0x6e3b002c,0x55bb0063,0xdfcf007e,0x00000000}},	//   _atub, _המיו, گين_,
  { {0x63a60898,0x79880022,0x6d43004d,0x00000000}},	//   _unkn, zedw, ebna,
  { {0xdfcf08aa,0x26c20078,0x539b0063,0x00000000}},	//   دين_, nyko_, _היכו,
  { {0x22400228,0x7bcb0b16,0x2b980013,0x00000000}},	//   mpik_, _algu, _ức_,
  { {0xb5fb007a,0x61fe0146,0xa91c0024,0x00000000}},	//   krán, mopl, teľm,
  { {0x7988002b,0x61fe45e5,0x7b630121,0x00000000}},	//   wedw, lopl, нтье,
  { {0xdcfa001c,0x798801e1,0x6d43013d,0x00000000}},	//   _patē, tedw, bbna,
  { {0x6d5a10c4,0xfaf9008f,0x1e57009a,0x00000000}},	//   _udta, egūs_, _משמר_,
  { {0x7c3a0c4a,0x7988001f,0x6d3b0063,0x00000000}},	//   _uttr, redw, _התבנ,
  { {0x61fe08c1,0xdc8b0063,0x2fc60130,0x00000000}},	//   hopl, _לְדָ, nkog_,
  { {0xe3bf006d,0x61fe45e6,0xe9a618f7,0x00000000}},	//   _niña_, kopl, _надп,
  { {0x64551929,0x69ca01e1,0x997601d5,0x00000000}},	//   tszi, _ulfe, _худш,
  { {0x151400a0,0xe97b0063,0xb5fb0114,0x00000000}},	//   едря, _הנוש, brán,
  { {0x61fe0034,0x656e0139,0xb5fb28be,0x00000000}},	//   eopl, agbh, ntáz,
  { {0x645500ea,0x91b906be,0x61fe004b,0x00000000}},	// [8270] sszi, огат_, fopl,
  { {0x61fe45e7,0x6455013d,0x454b0062,0x00000000}},	//   gopl, pszi, _учим_,
  { {0x6e3b45e8,0x25d80047,0x0638005d,0x00000000}},	//   _stub, _מוזן_, _وسیع_,
  { {0xe29f007a,0x2c5700dd,0x04640054,0x00000000}},	//   _eyða_, văd_, _ятьм,
  { {0x6ff50045,0x7dcf02ab,0x98be0080,0x00000000}},	//   jące, _løse, tatě_,
  { {0x6b89006f,0xdb070003,0x394e0003,0x00000000}},	//   weeg, _éléc, _nefs_,
  { {0x6b890004,0x6ca7000d,0xddc200c2,0x00000000}},	//   teeg, ярдж, btož,
  { {0x2fc6007d,0x5f940429,0xd7f9003b,0x00000000}},	//   ckog_, _пист, frăm_,
  { {0xc334014e,0x60180076,0x8d87042c,0x00000000}},	//   עוץ_, _хотя_, _нужд,
  { {0x26c200eb,0x08c502b3,0x9d55005d,0x00000000}},	//   vyko_, дбон, _آنات,
  { {0xb5fb0a63,0x8d74007e,0x6b89004b,0x00000000}},	//   trán, _سالا, peeg,
  { {0x66e60785,0xe73727b8,0xa09a0041,0x00000000}},	//   дома, мею_, קירט,
  { {0xb5fb02dd,0xd7f9000c,0x7d040080,0x00000000}},	//   rrán, crăm_, řist,
  { {0xb21b45e9,0x69c6008f,0x34aa0054,0x00000000}},	//   _spæn, ūker, овго_,
  { {0x2fcd45ea,0x61fe3f13,0x49da0043,0x00000000}},	//   _oleg_, vopl, _بانگ_,
  { {0xe3bf0331,0xf8b20063,0xf7720044,0x00000000}},	//   _piña_, _ישו_, _شاب_,
  { {0x764b00b9,0x4226114d,0x2907002b,0x00000000}},	// [8280] _ægyp, ддав, _hyna_,
  { {0x2fcd000c,0xe3bf006d,0xdb24013d,0x00000000}},	//   _aleg_, _viña_, éséi,
  { {0x61fe45eb,0x2fc6007d,0xf2c90063,0x00000000}},	//   ropl, tkog_, סע_,
  { {0x61fe010a,0xb5fb0080,0x4f0a05f1,0x00000000}},	//   sopl, hrál, онен_,
  { {0xa91c0066,0x61fe45ec,0xdcf8004c,0x00000000}},	//   teľk, popl, bevě,
  { {0x2fc645ed,0xddc20080,0x7d780021,0x00000000}},	//   skog_, stož, سمبر_,
  { {0x6da300d7,0x27e00050,0xb5fb45ee,0x00000000}},	//   тија, _omin_, drál,
  { {0xcfaa0021,0xeb97005e,0xd7f900dd,0x00000000}},	//   _باسم_, дић_, trăm_,
  { {0x298a046a,0x29070075,0xda7a0085,0x00000000}},	//   осно_, _ayna_, цяй_,
  { {0x29070186,0x27e018a5,0xb5fb45ef,0x00000000}},	//   _byna_, _amin_, stáz,
  { {0xf1bf0013,0x394e0014,0x48aa0054,0x00000000}},	//   _quái_, _vefs_, ітом_,
  { {0x2907001f,0x5ba50086,0xa7fd0058,0x00000000}},	//   _dyna_, _пріз, arın,
  { {0xbc1b0047,0xa7fd0058,0xb5fb274e,0x00000000}},	//   _וואש, brın, brál,
  { {0x27e001f7,0x6d5e0046,0x34951a6b,0x00000000}},	//   _emin_, ópah, нагр,
  { {0xe4e40086,0x6286001c,0x7dc60026,0x00000000}},	//   вітн, _apko, _aðsk,
  { {0xddc9004c,0x27e00022,0xe7870054,0x00000000}},	//   _dveř, _gmin_, _цуко,
  { {0x6b820025,0x7d081c59,0x52150336,0x00000000}},	// [8290] _mbog, _lyds, едат,
  { {0x91e40001,0x69c802fd,0xdddb45f0,0x00000000}},	//   вође, nkde, _opuš,
  { {0x3cde016a,0x35f80032,0x6b8208ed,0x00000000}},	//   _केले_, _تريد_, _obog,
  { {0x251a0063,0x2ef500e1,0x764d00ac,0x00000000}},	//   _מותא, нзер, _kway,
  { {0xde580086,0xddc90080,0x733a0047,0x00000000}},	//   дачі_, _zveř, _מערס,
  { {0x6b822cd5,0x3e320021,0x41e7000d,0x00000000}},	//   _abog, دفور, _ціма,
  { {0x63bd45f1,0x7d08002b,0xa7fd0058,0x00000000}},	//   _kosn, _cyds, vrın,
  { {0x6aa2001f,0x672d3d38,0x61e511d4,0x00000000}},	//   _brof, _ngaj, lihl,
  { {0xba250794,0xb5fb1958,0x6aa245f2,0x00000000}},	//   ндик, trál, _crof,
  { {0xb5fb0025,0x5cc70062,0x63bd0014,0x00000000}},	//   frám, _осез, _losn,
  { {0xe3bf02dd,0xa7fd0058,0xf1b2009a,0x00000000}},	//   _niño_, ltıy, אסי_,
  { {0x78bc0137,0x63bd45f3,0x0b780044,0x00000000}},	//   ärva, _nosn, _يصنع_,
  { {0xa7fd01f7,0x0aeb007e,0xb5fb006d,0x00000000}},	//   ntıy, _براي_, arám,
  { {0x69c801bb,0x6b8213d7,0x7bc945f4,0x00000000}},	//   ckde, _zbog, lkeu,
  { {0x63bd45f5,0x443e006c,0xc4c604a0,0x00000000}},	//   _bosn, ët_, رتسو,
  { {0x7bc900fe,0x42d60454,0xd91a0047,0x00000000}},	//   nkeu, нізу, _צוקל,
  { {0x7bc9024a,0x443e2886,0x21a60121,0x00000000}},	// [82a0] ikeu, ūt_, ниам,
  { {0x42070001,0x7bc90072,0x61e50046,0x00000000}},	//   енуо_, hkeu, gihl,
  { {0x7bc900fe,0xddc9004c,0x1f66019c,0x00000000}},	//   kkeu, _uveř, екем,
  { {0x78bc069f,0x6e280137,0x543b0047,0x00000000}},	//   ørvi, _sidb, _מעטא,
  { {0x7bc90173,0x6b9b001f,0x6289001c,0x00000000}},	//   dkeu, ddug, _ģeog,
  { {0x61e50058,0xf6530041,0x63bd0445,0x00000000}},	//   cihl, נצו_, _zosn,
  { {0xa7fd0058,0xac2601e2,0x25f10042,0x00000000}},	//   atıy, нфик, ँचती_,
  { {0x6b9b00a4,0xe8df0013,0xdb0b017d,0x00000000}},	//   gdug, _chửi_, _ingê,
  { {0x60e000eb,0x7b140062,0x0d8645f6,0x00000000}},	//   žymė, ъдих, _план,
  { {0x7d0800e8,0xc0c60026,0xa7fd0058,0x00000000}},	//   _tyds, _óásæ, arıl,
  { {0x764d0783,0x29c90014,0xdddb0130,0x00000000}},	//   _sway, _gúam_, _upuš,
  { {0x2d9c00ea,0x6aa245f7,0x6b8245f8,0x00000000}},	//   ldve_, _trof, _ubog,
  { {0xcf9300b5,0x63bd45f9,0xdce3056c,0x00000000}},	//   נטש_, _rosn, rgną,
  { {0x5b130086,0x63bd0cb6,0xceb30aeb,0x00000000}},	//   _сміт, _sosn, איש_,
  { {0x63bd00c3,0xc9530063,0x2d8e004d,0x00000000}},	//   _posn, _עמק_, iefe_,
  { {0x43940121,0xf77f00be,0x672d00a8,0x00000000}},	//   ласс, biça_, _ugaj,
  { {0xe1670001,0xf77f00be,0x8c1b0063,0x00000000}},	// [82b0] еђен, ciça_, לולי,
  { {0x8cb10053,0x00000000,0x00000000,0x00000000}},	//   _अपलो,   ,   ,
  { {0x63bd0025,0xc9530047,0xa7fd0058,0x00000000}},	//   _tosn, רמע_, yrıl,
  { {0x60c500fe,0xe8170053,0xa7fd0058,0x00000000}},	//   ryhm, _धीमा_, ttıy,
  { {0xee3815d4,0xd3560165,0xa3e60042,0x00000000}},	//   ені_, _שישי_, _भगत_,
  { {0x7bc90122,0x31350001,0x8d620076,0x00000000}},	//   wkeu, _јевр, авше,
  { {0x645a1aa5,0xb5fb013d,0x853c009d,0x00000000}},	//   štiv, tráj, הגוי,
  { {0xddc20006,0x63a90014,0xa7fd0058,0x00000000}},	//   ruoš, _óend, ptıy,
  { {0x7bc945fa,0x442b45fb,0x89d5000d,0x00000000}},	//   rkeu, _mic_, вінш,
  { {0x3f8f0026,0x442b45fc,0xddc20078,0x00000000}},	//   legu_, _lic_, puoš,
  { {0x442b0f78,0x9991000f,0xa3c30053,0x00000000}},	//   _oic_, öző_, ्सा_,
  { {0x3f8f0185,0xf77203eb,0xf77f017d,0x00000000}},	//   negu_, جاد_, tiça_,
  { {0x443303b2,0xa91c0066,0x2f5a0063,0x00000000}},	//   _aux_, deľu, ודרנ,
  { {0x7d0401f7,0x67eb00fe,0x442b01f4,0x00000000}},	//   şise, töjä, _aic_,
  { {0xdce1005b,0x0576007e,0x60180955,0x00000000}},	//   _kalı, _یادد, líme,
  { {0x73990635,0x2d9c00ea,0x442b0616,0x00000000}},	//   нтус_, zdve_, _cic_,
  { {0x44330164,0x442b3131,0x2d8500d1,0x00000000}},	// [82c0] _eux_, _dic_, _oble_,
  { {0x602c005b,0x7981002b,0x06570063,0x00000000}},	//   _aşma, nflw, _שייך_,
  { {0xe0d20021,0x27f7007e,0xd6a9007e,0x00000000}},	//   جزء_, _سفید_, _قدیم_,
  { {0x2d850037,0xbe8a0001,0x6e46000d,0x00000000}},	//   _able_, дске_, ведз,
  { {0x7dd400cd,0x442045fd,0xd37b0085,0x00000000}},	//   _làse, mmi_, зiцы,
  { {0x61430088,0x3f8f0019,0xf1bf008b,0x00000000}},	//   _вера, aegu_, _quát_,
  { {0x318300ea,0xdce1005b,0x61eb0003,0x00000000}},	//   észő_, _balı, ègle,
  { {0x442014d5,0xb5fb18a8,0xb4fb0063,0x00000000}},	//   nmi_, nuár, ופצי,
  { {0x6018006d,0xa934000d,0xdce10058,0x00000000}},	//   gíme, лепш, _dalı,
  { {0x98b8000a,0x442045fe,0x79a605bd,0x00000000}},	//   елот_, hmi_, трие,
  { {0xc1570063,0xb5fb00ea,0x6d5845ff,0x00000000}},	//   כשיו_, lság, mava,
  { {0x4420104c,0xa91c0066,0xdcfa008f,0x00000000}},	//   jmi_, deľt, _latī,
  { {0xb5fb000f,0x29020051,0x442b28cd,0x00000000}},	//   nság, łka_, _ric_,
  { {0x7dcf02ab,0x6d584600,0x44204601,0x00000000}},	//   _løsn, nava, emi_,
  { {0x645c00c7,0xdb0b00f4,0xe4540121,0x00000000}},	//   gsri, _angè, икры,
  { {0x63680cb5,0xa77500e1,0xa3dd0053,0x00000000}},	//   круг_, _слич, थों_,
  { {0xb5fb0405,0xd2340062,0x6d5840ed,0x00000000}},	// [82d0] hrái, интъ, kava,
  { {0x51f80076,0xb5fb0090,0x6d584602,0x00000000}},	//   вную_, dság, java,
  { {0x3c38000f,0x442b13d5,0x44200066,0x00000000}},	//   _név_, _tic_, bmi_,
  { {0xe4a40086,0xb5fb017d,0x6d584603,0x00000000}},	//   _трьо, cuár, eava,
  { {0x645a4604,0x7981001f,0xb5fb00ea,0x00000000}},	//   štit, yflw, gság,
  { {0xa3c30235,0x3e7b0164,0xed580024,0x00000000}},	//   ्सव_, rêt_, _poľa_,
  { {0xdb0b0164,0x7c2b01f4,0xc1720063,0x00000000}},	//   _ingé, _pigr, _לחם_,
  { {0x6d58021e,0x7c3e004a,0x765d19e5,0x00000000}},	//   aava, ípra, kssy,
  { {0x6d5822cb,0x7c2b0f49,0x8d770044,0x00000000}},	//   bava, _vigr, _لاضا,
  { {0x6d584605,0x3c380003,0x987e0058,0x00000000}},	//   cava, _fév_, _açıp_,
  { {0x44204606,0x7c2b4607,0x35c60053,0x00000000}},	//   ymi_, _tigr, रॉफ़,
  { {0x366a013e,0x9be4012c,0xa2b80042,0x00000000}},	//   намо_, _кічк, ोहम्,
  { {0x200f005b,0x44204608,0xda650062,0x00000000}},	//   ilgi_, vmi_, _свли,
  { {0x645c4609,0xda5a009d,0x00000000,0x00000000}},	//   tsri, _טכנל,   ,
  { {0x2a7f0019,0xb5fb460a,0x4420460b,0x00000000}},	//   ltub_, zság, tmi_,
  { {0x6d58000f,0x4420460c,0xb8820066,0x00000000}},	//   zava, umi_, číti,
  { {0xdcfa001c,0x03a30121,0xaa360041,0x00000000}},	// [82e0] _patī, щито, ָטעק_,
  { {0xddd40024,0xb5fb0016,0x7644002c,0x00000000}},	//   _ťažk, suár, _itiy,
  { {0xd12f0032,0x2a7f0019,0x8fa61321,0x00000000}},	//   أمم_, htub_, лаже,
  { {0x44440034,0xb4c20235,0xb5fb00ea,0x00000000}},	//   _it_, ्नी_, tság,
  { {0xa3c30053,0x7de6000d,0x6d58460d,0x00000000}},	//   ्सर_, лікд, tava,
  { {0x2703008b,0xb5fb095e,0x4444460e,0x00000000}},	//   ổng_, trái, _kt_,
  { {0xb5fb000f,0x4444460f,0xe1f70002,0x00000000}},	//   sság, _jt_, _сгр_,
  { {0xb5fb0027,0x7dc6007a,0xf77f017d,0x00000000}},	//   rrái, _aðst, viço_,
  { {0x0aea0021,0x9fb80240,0x8e760002,0x00000000}},	//   عربي_, nčí_, _љубч,
  { {0x765d069f,0xa27b0047,0x200600f5,0x00000000}},	//   vssy, עװיז, looi_,
  { {0x2d9e017d,0x44444610,0x28f802a1,0x00000000}},	//   _iate_, _nt_, тень_,
  { {0x2006021f,0x2d9e0034,0x7dcf01f2,0x00000000}},	//   nooi_, _hate_, _løsl,
  { {0xa91c034d,0x44441dbc,0x2d9e096b,0x00000000}},	//   teľs, _at_, _kate_,
  { {0xb5fb004a,0x6296002b,0x44444611,0x00000000}},	//   hráv, dwyo, _bt_,
  { {0xa4d40086,0x94d40413,0x19570063,0x00000000}},	//   борі, борц, _גבול_,
  { {0x2d9e0b7a,0xddc900dd,0x44444612,0x00000000}},	//   _late_, _oveş, _dt_,
  { {0xe5e5007e,0xfc3f027d,0x44444613,0x00000000}},	// [82f0] _نزدی, _čím_, _et_,
  { {0x44444614,0x600a004c,0x54554107,0x00000000}},	//   _ft_, kýms, _квот,
  { {0x200600ac,0xa0a70121,0x30a7000d,0x00000000}},	//   fooi_, ышал, ырав,
  { {0x200600e8,0xb4d10053,0x64454615,0x00000000}},	//   gooi_, वनी_, _ithi,
  { {0x2d9e4616,0x4444013d,0x8db50054,0x00000000}},	//   _bate_, _zt_, искі,
  { {0xd65803c3,0x60180080,0xdbde0026,0x00000000}},	//   ניות_, tímc, _síðn,
  { {0xabd50fe2,0xdcf8003d,0xeb990928,0x00000000}},	//   ициј, devē, вий_,
  { {0x3ff900b5,0x9e95005d,0xa7fd0075,0x00000000}},	//   _ספּע, _پارچ, nsıd,
  { {0x2d9e055b,0x2249006f,0x7bc60014,0x00000000}},	//   _fate_, npak_, ökua,
  { {0x2d9e123f,0xe8850257,0x888518ea,0x00000000}},	//   _gate_, агоп, алож,
  { {0x6ce40086,0x2a7f0019,0x2902005b,0x00000000}},	//   _ліце, stub_, şkan_,
  { {0x44444617,0x2249002c,0x645a0003,0x00000000}},	//   _rt_, kpak_, âtim,
  { {0xa3b90053,0x44444618,0x64454619,0x00000000}},	//   चान_, _st_, _athi,
  { {0x4444461a,0x98a5018e,0x9fb80080,0x00000000}},	//   _pt_, _вике, včí_,
  { {0xb4c20053,0xf6230054,0x69c3461b,0x00000000}},	//   ्ने_, ідсо, _ione,
  { {0x6441017d,0x4444461c,0xb5fb0460,0x00000000}},	//   ília, _vt_, dráu,
  { {0x60180114,0xe61a0169,0xddc200a8,0x00000000}},	// [8300] jíma, _иди_, hroš,
  { {0x673b0024,0x69c3461d,0xbbd20053,0x00000000}},	//   ľuje, _jone, _तत्क,
  { {0x44440707,0x20060104,0x2d9e1af3,0x00000000}},	//   _ut_, tooi_, _rate_,
  { {0xddc2003d,0x6d41461e,0x03a61c04,0x00000000}},	//   droš, _afla, _тимо,
  { {0x2d9e461f,0x1e960e82,0x6fdf0082,0x00000000}},	//   _pate_, ррер, पोइं,
  { {0x69c300e5,0xdb0b4620,0x9f4f013d,0x00000000}},	//   _none, _logó, fogó_,
  { {0xb5fb108f,0x8f760054,0xdb1b0130,0x00000000}},	//   práv, _вузі, ljuè,
  { {0x0b8a02a2,0x1d07005e,0x309b009a,0x00000000}},	//   тски_, јећи_, _בשלמ,
  { {0x6d41001f,0xee37000d,0x2a6d4621,0x00000000}},	//   _ffla, _вну_, greb_,
  { {0x4e7b014e,0x64430003,0x69c34622,0x00000000}},	//   _באמצ, _énig, _cone,
  { {0x291800c7,0x6607017f,0x69c34623,0x00000000}},	//   åra_, vojk, _done,
  { {0xe6950076,0x961f0053,0x0aea0121,0x00000000}},	//   бимы, पष्ट_, _идей_,
  { {0x86740086,0x69c34624,0xe6980062,0x00000000}},	//   оляє, _fone, авяш_,
  { {0x69c34625,0x3ea6059d,0xb6070054,0x00000000}},	//   _gone, ivot_, рямк,
  { {0x66074626,0xb5fb4627,0xe4a4354e,0x00000000}},	//   rojk, drát, орто,
  { {0x83350062,0x69c30da1,0xb5fb013d,0x00000000}},	//   снах, _zone, usáb,
  { {0x69da00fe,0x27e94628,0x6445002b,0x00000000}},	// [8310] ohte, _iman_, _wthi,
  { {0xa0a70121,0x6f0d0022,0x683e008f,0x00000000}},	//   ишел, żack, _zīda,
  { {0xd13833e7,0x64450035,0x69da01a1,0x00000000}},	//   рху_, _uthi, ihte,
  { {0x60180026,0xb5fb00ea,0x00000000,0x00000000}},	//   tíma, arát,   ,
  { {0x6d4100bd,0x27f200ea,0x25a1004d,0x00000000}},	//   _pfla, ézni_, _kahl_,
  { {0xb5fb06b2,0x8e080086,0xddc201b3,0x00000000}},	//   crát, анів_, troš,
  { {0x27e94629,0x98be0078,0xcf9b0699,0x00000000}},	//   _oman_, matė_, _ија_,
  { {0x69da0019,0x351c0063,0x2a6d063f,0x00000000}},	//   ehte, כוונ, treb_,
  { {0x69c3462a,0x93b80063,0xdb0b0022,0x00000000}},	//   _pone, שלחו_, _rogó,
  { {0x628f0290,0x69da057a,0x27e9462b,0x00000000}},	//   _mpco, ghte, _aman_,
  { {0x69c300bd,0x07a60086,0x66680047,0x00000000}},	//   _vone, банн, יפֿטצ,
  { {0x69c30194,0x69da3dd5,0x629d462c,0x00000000}},	//   _wone, ahte, _osso,
  { {0x69c3415a,0xa9a516fc,0x7ccc0023,0x00000000}},	//   _tone, _гилд, _vērš,
  { {0x69da462d,0xe6170076,0x201f29cc,0x00000000}},	//   chte, йдя_, _lhui_,
  { {0x64a6005a,0x044602a9,0x25a1462e,0x00000000}},	//   щава, себн, _dahl_,
  { {0x083a0047,0x7bdb08f3,0xdb0b0022,0x00000000}},	//   _געקל, nhuu, _uogó,
  { {0xb5fb462f,0x01360021,0xb7db009a,0x00000000}},	// [8320] grás, معاد, _תקפי,
  { {0x79c9009d,0x00000000,0x00000000,0x00000000}},	//   נֶּ֔,   ,   ,
  { {0x6f1b0118,0x629d4630,0x66250044,0x00000000}},	//   _azuc, _esso, _بريك,
  { {0x25a100bd,0x201f4631,0xb5fb013d,0x00000000}},	//   _zahl_, _chui_, brás,
  { {0x69da00fe,0x2d580121,0xdef40085,0x00000000}},	//   yhte, аиль_, ўплы,
  { {0x63a44632,0x628435aa,0x3ea60072,0x00000000}},	//   ldin, mtio, rvot_,
  { {0x628400fe,0xf41f00fe,0xb5fb017d,0x00000000}},	//   ltio, _yhä_, orár,
  { {0xb33b005b,0x443a08cf,0x00f7089e,0x00000000}},	//   _kaça, _mup_, _המלך_,
  { {0x62840238,0x63a44633,0xfaa3000d,0x00000000}},	//   ntio, idin, пшэн,
  { {0x984a005a,0xf77f01f7,0x7e6200b9,0x00000000}},	//   ляма_, miçi_, msop,
  { {0xa7b90001,0x8b66007e,0xdb4f2324,0x00000000}},	//   алну_, _هاشم, _ню_,
  { {0x63a40122,0x7bdb0035,0x62844634,0x00000000}},	//   jdin, chuu, ktio,
  { {0x6d5a0397,0x7e624635,0x443a337e,0x00000000}},	//   _keta, nsop, _aup_,
  { {0xd6d8019d,0x6d5a0003,0x6441017d,0x00000000}},	//   стю_, _jeta, ílio,
  { {0xdce8005b,0xa4d40086,0x443a4636,0x00000000}},	//   _kadı, порі, _cup_,
  { {0x25a100bd,0x395e4637,0x601100b9,0x00000000}},	//   _wahl_, lats_, påmi,
  { {0x82f80021,0xb33b1997,0x24180121,0x00000000}},	// [8330] مركز_, _caça, соты_,
  { {0x7c3a4638,0x395e4639,0xb5fb463a,0x00000000}},	//   _outr, nats_, rrás,
  { {0xceeb007e,0xa5d8007e,0xb5fb0026,0x00000000}},	//   گران_, _دبير_, srás,
  { {0xdea1007e,0x395e0cf2,0xb33b463b,0x00000000}},	//   ویزی, hats_, _faça,
  { {0x7c3a0c6e,0x628404bc,0x69d8006d,0x00000000}},	//   _autr, ctio, _olve,
  { {0x6d5a463c,0x395e27ac,0xdcf80078,0x00000000}},	//   _ceta, jats_, nevė,
  { {0x395e463d,0x7c3a1826,0x9f5f00ea,0x00000000}},	//   dats_, _cutr, óról_,
  { {0x7c3a0ead,0x69d8463e,0x4a45030b,0x00000000}},	//   _dutr, _alve, онив,
  { {0x7e62000f,0x7bdb006f,0x395e463f,0x00000000}},	//   csop, rhuu, fats_,
  { {0x63a400eb,0x395e2a97,0xa969005e,0x00000000}},	//   zdin, gats_, јина_,
  { {0x63a44640,0xc1720063,0xd7ca005d,0x00000000}},	//   ydin, וחי_, لوده_,
  { {0x69d808d5,0xa3a90053,0x907a00ff,0x00000000}},	//   _elve, _गोल_, סטרי,
  { {0x395e4641,0xab64000d,0x7c3a004d,0x00000000}},	//   bats_, _хвіл, _zutr,
  { {0x395e3e26,0xb33b017d,0xca360063,0x00000000}},	//   cats_, _raça, _ונסה_,
  { {0xb5fb017d,0x6aa92071,0x6e3b004b,0x00000000}},	//   trár, lvef, _luub,
  { {0x63a44642,0x7f5b0331,0x50ba007e,0x00000000}},	//   udin, _neuq, یداد_,
  { {0x98a5005b,0x62844643,0xb5fb017d,0x00000000}},	// [8340] malı_, utio, rrár,
  { {0xb21b00b9,0x63a40006,0xe693007e,0x00000000}},	//   _spær, sdin, _کلید,
  { {0xdbd1005b,0x6d5a089c,0x62841664,0x00000000}},	//   _güçl, _reta, stio,
  { {0x62840238,0x9eaa0002,0x98a5005b,0x00000000}},	//   ptio, ивеа_, nalı_,
  { {0x6d5a4644,0xdfcf0021,0x7bc64645,0x00000000}},	//   _peta, خين_, ökum,
  { {0x3ead0268,0x7c3a014f,0x395e27ac,0x00000000}},	//   _dret_, _putr, xats_,
  { {0x395e0268,0x98a501f7,0x6b890941,0x00000000}},	//   vats_, kalı_, ffeg,
  { {0x7e6200f5,0xdc2a007e,0x3ead0edc,0x00000000}},	//   psop, جسته_, _fret_,
  { {0x395e4646,0x6d5a0397,0x98f5001b,0x00000000}},	//   tats_, _teta, uản,
  { {0x395e0268,0xddc20051,0x670e0053,0x00000000}},	//   uats_, społ, _सड़क_,
  { {0x395e4647,0xeb9a071a,0x2cac001f,0x00000000}},	//   rats_, _вие_, _urdd_,
  { {0x56950856,0x395e4648,0x44224649,0x00000000}},	//   памт, sats_, _nhk_,
  { {0x3707464a,0x395e0358,0x3949000c,0x00000000}},	//   ючов, pats_, _şase_,
  { {0x69d8464b,0xe8ea005d,0x6ff50022,0x00000000}},	//   _ulve, _پرتو_, rąci,
  { {0x03c71224,0x98a50058,0xf8aa005d,0x00000000}},	//   осам, balı_, _خدشه_,
  { {0xedb70053,0xa7740062,0xb5fb013d,0x00000000}},	//   _इच्छ, _жлъч, csán,
  { {0x7c22001f,0xd7f900dd,0xe1f3013a,0x00000000}},	// [8350] _mhor, nsăm_, وسط_,
  { {0x44220004,0x91b80076,0x64481358,0x00000000}},	//   _ehk_, огут_, ídic,
  { {0xb8810080,0x6e3b004b,0x5f950062,0x00000000}},	//   žíve, _suub, зиет,
  { {0xf494007e,0x764f00ca,0x3ead464c,0x00000000}},	//   _کشید, opcy, _pret_,
  { {0xb3ba0063,0xe298000d,0x4429464d,0x00000000}},	//   _המרכ, _даў_, mma_,
  { {0x7c22048e,0x270a001b,0x2ba7008b,0x00000000}},	//   _ahor, ờng_, _ốc_,
  { {0x98a5005b,0x44292aac,0xc2120063,0x00000000}},	//   yalı_, oma_, _נהל_,
  { {0x3ead0268,0x44293da6,0xe4fc0063,0x00000000}},	//   _tret_, nma_, יפוש,
  { {0x3ead00b9,0xb33b017d,0x2b5f008f,0x00000000}},	//   _uret_, _laço, rauc_,
  { {0x9b02000d,0x6aa921ad,0x4429464e,0x00000000}},	//   эзыд, rvef, hma_,
  { {0x7c220025,0x4429464f,0x98a5005b,0x00000000}},	//   _fhor, kma_, talı_,
  { {0x44290ffc,0xddc20022,0xc5e9009a,0x00000000}},	//   jma_, apoń, _גד_,
  { {0x98ab01f7,0x44290019,0x98a5005b,0x00000000}},	//   ılık_, dma_, ralı_,
  { {0x4422004b,0x44294650,0x7c2201d1,0x00000000}},	//   _shk_, ema_, _zhor,
  { {0xb5fb0080,0x98a5005b,0x2508007e,0x00000000}},	//   psán, palı_, زرسی_,
  { {0x442918ab,0x7c291104,0x395c0130,0x00000000}},	//   gma_, nmer, _zevs_,
  { {0xb77b014e,0x877b0063,0x813a005d,0x00000000}},	// [8360] _האפש, _האפי, مساز_,
  { {0xb33b4651,0x7c2900bd,0xa7fd005b,0x00000000}},	//   _faço, hmer, nsın,
  { {0x7c292d3d,0x80a60021,0x7bc60014,0x00000000}},	//   kmer, ثمان, ökuk,
  { {0x44294652,0xa8560063,0x7c290130,0x00000000}},	//   cma_, פינה_, jmer,
  { {0xa7fd005b,0xa3b90053,0x7c294653,0x00000000}},	//   ksın, चार_, dmer,
  { {0x7c220034,0x63a6017e,0x7c294654,0x00000000}},	//   _shor, _hakn, emer,
  { {0x7c291660,0x395c1233,0x7c224655,0x00000000}},	//   fmer, _revs_, _phor,
  { {0x6c470021,0x8fa3000d,0x7c294656,0x00000000}},	//   أليف_, _пасе, gmer,
  { {0x63a62c8d,0x9a83007f,0x7acd030b,0x00000000}},	//   _makn, нуэл, а́те,
  { {0xd8f80086,0xdca64657,0x44294658,0x00000000}},	//   жної_, _нази, zma_,
  { {0x7c22057a,0xa3190053,0x38c8005d,0x00000000}},	//   _thor, _दर्ज_, زادی_,
  { {0x7c220024,0x63a64659,0xd0f70063,0x00000000}},	//   _uhor, _nakn, למית_,
  { {0xdb000080,0x61ee0331,0x96f80062,0x00000000}},	//   odmí, _ombl, зеят_,
  { {0xdb0b0025,0xb33b00be,0x1a9b07e9,0x00000000}},	//   _ungá, _paço, _לידע,
  { {0xdcf8008f,0x2578007f,0x4429465a,0x00000000}},	//   devī, ябрь_, tma_,
  { {0x799a0035,0x7dcf0093,0x44290b1c,0x00000000}},	//   letw, _høst, uma_,
  { {0x4429357c,0xa2940054,0x69ca465b,0x00000000}},	// [8370] rma_, наті, _kofe,
  { {0x764d00a4,0x7c2914d5,0x799a1a3a,0x00000000}},	//   _itay, zmer, netw,
  { {0x7c29001f,0x9f4f0164,0x66280080,0x00000000}},	//   ymer, ligé_, řské,
  { {0xc10401a7,0xa7fd005b,0x75f80066,0x00000000}},	//   روني, zsın, _väzň,
  { {0x82a4000d,0xada50200,0x996c0023,0x00000000}},	//   _заўж, далл, zēšu_,
  { {0x6b82006d,0x69ca001f,0x2d8100e7,0x00000000}},	//   _acog, _nofe, ühe_,
  { {0xdca2005a,0x63a6014f,0x7c291c42,0x00000000}},	//   ващи, _yakn, tmer,
  { {0x49060053,0x7c29465c,0x8d180044,0x00000000}},	//   _सँजो_, umer, أزهر_,
  { {0xb33b0058,0x69ca465d,0x200f0022,0x00000000}},	//   _raçl, _bofe, mogi_,
  { {0x39e9019d,0x9f4f0003,0x799a006f,0x00000000}},	//   ідно_, digé_, getw,
  { {0x7c29465e,0xa7fd005b,0x6aa2465f,0x00000000}},	//   pmer, rsın, _esof,
  { {0x6b820025,0x7e690078,0x200f4660,0x00000000}},	//   _gcog, _kvep, nogi_,
  { {0x63a60026,0xceb20063,0x6b9b004e,0x00000000}},	//   _rakn, ֣ים_, meug,
  { {0x63a602eb,0x7bcb04d0,0x6b9b4661,0x00000000}},	//   _sakn, _hogu, leug,
  { {0x7bcb0004,0x660e1dbe,0x764d0058,0x00000000}},	//   _kogu, robk, _etay,
  { {0x7bcb4662,0x42d6071f,0x200f1561,0x00000000}},	//   _jogu, мізу, jogi_,
  { {0x7bcb4663,0x63a60626,0x9f60004c,0x00000000}},	// [8380] _mogu, _vakn, ásím_,
  { {0x6b9b0122,0x70f60021,0x7bcb4664,0x00000000}},	//   heug, وسائ, _logu,
  { {0x63a61b67,0x200f00a3,0x14262099,0x00000000}},	//   _takn, fogi_, _одом,
  { {0x799a0051,0xef1a4665,0x98bc008f,0x00000000}},	//   zetw, оме_, _sevī_,
  { {0xde58000d,0x067b0047,0x27f900ea,0x00000000}},	//   чалі_, ַנקל, érni_,
  { {0x6b820387,0x61ee11ad,0x78a300a8,0x00000000}},	//   _scog, _umbl, _osnv,
  { {0x20750121,0x69ca4666,0x7c860002,0x00000000}},	//   _путё, _rofe, фуле,
  { {0x7dcf07e6,0x69ca3bbc,0xdb5a16f2,0x00000000}},	//   _søst, _sofe, цюк_,
  { {0x5a340905,0x1eaa005d,0x00000000,0x00000000}},	//   ннит, _بازي_,   ,
  { {0x61fe00d1,0xdb1b0014,0xa7fd0058,0x00000000}},	//   nnpl, rkuð, asıl,
  { {0x764d0034,0xd7f50076,0x6b9b4667,0x00000000}},	//   _stay, езны, beug,
  { {0x2d9c4668,0x2fc6013d,0x7bcb096c,0x00000000}},	//   leve_, njog_, _gogu,
  { {0xc6e70054,0xbb4305f4,0x7df4005f,0x00000000}},	//   фінп, _речк, _tęsė,
  { {0x7dd40268,0x9f4f0003,0x2d9c4669,0x00000000}},	//   _bàsi, rigé_, neve_,
  { {0x16340b3f,0xf807005e,0x7bcb3e5a,0x00000000}},	//   теря, _очин, _yogu,
  { {0x2d9c0821,0x43940e82,0xaad20042,0x00000000}},	//   heve_, касс, _तथाक,
  { {0x9f4f00d1,0xa7fd0058,0x47350054,0x00000000}},	// [8390] nngå_, nsım, _янис,
  { {0x6b9b0199,0xdbd60004,0x2d9c074f,0x00000000}},	//   zeug, _hääl, jeve_,
  { {0xdb0b00c7,0x2d9c09d3,0x9961001c,0x00000000}},	//   _ingå, deve_, nūšu_,
  { {0x4f94000a,0x7e6d001c,0xb33b0075,0x00000000}},	//   вршу, šapm, _maçk,
  { {0x040e0013,0x6b9b006c,0x7bcb466a,0x00000000}},	//   hưởn, veug, _rogu,
  { {0x44390034,0x0ea8019d,0xfe7001fb,0x00000000}},	//   _his_, ькій_, شده_,
  { {0x7bcb466b,0x7ddd00cd,0x443900ea,0x00000000}},	//   _pogu, _cèsa, _kis_,
  { {0x443900eb,0xdc28005d,0x539a009a,0x00000000}},	//   _jis_, وسيه_, ִיתו,
  { {0x4439466c,0x3f9d0150,0x7bcb466d,0x00000000}},	//   _mis_, mewu_, _vogu,
  { {0x2d9c0290,0x3f9d0051,0x4439466e,0x00000000}},	//   ceve_, lewu_, _lis_,
  { {0x0ca802b6,0x2fdf004d,0x05c30042,0x00000000}},	//   _отци_, _klug_, शानब,
  { {0xddc20080,0x2919001c,0xdb0b06a3,0x00000000}},	//   dpoř, āsa_, _angå,
  { {0x96ba0138,0x2fcd00ac,0xa3b90053,0x00000000}},	//   чуну_, _moeg_, चाई_,
  { {0x44392c00,0x6448017d,0x64a60785,0x00000000}},	//   _ais_, ídio, нага,
  { {0x44390199,0x6018006d,0x4736005d,0x00000000}},	//   _bis_, sími, برگز,
  { {0x04570021,0xdb0b0137,0xa6860054,0x00000000}},	//   علقة_, _engå, _злид,
  { {0x4439466f,0xe2970320,0x27e0149f,0x00000000}},	// [83a0] _dis_, нат_, _ilin_,
  { {0xdb0900ac,0x7981002b,0x44394670,0x00000000}},	//   edeë, nglw, _eis_,
  { {0x44394671,0x4096000d,0x61fe080f,0x00000000}},	//   _fis_, эрат, rnpl,
  { {0x24f5000d,0x44394672,0x7c39001f,0x00000000}},	//   _шчыр, _gis_, _niwr,
  { {0x245e02f4,0x2d9c4673,0x644101c8,0x00000000}},	//   lům_, teve_, íliv,
  { {0x4439000c,0x2d8e0003,0x2d9c0331,0x00000000}},	//   _zis_, uffe_, ueve_,
  { {0x245e0080,0x27e00ff2,0x2d9c4674,0x00000000}},	//   nům_, _olin_, reve_,
  { {0x8026007e,0x2d9c4675,0x2242004b,0x00000000}},	//   _سرزم, seve_, _kukk_,
  { {0x7c390185,0x20070003,0x245e004c,0x00000000}},	//   _diwr, énie_, hům_,
  { {0x27e04676,0x245e0080,0x2ca90051,0x00000000}},	//   _alin_, kům_, łada_,
  { {0x22420031,0x2918007a,0xdbd600fe,0x00000000}},	//   _lukk_, æra_, _pääl,
  { {0x245e0080,0x1ae6114d,0x040e0013,0x00000000}},	//   dům_, _поем, rưởn,
  { {0x6d4a0025,0x443936a0,0x7bc64677,0x00000000}},	//   ocfa, _ris_, ökuu,
  { {0x44394678,0x27f2002b,0x7afd0331,0x00000000}},	//   _sis_, _emyn_, úste,
  { {0xd5b80076,0x27e0001f,0xdbd600fe,0x00000000}},	//   хся_, _flin_, _tääl,
  { {0x6e3a0150,0xb5fb0080,0x69c80137,0x00000000}},	//   _litb, zsáh, ljde,
  { {0x98ac01f7,0x44394679,0x4668000d,0x00000000}},	// [83b0] madı_, _vis_, _прэм_,
  { {0x98ac005b,0x69da1781,0x443910da,0x00000000}},	//   ladı_, nkte, _wis_,
  { {0x69c80122,0x656700c2,0x69da03bf,0x00000000}},	//   ijde, majh, ikte,
  { {0x98ac0058,0xa8570063,0xddc202f7,0x00000000}},	//   nadı_, גיאה_, grož,
  { {0x2fcd1a20,0x2fdf00f5,0xdb0000b9,0x00000000}},	//   _voeg_, _vlug_, ldmæ,
  { {0x0c950062,0x7c39002b,0x63ad467a,0x00000000}},	//   вшия, _siwr, ldan,
  { {0x301b0021,0xdb0001e1,0x628d467b,0x00000000}},	//   _فترة_, ndmæ, ltao,
  { {0x63ad362c,0xdf72007e,0xeb99101a,0x00000000}},	//   ndan, _نگهب, фии_,
  { {0x8b25005a,0x63ad1366,0x628d467c,0x00000000}},	//   ъдие, idan, ntao,
  { {0x63ad2c17,0xfe67005d,0xb5fb013d,0x00000000}},	//   hdan, ید_, aráz,
  { {0x63ad467d,0x9b950021,0x27e0467e,0x00000000}},	//   kdan, _للات, _plin_,
  { {0x7981001f,0x245e0080,0x78bc0137,0x00000000}},	//   sglw, vům_, årva,
  { {0x63ad0106,0x21e400bd,0x7d040075,0x00000000}},	//   ddan, _höhe_, şist,
  { {0x7ae9000f,0x245e0080,0x69da467f,0x00000000}},	//   mzet, tům_, ckte,
  { {0xa806011c,0x7ae900ea,0x32134680,0x00000000}},	//   _изкл, lzet, doxy_,
  { {0x245e0080,0x7bdb00fe,0x6f160051,0x00000000}},	//   rům_, nkuu, życi,
  { {0x61460138,0xd5b1008b,0x628d00a4,0x00000000}},	// [83c0] веза, ốc_, gtao,
  { {0x7ae900ea,0x245e004c,0x63ad4681,0x00000000}},	//   izet, pům_, adan,
  { {0x7bdb024a,0xa067005a,0x7dd400cd,0x00000000}},	//   kkuu, ваха_, _màst,
  { {0x998500ea,0x63ad0075,0x9e660044,0x00000000}},	//   illő_, cdan, ناتن,
  { {0x69da0031,0x44444682,0x7f730054,0x00000000}},	//   ykte, _hu_, ргіє,
  { {0x44444683,0x6146005e,0xb5fb0139,0x00000000}},	//   _ku_, _јева, tsái,
  { {0xacf8000d,0xddc24684,0x6f092951,0x00000000}},	//   энку_, prož, _exec,
  { {0x3d160235,0xb5fb0025,0x776400cd,0x00000000}},	//   _पुणे_, rsái, _neix,
  { {0xda140002,0x7ae94685,0xdb0200ed,0x00000000}},	//   лдињ, gzet, _taoí,
  { {0x6e3a0173,0x44444686,0x63ad4687,0x00000000}},	//   _uitb, _ou_, zdan,
  { {0xddc20051,0x44444688,0x417b0063,0x00000000}},	//   zpoś, _nu_, וניב,
  { {0xb5fb0016,0xd0060593,0x69da4689,0x00000000}},	//   nsáv, صل_, skte,
  { {0x7764302e,0xb5fb017d,0x4444468a,0x00000000}},	//   _deix, isáv, _au_,
  { {0x4444468b,0xd6d80054,0xceb30063,0x00000000}},	//   _bu_, ттю_, ביש_,
  { {0x44440469,0x63ad069f,0x776403ea,0x00000000}},	//   _cu_, tdan, _feix,
  { {0x44440f4b,0x628d0072,0xdb0001e1,0x00000000}},	//   _du_, ttao, rdmæ,
  { {0x4444468c,0x63ad468d,0xb3640062,0x00000000}},	// [83d0] _eu_, rdan, ръск,
  { {0x4444468e,0x9f4f032a,0xddc20051,0x00000000}},	//   _fu_, rigí_, groż,
  { {0x628d0019,0x7ae9468f,0x82340021,0x00000000}},	//   stao, zzet, شركا,
  { {0x8014000d,0x7ae9013d,0x7e60002b,0x00000000}},	//   афіц, yzet, _bwmp,
  { {0x44440cd4,0x64450035,0x7e60002b,0x00000000}},	//   _zu_, _huhi, _cwmp,
  { {0x7ae90198,0xee38019d,0x8d54005a,0x00000000}},	//   vzet, вні_, атъч,
  { {0x64450019,0x65650019,0x44444690,0x00000000}},	//   _juhi, _mehh, _xu_,
  { {0x64450009,0x4aa9036a,0x6f0900cd,0x00000000}},	//   _muhi, екин_, _txec,
  { {0x7ae9017f,0x7e60001f,0x776400cd,0x00000000}},	//   uzet, _gwmp, _reix,
  { {0x2d830146,0x60180026,0xe8c90002,0x00000000}},	//   _øje_, símt, егол_,
  { {0x7ae900ea,0x77640367,0xdbd1004b,0x00000000}},	//   szet, _peix, _küül,
  { {0x907a0047,0x2cae013d,0xdce30111,0x00000000}},	//   עטרי, üldő_, nanč,
  { {0x64450019,0x44444691,0xe9a8007e,0x00000000}},	//   _auhi, _su_, ردین_,
  { {0x44444692,0x00000000,0x00000000,0x00000000}},	//   _pu_,   ,   ,
  { {0x44440c6e,0x999900eb,0xdce300eb,0x00000000}},	//   _qu_, ūsų_, kanč,
  { {0xdce300eb,0x44444693,0xdd030078,0x00000000}},	//   janč, _vu_, ūrėm,
  { {0x6d411847,0xdce30006,0xddc20051,0x00000000}},	// [83e0] _ogla, danč, troż,
  { {0x44444694,0x6d412389,0x2a6d002b,0x00000000}},	//   _tu_, _ngla, iseb_,
  { {0x44444695,0xcf9a018e,0x644500a4,0x00000000}},	//   _uu_, ејл_, _guhi,
  { {0xbe8a290b,0xdce30078,0xd3da0021,0x00000000}},	//   еске_, ganč, _أبدا_,
  { {0x442009fb,0x2d8a005b,0x44324696,0x00000000}},	//   mli_, _öbek_, mmy_,
  { {0xc6930063,0xdb0000d1,0xb33b00be,0x00000000}},	//   צאו_, ndmå, _caçu,
  { {0xac73007e,0x44204697,0x41270caa,0x00000000}},	//   مايش, oli_, _боро_,
  { {0x442001f7,0x3a740d4c,0x6018017c,0x00000000}},	//   nli_, алир, ríms,
  { {0xdd250006,0x27f90137,0x8e0a0054,0x00000000}},	//   rūši, visn_, _знав_,
  { {0x2a970032,0x3f86017d,0x44204698,0x00000000}},	//   ائية_, lgou_, hli_,
  { {0x0217014e,0x683e00eb,0x44204699,0x00000000}},	//   רחים_, _būda, kli_,
  { {0x4420007d,0x6445004d,0x3f86017d,0x00000000}},	//   jli_, _ruhi, ngou_,
  { {0xdb190051,0x44200ff8,0x64450077,0x00000000}},	//   _dowó, dli_, _suhi,
  { {0xceb300b5,0xdb0000bd,0x44320051,0x00000000}},	//   זיש_, rdmä, emy_,
  { {0xe5350121,0x4420469a,0x00000000,0x00000000}},	//   ревь, fli_,   ,
  { {0x4420469b,0xa7750062,0xb355469c,0x00000000}},	//   gli_, _тлич, ркаш,
  { {0x644a0003,0xd2510044,0x00000000,0x00000000}},	// [83f0] _éfin, زنا_,   ,
  { {0x4420469d,0x44f5047e,0x4432469e,0x00000000}},	//   ali_, _впос, amy_,
  { {0x43950088,0xdce30fb9,0x8b03004c,0x00000000}},	//   _канс, tanč, ěřil,
  { {0xb4c3024c,0x4420469f,0x673b007d,0x00000000}},	//   ्ही_, cli_, žuju,
  { {0x8d6546a0,0x1f64000d,0xea00008b,0x00000000}},	//   авле, скім, _giầy_,
  { {0x3f7500aa,0x7dd400cd,0xc27a0063,0x00000000}},	//   ều_, _bàsq, _ברשי,
  { {0x463c0047,0x228f21a5,0xfbd10021,0x00000000}},	//   געגע, lük_, قتة_,
  { {0x2a6d0019,0x7c640021,0x0b450189,0x00000000}},	//   tseb_, حاول, шнин,
  { {0x4a450fe2,0xf2d20041,0x99e50141,0x00000000}},	//   јнов, ַעט_, ижид,
  { {0x6d41027c,0x63af0066,0x601812c7,0x00000000}},	//   _ugla, _lacn, límp,
  { {0x44320051,0x97c646a1,0xf1b212cd,0x00000000}},	//   ymy_, айне, קסט_,
  { {0xd5b1001b,0x629d0438,0x5b150818,0x00000000}},	//   ốn_, _opso, _кмет,
  { {0x228f000f,0x25a30146,0x442046a2,0x00000000}},	//   jük_, fejl_, vli_,
  { {0x2d872f39,0x2ca7002b,0x44200022,0x00000000}},	//   ngne_, ownd_, wli_,
  { {0xdb00380f,0x2d8746a3,0x629d20d2,0x00000000}},	//   rdmå, igne_, _apso,
  { {0x442046a4,0xdb0b0813,0x864646a5,0x00000000}},	//   uli_, _pagè, _книж,

  { {0xf347026b,0x51660086,0x69dc087b,0x00000000}},	// [8400] рпул_, иваб, öreg,
  { {0x442046a6,0x63af0025,0xd5a4007e,0x00000000}},	//   sli_, _eacn, _الدی,
  { {0x442046a7,0xb5fb3b1c,0x161f0053,0x00000000}},	//   pli_, rsát, _मीटर_,
  { {0x99870006,0x2d8746a8,0x1e0e0042,0x00000000}},	//   _kinų_, egne_, ाक्ष_,
  { {0x63a4353c,0x3f8646a9,0x228f0058,0x00000000}},	//   mein, rgou_, cük_,
  { {0x8d63005e,0xdd900049,0xde031e97,0x00000000}},	//   овље, سوب_, опчи,
  { {0x9c57005e,0xcbe61527,0x2c4e0022,0x00000000}},	//   ашњу_, иции, _będa_,
  { {0xa7fd005b,0x63a446aa,0x2d910058,0x00000000}},	//   nsıt, nein, _özen_,
  { {0x75e20024,0xee3a1259,0x9f7b0063,0x00000000}},	//   _rôzn, _ана_, _שנמח,
  { {0xe61f0164,0x63a446ab,0x2a79013d,0x00000000}},	//   ntôt_, hein, ásba_,
  { {0x228f0b35,0x1d070062,0x63a446ac,0x00000000}},	//   zük_, _кефи_, kein,
  { {0x228f01f7,0x61d30161,0xdce80024,0x00000000}},	//   yük_, _दक्ष, _obdĺ,
  { {0x63a4420e,0xe1ff0124,0x7bc214a4,0x00000000}},	//   dein, _kvót_, _inou,
  { {0x63a40206,0xadf80053,0x628400dd,0x00000000}},	//   eein, ्चिन_, duio,
  { {0xd4370021,0xdb0031cd,0xb4c30042,0x00000000}},	//   لعرب, demé, ्हे_,
  { {0x63a446ad,0x228f00ea,0xf7f40044,0x00000000}},	//   gein, tük_, _وسيد,
  { {0xe6950032,0x809f0161,0x2d8c0552,0x00000000}},	// [8410] _الخد, _गैजे, _ocde_,
  { {0xf1a7018e,0xc05b013c,0xd628005e,0x00000000}},	//   јран, від_, _коње_,
  { {0xea00001b,0xdce3001c,0x36340021,0x00000000}},	//   _giấy_, kanā, _بريس,
  { {0x5f740021,0x63a446ae,0xa236008f,0x00000000}},	//   قاهر, cein, āršā_,
  { {0xf1a70095,0x82a40085,0x539a009a,0x00000000}},	//   _крвн, _даўж, _גירו,
  { {0xa184026c,0x1d0946af,0x75eb005b,0x00000000}},	//   _мысл, лели_, _düzg,
  { {0xddc90529,0x683f0078,0x2d8746b0,0x00000000}},	//   _aveţ, _rūdn, rgne_,
  { {0x6e45007e,0x3ff90047,0x7afd0066,0x00000000}},	//   _هنرم, _עפּע, ústo,
  { {0x75eb013d,0x00000000,0x00000000,0x00000000}},	//   _küzd,   ,   ,
  { {0x7bc20037,0x3ead00a4,0xa7fd0075,0x00000000}},	//   _enou, _iset_, ksıs,
  { {0xa889000d,0x34b30042,0xacb504a0,0x00000000}},	//   ыйна_, ुमोद, _دماغ,
  { {0xa09a0047,0xdb00013d,0x8a95005d,0x00000000}},	//   נירט, zemé, _هشتص,
  { {0xe9ce22ce,0x6b890b06,0x07a30591,0x00000000}},	//   _ек_, mgeg, чаян,
  { {0x63a423c6,0x6b8913e9,0x67f600c2,0x00000000}},	//   wein, lgeg, išji,
  { {0x8afd0080,0x69c346b1,0xb4260021,0x00000000}},	//   daři, _inne, معرو,
  { {0x680b0051,0xa7660001,0xdd3a003b,0x00000000}},	//   lędn, _укид, lăţi,
  { {0xb5fb0016,0x6b89004d,0x63a446b2,0x00000000}},	// [8420] rsár, igeg, rein,
  { {0xb5fb03d9,0x45860169,0x05aa46b3,0x00000000}},	//   ssár, _угов, _свой_,
  { {0x6b890d13,0x656e00ac,0xe1ff017d,0x00000000}},	//   kgeg, mabh, _avós_,
  { {0x6b89006f,0x645c46b4,0xa067005e,0x00000000}},	//   jgeg, mpri, саца_,
  { {0x20060003,0x6b890717,0x840800ea,0x00000000}},	//   rnoi_, dgeg, _előá,
  { {0x244e0024,0x2d9101f7,0x6b890717,0x00000000}},	//   _kým_, _özel_, egeg,
  { {0xa3cc0053,0x6b8905e4,0x2a7f004b,0x00000000}},	//   लाप_, fgeg, erub_,
  { {0x656e0025,0x69c346b5,0x645c0290,0x00000000}},	//   habh, _anne, ipri,
  { {0x6ff50045,0x75eb01f7,0xdd3a000c,0x00000000}},	//   jący, _yüzd, făţi,
  { {0xee373734,0xdd3a003b,0x321a00e5,0x00000000}},	//   _гну_, găţi, nopy_,
  { {0x2360006f,0x621b0063,0x645c07b4,0x00000000}},	//   kbij_, רויק, jpri,
  { {0x61fe005b,0x656e0025,0xa3cc0053,0x00000000}},	//   hipl, eabh, लाफ_,
  { {0xa3cc0235,0xdce1001c,0x61fe0058,0x00000000}},	//   लान_, _ielā, kipl,
  { {0x15eb0086,0xd5540062,0xdd3a003b,0x00000000}},	//   уємо_, зкръ, căţi,
  { {0x3c780063,0x6ff50022,0x41dc0042,0x00000000}},	//   יָּב, rącz, _मक़स,
  { {0xb8de0053,0xa7fd0075,0x244e011b,0x00000000}},	//   ीम_, asır, _dým_,
  { {0x27e91bfe,0x61f9000d,0x290b003b,0x00000000}},	// [8430] _ilan_, анаў_, şcat_,
  { {0x645c46b6,0x4958009a,0x00000000,0x00000000}},	//   bpri, שֻּׁ,   ,
  { {0x463c00b5,0x185b0047,0xc108000d,0x00000000}},	//   _געזע, ָכדע, бэце_,
  { {0x75eb01f7,0xdb090025,0x680b0051,0x00000000}},	//   _düze, hdeá, zędn,
  { {0xf41f0072,0x8afd004c,0x765d0244,0x00000000}},	//   _ikä_, obře, npsy,
  { {0x2718001b,0x27e9002b,0xe057005d,0x00000000}},	//   ọng_, _llan_, _هیئت_,
  { {0x27e901f7,0x6812001c,0x75eb005b,0x00000000}},	//   _olan_, lāde, _güze,
  { {0x5f940001,0x8c420ac5,0x68ed004c,0x00000000}},	//   _нист, меще, _řado,
  { {0xdd3a0529,0x6b893848,0xdb0b00bd,0x00000000}},	//   tăţi, rgeg, _ungü,
  { {0x6b8928e7,0x75eb005b,0x27e946b7,0x00000000}},	//   sgeg, _yüze, _alan_,
  { {0x6b89006f,0xdd3a003b,0x18690002,0x00000000}},	//   pgeg, răţi, јами_,
  { {0xe73a05fb,0x2243006f,0x3eb80078,0x00000000}},	//   иен_, _lijk_, žetų_,
  { {0x501a0063,0x69dc0058,0xaaf20041,0x00000000}},	//   שורו, örec, _גאַסט_,
  { {0x1a9a0047,0x69c312a9,0xcb360063,0x00000000}},	//   _כינע, _unne, _ואני_,
  { {0x656e0027,0x2360006f,0x2ea60053,0x00000000}},	//   rabh, tbij_, _गन्त,
  { {0xfe08008b,0x27e946b8,0x200d0078,0x00000000}},	//   iữa_, _glan_, _njei_,
  { {0x236002b0,0x645c46b9,0x6812001c,0x00000000}},	// [8440] rbij_, spri, gāde,
  { {0x645c46ba,0x201f0397,0x244e027d,0x00000000}},	//   ppri, _akui_, _tým_,
  { {0x397a0047,0x22433a73,0x321a03a4,0x00000000}},	//   שטענ, _dijk_, ropy_,
  { {0x224b1b47,0xe3ba000d,0x61fe0b45,0x00000000}},	//   _fuck_, _тбм_, sipl,
  { {0x661c0162,0xddc920d2,0x2d5801d5,0x00000000}},	//   oork, _sveš, биль_,
  { {0xddc90080,0x75eb46bb,0xe61f0013,0x00000000}},	//   _kteř, _tüze, huôn_,
  { {0xc0c90079,0x6da300d7,0xada30002,0x00000000}},	//   _луѓе_, фија, фајл,
  { {0x2d80000c,0x63b62761,0x9ad40cb2,0x00000000}},	//   şie_, ndyn, зжич,
  { {0xcb670138,0x49a60002,0x661c46bc,0x00000000}},	//   цање_, ојна, kork,
  { {0x63b6002b,0xdca624cc,0x661c46bd,0x00000000}},	//   hdyn, _мази, jork,
  { {0xf2df001b,0xd9170121,0x661c449c,0x00000000}},	//   _ngân_, жья_, dork,
  { {0xad1b0063,0x8ba60363,0x8ae60054,0x00000000}},	//   _דובר, _фидж, _мілл,
  { {0x63b6001f,0xd6d80121,0x661c01f2,0x00000000}},	//   ddyn, отр_, fork,
  { {0xdcfa005b,0x7a2f00d1,0x672d00c2,0x00000000}},	//   _hatı, tøte, _vzaj,
  { {0x22430122,0xdcfa01f7,0x200700ea,0x00000000}},	//   _rijk_, _katı, énik_,
  { {0x69d802ab,0x27e946be,0x3857007e,0x00000000}},	//   _hove, _ulan_, _بشود_,
  { {0x661c46bf,0x672d194f,0xd2290021,0x00000000}},	// [8450] bork, _uzaj, مكره_,
  { {0x6812003d,0x201f00ac,0x661c0089,0x00000000}},	//   rāde, _skui_, cork,
  { {0x69d83f1b,0xb4b5007f,0xdb0046c0,0x00000000}},	//   _move, _эйнш, nemâ,
  { {0x6d48002c,0x2243006f,0x9f9700cd,0x00000000}},	//   _agda, _wijk_, _açò_,
  { {0x9e640086,0xed5946c1,0xdb0b00be,0x00000000}},	//   двід, бол_, _pagí,
  { {0xdce1003b,0xbdc70121,0xa37b004b,0x00000000}},	//   _nelă, ющей, _slõh,
  { {0x459c00b5,0xdcfa005b,0x6da202a1,0x00000000}},	//   יסגע, _batı, хища,
  { {0x6e950076,0x2bb90021,0xce950062,0x00000000}},	//   _нибу, صابة_, _набъ,
  { {0x69d802b0,0x7ddd00cd,0x201d0051,0x00000000}},	//   _bove, _bèst, mowi_,
  { {0x69d846c2,0xdce1003b,0xf2a7000d,0x00000000}},	//   _cove, _celă, скiх_,
  { {0xd8260f9f,0x69d846c3,0xd7ca005d,0x00000000}},	//   здни, _dove, موده_,
  { {0x201d0051,0xf7460612,0x764d017e,0x00000000}},	//   nowi_, яемо, _buay,
  { {0xdce80080,0xf71a000d,0x661c1e4a,0x00000000}},	//   _oddě, сіны_, tork,
  { {0x2ca90051,0x69d830a8,0x4a44000d,0x00000000}},	//   ładu_, _gove, _жнів,
  { {0xdcfa005b,0x201d0051,0x99d40021,0x00000000}},	//   _yatı, kowi_, _تتنا,
  { {0x487a014e,0x69d846c4,0x201d0022,0x00000000}},	//   _הטקס, _zove, jowi_,
  { {0x764d1c5d,0x63b612cc,0x201d0022,0x00000000}},	// [8460] _guay, rdyn, dowi_,
  { {0x42230079,0xdb0000be,0x33190085,0x00000000}},	//   едув, lemã, ціся_,
  { {0x6296002c,0xd00a0121,0x68e100a3,0x00000000}},	//   styo, беже_, nyld,
  { {0x61e52b39,0x3ebf0f91,0x69c50046,0x00000000}},	//   akhl, _brut_, _óhef,
  { {0x3ebf46c5,0xdee345f6,0xe81d0042,0x00000000}},	//   _crut_, ноци, नवता_,
  { {0xdcfa01f7,0x61fc02e2,0x68e146c6,0x00000000}},	//   _satı, _umrl, kyld,
  { {0xd5b1001b,0x64580164,0x44220019,0x00000000}},	//   ối_, _évid, _kkk_,
  { {0x69d80bcf,0x75eb005b,0x201d0022,0x00000000}},	//   _sove, _müza, cowi_,
  { {0x6446007a,0x69d846c7,0x5a3438af,0x00000000}},	//   _miki, _pove, мнит,
  { {0x68e10146,0x644646c8,0x6284262b,0x00000000}},	//   fyld, _liki, irio,
  { {0x68e10205,0x9b46007e,0x628413d5,0x00000000}},	//   gyld, _فناو, hrio,
  { {0x64462de0,0x683f0078,0x26c046c9,0x00000000}},	//   _niki, _kūdi, _brio_,
  { {0x9f4d0137,0x69d846ca,0x95cb06da,0x00000000}},	//   _umeå_, _tove, бува_,
  { {0x26c0001f,0x69d806a5,0x4a7b009f,0x00000000}},	//   _drio_, _uove, _פרוב,
  { {0x2c55001c,0x64460b21,0x442200ac,0x00000000}},	//   _kāda_, _biki, _bkk_,
  { {0x683f003d,0x26c0017d,0x6284155f,0x00000000}},	//   _līdz, _frio_, frio,
  { {0xe8020053,0x442246cb,0x64461324,0x00000000}},	// [8470] _लगता_, _dkk_, _diki,
  { {0x64460006,0x645a0b16,0x7afd225f,0x00000000}},	//   _eiki, ític, ústi,
  { {0x6284048e,0xdb0b000f,0x64461d9c,0x00000000}},	//   ario, _magá, _fiki,
  { {0x683f0006,0x62840aca,0x7c220137,0x00000000}},	//   _būdi, brio, _nkor,
  { {0x4ea70088,0x442946cc,0x62840025,0x00000000}},	//   яржа, mla_, crio,
  { {0x442946cd,0x6da2005a,0x64460306,0x00000000}},	//   lla_, виша, _ziki,
  { {0x6114000a,0x442946ce,0x62340062,0x00000000}},	//   _здру, ola_, _черу,
  { {0x442925c5,0x6812001c,0x69dc46cf,0x00000000}},	//   nla_, kāda, ören,
  { {0x6b9b46d0,0x442946d1,0x3ebf3ad5,0x00000000}},	//   rfug, ila_, _urut_,
  { {0x7c220228,0xf2df0013,0xdb0900ca,0x00000000}},	//   _ekor, _ngâm_, leeë,
  { {0xc1720063,0xf3ff00be,0xdb0000be,0x00000000}},	//   כחי_, _omã_, temã,
  { {0xad1a00b7,0x3f8f0e53,0xdb09006f,0x00000000}},	//   _ווער, nggu_, neeë,
  { {0x7c2901f7,0x442946d2,0x644645bb,0x00000000}},	//   mler, dla_, _riki,
  { {0x442946d3,0x644646d4,0x8afd004c,0x00000000}},	//   ela_, _siki, sařs,
  { {0x644600f3,0x394e0024,0x442246d5,0x00000000}},	//   _piki, ájsť_, _pkk_,
  { {0x7c2901f7,0x628426a4,0x26c046d6,0x00000000}},	//   nler, trio, _trio_,
  { {0x644646d7,0xec09001b,0x62843716,0x00000000}},	// [8480] _viki, yến_, urio,
  { {0x64460280,0xea00008b,0x7c2946d8,0x00000000}},	//   _wiki, _phẩy_, hler,
  { {0x7c2925c5,0x442946d9,0x644646da,0x00000000}},	//   kler, bla_, _tiki,
  { {0xe8d60047,0x442236b0,0x44292aac,0x00000000}},	//   ווער_, _ukk_, cla_,
  { {0x7c290dfb,0x2c55001c,0x442000fe,0x00000000}},	//   dler, _rāda_, moi_,
  { {0x7bdd00bd,0xa3cc0053,0x7c293631,0x00000000}},	//   ösun, लाव_, eler,
  { {0xdb0002dd,0x7c2901f7,0x44200186,0x00000000}},	//   demá, fler, ooi_,
  { {0xdfa60032,0xdb000268,0x7c2902e0,0x00000000}},	//   _تحسي, temà, gler,
  { {0xc98625f8,0x7c2200a8,0x34ab0042,0x00000000}},	//   муни, _vkor, _चन्द,
  { {0x442904ab,0x442046db,0x7e6246dc,0x00000000}},	//   zla_, hoi_, mpop,
  { {0x442946dd,0xca48008b,0x2c55001c,0x00000000}},	//   yla_, _mời_, _tāda_,
  { {0xca48001b,0x44290137,0x7c2246de,0x00000000}},	//   _lời_, xla_, _ukor,
  { {0x683f0080,0xd5bb0062,0x442046df,0x00000000}},	//   jádř, осв_, doi_,
  { {0x7c20000f,0x2a69005b,0x6812008f,0x00000000}},	//   lomr, _çaba_, rāda,
  { {0xa504000d,0x442946e0,0x69ca46e1,0x00000000}},	//   вятл, tla_, _infe,
  { {0x44291fff,0x44201f36,0x7853003b,0x00000000}},	//   ula_, goi_, _zăvo,
  { {0x6d5a37f7,0xd774007e,0x442946e2,0x00000000}},	// [8490] _ofta, _شايع, rla_,
  { {0x44200027,0x7c2901f7,0x68ed0080,0x00000000}},	//   aoi_, zler, _řadi,
  { {0x96180021,0x7c2946e3,0x442946e4,0x00000000}},	//   _تغير_, yler, pla_,
  { {0x6d5a1c23,0x4420120d,0xca48008b,0x00000000}},	//   _afta, coi_, _dời_,
  { {0x7e6200a4,0x7c292d12,0x63ad46e5,0x00000000}},	//   gpop, vler, mean,
  { {0x69dc00c7,0x7c2946e6,0x63ad46e7,0x00000000}},	//   örel, wler, lean,
  { {0x7c2946e8,0xdb0000b9,0x4c92005e,0x00000000}},	//   tler, nemæ, гијс,
  { {0x7c3b001c,0x7c200093,0x69ca071c,0x00000000}},	//   umur, gomr, _anfe,
  { {0x7c2901f7,0xdb0006b2,0x7c3b46e9,0x00000000}},	//   rler, temá, rmur,
  { {0x63ad0027,0xe1ff0051,0x9ce7005a,0x00000000}},	//   hean, _swój_, _оцел,
  { {0x7c200d96,0xbc680032,0x31710290,0x00000000}},	//   bomr, _يمكن_, _mezz_,
  { {0x69ca46ea,0xcc560063,0x8cae0042,0x00000000}},	//   _enfe, _טבעי_, ूटरो,
  { {0x63ad0027,0x6d4700ea,0x7bcb46eb,0x00000000}},	//   dean, _újab, _ingu,
  { {0xba390047,0xec09008b,0x4420056c,0x00000000}},	//   _צײַט, iếm_, woi_,
  { {0xe1ff0045,0x07a60086,0x65c3026c,0x00000000}},	//   _twój_, _зайн, ыбра,
  { {0x4420175f,0xca48008b,0x683f0006,0x00000000}},	//   uoi_, _rời_, _būdu,
  { {0xb5fb00ea,0x75f00066,0x442046ec,0x00000000}},	// [84a0] mpán, _väzb, roi_,
  { {0xdb0000b9,0x442000fe,0x171b0063,0x00000000}},	//   bemæ, soi_, _מופע,
  { {0x44200529,0x63ad46ed,0x6812008f,0x00000000}},	//   poi_, bean, nādo,
  { {0x14d70063,0xca480013,0xc2090063,0x00000000}},	//   _נוכל_, _vời_, זה_,
  { {0x2bd30161,0x3f9a0051,0xa2e30062,0x00000000}},	//   थाना, ępu_, _бояд,
  { {0x7bcb2e34,0x7e6230c1,0x200f46ee,0x00000000}},	//   _angu, rpop, angi_,
  { {0x7e7c001c,0x987e0080,0x7c20011d,0x00000000}},	//   _ārpu, _péče_, tomr,
  { {0xa2c40053,0x2c7a001c,0xcfaa005d,0x00000000}},	//   रिप्, rīd_, _عازم_,
  { {0x7c20011d,0x20060072,0x8c43005e,0x00000000}},	//   romr, mioi_, ћење,
  { {0xf65f0026,0x7bcb2723,0x7c203588,0x00000000}},	//   lvæg_, _engu, somr,
  { {0xa7fd005b,0x79a3000d,0x63ad05b3,0x00000000}},	//   msız, урые, yean,
  { {0xc02e001b,0x9cd70063,0x7c650593,0x00000000}},	//   _điều_, _רואה_, _شامل,
  { {0xf804000d,0x95cb026b,0x09e61c09,0x00000000}},	//   учэн, пува_, _подн,
  { {0xa2c40161,0x2d91005b,0xa7fd005b,0x00000000}},	//   रिन्, _özet_, nsız,
  { {0x63ad0027,0xa25b017d,0xf484032d,0x00000000}},	//   tean, _crôn, лутн,
  { {0xdb000146,0xb21b00b9,0xa7fd0058,0x00000000}},	//   remæ, _kvæg, hsız,
  { {0x63ad0027,0x59b70053,0x200f00d1,0x00000000}},	// [84b0] rean, _असमर, vngi_,
  { {0x63ad46ef,0xdb00004b,0x6836011b,0x00000000}},	//   sean, memä, ráde,
  { {0xdb000963,0xddc9005b,0x63ad46f0,0x00000000}},	//   lemä, _ateş, pean,
  { {0x66070b7d,0x200f051e,0x6458006c,0x00000000}},	//   lijk, ungi_, _évia,
  { {0xed4e0001,0x2369000c,0x200f0e41,0x00000000}},	//   ио_, mbaj_, rngi_,
  { {0xd6580063,0x200f1de9,0x66071634,0x00000000}},	//   עיות_, sngi_, nijk,
  { {0x1fa7126b,0xdb000019,0xd214005e,0x00000000}},	//   _праг, hemä, _смрћ,
  { {0xdb0000fe,0x30350121,0xdb4e0044,0x00000000}},	//   kemä, _ребё, يَى_,
  { {0x660702b0,0x13c8009a,0xef650075,0x00000000}},	//   kijk, תּוֹ_, ğıdı_,
  { {0x7d79007e,0x3ea20137,0xe1ff0139,0x00000000}},	//   _آمار_, _äkta_, _dtóg_,
  { {0x9be70086,0x660700ca,0xdcea00dd,0x00000000}},	//   _підк, dijk, rafă,
  { {0x66e60002,0x6812001c,0x6e23264d,0x00000000}},	//   вома, rādo, lonb,
  { {0x26c40080,0x9f4f006d,0xaae4007e,0x00000000}},	//   ímo_, ligó_, _مسوو,
  { {0xa25b0003,0xb5fb2405,0x6e2301e1,0x00000000}},	//   _prôn, spán, nonb,
  { {0xdce3004c,0xdd03008f,0xa7fd0058,0x00000000}},	//   vaně, ērķi, mpın,
  { {0xb8f5016a,0x6f1e0051,0x442600be,0x00000000}},	//   सम_, ępcz, ôo_,
  { {0xe61a000a,0x200600fe,0x44392c7f,0x00000000}},	// [84c0] _оди_, vioi_, _dhs_,
  { {0xf1aa006a,0xa25b46f1,0xc64a0021,0x00000000}},	//   باره_, _trôn, _تجعل_,
  { {0xdce30080,0x27e00150,0xdb0001e1,0x00000000}},	//   raně, _koin_, memå,
  { {0x27e00c69,0xefd5000d,0xdb0005e7,0x00000000}},	//   _join_, лючэ, lemå,
  { {0xa7fd005b,0x6e2346f2,0x69dc21d2,0x00000000}},	//   tsız, fonb, örek,
  { {0x27e00164,0x27f2001f,0x6e233fe6,0x00000000}},	//   _loin_, _llyn_, gonb,
  { {0x200600fe,0xa7fd005b,0x6026000d,0x00000000}},	//   pioi_, rsız, _адва,
  { {0xeb970138,0x27e0024a,0x6ce30086,0x00000000}},	//   вић_, _noin_, ріше,
  { {0x2d960ac5,0xea00008b,0x8c43005e,0x00000000}},	//   _арес, _nhảy_, шеће,
  { {0x680400ea,0x27f200a3,0xada30094,0x00000000}},	//   sődl, _alyn_, _вафл,
  { {0xdb000093,0x5a33000d,0x7afd46f3,0x00000000}},	//   demå, рнэт, ústr,
  { {0x66070122,0x27e004bc,0x9b060002,0x00000000}},	//   wijk, _coin_, _изед,
  { {0xa3cc0053,0xea00008b,0x4ab60042,0x00000000}},	//   लाई_, _chảy_, _अनिव,
  { {0x4b37014e,0x27e00025,0xa25b0003,0x00000000}},	//   _סרגל_, _eoin_, _drôl,
  { {0x660702b0,0x48e30095,0x64740ace,0x00000000}},	//   rijk, _војв, игру,
  { {0xe414019d,0x926b000a,0x27f2001f,0x00000000}},	//   адсь, држа_, _glyn_,
  { {0x6b820035,0x68e82688,0x98be0058,0x00000000}},	// [84d0] _mdog, lydd, matı_,
  { {0x35b5047e,0x2fcd00b2,0x75d50021,0x00000000}},	//   _сбор, _sneg_, _إيدا,
  { {0x21a4019d,0xc0580088,0x68e80185,0x00000000}},	//   риєм, віч_, nydd,
  { {0x6b820009,0x25b1004c,0x98be0058,0x00000000}},	//   _ndog, lezl_, natı_,
  { {0x68e8001f,0x63bd00a4,0xde580054,0x00000000}},	//   hydd, _iasn, вачі_,
  { {0x68e800c7,0x63bd1c80,0x7e240054,0x00000000}},	//   kydd, _hasn, адіж,
  { {0x63bd065f,0xe0d4005e,0x98be0058,0x00000000}},	//   _kasn, _корњ, katı_,
  { {0x68e8001f,0xf42a00fe,0x6e231b3e,0x00000000}},	//   dydd, _isää_, sonb,
  { {0x6b82001f,0x63bd46f4,0x0a490121,0x00000000}},	//   _ddog, _masn, нзий_,
  { {0x27e00164,0x68e8001f,0x63bd0e78,0x00000000}},	//   _soin_, fydd, _lasn,
  { {0x27e000f3,0xdb0002ab,0x7794007e,0x00000000}},	//   _poin_, vemå, لیغا,
  { {0x69da085a,0xf64907e9,0x645a1358,0x00000000}},	//   ajte, _זצ_, ítim,
  { {0x27e000fe,0xa9a501e2,0xdb0b1b62,0x00000000}},	//   _voin_, _билд, _lagú,
  { {0x68e8001f,0x7bdb004b,0x7a7a0063,0x00000000}},	//   bydd, ljuu, _טרנס,
  { {0xdb0041da,0xa25b38b1,0x98be0058,0x00000000}},	//   remå, _drôm, batı_,
  { {0xdb0000d1,0x7bdd112c,0x63bd0e2f,0x00000000}},	//   semå, ösuh, _casn,
  { {0x7ae946f5,0x7afb004d,0x070a0021,0x00000000}},	// [84e0] nyet, nzut, _سيدي_,
  { {0x764b0164,0x63bd0139,0x7ae90058,0x00000000}},	//   _égyp, _easn, iyet,
  { {0x63bd001f,0x98a6007d,0x08760047,0x00000000}},	//   _fasn, čiće_, ָענט_,
  { {0xf1d20053,0x63bd46f6,0xa3e80042,0x00000000}},	//   साहन, _gasn, _भवि_,
  { {0x42d5000d,0x7e2a0304,0xdb200058,0x00000000}},	//   _кіру, ніка_, ütül,
  { {0xdcba005a,0x7ae900a4,0x63bd158e,0x00000000}},	//   ещи_, dyet, _zasn,
  { {0x98be005b,0xea00008b,0xa1160049,0x00000000}},	//   yatı_, _nhạy_, _صورت,
  { {0x63a446f7,0x200407b7,0x7afb004d,0x00000000}},	//   nfin, _ummi_, fzut,
  { {0x68e80c70,0x63a41c8f,0x3eba0023,0x00000000}},	//   wydd, ifin, āpts_,
  { {0xa7fd005b,0x68e846f8,0x02b70047,0x00000000}},	//   apıl, tydd, נליך_,
  { {0xea00001b,0xd90d007e,0x48153e42,0x00000000}},	//   _chạy_, ویه_, имос,
  { {0x3c0c004c,0x68360139,0x68e81e47,0x00000000}},	//   těvu_, táda, rydd,
  { {0x68e8001f,0x75f00066,0x63bd0734,0x00000000}},	//   sydd, _väzn, _rasn,
  { {0x6595000a,0x63bd003d,0x29560062,0x00000000}},	//   јаву, _sasn, _съдр,
  { {0x63bd46f9,0x683601c8,0x63a446fa,0x00000000}},	//   _pasn, mádn, ffin,
  { {0x75eb005b,0x78a50019,0x7bc01b35,0x00000000}},	//   _müzi, _ähva, ndmu,
  { {0x9295047e,0x2ba60053,0x91750160,0x00000000}},	// [84f0] разц, क्या, игац,
  { {0xddc900b2,0x395e46fb,0xe2a60014,0x00000000}},	//   _svež, ncts_, æðan_,
  { {0xfaf90006,0x5fe70086,0xffe7013c,0x00000000}},	//   lbūt_, лідж, людн,
  { {0xa295126b,0xdef10021,0x00000000,0x00000000}},	//   _камі, يًا_,   ,
  { {0x7415007e,0x6db50054,0xe37a009a,0x00000000}},	//   _موگا, ийду, _שרשר,
  { {0x7bc7003d,0x644f02dd,0x7ae90058,0x00000000}},	//   ējum, _hici, vyet,
  { {0x2c55003d,0xc2120063,0x290a017d,0x00000000}},	//   _kādi_, _והם_, úbal_,
  { {0x6a85005a,0x7afb004d,0xddc9007d,0x00000000}},	//   алиа, tzut, _uvež,
  { {0xde590086,0xa7fd0058,0xedd5007e,0x00000000}},	//   _разі_, rpıl, _پياد,
  { {0x644f46fc,0x7bdb0019,0xb9550001,0x00000000}},	//   _lici, sjuu, штић,
  { {0x2d8512a9,0x7afb0a67,0x63a446fd,0x00000000}},	//   _idle_, szut, yfin,
  { {0x644f141b,0xf7460256,0x680b056c,0x00000000}},	//   _nici, иено, wędr,
  { {0x64570764,0x387e003b,0x9a880021,0x00000000}},	//   _auxi, astr_, _مَنْ_,
  { {0x7ae600c7,0x644f001c,0xa2c40053,0x00000000}},	//   äkte, _aici, रिस्,
  { {0x644f46fe,0x15460131,0xab5d0022,0x00000000}},	//   _bici, ревм, adże,
  { {0x69c1007a,0x3ead017f,0xdb1b00cd,0x00000000}},	//   ldle, _opet_, nduï,
  { {0x644f46ff,0xc156005e,0xa2064700,0x00000000}},	// [8500] _dici, ањењ, апад,
  { {0x667b0047,0x69c12cb0,0x644f008f,0x00000000}},	//   _שטיק, ndle, _eici,
  { {0xf3f1001b,0x6026000d,0x657c11d4,0x00000000}},	//   ệc_, аджа, marh,
  { {0xbe8a290b,0x657c0626,0x2a7f1aff,0x00000000}},	//   вске_, larh, ksub_,
  { {0x6812008f,0xdb09013d,0x44324701,0x00000000}},	//   gādi, ideó, mly_,
  { {0x443204bf,0x644400fe,0x236000c2,0x00000000}},	//   lly_, lmii, lcij_,
  { {0xed570138,0xeb0e0161,0x69c14702,0x00000000}},	//   шој_, ाप्त_, ddle,
  { {0x44320034,0x317800bd,0x236000c2,0x00000000}},	//   nly_, _herz_, ncij_,
  { {0x44324703,0x69c10122,0x657c4704,0x00000000}},	//   ily_, fdle, karh,
  { {0x2c0b007e,0x644400fe,0x44324705,0x00000000}},	//   _یعنی_, hmii, hly_,
  { {0x236000c3,0x44324706,0x245c004a,0x00000000}},	//   kcij_, kly_, _ním_,
  { {0xcb6a4707,0x683d01f4,0xb5fb013d,0x00000000}},	//   _раде_, kéde, ppák,
  { {0x443204a3,0xab5d0051,0x67010053,0x00000000}},	//   dly_, udże, _लेखक_,
  { {0x44320e03,0x644f4708,0xfaf913ed,0x00000000}},	//   ely_, _sici, rbūt_,
  { {0x6ab60161,0x245c000f,0x442b0089,0x00000000}},	//   _अनुर, _cím_, _pkc_,
  { {0x26c9008b,0x64570137,0xc3550092,0x00000000}},	//   _trao_, _vuxi, скај,
  { {0x644f057a,0xdb0005b9,0x645700ca,0x00000000}},	// [8510] _vici, gemø, _wuxi,
  { {0x644f001f,0x51f8000d,0xd14b007e,0x00000000}},	//   _wici, аную_, نشان_,
  { {0x443228f0,0x3ead00c3,0x2c55008f,0x00000000}},	//   bly_, _spet_, _tādi_,
  { {0x44320034,0x40350121,0x683d01a8,0x00000000}},	//   cly_, щеес, béde,
  { {0x683d03b2,0x7a3d0164,0xec09008b,0x00000000}},	//   céde, lète, iết_,
  { {0x6812003d,0x44290d9e,0xec090013,0x00000000}},	//   rādi, loa_, hết_,
  { {0x22590205,0x7a3d0003,0xfbd100de,0x00000000}},	//   _husk_, nète, كتة_,
  { {0x3ea90268,0x2a7f0019,0x6a950086,0x00000000}},	//   çats_, tsub_, броє,
  { {0x8d87006a,0xeab10021,0x7a3d0003,0x00000000}},	//   _نشان, سعة_, hète,
  { {0x44294709,0xe9d9470a,0x4432004c,0x00000000}},	//   hoa_, уко_, zly_,
  { {0x69c1470b,0x4432098d,0x442935ac,0x00000000}},	//   rdle, yly_, koa_,
  { {0x6be40021,0x245c0066,0x44290050,0x00000000}},	//   _وكلم, _rím_, joa_,
  { {0x44290009,0x290b0051,0xfaf90006,0x00000000}},	//   doa_, ńca_, rbūs_,
  { {0x44320034,0x69dc00c7,0xe5a60001,0x00000000}},	//   wly_, öret, љиви,
  { {0x44320034,0x657c470c,0x74160044,0x00000000}},	//   tly_, rarh, موسا,
  { {0x245c004c,0x225901e1,0xdce3008f,0x00000000}},	//   _vím_, _busk_, lanē,
  { {0x44320034,0x64440072,0x236000c2,0x00000000}},	// [8520] rly_, rmii, rcij_,
  { {0x245c0114,0x44324705,0x2ca90022,0x00000000}},	//   _tím_, sly_, łady_,
  { {0xef6501f7,0x2c55003d,0x4432470d,0x00000000}},	//   ğını_, _kādu_, ply_,
  { {0xea00008b,0xef65005b,0xc0a90021,0x00000000}},	//   _thầy_, şını_, شامل_,
  { {0x3178051f,0x63b6470e,0xb184011b,0x00000000}},	//   _terz_, meyn, _íťov,
  { {0x6296005b,0x63b6470f,0x6dc30062,0x00000000}},	//   muyo, leyn, зсъж,
  { {0xec09001b,0x6296005b,0x763b0047,0x00000000}},	//   yết_, luyo, װעקג,
  { {0x8fa327c8,0x447b0047,0x7c294710,0x00000000}},	//   _насе, אנקע, goer,
  { {0x6296005b,0xd9f80121,0xfd9a0021,0x00000000}},	//   nuyo, иниц_, _مئات_,
  { {0x660e003e,0x2d9806a5,0xf2d30063,0x00000000}},	//   jibk, _øre_, פעת_,
  { {0xe1ff0331,0x7c291023,0xa8a30094,0x00000000}},	//   _otón_, boer, пряк,
  { {0x6812001c,0x683600ea,0x7c292069,0x00000000}},	//   kādu, ládj, coer,
  { {0x6e2a0159,0x41c80053,0x69dc086f,0x00000000}},	//   oofb, रयास, öres,
  { {0xa2ae0082,0x00000000,0x00000000,0x00000000}},	//   ुबन्,   ,   ,
  { {0x442924d4,0xb97b0149,0x25fa0042,0x00000000}},	//   toa_, _גרוז, _उतरी_,
  { {0x7a3d0003,0x56950062,0xb8de0042,0x00000000}},	//   rète, _даит, ुट_,
  { {0x6296002c,0x44294711,0xdcf800c2,0x00000000}},	// [8530] guyo, roa_, davč,
  { {0xf77f0268,0x44294712,0x7a3d006c,0x00000000}},	//   laç_, soa_, pète,
  { {0x442930d7,0xd13b373b,0x61ea0046,0x00000000}},	//   poa_, уха_, öfla,
  { {0x753a00bd,0x2d9e4713,0x20090013,0x00000000}},	//   ütze, _acte_, òai_,
  { {0x7c2903a8,0x539a0063,0x201c017d,0x00000000}},	//   voer, _דירו, évia_,
  { {0xdc3c001c,0x6d47013d,0x7e6d00dd,0x00000000}},	//   kšēj, _újak, ţapo,
  { {0xdddb003b,0x7c2901ac,0xf77f0058,0x00000000}},	//   _avuţ, toer, kaç_,
  { {0x7bc2066d,0xd0100044,0x00000000,0x00000000}},	//   _caou, _كلّ_,   ,
  { {0x0ae60076,0x200f00c3,0x7c290b28,0x00000000}},	//   ждый_, migi_, roer,
  { {0x78a90001,0x200f4714,0x7ae60137,0x00000000}},	//   аког_, ligi_, äkta,
  { {0xdc3c001c,0xdb090331,0x99580023,0x00000000}},	//   gšēj, rdeñ, kšņi_,
  { {0xa09a00b5,0x69dc4715,0x6296005b,0x00000000}},	//   סירט, örer, yuyo,
  { {0xddc2001c,0x200f0019,0x63b60058,0x00000000}},	//   lpoš, iigi_, veyn,
  { {0xf3f100aa,0xdce80080,0x6b9b004b,0x00000000}},	//   ện_, _nedě, lgug,
  { {0x2c55001c,0x49b8007e,0x628b2c74,0x00000000}},	//   _tādu_, _داند_, ágon,
  { {0x69c34716,0xf77f0268,0x6b9b04b4,0x00000000}},	//   _hane, caç_, ngug,
  { {0x2c55001c,0x7e690290,0x63b60026,0x00000000}},	// [8540] _kāds_, _ntep, reyn,
  { {0xea00001b,0x69c34717,0x6296005b,0x00000000}},	//   _thấy_, _jane, ruyo,
  { {0x69c33b3b,0xd7f900dd,0x10a30054,0x00000000}},	//   _mane, mpăr_, дихн,
  { {0x888a00b5,0xe29a4718,0xb21b01e1,0x00000000}},	//   שרײַ, _кам_, _hvæl,
  { {0xf67600b5,0x6e2a0104,0xb21b000e,0x00000000}},	//   קײַט_, tofb, _kvæl,
  { {0x8c660086,0x7bc2066d,0x200f0078,0x00000000}},	//   отид, _saou, aigi_,
  { {0xf77f005b,0xac940121,0xb5fb00f8,0x00000000}},	//   yaç_, чайш, mpát,
  { {0x7a340994,0x62840b4f,0x69c3006f,0x00000000}},	//   màti, osio, _aane,
  { {0x69c34719,0x628411b3,0x7a3401a8,0x00000000}},	//   _bane, nsio, làti,
  { {0xc3330063,0x094a2f16,0x6284175c,0x00000000}},	//   ווח_, ични_, isio,
  { {0xf816001b,0x61e300bd,0x69c3471a,0x00000000}},	//   ước_, önli, _dane,
  { {0x2fc6002c,0x6284471b,0x6249011b,0x00000000}},	//   ndog_, ksio, _užov,
  { {0x7a2f0307,0x69c3471c,0x6b8000a4,0x00000000}},	//   tøtt, _fane, mamg,
  { {0x3ea6001c,0x683f008f,0xfba60053,0x00000000}},	//   itot_, _jūdz, क्रम,
  { {0xf77f0268,0x628608a9,0xe5c80085,0x00000000}},	//   paç_, _avko, цыял_,
  { {0x683f0418,0x3ea600a4,0x6b8000a4,0x00000000}},	//   _lūdz, ktot_, namg,
  { {0x27e9471d,0xec09008b,0x683d0003,0x00000000}},	// [8550] _ioan_, iếp_, céda,
  { {0xdb0029ba,0x27e9008b,0xef650058,0x00000000}},	//   lemó, _hoan_, ğımı_,
  { {0x6f02006f,0x3ea6001c,0xef65005b,0x00000000}},	//   ezoc, etot_, şımı_,
  { {0x27e918d9,0x9ed90121,0x200f1d2a,0x00000000}},	//   _joan_, ймет_, uigi_,
  { {0x200f2f7f,0xf65f0026,0x15ff0053,0x00000000}},	//   rigi_, kvæm_, _उतार_,
  { {0x8e080086,0x27e91898,0xa25b0066,0x00000000}},	//   онів_, _loan_, _drôt,
  { {0x69c50014,0x7ae60137,0x3fb70021,0x00000000}},	//   _óhei, äktn, _وإرس,
  { {0xcfb4005a,0x69c3471e,0x251c009f,0x00000000}},	//   _обсъ, _sane, יווא,
  { {0x3ebf0150,0x69c3471f,0x6836027d,0x00000000}},	//   _usut_, _pane, sádk,
  { {0xbef80044,0x5d6400de,0x00000000,0x00000000}},	//   _برفض_, _يُقْ,   ,
  { {0x69c30004,0xf8650086,0xfd560047,0x00000000}},	//   _vane, явно, _זשעי_,
  { {0x2c63005b,0x2919003b,0x69c30849,0x00000000}},	//   _gıda_, ăsa_, _wane,
  { {0x27e9008d,0x69c34720,0xe1ff017c,0x00000000}},	//   _doan_, _tane, _atóm_,
  { {0x2c55001c,0x24983db1,0xc5d50054,0x00000000}},	//   _tāds_, turm_, місь,
  { {0x7981004d,0x8cce0053,0xdb0b0022,0x00000000}},	//   malw, थियो, _tagó,
  { {0x62841fc9,0x683d0080,0x74160044,0x00000000}},	//   tsio, lédn, أورا,
  { {0x62840006,0x26c00035,0x57fb0063,0x00000000}},	// [8560] usio, _usio_, _ללקו,
  { {0x7a3400cd,0xd175000d,0x60c9008f,0x00000000}},	//   tàti, дыцы, _ņema,
  { {0x201c017d,0xb69b0493,0x628407b9,0x00000000}},	//   évio_, nzân, ssio,
  { {0x79814721,0x40790076,0x788200ea,0x00000000}},	//   halw, ющую_, _hívá,
  { {0x7882000f,0x2fc62c64,0xb5fb0331,0x00000000}},	//   _kívá, rdog_, mpár,
  { {0x6f020122,0x645e4722,0x2bd10053,0x00000000}},	//   rzoc, _kupi, _दोबा,
  { {0x3ea6024a,0x32430086,0xada3018e,0x00000000}},	//   stot_, _черг, хајл,
  { {0xbc670021,0x22ae008f,0x6441004c,0x00000000}},	//   أمين_, pēkā_, ůliv,
  { {0x6b80007a,0x683600be,0x7981002b,0x00000000}},	//   ramg, cádi, falw,
  { {0x3dc5001f,0x395806a5,0x657e1e46,0x00000000}},	//   _galw_, ørs_, _neph,
  { {0x645e1840,0xd7950062,0xd9170121,0x00000000}},	//   _nupi, минъ, зья_,
  { {0x1ae60189,0xec4a0121,0x2007006c,0x00000000}},	//   _ноем, _узел_, énix_,
  { {0xa3c00161,0xf3f1001b,0xe6670ac5,0x00000000}},	//   ंजन_, ệm_, ятно,
  { {0x09e3413b,0x38cb007e,0x657e1a69,0x00000000}},	//   _почн, _گاهی_, _ceph,
  { {0x657e00f3,0x69c8001f,0x680b0051,0x00000000}},	//   _deph, mdde, iędz,
  { {0xc2c5007e,0x03c4065b,0x54540cb9,0x00000000}},	//   ويزي, нсум, евст,
  { {0x683d0003,0x69c84723,0x92a40022,0x00000000}},	// [8570] lédo, odde, ółpr,
  { {0xc104005d,0x69c80aff,0x00000000,0x00000000}},	//   کومي, ndde,   ,
  { {0xad3a0086,0xdb0b0026,0xc1e80121,0x00000000}},	//   _квiт, _lagð, чьте_,
  { {0x68360016,0xb5fb0026,0x6d5a00a4,0x00000000}},	//   tádi, ppás, _agta,
  { {0x62494724,0x69d83e0b,0x9e640054,0x00000000}},	//   _džor, _onve, евід,
  { {0xfe7001fb,0x68363b1c,0x63ad4725,0x00000000}},	//   ادن_, rádi, lfan,
  { {0x64580164,0x63ad0035,0x79810104,0x00000000}},	//   _évit, ofan, valw,
  { {0x69d8010a,0xa3c0016a,0xf65f00b9,0x00000000}},	//   _anve, ंजय_, gvæk_,
  { {0xde94005e,0x680b0022,0x7f580b69,0x00000000}},	//   _патњ, będz, _хаус_,
  { {0xe2a60026,0x08890121,0xa9e40021,0x00000000}},	//   æðin_, обой_, ّثَن,
  { {0x39451b79,0x02ba0053,0x22a3001c,0x00000000}},	//   ьног, _उन्न, lūkā_,
  { {0x645e4726,0x69d81677,0x69c84727,0x00000000}},	//   _rupi, _enve, adde,
  { {0xf8c600ea,0x63ad33e4,0x645e4696,0x00000000}},	//   óért_, dfan, _supi,
  { {0x2bbd0053,0x645e1e3e,0x7bc94728,0x00000000}},	//   ्यवा, _pupi, ldeu,
  { {0x3f8d00cd,0x63ad0b9c,0x683d0003,0x00000000}},	//   _odeu_, ffan, cédo,
  { {0x645a0268,0x680b0051,0x657e00ac,0x00000000}},	//   ítiq, zędz, _weph,
  { {0x6aa94729,0x7bc90cf4,0xa7fd472a,0x00000000}},	// [8580] ntef, ideu, apıs,
  { {0x63ad0035,0x42230002,0x645e472b,0x00000000}},	//   afan, вдув, _tupi,
  { {0x106a0076,0x76400080,0xafe60086,0x00000000}},	//   цией_, ůmys, можл,
  { {0x6aa9000e,0x680b0022,0xf1a90041,0x00000000}},	//   ktef, wędz, יס_,
  { {0x6d412d6f,0x69c825c6,0x7de60054,0x00000000}},	//   _azla, ydde, дійд,
  { {0x7bc900bd,0x7e7b0022,0xf1b8009a,0x00000000}},	//   edeu, _dwup, _מֶֽל,
  { {0xdb0b0026,0xd839007d,0xbc670044,0x00000000}},	//   _sagð, luče_, ومون_,
  { {0x683d2928,0x69c8001f,0x6143005e,0x00000000}},	//   védo, wdde, _реса,
  { {0x680b0051,0x2258472c,0x4a5416b4,0x00000000}},	//   pędz, _kirk_, нкис,
  { {0x6d5a0139,0x69c80ac9,0x260d0066,0x00000000}},	//   _ugta, udde, ržok_,
  { {0x63ad09c5,0xb21b00b9,0x69c80333,0x00000000}},	//   yfan, _svæk, rdde,
  { {0xb8e60161,0x7e60472d,0x628b00ea,0x00000000}},	//   _उन_, _kump, ágok,
  { {0x2905005b,0xd839007d,0x19941a6b,0x00000000}},	//   azla_, juče_, _заля,
  { {0x7a3400cd,0x7e600509,0x4422472e,0x00000000}},	//   tàtu, _mump, _ajk_,
  { {0x63ad007a,0x7e600397,0xe5340121,0x00000000}},	//   tfan, _lump, верь,
  { {0xeac8001b,0x63ad0035,0x44220051,0x00000000}},	//   _kỹ_, ufan, _cjk_,
  { {0x26c5003d,0xd839007d,0x7e60472f,0x00000000}},	// [8590] ālos_, guče_, _nump,
  { {0xeac8001b,0x63ad007a,0xd13b173e,0x00000000}},	//   _mỹ_, sfan, охе_,
  { {0x63ad0c38,0xf1a40062,0x22583cfc,0x00000000}},	//   pfan, ъртн, _dirk_,
  { {0x7e603996,0x7c2204aa,0xfe710021,0x00000000}},	//   _bump, _njor, هدت_,
  { {0x644d03b2,0x7e604730,0x6d410051,0x00000000}},	//   mmai, _cump, _szla,
  { {0x661500c3,0x0dc80001,0xadd6005e,0x00000000}},	//   nizk, дући_, емљу_,
  { {0xdce3001c,0x7bc945ca,0x271b0042,0x00000000}},	//   manī, tdeu, नपुर_,
  { {0x7bc94731,0x644d4732,0x6aa94733,0x00000000}},	//   udeu, nmai, ttef,
  { {0x7bc94734,0x9dab0062,0x644d01cf,0x00000000}},	//   rdeu, _мъжа_, imai,
  { {0xdf440088,0x89a90429,0x6f25003b,0x00000000}},	//   _рэсп, чков_, ărcă,
  { {0x7c22334a,0x6d411b68,0x6aa90220,0x00000000}},	//   _fjor, _uzla, stef,
  { {0x7c2231c8,0x60da00ea,0xcc76009a,0x00000000}},	//   _gjor, _átme, _נענה_,
  { {0xbbbd0161,0xdce10006,0xdffa0047,0x00000000}},	//   ्यीक, _pelė, פּטש,
  { {0xd839007d,0x3ea20137,0x644d457a,0x00000000}},	//   vuče_, _åkte_, emai,
  { {0x7c3b004b,0x35d50042,0x33d60054,0x00000000}},	//   olur, दाज़, ніат,
  { {0x7c3b00a4,0xf3ff017d,0x644d4735,0x00000000}},	//   nlur, _clã_, gmai,
  { {0x130a0088,0x7c3b000c,0xd196005e,0x00000000}},	// [85a0] чнай_, ilur, ешењ,
  { {0xe7ac0161,0x644d14bd,0x16770063,0x00000000}},	//   ट्रप, amai, _רגיל_,
  { {0x22580026,0x7e600c96,0x644d4736,0x00000000}},	//   _virk_, _sump, bmai,
  { {0x7e602280,0xb7db0041,0x4ea64737,0x00000000}},	//   _pump, ּקסי, ерка,
  { {0x61f306a5,0x44204738,0x44324739,0x00000000}},	//   ådlø, mni_, moy_,
  { {0x443200bb,0xf487007e,0xfcc60001,0x00000000}},	//   loy_, _تایی, ељим,
  { {0x4420473a,0xeac8008b,0x7c3b0026,0x00000000}},	//   oni_, _sỹ_, flur,
  { {0xcb0a005a,0x7e603534,0x2bba0021,0x00000000}},	//   зход_, _tump, ساعة_,
  { {0x61ee0031,0x03560047,0xb4bd0042,0x00000000}},	//   _kobl, עיִש_, _इन्_,
  { {0xd8f80086,0x44320178,0x7c3b003b,0x00000000}},	//   дної_, hoy_, alur,
  { {0x4432002c,0x4420473b,0x644d262b,0x00000000}},	//   koy_, kni_, ymai,
  { {0x4432473c,0x7c3b05d7,0x44202888,0x00000000}},	//   joy_, clur, jni_,
  { {0x443209aa,0x8c43210d,0xd6d84334,0x00000000}},	//   doy_, _сеце, нтр_,
  { {0x63a641b9,0x6b8200a4,0x61ee10c5,0x00000000}},	//   _ackn, _heog, _nobl,
  { {0x44201a95,0xdce3008f,0x4432006c,0x00000000}},	//   fni_, vanī, foy_,
  { {0x4420473d,0x69ca473e,0x493b0063,0x00000000}},	//   gni_, _hafe, _מגוו,
  { {0x61ee001f,0x92590002,0x2369003b,0x00000000}},	// [85b0] _bobl, даат_, rcaj_,
  { {0xd904007e,0x4420473f,0x61ee04ec,0x00000000}},	//   می_, ani_, _cobl,
  { {0x61ee4740,0x44204741,0x644d001c,0x00000000}},	//   _dobl, bni_, pmai,
  { {0x6b824742,0x44201be2,0x44321b3f,0x00000000}},	//   _neog, cni_, coy_,
  { {0x539a014e,0xa3440085,0xcee80044,0x00000000}},	//   _קישו, _бэрл, فرون_,
  { {0x44d100eb,0xdce8003d,0x61ee4743,0x00000000}},	//   _ką_, _nedē, _gobl,
  { {0x6b821181,0x7c3b000c,0x44d1078a,0x00000000}},	//   _beog, tlur, _ją_,
  { {0xdce1003b,0xa1582049,0x04dc0063,0x00000000}},	//   _află, _часу_, לקול,
  { {0x2fc00019,0x1ef80044,0xc3b8009a,0x00000000}},	//   õige_, _كعكة_, תלחץ_,
  { {0x7c3b0026,0x69ca4744,0x44204745,0x00000000}},	//   slur, _cafe, zni_,
  { {0x443200a4,0x7c3b1897,0x2d874746,0x00000000}},	//   yoy_, plur, mane_,
  { {0x2d874747,0x6b824748,0x5b150956,0x00000000}},	//   lane_, _geog, _имет,
  { {0x44204749,0x2d87003b,0xc0520047,0x00000000}},	//   vni_, oane_, יזט_,
  { {0x7bcb0994,0x2d874747,0xa6e30026,0x00000000}},	//   _hagu, nane_, æðas,
  { {0x2aab010a,0x7bcb3d23,0x4432474a,0x00000000}},	//   løb_, _kagu, toy_,
  { {0x44202170,0x7983001f,0x69ca005b,0x00000000}},	//   uni_, _henw, _zafe,
  { {0x2d87474b,0x6b840019,0x66060076,0x00000000}},	// [85c0] kane_, _õige, _аппа,
  { {0x9f440268,0x7ae60137,0x7bcb474c,0x00000000}},	//   _romà_, äkti, _lagu,
  { {0x2d87474d,0x94260caa,0xe058005d,0x00000000}},	//   dane_, _амне, فیست_,
  { {0xef1a0076,0x7bcb474e,0x2aab00b9,0x00000000}},	//   мме_, _nagu, køb_,
  { {0x5f06005a,0x7e2a01dd,0x260d0124,0x00000000}},	//   ъзда, міка_, ržov_,
  { {0x998c0080,0x2aab00b9,0x2d87474f,0x00000000}},	//   vodů_, døb_, gane_,
  { {0x6abc0161,0x7bcb18a5,0x69ca4750,0x00000000}},	//   ्ट्र, _bagu, _rafe,
  { {0x7bcb00ae,0x63a44751,0xab5d0051,0x00000000}},	//   _cagu, ngin, jeżd,
  { {0xf4130063,0x7bcb4752,0x5a344753,0x00000000}},	//   יפה_, _dagu, лнит,
  { {0xbd8a006a,0x998c0080,0x683d4754,0x00000000}},	//   _آنان_, rodů_, médi,
  { {0x683d0003,0x7bcb4755,0x6b824756,0x00000000}},	//   lédi, _fagu, _teog,
  { {0x63a4006f,0x3f844757,0x2006002b,0x00000000}},	//   jgin, _jemu_, nhoi_,
  { {0x44d10045,0x63a406b8,0x683d0003,0x00000000}},	//   _są_, dgin, nédi,
  { {0x7bc00004,0x6aa02109,0x63a43037,0x00000000}},	//   lemu, mumf, egin,
  { {0x6d5c0024,0xde88008b,0x20064758,0x00000000}},	//   _úrad, hị_, khoi_,
  { {0x7bc0003e,0x2d871b27,0x3f840066,0x00000000}},	//   nemu, zane_, _nemu_,
  { {0x36d52758,0x2d874759,0x6aa0004d,0x00000000}},	// [85d0] _сопр, yane_, numf,
  { {0x7988001f,0x44d11265,0x7bc01e50,0x00000000}},	//   nadw, _tą_, hemu,
  { {0x7bc015a5,0xa37b00be,0xab5d0022,0x00000000}},	//   kemu, _anõe, leże,
  { {0x2d870045,0xf8b300b5,0x7bc00150,0x00000000}},	//   wane_, ישע_, jemu,
  { {0x8f340088,0x539a014e,0xf3f1001b,0x00000000}},	//   аецц, _אירו, ệu_,
  { {0x3dcc0185,0x7bcb475a,0x79880150,0x00000000}},	//   _cadw_, _sagu, jadw,
  { {0x645d0b7e,0x2d8704d9,0x7988475b,0x00000000}},	//   _kisi, rane_, dadw,
  { {0x7bc03407,0x2d87475c,0x5ac916fc,0x00000000}},	//   gemu, sane_, елим_,
  { {0x2d87475d,0x44391a23,0x7bcb04bc,0x00000000}},	//   pane_, _mks_, _vagu,
  { {0x1ddb0032,0x3dcc0185,0x645d475e,0x00000000}},	//   _تبرع_, _gadw_, _lisi,
  { {0x7a3d0268,0x7bcb475f,0xa2ca0053,0x00000000}},	//   nèti, _tagu, _सैन्,
  { {0x2d850844,0x645d0f9d,0x798800ca,0x00000000}},	//   _hele_, _nisi, aadw,
  { {0xa3e70053,0xdcf80078,0x62980078,0x00000000}},	//   पान_, davę, ąvok,
  { {0x1a9a0047,0xaa920021,0xd839007d,0x00000000}},	//   _ניצע, _الوث, ruča_,
  { {0x69c14760,0x2d850529,0x645d3fce,0x00000000}},	//   mele, _mele_, _bisi,
  { {0x2d850150,0x68fc04aa,0x2cb80137,0x00000000}},	//   _lele_, ørde, _ärde_,
  { {0xe2974761,0x645d386d,0xc68f0021,0x00000000}},	// [85e0] лат_, _disi, _فِي_,
  { {0x443902ab,0x645d264c,0xdb0a0164,0x00000000}},	//   _eks_, _eisi, énér,
  { {0x645d4762,0x5a160047,0xd5fb0063,0x00000000}},	//   _fisi, נקען_, _נפטר,
  { {0xf3f1001b,0x6b890035,0x69c14763,0x00000000}},	//   ệt_, jaeg, hele,
  { {0xa83700b5,0x765e0035,0x69c14764,0x00000000}},	//   אָגס_, _kipy, kele,
  { {0x69c1000f,0x2d854765,0x645d0035,0x00000000}},	//   jele, _cele_, _zisi,
  { {0x69c14766,0xf65f00d1,0x7bc01742,0x00000000}},	//   dele, nvær_, temu,
  { {0x683d4767,0xab5d0051,0x69c14768,0x00000000}},	//   pédi, zeże, eele,
  { {0xb21b0146,0x69c14769,0x78a100ac,0x00000000}},	//   _ivær, fele, eulv,
  { {0x69c1476a,0x60c9003d,0x2d850122,0x00000000}},	//   gele, _ņemi, _gele_,
  { {0xb21b476b,0x79880185,0x395801bb,0x00000000}},	//   _kvær, radw, ärs_,
  { {0x69c10035,0x6d48476c,0xa835005e,0x00000000}},	//   aele, _izda, ремљ,
  { {0xcaf601a7,0xddc9000c,0x69c1476d,0x00000000}},	//   _حساب, _uteţ, bele,
  { {0x645d15c4,0x6828005b,0x75eb005b,0x00000000}},	//   _sisi, rıda, _yüzy,
  { {0x344b0138,0xe4e41c15,0x4439476e,0x00000000}},	//   ечан_, бітн, _pks_,
  { {0xe7870001,0x628d004b,0x17fb0021,0x00000000}},	//   _суко, tsao, _سرعة_,
  { {0x521527ad,0xdcf80006,0x645d476f,0x00000000}},	// [85f0] адат, ravę, _visi,
  { {0x9475006a,0x91e40001,0x7a3d00cd,0x00000000}},	//   _نگرا, бође, tèti,
  { {0x628d0b70,0x2d85003b,0x4439004e,0x00000000}},	//   ssao, _rele_, _tks_,
  { {0xe8d70063,0x628b00ea,0x2d854770,0x00000000}},	//   טובר_, ágos, _sele_,
  { {0xb21b00b9,0x2d854771,0x69c14772,0x00000000}},	//   _dvær, _pele_, yele,
  { {0xa0c5007e,0x2bda0053,0x69c1240a,0x00000000}},	//   _پيرو, _मोबा, xele,
  { {0x2d854773,0x06380047,0x69c14774,0x00000000}},	//   _vele_, אנגט_, vele,
  { {0xdcfa0529,0x753a004d,0x7c2d218f,0x00000000}},	//   _setă, ützi, čaro,
  { {0x80040ac5,0x290c0066,0x2d854775,0x00000000}},	//   _учре, ezda_, _tele_,
  { {0x6b890019,0xcef40001,0xc9550076,0x00000000}},	//   saeg, _упућ, итны,
  { {0x7cdc003b,0x69c14776,0xd9451159,0x00000000}},	//   _cără, rele, рени,
  { {0x366a005e,0x69c14777,0x7cdc00dd,0x00000000}},	//   камо_, sele, _dără,
  { {0x24860024,0x09e5101a,0x69c14778,0x00000000}},	//   _ňom_, _волн, pele,
  { {0x7afb0035,0x3e6b00d1,0x7cdc003b,0x00000000}},	//   myut, _møt_, _fără,
  { {0x765e0009,0xd9390041,0x18a5137a,0x00000000}},	//   _vipy, _בײַש, _тайм,
  { {0x3ced0053,0x27e000a4,0x7afb0058,0x00000000}},	//   _अपने_, _unin_, oyut,
  { {0x883b009a,0x7afb0089,0x765e001f,0x00000000}},	// [8600] _בתקו, nyut, _tipy,
  { {0xb21b02ab,0x9f4d0268,0xf65f05b9,0x00000000}},	//   _svær, _lleó_, svær_,
  { {0x6f660001,0x661c4779,0x61fe477a,0x00000000}},	//   авез, mirk, rkpl,
  { {0x61fe01f2,0x661c4772,0xe04313a2,0x00000000}},	//   skpl, lirk, онхи,
  { {0x683d0164,0x9f490014,0xdfcf0593,0x00000000}},	//   cédu, óað_, بين_,
  { {0x2735008b,0x661c477b,0x60da013d,0x00000000}},	//   ụng_, nirk, _átmo,
  { {0x6da30540,0xb21b0146,0x661c004b,0x00000000}},	//   ција, _tvær, iirk,
  { {0x661c053b,0x60c20022,0x63b600a3,0x00000000}},	//   hirk, łoms, nfyn,
  { {0x15f80161,0x7cdc003b,0x661c477c,0x00000000}},	//   ुसार_, _sără, kirk,
  { {0x7cdc000c,0x49d70121,0x9966007b,0x00000000}},	//   _pără, адью_, штил,
  { {0x661c00f3,0xd491001b,0x6d480f74,0x00000000}},	//   dirk, ời_, _uzda,
  { {0x7ae60137,0xeb970cb2,0x09030085,0x00000000}},	//   äkts, _виц_, ючым,
  { {0x661c12bd,0x63b6002b,0xec1304a0,0x00000000}},	//   firk, dfyn, _بوند,
  { {0x18660138,0x2cbe0089,0xfa33007e,0x00000000}},	//   _књиг, _kptd_, _ورود,
  { {0xe654019d,0xedf40161,0xb8940021,0x00000000}},	//   івсь, _अवैध_, _البع,
  { {0x53980086,0xab5d0051,0xd3780e81,0x00000000}},	//   ився_, leża, ичу_,
  { {0xe1670001,0x24580076,0x661c00b2,0x00000000}},	// [8610] ађен, рать_, birk,
  { {0x661c477d,0xc73c0063,0x683d0003,0x00000000}},	//   cirk, _בתחת, rédu,
  { {0x35f8007e,0x8f00000d,0x3e6b00d1,0x00000000}},	//   _خريد_, кiя_, _søt_,
  { {0x4e950021,0x80140054,0xd347005d,0x00000000}},	//   مشتر, офіц, _نیزه_,
  { {0x1de20161,0x201c0268,0xc257006a,0x00000000}},	//   पांत, èvia_, _نخست,
  { {0xee3815d4,0x248d008f,0x6e920021,0x00000000}},	//   ані_, ņemu_, ألوا,
  { {0x9da80062,0xcfd501ce,0x7094477e,0x00000000}},	//   ръча_, _ловћ, _марф,
  { {0x661c3a98,0xf412009a,0x0be900de,0x00000000}},	//   zirk, ּ֤ה_, افةً_,
  { {0xe7eb0042,0xa9690aad,0x998b011b,0x00000000}},	//   टाना_, липа_, álům_,
  { {0x1a05101a,0x201d0022,0xda0902da,0x00000000}},	//   спом, liwi_, ايده_,
  { {0x661c19b2,0x63b6001f,0x2cbe0089,0x00000000}},	//   virk, yfyn, _gptd_,
  { {0x661c00bd,0x7e690035,0x7afb0035,0x00000000}},	//   wirk, _kuep, pyut,
  { {0x661c0d95,0x7e6100fe,0xfc7d004c,0x00000000}},	//   tirk, _kilp, žádá_,
  { {0x99850021,0xbb3a0047,0x6d41477f,0x00000000}},	//   _الثو, _געני, _kyla,
  { {0x201d0035,0x661c005b,0xa507080a,0x00000000}},	//   kiwi_, rirk, бера_,
  { {0x69de0268,0xf3f1001b,0x78fa0063,0x00000000}},	//   _òper, ệp_, _תפקו,
  { {0x63b60185,0x38b14780,0x661c4781,0x00000000}},	// [8620] rfyn, lár_, pirk,
  { {0xe3b204de,0x6d41005b,0x68ec0078,0x00000000}},	//   _کرد_, _oyla, ţodţ,
  { {0x04b6005a,0x7c2d00c2,0x6d411310,0x00000000}},	//   _успя, čarj, _nyla,
  { {0x4f0a047e,0x8fa602b3,0x44d800a8,0x00000000}},	//   лнен_, саде, _ič_,
  { {0x248d003d,0x6e46000d,0x7e690089,0x00000000}},	//   ņemt_, бедз, _cuep,
  { {0x44d80080,0x6d412d70,0x64444782,0x00000000}},	//   _kč_, _byla, llii,
  { {0xdd990086,0x64440213,0xa7fd0058,0x00000000}},	//   рші_, olii, apıy,
  { {0x6d41035a,0x64440072,0x26c025b5,0x00000000}},	//   _dyla, nlii, _opio_,
  { {0x644400fe,0x93fb0063,0x539b016e,0x00000000}},	//   ilii, טלקי, אספא,
  { {0x98b8000a,0x3eb90137,0x44d8011b,0x00000000}},	//   алот_, _ästa_, _oč_,
  { {0x41bb0047,0xabaa0021,0x9f4d0014,0x00000000}},	//   נצטע, _مهام_, _hleð_,
  { {0xfaa60088,0x2fc60025,0x3942001c,0x00000000}},	//   _гадо, neog_, āks_,
  { {0xab5d0045,0x1994000d,0xdc3b0047,0x00000000}},	//   leżn, _даля, _געאר,
  { {0x201d0035,0x6e240025,0x6444078c,0x00000000}},	//   ziwi_, éibh, elii,
  { {0x9f440268,0x55590062,0x4c98089e,0x00000000}},	//   _comú_, равя_, יֹּא,
  { {0xcc770063,0x2d8e004d,0x9d1b0041,0x00000000}},	//   מעלה_, hafe_, אולט,
  { {0x7a3d2203,0x44d800c3,0xe3b00021,0x00000000}},	// [8630] mètr, _eč_, عرف_,
  { {0x320715f4,0x64444783,0xdb190022,0x00000000}},	//   óny_, alii, _zawó,
  { {0x753a004d,0x61f500a8,0xe8160082,0x00000000}},	//   ützt, _vozl, दोवा_,
  { {0x248d001c,0x7a3d0003,0x9ed90121,0x00000000}},	//   ņems_, nètr, имет_,
  { {0x44294784,0x26dc00b5,0x7e611708,0x00000000}},	//   mna_, ָקומ, _pilp,
  { {0x201d0035,0x443b0089,0x999e0078,0x00000000}},	//   siwi_, loq_, imtų_,
  { {0xfbda0053,0xcc860ac5,0x44294785,0x00000000}},	//   _मोहम, обще_, ona_,
  { {0x6b840019,0x251c0047,0x9f350054,0x00000000}},	//   _õigl, טווא, _дебі,
  { {0x7e6104b1,0xab294786,0x44294787,0x00000000}},	//   _tilp, ропа_, ina_,
  { {0x38b1000f,0x3ea00025,0xa91c017c,0x00000000}},	//   tár_, áite_, haľu,
  { {0x44294788,0x290318a8,0xd7ea167b,0x00000000}},	//   kna_, ája_, амне_,
  { {0x3ea006bb,0x38b10026,0x290b0051,0x00000000}},	//   šite_, rár_, ąca_,
  { {0x290300c3,0xd491001b,0x38b11d6b,0x00000000}},	//   šja_, ần_, sár_,
  { {0x2ca70034,0x386a0025,0x1f5a0047,0x00000000}},	//   ound_, úirí_, ידרא,
  { {0x4429007a,0x7c294789,0x644419fb,0x00000000}},	//   fna_, oner, tlii,
  { {0x68360024,0x24070086,0x7c3b478a,0x00000000}},	//   hádz, онси_, nour,
  { {0xdb110003,0x2ca706fb,0x7c29399a,0x00000000}},	// [8640] éfèr, hund_, iner,
  { {0x6b8b478b,0x7c2900bd,0x7ae40025,0x00000000}},	//   _legg, hner, _áite,
  { {0x63af024a,0x6444112c,0xd46a005e,0x00000000}},	//   ännö, plii, _њиме_,
  { {0x7c3b03b2,0xb4c8016a,0x7c29478c,0x00000000}},	//   jour, ोटी_, jner,
  { {0xa3e70161,0x998500c2,0x4420478d,0x00000000}},	//   पार_, dolž_, mii_,
  { {0xa6e3007a,0x4420478e,0x7c29478f,0x00000000}},	//   æðis, lii_, ener,
  { {0x2ca7007a,0x2d8e00bd,0x3ea60ddd,0x00000000}},	//   gund_, rafe_, suot_,
  { {0x7c3b12ee,0x44204790,0x7c294791,0x00000000}},	//   gour, nii_, gner,
  { {0x9c870066,0x44204792,0x00000000,0x00000000}},	//   _počú, iii_,   ,
  { {0x44204793,0x7c29344e,0x44294794,0x00000000}},	//   hii_, aner, zna_,
  { {0xd839007d,0x2ca713cb,0x44294795,0x00000000}},	//   luči_, cund_, yna_,
  { {0x7c3b04bc,0x442900c7,0x1ae60121,0x00000000}},	//   cour, xna_, _моем,
  { {0x7764011c,0x44204796,0x44290a97,0x00000000}},	//   държ, dii_, vna_,
  { {0x6b8b0122,0x2d8c00bd,0x44290051,0x00000000}},	//   _zegg, _jede_, wna_,
  { {0xa3e70053,0x68fc00c7,0x63bd0089,0x00000000}},	//   पाल_, ärdd, _pbsn,
  { {0x2d8c3073,0x78a800b9,0x44294797,0x00000000}},	//   _lede_, mudv, una_,
  { {0x442902eb,0x416b0001,0xd83902e2,0x00000000}},	// [8650] rna_, ајем_, juči_,
  { {0xdb110164,0x2d8c0205,0x69c829b8,0x00000000}},	//   éfér, _nede_, nede,
  { {0x68360024,0x69c84798,0x7c294799,0x00000000}},	//   vádz, iede, yner,
  { {0x98b3017f,0x69c8479a,0x64da0047,0x00000000}},	//   žeći_, hede, _פֿיס,
  { {0x63ad0dfb,0x2d8c0230,0x6b8b479b,0x00000000}},	//   mgan, _bede_, _regg,
  { {0x63ad05db,0x69c8479c,0xdb0000b9,0x00000000}},	//   lgan, jede, ogmæ,
  { {0x7c3b479d,0x6b8b2437,0x69c8479e,0x00000000}},	//   tour, _pegg, dede,
  { {0x63ad479f,0x2ca747a0,0x3dc7002b,0x00000000}},	//   ngan, rund_, senw_,
  { {0x6b8b1732,0x2d8c47a1,0x63ad08fa,0x00000000}},	//   _vegg, _fede_, igan,
  { {0x2d8c0150,0x6b8b0d5e,0x7c3b47a2,0x00000000}},	//   _gede_, _wegg, sour,
  { {0x6b8b0089,0x78a801e1,0x7c3b47a3,0x00000000}},	//   _tegg, gudv, pour,
  { {0x21160041,0xdcfa004c,0x9c82004c,0x00000000}},	//   פֿיש_, _letě, áčen,
  { {0x63ad0c8e,0x442047a4,0x69c847a5,0x00000000}},	//   dgan, vii_, bede,
  { {0x9c8247a6,0x69c847a7,0x3f8d00ac,0x00000000}},	//   ščen, cede, _leeu_,
  { {0x442047a8,0x63ad47a9,0xb4c80042,0x00000000}},	//   tii_, fgan, ोटे_,
  { {0x68fc00c7,0x61e70150,0xb89a0063,0x00000000}},	//   ärde, _anjl, _הבקש,
  { {0x442047aa,0xd387137a,0x95760121,0x00000000}},	// [8660] rii_, яйте_, _нынч,
  { {0x63ad061e,0x442047ab,0xd8390130,0x00000000}},	//   agan, sii_, vuči_,
  { {0x2d8c47ac,0x442047ad,0x6601051c,0x00000000}},	//   _rede_, pii_, ölke,
  { {0x2d8c313e,0x69c80758,0xd0190083,0x00000000}},	//   _sede_, zede, офі_,
  { {0x2d8c22ea,0xf8a80053,0x69c80058,0x00000000}},	//   _pede_, _कम्प, yede,
  { {0x69c8017d,0xd839007d,0x02460044,0x00000000}},	//   xede, ruči_, _رَأَ,
  { {0x7e7b0072,0x69c80a97,0x2d8c47ae,0x00000000}},	//   _etup, vede, _vede_,
  { {0x69c847af,0x2d8c00a4,0x8cbd0053,0x00000000}},	//   wede, _wede_, _शहरो,
  { {0x69c802ab,0x6296002c,0x8f00000d,0x00000000}},	//   tede, nsyo, кiх_,
  { {0x69c802dd,0x2d8c006d,0x20060072,0x00000000}},	//   uede, _uede_, lkoi_,
  { {0xb4c80053,0x69c847b0,0x63ad47b1,0x00000000}},	//   ोटो_, rede, ygan,
  { {0x629600bb,0x78a800b9,0xd4910013,0x00000000}},	//   ksyo, rudv, ầm_,
  { {0x78a800b9,0x56940062,0x69c847b2,0x00000000}},	//   sudv, наят, pede,
  { {0xa2db0053,0x7afd47b3,0x00000000,0x00000000}},	//   निस्, äste,   ,
  { {0x49bb0063,0x19bb0165,0x753a004d,0x00000000}},	//   _המוס, _המוב, ützp,
  { {0x63ad47b4,0x9c7c0130,0x2be50042,0x00000000}},	//   ugan, _grče, काएं_,
  { {0xc6190076,0x63ad47b5,0x979c0063,0x00000000}},	// [8670] _моих_, rgan, _השחק,
  { {0x20c80161,0x63ad47b6,0x51f80145,0x00000000}},	//   रबंध, sgan, пную_,
  { {0x7fd50086,0x62962e10,0xf1a4000d,0x00000000}},	//   ділі, asyo, эртн,
  { {0x2c7147b7,0x00000000,0x00000000,0x00000000}},	//   _rád_,   ,   ,
  { {0xdcf8001c,0x2c710066,0x9ea90054,0x00000000}},	//   kavē, _sád_, івка_,
  { {0x273c0013,0x6da526b8,0x2c7101c8,0x00000000}},	//   ửng_, фика, _pád_,
  { {0xed560079,0x859c0041,0xd2500044,0x00000000}},	//   мош_, זשוו, _إنّ_,
  { {0xdfd40076,0x7ae40078,0x5ba90a91,0x00000000}},	//   _посы, _šita, цким_,
  { {0x7bc90104,0xee84000d,0xbdb50141,0x00000000}},	//   reeu, _зыхо, _обај,
  { {0x7bc900ca,0x27e947b8,0xf2d4016e,0x00000000}},	//   seeu, _anan_, געץ_,
  { {0x200d006f,0x07a647b9,0xc7a647ba,0x00000000}},	//   _klei_, манн, минк,
  { {0x3a3800a8,0x23660078,0x7d030014,0x00000000}},	//   črpa_, žoji_, myns,
  { {0xac060086,0xc9f50021,0x6b65000d,0x00000000}},	//   _інша_, _يستع, _ўкла,
  { {0x200d0268,0x69250001,0x09e40054,0x00000000}},	//   _llei_, _омла, _поін,
  { {0x96630a29,0x9c7c00a8,0xef650058,0x00000000}},	//   ткре, _trče, ğıyı_,
  { {0x9c7c0114,0xe3ba0085,0xd4350044,0x00000000}},	//   _urče, ўба_, ّعْب,
  { {0x6e2300a4,0x43460002,0x41b60cbd,0x00000000}},	// [8680] kinb, феав, дсет,
  { {0x6296002c,0x7d0347bb,0x27e91253,0x00000000}},	//   rsyo, kyns, _znan_,
  { {0x200d11aa,0x20060072,0x6e230168,0x00000000}},	//   _blei_, tkoi_, dinb,
  { {0xa2db0161,0x629600a4,0xc0060085,0x00000000}},	//   निश्, psyo, ьпек,
  { {0x200747bc,0x7d030014,0xee3a1580,0x00000000}},	//   ênia_, eyns, онд_,
  { {0xa2db0053,0xdb0001e1,0x6e2347bd,0x00000000}},	//   निर्, ngmå, ginb,
  { {0xd5ed00aa,0x0caa0086,0xd00a0ada,0x00000000}},	//   _quả, ітки_, _деве_,
  { {0x8af80c09,0x61fc47be,0x711b009a,0x00000000}},	//   знис_, _horl, _וולפ,
  { {0x61fc44a0,0x6e23002c,0x3e7b003b,0x00000000}},	//   _korl, binb, _câtă_,
  { {0x4efb0063,0x3f8647bf,0xc3330063,0x00000000}},	//   _והמו, lbou_, כוח_,
  { {0xd9170121,0x2b510022,0x7857005d,0x00000000}},	//   дья_, ęzca_, ویتز_,
  { {0x3f863c07,0x0bd40044,0x00000000,0x00000000}},	//   nbou_, _سيتح,   ,
  { {0xe9da000a,0x61fc0173,0xdb2400fe,0x00000000}},	//   _мкд_, _oorl, äräy,
  { {0x61fc47c0,0x8a03005a,0xdb0039a0,0x00000000}},	//   _norl, _изче, rgmä,
  { {0x443f001b,0x69da00a5,0x7ae247c1,0x00000000}},	//   _ưu_, mdte, _hrot,
  { {0x69da47c2,0x69d82347,0x27e947c3,0x00000000}},	//   ldte, _have, _unan_,
  { {0x6d481641,0x69d847c4,0xa2940054,0x00000000}},	// [8690] _lyda, _kave, каті,
  { {0x3f8647c5,0xf3ff0013,0xe1d9000d,0x00000000}},	//   ebou_, _giãn_, ядзі_,
  { {0xd839007d,0x6d481778,0x38b847c6,0x00000000}},	//   suču_, _nyda, nér_,
  { {0x69d802ab,0x6fd40086,0xa2a70042,0x00000000}},	//   _lave, кціє, _चिप्,
  { {0x9f40007a,0x61fc47c7,0x38b800ea,0x00000000}},	//   ðið_, _forl, hér_,
  { {0xc332014e,0x7bc20127,0x7d03172b,0x00000000}},	//   _תוך_, _abou, tyns,
  { {0xeb9901d5,0x6e2335f2,0x8c450320,0x00000000}},	//   пий_, rinb, неке,
  { {0x3ea647c8,0x6e2300c7,0x61fc005b,0x00000000}},	//   brot_, sinb, _zorl,
  { {0x78ba0031,0x69da006f,0x394747c9,0x00000000}},	//   ettv, fdte, _syns_,
  { {0x9c8208ea,0x5d840021,0xa2a70053,0x00000000}},	//   ščan, _للكل, _चिन्,
  { {0x69d801f7,0x38b80146,0x2d8700c3,0x00000000}},	//   _dave, gér_, mbne_,
  { {0xb6a6000a,0x68fc00c7,0x7c2d02e2,0x00000000}},	//   нимл, ärda, čars,
  { {0x7ae247ca,0x69d812cf,0x386900a3,0x00000000}},	//   _grot, _fave, _diar_,
  { {0x69d81f73,0x60d51556,0x3f8601d1,0x00000000}},	//   _gave, _oszm, zbou_,
  { {0xddc9074f,0x7bd90150,0x3f8601c8,0x00000000}},	//   _otež, _kawu, ybou_,
  { {0xb6020080,0xe73a0076,0x69d8189f,0x00000000}},	//   _žádo, _ней_, _zave,
  { {0x52aa0d64,0x43751845,0xc1e8005d,0x00000000}},	// [86a0] явам_, туст, وکسل_,
  { {0x38690a37,0xa3ba007e,0xdc030066,0x00000000}},	//   _ziar_, _کادر_, dčís,
  { {0xa3ea0431,0x61fc13f9,0x3f86027d,0x00000000}},	//   _една_, _vorl, tbou_,
  { {0x61fc47cb,0x6d48001f,0xa3ba0053,0x00000000}},	//   _worl, _ryda, _आउट_,
  { {0x6d481374,0x69c300c2,0x38b8013d,0x00000000}},	//   _syda, _obne, zér_,
  { {0x29050078,0xfe79004c,0x62841130,0x00000000}},	//   kyla_, _trůn_, mpio,
  { {0x8fa60088,0x3f8600ac,0x69d847cc,0x00000000}},	//   _паве, pbou_, _rave,
  { {0x961d0161,0x69d803bd,0x38b81d6b,0x00000000}},	//   _नष्ट_, _save, vér_,
  { {0x6d480045,0x69d847cd,0x7e6800c7,0x00000000}},	//   _wyda, _pave, _tidp,
  { {0x38690027,0x7afd248f,0x38b847ce,0x00000000}},	//   _siar_, ästa, tér_,
  { {0x0b8a0055,0x9f4402dd,0x7ae247cf,0x00000000}},	//   _если_, _tomó_, _wrot,
  { {0x69d80034,0x38b800d1,0x7ae247d0,0x00000000}},	//   _wave, rér_, _trot,
  { {0x69d847d1,0x7c2247d2,0x7ae247d3,0x00000000}},	//   _tave, _imor, _urot,
  { {0x29050080,0x442247d4,0x8cd70053,0x00000000}},	//   byla_, _amk_, _मनमो,
  { {0x248d017f,0x58d40330,0x4422004e,0x00000000}},	//   ćemo_, _ройт, _bmk_,
  { {0x21030024,0x60c70150,0x442208b7,0x00000000}},	//   nčiť_, _rpjm, _cmk_,
  { {0x6b840004,0x2d870066,0x24180766,0x00000000}},	// [86b0] _õigu, ybne_, хоты_,
  { {0x78a847d5,0x21030066,0x64460046,0x00000000}},	//   ordv, hčiť_, _ekki,
  { {0x5f950189,0x625000fe,0xc0780086,0x00000000}},	//   виет, päon, есії_,
  { {0xf1c00078,0x62500e7b,0xf8b30041,0x00000000}},	//   ėšas_, läol, טשע_,
  { {0x62830117,0x21030066,0x644d47d6,0x00000000}},	//   ćnos, dčiť_, mlai,
  { {0x62500019,0x7c220dd1,0x9c7c007d,0x00000000}},	//   näol, _amor, _srča,
  { {0xdce10051,0x6cd20021,0x644d47d7,0x00000000}},	//   _oglą, لقوا, olai,
  { {0x7c84005e,0x644d47d8,0x6250004d,0x00000000}},	//   ћује, nlai, häol,
  { {0x68fc0137,0x7bdb056f,0x644d47d9,0x00000000}},	//   ärdn, rduu, ilai,
  { {0x2fcf47da,0x644d0025,0x7bdb006f,0x00000000}},	//   legg_, hlai, sduu,
  { {0x644d3087,0x6abb1c7d,0x9c7c007d,0x00000000}},	//   klai, stuf, _trča,
  { {0xa088009a,0x6284056c,0x00000000,0x00000000}},	//   עְתִ, ypio,   ,
  { {0x442224ed,0x78a847db,0x9aa40049,0x00000000}},	//   _rmk_, ardv, _ممنو,
  { {0x69c347dc,0x6e2d0139,0x4422311b,0x00000000}},	//   _ubne, éabh, _smk_,
  { {0x442207b7,0x3667290b,0x6aa944b9,0x00000000}},	//   _pmk_, таро_, lref,
  { {0x644d47dd,0x62842f41,0x2fcf00d1,0x00000000}},	//   glai, tpio, jegg_,
  { {0xe29706e6,0x9196005e,0x232701e2,0x00000000}},	// [86c0] кат_, вјеш, воти_,
  { {0x17570063,0xd179000d,0x6b89004d,0x00000000}},	//   _בספר_, есці_, hbeg,
  { {0x644d4671,0xdfda0062,0x6aa9002b,0x00000000}},	//   blai, дъл_, href,
  { {0x6aa9076c,0x78fa0165,0x644d1823,0x00000000}},	//   kref, ופעו, clai,
  { {0x443247de,0x6b8900b8,0x7ed30044,0x00000000}},	//   mny_, dbeg, لزوا,
  { {0xa2a70235,0x44320d10,0x7c220d41,0x00000000}},	//   _चित्, lny_, _smor,
  { {0x61ee0e04,0x764e06a5,0x443213e4,0x00000000}},	//   _inbl, ilby, ony_,
  { {0x2cf20053,0x443247df,0x6b8947e0,0x00000000}},	//   _अपील_, nny_, gbeg,
  { {0x9c370062,0x21030066,0x69c13cda,0x00000000}},	//   ъпът_, rčiť_, ffle,
  { {0xd8f80086,0x2a6a00ea,0x44322eae,0x00000000}},	//   еної_, öbb_, hny_,
  { {0x38c8007e,0x6aa947e1,0x644d47e2,0x00000000}},	//   رادی_, aref, ylai,
  { {0x27ff007a,0x443206ce,0x3ea90008,0x00000000}},	//   ðun_, jny_, šate_,
  { {0xcc88006a,0x96f8005a,0xc6a70062,0x00000000}},	//   _آنچه_, веят_, ърни,
  { {0xb88247e3,0x764e00b9,0x44320ad6,0x00000000}},	//   üíst, glby, eny_,
  { {0x6b840019,0xca47007e,0x644d47e4,0x00000000}},	//   _õigs, _جلوه_, tlai,
  { {0x443247e5,0x61ee0ae2,0x62500072,0x00000000}},	//   gny_, _anbl, säol,
  { {0xfe790080,0xb355000d,0x644d47e6,0x00000000}},	// [86d0] _prům_, укаш, rlai,
  { {0x443247e7,0x644d47e8,0x52140505,0x00000000}},	//   any_, slai, адут,
  { {0x644d0cfc,0x26080053,0x9c7c00c2,0x00000000}},	//   plai, _सकती_, _srčn,
  { {0xa283006a,0x44320051,0xd491008b,0x00000000}},	//   _نیرو, cny_, ầu_,
  { {0xceeb006a,0x442947e9,0x69c1001f,0x00000000}},	//   بران_, mia_, yfle,
  { {0x3eaf0583,0x442947ea,0xed5902f9,0x00000000}},	//   rugt_, lia_, нол_,
  { {0x7c94000d,0x4c92005e,0x6b8947eb,0x00000000}},	//   арыц, бијс, tbeg,
  { {0x6aa947ec,0x249e0066,0x442947ed,0x00000000}},	//   tref, átmi_, nia_,
  { {0x1b490121,0x44290e78,0x69c1004d,0x00000000}},	//   эзии_, iia_, tfle,
  { {0x44320051,0x442947ee,0x4ea40062,0x00000000}},	//   zny_, hia_, _ърса,
  { {0x442947ef,0x44320045,0x6b890137,0x00000000}},	//   kia_, yny_, pbeg,
  { {0x442947f0,0xdb23007e,0x6aa903d4,0x00000000}},	//   jia_, _پوتی, pref,
  { {0x44320240,0x442947f1,0x69c147f2,0x00000000}},	//   vny_, dia_, pfle,
  { {0x44320045,0x7f5d006d,0x06560021,0x00000000}},	//   wny_, _úsqu, انسح,
  { {0xd5b8001c,0x442920c1,0x443227f1,0x00000000}},	//   ļā_, fia_, tny_,
  { {0x443247f3,0x442947f4,0x7c2947f5,0x00000000}},	//   uny_, gia_, nier,
  { {0x66e624fe,0x62500072,0x083b0047,0x00000000}},	// [86e0] _сопа, säom, _רעפל,
  { {0x7c2947f6,0x81a50021,0xc6930041,0x00000000}},	//   hier, لحمل, _האז_,
  { {0xd00a0905,0x442947f7,0x7c2947f8,0x00000000}},	//   неже_, bia_, kier,
  { {0x442947f9,0x71592979,0xb4c00082,0x00000000}},	//   cia_, трус_, ंझी_,
  { {0x539b0063,0xdfcf0021,0x7afd0a26,0x00000000}},	//   _איכו, ثين_, ästl,
  { {0x61ee08a5,0x7c2947fa,0x61461499,0x00000000}},	//   _unbl, eier, _бега,
  { {0x7c2947fb,0xec6a0893,0xc7cb008d,0x00000000}},	//   fier, нрик_, hiêị,
  { {0x7c2947fc,0x63b6002b,0xddc1008f,0x00000000}},	//   gier, ngyn, _vilš,
  { {0xee3a018b,0x8c43005e,0xcec3004c,0x00000000}},	//   _зна_, љење, ěří_,
  { {0x7c2900e8,0xf2d30063,0x7dc50021,0x00000000}},	//   aier, צעת_, _نتمك,
  { {0x9c7c0024,0x7c2947fd,0x4c86183f,0x00000000}},	//   _krčm, bier, _слев,
  { {0xaae60754,0xb606001c,0x64c700c2,0x00000000}},	//   _مستو, _lašā, nčiš,
  { {0x95cb47fe,0x7d0a00ac,0x66c83ce8,0x00000000}},	//   нува_, lyfs, лург_,
  { {0x442947ff,0x998c0006,0x63b61c59,0x00000000}},	//   wia_, rodų_, egyn,
  { {0xa2a70161,0x44294800,0x799a0d69,0x00000000}},	//   _चिह्, tia_, matw,
  { {0x44290858,0x767507ed,0x24f8014b,0x00000000}},	//   uia_, _клиф, ынсы_,
  { {0x290d0066,0x44294801,0x284a0041,0x00000000}},	// [86f0] čkať_, ria_, _שעפּ,
  { {0x7c294802,0x44294803,0x171c0041,0x00000000}},	//   zier, sia_, _רוזע,
  { {0x6013005b,0xcf27007e,0x44293e5a,0x00000000}},	//   _açma, گراي, pia_,
  { {0x7c2900bd,0xb4fa03c3,0x7416005d,0x00000000}},	//   xier, _ספרי, _نوپا,
  { {0x799a00a4,0x4439006f,0x539a009a,0x00000000}},	//   katw, _ijs_, _בירו,
  { {0x7c290045,0x9f5f0003,0x867c0149,0x00000000}},	//   wier, _joué_, ערוו,
  { {0x7c294804,0x799a00d1,0x88c7004c,0x00000000}},	//   tier, datw, _kněž,
  { {0x7c29006d,0x9f5f0003,0xa0c40021,0x00000000}},	//   uier, _loué_, _ديفو,
  { {0x7c294805,0xab620062,0x00000000,0x00000000}},	//   rier, овъл,   ,
  { {0x7c294806,0xa96902b3,0x2fdf4807,0x00000000}},	//   sier, кипа_, _haug_,
  { {0x2fdf004e,0x5bb94808,0x7c294809,0x00000000}},	//   _kaug_, _алея_, pier,
  { {0xfc67005a,0x28b60042,0xb0b6009a,0x00000000}},	//   _съзн, _अमरि, ספרס_,
  { {0xfaa5005e,0x3b09005e,0x6b9b0168,0x00000000}},	//   _ђако, _јело_, maug,
  { {0xb21b00b9,0x6b9b480a,0x9816005d,0x00000000}},	//   _stæn, laug, ابگا,
  { {0xc3960259,0x9f5f0003,0xf5030156,0x00000000}},	//   ијањ, _doué_, озро,
  { {0xf814006a,0x3ea0027c,0x07a63e90,0x00000000}},	//   _دستگ, šiti_, _таин,
  { {0x27e000f3,0xf3f7001b,0xd4670962,0x00000000}},	// [8700] _iain_, ợng_, рите_,
  { {0x2606017d,0x63b6001f,0x27e0162d,0x00000000}},	//   _vôos_, sgyn, _hain_,
  { {0x6b9b1a61,0x27e0070e,0x3c3a008f,0x00000000}},	//   kaug, _kain_, hīva_,
  { {0xe3b2006a,0xc059000d,0x888c0047,0x00000000}},	//   _برد_, гіі_, גראַ,
  { {0x2fdf00eb,0x27e02704,0x3ea00003,0x00000000}},	//   _daug_, _main_, éit_,
  { {0x27e00397,0x7ae40027,0xeca60001,0x00000000}},	//   _lain_, _áiti, ајин,
  { {0x4c940076,0xadf70021,0x62500072,0x00000000}},	//   щийс, شروط_, jäoi,
  { {0xa3c90161,0x7d0a00ac,0xeca70053,0x00000000}},	//   ल्प_, ryfs, _गिरफ,
  { {0xb881017d,0xf1c60053,0x799a002b,0x00000000}},	//   üíne, र्थन, tatw,
  { {0xdb09005b,0x6b9b008f,0xdca6480b,0x00000000}},	//   zgeç, aaug, _важи,
  { {0xa3e60394,0x27e00027,0x395800b9,0x00000000}},	//   पया_, _bain_, års_,
  { {0x2d9c480c,0xf1c60053,0x9873000d,0x00000000}},	//   lave_, र्तन, ўляц,
  { {0x799a0035,0x6286006f,0x7d0f0066,0x00000000}},	//   patw, _ntko, čisť,
  { {0x2d9c2a64,0x88c7004c,0x25ad004d,0x00000000}},	//   nave_, _sněž, ßel_,
  { {0xf5e40086,0x26c200fe,0x3427000d,0x00000000}},	//   ціям, atko_, афав,
  { {0x2004051e,0x2d9c0860,0xd3750001,0x00000000}},	//   _nomi_, have_, слаћ,
  { {0x2d9c085a,0x9c7c007d,0x91870044,0x00000000}},	// [8710] kave_, _brčk, لجام,
  { {0x27e000e3,0x98da0053,0xf8da0053,0x00000000}},	//   _zain_, _बनाए, _बनाय,
  { {0xe4e40054,0x68fc00a5,0xa3d51313,0x00000000}},	//   _діян, ärdh, _лонч,
  { {0xa25b0003,0x2d9c480d,0x0ee20042,0x00000000}},	//   _apôt, eave_, पिंड,
  { {0xa2670062,0xdfd80062,0xdb070058,0x00000000}},	//   _въвл, ръх_, ölüm,
  { {0x9c7c017f,0x2d9c05e5,0x6b82017d,0x00000000}},	//   _grčk, gave_, _afog,
  { {0x4c920001,0x6b9b252f,0x20d400de,0x00000000}},	//   пијс, taug, _وتفج,
  { {0x2d82000f,0xf5383997,0x3c3a001c,0x00000000}},	//   _őket_, ינוי_, tīva_,
  { {0xa3c90161,0x27e0480e,0x3f15026c,0x00000000}},	//   ल्य_, _rain_, _удас,
  { {0x6b9b480f,0x75280051,0x27e04810,0x00000000}},	//   saug, ździ, _sain_,
  { {0x27e034a4,0x29114811,0xd945182e,0x00000000}},	//   _pain_, áza_, сени,
  { {0x7d560063,0x96ba0184,0xa3c90053,0x00000000}},	//   _היעד_, лугу_, ल्म_,
  { {0x27e0024a,0xdce301f7,0x39540024,0x00000000}},	//   _vain_, manı, _časť_,
  { {0xdce301f7,0xef120047,0x26c24812,0x00000000}},	//   lanı, פּר_, rtko_,
  { {0x26c20051,0x291e0051,0x5e560041,0x00000000}},	//   stko_, czta_, מישע_,
  { {0x2d9c0198,0xdce3005b,0x05550054,0x00000000}},	//   zave_, nanı, ітря,
  { {0x38a301f7,0x26de001c,0xc3560062,0x00000000}},	// [8720] lır_, ātos_, съвъ,
  { {0x9c820198,0x21760086,0xd24f0044,0x00000000}},	//   ščin, суар, ّنك_,
  { {0x386000e3,0x999a00b5,0x38a301f7,0x00000000}},	//   _khir_, רבעט, nır_,
  { {0x68fc0137,0x2d9c3992,0xa0671528,0x00000000}},	//   ärdi, wave_, баха_,
  { {0x9f49007a,0xf67a0047,0x628608a9,0x00000000}},	//   ðað_, נאַמ, _utko,
  { {0x6b82051e,0x38a30058,0xe3b2005d,0x00000000}},	//   _sfog, kır_, _برگ_,
  { {0x557700b5,0xdce3005b,0x2d9c1bdb,0x00000000}},	//   זעצן_, fanı, rave_,
  { {0x5b140055,0x38a301f7,0x6d5a0080,0x00000000}},	//   жмит, dır_, _vzta,
  { {0xda7a0088,0xea18066f,0x0aea0044,0x00000000}},	//   ыяй_, ижиш_, اربي_,
  { {0x386000cd,0xff170063,0x290c0b13,0x00000000}},	//   _ahir_, _הקמת_, tyda_,
  { {0x2bca019d,0x66050004,0xf814001b,0x00000000}},	//   _було_, _rohk, ược_,
  { {0x3c770063,0x7ae40078,0xa1570063,0x00000000}},	//   _התאם_, _šitu, מביה_,
  { {0x291e14e0,0xf1d80042,0x00000000,0x00000000}},	//   szta_, ड़ान,   ,
  { {0xe84c0080,0x09e30121,0x78ab00b9,0x00000000}},	//   ětší, _ночн, ålvæ,
  { {0xe654019d,0x38600139,0x88590002,0x00000000}},	//   ївсь, _fhir_, _кикс_,
  { {0x69c80104,0x54550054,0x3eaf0014,0x00000000}},	//   lfde, іват, yrgt_,
  { {0x24580076,0x69c8006f,0x27f40066,0x00000000}},	// [8730] сать_, ofde, šaní_,
  { {0xdce3005b,0xdb1f0003,0x7afd4813,0x00000000}},	//   zanı, évér, ästi,
  { {0xa25b0024,0xdce3005b,0xc0d5007e,0x00000000}},	//   _spôs, yanı, تياب,
  { {0x9c7c00c2,0x58bb0041,0x9f5518ea,0x00000000}},	//   _grči, רמאצ, овеч,
  { {0x38a3005b,0x9f340086,0xdce30058,0x00000000}},	//   zır_, пеці, vanı,
  { {0x38a3005b,0x26140019,0xee380086,0x00000000}},	//   yır_, _näol_, бні_,
  { {0xdce3005b,0xa3c90042,0xed591577,0x00000000}},	//   tanı, ल्थ_, шок_,
  { {0xe0d200b5,0x38a30058,0x69c800ca,0x00000000}},	//   _קײן_, vır_, efde,
  { {0xdce301f7,0xce940062,0x628d0050,0x00000000}},	//   ranı, _натъ, npao,
  { {0x38a301f7,0xdce3005b,0x88c90612,0x00000000}},	//   tır_, sanı, алов_,
  { {0x999e0080,0x442b4814,0xf1b20063,0x00000000}},	//   nitř_, _omc_, וסי_,
  { {0x7e7b0004,0xb9010053,0x442b0089,0x00000000}},	//   _kuup, _नई_, _nmc_,
  { {0x38a3005b,0xf77201fb,0xf7190085,0x00000000}},	//   sır_, باد_, біры_,
  { {0x644f4815,0x7ae90137,0x442b4816,0x00000000}},	//   _akci, mvet, _amc_,
  { {0xd4f50121,0x7ae94817,0x3860002b,0x00000000}},	//   пяты, lvet, _thir_,
  { {0x69c50053,0x442b0afd,0x69de42d7,0x00000000}},	//   ़्री, _cmc_, _óper,
  { {0x7ae900fe,0x87230062,0xfbd20063,0x00000000}},	// [8740] nvet, _омъж, ותן_,
  { {0xe1f7413b,0x915f008b,0xe2460021,0x00000000}},	//   огу_, _sắp_, آخري,
  { {0x7c2b0147,0x60260500,0x9c7c0077,0x00000000}},	//   _omgr, оджа, _trči,
  { {0x9c7c016b,0x2d8545b0,0x2eed4818,0x00000000}},	//   _urči, _afle_, _bref_,
  { {0x64410003,0x65890003,0xaad80053,0x00000000}},	//   élie, _éphé, _बैंक,
  { {0x6ce50161,0x7ae900c7,0x2eed001f,0x00000000}},	//   किंग_, dvet, _dref_,
  { {0xb7bb017d,0x7bc94819,0x6fb60044,0x00000000}},	//   lhãe, ffeu, _ومسا,
  { {0x984d0022,0x8aa601f8,0xddc80078,0x00000000}},	//   _iść_, ород, _didš,
  { {0x7ae900ea,0xada60002,0x2eed002b,0x00000000}},	//   gvet, _маал, _gref_,
  { {0x82f7014e,0xdb09004c,0x91ba009a,0x00000000}},	//   קציב_, énác, ׁמִי,
  { {0xb17b00b5,0xb21b0026,0x62500072,0x00000000}},	//   יטיר, _stæk, läos,
  { {0xe7eb0082,0x00000000,0x00000000,0x00000000}},	//   _जोशा_,   ,   ,
  { {0x6250004b,0x7ae9085a,0xeb910063,0x00000000}},	//   näos, cvet, _נָא_,
  { {0xceb307e9,0xdcfa008f,0x60c5481a,0x00000000}},	//   ויש_, _netī, ythm,
  { {0x80c90053,0x442b18c3,0x4dfb0047,0x00000000}},	//   _रहें, _pmc_, ספלא,
  { {0x68fc004b,0xdc8b009a,0xb867043e,0x00000000}},	//   ärdu, יְמָ, _باتو,
  { {0xd763007e,0x95cb1845,0xe18b005d,0x00000000}},	// [8750] _تنظی, _куна_, لئان_,
  { {0xd251013a,0xc692069a,0x20d60042,0x00000000}},	//   رنا_, _ראי_, ठबंध,
  { {0x212700aa,0x7ae919e6,0x7e7b004e,0x00000000}},	//   ành_, zvet, _suup,
  { {0x2eed481b,0x60c5035a,0x69ca0053,0x00000000}},	//   _pref_, rthm, त्ती,
  { {0xfd4c008b,0xb3670062,0x644d005f,0x00000000}},	//   _triề, _фънк, moai,
  { {0xc27a0063,0x7ae9005b,0xfce5055d,0x00000000}},	//   _לרשי, vvet, зоко,
  { {0xba3d004c,0xdd8e0044,0x2fd700de,0x00000000}},	//   zrůs, دوى_, _وترح,
  { {0x2eed481c,0x644d30f2,0x62500072,0x00000000}},	//   _tref_, noai, säot,
  { {0xeab10021,0x443b0003,0xdb0904aa,0x00000000}},	//   رعة_, inq_, ngeø,
  { {0x7ae93c69,0xba220505,0x7bc90244,0x00000000}},	//   rvet, едьк, sfeu,
  { {0xbb7500d7,0xf1b20047,0x7ae9481d,0x00000000}},	//   _егеј, עסט_, svet,
  { {0x7ae900ea,0x7c2b0244,0xe8f6012c,0x00000000}},	//   pvet, _umgr, їля_,
  { {0xf7720021,0x4b7a0063,0xa3e60053,0x00000000}},	//   عاج_, _האנו, _योग_,
  { {0xa3c90053,0x7afd481e,0xa50a2b4f,0x00000000}},	//   ल्स_, ästu, бега_,
  { {0x38ca006a,0x1828006a,0x7ae40139,0x00000000}},	//   _هايی_, _وقتی_, _áitr,
  { {0x7c3b481f,0xba3d011b,0x00000000,0x00000000}},	//   nnur, průs,   ,
  { {0x3cdd0053,0x7c3b4820,0xc8650021,0x00000000}},	// [8760] _कैसे_, inur, _تطوي,
  { {0x7c3b00e0,0x61460896,0xd2a7014b,0x00000000}},	//   hnur, пеза, якуе_,
  { {0x64560034,0xc5eb0063,0xc3290063,0x00000000}},	//   plyi, _הַכֹ, נו_,
  { {0x764e0246,0xdb1b00be,0x1eaa009e,0x00000000}},	//   loby, rguê, ماتي_,
  { {0x0377009a,0x7053043e,0xb77b009a,0x00000000}},	//   _מתכת_, رنها, צָאת,
  { {0x7c3b0801,0x60e10072,0xd2520021,0x00000000}},	//   enur, äymä, _أنس_,
  { {0x39a60025,0x4420004b,0x62500072,0x00000000}},	//   hísí_, ohi_, säos,
  { {0x4420002c,0x6bd60021,0xa08b089e,0x00000000}},	//   nhi_, ستعر, _לְמִ,
  { {0xade70053,0x764e1bc1,0xef1a2184,0x00000000}},	//   _टोकन_, koby, _ума_,
  { {0x39140138,0x2bac0013,0x44204821,0x00000000}},	//   дмор, ớc_, hhi_,
  { {0x44322909,0x44200532,0x764e0470,0x00000000}},	//   kiy_, khi_, doby,
  { {0x3f86017d,0xe7590086,0x9a86005e,0x00000000}},	//   ncou_, жимі_, _еукл,
  { {0x44200009,0xe667005a,0x3f86017d,0x00000000}},	//   dhi_, зтво, icou_,
  { {0x68fc0137,0x7ae23973,0xa8a604f2,0x00000000}},	//   ärds, _isot, _ерик,
  { {0x69da39cc,0x644d3faf,0x2d9e4822,0x00000000}},	//   mete, toai, _mete_,
  { {0x9d1b00b7,0x69da4823,0x2d9e4824,0x00000000}},	//   זולט, lete, _lete_,
  { {0x69da224d,0x877c0047,0x644d00dd,0x00000000}},	// [8770] oete, _פאזי, roai,
  { {0x644d0016,0x69da4825,0xe1d9000d,0x00000000}},	//   soai, nete, юдзі_,
  { {0x320a0114,0x69da4826,0xf485005d,0x00000000}},	//   _doby_, iete, _تاخی,
  { {0x69da4827,0x98c5007d,0x44204828,0x00000000}},	//   hete, žući_, chi_,
  { {0xa2a70053,0x3885008f,0x69da4829,0x00000000}},	//   _चिट्, _mēra_, kete,
  { {0x41e4000d,0xee380086,0x2d9e482a,0x00000000}},	//   _піса, пні_, _cete_,
  { {0xd0d4011c,0x1d06005a,0x69da482b,0x00000000}},	//   _поръ, дещи_, dete,
  { {0x61e700ea,0x7c3b482c,0xdb1b14ca,0x00000000}},	//   _hajl, unur, lgué,
  { {0x2d9e3fe3,0x69da482d,0x7c3b482e,0x00000000}},	//   _fete_, fete, rnur,
  { {0xb33b01f7,0xdb1b482f,0xf8a90065,0x00000000}},	//   _geçe, ngué, овок_,
  { {0x61e700e3,0x186a0c09,0x7ae24830,0x00000000}},	//   _majl, жани_, _esot,
  { {0xf09200b5,0x5b15005e,0xc5f8008f,0x00000000}},	//   כנט_, _омет, ķēm_,
  { {0xddc1127e,0x69da4831,0xf77204a0,0x00000000}},	//   _milž, bete, ضاح_,
  { {0x61e74832,0x78ba13e5,0x69da4833,0x00000000}},	//   _najl, butv, cete,
  { {0x44204834,0xd4d50085,0x60130075,0x00000000}},	//   thi_, нітэ, _eçmi,
  { {0xe29a000a,0xc9520063,0x442018d5,0x00000000}},	//   жаа_, _שמה_, uhi_,
  { {0x44204835,0x21a60263,0x48e50082,0x00000000}},	// [8780] rhi_, дизм, टिको_,
  { {0x442010ca,0xdb1b01a8,0xc1d80042,0x00000000}},	//   shi_, rguè, ड़ेग,
  { {0x2d9e02f6,0x442025ca,0x25e70053,0x00000000}},	//   _rete_, phi_, _छोटी_,
  { {0xb33b01f7,0x2d9e4836,0x69da4837,0x00000000}},	//   _seçe, _sete_, zete,
  { {0x3f860016,0x61e7017f,0x63b90051,0x00000000}},	//   rcou_, _fajl, ówne,
  { {0xdce80024,0x3f9f006d,0xdc8a0076,0x00000000}},	//   _vedľ, _eeuu_, осил_,
  { {0xdb190051,0x2d9e4838,0x3ea64839,0x00000000}},	//   _obwó, _vete_, ssot_,
  { {0x2d9e00f5,0x69da1031,0x44c8004d,0x00000000}},	//   _wete_, wete, iß_,
  { {0x69da0246,0xe4570063,0x5a460085,0x00000000}},	//   tete, ויקט_, дэна,
  { {0x63a4483a,0x7ae200c3,0x6ffe000c,0x00000000}},	//   hain, _vsot, _făcâ,
  { {0x291837cb,0x7afd0137,0x63a4483b,0x00000000}},	//   ára_, ästr, kain,
  { {0x63a4483c,0x78ba0829,0x69da483d,0x00000000}},	//   jain, rutv, sete,
  { {0x44c800bd,0x78ba483e,0x63a4483f,0x00000000}},	//   eß_, sutv, dain,
  { {0x7bc00146,0x7afd16af,0xaa570021,0x00000000}},	//   lgmu, åste, _قلنا_,
  { {0xdb00006d,0x63a4001f,0x18970021,0x00000000}},	//   damé, fain, _قضية_,
  { {0x3ea902e2,0x69ca0053,0x63a44840,0x00000000}},	//   šati_, त्री, gain,
  { {0x44c800bd,0x533402b6,0x787d0066,0x00000000}},	// [8790] aß_, ветт, rávň,
  { {0xdb0003b2,0xc2c40032,0xd25b000d,0x00000000}},	//   ramè, ئيلي, іца_,
  { {0xd1310032,0x31c4005a,0x63a44841,0x00000000}},	//   دما_, ъств, bain,
  { {0xa2950088,0x63a404bc,0x27e90019,0x00000000}},	//   _памі, cain, _jaan_,
  { {0x27e94842,0x22840058,0x61e72ee7,0x00000000}},	//   _maan_, _gök_, _tajl,
  { {0xe61f017d,0x27e909fe,0x7bc0013d,0x00000000}},	//   mpôs_, _laan_, egmu,
  { {0xf41f0137,0x64480003,0xddc10078,0x00000000}},	//   _klä_, édig, _tilž,
  { {0x5ba90001,0x3eb20006,0xd4910013,0x00000000}},	//   чким_, šyta_, ầy_,
  { {0xef54005a,0x7bdb02d2,0x3da73852,0x00000000}},	//   _акть, reuu, _жреб,
  { {0xf41f00fe,0xbef80021,0x7bdb004b,0x00000000}},	//   _llä_, _ترفض_, seuu,
  { {0xf65f0146,0x27e90983,0xd7ea0002,0x00000000}},	//   rtæl_, _baan_, пмне_,
  { {0x628f01d9,0xab5d0051,0x9f4401c8,0x00000000}},	//   _otco, zeży, _samé_,
  { {0x27e9002c,0x7d180024,0xcc3a00b5,0x00000000}},	//   _daan_, časť, _צענט,
  { {0x63a44843,0xd9450e6b,0x64411123,0x00000000}},	//   wain, _пели, élin,
  { {0x228401e3,0x63a40498,0xd46a0001,0x00000000}},	//   _sök_, tain, зиве_,
  { {0x27e904c6,0x6b894844,0x7dd3005b,0x00000000}},	//   _gaan_, nceg, lısı,
  { {0x62660002,0x6aa94845,0x25a1004d,0x00000000}},	// [87a0] еваа, nsef, _fehl_,
  { {0x7dd3005b,0x69c1119a,0x63a44846,0x00000000}},	//   nısı, ngle, sain,
  { {0xf1c60053,0x63a416fa,0x3ebd006f,0x00000000}},	//   र्गन, pain, euwt_,
  { {0x40560021,0xa2b20053,0x6143000d,0x00000000}},	//   رئاس, ेंद्, ыеха,
  { {0x201f003b,0xddc3013d,0x7dd30075,0x00000000}},	//   _dlui_, elnő, kısı,
  { {0x6aa925c6,0x2d580121,0x41c70042,0x00000000}},	//   dsef, миль_, _लायस,
  { {0x69c1007d,0xace70002,0xf41f0072,0x00000000}},	//   dgle, емја_, _ylä_,
  { {0x2c610024,0x59c20053,0x69c14847,0x00000000}},	//   tóda_, _शाहर, egle,
  { {0xdcea01f7,0x8bd3000d,0x99a4004c,0x00000000}},	//   rafı, ужыц, átům_,
  { {0x27e91eb1,0xf3ff008b,0x69c14848,0x00000000}},	//   _saan_, _nhãn_, ggle,
  { {0x39580146,0x0dc90021,0x48a7012c,0x00000000}},	//   ærs_, _تبقى_, нтям_,
  { {0x69c14303,0x2481004d,0xb8d80053,0x00000000}},	//   agle, _ruhm_, _चि_,
  { {0x27e900fe,0x68e100ca,0x69c1004d,0x00000000}},	//   _vaan_, awld, bgle,
  { {0xdb02017d,0x7dd3005b,0x6d5a004c,0x00000000}},	//   _adoç, cısı, _kyta,
  { {0x644103b2,0xf65f0026,0x69b90042,0x00000000}},	//   élio, ltæk_, _एफ़टी,
  { {0xb6f50095,0x3c3a008f,0x55580085,0x00000000}},	//   _азиј, būve_, хася_,
  { {0x200d00f5,0x6a660014,0x57b40121,0x00000000}},	// [87b0] _roei_, aðfe, _сбыт,
  { {0xa507000d,0xc354005e,0x28c40042,0x00000000}},	//   _зямл, укуј, लंपि,
  { {0x999e013d,0x6aa9009c,0xc05b012c,0x00000000}},	//   nitő_, zsef, під_,
  { {0x7dd3005b,0x69c108ed,0x6e950962,0x00000000}},	//   zısı, zgle, виду,
  { {0x7dd301f7,0x64480003,0xb3640062,0x00000000}},	//   yısı, édie, _бърк,
  { {0x6d5a0137,0x7e7a0023,0xfe57005d,0x00000000}},	//   _byta, _citp, ریاب_,
  { {0xdb09004d,0x3c3a008f,0x6d5a0022,0x00000000}},	//   sgeü, hīvu_, _cyta,
  { {0x201f0529,0xcec10051,0x7c2d0066,0x00000000}},	//   _ului_, _pięć_, ďaro,
  { {0x69c1004d,0x6b894849,0x7dd30058,0x00000000}},	//   tgle, rceg, tısı,
  { {0x6aa9484a,0x69c1484b,0x6b8926c7,0x00000000}},	//   rsef, ugle, sceg,
  { {0x69c10199,0x7dd3005b,0x6e2100c7,0x00000000}},	//   rgle, rısı, _illb,
  { {0x69c12cbf,0x68fc0137,0xdb1b0331,0x00000000}},	//   sgle, årda, lguí,
  { {0x96f9000d,0x7dd3005b,0xdb070072,0x00000000}},	//   нэру_, pısı, äläl,
  { {0xdb1b16eb,0x6280006c,0x69c6013d,0x00000000}},	//   nguí, _émoi, őker,
  { {0xf3ff0016,0xe5a30893,0xba080044,0x00000000}},	//   _chão_, риси, _ستوك_,
  { {0xe8d60063,0x38690139,0x3f8d01a8,0x00000000}},	//   _יוצר_, _ghar_, _nfeu_,
  { {0xb33b0016,0x6e2132fe,0x77990063,0x00000000}},	// [87c0] _peça, _ollb, _אֹתו,
  { {0xb21b263e,0x422305a1,0x6448006c,0x00000000}},	//   _stær, адув, édib,
  { {0x3ead08c0,0x2176484c,0x00000000,0x00000000}},	//   _avet_, туар,   ,
  { {0xdfd0007e,0x7e7a00ac,0x6d5a0078,0x00000000}},	//   صيت_, _sitp, _ryta,
  { {0x442201f7,0x8fc5007e,0x3ed40021,0x00000000}},	//   _ilk_, ازمن, اقتر,
  { {0x6d5a0045,0x6836008f,0x3eb20078,0x00000000}},	//   _pyta, kšdo, šyto_,
  { {0x10a30086,0xa3c90161,0x3ead005b,0x00000000}},	//   _висн, ल्क_, _evet_,
  { {0xdc2a007e,0x6d5a484d,0x21670054,0x00000000}},	//   بسته_, _vyta, _риси_,
  { {0x442225b5,0x8c43005e,0x6826013d,0x00000000}},	//   _mlk_, јење, _módd,
  { {0x7e7a0983,0xf65f0014,0x6d5a484e,0x00000000}},	//   _uitp, rtæk_, _tyta,
  { {0x91bb0063,0x2cb800ea,0x23e20053,0x00000000}},	//   ומיי, _írd_, _पसंद,
  { {0x92a90051,0x3c3a001c,0x28c40053,0x00000000}},	//   nałó, tīvu_, लंबि,
  { {0xf848000d,0x64410003,0x95cb06da,0x00000000}},	//   тчэй_, élim, мува_,
  { {0xb8f40021,0x7c22484f,0x7793005d,0x00000000}},	//   _مكتب, _hlor, دیکا,
  { {0x03c70088,0x38690025,0x55580ac5,0x00000000}},	//   ксам, _thar_, варя_,
  { {0x99650086,0x34240054,0x9cd7009a,0x00000000}},	//   _стіл, афув, כולה_,
  { {0x24580055,0x6e3800a5,0x62d90085,0x00000000}},	// [87d0] тать_, kivb, эмаў_,
  { {0x44220a53,0x9f440268,0x7c224850,0x00000000}},	//   _elk_, _camí_, _llor,
  { {0x7c224851,0x3ead0648,0x64483c81,0x00000000}},	//   _olor, _svet_, édic,
  { {0x251a0aeb,0x50641f63,0xa2c30082,0x00000000}},	//   _נורא, атча, िंद्,
  { {0x539a0063,0x3c3a008f,0x03d600ff,0x00000000}},	//   _רישו, hīvs_, _גורם_,
  { {0x7c2203b2,0x51871225,0x0dc8005e,0x00000000}},	//   _alor, _шума, вући_,
  { {0x6da203d1,0x4e18007e,0xdb1b0857,0x00000000}},	//   щища, ختند_, rguí,
  { {0x20f3007d,0x7c223131,0x2b400b59,0x00000000}},	//   _ići_, _clor, _žica_,
  { {0xdd950085,0x78ba4852,0x0a39082d,0x00000000}},	//   _базы, ertv, ечны_,
  { {0xf9d40086,0xb33b0003,0x68264853,0x00000000}},	//   ацюю, _leço, _móde,
  { {0x07a61099,0x7c220749,0xc7a60867,0x00000000}},	//   ланн, _flor, линк,
  { {0x30da0047,0x7c220653,0xc5e90063,0x00000000}},	//   ײַטע, _glor, _מד_,
  { {0x9f8a0019,0x38b90026,0x78ba00ca,0x00000000}},	//   _tööd_, _býrð_, artv,
  { {0x2aba014e,0x7c2200c3,0x7d1e04aa,0x00000000}},	//   _נמצא, _zlor, øpsg,
  { {0x38b90014,0x33d6071f,0x43fa030b,0x00000000}},	//   _dýrð_, ліат, нхая_,
  { {0xba3d004c,0xf814005d,0x80cd0042,0x00000000}},	//   jrůz, _خستگ, _सहजे,
  { {0x7c3e0003,0x2327167b,0x9f9d0014,0x00000000}},	// [87e0] épri, готи_, _ræðu_,
  { {0x55e6253f,0x44223752,0x869b016e,0x00000000}},	//   _сооб, _wlk_, _רייז,
  { {0xa988009a,0xe08500de,0x00000000,0x00000000}},	//   דָנִ, لجني,   ,
  { {0xe29a019d,0x4f2601ce,0x6fb6005d,0x00000000}},	//   _пам_, лдеб, امشا,
  { {0x66ad0063,0xdd92007e,0x6826013d,0x00000000}},	//   ֵיהֶ, موش_, _kódb,
  { {0x69d30053,0x7c2200ca,0x90a60049,0x00000000}},	//   _बॉली, _slor, _محرم,
  { {0x628610c4,0x6e3801b9,0xb2230001,0x00000000}},	//   _huko, rivb, _умрл,
  { {0x61ee02dd,0xe4f70161,0x6abb2cbf,0x00000000}},	//   _habl, ुमति_, fruf,
  { {0xbc670754,0x61ee4854,0xa3c90053,0x00000000}},	//   دمين_, _kabl, ल्ट_,
  { {0xd8f8019d,0x62861964,0x3c3a001c,0x00000000}},	//   вної_, _muko, tīvs_,
  { {0x644400fe,0x61ee0035,0x7d1e00d1,0x00000000}},	//   knii, _mabl, øpsd,
  { {0x645600e5,0xdb00002b,0xf8070085,0x00000000}},	//   joyi, ramâ, учон,
  { {0x62860006,0xb33b0164,0xcc57069a,0x00000000}},	//   _nuko, _reço, _גבאי_,
  { {0x61ee4855,0x34950121,0x27ed45e4,0x00000000}},	//   _nabl, иагр, žen_,
  { {0xf993014e,0x5559005a,0x63a6006f,0x00000000}},	//   _פרק_, тавя_, _bekn,
  { {0x62864856,0x3ea001c8,0x43950085,0x00000000}},	//   _buko, šity_, раас,
  { {0x92590079,0x64480164,0x53470001,0x00000000}},	// [87f0] ваат_, édia, ухва,
  { {0xbb3b0047,0xbc840013,0xa5350054,0x00000000}},	//   געמי, _ướn, _вноч,
  { {0xc5f8001c,0xd262008f,0x69dd013d,0x00000000}},	//   ķēt_, diņā_, őseg,
  { {0x6b82001f,0x63a60518,0x2ef545f6,0x00000000}},	//   _ngog, _gekn, изер,
  { {0x69d81312,0xddc800eb,0x44290025,0x00000000}},	//   _obve, _didž, mha_,
  { {0x442903d9,0xef180088,0xb2ba0063,0x00000000}},	//   lha_, ымі_, _במשר,
  { {0x999e0080,0x20f3007d,0x7c84005e,0x00000000}},	//   entů_, _ući_, буње,
  { {0x442913a8,0x26c200a4,0x443b3170,0x00000000}},	//   nha_, yuko_, niq_,
  { {0xcda90032,0x62800164,0x1c42000d,0x00000000}},	//   _لهذه_, _émot, ўным,
  { {0xd262001c,0xe8f90086,0x6444008f,0x00000000}},	//   ciņā_, вло_, znii,
  { {0x44294857,0x5d8408aa,0x6abb004d,0x00000000}},	//   kha_, _المل, sruf,
  { {0x67fb00fe,0x3ea0003b,0xbc360072,0x00000000}},	//   _räjä, ţite_, äätö,
  { {0x44290009,0x46e7019d,0x8c1a014e,0x00000000}},	//   dha_, адян_, _שוני,
  { {0x7c294858,0xc987413b,0x44291aec,0x00000000}},	//   lher, _суди, eha_,
  { {0x9f44006d,0x62864859,0x845a0925,0x00000000}},	//   _mamá_, _suko, врат_,
  { {0x4429485a,0x9346000a,0xb8db0053,0x00000000}},	//   gha_, анбе, ें_,

  { {0x64560034,0x935a0001,0x61ee485b,0x00000000}},	// [8800] royi, трву_, _pabl,
  { {0xb33b01f7,0xc6930063,0x44292831,0x00000000}},	//   _geçm, _ואז_, aha_,
  { {0x55bb0063,0x61ee00c2,0x63a63ce4,0x00000000}},	//   _במיו, _vabl, _tekn,
  { {0xfa88008b,0x1eaa0021,0x4429485c,0x00000000}},	//   _lừa_, ناتي_, cha_,
  { {0xd262001c,0x5de60062,0xd9e50053,0x00000000}},	//   tiņā_, ижда, क़ात_,
  { {0x7c291629,0x471b0047,0xdb000014,0x00000000}},	//   eher, כונג, jamá,
  { {0xdb000014,0xcd060002,0x6143259e,0x00000000}},	//   damá, рчли, _дера,
  { {0x7c29485d,0x1d070001,0x01630086,0x00000000}},	//   gher, рећи_, _єкто,
  { {0x5a34005a,0x7d1e00d1,0x787f008f,0x00000000}},	//   йнит, øpsb, _būvn,
  { {0x5cd60086,0xcb670095,0xdb000014,0x00000000}},	//   _відх, шање_, gamá,
  { {0x4420485e,0xa954000d,0xfa880013,0x00000000}},	//   kki_, скні, _dừa_,
  { {0xb33b01f7,0x7c3b003b,0x7c290136,0x00000000}},	//   _seçm, ciur, cher,
  { {0xaa940021,0xdce10023,0x4420485f,0x00000000}},	//   _التث, _izlā, dki_,
  { {0x44204860,0x8afb0063,0xaadb0149,0x00000000}},	//   eki_, _שהגי, _סחור,
  { {0x44294861,0x2918004b,0xa5f8005e,0x00000000}},	//   tha_, ärad_, јесу_,
  { {0xe97b014e,0x69c80afe,0x442000a4,0x00000000}},	//   _בנוש, lgde, gki_,
  { {0xf773007e,0x44294862,0x443b4863,0x00000000}},	// [8810] _باغ_, rha_, riq_,
  { {0x4429058c,0x69c806a3,0x9178008b,0x00000000}},	//   sha_, ngde, _sớm_,
  { {0x44204864,0x91070085,0x44294865,0x00000000}},	//   bki_, шчад, pha_,
  { {0xa3ce0161,0xfff9006a,0x1dc9016a,0x00000000}},	//   _राय_, دکست_, _राहत,
  { {0x161b0235,0x7c3b223e,0x613c01f2,0x00000000}},	//   _नकार_, viur, _pålø,
  { {0x7c290034,0x6da21001,0x63ad4866,0x00000000}},	//   wher, пиша, laan,
  { {0x7c294867,0xa3ce0053,0x44393976,0x00000000}},	//   ther, _राम_, _kms_,
  { {0x4035005a,0x44390019,0x69c8006f,0x00000000}},	//   _уебс, _jms_, egde,
  { {0x44394868,0x7c3b4869,0x7c29486a,0x00000000}},	//   _mms_, riur, rher,
  { {0x69c800c7,0x7c29486b,0xe8df0013,0x00000000}},	//   ggde, sher, hiễm_,
  { {0xfa88001b,0x44200051,0x7c29116b,0x00000000}},	//   _vừa_, yki_, pher,
  { {0x69c81c41,0x63ad486c,0x6a25005d,0x00000000}},	//   agde, jaan, _گفتم,
  { {0x442001a6,0x63ad486d,0xfaa50002,0x00000000}},	//   vki_, daan, _ѓако,
  { {0x44200045,0x645d486e,0x7ae90035,0x00000000}},	//   wki_, _aksi, mwet,
  { {0xfa34007e,0x4420486f,0x64481560,0x00000000}},	//   _برند, tki_, édio,
  { {0x3eb200eb,0x3f8000eb,0x68fc05b9,0x00000000}},	//   šyti_, žiui_, ærde,
  { {0x61e500bd,0x44204870,0xa923004c,0x00000000}},	// [8820] fehl, rki_, ěžuj,
  { {0x7ae9001f,0x7afd00fe,0x44204871,0x00000000}},	//   iwet, ästy, ski_,
  { {0xf77f0016,0x5a3a0047,0x6a3a0047,0x00000000}},	//   meça_, נגעה, נגעפ,
  { {0x63ad4872,0xf77f017d,0x7ae94873,0x00000000}},	//   caan, leça_, kwet,
  { {0x92f60086,0x61e50066,0x69c800cf,0x00000000}},	//   _учні, behl, ygde,
  { {0xf77f017d,0xe0860044,0x00000000,0x00000000}},	//   neça_, _هجري,   ,
  { {0x645d024a,0x20e8003b,0x44390072,0x00000000}},	//   _yksi, _uşi_, _yms_,
  { {0xeb97005e,0x1e8636b1,0x2d85004e,0x00000000}},	//   бић_, _глам, _egle_,
  { {0xdfcf04a0,0xd9aa0094,0xbea34874,0x00000000}},	//   _سيل_, лънд_, _натк,
  { {0x98a701f7,0xef170001,0x23ad0006,0x00000000}},	//   _aynı_, _уму_, mųjų_,
  { {0x69c8006f,0x63ad4197,0x2d950caa,0x00000000}},	//   rgde, yaan, _фрус,
  { {0xbb860032,0x64480003,0xf3ff0013,0x00000000}},	//   _الإي, édil, _thãi_,
  { {0x29180019,0x63ad11b0,0x23ad0078,0x00000000}},	//   ärab_, vaan, nųjų_,
  { {0x44394875,0x7afd10c4,0x3eb900b9,0x00000000}},	//   _sms_, æste, _æste_,
  { {0x63ad3c94,0x7c39002b,0x25bf0058,0x00000000}},	//   taan, _ymwr, ğul_,
  { {0x25bf000c,0x53990076,0x99850078,0x00000000}},	//   şul_, рвая_, bilų_,
  { {0xf77f0016,0xd2150001,0x63ad4866,0x00000000}},	// [8830] beça_, омаћ, raan,
  { {0x63ad4876,0x23ad0078,0xd3010054,0x00000000}},	//   saan, dųjų_, кiвс,
  { {0x63ad00bb,0x61e50024,0x316b005e,0x00000000}},	//   paan, rehl, ушао_,
  { {0x44394877,0xfde10042,0x16070042,0x00000000}},	//   _ums_, फ़्फ, शावर_,
  { {0xa3ce0053,0x287c0047,0x3da90416,0x00000000}},	//   _रात_, אנאמ, акло_,
  { {0xae030161,0x2c4c0080,0x291e0006,0x00000000}},	//   लाइन_, věda_, kyta_,
  { {0x7c840001,0xdb000bda,0x7844013d,0x00000000}},	//   пуње, hamä, lőve,
  { {0x291e0006,0xa4b80063,0xfc310021,0x00000000}},	//   dyta_, צלחה_, بحت_,
  { {0x7bc907c1,0xddc300dd,0xdb0001a9,0x00000000}},	//   rgeu, conş, jamä,
  { {0x7ae90438,0x39450065,0xf7cb004c,0x00000000}},	//   rwet, жног, ážní_,
  { {0x7ae93037,0x291e005f,0x7c460046,0x00000000}},	//   swet, gyta_, ðurð,
  { {0xe8df001b,0x9985005f,0xb33b0075,0x00000000}},	//   hiệm_, tilų_, _teçh,
  { {0x65690080,0x89d50054,0x00000000,0x00000000}},	//   řehl, _дійш,   ,
  { {0xb33b01f7,0x291e4878,0x38ca005d,0x00000000}},	//   _geçi, byta_, دایی_,
  { {0xf77f0994,0x7d29009a,0x8d29009d,0x00000000}},	//   reça_, בֵּ֔, בֵּ֤,
  { {0xccf2014e,0xdb000019,0xe8df0013,0x00000000}},	//   וכל_, bamä, _laịi_,
  { {0x987b0047,0x41aa106d,0xf77f017d,0x00000000}},	// [8840] _דאקט, иван_, peça_,
  { {0x6826394f,0xfe65007e,0x23ad0078,0x00000000}},	//   _kódo, _سگ_, vųjų_,
  { {0x765c2f40,0xbfaa1849,0xd46a0121,0x00000000}},	//   mory, атле_, _вине_,
  { {0x6826000f,0xd5b1001b,0x3076026c,0x00000000}},	//   _módo, ức_, цузс,
  { {0x087700b5,0xaedc02fe,0x43764345,0x00000000}},	//   קענט_, ублi, _фунт,
  { {0xdcba011c,0xf67a0047,0x23ad0078,0x00000000}},	//   ащи_, סאַמ, rųjų_,
  { {0x7cdc008f,0x38850023,0x93fa009a,0x00000000}},	//   kārš, _mērs_, ֹלִי,
  { {0xb33b01f7,0x290000eb,0x61e200ea,0x00000000}},	//   _seçi, _čia_, őold,
  { {0x63b90051,0xba0a20e5,0x2d962046,0x00000000}},	//   ówni, ахне_, _дрес,
  { {0x291e0006,0xfce60817,0xee37290b,0x00000000}},	//   tyta_, _мозо, _дну_,
  { {0xdb0000c7,0xfa330021,0x8e75000d,0x00000000}},	//   damå, بريد, _хутч,
  { {0xb0840086,0x291e4879,0x3eb2005f,0x00000000}},	//   овiд, ryta_, šytu_,
  { {0x249a0150,0x291e0078,0x765c1780,0x00000000}},	//   _atpm_, syta_, fory,
  { {0x765c487a,0x7ae241e6,0xdb0004aa,0x00000000}},	//   gory, _ipot, gamå,
  { {0x45d40062,0xe6540054,0xdb00487b,0x00000000}},	//   ьорс, євсь, samä,
  { {0xdb00487c,0x69da2dd2,0x7844013d,0x00000000}},	//   pamä, lfte, tőve,
  { {0xf77f0016,0x8335005a,0x018b0121,0x00000000}},	// [8850] meço_, чнах, ащей_,
  { {0xf1c3001b,0xe1670001,0x69da00bd,0x00000000}},	//   _giờ_, ођен, nfte,
  { {0xd258000d,0x64410003,0x50cb0085,0x00000000}},	//   іцу_, élis, рызм_,
  { {0x7ae20445,0x1048012c,0x30150299,0x00000000}},	//   _opot, оячи_, ядер,
  { {0x63a2006d,0x06fb0053,0x3218002b,0x00000000}},	//   ñone, एटिव_, _fory_,
  { {0xee380086,0x42790041,0x609b0044,0x00000000}},	//   оні_, _לאָג, _نخرج_,
  { {0x7ae2487d,0xa2c30053,0xc5bc009a,0x00000000}},	//   _apot, िंक्, שֶׂר,
  { {0xc10400f2,0x69da487e,0x09b50042,0x00000000}},	//   _توفي, efte, ूल्य,
  { {0x0b450156,0xf77f00be,0xe8df008d,0x00000000}},	//   янин, deço_, _taịi_,
  { {0x61f50089,0x442b487f,0xe26f0054,0x00000000}},	//   _jazl, _llc_, нтiв_,
  { {0x644f0051,0x7a2d0066,0x61f54880,0x00000000}},	//   _ojci, _núte, _mazl,
  { {0x7c2d0240,0x2c610066,0x66e60a36,0x00000000}},	//   ďars, tódu_, пома,
  { {0x765c4881,0x249a0089,0x7c2b0046,0x00000000}},	//   tory, _stpm_, _ilgr,
  { {0x915e008b,0xa6e30014,0x8afa0063,0x00000000}},	//   hắm_, óðar, _להני,
  { {0xd4d50088,0x765c4882,0x7afb4883,0x00000000}},	//   мітэ, rory, lvut,
  { {0x7afb0ee6,0xccf20047,0xdb0b017d,0x00000000}},	//   ovut, עכן_, _regê,
  { {0x32180051,0x61f50075,0xa2c30042,0x00000000}},	// [8860] _pory_, _bazl, िंग्,
  { {0x1757014e,0xd5b1008b,0xa3ce0042,0x00000000}},	//   _מספר_, ứa_, _राव_,
  { {0x30a50054,0x361b009a,0xe0da01ce,0x00000000}},	//   дрів, _הויד, све_,
  { {0x442b0222,0x44240013,0x1fd60053,0x00000000}},	//   _glc_, _ôm_, ठभेड,
  { {0x61f504ab,0xbea30002,0xdce800c2,0x00000000}},	//   _fazl, еачк, čoče,
  { {0x7c2b0014,0x61f50058,0xc3330063,0x00000000}},	//   _algr, _gazl, _טור_,
  { {0x63a40035,0x5d630062,0xe6a90042,0x00000000}},	//   obin, нтъз, _कब्ज,
  { {0x63a44884,0xeb97005e,0x00000000,0x00000000}},	//   nbin, пић_,   ,
  { {0x7afc001c,0x298a0086,0xe7c60053,0x00000000}},	//   ārto, йсно_, _वाजप,
  { {0x98b8000a,0x3f800006,0x831b0047,0x00000000}},	//   олот_, žius_, צויז,
  { {0xdca3019d,0xef1f004b,0x69da4885,0x00000000}},	//   _захи, _üür_, rfte,
  { {0x63a400b2,0x00000000,0x00000000,0x00000000}},	//   jbin,   ,   ,
  { {0xf77f03d9,0x7ae24886,0x682600ea,0x00000000}},	//   reço_, _upot, _kódj,
  { {0x4b7b0063,0x8b450044,0xd6844250,0x00000000}},	//   _האדו, _تضمن, еусп,
  { {0x7a2d02dd,0x61f506bb,0x682600ea,0x00000000}},	//   _fútb, _razl, _módj,
  { {0xfc49008b,0x6d4a0013,0xdcf80058,0x00000000}},	//   hận_, _đoà, navı,
  { {0x64410003,0x61f500b2,0x67bc0063,0x00000000}},	// [8870] éliq, _pazl, _המחק,
  { {0xdb0b00b9,0x26cb0331,0xb18b0121,0x00000000}},	//   _udgå, muco_, ссаж_,
  { {0xb33b0164,0x2127001b,0x7d1e00d1,0x00000000}},	//   _reçu, ánh_, øpsl,
  { {0x26cb017d,0xe3a5005d,0x417404a0,0x00000000}},	//   ouco_, _تشدی, رالس,
  { {0x1ec90086,0x644d006c,0xd00e005d,0x00000000}},	//   ілки_, mnai, شلو_,
  { {0x0dcb0a29,0x2f23008f,0x9e340054,0x00000000}},	//   суди_, _rīgā_, нечч,
  { {0x644d4887,0xcfb50062,0x3cf90053,0x00000000}},	//   onai, _обвъ, ्में_,
  { {0x628702dd,0x644d4888,0xf2050053,0x00000000}},	//   _hijo, nnai, राक़_,
  { {0xb33b005b,0x29180504,0x62870022,0x00000000}},	//   _geçt, äran_, _kijo,
  { {0x7afb0019,0x644d0025,0xaa56005e,0x00000000}},	//   rvut, hnai, мињу_,
  { {0xd90f006a,0xdb0b00ea,0x63a40006,0x00000000}},	//   ایع_, _megé, ybin,
  { {0x3e72003b,0x7d1e004b,0x629d0072,0x00000000}},	//   râte_, äpse, _otso,
  { {0xe9ce185b,0xcfb60063,0xf71a0085,0x00000000}},	//   _ик_, ולרי_, ціны_,
  { {0xdb0b00cd,0x644d4889,0xdb26007e,0x00000000}},	//   _regè, enai, _توهی,
  { {0x33f60086,0x26d900fe,0x63a40760,0x00000000}},	//   мчас, atso_, tbin,
  { {0x644d488a,0x628f2cac,0x26cb0331,0x00000000}},	//   gnai, _buco, buco_,
  { {0x4b7a00b5,0x434300a0,0x628f003b,0x00000000}},	// [8880] ַטעג, ветв, _cuco,
  { {0xb5ca007e,0x63a4488b,0x644d488c,0x00000000}},	//   _بودم_, sbin, anai,
  { {0xb33b01f7,0x6287488d,0x3cf90053,0x00000000}},	//   _seçt, _dijo, ्मों_,
  { {0x3e690139,0x28c50042,0x23b20042,0x00000000}},	//   lúth_, _विनि, _ज़िद,
  { {0x6287488e,0x987b0047,0x5f93005e,0x00000000}},	//   _fijo, קאנט, њишт,
  { {0xfc49008b,0x64440332,0x6287488f,0x00000000}},	//   uận_, liii, _gijo,
  { {0xfc490013,0xe0d70002,0xfce3007b,0x00000000}},	//   rận_, _овр_, војо,
  { {0xb33b0075,0xa157009a,0x3c4400de,0x00000000}},	//   _geçs, _חבלה_, عَظِ,
  { {0x9846003d,0x539b0063,0xcb67005e,0x00000000}},	//   _dēļ_, חיפו, маће_,
  { {0x39144890,0x0377009a,0x4d76043e,0x00000000}},	//   емор, ותפת_, _قطار,
  { {0xa3ce016a,0x644d4467,0xa3c00042,0x00000000}},	//   रला_, ynai, ीला_,
  { {0x3ea9003b,0x7852008f,0xfaa616f2,0x00000000}},	//   ţate_, tāva, _жадо,
  { {0x7764005a,0xe6670086,0x2ba40042,0x00000000}},	//   върж, дтво, _ग्या,
  { {0x1af3000d,0x68fc0a8c,0x764e05a5,0x00000000}},	//   _шпія, årds, gnby,
  { {0x628f0e7c,0xd7fb0002,0xa4d40054,0x00000000}},	//   _suco, _дуп_, корі,
  { {0x62870b4e,0xdb0b00ea,0x60c50066,0x00000000}},	//   _sijo, _segé, vrhm,
  { {0x6595000d,0x8c1b0063,0x644d4891,0x00000000}},	// [8890] _папу, קומי, rnai,
  { {0x416b0001,0x644d3ffe,0xe5c70085,0x00000000}},	//   ојем_, snai, _ўспо,
  { {0x63af2358,0x628700b2,0xc5f2009a,0x00000000}},	//   _tecn, _vijo, _גדי_,
  { {0x44324892,0x63bd00b9,0xb9d9008d,0x00000000}},	//   chy_, _udsn, _bơị_,
  { {0x28c50161,0x6287017d,0x44294893,0x00000000}},	//   _विभि, _tijo, mka_,
  { {0x7876017d,0xd0d50062,0x999e004c,0x00000000}},	//   máve, _погъ, ditů_,
  { {0x442900fe,0x7a2400cd,0x29180019,0x00000000}},	//   oka_, _gòti, äral_,
  { {0x2101007d,0xf3f20063,0xa3d70042,0x00000000}},	//   rčić_, ָ֣ה_, _साफ_,
  { {0x7876017d,0x44294894,0xcb09005d,0x00000000}},	//   náve, ika_, سيدن_,
  { {0x44294895,0xe9d90571,0xedd50044,0x00000000}},	//   hka_, чко_, _سيؤد,
  { {0x44294896,0x186a0afc,0x68463acd,0x00000000}},	//   kka_, зани_, енна,
  { {0xdb350002,0x44294897,0x764e002b,0x00000000}},	//   _пеењ, jka_, wnby,
  { {0x7876017d,0xac38014d,0x442905ea,0x00000000}},	//   jáve, _تسلط_, dka_,
  { {0xf6520021,0x7c294898,0x44294899,0x00000000}},	//   ائح_, lker, eka_,
  { {0xa9660062,0x4432489a,0xfc490013,0x00000000}},	//   _пиша_, thy_, hậm_,
  { {0x44291193,0x787600be,0xe29a0002,0x00000000}},	//   gka_, fáve, заа_,
  { {0x7c29489b,0x7876017d,0x28c50053,0x00000000}},	// [88a0] iker, gáve, _विडि,
  { {0x4429489c,0x44323623,0x7c29489d,0x00000000}},	//   aka_, shy_, hker,
  { {0x44320037,0x7c2905e5,0x3ead0150,0x00000000}},	//   phy_, kker, _awet_,
  { {0x7c290122,0xbe8a0001,0x768b0045,0x00000000}},	//   jker, пске_, _użyc,
  { {0xc8ec0235,0x68260fca,0x78760016,0x00000000}},	//   _जन्म_, _códi, cáve,
  { {0x3f8d021a,0x7c290f7d,0xdd8f0044,0x00000000}},	//   _egeu_, eker, موه_,
  { {0x3da5019d,0x7c2900f5,0x229601e1,0x00000000}},	//   тріб, fker, _hæk_,
  { {0x7c29489e,0x661e0023,0xd577009a,0x00000000}},	//   gker, _lopk, עתקה_,
  { {0x59d4016a,0x7852008f,0xee3a0fb4,0x00000000}},	//   _दादर, tāvn, _ена_,
  { {0x7c29489f,0x7a2d0066,0x6da60021,0x00000000}},	//   aker, _púta, _أمام,
  { {0x44290051,0x78762ec9,0x7afd02c0,0x00000000}},	//   yka_, záve, åstr,
  { {0x2fc00025,0xac970021,0x7c292e83,0x00000000}},	//   óigh_, _أننا_, cker,
  { {0x442948a0,0xead4183e,0xbc1b009d,0x00000000}},	//   vka_, _роль, _מואש,
  { {0x78760016,0xe980000d,0x44290051,0x00000000}},	//   váve, _калi_, wka_,
  { {0xd491008b,0x4429429c,0xa4070092,0x00000000}},	//   ề_, tka_, нџак,
  { {0x78760016,0x2c090161,0xd6db0ae8,0x00000000}},	//   táve, वाएं_, _ето_,
  { {0x78ba189f,0xd3240121,0x8627000d,0x00000000}},	// [88b0] lstv, льфи, _зьне,
  { {0x787648a1,0x51f8026c,0x229600b9,0x00000000}},	//   ráve, нную_, _dæk_,
  { {0x682600ed,0x644800cd,0x44291ab3,0x00000000}},	//   _sódi, èdic, pka_,
  { {0x64483a4e,0x9f98005e,0x78ba00a8,0x00000000}},	//   édit, евцу_, istv,
  { {0xdb0b0146,0x4df50062,0x7c29013d,0x00000000}},	//   _udgø, вяйт, vker,
  { {0xf77400b5,0x78ba48a2,0xd1670062,0x00000000}},	//   נקס_, kstv, _зъби,
  { {0xf4020529,0x9165007e,0x78ba3692,0x00000000}},	//   _faţă_, _شهره, jstv,
  { {0x78ba06b9,0x7c292579,0x5fd80042,0x00000000}},	//   dstv, uker, _डायल,
  { {0xce950121,0x3df5005e,0x7c291110,0x00000000}},	//   _разъ, _изас, rker,
  { {0x7c2948a3,0xef640062,0x7852008f,0x00000000}},	//   sker, _съсо, tāvo,
  { {0x7c2900ea,0x07a647b9,0x78ba48a4,0x00000000}},	//   pker, канн, gstv,
  { {0x7e6348a5,0x201f006c,0x661e48a6,0x00000000}},	//   lonp, _joui_, _sopk,
  { {0x7c260137,0xfc460114,0xcc3a0041,0x00000000}},	//   ökre, ších_, _קענט,
  { {0xceb20132,0x2c4c0080,0x6abb06a5,0x00000000}},	//   שים_, vědi_, msuf,
  { {0xdb0b00ea,0x31bc004c,0xfa880013,0x00000000}},	//   _megí, hází_, _cừu_,
  { {0x2ae50053,0xdb0b0955,0xe8d60063,0x00000000}},	//   _कहाँ_, _legí, _סופר_,
  { {0x63b6005b,0x7e630072,0x6abd0139,0x00000000}},	// [88c0] rayn, konp, ásfh,
  { {0x42530032,0x22960146,0xa3d70053,0x00000000}},	//   لنقر, _væk_, _साथ_,
  { {0x64a6195a,0x3e694556,0x6448006c,0x00000000}},	//   _шана, nútu_, édis,
  { {0xd91a0047,0xc9520063,0x22960014,0x00000000}},	//   וועל, סמא_, _tæk_,
  { {0xa3d70053,0x935a005e,0x52860021,0x00000000}},	//   _सात_, _црну_, _للحك,
  { {0x77ee0042,0x00000000,0x00000000,0x00000000}},	//   ज़ुक_,   ,   ,
  { {0x32530121,0x61fc48a7,0x61460b0e,0x00000000}},	//   _твёр, _iarl, _рева,
  { {0x61fc48a8,0x61fe48a9,0x31bc004c,0x00000000}},	//   _harl, ldpl, bází_,
  { {0xdb000026,0x61fc48aa,0xcec10022,0x00000000}},	//   samþ, _karl, _chęć_,
  { {0x682648ab,0x3ea648ac,0x61fe48ad,0x00000000}},	//   _módu, mpot_, ndpl,
  { {0xd9170121,0x26c400ea,0x49730499,0x00000000}},	//   вья_, ámon_, ильс,
  { {0x78ba0993,0x61fc0075,0x25b80168,0x00000000}},	//   rstv, _larl, earl_,
  { {0xe29f0026,0x6f020e57,0x8cca0082,0x00000000}},	//   _orða_, nvoc, संको,
  { {0x78ba0743,0xa4d50726,0x6f024851,0x00000000}},	//   pstv, логі, ivoc,
  { {0xfa77089e,0xa3d70042,0xa3ce0042,0x00000000}},	//   _שעות_, _साद_, _राख_,
  { {0x78760a63,0x545448ae,0x9f44004c,0x00000000}},	//   rávc, авст, _samý_,
  { {0xa858014e,0x2d9e31d4,0x61fc48af,0x00000000}},	// [88d0] _שיחה_, _ofte_, _barl,
  { {0x9f4f00b9,0x61fc04cf,0xdb0001a8,0x00000000}},	//   ndgå_, _carl, lamó,
  { {0xdb0b006d,0x61fc48b0,0x7bc200e5,0x00000000}},	//   _regí, _darl, _odou,
  { {0xdb0b000f,0x61fc0034,0xce950062,0x00000000}},	//   _segí, _earl, гадъ,
  { {0x7876027d,0x61fc48b1,0x645a0003,0x00000000}},	//   náva, _farl, étie,
  { {0x7bc218e6,0xe8df0013,0xdb00266a,0x00000000}},	//   _adou, êịc_, hamó,
  { {0xeb990b29,0x7e63487b,0x78763995,0x00000000}},	//   ний_, ronp, háva,
  { {0x200d0529,0x1bb90021,0xdb0b00dd,0x00000000}},	//   _unei_, رابع_, _regâ,
  { {0x76450146,0x78760090,0x61fc0058,0x00000000}},	//   _omhy, jáva, _yarl,
  { {0x78763e3b,0x3c310066,0x3e690066,0x00000000}},	//   dáva, _dáva_, tútu_,
  { {0x2ba40053,0x0a460085,0x6abb0244,0x00000000}},	//   _ग्वा, узэй_, ssuf,
  { {0x2c090053,0xb8eb0053,0xab950086,0x00000000}},	//   वाओं_, _लि_, _сиді,
  { {0x28c50235,0x44f50080,0x09e50794,0x00000000}},	//   _विवि, _ať_, _болн,
  { {0xaf760047,0x386948b2,0x7f3a0047,0x00000000}},	//   טערס_, _ekar_, געשו,
  { {0x6e21017f,0xc984005e,0x26cb213a,0x00000000}},	//   _molb, _кући, arco_,
  { {0x61fc3ce3,0x787632b4,0x044313da,0x00000000}},	//   _sarl, báva, бесн,
  { {0xb69b2b1f,0x61fc48b3,0x6e2148b4,0x00000000}},	// [88e0] lvân, _parl, _oolb,
  { {0xf1a904de,0xc176043e,0x6fd10042,0x00000000}},	//   نامه_, هدات, _हाउं,
  { {0x3ebf000c,0x19b60047,0x11d70021,0x00000000}},	//   _avut_, רפער_, اومة_,
  { {0x68fc0146,0x6f02006f,0x2cb800b9,0x00000000}},	//   ærdi, tvoc, _ærdi_,
  { {0xc7d70063,0x7852001c,0x7a360003,0x00000000}},	//   רוני_, tāvj, _hâte,
  { {0xccfa0138,0x2907174c,0xa6e30014,0x00000000}},	//   ећи_, _orna_, óðir,
  { {0xf8c50235,0x442248b5,0x6aa248b6,0x00000000}},	//   _विषय, _kok_, _stof,
  { {0x682600ea,0x69c3001f,0x628e006c,0x00000000}},	//   _móds, _adne, _hibo,
  { {0x26c00290,0x4dd6007e,0x628e14f9,0x00000000}},	//   _nvio_, _متاس, _kibo,
  { {0x2ba40161,0xa3e40161,0x28c50053,0x00000000}},	//   _ग्रा, प्त_, _विशि,
  { {0x8d930032,0x7d930032,0x44220ac8,0x00000000}},	//   _المش, _المؤ, _ook_,
  { {0x442204b1,0x81570047,0x628e48b7,0x00000000}},	//   _nok_, רסטע_, _libo,
  { {0x6aa20035,0x290710b8,0xa3ce0053,0x00000000}},	//   _utof, _erna_, _राज_,
  { {0x7c220179,0x7876108e,0x45d50002,0x00000000}},	//   _hoor, ráva, јовс,
  { {0x7a360529,0x7876000f,0x98a30001,0x00000000}},	//   _câte, sáva, _лије,
  { {0x26de000c,0x787648b8,0x44220058,0x00000000}},	//   ător_, lávn, _cok_,
  { {0x44220117,0x27e923b6,0x7c2248b9,0x00000000}},	// [88f0] _dok_, _iban_, _moor,
  { {0x7d0806f1,0x628e48ba,0x7c22004b,0x00000000}},	//   _ords, _cibo, _loor,
  { {0x645a06b2,0xdb0b00ea,0x628e48bb,0x00000000}},	//   étic, _megá, _dibo,
  { {0x4422006f,0x6e21102b,0x44c10078,0x00000000}},	//   _gok_, _solb, mė_,
  { {0x44c10006,0xb3ba009a,0x63ad07f9,0x00000000}},	//   lė_, _במרכ, mban,
  { {0x63ad48bc,0x0dc8005e,0x7d08007c,0x00000000}},	//   lban, гући_, _brds,
  { {0x44c100eb,0x6e210080,0x442201f7,0x00000000}},	//   nė_, _volb, _yok_,
  { {0x63ad48bd,0x999e0072,0x0c2506e0,0x00000000}},	//   nban, vitš_, рмин,
  { {0x9ed90088,0x7c220625,0x63ad48be,0x00000000}},	//   _шмат_, _door, iban,
  { {0x44c10006,0x6f0948bf,0x63ad48c0,0x00000000}},	//   kė_, _irec, hban,
  { {0x7c220004,0x63ad00bb,0xb69b000c,0x00000000}},	//   _foor, kban, uvân,
  { {0x44c10006,0x7bc70006,0xb69b3717,0x00000000}},	//   dė_, ėjus, rvân,
  { {0x98aa001c,0xf77200b3,0x8aa70336,0x00000000}},	//   ējāt_, تاد_, _сред,
  { {0x4422000f,0x63ad477c,0xbb3a0063,0x00000000}},	//   _sok_, eban, _בעני,
  { {0x44c10006,0x89da0063,0x6aa900d1,0x00000000}},	//   gė_, _יחסי, lpef,
  { {0x6f0948c1,0x18760047,0x63ad48c2,0x00000000}},	//   _orec, _דעֶר_, gban,
  { {0x96760088,0x6aa4005b,0xa3d70053,0x00000000}},	// [8900] _выні, _çift, _सार_,
  { {0xb77b014e,0x15460001,0x63ad48c3,0x00000000}},	//   _באפש, _веом, aban,
  { {0x442248c4,0xeaf20053,0x73e60b4a,0x00000000}},	//   _tok_, _अन्त_, _конз,
  { {0x628e0150,0x4ea6296c,0x6f0948c5,0x00000000}},	//   _wibo, арка, _brec,
  { {0x6f0902dd,0x644100ca,0x479b0041,0x00000000}},	//   _crec, ëlie, דינס,
  { {0x6f092b73,0x7d0000ea,0x7c221f8f,0x00000000}},	//   _drec, járá, _soor,
  { {0x7fd6000d,0x7c2248c6,0x787d00ea,0x00000000}},	//   _візі, _poor, léve,
  { {0xf65f00b9,0x6f0948c7,0x6a7401a8,0x00000000}},	//   træk_, _frec, tàfo,
  { {0x7c22182f,0x44c10006,0xadba0021,0x00000000}},	//   _voor, zė_, _لهذا_,
  { {0x7c220102,0xbae3000d,0x5a3400da,0x00000000}},	//   _woor, іцый, снот,
  { {0xa3d70161,0x2ca548c8,0x78760512,0x00000000}},	//   _साल_, _gtld_, rávn,
  { {0x44c10006,0x3e7b0003,0x9b6a005e,0x00000000}},	//   vė_, rête_, _ишла_,
  { {0x787d013d,0x624b056c,0x290548c9,0x00000000}},	//   jéve, dżon, avla_,
  { {0x44c100eb,0x6456053b,0xa3e40053,0x00000000}},	//   tė_, enyi, प्स_,
  { {0x3a7b0047,0x8a7b0063,0x63ad48ca,0x00000000}},	//   _שטוד, _שאות, tban,
  { {0xe3b3006a,0x44c10006,0x6456013d,0x00000000}},	//   ترس_, rė_, gnyi,
  { {0x9259000a,0x787d00ea,0x44c10006,0x00000000}},	// [8910] гаат_, géve, sė_,
  { {0x44c100eb,0x63ad48cb,0xf426004b,0x00000000}},	//   pė_, sban, äära_,
  { {0x26140053,0x6f09007d,0x5f950021,0x00000000}},	//   दारी_, _srec, ملائ,
  { {0x7d0000ea,0x7852001c,0x6aa92494,0x00000000}},	//   zárá, tāvi, ypef,
  { {0x7a2d0025,0xd37b24fe,0x84160063,0x00000000}},	//   _fúth, _шчо_, _הקרב_,
  { {0xfc49008b,0x644d48cc,0x3cf30053,0x00000000}},	//   hật_, liai, ंबले_,
  { {0x7d0000ea,0x30a400e1,0x6f09085c,0x00000000}},	//   várá, _мртв, _wrec,
  { {0x644d48cd,0x6f0948ce,0x85580063,0x00000000}},	//   niai, _trec, ישוב_,
  { {0x6f09003b,0x7d0000ea,0xcddb0896,0x00000000}},	//   _urec, tárá, _ање_,
  { {0x7876000f,0x6ce70086,0x89a90076,0x00000000}},	//   távo, _віде, ыков_,
  { {0x999e00eb,0x644d1404,0xa3d70053,0x00000000}},	//   entų_, kiai, सला_,
  { {0x9b950021,0x7afc001c,0x6aa906a5,0x00000000}},	//   _الإت, ārtr, ppef,
  { {0xbb850032,0x3897000c,0x7c3b1a11,0x00000000}},	//   _الشي, _mări_, mhur,
  { {0x0f7a0041,0x787d2033,0xab630022,0x00000000}},	//   טארב, véve, óżuj,
  { {0x2ba60080,0xdce1008f,0x644d48cf,0x00000000}},	//   síců_, _izlē, fiai,
  { {0x2c610024,0x787d013d,0x88560063,0x00000000}},	//   tódy_, téve, _לֹ֥א_,
  { {0xd3b90597,0x130a000d,0x624b0022,0x00000000}},	// [8920] русі_, ынай_, rżon,
  { {0x26c20606,0x228d0078,0x7a2d0046,0x00000000}},	//   msko_, _užkl_, _búti,
  { {0x787d000f,0x26c21a04,0x052a0002,0x00000000}},	//   séve, lsko_, _сонк_,
  { {0x644d48d0,0x764e0022,0xdb000046,0x00000000}},	//   ciai, liby, mamö,
  { {0x26c218c4,0x4432004a,0x2f183eea,0x00000000}},	//   nsko_, mky_, роль_,
  { {0x50960138,0x764e001f,0x442048d1,0x00000000}},	//   _грађ, niby, lji_,
  { {0x442048d2,0x91bb0063,0x7c260137,0x00000000}},	//   oji_, _תמלי, ökro,
  { {0x4432027d,0x93c5008b,0x1d07005e,0x00000000}},	//   nky_, _ngắ, сећи_,
  { {0x26c248d3,0xcf26007e,0x442048d4,0x00000000}},	//   jsko_, _ارزي, iji_,
  { {0x26c22061,0x24610078,0x7a360003,0x00000000}},	//   dsko_, mėme_, _bâta,
  { {0x290a017d,0x764e0150,0xd7f5026c,0x00000000}},	//   íba_, diby, озны,
  { {0xdb0b01e3,0x26c2082a,0xdb000504,0x00000000}},	//   _begä, fsko_, damö,
  { {0x95cb000a,0x4432016b,0x7c650021,0x00000000}},	//   лува_, dky_, _بالل,
  { {0x9aa4007e,0x442017b8,0x68fc00b9,0x00000000}},	//   _همچو, eji_, ærds,
  { {0x26c200a4,0x644d48d5,0x3858005d,0x00000000}},	//   asko_, tiai, _گشود_,
  { {0xb4e90053,0x915f008b,0x69da48d6,0x00000000}},	//   _यही_, _lặp_, lgte,
  { {0x91b9005a,0x764e48d7,0xc1b90200,0x00000000}},	// [8930] игат_, biby, илах_,
  { {0xe3bf02dd,0x1a9b0047,0x44200b1c,0x00000000}},	//   _doña_, טימע, aji_,
  { {0xdce80080,0x7a8b0047,0x443248d8,0x00000000}},	//   _vzdě, אָאַ, bky_,
  { {0x44201112,0x443248d9,0x6a6f05e7,0x00000000}},	//   cji_, cky_, løft,
  { {0x443903b2,0xd7fc0047,0xf2071915,0x00000000}},	//   _ils_, טהאל, _ляво,
  { {0x2d940062,0x915f008d,0x7c3b18c0,0x00000000}},	//   пръс, _cặp_, whur,
  { {0xfe70006a,0xac390086,0x7d1e00d1,0x00000000}},	//   رده_, ичих_, øpsp,
  { {0x69da00ea,0x5ac92e56,0x26c20022,0x00000000}},	//   egte, алим_, ysko_,
  { {0x63b90051,0xb4d60053,0x7c3b1171,0x00000000}},	//   ówny, _सम्_, rhur,
  { {0x44200051,0x5ce50021,0x915f008b,0x00000000}},	//   zji_, _وكذل, _gặp_,
  { {0x35d30161,0x26c20022,0x44391e3d,0x00000000}},	//   _ताज़, wsko_, _ols_,
  { {0x78760024,0x69da2f41,0x26c2389e,0x00000000}},	//   mávk, agte, tsko_,
  { {0x44320512,0x28c50053,0xdb0b0666,0x00000000}},	//   vky_, _विकि, _begå,
  { {0x443948da,0x26c2068a,0xdb000014,0x00000000}},	//   _als_, rsko_, tamö,
  { {0x4432027d,0x442048db,0x25830003,0x00000000}},	//   tky_, tji_, vélé_,
  { {0xd5dc0053,0x26c242d9,0x17fa0021,0x00000000}},	//   _बावज, psko_, _ضربة_,
  { {0x442048dc,0x27e00058,0x443248dd,0x00000000}},	// [8940] rji_, _icin_, rky_,
  { {0x44390c3f,0x44200045,0x6aa40025,0x00000000}},	//   _els_, sji_, _éife,
  { {0x6a3a0047,0x44320114,0x10a60962,0x00000000}},	//   סגעפ, pky_, циен,
  { {0x23e10235,0x24610006,0xa2a20053,0x00000000}},	//   _फायद, tėme_, _कंप्,
  { {0xa25b0024,0xdfcf006a,0x69da00b9,0x00000000}},	//   _kvôl, ئيه_, ygte,
  { {0x24610006,0xeca6005e,0x4c940ace,0x00000000}},	//   rėme_, ојин, пикс,
  { {0x672f0045,0xed870062,0x16b70053,0x00000000}},	//   zycj, осък_, _अब्ब,
  { {0x443948de,0x2036006a,0x04370047,0x00000000}},	//   _xls_, _بفرس, ַטיש_,
  { {0x63a43fba,0x6df60044,0xe80e0042,0x00000000}},	//   icin, _وكرا, ियना_,
  { {0x7bdb00a4,0x9a67014d,0x69da004d,0x00000000}},	//   aguu, يميل_, ugte,
  { {0x20040645,0x63a400fc,0xc19b0063,0x00000000}},	//   _kami_, kcin, ישיי,
  { {0x69da00a4,0x20041506,0x200600dd,0x00000000}},	//   sgte, _jami_, ndoi_,
  { {0x61ee051e,0x443900cd,0x7bc048df,0x00000000}},	//   _obbl, _rls_, mamu,
  { {0x63a4003d,0x7bc048e0,0xddda013d,0x00000000}},	//   ecin, lamu, _kitű,
  { {0x6e2800b9,0xe4e40636,0x344b02d8,0x00000000}},	//   _modb, мітн, ачан_,
  { {0x320d005b,0x200448e1,0x63a400ac,0x00000000}},	//   _şey_, _nami_, gcin,
  { {0xa8740085,0xa3cd0042,0x22950044,0x00000000}},	// [8950] _ільі, रणब_, سلاس,
  { {0xfc49008b,0x63a448e2,0x7bc048e3,0x00000000}},	//   hập_, acin, hamu,
  { {0x31c448e4,0x26d948e5,0x50670062,0x00000000}},	//   ьств, luso_, отда,
  { {0x7bc00576,0xa2950454,0x75d5007e,0x00000000}},	//   jamu, _намі, _بيگا,
  { {0xdefb0055,0x63bd003d,0x2004002c,0x00000000}},	//   рые_, _iesn, _dami_,
  { {0xa6fc0063,0x9e340454,0x7bc000dd,0x00000000}},	//   שִׁי, мечч, eamu,
  { {0xfc310032,0x629d0035,0x660523c1,0x00000000}},	//   فحة_, _huso, _mahk,
  { {0x66050fbf,0x629d0009,0x69ca001f,0x00000000}},	//   _lahk, _kuso, _adfe,
  { {0x768b0045,0x6e280146,0x3da7005a,0x00000000}},	//   _używ, _fodb, _дреб,
  { {0x2a6c00c2,0x6e2848e6,0x2bab0053,0x00000000}},	//   godb_, _godb, _ट्रा,
  { {0xda09007e,0x629d24c3,0xf7690047,0x00000000}},	//   ليکه_, _luso, _עק_,
  { {0xdb0b00ea,0x26d948e7,0x7bc01d4c,0x00000000}},	//   _megú, fuso_, camu,
  { {0x660506a7,0xdb0b00ea,0x26d905b3,0x00000000}},	//   _bahk, _legú, guso_,
  { {0x8b050045,0x644100ac,0x6d4348e8,0x00000000}},	//   _częś, ëlin, ozna,
  { {0x63a4003b,0x6e23006f,0xca360063,0x00000000}},	//   tcin, ijnb, _מנסה_,
  { {0x26d948e9,0x69c148ea,0x629d48eb,0x00000000}},	//   buso_, lale, _buso,
  { {0x200420a7,0xe29f0014,0x629548ec,0x00000000}},	// [8960] _rami_, _yrði_, _bizo,
  { {0x69c148ed,0x290e001f,0x63bd004b,0x00000000}},	//   nale, _yrfa_, _eesn,
  { {0xdb000025,0x6d430a99,0x6295003b,0x00000000}},	//   rcmé, jzna, _dizo,
  { {0x38a10027,0x6a7400cd,0x69c148ee,0x00000000}},	//   _mór_, ràfi, hale,
  { {0x7bc00004,0x80250021,0x69c148ef,0x00000000}},	//   vamu, برلم, kale,
  { {0x61ee41a9,0xdcba0062,0x69c148f0,0x00000000}},	//   _ubbl, бщи_, jale,
  { {0x69c1196d,0xd00a005e,0x2ee601ac,0x00000000}},	//   dale, _леве_, stof_,
  { {0x629d00e3,0xf8c50235,0x7521004d,0x00000000}},	//   _yuso, _विजय, älzi,
  { {0x69c13fc8,0x7bc01f0e,0x6d4348f1,0x00000000}},	//   fale, ramu, azna,
  { {0x7f3b0063,0xf1c30013,0x7bc048f2,0x00000000}},	//   _העמו, _nhờ_, samu,
  { {0x24890022,0x09940131,0xd90e005d,0x00000000}},	//   ymam_, ќанџ, ایب_,
  { {0x7d7b00b5,0x4c9b0063,0x26d90006,0x00000000}},	//   _פראג, _הבאו, tuso_,
  { {0x63bd00c3,0xddc300c2,0x8b660021,0x00000000}},	//   _resn, lonš, _عاصم,
  { {0x69c148f3,0xf1c3008b,0x8a181c7a,0x00000000}},	//   cale, _chờ_, _фокс_,
  { {0xab5d0051,0x1957000d,0x2902001c,0x00000000}},	//   raże, _нашы_, ākas_,
  { {0x26d902dd,0xab5d0051,0x629d48f4,0x00000000}},	//   puso_, saże, _puso,
  { {0xdb0b048e,0x248948f5,0x26c400ea,0x00000000}},	// [8970] _segú, rmam_, ámot_,
  { {0xdb0900ea,0xddc3122a,0x018b0121,0x00000000}},	//   nbeá, konš, бщей_,
  { {0x63bd18c4,0x787d1f20,0x14d5009a,0x00000000}},	//   _tesn, névo, _קוֹל_,
  { {0xddc300a2,0xaae30041,0xe0d00593,0x00000000}},	//   donš, _לאַנד_, ازل_,
  { {0x69c148f6,0xe80e0053,0x8f34000d,0x00000000}},	//   yale, ियता_, нецц,
  { {0x238a0024,0x6d430206,0x442b48f7,0x00000000}},	//   ňujú_, tzna, _hoc_,
  { {0xc212014e,0x69c148f8,0x6c850043,0x00000000}},	//   _בהם_, vale, ولتم,
  { {0x442b1f1c,0x69c10051,0x2ef50086,0x00000000}},	//   _joc_, wale, _озбр,
  { {0x69c148f9,0x3e720003,0x765c002b,0x00000000}},	//   tale, gâts_, ynry,
  { {0x442b0529,0x88c903d1,0x69c148fa,0x00000000}},	//   _loc_, олов_, uale,
  { {0x69c148fb,0x8c3c0058,0x88c7004c,0x00000000}},	//   rale, _buğd, _oběž,
  { {0xbca40021,0x69c148fc,0x442b1026,0x00000000}},	//   _أمني, sale, _noc_,
  { {0x9676000d,0x5747000d,0x69c148fd,0x00000000}},	//   дыві, дзям_, pale,
  { {0x7a3f0003,0xf1ba0013,0x442b006c,0x00000000}},	//   _bête, ươi_, _aoc_,
  { {0x6a7d0268,0x442b302d,0xe29f0014,0x00000000}},	//   lèfo, _boc_, _auð_,
  { {0x998300eb,0x26c400ea,0x7ae948fe,0x00000000}},	//   ųjų_, ámos_, otet,
  { {0x442b48ff,0xf7460076,0x7ae94900,0x00000000}},	// [8980] _doc_, _цепо, ntet,
  { {0x7ae92691,0x7c2b4901,0x2fcd001f,0x00000000}},	//   itet, _logr, _adeg_,
  { {0x30a50086,0x7ae91ab2,0x442b4902,0x00000000}},	//   ерів, htet, _foc_,
  { {0xdfcf01a7,0xe29f0014,0x7c2b008f,0x00000000}},	//   ليم_, _arðu_, _nogr,
  { {0x7ae900ea,0x2fcd001f,0xe29f0026,0x00000000}},	//   jtet, _ddeg_, _guð_,
  { {0x768b0045,0x2d9a0031,0xddc300a2,0x00000000}},	//   _użyt, øpe_, tonš,
  { {0xa3e50053,0xddde00ea,0x3e690066,0x00000000}},	//   _नाम_, övőb, núty_,
  { {0x442b00cd,0x7ae93392,0xe29f0014,0x00000000}},	//   _xoc_, ftet, _erðu_,
  { {0xae1e0053,0x1ea90021,0x7ae900ea,0x00000000}},	//   पादन_, _فالي_, gtet,
  { {0xddc30266,0x7c2b4903,0x1e830899,0x00000000}},	//   ponš, _eogr, _алум,
  { {0x7c2b0025,0x7ae94904,0x69a40082,0x00000000}},	//   _fogr, atet, चुगी,
  { {0x787d0003,0xec690054,0x5cc50044,0x00000000}},	//   révo, _ерік_, _أغلق,
  { {0x442b46ec,0x6a7d01a8,0xdb09013d,0x00000000}},	//   _roc_, cèfo, pbeá,
  { {0x6b8200c3,0x442b4905,0x4b7b009a,0x00000000}},	//   _izog, _soc_, _ואדו,
  { {0x442b0268,0xfa97009a,0x5694089d,0x00000000}},	//   _poc_, _קדוש_, тарт,
  { {0x7a3f0164,0x443d0051,0xb7e60042,0x00000000}},	//   _vête, ów_, _कायम_,
  { {0x7d1c0014,0x442b4906,0x52151bc9,0x00000000}},	// [8990] _ársf, _voc_, ндат,
  { {0x7a3f0164,0x3e690024,0xa2950636,0x00000000}},	//   _tête, búty_, хазі,
  { {0x7ae900ea,0x4035007f,0x442b4907,0x00000000}},	//   ztet, нежс, _toc_,
  { {0x7ae92fca,0x64480268,0x84350047,0x00000000}},	//   ytet, èdit, _נאָװ_,
  { {0x7ae900a5,0xca6b0085,0x7c2b4908,0x00000000}},	//   xtet, _фiзi, _rogr,
  { {0x7c2b04a5,0xa3cd0042,0xb2ba009a,0x00000000}},	//   _sogr, रणव_, _ממשר,
  { {0xba3d02f4,0xdfd50076,0x7c2b4909,0x00000000}},	//   způs, _повы, _pogr,
  { {0x7ae9490a,0xfd650013,0xdde9007e,0x00000000}},	//   ttet, _khuẩ, ترچه_,
  { {0xed580024,0x7ae900fe,0xa3e40053,0x00000000}},	//   _veľa_, utet, प्ट_,
  { {0xdb0e00ea,0xe29f0014,0xa9252e56,0x00000000}},	//   ájáh, _urðu_, едол,
  { {0x61e1007a,0x7ae9490b,0x6441008f,0x00000000}},	//   _öllu, stet, īlij,
  { {0xc5e90063,0x64410023,0x7ae9490c,0x00000000}},	//   _לד_, ūlij, ptet,
  { {0x6d64000c,0x76550022,0xceb2009a,0x00000000}},	//   ătaţ, fizy, ֨ים_,
  { {0xceb2490d,0xa6e30014,0x56930085,0x00000000}},	//   רים_, áðas, лаўт,
  { {0xa806005b,0xe29f0014,0x6e34009c,0x00000000}},	//   _alış, _orðs_, _égbő,
  { {0x52aa005a,0x25e40053,0x35dc0053,0x00000000}},	//   звам_, ञ्जी_, _बाक़,
  { {0xa6960138,0x63b60185,0x69dc0051,0x00000000}},	// [89a0] _прој, rbyn, óreg,
  { {0xdb09017d,0xf65f0014,0x7206009e,0x00000000}},	//   abeç, nsæl_, عوام,
  { {0x78ab000c,0x261d0053,0x00000000,0x00000000}},	//   _învă, मारी_,   ,
  { {0xdfd2006a,0xa0670f92,0x7d0e006d,0x00000000}},	//   ايش_, наха_, _ábsi,
  { {0xe29a00d7,0x11d60086,0x0665005d,0x00000000}},	//   _хаг_, _півр, _سایپ,
  { {0x64560058,0xad260021,0x644c0022,0x00000000}},	//   liyi, فربو, żnią,
  { {0x78760195,0x61fe490e,0x6b821556,0x00000000}},	//   návs, mepl, _szog,
  { {0xcd030076,0xab5d0051,0x64560058,0x00000000}},	//   учши, waża, niyi,
  { {0xda7a000d,0xeaaf007e,0xcb070021,0x00000000}},	//   зян_, یعی_, فيين_,
  { {0x5a34065b,0x61fe490f,0xc3330063,0x00000000}},	//   тнот, nepl, טוח_,
  { {0x7655005b,0xab5d0051,0x6e2b009a,0x00000000}},	//   vizy, raża, _מֵאַ,
  { {0xfaa63994,0x415b0047,0x76550051,0x00000000}},	//   _задо, לדיג, wizy,
  { {0x61fe04c7,0x7c260137,0x78a4007d,0x00000000}},	//   kepl, ökru, _čivu,
  { {0x320a00e8,0x2c4c0080,0x7b06001c,0x00000000}},	//   _naby_, vědy_, ērtī,
  { {0xe8210053,0x61fe4910,0x24990022,0x00000000}},	//   यादा_, depl, _pism_,
  { {0x897b0063,0xa97b009a,0xb97b009a,0x00000000}},	//   _מרוצ, _מאוכ, _מנוי,
  { {0xe2f80086,0x320a4911,0xb2750a8f,0x00000000}},	// [89b0] неті_, _baby_, влаш,
  { {0x7a360164,0x61fe4912,0x999e0078,0x00000000}},	//   _bâti, gepl, mitų_,
  { {0x659502a9,0xcf27007e,0x41e20042,0x00000000}},	//   _јану, کراي, _पारस,
  { {0x26d90290,0x7a3f0013,0xdfd5000d,0x00000000}},	//   orso_, _mêta, тоды,
  { {0x61fe24c8,0x26cb002b,0x22950044,0x00000000}},	//   bepl, nsco_, _للحس,
  { {0x44294913,0xee380097,0x20090006,0x00000000}},	//   lja_, нні_, žai_,
  { {0x27ec00ea,0x25e90053,0x8d540062,0x00000000}},	//   ődni_, _जानी_, лтъч,
  { {0x44294914,0x2d9e00ac,0x351c0063,0x00000000}},	//   nja_, _egte_, לוונ,
  { {0xe7db0053,0x44294915,0xdde3013d,0x00000000}},	//   _भाजप, ija_, űrőj,
  { {0x4429021e,0xc3340063,0x999e0078,0x00000000}},	//   hja_, רוץ_, ditų_,
  { {0x44294916,0x26d90290,0x186a0794,0x00000000}},	//   kja_, erso_, дани_,
  { {0x7bc200ac,0x2c170053,0x3dc7002b,0x00000000}},	//   _geou, थाओं_, lanw_,
  { {0xf09200b5,0x7c290117,0xf1e2016a,0x00000000}},	//   ינט_, mjer, _पालन,
  { {0x7c290f4b,0x7d0300e5,0x44294917,0x00000000}},	//   ljer, owns, eja_,
  { {0x3aeb0031,0x44290026,0xd9420905,0x00000000}},	//   løp_, fja_, _вещи,
  { {0x44294918,0x69c34919,0x7c29491a,0x00000000}},	//   gja_, _hene, njer,
  { {0x7c3b0035,0x64440019,0x7c2920ba,0x00000000}},	// [89c0] ikur, rhii, ijer,
  { {0x69c333c9,0x5a0c0047,0x7a360003,0x00000000}},	//   _jene, ּלאַ, _pâti,
  { {0x7c2900d1,0x61fe0d11,0xa5d90047,0x00000000}},	//   kjer, repl, _אַרי,
  { {0x44291112,0xdb0b004d,0x61fe0a44,0x00000000}},	//   cja_, _begü, sepl,
  { {0xab5d0051,0x3aeb00d1,0xdb0b013d,0x00000000}},	//   ważn, jøp_, _megó,
  { {0x7c2900b9,0x7c3b1c86,0x69c3083e,0x00000000}},	//   ejer, ekur, _nene,
  { {0x7c29000e,0x265b0047,0x6f020244,0x00000000}},	//   fjer, וכסא, swoc,
  { {0x7c290031,0xdb0b0016,0x1d070001,0x00000000}},	//   gjer, _negó, тећи_,
  { {0x4e060138,0xbea6011c,0x629c491b,0x00000000}},	//   _изаб, _разк, _kiro,
  { {0x69c30185,0x8f750086,0x44290ca2,0x00000000}},	//   _cene, _сусі, zja_,
  { {0x7c3b003d,0x787d0164,0x35dc0053,0x00000000}},	//   bkur, lévi, _बाज़,
  { {0xc1730063,0x69c3491c,0x7b070072,0x00000000}},	//   יחת_, _eene, ärtä,
  { {0xada20026,0x4429491d,0x26d90516,0x00000000}},	//   _þúsu, vja_, urso_,
  { {0x7ae01500,0x69c31c84,0x8674012c,0x00000000}},	//   mumt, _gene, иляє,
  { {0x4429491e,0x6448003d,0x98a3005e,0x00000000}},	//   tja_, īdin, _кије,
  { {0x64a4000a,0x69c300ea,0x4429491f,0x00000000}},	//   раѓа, _zene, uja_,
  { {0x44294920,0x69c329ed,0x6d5c0061,0x00000000}},	// [89d0] rja_, _yene, _žral,
  { {0xa3e50235,0x69c84921,0x44294922,0x00000000}},	//   _नाव_, nade, sja_,
  { {0xdb0b0994,0x645a0268,0x4429000f,0x00000000}},	//   _segü, ètic, pja_,
  { {0x645a0164,0xddd80080,0x92b70021,0x00000000}},	//   étit, livň, _لحسا,
  { {0x7c290117,0x9e35000d,0x63ad002b,0x00000000}},	//   vjer, ледч, mcan,
  { {0x629c4923,0x69c84924,0xab5d0022,0x00000000}},	//   _giro, jade, ważo,
  { {0x69c84925,0x7c294926,0x7c3b4927,0x00000000}},	//   dade, tjer, tkur,
  { {0x63ad0397,0x69c31351,0x7c3b0006,0x00000000}},	//   ncan, _sene, ukur,
  { {0xc052014e,0x69c34928,0x7c3b4929,0x00000000}},	//   _הזן_, _pene, rkur,
  { {0x7c290031,0x69c8492a,0xc3320063,0x00000000}},	//   sjer, gade, צוי_,
  { {0x6a7d00cd,0x69c3492b,0x61e5492c,0x00000000}},	//   nèfi, _vene, ighl,
  { {0x69c8004b,0x7ae0492d,0x63ad007d,0x00000000}},	//   aade, bumt, jcan,
  { {0x69c3492e,0x69c8492f,0x85430078,0x00000000}},	//   _tene, bade, šėli,
  { {0x69c30035,0x69c84930,0x63ad4931,0x00000000}},	//   _uene, cade, ecan,
  { {0x629c00a8,0x2aa9017c,0x33f61e3b,0x00000000}},	//   _riro, _húb_, лчас,
  { {0x60da00c7,0x629c4932,0x37e60002,0x00000000}},	//   _åtmi, _siro, _соиг,
  { {0x629c4933,0xe8210082,0x57fb009a,0x00000000}},	// [89e0] _piro, यारा_, _טלקו,
  { {0x63ad4934,0x68e100e5,0x2ca54935,0x00000000}},	//   acan, ould, _ould_,
  { {0x25e90161,0xa494007e,0x645a0003,0x00000000}},	//   _जाती_, _نیست, étis,
  { {0x63ad23a0,0x69c84936,0xdb1b017d,0x00000000}},	//   ccan, zade, cauç,
  { {0x200d0150,0x629c4937,0x68e14938,0x00000000}},	//   _daei_, _tiro, huld,
  { {0x99850006,0x787d11f5,0x69c84939,0x00000000}},	//   nklų_, révi, xade,
  { {0x6f09051e,0x69c8493a,0x867b0047,0x00000000}},	//   _esec, vade, ערצו,
  { {0x7e630025,0x68e12897,0x711b009a,0x00000000}},	//   annp, duld, _אולפ,
  { {0x38a80164,0x9f4a00fe,0xdb0b00cd,0x00000000}},	//   _sûr_, ämän_, _segò,
  { {0x2ca50146,0x68e10146,0x69c8493b,0x00000000}},	//   _fuld_, fuld, uade,
  { {0x6e930032,0x68e1001c,0x2ca51374,0x00000000}},	//   _اللا, guld, _guld_,
  { {0x69c8493c,0xcb670043,0x00000000,0x00000000}},	//   sade, ئمیه_,   ,
  { {0x69c8493d,0xd90e007e,0xac970021,0x00000000}},	//   pade, زیک_, _إننا_,
  { {0xdd200080,0x19940088,0x7a360003,0x00000000}},	//   _může, _каля, _pâtu,
  { {0x68e10016,0x659532f0,0xdb0b0026,0x00000000}},	//   culd, раву, _hegð,
  { {0x63ad493e,0x2480007d,0xa98b009a,0x00000000}},	//   ucan, glim_, _אָחִ,
  { {0x95cb005e,0x63ad04cf,0x57b40121,0x00000000}},	// [89f0] _пуна_, rcan, _убыт,
  { {0x24804675,0x249216bb,0x63ad1f31,0x00000000}},	//   alim_, amym_, scan,
  { {0xdfd10021,0x24803df6,0x63ad3f4c,0x00000000}},	//   قيا_, blim_, pcan,
  { {0x98be0051,0x3f150169,0xab5d056c,0x00000000}},	//   cztą_, идес, ważm,
  { {0x764b0078,0xddc5208c,0xe7e60042,0x00000000}},	//   _įgyj, абли, कलता_,
  { {0xfe6e007e,0x68e10058,0xc105005d,0x00000000}},	//   وگل_, yuld, _پوري,
  { {0x5184000d,0x9d450071,0x3eb800c2,0x00000000}},	//   _гута, рейд, _črte_,
  { {0x201f0529,0x68e1016d,0x3e7b0003,0x00000000}},	//   _unui_, vuld, vêtu_,
  { {0x99850078,0x8a050062,0x5ac60085,0x00000000}},	//   yklų_, азпе, алым_,
  { {0x38691f3a,0xf2d40047,0x2ca5004b,0x00000000}},	//   _ajar_, זעץ_, _tuld_,
  { {0x5d67005e,0x8bd501fb,0x85430078,0x00000000}},	//   _стаз, _نقاش, šėji,
  { {0x68e101f7,0x6b8e0058,0xddc3013d,0x00000000}},	//   ruld, öngü, minő,
  { {0xb6a60076,0x7c3a0063,0xb8870026,0x00000000}},	//   ригл, _שתנס, _smíð,
  { {0xbb840021,0x79a70002,0x86760085,0x00000000}},	//   _الهي, _срде, рымц,
  { {0xe47a005e,0x64480078,0x24800249,0x00000000}},	//   вљај_, ūdim, tlim_,
  { {0x03a31743,0xf74a0044,0xe40601ce,0x00000000}},	//   жито, _للبي_, јзап,
  { {0x645a0164,0x2480493f,0xb86501fb,0x00000000}},	// [8a00] étiq, rlim_, _داوو,
  { {0x24802f2b,0x41b60062,0x245f0072,0x00000000}},	//   slim_, рсат, tämä_,
  { {0x4fc60088,0x2480007d,0x765c07a5,0x00000000}},	//   асла, plim_, miry,
  { {0x50460001,0x58f60047,0xf9920132,0x00000000}},	//   једб, יצען_, קרא_,
  { {0x2d8100bd,0x76800072,0x64464940,0x00000000}},	//   ühen_, töyh, _ilki,
  { {0xddc3003b,0x44220130,0x764b005f,0x00000000}},	//   rinş, _hnk_, _įgyk,
  { {0xdb0b0026,0x9c460086,0x7d0d0051,0x00000000}},	//   _segð, ихил, łasn,
  { {0x765c00a3,0x10a30899,0x21674161,0x00000000}},	//   hiry, _фитн, _тиси_,
  { {0xab380076,0x765c1e3d,0xaa662183,0x00000000}},	//   уппу_, kiry, иток,
  { {0x5cf6000d,0x6f1d00ed,0xedd30044,0x00000000}},	//   _вяду, _ásca, _ويقد,
  { {0x64462dfb,0x29184941,0x0217009a,0x00000000}},	//   _olki, íra_, בחים_,
  { {0xdb090268,0xdb1900bd,0x3cfe4942,0x00000000}},	//   cceï, _bewä, _iptv_,
  { {0x95cb05fb,0x38a1003b,0x2902004c,0x00000000}},	//   кува_, tărî_, ňka_,
  { {0x7aef00cd,0x44224943,0x64464944,0x00000000}},	//   àcte, _ank_, _alki,
  { {0x7c221c2a,0xc8d30042,0x03c71135,0x00000000}},	//   _knor, _थिएट, исам,
  { {0x386906c2,0x34480001,0x442200c2,0x00000000}},	//   _ujar_, ачун_, _cnk_,
  { {0xdb1900bd,0x4992006a,0xd6d10754,0x00000000}},	// [8a10] _gewä, _دیگر, _عقد_,
  { {0xc2c40021,0xd904007e,0x44222dd6,0x00000000}},	//   تيكي, وی_, _enk_,
  { {0x7c221386,0x6441006f,0x6fb901d5,0x00000000}},	//   _onor, ëlis, ггер_,
  { {0x5f951001,0x7d1500ea,0x7c2223a8,0x00000000}},	//   биет, _ázsi, _nnor,
  { {0xa282007e,0x7d1a2909,0x6d5e4945,0x00000000}},	//   _کیلو, _arts, úpan,
  { {0xc33211b4,0x9f5600ea,0x7c224946,0x00000000}},	//   _צום_, ágát_, _anor,
  { {0x20dd0014,0x44220b2a,0x8c3c0058,0x00000000}},	//   _dáið_, _ynk_, _tuğl,
  { {0xdb0b013d,0x0c2505ce,0x44d34947,0x00000000}},	//   _megö, смин, ić_,
  { {0xdb0b00ea,0x7d1a0821,0x9b450021,0x00000000}},	//   _legö, _erts, صندو,
  { {0xe29200b5,0x3e7b0164,0x2b4d0051,0x00000000}},	//   ּװט_, rêts_, rzec_,
  { {0x49990076,0x3cf00066,0x6fab0082,0x00000000}},	//   ытия_, ľoví_, _छलां,
  { {0x7c224948,0x3cf80137,0x321100e5,0x00000000}},	//   _gnor, _ärva_, _lazy_,
  { {0xac740021,0x44d3427f,0x44220734,0x00000000}},	//   _بالش, eć_, _rnk_,
  { {0x7c2200a8,0xdb0b00a5,0x6f1b0022,0x00000000}},	//   _znor, _begö, _mruc,
  { {0x25e90161,0xc8b50be6,0x765c0072,0x00000000}},	//   _जारी_, _услы, riry,
  { {0x6f1b2863,0x765c4949,0x47c60481,0x00000000}},	//   _oruc, siry, _убив,
  { {0x44d30051,0x2327494a,0x32110051,0x00000000}},	// [8a20] ać_, боти_, _bazy_,
  { {0x17570063,0x15462183,0xf1e20082,0x00000000}},	//   _לספר_, _геом, _पाओन,
  { {0xd1790088,0xdfda005a,0x21a30062,0x00000000}},	//   асці_, гъл_, чихм,
  { {0x4ea60002,0x64460072,0x6f1b3c99,0x00000000}},	//   брка, _ulki, _bruc,
  { {0x21d8006a,0xd00f0021,0x6f1b3f90,0x00000000}},	//   _نژاد_, عله_, _cruc,
  { {0x6f1b3a98,0xcf250044,0x3211097a,0x00000000}},	//   _druc, ترمي, _gazy_,
  { {0xd132013a,0xacf30044,0xc536009d,0x00000000}},	//   _عمر_, كسيت, מָ֤ה_,
  { {0x6f1b494b,0x1ab40062,0xf65f01e1,0x00000000}},	//   _fruc, обия, lsæt_,
  { {0xddc1013d,0x7e7800a8,0x6f1b0022,0x00000000}},	//   _emlő, povp, _gruc,
  { {0xd8f80086,0x44d30051,0x9f590025,0x00000000}},	//   аної_, yć_, _úsá_,
  { {0x5d860032,0x28f80086,0xe895000d,0x00000000}},	//   _الال, шень_, жань,
  { {0x96eb0088,0x17990121,0x673d0072,0x00000000}},	//   льга_, ивны_, tysj,
  { {0x2127001b,0x6c7b0047,0x1dac0053,0x00000000}},	//   ̣nh_, _גראד, _चलात,
  { {0xef110063,0x25a504aa,0xe667354e,0x00000000}},	//   וּל_, øll_, стмо,
  { {0xf65f0146,0x32110051,0xe5990054,0x00000000}},	//   dsæt_, _razy_, ркві_,
  { {0x44d30022,0x69ca494c,0x94a805fd,0x00000000}},	//   rć_, _hefe, стра_,
  { {0xf7f4006a,0x966b014d,0xb6070085,0x00000000}},	// [8a30] _رسيد, _مصدق_, _лянк,
  { {0x69ca006d,0xdd210006,0xa3e50042,0x00000000}},	//   _jefe, _rįžt, _नाक_,
  { {0x3eb800c2,0x2127008b,0x31c4000d,0x00000000}},	//   _črta_, ãnh_, яств,
  { {0x753a00bd,0x06ed0053,0x69ca3f8d,0x00000000}},	//   ätze, _जमाव_, _lefe,
  { {0x644d0027,0x69ca0983,0x69d80d58,0x00000000}},	//   mhai, _oefe, _odve,
  { {0x6f1b0122,0x66150051,0x3e6b0121,0x00000000}},	//   _vruc, ndzk, ышен_,
  { {0xa63c0063,0xd5cc0063,0xc212089e,0x00000000}},	//   רגור, אֶחָ, _קהל_,
  { {0x4c920001,0x6f1b494d,0x69d80112,0x00000000}},	//   мијс, _truc, _adve,
  { {0x6f1b0051,0x628500ac,0x4ea406da,0x00000000}},	//   _uruc, olho, _ерха,
  { {0x2fcf00b8,0x644d004b,0x1a390002,0x00000000}},	//   lagg_, hhai, рџиќ_,
  { {0x24610006,0x644d494e,0x6285017d,0x00000000}},	//   nėms_, khai, ilho,
  { {0xc85a0086,0x291c007d,0x3ff90041,0x00000000}},	//   ршої_, _drva_, ױפֿע,
  { {0x7bcb001c,0x644d1632,0x291c017d,0x00000000}},	//   _iegu, dhai, _erva_,
  { {0x9f4f006d,0xfa37007e,0xceb20149,0x00000000}},	//   legó_, _درصد, ויך_,
  { {0x7bcb053b,0x645f0089,0xe5a306da,0x00000000}},	//   _kegu, fiqi, дири,
  { {0x644d018d,0x6285494f,0xc48601dd,0x00000000}},	//   ghai, elho, ілак,
  { {0xf65f0146,0x764b0006,0x69c14950,0x00000000}},	// [8a40] tsæt_, _įgyv, oble,
  { {0x7a3f0003,0x7bcb4951,0x68e13623,0x00000000}},	//   _bêti, _legu, orld,
  { {0x644d018d,0xf65f0146,0xcfa60142,0x00000000}},	//   bhai, rsæt_, ошли,
  { {0x644d4952,0xef1a3994,0xf65f00b9,0x00000000}},	//   chai, име_, ssæt_,
  { {0x63b40051,0x6fcc0042,0x3fcb005d,0x00000000}},	//   ągną, ारबं, شدنی_,
  { {0x7bcb0019,0x78a4112c,0x6aa30dd1,0x00000000}},	//   _aegu, _liiv, _ninf,
  { {0xe0d7026b,0x69dc0051,0x69c101e1,0x00000000}},	//   _мвр_, órem, dble,
  { {0x69ca005b,0x644400fe,0x78a40019,0x00000000}},	//   _sefe, nkii, _niiv,
  { {0x7bcb4953,0xcb070021,0x9e662b31,0x00000000}},	//   _degu, قيين_, _двад,
  { {0xa9540001,0x291c01b3,0x644d005f,0x00000000}},	//   звољ, _prva_, zhai,
  { {0x644400fe,0x7bcb0014,0x69ca0014,0x00000000}},	//   kkii, _fegu, _vefe,
  { {0x69ba0161,0x6aa34954,0x7bcb0006,0x00000000}},	//   _श्री, _einf, _gegu,
  { {0x69c14955,0x24610078,0x44c81638,0x00000000}},	//   bble, zėms_, eş_,
  { {0x69d805b9,0x29180137,0x7983001f,0x00000000}},	//   _udve, åras_, _fynw,
  { {0x34950138,0x644d4956,0xa967005e,0x00000000}},	//   завр, thai, _миља_,
  { {0x68e800e3,0x24610078,0x6aa3330e,0x00000000}},	//   mudd, vėms_, _zinf,
  { {0x644d1039,0x68e80096,0x6d5e0066,0x00000000}},	// [8a50] rhai, ludd, úpaj,
  { {0x24610078,0x644d1013,0x6595202f,0x00000000}},	//   tėms_, shai, _напу,
  { {0xdb090027,0x68e8014f,0x2fcf0137,0x00000000}},	//   iceá, nudd, tagg_,
  { {0x26c90035,0x80a80054,0x5f950601,0x00000000}},	//   _kwao_, івів_, пиет,
  { {0xd2470076,0x68e84957,0x54541dd6,0x00000000}},	//   _дэви, hudd, _цвят,
  { {0x68e80031,0x24610006,0x44391781,0x00000000}},	//   kudd, pėms_, _hos_,
  { {0x1d190088,0x44394958,0x6aa30290,0x00000000}},	//   сюль_, _kos_, _rinf,
  { {0x44394959,0x6aa3202e,0x9f98011b,0x00000000}},	//   _jos_, _sinf, _záík_,
  { {0xcf270032,0x9f4f02dd,0xec460062,0x00000000}},	//   _برأي, regó_, язъл_,
  { {0x44390814,0x68e8014f,0x2cac495a,0x00000000}},	//   _los_, fudd, _fudd_,
  { {0x443900e8,0x645d2cb3,0x2cac002b,0x00000000}},	//   _oos_, _omsi, _gudd_,
  { {0x186a0376,0x44390552,0x69c1004d,0x00000000}},	//   сами_, _nos_, sble,
  { {0x29180137,0x78a4065c,0x64440058,0x00000000}},	//   årar_, _viiv, vkii,
  { {0x443903d9,0x2fcd495b,0x3ead0003,0x00000000}},	//   _aos_, _leeg_, _muet_,
  { {0x7ae9024a,0x78a40659,0x44393a35,0x00000000}},	//   luet, _tiiv, _bos_,
  { {0x442602dd,0x2d8500ac,0x4439495c,0x00000000}},	//   ño_, _myle_, _cos_,
  { {0x44390ba0,0x443200ac,0x3eb800c2,0x00000000}},	// [8a60] _dos_, rjy_, _črto_,
  { {0xd196005e,0x9196005e,0x7c391542,0x00000000}},	//   пшењ, пјеш, _lowr,
  { {0xc006019d,0x44390268,0xe63b0063,0x00000000}},	//   зпек, _fos_, _התיכ,
  { {0x3ea50025,0x44391d6f,0x2cac495d,0x00000000}},	//   _ailt_, _gos_, _rudd_,
  { {0x68e80089,0xdfcf01fb,0xd0070085,0x00000000}},	//   zudd, ايه_, яеце_,
  { {0xb1460138,0x68e80089,0x3ead358b,0x00000000}},	//   _енгл, yudd, _duet_,
  { {0x44390509,0xdb0901e1,0x63b600a3,0x00000000}},	//   _yos_, nceæ, ocyn,
  { {0xbab82c9e,0x24820089,0x68e80137,0x00000000}},	//   огих_, _jkkm_, vudd,
  { {0xdee30781,0x7ae91554,0x3ead0805,0x00000000}},	//   _поти, guet, _guet_,
  { {0x78ad017f,0x68e8419b,0x3ea5495e,0x00000000}},	//   _čavr, tudd, _gilt_,
  { {0x6e28010a,0xdb090025,0x7ae90072,0x00000000}},	//   _indb, rceá, auet,
  { {0x68e8495f,0x98c30085,0xa2dd0042,0x00000000}},	//   rudd, эсьл, _पिल्,
  { {0x7ae9006d,0xbebd0078,0x96f80062,0x00000000}},	//   cuet, _grūd, пеят_,
  { {0x7689007a,0x26ed016a,0x6595013c,0x00000000}},	//   mþyk, _जमीर_, дагу,
  { {0x4439021f,0xa4d50054,0x94d50062,0x00000000}},	//   _pos_, ьові, ьовц,
  { {0x44390168,0x34954960,0xb8670043,0x00000000}},	//   _qos_, фабр, _ژاکو,
  { {0x44390623,0x18780047,0xe3b0002a,0x00000000}},	// [8a70] _vos_, _מעהר_, ارف_,
  { {0xe60300fe,0x52d80121,0xc87f004d,0x00000000}},	//   ätää, ямую_, loß_,
  { {0x44392174,0x15fa009a,0x45fa009a,0x00000000}},	//   _tos_, _והתע, _והתג,
  { {0xaadd0053,0x3ead0003,0x645d004d,0x00000000}},	//   _मिलक, _puet_, _umsi,
  { {0x3ea50019,0x765e0072,0x2fc00331,0x00000000}},	//   _pilt_, _ympy, ñiga_,
  { {0xf7740047,0x2fcd00f5,0x7868013d,0x00000000}},	//   עקס_, _weeg_, műve,
  { {0x3ea5007a,0x7c390045,0xc879005b,0x00000000}},	//   _vilt_, _powr, luğu_,
  { {0x3ea502b0,0xdb020460,0x3ab5005e,0x00000000}},	//   _wilt_, _egoí, мљот,
  { {0xadf506be,0x2ca618c1,0xda64005d,0x00000000}},	//   _опаш, _diod_, کايي,
  { {0x2d850051,0x8f680021,0x39454961,0x00000000}},	//   _tyle_, _عملك_, дног,
  { {0x7e634962,0x24894963,0x64930075,0x00000000}},	//   minp, klam_, içib,
  { {0x7e634964,0x6d434965,0x25c60042,0x00000000}},	//   linp, myna, वर्ण,
  { {0xba55005a,0x7ae94966,0x44f70058,0x00000000}},	//   _откъ, quet, eç_,
  { {0xc87901f7,0x7e633070,0x6f040058,0x00000000}},	//   duğu_, ninp, çici,
  { {0x6d434967,0x7e630050,0x44164968,0x00000000}},	//   nyna, iinp, мфат,
  { {0x78b30418,0x7a3f0003,0xd7ff003b,0x00000000}},	//   ēgvā, _vêtu, şări_,
  { {0x6d43001f,0x64bc007d,0x38600139,0x00000000}},	// [8a80] hyna, _očig, _imir_,
  { {0x24891a67,0x63b60022,0xe297014b,0x00000000}},	//   alam_, scyn, дау_,
  { {0x7e630072,0xe8e00013,0x6e3a004d,0x00000000}},	//   dinp, _trụy_, _rotb,
  { {0xc879005b,0x24892667,0x7d1c0014,0x00000000}},	//   buğu_, clam_, _ársi,
  { {0xc8790058,0x62400244,0x64480023,0x00000000}},	//   cuğu_, _böot, ūdis,
  { {0xdcba042c,0x64670051,0x7e634969,0x00000000}},	//   ощи_, ąpił, ginp,
  { {0x91e301ce,0x100a0044,0xc693009a,0x00000000}},	//   _јосе, _وترى_, דאג_,
  { {0x5b140336,0x7b140062,0x3ce03fb1,0x00000000}},	//   емит, едих, čiv_,
  { {0xb9e60086,0x6d43005b,0x3f672046,0x00000000}},	//   міни, ayna, _жито_,
  { {0x2fc6002c,0x386026c5,0x6d43002b,0x00000000}},	//   lbog_, _amir_, byna,
  { {0x3218031d,0xbfa3008b,0xc87f004d,0x00000000}},	//   _mary_, hiề, toß_,
  { {0x2fc600b9,0xb9060042,0x7b661406,0x00000000}},	//   nbog_, _पि_, _отле,
  { {0xd78b0032,0x44da027d,0xc87f004d,0x00000000}},	//   تخدم_, eď_, roß_,
  { {0x3eb902dd,0x61fe00ca,0x3860496a,0x00000000}},	//   _éste_, jfpl, _emir_,
  { {0x75880121,0xb886004c,0xa5f80121,0x00000000}},	//   дств_, _smíš, ьеру_,
  { {0x88c4004c,0xc8790075,0xc2c50044,0x00000000}},	//   _vděč, tuğu_, فيري,
  { {0x6d430051,0x2fc605b9,0x64930058,0x00000000}},	// [8a90] zyna, dbog_, eçic,
  { {0x2489496b,0x7a3f0003,0xd14b01fb,0x00000000}},	//   slam_, _hêtr, يشان_,
  { {0x248901f7,0x32180aa3,0xc6780044,0x00000000}},	//   plam_, _dary_, _تحيط_,
  { {0x2fc600b9,0x26d919c0,0x61fe0229,0x00000000}},	//   gbog_, osso_, afpl,
  { {0xe45600b7,0xdb02001b,0x7e630a5f,0x00000000}},	//   _נישט_, _ngoà, tinp,
  { {0x645a001c,0xef18000d,0xee380636,0x00000000}},	//   ītie, ьмі_, мні_,
  { {0x7e63496c,0x645a2886,0x61ea0014,0x00000000}},	//   rinp, ūtie, ófle,
  { {0x6d43496d,0x7e6308f3,0x5ac90a8f,0x00000000}},	//   ryna, sinp, плим_,
  { {0x2ef4011c,0x99f50054,0x6d43496e,0x00000000}},	//   _изтр, няні, syna,
  { {0x1eea005d,0x08c50cb2,0x00000000,0x00000000}},	//   _رومی_, нбон,   ,
  { {0x26d901f4,0xf8661240,0xa3c10042,0x00000000}},	//   esso_, евно, ुरा_,
  { {0xdb0b00b9,0x88bc004c,0xb60600a8,0x00000000}},	//   _afgå, dvěd, zvšč,
  { {0x7c2b03db,0xdcb10013,0xab290094,0x00000000}},	//   _ingr, _hủ_, _хола_,
  { {0xbb3a11b4,0x8b3a0063,0x442b496f,0x00000000}},	//   _מעני, _מתנצ, _anc_,
  { {0x26d94970,0x38600150,0xf2020053,0x00000000}},	//   asso_, _tmir_, र्फ़_,
  { {0x7afb0290,0x32184971,0xd0190022,0x00000000}},	//   otut, _sary_, _nań_,
  { {0x394500ac,0x7afb4972,0x4226000d,0x00000000}},	// [8aa0] lyls_, ntut, ндав,
  { {0xb77b014e,0x877b0063,0x26c0006d,0x00000000}},	//   _מאפש, _מאפי, _itio_,
  { {0x7afb0019,0x321807ee,0x26c0007d,0x00000000}},	//   htut, _vary_, _htio_,
  { {0x67244973,0xdfcf0242,0x2ee64974,0x00000000}},	//   _krij, ميم_, trof_,
  { {0xc7d7009a,0x9423014b,0x00000000,0x00000000}},	//   תוני_, _смяе,   ,
  { {0x29070627,0x2fc60146,0x7c2b1ea3,0x00000000}},	//   _opna_, sbog_, _angr,
  { {0xa3e40053,0x2fc600b9,0x9cca000d,0x00000000}},	//   _नया_, pbog_, чыла_,
  { {0x67244975,0x629e4976,0x60fb009a,0x00000000}},	//   _orij, lmpo, _מהלק,
  { {0x7afb002c,0x3a3c00c3,0xdb1900bd,0x00000000}},	//   gtut, _povp_, _gewü,
  { {0xef17000d,0x629e00a4,0x27e000be,0x00000000}},	//   _яму_, nmpo, _adin_,
  { {0x7afb0035,0x753a00bd,0x629e1fb2,0x00000000}},	//   atut, ätzl, impo,
  { {0xa7fb006d,0x67240401,0xe7870121,0x00000000}},	//   riño, _brij, еуго,
  { {0x26d919c0,0x67241236,0x87042a3b,0x00000000}},	//   usso_, _crij, ляре,
  { {0x27e001f7,0x67242780,0x6d583dbb,0x00000000}},	//   _edin_, _drij, ozva,
  { {0x25a500c7,0xdcfa001c,0x7afc003b,0x00000000}},	//   äll_, _iztē, ărtu,
  { {0x68e70024,0x6d584056,0x629e4977,0x00000000}},	//   ájde, izva, empo,
  { {0x88bc0080,0x24580121,0x67244978,0x00000000}},	// [8ab0] svěd, хать_, _grij,
  { {0x68e8006f,0x6d580114,0x442b002b,0x00000000}},	//   ordd, kzva, _wnc_,
  { {0x442b0089,0xa2dd0053,0x27e00072,0x00000000}},	//   _tnc_, _पिक्, _ydin_,
  { {0x629e4979,0x9f5f0014,0x21840002,0x00000000}},	//   ampo, _bauð_, уѓув,
  { {0x42990021,0x41e70085,0x6d580023,0x00000000}},	//   _ينجح_, _піва, ezva,
  { {0x8e85497a,0xa0c50044,0x32cf056c,0x00000000}},	//   ъгле, _ليسو, mży_,
  { {0x92a60051,0x93c6000c,0x5ff5005e,0x00000000}},	//   _dołą, sfăş, _изву,
  { {0x7afb051e,0x0c25000a,0xcf7b0021,0x00000000}},	//   ttut, тмин, _فإذا_,
  { {0x200f004b,0x68e8002b,0x32cf0022,0x00000000}},	//   megi_, erdd, nży_,
  { {0x6aaa00b9,0x4a4500a0,0x200f497b,0x00000000}},	//   _ciff, тнов, legi_,
  { {0x7afb497c,0xf1b20063,0x6724007d,0x00000000}},	//   stut, יסי_, _srij,
  { {0x6724064f,0x200f497d,0x0d640062,0x00000000}},	//   _prij, negi_, _съум,
  { {0xddd800c2,0xe7371a5d,0x68e846fa,0x00000000}},	//   lovš, вея_, ardd,
  { {0x63bd010a,0x6724497e,0x7ae907e6,0x00000000}},	//   _afsn, _vrij, mret,
  { {0x7ae90dfb,0x6724006f,0x32cf0051,0x00000000}},	//   lret, _wrij, eży_,
  { {0xc952014e,0x3f89001c,0x9f4d00cd,0x00000000}},	//   _כמו_, ļauj_, _oceà_,
  { {0x7af600fe,0xfbd20063,0x200f0026,0x00000000}},	// [8ac0] _äytt, יתן_, degi_,
  { {0x200f004b,0x7ae9497f,0x9f5f0014,0x00000000}},	//   eegi_, iret, _rauð_,
  { {0x69ce007a,0xe5720021,0xa0a61406,0x00000000}},	//   ðbei, _خطة_, важд,
  { {0x6946017f,0xddd84980,0x14d70063,0x00000000}},	//   _učeš, dovš, _בוטל_,
  { {0x92a60045,0x69c805a5,0xa067005e,0x00000000}},	//   _połą, ybde, њача_,
  { {0x68e8001f,0xad65007e,0x7bc90229,0x00000000}},	//   yrdd, گاهه, ebeu,
  { {0x8d63005e,0x7ae94981,0x6aaa4982,0x00000000}},	//   ивље, eret, _riff,
  { {0x6aaa4983,0x7ae94984,0x6b8b4985,0x00000000}},	//   _siff, fret, _bygg,
  { {0xa0670138,0x2d8100bd,0xda7a0a36,0x00000000}},	//   _рата_, üher_, дян_,
  { {0x3eb9048e,0x539b0047,0xdb1b0026,0x00000000}},	//   _ésta_, ויפו, rauð,
  { {0x3eab0066,0x7ae94986,0xdb1b0014,0x00000000}},	//   žitú_, aret, sauð,
  { {0x4bda00b3,0x7ae94987,0xab660062,0x00000000}},	//   _آباد_, bret, _ивел,
  { {0xf804000d,0x69dc01a8,0x7ae903e1,0x00000000}},	//   шчэн, óres, cret,
  { {0xe944005d,0x200f12a6,0x25bf0042,0x00000000}},	//   _مربی, zegi_, ्रेण,
  { {0x984f0051,0xc7c700e1,0x3eac01f2,0x00000000}},	//   jęć_, _испи, _midt_,
  { {0x3eac0146,0x31cb0053,0x62870119,0x00000000}},	//   _lidt_, िर्ध, _skjo,
  { {0x2d8c00b9,0xb27514cf,0xc2750141,0x00000000}},	// [8ad0] _lyde_, глаш, глај,
  { {0x7aef0268,0xa6e30026,0x53980121,0x00000000}},	//   àcti, íðus, твуя_,
  { {0x7ae94988,0x200f10a5,0x2d8c01e1,0x00000000}},	//   zret, tegi_, _nyde_,
  { {0x25ff0042,0x7ae94989,0xae000042,0x00000000}},	//   श्री_, yret, ल्सन_,
  { {0x9f050044,0x200f498a,0xa2dd0082,0x00000000}},	//   اوتو, regi_, _पिट्,
  { {0x644d024a,0x2d8c00b9,0xddd800c2,0x00000000}},	//   lkai, _byde_, tovš,
  { {0x644d2af7,0x6285498b,0xd0d40062,0x00000000}},	//   okai, moho, _восъ,
  { {0xc172014e,0x2fd9007e,0x7ae926e8,0x00000000}},	//   _החל_, _سوئد_, tret,
  { {0x6a850076,0x644d0b4e,0xac960021,0x00000000}},	//   ллиа, ikai, دنيا_,
  { {0x3f7a00b5,0x7ae93b4b,0x7bc9087d,0x00000000}},	//   _אָבע, rret, sbeu,
  { {0x644d498c,0x7ae9498d,0x186a0727,0x00000000}},	//   kkai, sret, еани_,
  { {0x7ae91609,0x00000000,0x00000000,0x00000000}},	//   pret,   ,   ,
  { {0x64930058,0x78ad498e,0x3b090caa,0x00000000}},	//   tçin, _diav, _чело_,
  { {0x75d60021,0x64bc0078,0x644d0078,0x00000000}},	//   طيرا, _ačia, ekai,
  { {0xdb0b0146,0x2919001c,0x6285498f,0x00000000}},	//   _afgø, āsas_, doho,
  { {0x644d002c,0x7c3b4309,0x64560089,0x00000000}},	//   gkai, njur, uhyi,
  { {0x645a00cd,0x99870078,0x28d70042,0x00000000}},	// [8ae0] ètiq, _tonų_, _भौति,
  { {0x62330001,0x7e1d0053,0xe8050053,0x00000000}},	//   беђу, पयोग_, ष्ठा_,
  { {0x00e64990,0x4fea184b,0x7c3b0014,0x00000000}},	//   ужен, емен_, kjur,
  { {0x984f0022,0x7d160022,0xd0950085,0x00000000}},	//   ręć_, łysk, ашчы,
  { {0x442001f7,0x9f340086,0xbe8a290b,0x00000000}},	//   mdi_, релі, нске_,
  { {0x628505b6,0x44204991,0x64930058,0x00000000}},	//   coho, ldi_, hçil,
  { {0x3eac02c0,0x0caa0121,0xcd060062,0x00000000}},	//   _vidt_, нтии_, учли,
  { {0x44204992,0x661e3202,0x3ed601fb,0x00000000}},	//   ndi_, _lapk, _مقرر,
  { {0x78ad051e,0xba540856,0x0a6a08b0,0x00000000}},	//   _riav, ивиј, ерни_,
  { {0x8f99005a,0x6493005b,0x44204993,0x00000000}},	//   _ръст_, eçil, hdi_,
  { {0x78ad2a70,0x61e30014,0x629c002b,0x00000000}},	//   _piav, ónli, _mhro,
  { {0x228f0019,0x442022ed,0x4d7b0ca4,0x00000000}},	//   tükk_, jdi_, _ארבע,
  { {0xa2b00161,0xead403e6,0x44204994,0x00000000}},	//   _अंग्, _толь, ddi_,
  { {0x44204995,0xda08007e,0x7afd00cd,0x00000000}},	//   edi_, _شيعه_, àste,
  { {0xa4d5019d,0x644d024a,0xa9bb0063,0x00000000}},	//   робі, tkai, _אזור,
  { {0x644d0341,0x645a00cc,0x69da0cc8,0x00000000}},	//   ukai, ūtin, late,
  { {0x644d014f,0x629c0025,0x628546de,0x00000000}},	// [8af0] rkai, _bhro, toho,
  { {0x644d4996,0x51f80076,0x44200b1c,0x00000000}},	//   skai, лную_, adi_,
  { {0x212700aa,0xffd50088,0x34950001,0x00000000}},	//   ính_, аўля, _ванр,
  { {0xa3d60053,0x69da4997,0x6d4a00a3,0x00000000}},	//   हरण_, hate, dyfa,
  { {0x62854998,0x69da4999,0xcee80021,0x00000000}},	//   poho, kate, هرون_,
  { {0x69da499a,0x64930058,0x7c2000c2,0x00000000}},	//   jate, içim, edmr,
  { {0xa3b90053,0x2dd80021,0x69da0a66,0x00000000}},	//   _चला_, ابهة_, date,
  { {0x6ee7007e,0x629c027d,0x3eb9006d,0x00000000}},	//   _مسئل, _zhro, _ésto_,
  { {0x6d4a01f7,0x69da001f,0x7d1a1841,0x00000000}},	//   ayfa, fate, _ests,
  { {0xf41f00c7,0x69da499b,0x09054222,0x00000000}},	//   _skäl_, gate, апон,
  { {0x6493005b,0x4420499c,0x64bc0130,0x00000000}},	//   tçil, ydi_, _ačin,
  { {0x38ca006a,0x186a0928,0x69da01a9,0x00000000}},	//   کایی_, тами_, aate,
  { {0x6c840021,0x38ba00ac,0x69da499d,0x00000000}},	//   _النم, _eër_, bate,
  { {0x69da1823,0xdb19004d,0xe9a512b9,0x00000000}},	//   cate, _bewö, _калп,
  { {0xd46a000a,0x287602dc,0x321301c8,0x00000000}},	//   виве_, _выпр, dexy_,
  { {0x2b090053,0x4420499e,0x7bdb00a4,0x00000000}},	//   _वहाँ_, udi_, nauu,
  { {0x6266499f,0x44203685,0x629c0123,0x00000000}},	// [8b00] аваа, rdi_, _phro,
  { {0x7bdb004d,0x4420017e,0x91e649a0,0x00000000}},	//   hauu, sdi_, роже,
  { {0xdb1900bd,0xa3ea0002,0x7bdb004b,0x00000000}},	//   _gewö, _идна_, kauu,
  { {0x7bdb004e,0x69da49a1,0x3fc6005d,0x00000000}},	//   jauu, zate, شگری_,
  { {0x629c1c9f,0x60c900c3,0x6d4a001f,0x00000000}},	//   _thro, _čeme, wyfa,
  { {0x9ce6005e,0xa116005d,0x9df83891,0x00000000}},	//   ацил, _پورت, ункт_,
  { {0x69da49a2,0x6f1b004d,0x06370047,0x00000000}},	//   vate, _esuc, ינסט_,
  { {0x6d4a002b,0x8c43005e,0x69da49a3,0x00000000}},	//   ryfa, жеће, wate,
  { {0x69da09ee,0xfa900058,0xe4570063,0x00000000}},	//   tate, şümü_, ייקט_,
  { {0x228f0019,0xba54007b,0x79a60330,0x00000000}},	//   tüki_, свој, ирне,
  { {0x7bdb004d,0x98be0078,0xa3d60053,0x00000000}},	//   bauu, kytą_, हरा_,
  { {0x69da49a4,0x228f004e,0xcb67005d,0x00000000}},	//   sate, rüki_, امیه_,
  { {0x69da49a5,0x98be0006,0x6f0249a6,0x00000000}},	//   pate, dytą_, ntoc,
  { {0x999800ea,0xddc3003b,0x386b002b,0x00000000}},	//   űrő_, minţ, sicr_,
  { {0x2492001f,0xddc3003b,0x2d8301e1,0x00000000}},	//   flym_, linţ, _øjet_,
  { {0x6f0249a7,0x91ad0013,0x7ae211a3,0x00000000}},	//   ktoc, _đè_, _kvot,
  { {0xddc3000c,0x212a0025,0x64bc49a8,0x00000000}},	// [8b10] ninţ, _arbh_, _učin,
  { {0x78b8005b,0x35f51240,0xa2cd0042,0x00000000}},	//   _kuvv, _упор, दीग्,
  { {0x69d80268,0xdfd10021,0x24550593,0x00000000}},	//   _meve, كيا_, _هندس,
  { {0x5fe70054,0x69d849a9,0x00000000,0x00000000}},	//   ріжж, _leve,   ,
  { {0xdefb0076,0x69d8006f,0x7bdb0019,0x00000000}},	//   тые_, _oeve, vauu,
  { {0x9e64019d,0xc33200b7,0xddc3000c,0x00000000}},	//   овід, _זוך_, dinţ,
  { {0x386949aa,0xc2120063,0x7ae2001c,0x00000000}},	//   _omar_, _מהם_, _avot,
  { {0xddc3003b,0xeb9949ab,0x5578009a,0x00000000}},	//   finţ, лий_, יעון_,
  { {0x69d849ac,0xc5ff008f,0x395e008f,0x00000000}},	//   _beve, ļēji_, ezts_,
  { {0x386949ad,0x7ae20734,0xaa350121,0x00000000}},	//   _amar_, _dvot, схищ,
  { {0x8d950021,0x644200fe,0x69d811eb,0x00000000}},	//   _الاش, öoik, _deve,
  { {0x3d010045,0xa856041d,0x6e2149ae,0x00000000}},	//   mów_, стој, _halb,
  { {0x6e2100eb,0x8b68019d,0xe73a0001,0x00000000}},	//   _kalb, _київ_, ћег_,
  { {0x69d80a53,0x65c31527,0xb6a606da,0x00000000}},	//   _geve, збра, сигл,
  { {0x3d010045,0x7bd900e3,0x98be0006,0x00000000}},	//   nów_, _kewu, tytą_,
  { {0x69d80122,0xab5d0051,0xa6db0014,0x00000000}},	//   _zeve, waży, eyðu,
  { {0x7bd9053b,0x3aba0047,0x04433607,0x00000000}},	// [8b20] _mewu, ָמענ, четн,
  { {0x3d010045,0x6e2149af,0x98be0078,0x00000000}},	//   ków_, _nalb, sytą_,
  { {0x3d010051,0x02190054,0x248949b0,0x00000000}},	//   jów_, шіть_, boam_,
  { {0x3d010045,0xb69b43a5,0x6f020b09,0x00000000}},	//   dów_, ntân, ttoc,
  { {0x6e2128f4,0x6f0249b1,0x00000000,0x00000000}},	//   _balb, utoc,   ,
  { {0x442249b2,0xddc3000c,0x471b0047,0x00000000}},	//   _hak_, vinţ, טונג,
  { {0x644600eb,0x442249b3,0x3d010051,0x00000000}},	//   _koki, _kak_, gów_,
  { {0x6446130a,0x442203a4,0xddc3003b,0x00000000}},	//   _joki, _jak_, tinţ,
  { {0x236049b4,0x64460006,0x442249b5,0x00000000}},	//   nzij_, _moki, _mak_,
  { {0xddc30529,0xc333014e,0x6e960032,0x00000000}},	//   rinţ, פות_, _الطا,
  { {0x44220034,0x3d010051,0xddc3003b,0x00000000}},	//   _oak_, ców_, sinţ,
  { {0x644649b6,0x44222294,0x764800fe,0x00000000}},	//   _noki, _nak_, ödyn,
  { {0x69d849b7,0x7645004a,0xec770054,0x00000000}},	//   _teve, _pohy, _упц_,
  { {0x7aef006d,0xa5f90001,0x44220229,0x00000000}},	//   ácte, јеву_, _aak_,
  { {0x661500c3,0xe5730021,0x644649b8,0x00000000}},	//   rezk, سطس_, _boki,
  { {0xb69b49b9,0x442214b5,0x38690b21,0x00000000}},	//   ctân, _cak_, _umar_,
  { {0x442249ba,0x3d010051,0x61d90076,0x00000000}},	// [8b30] _dak_, zów_, имая_,
  { {0x765c1780,0xf1a70ae8,0x659549bb,0x00000000}},	//   chry, брен, _мапу,
  { {0x644649bc,0x104b11ec,0xd1310021,0x00000000}},	//   _foki, ляди_, بما_,
  { {0x442200f3,0x7c22017f,0x64bc007d,0x00000000}},	//   _gak_, _naor, _očij,
  { {0x3d010051,0x69c11098,0x6e21004c,0x00000000}},	//   wów_, ycle, _palb,
  { {0x3d010045,0xd0d5005a,0x3cc9130d,0x00000000}},	//   tów_, _могъ, алко_,
  { {0xed594215,0x660a0058,0x44221ded,0x00000000}},	//   рой_, _öfke, _yak_,
  { {0x3d010045,0x69c1001f,0x27e9005b,0x00000000}},	//   rów_, wcle, _ndan_,
  { {0x3d010045,0xddc30066,0x0a39000d,0x00000000}},	//   sów_, ainš, ачны_,
  { {0xda65019d,0x3d010051,0xe9d90f55,0x00000000}},	//   івни, pów_, шко_,
  { {0xd9451dd1,0x69c102a0,0x98a60727,0x00000000}},	//   цени, rcle, жине,
  { {0x7aee005b,0x69c1057a,0x244e0066,0x00000000}},	//   üntü, scle, _tými_,
  { {0xb69b13f8,0x09e50189,0x765c162d,0x00000000}},	//   rtân, _долн, thry,
  { {0x8aa72f4b,0xe939006a,0xb69b49bd,0x00000000}},	//   _уред, _نسبت_, stân,
  { {0x644649be,0xb69b003b,0xa9663f17,0x00000000}},	//   _poki, ptân, _миша_,
  { {0x23600122,0x229449bf,0x672d49c0,0x00000000}},	//   tzij_, mäki_, _fraj,
  { {0x44220122,0x64460006,0xddc300c2,0x00000000}},	// [8b40] _vak_, _voki, zinš,
  { {0x236000c3,0xd1960095,0xb69b003b,0x00000000}},	//   rzij_, ошењ, ntâl,
  { {0x644600eb,0x044602a1,0x27e9002b,0x00000000}},	//   _toki, _денн, _ydan_,
  { {0xdfcf007e,0xd00a290b,0xddc3011b,0x00000000}},	//   نيم_, реде_, vinš,
  { {0x245c000f,0x2905004b,0x987b0041,0x00000000}},	//   _címe_, htla_, סאנט,
  { {0x6481001c,0x7c224344,0xddc302f7,0x00000000}},	//   rķie, _saor, tinš,
  { {0xf98700b3,0x998c0051,0x6ce60054,0x00000000}},	//   _آب_, zedł_, ціле,
  { {0x9c3809c2,0xcb0a0085,0xa4b7009a,0x00000000}},	//   спит_, аход_, חלקה_,
  { {0xcf26007e,0x29050051,0x6fd00042,0x00000000}},	//   _برزي, etla_, _ड्यू,
  { {0x764800fe,0x7c2205b3,0xd8f80086,0x00000000}},	//   ödyl, _waor, бної_,
  { {0x41bb0047,0x26c9007d,0x672d00c2,0x00000000}},	//   יציע, _stao_, _sraj,
  { {0x672d49c1,0xc8670086,0x9ca50044,0x00000000}},	//   _praj, ітни, _فإنن,
  { {0x6747000d,0x64bc00a8,0xa92701d1,0x00000000}},	//   цэнз, _učij, _poží,
  { {0x672d00dd,0x98be0022,0x8f9b009a,0x00000000}},	//   _vraj, zytę_, ייכי,
  { {0x394300b9,0xe5990086,0xe46b0239,0x00000000}},	//   øjst_, скві_, ашал_,
  { {0xd6db0055,0x672d0648,0xe3b9014b,0x00000000}},	//   _кто_, _traj, слач_,
  { {0x24580076,0x8c1b0063,0x439413a2,0x00000000}},	// [8b50] цать_, סומי, датс,
  { {0xbebd0078,0x245c0066,0xa228005e,0x00000000}},	//   _krūv, _ríme_, ожђа_,
  { {0xc0150055,0x34950001,0x7d0d0051,0x00000000}},	//   змещ, _наор, łasz,
  { {0xc8b50041,0x351a009a,0x88bc004c,0x00000000}},	//   פּעה_, _פורנ, tvěj,
  { {0xce95005a,0xf43a0165,0x543a0041,0x00000000}},	//   падъ, _הגרמ, _הערא,
  { {0x2905027d,0x245c004c,0x82d6009a,0x00000000}},	//   ytla_, _víme_, _מושג_,
  { {0xdfd517ab,0x2905424c,0x365c009a,0x00000000}},	//   _новы, xtla_, שכונ,
  { {0xc57c0063,0x0b450062,0x245c0066,0x00000000}},	//   ירות, знин, _tíme_,
  { {0xfaf10021,0xf2020042,0x5ac60183,0x00000000}},	//   رثة_, र्क़_, плым_,
  { {0xadf40caa,0xc9650062,0xb3650085,0x00000000}},	//   _опуш, звой, ўнiч,
  { {0xbd6b1001,0xdcef0006,0x6b823f12,0x00000000}},	//   _трае_, _įdėt, _exog,
  { {0x31560047,0x78760023,0xc156009a,0x00000000}},	//   פירן_, kšve, פשרו_,
  { {0xd5b8001c,0x69cc0053,0x290549c2,0x00000000}},	//   žām_, _द्वी, stla_,
  { {0xfe790080,0x35c7005e,0x644b004b,0x00000000}},	//   _svůj_, згро_, ögin,
  { {0x64a60088,0xceb201f9,0x98bf008f,0x00000000}},	//   зава, תים_, ērēt_,
  { {0xd467005e,0x98a30363,0xe73a0121,0x00000000}},	//   писе_, _пище, _геи_,
  { {0xb8fe016a,0x08770041,0xf8b3009a,0x00000000}},	// [8b60] दी_, _מעקט_, _אשה_,
  { {0x42230c0b,0x0594005d,0x637915ce,0x00000000}},	//   ндув, _يادگ, істр_,
  { {0xfe79004c,0x9556005d,0x6d450656,0x00000000}},	//   _tvůj_, _رخدا, ähal,
  { {0xa06a0001,0xdd1e004c,0xd8d60041,0x00000000}},	//   љада_, tíže, פונט_,
  { {0xddcf0080,0x38ba0023,0x90290044,0x00000000}},	//   _řeše, _vīri_, تألف_,
  { {0xad260044,0x539b009a,0xdd940183,0x00000000}},	//   كربو, _ליכו, малы,
  { {0xf2a30062,0xbd180054,0x20da0043,0x00000000}},	//   _чирп, іжих_, _دوزخ_,
  { {0xd0070086,0x321a0051,0x244e01c2,0x00000000}},	//   _несе_, lepy_, _týmu_,
  { {0xcb070021,0xaae60021,0x3ec2056c,0x00000000}},	//   كيين_, أسبو, óstą_,
  { {0x61fe49c3,0xc9862184,0x5e2500de,0x00000000}},	//   ngpl, зуми, _يعلق,
  { {0x3ec20006,0xfe45005d,0xd257009a,0x00000000}},	//   ųstą_, _تکنی, פשטה_,
  { {0xbb4604d8,0x78a449c4,0x6d3b009a,0x00000000}},	//   _неек, _chiv, _לתבנ,
  { {0x2bd20161,0xc053009a,0x6afa009d,0x00000000}},	//   _ध्या, גזר_, _הִ֔ו,
  { {0x19580183,0xd6d00043,0x0f57009a,0x00000000}},	//   _малы_, طقِ_, ליכם_,
  { {0xb495005e,0x89eb009a,0xba9b009a,0x00000000}},	//   дивљ, _הַחֵ, _הסגי,
  { {0x95840045,0xa37b017d,0x3f9a0051,0x00000000}},	//   _łącz, _leõe, ępuj_,
  { {0xa2b5019d,0xe3bf006d,0x68fa49c5,0x00000000}},	// [8b70] дбач, _caña_, lutd,
  { {0xe3b00021,0x61fe04aa,0x78a449c6,0x00000000}},	//   طرق_, ggpl, _zhiv,
  { {0xa1670001,0x411901f3,0xa1190044,0x00000000}},	//   чњак, تياج_, تقاط_,
  { {0x68e70066,0x90550085,0x00000000,0x00000000}},	//   ájdi, ьвец,   ,
  { {0x443949c7,0x8ee80086,0x442949c8,0x00000000}},	//   _ins_, змів_, mda_,
  { {0x999e0006,0x442949c9,0x479c0047,0x00000000}},	//   nktų_, lda_, ציגס,
  { {0x442949ca,0x9e320002,0x999e0078,0x00000000}},	//   oda_, тејч, iktų_,
  { {0xcac90076,0xf5381469,0xbd180086,0x00000000}},	//   огие_, לטור_, яції_,
  { {0x99f5000d,0x44390222,0xdb09005b,0x00000000}},	//   мяні, _mns_, _önüm,
  { {0x442900fe,0x99d40054,0x1dc60042,0x00000000}},	//   hda_, нююч, रुआत,
  { {0x4439102f,0x442900bb,0xd5b8001c,0x00000000}},	//   _ons_, kda_, žāk_,
  { {0xc5e90ee1,0xfb150021,0x2fdf00ac,0x00000000}},	//   _כד_, _يواج, _jeug_,
  { {0x61fe00c7,0x442949cb,0xbebd001c,0x00000000}},	//   ygpl, dda_, _grūt,
  { {0x3ebf024a,0x443949cc,0x44292ac0,0x00000000}},	//   _muut_, _ans_, eda_,
  { {0xe96905f7,0x7afb065c,0x4439004b,0x00000000}},	//   _файл_, luut, _bns_,
  { {0x442949cd,0xf99200ff,0x7c2949ce,0x00000000}},	//   gda_, _שרה_, nder,
  { {0x3ebf00e8,0x7afb024a,0xda0e0013,0x00000000}},	// [8b80] _nuut_, nuut, _mỏng_,
  { {0x443949cf,0x44260057,0xda0e008b,0x00000000}},	//   _ens_, žo_, _lỏng_,
  { {0x27e00199,0x661c49d0,0xa5d40053,0x00000000}},	//   _kein_, merk, _ब्यौ,
  { {0x7c292876,0x7afb024a,0xc2090063,0x00000000}},	//   jder, kuut, יה_,
  { {0x27e000bd,0x2ee60089,0x7afb0072,0x00000000}},	//   _mein_, usof_, juut,
  { {0xa2e3018e,0x27e00e7f,0x7c2949d1,0x00000000}},	//   _јорд, _lein_, eder,
  { {0x2ee60089,0xeca60002,0xda0e0013,0x00000000}},	//   ssof_, мјин, _bỏng_,
  { {0x32c4005b,0x27e00649,0x661c49d2,0x00000000}},	//   _köy_, _nein_, herk,
  { {0x1dcf0235,0x661c2585,0xeb97005e,0x00000000}},	//   _स्वत, kerk, мић_,
  { {0xae05016a,0xdb220045,0x68fa0829,0x00000000}},	//   _रायन_, _źród, tutd,
  { {0x442906f6,0x61e1004b,0xeaaf0021,0x00000000}},	//   yda_, _õlle, جعي_,
  { {0x26c00290,0x286b0086,0x7afb49d3,0x00000000}},	//   _buio_, ірно_, buut,
  { {0x27e017be,0x68fa08a9,0xe8200042,0x00000000}},	//   _dein_, sutd, _बसरा_,
  { {0x661c0e56,0x44290051,0x999e0078,0x00000000}},	//   gerk, wda_, uktų_,
  { {0x4439028d,0x659432f0,0xa3b10053,0x00000000}},	//   _pns_, вару, टेन_,
  { {0xd5b80b29,0x6493005b,0x442949d4,0x00000000}},	//   ься_, eçir, uda_,
  { {0x6e3a0179,0x92590002,0x4439004d,0x00000000}},	// [8b90] _ontb, паат_, _vns_,
  { {0x91e4005e,0x6d4501cf,0x64930058,0x00000000}},	//   кође, ähak, tçis,
  { {0x25d60063,0x7c2949d5,0xeab10063,0x00000000}},	//   _אותן_, yder, רֹן_,
  { {0x603e000c,0x245c007a,0x443949d6,0x00000000}},	//   _rămâ, _tíma_, _uns_,
  { {0x229400c7,0x69ca49d7,0xef0e000d,0x00000000}},	//   täkt_, _offe, ым_,
  { {0xceb80051,0x603e000c,0x7afb00fe,0x00000000}},	//   _cię_, _pămâ, vuut,
  { {0xdc3a005b,0x7c29001c,0x22940137,0x00000000}},	//   _açıs, tder, räkt_,
  { {0x661c000f,0x229400c7,0x4c920001,0x00000000}},	//   zerk, säkt_, лијс,
  { {0x8ed80021,0x661c00a4,0x7c290fdf,0x00000000}},	//   _يذكر_, yerk, rder,
  { {0x7afb024a,0x27e049d8,0xfeb80021,0x00000000}},	//   ruut, _sein_, _قالت_,
  { {0x2d800529,0x661c1699,0x7afb49d9,0x00000000}},	//   şier_, verk, suut,
  { {0xed5600b5,0x661c49da,0x7afb0ff2,0x00000000}},	//   _אבער_, werk, puut,
  { {0x61e50014,0x661c0b94,0x2cad49db,0x00000000}},	//   kahl, terk, mmed_,
  { {0xe3bf006d,0x27e0004d,0x443e00ea,0x00000000}},	//   _baño_, _wein_, _őt_,
  { {0xa9790047,0x7ae949dc,0x61e50ebe,0x00000000}},	//   _מאַכ, lset, dahl,
  { {0x46ea011c,0xe3bf006d,0x7bc949dd,0x00000000}},	//   _един_, _daño_, nceu,
  { {0x2cad0034,0x7ae949de,0xd3870612,0x00000000}},	// [8ba0] imed_, nset, ейте_,
  { {0x9985000f,0x2c7a008f,0x2cad49df,0x00000000}},	//   lelő_, rīdi_, hmed_,
  { {0x2cad0019,0x6e3c00cd,0xf77f017d,0x00000000}},	//   kmed_, _òrbi, maça_,
  { {0xceb81112,0x68fc00cd,0x62950089,0x00000000}},	//   _się_, àrdi, _ekzo,
  { {0x2cad0004,0x7ae949e0,0x24800b59,0x00000000}},	//   dmed_, jset, mnim_,
  { {0x248001b3,0xf77f0110,0x7ae949e1,0x00000000}},	//   lnim_, naça_, dset,
  { {0xcd930001,0x6e2800c2,0xf6530149,0x00000000}},	//   лашћ, _vadb, רצו_,
  { {0x7ae90026,0xa25b0013,0x6b9900a3,0x00000000}},	//   fset, _tuôc, _bywg,
  { {0x7ae9007a,0x6e280089,0x2480003b,0x00000000}},	//   gset, _tadb, inim_,
  { {0x2cad00e5,0x38600331,0x99620066,0x00000000}},	//   amed_, _alir_, ríža_,
  { {0x386002f0,0x88bc0080,0x67d50086,0x00000000}},	//   _blir_, jvět, кону,
  { {0xa3b10235,0x61e500bd,0x2480027c,0x00000000}},	//   टेड_, zahl, jnim_,
  { {0x41e10161,0x248031a9,0xdc8b0063,0x00000000}},	//   _फ़लस, dnim_, _צְבָ,
  { {0x3872002b,0xe3bf0331,0xbb3b009f,0x00000000}},	//   _emyr_, _paño_, _מעדי,
  { {0xceb300b5,0x659532f0,0x75881e3b,0x00000000}},	//   טיש_, таву, еств_,
  { {0x3860001f,0x299b0063,0x290b003b,0x00000000}},	//   _glir_, _מסומ, ăcat_,
  { {0x57f4000d,0x61e549e2,0xdc8b009a,0x00000000}},	// [8bb0] _спыт, tahl, לְמָ,
  { {0x7afd0268,0x2cad00c2,0x248049e3,0x00000000}},	//   àsti, zmed_, anim_,
  { {0xdfd10067,0x61e51660,0x2480027c,0x00000000}},	//   ليا_, rahl, bnim_,
  { {0xf9930047,0x24800734,0x8f750e74,0x00000000}},	//   ארע_, cnim_, кулі,
  { {0x442b0024,0x4f580086,0xd9ad0053,0x00000000}},	//   _iac_, ницю_, _घण्ट,
  { {0x644f0024,0x7ae93226,0x998500ea,0x00000000}},	//   _hoci, vset, zelő_,
  { {0xfc310032,0x8d620076,0x2cad0019,0x00000000}},	//   لحة_, ивше, tmed_,
  { {0x7ae935e4,0x63a20051,0x442b3347,0x00000000}},	//   tset, żone, _jac_,
  { {0x7bc90003,0x644f12c7,0x442b49e4,0x00000000}},	//   rceu, _moci, _mac_,
  { {0x442b49e5,0x248001b3,0x644f1aea,0x00000000}},	//   _lac_, znim_, _loci,
  { {0x9985013d,0x7ae949e6,0x3a3c0244,0x00000000}},	//   telő_, sset, _dnvp_,
  { {0x442b001f,0x7ae949e7,0x644f0955,0x00000000}},	//   _nac_, pset, _noci,
  { {0x24800add,0x7c2b03d4,0x9b92005d,0x00000000}},	//   vnim_, _iagr, _پلوت,
  { {0x7c2b007a,0xa3d4016a,0x23690051,0x00000000}},	//   _hagr, सुन_, dzaj_,
  { {0xf77f0555,0x442b49e8,0x24801587,0x00000000}},	//   raça_, _bac_, tnim_,
  { {0x644f3196,0xc4830f55,0x442b49e9,0x00000000}},	//   _coci, алск, _cac_,
  { {0x130a0088,0x88bc0080,0x248001b3,0x00000000}},	// [8bc0] ьнай_, svět, rnim_,
  { {0x7c2b0666,0x248001b3,0xa6e20026,0x00000000}},	//   _lagr, snim_, íðub,
  { {0x442b000c,0x236900c2,0x2480027c,0x00000000}},	//   _fac_, azaj_, pnim_,
  { {0xc059000d,0x7e6109ea,0x6b840014,0x00000000}},	//   ніі_, _allp, _þigg,
  { {0xbe8a0001,0x442049ea,0x23690022,0x00000000}},	//   мске_, mei_, czaj_,
  { {0x765c00e8,0xdce1005b,0x442049eb,0x00000000}},	//   nkry, _aylı, lei_,
  { {0x7c2b49ec,0x27f2002b,0xc5f30063,0x00000000}},	//   _bagr, _odyn_, בדו_,
  { {0x91bf001b,0x6481008f,0x442049ed,0x00000000}},	//   _đủ_, eķij, nei_,
  { {0x442049ee,0x7c2b002b,0xaf06013c,0x00000000}},	//   iei_, _dagr, _шпал,
  { {0x7c2b0027,0xdb1100ea,0x442049ef,0x00000000}},	//   _eagr, ágán, hei_,
  { {0xdd1f0024,0x442049f0,0xbd4601fb,0x00000000}},	//   píšt, kei_, _جناي,
  { {0x2c0b007e,0x6d790047,0x5d790041,0x00000000}},	//   _يعنی_, _אָנװ, _אָננ,
  { {0x6d580006,0x442b0025,0x27f2001f,0x00000000}},	//   lyva, _rac_, _ddyn_,
  { {0x7c202c33,0x7c2b31a9,0x442b1575,0x00000000}},	//   lemr, _zagr, _sac_,
  { {0x25a500c7,0xc1e00053,0x442049f1,0x00000000}},	//   åll_, _पड़ेग, fei_,
  { {0x629e0d90,0x442049f2,0xe4a70141,0x00000000}},	//   elpo, gei_, трго,
  { {0x6d580078,0x644f49f3,0x823900d9,0x00000000}},	// [8bd0] hyva, _voci, нзас_,
  { {0x76480072,0x7d1a49f4,0x23690eb5,0x00000000}},	//   ödyt, _opts, rzaj_,
  { {0xf77004de,0x2127001b,0x442049f5,0x00000000}},	//   _های_, ình_, bei_,
  { {0x44200954,0x32070051,0x38bb005f,0x00000000}},	//   cei_, żny_, _mūro_,
  { {0xd9e30053,0xdd100114,0x1eea005d,0x00000000}},	//   _ग़लत_, výše, فونی_,
  { {0x7c2b49f6,0x3b0d49f7,0xfebb005d,0x00000000}},	//   _sagr, vteq_, ذاشت_,
  { {0x7c2b1b74,0x0ffb0044,0x00000000,0x00000000}},	//   _pagr, _يعرب_,   ,
  { {0x0c2506b4,0x69da004d,0x6c350593,0x00000000}},	//   умин, ebte, افظا,
  { {0x786602dd,0xf77f017d,0xfe79004c,0x00000000}},	//   _jóve, daço_, _dvůr_,
  { {0x78660016,0x6f1b005b,0x7d2800fe,0x00000000}},	//   _móve, _ipuc, ässä,
  { {0x442049f8,0x37e601ce,0x00000000,0x00000000}},	//   yei_, лонг,   ,
  { {0xe43c0080,0xbbeb007e,0x44203595,0x00000000}},	//   _příč, _آرام_, xei_,
  { {0x7bdb14aa,0xf0920063,0x78660014,0x00000000}},	//   mbuu, מנט_, _nóve,
  { {0x44200221,0x38ca007e,0xa25b0013,0x00000000}},	//   wei_, بایی_, _suôn,
  { {0x765c00ac,0x05550054,0x7cd1008f,0x00000000}},	//   rkry, аття, _dārg,
  { {0x765c021f,0x7866006d,0x64ac004d,0x00000000}},	//   skry, _bóve, ißig,
  { {0xa25b008b,0x442049f9,0x06760054,0x00000000}},	// [8be0] _vuôn, rei_, _буня,
  { {0x442049fa,0x26c4004c,0x614649fb,0x00000000}},	//   sei_, ímou_, леза,
  { {0xea760047,0x7afb0025,0x6f1b003b,0x00000000}},	//   נגער_, hrut, _apuc,
  { {0xd46a0001,0xb4fb0149,0x7afb49fc,0x00000000}},	//   _чиме_, _אפטי, krut,
  { {0xe3b2007e,0x7afb159a,0xcef602d8,0x00000000}},	//   _درد_, jrut, учењ,
  { {0x6d580006,0x11da0021,0x644b004b,0x00000000}},	//   tyva, _سورة_, ögiv,
  { {0x2cc90024,0x7afb478f,0x0166439c,0x00000000}},	//   _ľudí_, erut, _скво,
  { {0x7afb1eee,0xb69b003b,0x2c7a008f,0x00000000}},	//   frut, ntâr, vīds_,
  { {0xa0670001,0xe4570047,0x68f5004a,0x00000000}},	//   _сата_, טיקט_, ázdn,
  { {0x7bdb002c,0x6d580006,0x69da49fd,0x00000000}},	//   abuu, pyva, ubte,
  { {0x7ea400cd,0x69da004d,0x3cfa0044,0x00000000}},	//   lòpo, rbte, _سعاد_,
  { {0x7afb02f0,0x3ebe2071,0xd847013f,0x00000000}},	//   brut, _hitt_, ухоп,
  { {0x7c930032,0xf77f017d,0x70e10042,0x00000000}},	//   _النص, raço_, _पब्ल,
  { {0xcf930063,0x6d490022,0xb6040054,0x00000000}},	//   מטר_, ślał, йяск,
  { {0xf77f0016,0x3ebe49fe,0x94ab0002,0x00000000}},	//   paço_, _mitt_, етаа_,
  { {0x3ebe10bc,0x248d082a,0x13d5000d,0x00000000}},	//   _litt_, čemo_, ржаў,
  { {0x4275000d,0x94a8005e,0xbec7008f,0x00000000}},	// [8bf0] агас, утра_, olīš,
  { {0x7aef1d4b,0x2bdb0053,0xc3980054,0x00000000}},	//   ácti, _ग्नू_, укує_,
  { {0xe796007e,0x6f1b0244,0xf1a749ff,0x00000000}},	//   _مایک, _spuc, уран,
  { {0x897b0047,0x6f0201f4,0x7cd1008f,0x00000000}},	//   עראצ, fuoc, _jāre,
  { {0x2aab00b9,0x2009001c,0x644d00ea,0x00000000}},	//   løbe_, ļai_, mjai,
  { {0xacf50001,0x62834a00,0x7afb0137,0x00000000}},	//   ачиј, čnos, vrut,
  { {0xd658014e,0x3ebe4a01,0x1d060062,0x00000000}},	//   ריות_, _ditt_, аещи_,
  { {0x3ebe0627,0x7afb4a02,0x4c35000d,0x00000000}},	//   _eitt_, trut, рэкт,
  { {0x644d00fe,0xdb19001f,0x5064435a,0x00000000}},	//   ijai, _sgwâ, _утра,
  { {0x3ebe0031,0x62850031,0x7cd1001c,0x00000000}},	//   _gitt_, nnho, _pārd,
  { {0x7afb01b9,0x4a420086,0x6846026c,0x00000000}},	//   srut, інюв, анна,
  { {0x78ad03d9,0x7cd1003d,0x61e70146,0x00000000}},	//   _chav, _vārd, _lejl,
  { {0xcf9200b5,0xe73a0001,0xe9ce3652,0x00000000}},	//   ַטל_, њег_, _мк_,
  { {0x61e70080,0x62851c40,0x6e23211e,0x00000000}},	//   _nejl, jnho, nenb,
  { {0x7d030fe5,0xa9660086,0x62974a03,0x00000000}},	//   nuns, _вища_, doxo,
  { {0xdd010080,0x26c4039f,0x644d00ea,0x00000000}},	//   _štěs, ímos_, gjai,

  { {0xa3b10235,0xe29a000a,0x33d5000d,0x00000000}},	// [8c00] टेल_, ваа_, сіст,
  { {0x7d034a04,0xb69b003b,0xc2431135,0x00000000}},	//   kuns, luân, онук,
  { {0x6aa10d5a,0x61e74a05,0x0fc60330,0x00000000}},	//   illf, _dejl, айен,
  { {0x3ebe31c8,0x62854a06,0xb69b003b,0x00000000}},	//   _sitt_, anho, nuân,
  { {0x61e74a07,0x6e234a08,0x1df80121,0x00000000}},	//   _fejl, fenb, гелы_,
  { {0x7ea400cd,0x6e234a09,0x2006002b,0x00000000}},	//   ròpo, genb, sgoi_,
  { {0xafe60088,0xddc80051,0x3ebe087b,0x00000000}},	//   _вобл, _podł, _vitt_,
  { {0x69c33df4,0x44324a0a,0xe7f20053,0x00000000}},	//   _agne, ndy_, _आएगा_,
  { {0xcb070021,0x3ebe0829,0x6e234a0b,0x00000000}},	//   ليين_, _titt_, benb,
  { {0xf1aa0053,0x2d96137a,0x44324a0c,0x00000000}},	//   _करान, _крес, hdy_,
  { {0x44322f42,0x7cd1001c,0x7d03053c,0x00000000}},	//   kdy_, _pāre, cuns,
  { {0x69c302ab,0xdd7b0063,0x60c04a0d,0x00000000}},	//   _egne, _בטבל, _jimm,
  { {0x7ad40242,0x6285001f,0x629c4a0e,0x00000000}},	//   _اقتص, ynho, _okro,
  { {0x44324a0f,0xaa57167b,0x60c000a5,0x00000000}},	//   edy_, _вишу_, _limm,
  { {0xa4d50086,0x588706bc,0x644d042e,0x00000000}},	//   собі, _выпа, tjai,
  { {0x60c000bd,0x61e700b9,0x629c4a10,0x00000000}},	//   _nimm, _sejl, _akro,
  { {0xa3b10161,0x644d00fe,0xb867005d,0x00000000}},	// [8c10] टें_, rjai, _ماکو,
  { {0xfe050053,0xdcee004c,0x443205ea,0x00000000}},	//   _राइस_, áděn, ady_,
  { {0x61e70146,0x61130080,0x644d00ea,0x00000000}},	//   _vejl, dělá, pjai,
  { {0x27e904bc,0x9ef50021,0x7d030050,0x00000000}},	//   _jean_, مستش, vuns,
  { {0x53340076,0x27e904ff,0x238a0024,0x00000000}},	//   _деят, _mean_, čujú_,
  { {0x27e919d9,0x8e080086,0x7ead0066,0x00000000}},	//   _lean_, инів_, kúpe,
  { {0x4035005a,0xbd6b005a,0x60c00026,0x00000000}},	//   _левс, ърде_, _fimm,
  { {0x7cd1003d,0x213e0025,0x7d034a11,0x00000000}},	//   _pārb, _átha_, runs,
  { {0x20100024,0x7d033092,0x98bf0078,0x00000000}},	//   íliž_, suns, lytė_,
  { {0x6aa10031,0xf41f0137,0x60c04a12,0x00000000}},	//   ullf, _själ_, _zimm,
  { {0xb69b017d,0x44323079,0x69c300a8,0x00000000}},	//   tuân, ydy_, _vgne,
  { {0x245c0026,0x7d7a0047,0x9f440003,0x00000000}},	//   _tími_, _גרעג, _semé_,
  { {0x27e93f1b,0x443201d1,0x77830094,0x00000000}},	//   _dean_, vdy_, зляз,
  { {0xa3bd0053,0x6f7a0047,0x3f7a0047,0x00000000}},	//   ेखन_, אָלג, אָלע,
  { {0xba740021,0x672d4a13,0xe5a612b9,0x00000000}},	//   _بانت, _esaj, сиви,
  { {0x290515c4,0x7876001c,0x3958004b,0x00000000}},	//   mula_, kšvi, ärse_,
  { {0x290519a6,0x61ea0014,0xe73a1e1b,0x00000000}},	// [8c20] lula_, ðflo, _сеп_,
  { {0x200d003b,0xd9f90053,0x290500be,0x00000000}},	//   _acei_, ूलित_, oula_,
  { {0x62834a14,0x2905041f,0xd657009a,0x00000000}},	//   čnop, nula_, _היית_,
  { {0x3a254a15,0x629c0022,0x64930058,0x00000000}},	//   help_, _wkro, kçiy,
  { {0xa067005e,0x29054a16,0x11d60083,0x00000000}},	//   љача_, hula_, _гібр,
  { {0x412a019d,0x3a250031,0x29054a17,0x00000000}},	//   _його_, jelp_, kula_,
  { {0x60c001e3,0xc27b0047,0x290507a2,0x00000000}},	//   _timm, _ערלי, jula_,
  { {0xbf4d0080,0x29051e17,0x7bdd0014,0x00000000}},	//   _šířk, dula_, ðsup,
  { {0x7cd1008f,0x6f6601dd,0xfbcf00f2,0x00000000}},	//   _pārc, _уваз, رتي_,
  { {0x7f3b0047,0x27e94a18,0x7ead0066,0x00000000}},	//   _געמו, _sean_, túpe,
  { {0x27e90019,0x6da601fb,0x29054a19,0x00000000}},	//   _pean_, _امام, gula_,
  { {0x4867005a,0xc8674a1a,0x244e004c,0x00000000}},	//   съоб, стои, _týmy_,
  { {0x27e9140a,0x29054a1b,0xac970021,0x00000000}},	//   _vean_, aula_, _اننا_,
  { {0x45d40a29,0x29054a1c,0xeb970094,0x00000000}},	//   зорс, bula_, _уич_,
  { {0x29051117,0x7cf80063,0x27e94a1d,0x00000000}},	//   cula_, יִּק, _tean_,
  { {0x985d0045,0x73d9000a,0x9405007e,0x00000000}},	//   _błąd_, рдар_, توره,
  { {0x672d0035,0xb7dc0047,0x26c108ed,0x00000000}},	// [8c30] _usaj, _עקזי, _tiho_,
  { {0x754800ea,0x332900e5,0x98bf005f,0x00000000}},	//   ószí, rwax_, tytė_,
  { {0x50b9007e,0x38693588,0xf8c90013,0x00000000}},	//   لگرد_, _klar_, _lẩn_,
  { {0x3e6b00d1,0xc87f004d,0xb7fb0042,0x00000000}},	//   _møte_, niß_, ्लिम_,
  { {0xddc5019d,0x5f050085,0x99870130,0x00000000}},	//   обли, ізка, _manš_,
  { {0x38694a1e,0xdce8005b,0x248900ca,0x00000000}},	//   _llar_, _aydı, lnam_,
  { {0x24890016,0xe80a0053,0xb7fb0053,0x00000000}},	//   onam_, _वाला_, ्लाम_,
  { {0xf8c90013,0x64930058,0x78760078,0x00000000}},	//   _bẩn_, tçiy, pšvi,
  { {0xf8c9008b,0x290500ac,0x24890023,0x00000000}},	//   _cẩn_, wula_, inam_,
  { {0x38694a1f,0xc87f004d,0x29054a20,0x00000000}},	//   _alar_, eiß_, tula_,
  { {0x386900d1,0xc9a9167b,0xdb0b0014,0x00000000}},	//   _blar_, рвне_, _eggð,
  { {0x7645001f,0x38694a21,0xf6490063,0x00000000}},	//   _anhy, _clar_, _בצ_,
  { {0x29054a22,0xda35000d,0x6be8009d,0x00000000}},	//   sula_, _меды, _הַצַ,
  { {0x2489143b,0x245c0014,0x29050e57,0x00000000}},	//   enam_, _límt_, pula_,
  { {0x1a9a0041,0x65c31dd0,0xc448005d,0x00000000}},	//   _דיסע, дбра, میدن_,
  { {0x60c9109f,0x9f4f0014,0x04434a23,0x00000000}},	//   _čemp, yggð_, месн,
  { {0xc8890032,0xd467295e,0x03a308e5,0x00000000}},	// [8c40] _دخول_, ците_, дито,
  { {0x25ad004c,0xae0e0042,0x7645002b,0x00000000}},	//   řela_, _साधन_, _gnhy,
  { {0x7cf00025,0x4fc60861,0xd00f0131,0x00000000}},	//   _mórá, осла, мф_,
  { {0xa06a0141,0xdfd0002a,0x91da0042,0x00000000}},	//   јада_, ريت_, _प्रै,
  { {0x888b0041,0x64464a24,0x3ed400de,0x00000000}},	//   ברײַ, _inki, أقتر,
  { {0x72c30076,0xccfa0001,0x3e870062,0x00000000}},	//   _обяз, аћи_, ойчо_,
  { {0xf6530063,0x68ed0022,0x7cd1008f,0x00000000}},	//   וצג_, _ładn, _pāra,
  { {0x245c0024,0xcb54005e,0x6ab20053,0x00000000}},	//   _tímu_, звић, ँग्र,
  { {0x3ce9017f,0x3e6b00d1,0x69cf004c,0x00000000}},	//   ćava_, _søte_, ěcen,
  { {0x24894a25,0x24800150,0xc87f004d,0x00000000}},	//   znam_, hiim_, wiß_,
  { {0x64460072,0x7657396a,0xdc6a0121,0x00000000}},	//   _onki, _roxy, _кажд_,
  { {0x0b462ab5,0x7afd001c,0xc87b0002,0x00000000}},	//   _мнен, šsta, рџо_,
  { {0xf8c90013,0xdce30022,0x00000000,0x00000000}},	//   _uẩn_, rzną,   ,
  { {0x64464a26,0x95c80062,0x7aa60044,0x00000000}},	//   _anki, жута_, _بإصل,
  { {0x24890d31,0xd7fb1259,0xe9170054,0x00000000}},	//   tnam_, _куп_, _дощі_,
  { {0x6f020051,0x3869017e,0xd14b007e,0x00000000}},	//   kroc, _ular_, یشان_,
  { {0x24894a27,0x22584a28,0x44980085,0x00000000}},	// [8c50] rnam_, _bork_, івую_,
  { {0x2489002b,0x22584a29,0x93882049,0x00000000}},	//   snam_, _cork_, іста_,
  { {0x7fd5000d,0xa282007e,0x92680092,0x00000000}},	//   пілі, ریفو, црта_,
  { {0xc9530149,0x6b8d0014,0xc0780054,0x00000000}},	//   ומע_, _þagg, осії_,
  { {0x44294a2a,0xddc11c8a,0xdf780054,0x00000000}},	//   mea_, _bolş, обці_,
  { {0x44294a2b,0x8d550062,0xb3ba0063,0x00000000}},	//   lea_, зтич, _למרכ,
  { {0x38b20024,0xde880013,0xed5905ac,0x00000000}},	//   láre_, uịa_, сой_,
  { {0x9f440080,0x44293b46,0x68ed0051,0x00000000}},	//   _zemí_, nea_, _łado,
  { {0x4ea70540,0x6f021130,0x69c700a8,0x00000000}},	//   _држа, croc, žjem,
  { {0x28cf0053,0x44294a2c,0x786600be,0x00000000}},	//   _संदि, hea_, _póvo,
  { {0x442947f0,0xd94543bd,0x4ea402f8,0x00000000}},	//   kea_, чени, _црта,
  { {0x44290009,0xa3bd0053,0xda1c0053,0x00000000}},	//   jea_, ेखा_, ब्बत_,
  { {0xeb8e019d,0x32110051,0x44294a2d,0x00000000}},	//   _чи_, _oczy_, dea_,
  { {0xc4c60032,0x7c294a2e,0x4429003b,0x00000000}},	//   كترو, leer, eea_,
  { {0xc1aa0161,0xceb2014e,0x04460086,0x00000000}},	//   _करेग, גים_, певн,
  { {0xa5070001,0x6f024a2f,0x44294a30,0x00000000}},	//   џета_, yroc, gea_,
  { {0xc2c6007e,0x77830062,0x2258423a,0x00000000}},	// [8c60] سياي, _плъз, _pork_,
  { {0x7c2903a8,0x69de0004,0xb77b0063,0x00000000}},	//   heer, _õpet, _לאפש,
  { {0x23660117,0x44294a31,0x0594007e,0x00000000}},	//   šoj_, bea_, _زادگ,
  { {0x22580037,0x4256007e,0x44294a32,0x00000000}},	//   _work_, _کنسر, cea_,
  { {0xbea60097,0x9e340062,0x7d034a33,0x00000000}},	//   падк, делч, erns,
  { {0x6f024a34,0xde880013,0x471b0041,0x00000000}},	//   rroc, aịn_, מונג,
  { {0xf8c90013,0x7c291500,0x629e0938,0x00000000}},	//   _bẩm_, feer, mopo,
  { {0x3f6a0055,0x7ead0025,0x61ee001f,0x00000000}},	//   _либо_, rúpa, _hebl,
  { {0x61ee12b1,0x7acd030b,0xda660044,0x00000000}},	//   _kebl, и́те, كادي,
  { {0x8fa30002,0x44294a35,0x03770063,0x00000000}},	//   _џафе, zea_, פתית_,
  { {0x7c294a36,0xe895000d,0xb69b003b,0x00000000}},	//   beer, дань, frân,
  { {0x7c2902b0,0x27ed0331,0x61ee4a37,0x00000000}},	//   ceer, úen_, _lebl,
  { {0xf1bf0024,0xb8d30053,0x629e4a38,0x00000000}},	//   čšie_, _जी_, kopo,
  { {0xcad7014e,0xddc8004c,0x629e007c,0x00000000}},	//   _צוות_, _podř, jopo,
  { {0x44294a39,0x746b4a3a,0x885902b3,0x00000000}},	//   tea_, брав_, _микс_,
  { {0x98a4005e,0xc7c70121,0xb69b3ecf,0x00000000}},	//   _пије, _эски, crân,
  { {0x44290469,0x20f8017f,0x24580b0f,0x00000000}},	// [8c70] rea_, eči_, чать_,
  { {0x44294a3b,0x61ee00a3,0x7c294a3c,0x00000000}},	//   sea_, _cebl, zeer,
  { {0x30150daf,0x51f40021,0xd1640062,0x00000000}},	//   ддер, عسكر, нъци,
  { {0x7c290122,0xf1b00044,0x00000000,0x00000000}},	//   xeer, اءك_,   ,
  { {0xef0e005a,0x61ee00cd,0x7c29017a,0x00000000}},	//   ъм_, _febl, veer,
  { {0x7c290173,0x9f4400cd,0x61ee03ac,0x00000000}},	//   weer, _demà_, _gebl,
  { {0x7c294a3d,0x3888013d,0x7d03002b,0x00000000}},	//   teer, lőre_, urns,
  { {0xccf80080,0x69d84a3e,0x60180062,0x00000000}},	//   _dvě_, _afve, _нося_,
  { {0xa0c40021,0x7c294a3f,0xb69b00dd,0x00000000}},	//   _سيكو, reer, vrân,
  { {0xe8f94a40,0x7c294a41,0xdb0c008d,0x00000000}},	//   оло_, seer, _điôx,
  { {0xb69b000c,0x67240f7e,0xac190086,0x00000000}},	//   trân, _spij, _можу_,
  { {0x200f0e53,0x61e50025,0x6d414a42,0x00000000}},	//   nggi_, hbhl, _irla,
  { {0xb69b017d,0x629e0035,0x28cf0053,0x00000000}},	//   rrân, yopo, _संवि,
  { {0x753c02f4,0x9f4f0003,0xab64000d,0x00000000}},	//   tvrz, gagé_, _явіл,
  { {0x845a41b8,0xddd8007c,0x67f8013d,0x00000000}},	//   орат_, nivš, gújí,
  { {0x6f0b00ac,0x161f0042,0x68330078,0x00000000}},	//   kugc, म्बर_, gždė,
  { {0x60ce4a43,0x60dc0d77,0x64a32b2b,0x00000000}},	// [8c80] _subm, _strm, тата,
  { {0x7cd1003d,0x200f0290,0x9f440240,0x00000000}},	//   _pārl, eggi_, _nemá_,
  { {0x629e4a44,0x20f800c2,0x61fc00c2,0x00000000}},	//   ropo, uči_, _vdrl,
  { {0x629e000f,0x61ee4a45,0x2905006d,0x00000000}},	//   sopo, _webl, irla_,
  { {0x629e4a46,0x61ee0058,0x6d414a47,0x00000000}},	//   popo, _tebl, _arla,
  { {0x200f0290,0x7bcb0290,0xa3bd0042,0x00000000}},	//   aggi_, _aggu, ेखर_,
  { {0xa06a0189,0x9f440066,0x9985004c,0x00000000}},	//   _дава_, _demá_, delů_,
  { {0x7d0a00bd,0xe0432e2f,0xdb22007e,0x00000000}},	//   rufs, _инси, نوعی,
  { {0x6d410c38,0x9f4f006c,0xfc2f0044,0x00000000}},	//   _erla, yagé_, شحي_,
  { {0x5a34005a,0xd90e007e,0xddd8007c,0x00000000}},	//   хнот, لیت_, bivš,
  { {0x388800ea,0x9f4f006c,0x00000000,0x00000000}},	//   zőre_, vagé_,   ,
  { {0x6b6601fe,0xfe0e0042,0xbb4a0044,0x00000000}},	//   _океа, _साँस_, _ولان_,
  { {0x29054a48,0x9874014b,0xfb1300de,0x00000000}},	//   arla_, тляц, _لونج,
  { {0x19940088,0x056b0002,0x7ea401a8,0x00000000}},	//   _паля, ојби_, còpt,
  { {0x44220150,0x200f0026,0x9f4f0003,0x00000000}},	//   _bbk_, yggi_, ragé_,
  { {0x290c4a49,0x78fb0063,0x2919003b,0x00000000}},	//   muda_, _ולהפ, ăsat_,
  { {0x290c0019,0xa2b508a2,0xddc80022,0x00000000}},	// [8c90] luda_, ебач, _podś,
  { {0xe3b00032,0x38b200ea,0x8c3d095a,0x00000000}},	//   شرق_, mára_, moşe,
  { {0x7cd1001c,0x69dc0026,0x290c4a4a,0x00000000}},	//   _pārm, ðrey, nuda_,
  { {0x41df0161,0x5f95071a,0xddd8007c,0x00000000}},	//   _प्रस, ниет, vivš,
  { {0x645d003b,0x926b0141,0x44394a4b,0x00000000}},	//   _iosi, _дрва_, _ias_,
  { {0x4439344e,0x99850080,0x290c4a4c,0x00000000}},	//   _has_, xelů_, kuda_,
  { {0x6da20086,0x44394a4d,0x6f19002b,0x00000000}},	//   лиша, _kas_, stwc,
  { {0x290c30fa,0x44394a4e,0xddd8007d,0x00000000}},	//   duda_, _jas_, rivš,
  { {0x998502f4,0x44394a4f,0x38b214ab,0x00000000}},	//   telů_, _mas_, jára_,
  { {0x44390814,0xc3320132,0x69ce02e2,0x00000000}},	//   _las_, נוי_, žben,
  { {0x60c9000f,0x290c0bba,0x7cd1001c,0x00000000}},	//   _kiem, guda_, _mārk,
  { {0x6a6d0024,0x60c90006,0x44394a50,0x00000000}},	//   _dúfa, _jiem, _nas_,
  { {0x60c94a51,0xb69b017d,0x38b200ea,0x00000000}},	//   _miem, arâm, gára_,
  { {0x786602dd,0x44220150,0x2905085a,0x00000000}},	//   _móvi, _sbk_, prla_,
  { {0x44393fd7,0x645d0185,0x395801f2,0x00000000}},	//   _bas_, _bosi, ørst_,
  { {0x645d04e5,0x44394a52,0x6285006f,0x00000000}},	//   _cosi, _cas_, eiho,
  { {0x44394a53,0x7c390185,0x645d4a54,0x00000000}},	// [8ca0] _das_, _mawr, _dosi,
  { {0x6aa10185,0x60c900fe,0x7c3904bf,0x00000000}},	//   nolf, _aiem, _lawr,
  { {0x26d20035,0x645d4a55,0xe853007e,0x00000000}},	//   _huyo_, _fosi, _شنید,
  { {0x645d4a56,0x61e3005b,0xc059000d,0x00000000}},	//   _gosi, ınla, міі_,
  { {0x9f340086,0x765e32a4,0x60c94a57,0x00000000}},	//   телі, _kopy, _diem,
  { {0x290c02dd,0x44204a58,0x7c3b0104,0x00000000}},	//   yuda_, lfi_, edur,
  { {0x61430062,0x4439107b,0xdd8f4a59,0x00000000}},	//   _йера, _yas_, уш_,
  { {0x6aa10139,0x7ea401a8,0x8fa643d4,0x00000000}},	//   eolf, tòps, _забе,
  { {0x442046c0,0x9b6a2bb8,0x16200082,0x00000000}},	//   ifi_, яшка_, यभार_,
  { {0x4efb0063,0x290c4a5a,0x7c3b4a5b,0x00000000}},	//   _מהמו, tuda_, adur,
  { {0x7c39001f,0x79940062,0x628b4a5c,0x00000000}},	//   _fawr, тинф, égoi,
  { {0x7c220035,0x290c4a5d,0xfd570063,0x00000000}},	//   _ubor, ruda_, _רשאי_,
  { {0x26d202dd,0x6d5c00cd,0x645d4a5e,0x00000000}},	//   _cuyo_, _àrab, _rosi,
  { {0x645d1e7a,0x44394a5f,0x7c390022,0x00000000}},	//   _sosi, _sas_, _zawr,
  { {0x44394a60,0x38b218a8,0x442018ca,0x00000000}},	//   _pas_, sára_, ffi_,
  { {0x6e3a4a61,0x68fa0137,0x97820043,0x00000000}},	//   _latb, mstd, اییه,
  { {0xf8bf0164,0x7cd1001c,0xe4ed0053,0x00000000}},	// [8cb0] mmé_, _pārk, _जबकि_,
  { {0x44394a62,0x60c94a63,0x69da4a64,0x00000000}},	//   _was_, _siem, ncte,
  { {0x60c9003d,0x645d10f0,0x44394a65,0x00000000}},	//   _piem, _tosi, _tas_,
  { {0x7afd0080,0x645d0072,0x62854a66,0x00000000}},	//   ástk, _uosi, siho,
  { {0x60c91efb,0x7052005d,0xe80a0042,0x00000000}},	//   _viem, شنوا, _वाघा_,
  { {0x7c3b002b,0x60c90022,0x68fa4a67,0x00000000}},	//   wdur, _wiem, kstd,
  { {0x60c94112,0x6e3a0185,0x765a0050,0x00000000}},	//   _tiem, _datb, ötyi,
  { {0xdd8e0032,0x69da02a4,0x20d7005b,0x00000000}},	//   توى_, ecte, _içi_,
  { {0xaed5019d,0x7c3b4a68,0x68fa4a69,0x00000000}},	//   _розш, rdur, estd,
  { {0x27f200bd,0x39450928,0x6a860003,0x00000000}},	//   _seyn_, вног, _réfè,
  { {0x26d2006d,0xdd1e027d,0x44204a6a,0x00000000}},	//   _suyo_, píše, yfi_,
  { {0xcc1401fb,0x49980085,0x7d560063,0x00000000}},	//   _مذهب, этыя_, _ביעד_,
  { {0x6c7a0047,0x2cbf004b,0x2cad01e1,0x00000000}},	//   _קאנפ, mmud_, mled_,
  { {0x2cad1c9f,0xa925000d,0x7afb00b8,0x00000000}},	//   lled_, _адкл, msut,
  { {0x29350047,0x44204a6b,0x48b60121,0x00000000}},	//   _יאַן_, tfi_, _ищит,
  { {0x64be0053,0x26d2006d,0xb4ac0042,0x00000000}},	//   ्देश, _tuyo_, गते_,
  { {0x44204916,0x2cad3ef9,0x7afb00cf,0x00000000}},	// [8cc0] rfi_, iled_, nsut,
  { {0x2cad0080,0x91e60076,0x44200290,0x00000000}},	//   hled_, тоже, sfi_,
  { {0xa3ea0376,0x6e3c00f8,0xc0aa0021,0x00000000}},	//   _одна_, _órbi, واصل_,
  { {0x7afb0d9e,0xa067005a,0x24820150,0x00000000}},	//   ksut, каха_, _umkm_,
  { {0x44fe0006,0xe3b2007e,0x24920022,0x00000000}},	//   lį_, _خرد_, mnym_,
  { {0x24920ad3,0x7afb00df,0x577b0063,0x00000000}},	//   lnym_, dsut, וטנצ,
  { {0x44fe00eb,0x6e3a006f,0x24920022,0x00000000}},	//   nį_, _vatb, onym_,
  { {0x2cad06bb,0x38604a6c,0x628b0003,0x00000000}},	//   gled_, _noir_, égov,
  { {0x38b900ea,0x501b0063,0x7afb08a9,0x00000000}},	//   nére_, _קומו, gsut,
  { {0x44fe0006,0xf8ca008b,0x2cad423a,0x00000000}},	//   kį_, _mẩu_, aled_,
  { {0x7afb0004,0x987e005b,0x2cad1360,0x00000000}},	//   asut, _açın_, bled_,
  { {0x24920051,0x3b86018e,0x38600139,0x00000000}},	//   jnym_, _илег, _coir_,
  { {0xf8bf0164,0x24920ad3,0x38b900ea,0x00000000}},	//   rmé_, dnym_, jére_,
  { {0xb7e30053,0x7f420153,0x7aed0745,0x00000000}},	//   _क्रम_, ivoq, _çata,
  { {0x7cd1001c,0x38720829,0x75880e82,0x00000000}},	//   _pāri, _flyr_, вств_,
  { {0xdd3b0047,0x481505ef,0xd4984161,0x00000000}},	//   ועלכ, _смис, вру_,
  { {0x1da90053,0x36d50054,0x38b9013d,0x00000000}},	// [8cd0] _चुनत, _щопр, gére_,
  { {0x7afd4a6d,0x291e3af6,0x7ae205b3,0x00000000}},	//   ásti, otta_, _mtot,
  { {0xdfd10021,0x24920051,0xc1a40002,0x00000000}},	//   ميا_, bnym_, ајци,
  { {0x7ae236a1,0x50b8007e,0x24920051,0x00000000}},	//   _otot, ندند_, cnym_,
  { {0x2489017d,0x7d0a1863,0x644f1014,0x00000000}},	//   miam_, erfs, _inci,
  { {0x2cad107e,0x42790047,0x24894a6e,0x00000000}},	//   wled_, _טאָג, liam_,
  { {0xc212014e,0x2cad4a6f,0x7ae24a70,0x00000000}},	//   _להם_, tled_, _atot,
  { {0x24894a71,0x39491582,0x7afb2043,0x00000000}},	//   niam_, _čas_, tsut,
  { {0x1c4202dc,0x291e4a72,0x89f50500,0x00000000}},	//   сным, etta_, лянц,
  { {0x386018b2,0x7ead0066,0x24922259,0x00000000}},	//   _soir_, kúpi, znym_,
  { {0xe73c01f7,0x7afb4a73,0x24890078,0x00000000}},	//   _küçü, ssut, kiam_,
  { {0xec6e0002,0x7c8422ce,0x7afb4a74,0x00000000}},	//   _ѓп_, _куче, psut,
  { {0x386003b2,0x2b4600cd,0x24920066,0x00000000}},	//   _voir_, _groc_, vnym_,
  { {0x644f04bc,0x24920051,0x44fe0006,0x00000000}},	//   _anci, wnym_, tį_,
  { {0x249227f1,0x248900be,0x8aa80041,0x00000000}},	//   tnym_, fiam_, _בֹקֶ,
  { {0x44fe0006,0x3896001c,0x38b900ea,0x00000000}},	//   rį_, māro_, tére_,
  { {0x44fe0006,0x249227f1,0x3f4e0014,0x00000000}},	// [8ce0] sį_, rnym_, iðuð_,
  { {0xe74713a8,0x44fe00eb,0x644f4a75,0x00000000}},	//   ções_, pį_, _enci,
  { {0x38b9000f,0x600a0071,0x24894a76,0x00000000}},	//   sére_, енем_, biam_,
  { {0x24894a77,0x38b9013d,0xf8ca008d,0x00000000}},	//   ciam_, pére_, _tẩu_,
  { {0xee86007f,0x6d4300a5,0x44324a78,0x00000000}},	//   лыко, evna, mey_,
  { {0x291e02eb,0x7e614a79,0x2c71004c,0x00000000}},	//   ytta_, _colp, _ráda_,
  { {0x60d54a7a,0x2fdf001f,0x7e614a7b,0x00000000}},	//   _guzm, _ffug_, _dolp,
  { {0x44324a7c,0x8c3d003b,0x2b464a7d,0x00000000}},	//   ney_, toşa, _proc_,
  { {0xeb970001,0x9a8a005a,0xfc630062,0x00000000}},	//   лић_, ещна_, същн,
  { {0x44320037,0x27e003b2,0xc333014e,0x00000000}},	//   hey_, _afin_, צות_,
  { {0x291e024a,0xdc54007e,0xc27b0149,0x00000000}},	//   utta_, _پراک, גריי,
  { {0x7cd1003d,0x291e362b,0x9be3014b,0x00000000}},	//   _pārv, rtta_, _лішк,
  { {0x24894a7e,0xb6070054,0x44321fb6,0x00000000}},	//   viam_, лявк, dey_,
  { {0xbb3b00b5,0x7ead4a7f,0x60c200e0,0x00000000}},	//   _רעגי, túpi, hmom,
  { {0x27e0001f,0x24894a80,0xceb3069a,0x00000000}},	//   _ffin_, tiam_, מיש_,
  { {0x44324a81,0xe4a74a82,0x998c011b,0x00000000}},	//   gey_, урго, ledů_,
  { {0x24894a83,0x2ab90003,0xf773007e,0x00000000}},	// [8cf0] riam_, sèbe_, _داغ_,
  { {0x7cd1001c,0x290c1438,0xbbd10053,0x00000000}},	//   _kārt, orda_, _हल्क,
  { {0x7e6100e8,0x6d5e00fe,0x44324a84,0x00000000}},	//   _rolp, äpal, bey_,
  { {0xd138000d,0x7e6101e1,0xfafe008f,0x00000000}},	//   ыху_, _solp, _ķīna_,
  { {0x6d480185,0x8e550086,0x8fa500e1,0x00000000}},	//   _arda, иткі, јале,
  { {0x26dc0047,0x60c20078,0x8d65342a,0x00000000}},	//   עקומ, amom, ивле,
  { {0x7e612a9d,0xed594a85,0xbdf8002a,0x00000000}},	//   _volp, той_, ارها_,
  { {0x3a2700a8,0xf0bb005d,0xbc652ceb,0x00000000}},	//   _sbnp_, _سازش_, рвик,
  { {0x290c1143,0x3f4e0026,0xaae4007e,0x00000000}},	//   erda_, rðuð_, یسیو,
  { {0x4432005b,0x3896008f,0x92a60022,0x00000000}},	//   zey_, tāro_, _gałą,
  { {0x2aab00b9,0xf9910021,0x3ea74a86,0x00000000}},	//   døbt_, تبة_, mont_,
  { {0x18a60055,0x92a60051,0xf746047e,0x00000000}},	//   рамм, _załą, аемо,
  { {0xbca4006a,0x4a750076,0xa3d90053,0x00000000}},	//   _امني, _выйт, ाशन_,
  { {0xddc1001c,0x4b7a0149,0xe7370259,0x00000000}},	//   _nolū, _באנו, јер_,
  { {0xc6c3000d,0x7ae94a87,0x60c24a88,0x00000000}},	//   ійск, lpet, ymom,
  { {0x7ae94a89,0x232a1849,0xfe79004c,0x00000000}},	//   opet, коби_, _stůl_,
  { {0x44324473,0x7ae94a8a,0x3ea74a8b,0x00000000}},	// [8d00] rey_, npet, kont_,
  { {0xf2df008b,0x38b912a2,0x7ae901f4,0x00000000}},	//   _trân_, méra_, ipet,
  { {0x7f4904d0,0x69dc0078,0x38b9006c,0x00000000}},	//   _areq, žreg, léra_,
  { {0x03a6019d,0x628b0164,0xd46a0121,0x00000000}},	//   _вимо, égor, _риме_,
  { {0x6d48007d,0x3fcb007e,0x3ea74a8c,0x00000000}},	//   _srda, ندهی_, font_,
  { {0x290c00a5,0x60c24a8d,0xadbc045b,0x00000000}},	//   yrda_, smom, налi,
  { {0x7ae94a8e,0xc5f3009a,0xd657009a,0x00000000}},	//   epet, חדו_, ייסת_,
  { {0x290c007c,0x9c380121,0x3b0d179c,0x00000000}},	//   vrda_, упит_, freq_,
  { {0x3ea7002b,0xf41f0137,0x7cd1008f,0x00000000}},	//   bont_, _omän_, _sārt,
  { {0x7cd1003d,0x3ea700dd,0x38b9006c,0x00000000}},	//   _pārt, cont_, déra_,
  { {0x672d074f,0x6d484a8f,0x88bd004c,0x00000000}},	//   _spaj, _urda, jtěc,
  { {0x245c0066,0x7cd1008f,0x998c004c,0x00000000}},	//   _tímy_, _vārt, sedů_,
  { {0xab830138,0x62800006,0xb71403d6,0x00000000}},	//   _мушк, _įmon, одящ,
  { {0xb8820ac6,0xc986007e,0xaa2c0072,0x00000000}},	//   _þína, _پشتي, äjää_,
  { {0xa5f84a90,0xae1b0053,0x28d00053,0x00000000}},	//   ресу_, प्टन_, _संचि,
  { {0x57f50001,0x65940054,0x3ea74a91,0x00000000}},	//   _упит, іату, zont_,
  { {0x672d0384,0x2bc90053,0x99870078,0x00000000}},	// [8d10] _upaj, ाइया, _fanų_,
  { {0xa4f9005d,0xa15901ce,0xe796005d,0x00000000}},	//   _مکرر_, лазу_, _چایک,
  { {0xc5f20063,0x3167003b,0x3ea7013d,0x00000000}},	//   _מדי_, ânz_, vont_,
  { {0x61ea0058,0x6aa8002b,0x75360041,0x00000000}},	//   ıfla, hodf, _פארד_,
  { {0xc8d0016a,0x3ea704a7,0x7ee4005e,0x00000000}},	//   _संघट, tont_, оцје,
  { {0x1e84012c,0xdc010042,0x0ea8012c,0x00000000}},	//   олім, ोल्ड_, акій_,
  { {0x3ea72464,0x1d060062,0xa1581cdf,0x00000000}},	//   ront_, бещи_, _кару_,
  { {0xae1c0053,0x1ee7007e,0x7ae90605,0x00000000}},	//   _नाथन_, _نوری_, tpet,
  { {0x7cd10418,0x3ea74a92,0xff990131,0x00000000}},	//   _pārs, pont_, _скај_,
  { {0xca550856,0x7ae94a93,0xfc3f0114,0x00000000}},	//   стињ, rpet, ží_,
  { {0x7ae94a94,0x38b20066,0x88ca0456,0x00000000}},	//   spet, lári_, ллов_,
  { {0x385a0086,0x7ae9121f,0x442b4a95,0x00000000}},	//   урою_, ppet, _nbc_,
  { {0x76890006,0x38b23887,0x3b0904f2,0x00000000}},	//   ažym, nári_, _село_,
  { {0x442b4a96,0x78ad0130,0xda340085,0x00000000}},	//   _abc_, _ekav, _мечы,
  { {0xceb200ff,0x38b20066,0x86990330,0x00000000}},	//   פיל_, hári_, ртят_,
  { {0x28d00235,0x475a005a,0x38b21416,0x00000000}},	//   _सूचि, _броя_, kári_,
  { {0xe29a0002,0x38b20066,0x04570044,0x00000000}},	// [8d20] гаа_, jári_, حلقة_,
  { {0x6f041a77,0x21a601ce,0x959601ce,0x00000000}},	//   šick, бизм, _грмљ,
  { {0x64ac00bd,0x64a6000d,0x6026046f,0x00000000}},	//   ußis, _гана, йджа,
  { {0x10160044,0x68f6056c,0xb7fa0082,0x00000000}},	//   إباد, _łydk, ्णिम_,
  { {0xb4c40161,0x14b50053,0xbe8a005e,0x00000000}},	//   एगी_, ंतरण, лске_,
  { {0x7c2b00bd,0x66c00137,0xbea333e3,0x00000000}},	//   _abgr, sökf, пачк,
  { {0x2167093d,0x2d980066,0x61fe004b,0x00000000}},	//   _лири_, _žreb_, mapl,
  { {0xfd0f0021,0xd1970063,0x61fe4a97,0x00000000}},	//   رجى_, _הכלי_, lapl,
  { {0x7cd1001c,0xcb070021,0x7ead0066,0x00000000}},	//   _pārr, ميين_, túpt,
  { {0x9e650032,0x527b00b5,0xc333014e,0x00000000}},	//   _والن, ָנטא, לוח_,
  { {0x7afd4a98,0xacea0002,0x6f024a99,0x00000000}},	//   ástr, _смеа_, lsoc,
  { {0xc19b0047,0x2db70047,0x76890078,0x00000000}},	//   רשטי, _פלאן_, ržym,
  { {0x61fe4a9a,0x6f024a9b,0x6ac3007e,0x00000000}},	//   kapl, nsoc, تقیم,
  { {0x3e79006c,0xeb070044,0x00000000,0x00000000}},	//   _tète_, _اقوى_,   ,
  { {0xe5c4005a,0x7d1c10ed,0x6f04004c,0x00000000}},	//   зсто, _årsd, šich,
  { {0xb4b30235,0x38b90164,0x644400a4,0x00000000}},	//   टते_, méro_, gdii,
  { {0x228f0022,0xf2df0013,0x8afd004c,0x00000000}},	// [8d30] eżka_, _trâm_, tyři,
  { {0x51f802dc,0x3eb9008f,0x6f0200a5,0x00000000}},	//   йную_, _īsto_, dsoc,
  { {0x3e6b00d1,0x6d4e0078,0x55594a9c,0x00000000}},	//   _møtt_, _šban, _таня_,
  { {0xdd000080,0x61fe00a4,0x38b23887,0x00000000}},	//   štěn, aapl, tári_,
  { {0x7ce70058,0x44294a9d,0xaf04012c,0x00000000}},	//   _kırg, mfa_, зпіл,
  { {0x2c1b0235,0x999e000f,0x63bd001c,0x00000000}},	//   _याहू_, hető_, _izsn,
  { {0x38b20024,0x6cc51862,0xad240044,0x00000000}},	//   sári_, ойка, كريو,
  { {0x4429001f,0x26d3017d,0xa3d90053,0x00000000}},	//   nfa_, _lixo_, ाशि_,
  { {0x290a000f,0x44294a9e,0x999e013d,0x00000000}},	//   ában_, ifa_, dető_,
  { {0x0905019d,0x4429001f,0xd358009a,0x00000000}},	//   опон, hfa_, משחק_,
  { {0xa3d9024c,0xdd9b0b62,0x3896001c,0x00000000}},	//   ाशा_, _сша_, lāri_,
  { {0xc5e90ee1,0x61fe027d,0x49980121,0x00000000}},	//   _יד_, zapl, стья_,
  { {0x27ff007a,0xdd1e0024,0x4429001f,0x00000000}},	//   ðuna_, _víťa, dfa_,
  { {0x44294a9f,0x7c294aa0,0x0ac70e82,0x00000000}},	//   efa_, lfer, _ущем,
  { {0x291100ea,0x61fe005b,0x7c29004d,0x00000000}},	//   ázad_, vapl, ofer,
  { {0x26d3017d,0x7c294aa1,0x4429002b,0x00000000}},	//   _eixo_, nfer, gfa_,
  { {0x61fe01f7,0x26d3017d,0xe1fa13e1,0x00000000}},	// [8d40] tapl, _fixo_, ига_,
  { {0x44290bad,0x7ce70058,0xb1b6005e,0x00000000}},	//   afa_, _kırd, ољећ,
  { {0x27e50051,0x27244aa2,0x6f02002b,0x00000000}},	//   ślne_, lön_, wsoc,
  { {0x7c290122,0x61fe01f7,0xf3ff008b,0x00000000}},	//   jfer, sapl, _hoãn_,
  { {0x2724024a,0xd00f007e,0x289b0047,0x00000000}},	//   nön_, ئله_, סינא,
  { {0x999e00ea,0x25ad003b,0xf7730063,0x00000000}},	//   zető_, şele_, וקד_,
  { {0xafe60086,0x61fc0250,0x7c294aa3,0x00000000}},	//   _мовл, _ierl, ffer,
  { {0x61fc4aa4,0x8c43005e,0x672604aa,0x00000000}},	//   _herl, деће, ktkj,
  { {0x999e00ea,0x27240ee9,0x7a3f0078,0x00000000}},	//   vető_, jön_, kštė,
  { {0x61fc0089,0x76890006,0x60dc0792,0x00000000}},	//   _jerl, ržyk, _kurm,
  { {0x44294aa5,0x38b2004c,0x999e013d,0x00000000}},	//   yfa_, háru_, tető_,
  { {0xf8b00021,0xab2a0336,0x60dc4aa6,0x00000000}},	//   َةَ_, _вода_, _murm,
  { {0xa09b0047,0xaa4607b0,0xd90e007e,0x00000000}},	//   שיכט, _медл, ریک_,
  { {0x764a0046,0xf98a005d,0xee2e15ce,0x00000000}},	//   _ófyl, _پخته_, енi_,
  { {0x60dc4aa7,0xf3ff0013,0x45d420c6,0x00000000}},	//   _nurm, _doãn_, дорс,
  { {0x57f50121,0x656800a5,0xd5b80d80,0x00000000}},	//   _эпит, ädha, юся_,
  { {0x61fc4aa8,0x44290742,0x6695005e,0x00000000}},	// [8d50] _berl, rfa_, _наиђ,
  { {0x66c0024a,0x44294aa9,0x656e00ea,0x00000000}},	//   töke, sfa_, ínhá,
  { {0x61fc4aaa,0x2fd90021,0x60dc003b,0x00000000}},	//   _derl, مواد_, _curm,
  { {0x61fc0229,0x60dc4aab,0xa439005e,0x00000000}},	//   _eerl, _durm, _узму_,
  { {0x61fc0026,0x66c040a3,0x9f400026,0x00000000}},	//   _ferl, söke, úið_,
  { {0x8c3d003b,0x61fc4aac,0x38690130,0x00000000}},	//   moşi, _gerl, _loar_,
  { {0x7c294aad,0xf3ff0016,0xc69400b5,0x00000000}},	//   tfer, _joão_, ואס_,
  { {0x61fc004d,0x27240072,0x61e52b09,0x00000000}},	//   _zerl, yön_, lchl,
  { {0x7c290ac6,0x5f94019d,0x61fc01f7,0x00000000}},	//   rfer, _житт, _yerl,
  { {0x7c294aae,0x62800006,0x61e54aaf,0x00000000}},	//   sfer, _įmok, nchl,
  { {0x7c291d30,0x386900e5,0xf2d40063,0x00000000}},	//   pfer, _boar_, ועץ_,
  { {0x6d414ab0,0x7e680a63,0x88bd0080,0x00000000}},	//   _isla, _zodp, stěn,
  { {0x38690529,0x2cad006f,0x31b80053,0x00000000}},	//   _doar_, moed_, _अर्ध,
  { {0x76450150,0xe7370d34,0x2cad0229,0x00000000}},	//   _cahy, џер_, loed_,
  { {0x27243928,0xdeba009a,0x65c34ab1,0x00000000}},	//   sön_, ממשל, ебра,
  { {0x61fc4ab2,0x07a601dd,0x2cad002b,0x00000000}},	//   _serl, _найн, noed_,
  { {0x61fc0397,0xe61a0635,0x60dc4ab3,0x00000000}},	// [8d60] _perl, _лдп_, _surm,
  { {0x320100a4,0x2cad0849,0x2e2f0058,0x00000000}},	//   gahy_, hoed_, nıfı_,
  { {0x2c710025,0xb5f70063,0x85f70063,0x00000000}},	//   _tádh_, _מציג_, _מציע_,
  { {0xb4d80053,0x76450114,0x61fc01e1,0x00000000}},	//   ादी_, _zahy, _werl,
  { {0x61fc014f,0x442206aa,0x76452e25,0x00000000}},	//   _terl, _ick_, _yahy,
  { {0x64464ab4,0x29054ab5,0x9f530085,0x00000000}},	//   _haki, ksla_, эвіч,
  { {0xdb07108f,0x64464ab6,0x3896001c,0x00000000}},	//   _člán, _kaki, lāru_,
  { {0xc19b014e,0x64460e5d,0x2cad4ab7,0x00000000}},	//   _השלי, _jaki, goed_,
  { {0x8b230001,0x64460465,0x6d410530,0x00000000}},	//   едње, _maki, _esla,
  { {0x644621ca,0x38b2013d,0x49740ace,0x00000000}},	//   _laki, zárt_, длос,
  { {0x44220137,0x00000000,0x00000000,0x00000000}},	//   _ock_,   ,   ,
  { {0x64464ab8,0x63a20051,0x3eae00ca,0x00000000}},	//   _naki, żony, loft_,
  { {0x99690024,0x3869017d,0x61e54ab9,0x00000000}},	//   hŕňa_, _voar_, ychl,
  { {0x6d4100e8,0x2c710080,0x44224aba,0x00000000}},	//   _ysla, _rádi_, _ack_,
  { {0x64464abb,0x38b2013d,0x764701e1,0x00000000}},	//   _baki, tárt_, rdjy,
  { {0xa8a40088,0x6d5700b5,0x7645014f,0x00000000}},	//   _прык, הילף_, _wahy,
  { {0x32010080,0x64464abc,0x27e9001f,0x00000000}},	// [8d70] tahy_, _daki, _ifan_,
  { {0xdbf2004c,0x8c3d00dd,0x442240c9,0x00000000}},	//   dříz, roşi, _eck_,
  { {0x7c224abd,0x2509006a,0x442200b9,0x00000000}},	//   _ocor, _برخی_, _fck_,
  { {0x61e50199,0xdfd10067,0x628e4abe,0x00000000}},	//   schl, نيا_, _embo,
  { {0x2cad006f,0x00000000,0x00000000,0x00000000}},	//   voed_,   ,   ,
  { {0x171c014e,0x6d412a76,0x7c224abf,0x00000000}},	//   מודע, _psla, _acor,
  { {0x27e9007a,0xdca5005a,0x3cc906f0,0x00000000}},	//   _ofan_, маки, олко_,
  { {0xe81f0053,0x9872001c,0x14bf0053,0x00000000}},	//   _भाषा_, kšā_, ्षिण,
  { {0x200d0339,0x1c42026c,0x2cad00f1,0x00000000}},	//   _idei_, тным, roed_,
  { {0x89f4000d,0xddc1003b,0x66c00072,0x00000000}},	//   няюц, _colţ, köka,
  { {0x3896001c,0x6d410078,0x2cad4ac0,0x00000000}},	//   kārt_, _usla, poed_,
  { {0x29050627,0x7d1c02ab,0x16200161,0x00000000}},	//   rsla_, _årsa, _बाहर_,
  { {0x7c3b0164,0x9872001c,0x29050e04,0x00000000}},	//   meur, gšā_, ssla_,
  { {0x6446014f,0x7c3b4ac1,0x38b2013d,0x00000000}},	//   _saki, leur, társ_,
  { {0xceb20a7a,0x644611a0,0x186a09c2,0x00000000}},	//   דים_, _paki, _маки_,
  { {0x7c3b2ba0,0x88bd004c,0x3896008f,0x00000000}},	//   neur, htěj, tāru_,
  { {0x64464ac2,0x232714db,0x55f6030b,0x00000000}},	// [8d80] _vaki, моти_, _очну,
  { {0x24801880,0x64462738,0xdce3008f,0x00000000}},	//   shim_, _waki, gznī,
  { {0x7c3b0a53,0x54c6042c,0x0594007e,0x00000000}},	//   keur, _обоб, _سادگ,
  { {0x7c3b4ac3,0xd61a005d,0x6e2d013d,0x00000000}},	//   jeur, _اتکا_, őabl,
  { {0xde58000d,0x9c7c007d,0x3896001c,0x00000000}},	//   залі_, _juče, lārs_,
  { {0x7c224ac4,0x628e0014,0x44204ac5,0x00000000}},	//   _scor, _umbo, lgi_,
  { {0x44204ac6,0x61430121,0xa2ab0053,0x00000000}},	//   ogi_, _иера, जकर्,
  { {0x3eae4ac7,0x44204ac8,0x7c3b4ac9,0x00000000}},	//   soft_, ngi_, geur,
  { {0x44204aca,0xcf46365e,0xf2df00dd,0x00000000}},	//   igi_, _юнай, _frâu_,
  { {0x66c000fe,0xf2df003b,0x00000000,0x00000000}},	//   yöka, _grâu_,   ,
  { {0x7c3b04c6,0x1958000d,0x7c470137,0x00000000}},	//   beur, чаны_, örrä,
  { {0x7c3b12a2,0x3eb9008f,0x00000000,0x00000000}},	//   ceur, _īsti_,   ,
  { {0xb69b006c,0x6483004b,0xeaaf005d,0x00000000}},	//   ssâm, _hõig, طعی_,
  { {0x64830004,0xddda0080,0xf98f006a,0x00000000}},	//   _kõig, _potř, ابی_,
  { {0x7ce70058,0xd8bb0044,0x3ea20046,0x00000000}},	//   _kıra, _ودعا_, _íktu_,
  { {0x44204acb,0x261b0053,0x98c70085,0x00000000}},	//   ggi_, _बाकी_, _ўскл,
  { {0x66c001e3,0x64830004,0x43940d34,0x00000000}},	// [8d90] söka, _lõig, ватс,
  { {0x44204acc,0x0738007e,0xa3ce0042,0x00000000}},	//   agi_, _آسيب_, षेध_,
  { {0x6f09007d,0x7c3b12fe,0xb015005e,0x00000000}},	//   _svec, yeur, емељ,
  { {0x8c3d000c,0xf8ca0013,0x7c3b006c,0x00000000}},	//   noşt, _bẩy_, xeur,
  { {0xb4bd0161,0x7c3b109c,0x38a40058,0x00000000}},	//   ेगी_, veur, nıra_,
  { {0x171c0041,0xfe71005d,0xc2c50044,0x00000000}},	//   קווע, دگر_, _سيزي,
  { {0x7ce701f7,0x7c3b18b9,0xddc14acd,0x00000000}},	//   _bıra, teur, _bolš,
  { {0x88bd0080,0x7c94000d,0x0b4502b1,0x00000000}},	//   stěj, крыц, енин,
  { {0x7c3b02a5,0xf2df0013,0x6d5e12b8,0x00000000}},	//   reur, _trâu_, äpar,
  { {0x7d2800c7,0xdb0e0025,0x2c710066,0x00000000}},	//   örsö, ádál, _rádu_,
  { {0x9c7c0117,0xa3b60053,0x2d9a0024,0x00000000}},	//   _suče, _चुन_, ĺpec_,
  { {0x38a40058,0x2c7101c8,0x3896008f,0x00000000}},	//   fıra_, _pádu_, vārs_,
  { {0xd5b8001c,0xf8ca0013,0x442008af,0x00000000}},	//   ļām_, _xẩy_, vgi_,
  { {0x9c7c007d,0x3896008f,0xe9a501ce,0x00000000}},	//   _vuče, tārs_, _палп,
  { {0x44204ace,0x6aa6013d,0x38cb005d,0x00000000}},	//   tgi_, ékfe, تایی_,
  { {0x69c3017f,0x44204acf,0x044301f6,0x00000000}},	//   _izne, ugi_, лесн,
  { {0xb89b0063,0x44204ad0,0x2216058f,0x00000000}},	// [8da0] _מבקש, rgi_, ефер,
  { {0x66290024,0x63790086,0x44204ad1,0x00000000}},	//   ľský, єстр_, sgi_,
  { {0x44200031,0x66c0024a,0x7cd1008f,0x00000000}},	//   pgi_, löko, _dārz,
  { {0x44fe0080,0xc2090063,0xb77a016e,0x00000000}},	//   mů_, מה_, ּאַש,
  { {0x44fe0080,0xddc80051,0xd3b90054,0x00000000}},	//   lů_, łoże, _журі_,
  { {0x7ce701f7,0x179b0041,0x2ce8005d,0x00000000}},	//   _sıra, הינב, وظبی_,
  { {0x44fe0080,0xc5f30063,0x765a0072,0x00000000}},	//   nů_, נדה_, ötyy,
  { {0x26da0198,0xf8ca008b,0x6483004b,0x00000000}},	//   _lipo_, _tẩy_, _võig,
  { {0x44fe0080,0x4fa30071,0x343b0047,0x00000000}},	//   hů_, _битв, לײקע,
  { {0xdee3071a,0x44fe0080,0xd90e007e,0x00000000}},	//   _софи, ků_, میت_,
  { {0x2d870045,0x44fe0080,0x66c00137,0x00000000}},	//   czne_, jů_, tökn,
  { {0x44fe0080,0x6fd6005b,0x38a4005b,0x00000000}},	//   dů_, _gücü, tıra_,
  { {0x66c000a5,0xc6a731ab,0x6cd30044,0x00000000}},	//   rökn, ерви, _إقنا,
  { {0x66c000c7,0x44fe004c,0xd6d8263d,0x00000000}},	//   sökn, fů_, етс_,
  { {0x44fe0080,0x38a40058,0x8c3d00dd,0x00000000}},	//   gů_, sıra_, poşt,
  { {0xf9690086,0x7ae2003e,0x1957016e,0x00000000}},	//   _юрій_, _kuot, _טבול_,
  { {0x7cd1003d,0x48140076,0xbec7008f,0x00000000}},	// [8db0] _pārz, _смыс, lnīš,
  { {0x7ae2024a,0x64830004,0x979c0063,0x00000000}},	//   _muot, _sõid, _משחק,
  { {0x7ae2024a,0xf1a74ad2,0x291e4ad3,0x00000000}},	//   _luot, хран, nuta_,
  { {0xc0780086,0xf8b30042,0x66070195,0x00000000}},	//   нсії_, ीतिय, lajk,
  { {0x7ae200eb,0x64830019,0x78bd01f2,0x00000000}},	//   _nuot, _võid, ilsv,
  { {0x88bd0080,0x644d4ad4,0x291e4ad5,0x00000000}},	//   stěh, ldai, kuta_,
  { {0xa3d90053,0x62850139,0xd658089e,0x00000000}},	//   ाशक_, mhho, תיות_,
  { {0x291e4ad6,0x2d870051,0x4c35000d,0x00000000}},	//   duta_, rzne_, тэкт,
  { {0x7aa5005a,0x7ae20118,0x44fe0080,0x00000000}},	//   кииз, _cuot, zů_,
  { {0x644d1761,0x291e10ca,0xc3320063,0x00000000}},	//   hdai, futa_, סוי_,
  { {0x60db0035,0x60c94ad7,0x99d4013c,0x00000000}},	//   _kium, _khem, лююч,
  { {0x44fe0080,0x66c00072,0x9b92007e,0x00000000}},	//   vů_, töko, الیت,
  { {0x644d001f,0x291e4ad8,0x6ec50082,0x00000000}},	//   ddai, auta_, ितपु,
  { {0x44fe0080,0x09e233df,0x645d4ad9,0x00000000}},	//   tů_, _кошн, _ansi,
  { {0xceb211b4,0x291e09c7,0x69c31235,0x00000000}},	//   ייך_, cuta_, _uzne,
  { {0x44fe0080,0x6b960078,0x9c7c00a8,0x00000000}},	//   rů_, _žygi, _kuča,
  { {0x44fe0080,0x26da0fbe,0xb60600c2,0x00000000}},	// [8dc0] sů_, _tipo_, tušč,
  { {0x645d4ada,0x6f19001f,0x44fe0080,0x00000000}},	//   _ensi, drwc, pů_,
  { {0x44e7008b,0xb6064adb,0x2a6a013d,0x00000000}},	//   _gõ_, rušč, öbbi_,
  { {0x68e32b2e,0x629703ea,0x60db4adc,0x00000000}},	//   _mund, aixo, _cium,
  { {0xb60600c3,0x20060025,0x60db2056,0x00000000}},	//   pušč, raoi_, _dium,
  { {0x291e0009,0x60c900bd,0x52761736,0x00000000}},	//   yuta_, _ehem, _руму,
  { {0x60db051e,0x6026005a,0x27e04add,0x00000000}},	//   _fium, _идва, _ogin_,
  { {0x291e4ade,0x7ce7005b,0x7ae24adf,0x00000000}},	//   vuta_, _tırn, _puot,
  { {0xcb070032,0xeb97005e,0x38b9013d,0x00000000}},	//   نيين_, кић_, iért_,
  { {0xd8f80086,0x7c2d0137,0x7ae22139,0x00000000}},	//   нної_, _öarn, _vuot,
  { {0x644d0185,0x38b9000f,0xc9864ae0,0x00000000}},	//   ydai, kért_, тупи,
  { {0x7ae2024a,0x44e7001b,0xf1b30063,0x00000000}},	//   _tuot, _rõ_, יסת_,
  { {0x6b890045,0x6d5c06b2,0x291e0763,0x00000000}},	//   czeg, _árab, suta_,
  { {0x38b90024,0xd954013a,0x27e04ae1,0x00000000}},	//   véru_, _منتخ, _egin_,
  { {0x68e34ae2,0x44321926,0x66074ae3,0x00000000}},	//   _gund, ffy_, rajk,
  { {0xed10001b,0x44e7008b,0x38b9013d,0x00000000}},	//   _đổi_, _võ_, gért_,
  { {0x644d018d,0x92590002,0x722b0121,0x00000000}},	// [8dd0] rdai, наат_, дцев_,
  { {0xf8bf3525,0x644d1098,0x60c94ae4,0x00000000}},	//   llé_, sdai, _shem,
  { {0x60db429f,0x64830019,0x6d484ae5,0x00000000}},	//   _pium, _võib, _nsda,
  { {0x332000cd,0xcfe901fb,0x645d4ae6,0x00000000}},	//   buix_, رفته_, _unsi,
  { {0x20044ae7,0xe8e00013,0x7d1c00b8,0x00000000}},	//   _demi_, _ướt_, _årsj,
  { {0x9c7c007d,0x6f19002b,0x7ce70058,0x00000000}},	//   _ruča, rrwc, _fırl,
  { {0xcd350021,0x660500c2,0x60c92e38,0x00000000}},	//   ارتب, _mehk, _them,
  { {0x68e304b1,0x6b8904a1,0x6605004c,0x00000000}},	//   _rund, tzeg, _lehk,
  { {0x09e50856,0x68e303ef,0x9f4f00cd,0x00000000}},	//   лопн, _sund, ragó_,
  { {0x38b900ea,0x20044ae8,0x6b894ae9,0x00000000}},	//   zért_, _zemi_, rzeg,
  { {0x7ce7005b,0x6b894aea,0x7c870121,0x00000000}},	//   _kırm, szeg, _иуде,
  { {0xe8f6000d,0x68e34aeb,0xf8bf0003,0x00000000}},	//   ылю_, _vund, glé_,
  { {0x68e300bd,0x66c00137,0x9cd60063,0x00000000}},	//   _wund, sökm, _עונה_,
  { {0x68e34aec,0xcb120047,0x764e01e1,0x00000000}},	//   _tund, _פלו_, udby,
  { {0x68e323c2,0x66c00026,0xf8bf0153,0x00000000}},	//   _uund, lökk, blé_,
  { {0xf8bf006c,0x9c7c10f5,0xa976009d,0x00000000}},	//   clé_, _lučn, _תתקנ_,
  { {0x7413007e,0x20044aed,0x7ce70058,0x00000000}},	// [8de0] صولا, _remi_, _sırl,
  { {0x38b900ea,0x443200e5,0xe6460002,0x00000000}},	//   sért_, sfy_, _сеоп,
  { {0xda7a0047,0x7a7a0047,0x7f49006d,0x00000000}},	//   ענער, ערעס, _aseq,
  { {0x442404aa,0x50ba01fb,0xa3f50085,0x00000000}},	//   _øm_, رداد_, _вярш,
  { {0x5376005e,0x3ae9008d,0x9c7c0130,0x00000000}},	//   _сунђ, _núp_, _bučn,
  { {0x0ef9000d,0x91e31527,0x69dc008f,0x00000000}},	//   тэцы_, _горе, žrei,
  { {0x20044aee,0x11d5013c,0xdff60085,0x00000000}},	//   _temi_, _вітр, _бязь,
  { {0x5b14065b,0x7b140062,0x3ae90013,0x00000000}},	//   амит, адих, _búp_,
  { {0x3ae90013,0x543b0047,0x8c430141,0x00000000}},	//   _cúp_, געפא, сење,
  { {0xfce61138,0xdb250043,0x00000000,0x00000000}},	//   _божо, گویی,   ,
  { {0x02b70047,0x3ce504aa,0xdea3007e,0x00000000}},	//   רליך_, _gulv_, _دیوی,
  { {0x2cbf000c,0xf8bf0003,0xd00604a0,0x00000000}},	//   clud_, ulé_, غل_,
  { {0xf8bf0164,0x6483004b,0xec35005d,0x00000000}},	//   rlé_, _nõia, _خونگ,
  { {0xe45f0137,0xf8bf0114,0x3ea00139,0x00000000}},	//   _snö_, slé_, éith_,
  { {0x6672007e,0x6e350058,0xf8bf29be,0x00000000}},	//   تگير, _özbe, plé_,
  { {0x7793005d,0xd4983f17,0x93f50085,0x00000000}},	//   _هیجا, гру_, рпац,
  { {0xd5b10053,0x6605004b,0xe796005d,0x00000000}},	// [8df0] _आँकड़, _tehk, _پايک,
  { {0x6683005d,0xa1594448,0x63bd011b,0x00000000}},	//   _ایسل, казу_, _vysn,
  { {0x81c70121,0x9c7c226f,0x32b80021,0x00000000}},	//   ущае, _ručn, ادقة_,
  { {0xb4fa00b5,0x9099005a,0x66c00072,0x00000000}},	//   _שפרי, ъвет_, yökk,
  { {0x24890150,0x4f580054,0x442b4aef,0x00000000}},	//   mham_, лицю_, _icc_,
  { {0x644f048e,0x24894af0,0x2911013d,0x00000000}},	//   _haci, lham_, ázak_,
  { {0x44390222,0x644f4af1,0x7ce70058,0x00000000}},	//   _kbs_, _kaci, _tırm,
  { {0xaf34006a,0x24894af2,0x644f0e1f,0x00000000}},	//   _گرفت, nham_, _jaci,
  { {0xbc480001,0x248900a4,0xfd4c008b,0x00000000}},	//   учје_, iham_, _khiể,
  { {0x644f0268,0x7f840021,0x442b4af3,0x00000000}},	//   _laci, _الكن, _lcc_,
  { {0x44392118,0x66c000ea,0xf8664af4,0x00000000}},	//   _obs_, sökk, авно,
  { {0x9c82027d,0x644f4af5,0x2bd20042,0x00000000}},	//   účto, _naci, देहा,
  { {0x661a0022,0x24894af6,0xa088009a,0x00000000}},	//   ótko, dham_, רְתִ,
  { {0x4439103b,0x442b3183,0xfd4c008d,0x00000000}},	//   _abs_, _acc_, _nhiể,
  { {0xa507065b,0x644f4af7,0x442b4af8,0x00000000}},	//   иера_, _baci, _bcc_,
  { {0x38601e44,0x3d080053,0x03a60121,0x00000000}},	//   _unir_, _सबसे_, аибо,
  { {0xb6a60086,0xa2061b8b,0x020625d5,0x00000000}},	// [8e00] _випл, ипад, изан,
  { {0x88bd0080,0x442b051e,0xc1560001,0x00000000}},	//   stět, _ecc_, ињењ,
  { {0x24894af9,0x644f0725,0x442b4afa,0x00000000}},	//   bham_, _faci, _fcc_,
  { {0x44390089,0xd0100021,0xc0590085,0x00000000}},	//   _gbs_, سلت_, ліі_,
  { {0x8fa60121,0x91e60074,0x78a60014,0x00000000}},	//   шаде, _воге, inkv,
  { {0x644f4afb,0x24800051,0x97570063,0x00000000}},	//   _zaci, lkim_, יינו_,
  { {0x644f006d,0x27f2001f,0x3f801dd9,0x00000000}},	//   _yaci, _ofyn_, šiu_,
  { {0xbf6b004c,0x3ea0013d,0x24800534,0x00000000}},	//   _šíři, őit_, nkim_,
  { {0x7c2f00cd,0x9e661dd0,0xfb860085,0x00000000}},	//   òcra, _квад, рыйн,
  { {0x60c24afc,0xc33301f9,0xba180021,0x00000000}},	//   llom, קות_, ديدا_,
  { {0xfc66005a,0x24804afd,0xc27b07e9,0x00000000}},	//   _вълн, kkim_, דריי,
  { {0x248900e5,0x6d5a0072,0xdd7b0041,0x00000000}},	//   xham_, _irta, _שטאל,
  { {0x07a40088,0x2bd20042,0x644f1950,0x00000000}},	//   жаўн, देशा, _raci,
  { {0x644f4225,0x44394afe,0xda6600f2,0x00000000}},	//   _saci, _sbs_, _خاصي,
  { {0x442b4731,0x443945b3,0x2419066e,0x00000000}},	//   _pcc_, _pbs_, ловы_,
  { {0x6d5a007d,0x20e80058,0x0464005e,0x00000000}},	//   _mrta, _eğik_, отум,
  { {0x228400c7,0x248918fe,0x644f1554,0x00000000}},	// [8e10] _söka_, rham_, _vaci,
  { {0x6d5a01f7,0x60c2014f,0x24894aff,0x00000000}},	//   _orta, elom, sham_,
  { {0x75d5007e,0x26c300c2,0xd5bb0002,0x00000000}},	//   _ديدا, mljo_, _јсп_,
  { {0x291e0026,0x248014e2,0x0018000d,0x00000000}},	//   irta_, ckim_, аўшы_,
  { {0x6d5a4b00,0xfd4c008b,0x26c300c2,0x00000000}},	//   _arta, _thiể, oljo_,
  { {0x7c390185,0x52850021,0xc0b90080,0x00000000}},	//   _sbwr, _السك, _žádá,
  { {0x6d5a007d,0x44294b01,0x60c202e0,0x00000000}},	//   _crta, oga_, blom,
  { {0x44294b02,0xfc310021,0x8c4904d6,0x00000000}},	//   nga_, سحب_, упив_,
  { {0x6d5c007a,0x66c00137,0x291e4b03,0x00000000}},	//   _áran, söki, erta_,
  { {0xdb06013d,0x8e740021,0xe8e1008d,0x00000000}},	//   émáj, _والض, ướp_,
  { {0xd9450c07,0x442900a8,0x29110566,0x00000000}},	//   щени, kga_, éza_,
  { {0x3cd50121,0x26c300a8,0x913a0041,0x00000000}},	//   _ужес, eljo_, נערק,
  { {0x44290e04,0x291e4b04,0x628700a5,0x00000000}},	//   dga_, arta_, _oljo,
  { {0x7afb4b05,0x7bcb4b06,0x7c294b07,0x00000000}},	//   mput, _izgu, lger,
  { {0xe8f50067,0xb60600c2,0x24801aea,0x00000000}},	//   _استخ, vršč, tkim_,
  { {0xdb230026,0x44294b08,0x4d7a0047,0x00000000}},	//   _þróu, gga_, אָמא,
  { {0x7c294b09,0x38cb007e,0x2480055c,0x00000000}},	// [8e20] iger, _حاوی_, rkim_,
  { {0x7afb1606,0x7c29004d,0x44294b0a,0x00000000}},	//   iput, hger, aga_,
  { {0xd6db0063,0x27ed01b3,0xc6930063,0x00000000}},	//   _תחיל, žene_, _מאז_,
  { {0x7c29006f,0x3ea7004d,0x63a92b4e,0x00000000}},	//   jger, ennt_, _žene,
  { {0x60c22791,0x7c29244c,0xd6d7005d,0x00000000}},	//   rlom, dger, _خویش_,
  { {0x44ee001b,0x60c20072,0x7c294b0b,0x00000000}},	//   _ký_, slom, eger,
  { {0x7c29050c,0x7afb165d,0x629e308a,0x00000000}},	//   fger, eput, mipo,
  { {0x629e4b0c,0x7c294b0d,0x7ead0066,0x00000000}},	//   lipo, gger, tĺpc,
  { {0x44ee001b,0x7afb00a4,0x320a0024,0x00000000}},	//   _lý_, gput, _keby_,
  { {0x33770063,0x629e4b0e,0x7c291bb6,0x00000000}},	//   צעים_, nipo, ager,
  { {0x44ee007a,0x6d5a4b0f,0x44291091,0x00000000}},	//   _ný_, _urta, yga_,
  { {0xc1730063,0xa3d80042,0x00000000,0x00000000}},	//   לחת_, ाधा_,   ,
  { {0xeb970076,0xa09b00b5,0xeb33007e,0x00000000}},	//   _лиц_, ריכט, _فروخ,
  { {0x291e00c2,0x44ee0026,0x8bd70063,0x00000000}},	//   prta_, _bý_, _הודו_,
  { {0x629e4b10,0x34790085,0x32cf0075,0x00000000}},	//   dipo, абвэ_, nüye_,
  { {0xcd020045,0x98a40001,0x18a40fe2,0x00000000}},	//   mość_, _није, _најм,
  { {0x660e0e53,0x44292f9f,0x24580076,0x00000000}},	// [8e30] babk, rga_, щать_,
  { {0x5b7b00b5,0x44294b11,0xa5f9005e,0x00000000}},	//   ארמא, sga_, _њену_,
  { {0xcd020045,0x442900d1,0x7ce70058,0x00000000}},	//   ność_, pga_, _hırv,
  { {0xf8c90053,0x657a092e,0x859a009d,0x00000000}},	//   रतिय, äthe, _כשתו,
  { {0x629e004b,0x3f69289a,0x1eea005d,0x00000000}},	//   bipo, рило_, لونی_,
  { {0xcd020045,0xee380086,0x629e017d,0x00000000}},	//   kość_, йні_, cipo,
  { {0x265a00b5,0x7c294b12,0x6483004b,0x00000000}},	//   יכװא, tger, _lõim,
  { {0x7afb4b13,0x7c294b14,0xa2b90053,0x00000000}},	//   tput, uger, ्तव्,
  { {0x68ea004d,0x200f004b,0x7c294b15,0x00000000}},	//   _aufd, magi_, rger,
  { {0x827600b5,0x7afb014f,0x78ad0ff2,0x00000000}},	//   ַערע_, rput, _ajav,
  { {0x9f46007a,0xddab0076,0xcd020051,0x00000000}},	//   lboð_, _стал_, gość_,
  { {0x200f0019,0xfd100021,0x7afb17cb,0x00000000}},	//   nagi_, _أجل_, pput,
  { {0x61c60235,0xc1c60235,0xe73a0001,0x00000000}},	//   _वर्ष, _वर्ग, јег_,
  { {0x200f4b16,0x66c000fe,0x96ba2469,0x00000000}},	//   hagi_, yöku, руму_,
  { {0x7d1c334a,0x200f0019,0x7aeb0026,0x00000000}},	//   _årst, kagi_, _hugt,
  { {0x08c3005a,0x07a60086,0x6d4112fe,0x00000000}},	//   _общн, _майн, _mpla,
  { {0x200f0004,0x629e4b17,0x7ae34b18,0x00000000}},	// [8e40] dagi_, tipo, _kint,
  { {0x6d411923,0x66c00026,0x6d4a001f,0x00000000}},	//   _opla, töku, ywfa,
  { {0x68e40019,0xb5ca007e,0x4fea05bd,0x00000000}},	//   _kiid, _خودم_, амен_,
  { {0x69c30185,0x7ae313b8,0x200f0019,0x00000000}},	//   _myne, _lint, gagi_,
  { {0x6d414b19,0xcd020051,0x66c00014,0x00000000}},	//   _apla, zość_, söku,
  { {0x68e40004,0xddc100c3,0x32cf005b,0x00000000}},	//   _liid, _dolž, tüye_,
  { {0x200f028d,0xa2b90053,0x629c0150,0x00000000}},	//   bagi_, ्तर्, _imro,
  { {0x68e4024a,0x7aeb4b1a,0x6d5c00ea,0x00000000}},	//   _niid, _bugt, _áram,
  { {0xcd020045,0x7ae30e5b,0xc4d30063,0x00000000}},	//   wość_, _bint, וגה_,
  { {0xd90e007e,0x7ae34b1b,0x5a34065b,0x00000000}},	//   نیت_, _cint, чнот,
  { {0x7ae30529,0xec4a0062,0x6483004b,0x00000000}},	//   _dint, _взел_, _sõim,
  { {0x57f4011c,0x6c34007e,0x7aeb00b9,0x00000000}},	//   мпют, _رفتا, _fugt,
  { {0x629c006f,0x7ae34b1c,0x68e439af,0x00000000}},	//   _omro, _fint, _diid,
  { {0x64830004,0x69c3001f,0x199442b0,0x00000000}},	//   _võim, _fyne, _наля,
  { {0x80da0053,0x291119bc,0x9c7c0b59,0x00000000}},	//   बगाइ, ázat_, _auči,
  { {0xd7fb011c,0x7aeb00a4,0x9c7c4b1d,0x00000000}},	//   _тук_, _yugt, _buči,
  { {0x5334005a,0x7ae30035,0x78bd04fd,0x00000000}},	// [8e50] метт, _yint, mosv,
  { {0x64830004,0xd2510032,0xf2c7000d,0x00000000}},	//   _kõik, عنا_, ісан,
  { {0x7583007e,0xdcf8008f,0x8c3d0058,0x00000000}},	//   _غیرم, izvē, lişe,
  { {0x66c000c7,0x78bd01b2,0xa2cb0042,0x00000000}},	//   sökt, nosv, _तीर्,
  { {0x64830004,0x6d5c00ea,0x9f98005e,0x00000000}},	//   _lõik, _áraj, овцу_,
  { {0x200f4b1e,0xe7e30053,0x6d410829,0x00000000}},	//   sagi_, _गणना_, _ppla,
  { {0x661a0051,0xbf0b0053,0xdcf8008f,0x00000000}},	//   ótki, _सौरभ_, dzvē,
  { {0x6d4100c3,0x69c30051,0x7ae31d88,0x00000000}},	//   _vpla, _ryne, _sint,
  { {0x69c34b1f,0x629c001f,0x7ae34b20,0x00000000}},	//   _syne, _ymro, _pint,
  { {0x8c3d005b,0x64ac005b,0xb9b50062,0x00000000}},	//   dişe, eğil, зсмъ,
  { {0x6d411973,0xf27c0047,0x2d980014,0x00000000}},	//   _upla, ירזש, _þrep_,
  { {0x7aeb0025,0x7cd90076,0x8c3d003b,0x00000000}},	//   _tugt, _умер_, fişe,
  { {0x69c3001f,0x68e4065c,0x77830062,0x00000000}},	//   _wyne, _viid, еляз,
  { {0xfe67006a,0xaa4100fe,0x8afa0063,0x00000000}},	//   رد_, ärää_, _הפסק,
  { {0xf484007e,0x2a6704aa,0x27ed45e4,0x00000000}},	//   واری, _innb_, žena_,
  { {0x66c000fe,0x7ce70058,0x628500ca,0x00000000}},	//   töks, _hırs, ekho,
  { {0x7c3b0035,0x0326000d,0x7ce70058,0x00000000}},	// [8e60] ifur, ядан, _kırs,
  { {0x9c7c007d,0x66c0013d,0x7ce70058,0x00000000}},	//   _vuči, röks, _yırt,
  { {0xf67b0063,0x66c00137,0x867b009a,0x00000000}},	//   _האימ, söks, _הריו,
  { {0x6aa100bd,0xd12f005d,0x62854b21,0x00000000}},	//   hilf, طمه_, akho,
  { {0xd00f03eb,0x7981002b,0xffe30145,0x00000000}},	//   اله_, hylw, нюшн,
  { {0x62854b22,0x629c0150,0x6d5c013d,0x00000000}},	//   ckho, _umro, _árak,
  { {0x61430597,0x6aa10089,0x7c3b4671,0x00000000}},	//   _пера, dilf, ffur,
  { {0xd00f0032,0x399c0066,0x1d07005e,0x00000000}},	//   _ملف_, násť_, чећи_,
  { {0x769000fe,0x7ce70058,0x6aa114a7,0x00000000}},	//   _käyd, _sırt, filf,
  { {0x27e9002b,0x6483004e,0xd357009a,0x00000000}},	//   _sgan_, _põik, ליפי_,
  { {0x6f0900bd,0xe8e0008b,0x7e6801e1,0x00000000}},	//   _zwec, _ngồi_, _indp,
  { {0x64830004,0xab2a17ab,0xdce30078,0x00000000}},	//   _võik, _года_, dynė,
  { {0x63830026,0xac970021,0x7ce7005b,0x00000000}},	//   _mínú, _عنها_, _fırs,
  { {0x672000ea,0x8c3d0058,0xee2e0054,0x00000000}},	//   ámja, rişe, внi_,
  { {0x9a3b0063,0x2a3b089e,0x7e7a02fd,0x00000000}},	//   _התוק, _העומ, _motp,
  { {0x98620022,0x8c3d00dd,0xddc80022,0x00000000}},	//   _róć_, mişc, _bodź,
  { {0x38690025,0x66c0013d,0xe6674b23,0x00000000}},	// [8e70] _inar_, rökr, _етно,
  { {0xedf80161,0xf8bf3a7d,0x66c01fdb,0x00000000}},	//   ुरोध_, loé_, sökr,
  { {0xc5fb0053,0xc035005e,0x62854b24,0x00000000}},	//   ्रीय_, днеј, rkho,
  { {0xdbf1004c,0xa3e70042,0x00000000,0x00000000}},	//   třík, _पलट_,   ,
  { {0x3dc5001f,0xef180054,0xf2070085,0x00000000}},	//   _sylw_, змі_, _няво,
  { {0x6e940817,0x7e2b0054,0xa2e40085,0x00000000}},	//   ничу, сіда_, _поўд,
  { {0x2d8a004d,0x38690949,0x3015007b,0x00000000}},	//   _übel_, _onar_, _одвр,
  { {0xdbf10080,0x6aa1002b,0x7e6803a7,0x00000000}},	//   přík, wilf, _endp,
  { {0xabc20047,0x6aa14b25,0x7c3b4b26,0x00000000}},	//   _האָבן_, tilf, rfur,
  { {0x38690268,0x27360026,0x38b90066,0x00000000}},	//   _anar_, væn_, méry_,
  { {0x6aa101e1,0x38b94b27,0x6b840023,0x00000000}},	//   rilf, léry_, _ačgā,
  { {0xc68900b5,0xe73a0be6,0x186a015a,0x00000000}},	//   _דא_, оем_, цами_,
  { {0x2cad0898,0x9b45007e,0xf3ff00be,0x00000000}},	//   mned_, _آنتو, _anão_,
  { {0xdce30006,0x2cad01e1,0xcb120063,0x00000000}},	//   tynė, lned_, _ילד_,
  { {0x2cad0037,0x66e33b4d,0xc99200de,0x00000000}},	//   oned_, тора, _للوظ,
  { {0x130a000d,0x2cad1af3,0x2cbf00ca,0x00000000}},	//   жнай_, nned_, noud_,
  { {0x2cad0037,0xae0d0042,0x4e0d0042,0x00000000}},	// [8e80] ined_, हरान_, हराई_,
  { {0x2cbf0ac8,0x02190088,0x0caa0042,0x00000000}},	//   houd_, зіць_, _छद्म,
  { {0x63a9007a,0x7e7a124f,0x74f60044,0x00000000}},	//   _þenn, _rotp, _تأخذ,
  { {0xd095000d,0x601a02fe,0x6d5c013d,0x00000000}},	//   ншчы, іцер_, _árai,
  { {0x7e7a0117,0x769000fe,0x64a5005f,0x00000000}},	//   _potp, _täyd, rėit,
  { {0xccfa0001,0x67260014,0x7e530054,0x00000000}},	//   оћи_, irkj, квіє,
  { {0xdd900021,0x00000000,0x00000000,0x00000000}},	//   طوة_,   ,   ,
  { {0x2cad0037,0xcb540001,0x628e0066,0x00000000}},	//   gned_, евић, _hlbo,
  { {0x8c4300d7,0x20060089,0x7e7a0244,0x00000000}},	//   тење, mboi_, _totp,
  { {0x6f0202dd,0x2cad00e5,0x69cf0022,0x00000000}},	//   mpoc, aned_, ęcen,
  { {0x29184b28,0x22584b29,0xed5a0002,0x00000000}},	//   éra_, _mark_, _фое_,
  { {0x64830019,0x3af200a3,0x3b8604d6,0x00000000}},	//   _hõiv, _tâp_, _олег,
  { {0xa7740054,0x6483004b,0xf8bf1775,0x00000000}},	//   вляч, _kõiv, roé_,
  { {0x3b530086,0x7afd4b2a,0x95fb0042,0x00000000}},	//   _шкір, íste, ्रेट_,
  { {0x7aef034d,0x7ce70058,0xe4e70054,0x00000000}},	//   íctv, _kırp, діан,
  { {0xed5f0066,0x20c7004b,0x6483004b,0x00000000}},	//   úžil_, lõiv_, _lõiv,
  { {0x22584b2b,0xd4e402f9,0xd25b014b,0x00000000}},	// [8e90] _bark_, тюри, жце_,
  { {0x2b460089,0xdcee004c,0xc539012c,0x00000000}},	//   _mpoc_, íděn, _епох_,
  { {0x22582b71,0x49d4009a,0x41e4014b,0x00000000}},	//   _dark_, תֵּן_, віца,
  { {0x628e3ef9,0x24920022,0x88bd004c,0x00000000}},	//   _elbo, chym_, etěz,
  { {0x2258005b,0x44f50137,0x4df51213,0x00000000}},	//   _fark_, _hå_, няйт,
  { {0x2cad0034,0x24894b2c,0x661501a8,0x00000000}},	//   wned_, lkam_, nazk,
  { {0x3f890078,0xc2c40021,0x20e80058,0x00000000}},	//   šau_, _شيفي, _işin_,
  { {0x44f5191f,0x8c3d000c,0x24894b2d,0x00000000}},	//   _må_, fişa, nkam_,
  { {0x2cad0034,0x44f502ea,0xff280021,0x00000000}},	//   rned_, _lå_, _يكفي_,
  { {0x17fa0053,0x8fa4005e,0x644d00a3,0x00000000}},	//   ूर्व_, _рађе, heai,
  { {0x44f54b2e,0x2489004e,0xa9691579,0x00000000}},	//   _nå_, kkam_, чина_,
  { {0x2d51007d,0xddc8004c,0x644d0072,0x00000000}},	//   _iše_, _nadř, jeai,
  { {0xeb8e4b2f,0x8c3d000c,0x66150089,0x00000000}},	//   _си_, cişa, fazk,
  { {0xba3900b5,0x2006000c,0x2489001c,0x00000000}},	//   _זײַט, zboi_, ekam_,
  { {0x49bb006a,0x6f020045,0x2492001f,0x00000000}},	//   _باشد_, zpoc, thym_,
  { {0x44f501e3,0x644d0164,0x225813cb,0x00000000}},	//   _då_, geai, _sark_,
  { {0x67560021,0x22581865,0xd80b009a,0x00000000}},	// [8ea0] _أخبر, _park_, _מִיָ,
  { {0x44f51bbc,0x2006002b,0x78a64b30,0x00000000}},	//   _få_, wboi_, likv,
  { {0x44f52453,0x6483004b,0xe5a64b31,0x00000000}},	//   _gå_, _rõiv, _чини,
  { {0xb4fb009d,0x00000000,0x00000000,0x00000000}},	//   _מפטי,   ,   ,
  { {0x2258004b,0xde582049,0x2d51348d,0x00000000}},	//   _tark_, далі_, _aše_,
  { {0x764e4b32,0x471b00b5,0x60cb00b9,0x00000000}},	//   neby, לונג, algm,
  { {0x64830019,0x02be0053,0x52be0053,0x00000000}},	//   _võiv, ्तीन, ्तीस,
  { {0xbd430021,0x764e002b,0x776400be,0x00000000}},	//   انيي, heby, _orix,
  { {0xab940054,0x0b8a01d5,0xd336009a,0x00000000}},	//   типі, яски_, ׂרֵה_,
  { {0xd8f80086,0x60c225b3,0x6fb30021,0x00000000}},	//   мної_, loom, _إمكا,
  { {0xe8950088,0x39470150,0x78a61b6b,0x00000000}},	//   вань, _cpns_, fikv,
  { {0x77644b33,0x27ed02ab,0x765c00ac,0x00000000}},	//   _brix, øen_, edry,
  { {0xe7870086,0x44f54b34,0x753c0a20,0x00000000}},	//   хуно, _så_, etrz,
  { {0x44f51bbc,0x764e06a5,0x22840014,0x00000000}},	//   _på_, geby, _köku_,
  { {0x66151a03,0xd5b80320,0x24894b35,0x00000000}},	//   razk, ест_, tkam_,
  { {0x3913005a,0x6f19001f,0x44324b36,0x00000000}},	//   _смър, yswc, ggy_,
  { {0x9259000a,0x644d0d2f,0x764e08a9,0x00000000}},	// [8eb0] маат_, reai, beby,
  { {0x6d484b37,0x673d006f,0x44f50137,0x00000000}},	//   _opda, mtsj, _tå_,
  { {0x26c30006,0x672f0051,0x644d497d,0x00000000}},	//   mojo_, lucj, peai,
  { {0x7aea27ff,0x26c30331,0x251a0063,0x00000000}},	//   _lift, lojo_, _קורא,
  { {0x84160063,0x673d0180,0xa022004b,0x00000000}},	//   _בקרב_, ntsj, ööaj,
  { {0x26c34b38,0x6aba0053,0x673d004b,0x00000000}},	//   nojo_, ईकोर, itsj,
  { {0x60c200ca,0x5ff50ae8,0x6cd902b3,0x00000000}},	//   boom, _азбу, мфис_,
  { {0x2d510080,0x27ed00c2,0xd0d50062,0x00000000}},	//   _vše_, ženj_, _робъ,
  { {0x9e150088,0x66d200b9,0x8c3d003b,0x00000000}},	//   _адзі, dækn, bişn,
  { {0x26c30078,0x7b4400f2,0x753c0022,0x00000000}},	//   jojo_, ائيل, ytrz,
  { {0x69ca0185,0xe9d90619,0x9e7a00b5,0x00000000}},	//   _cyfe, ько_, _קנעפ,
  { {0x64830004,0x8c3d000c,0x69ca001f,0x00000000}},	//   _mõis, mişo, _dyfe,
  { {0x7aea0034,0x69ce0066,0x2d874b39,0x00000000}},	//   _fift, ýber, lyne_,
  { {0x3ea70268,0x64ac000c,0x60c226ad,0x00000000}},	//   nint_, işie, zoom,
  { {0x69ca0185,0x765c0474,0x64a64b3a,0x00000000}},	//   _gyfe, rdry, вава,
  { {0x98a6001c,0x29054b3b,0x672f0022,0x00000000}},	//   bulā_, mpla_, bucj,
  { {0x753c0045,0x44320969,0x26c30078,0x00000000}},	// [8ec0] strz, rgy_, bojo_,
  { {0x64830019,0xddc8007d,0xe10a0121,0x00000000}},	//   _sõit, _rodž, дежд_,
  { {0x3ea70268,0xc05a0086,0x7bcb0006,0x00000000}},	//   dint_, діл_, _lygu,
  { {0x3ea74b3c,0xfbc701fb,0xddc84b3d,0x00000000}},	//   eint_, _نت_, _podž,
  { {0x64830019,0x60c24b3e,0x66d201e1,0x00000000}},	//   _võit, room, næko,
  { {0x6d4802f0,0x3ea74b3f,0xeaa70021,0x00000000}},	//   _ppda, gint_, _ضع_,
  { {0x90c60088,0xdfd2007e,0xc5f30063,0x00000000}},	//   _абве, _چيز_, סדה_,
  { {0xdfd2006a,0x69ca001f,0x3ea74b40,0x00000000}},	//   _نيز_, _ryfe, aint_,
  { {0x69ca00e8,0xee3a4b41,0xa03b0047,0x00000000}},	//   _syfe, _она_, _קעמפ,
  { {0x63a909fc,0xaa66000a,0x3ea7056d,0x00000000}},	//   _ženk, ттик, cint_,
  { {0x26c3146a,0x66d20026,0x7aea061f,0x00000000}},	//   vojo_, tækn, _vift,
  { {0x387f0ac6,0xa9c3019d,0x8c3d01f7,0x00000000}},	//   ður_, рськ, nişl,
  { {0x26c300eb,0x66d200b9,0xb87b004c,0x00000000}},	//   tojo_, rækn, emíc,
  { {0x91790013,0x29180139,0x9966197b,0x00000000}},	//   hớp_, áras_, _атил,
  { {0x7c2200c2,0xc9860095,0x26c34b38,0x00000000}},	//   _kdor, _јули, rojo_,
  { {0x998c0022,0x33294b42,0x26c300a8,0x00000000}},	//   padł_, trax_, sojo_,
  { {0x03d5007f,0xd6db1415,0x62d90085,0x00000000}},	// [8ed0] ужаю, _ото_, емаў_,
  { {0x85750a39,0x799a056c,0xaab40042,0x00000000}},	//   _блох, oztw, ुविक,
  { {0x7690024a,0xb6020080,0x3ea70bbd,0x00000000}},	//   _käyn, čáte, vint_,
  { {0x64830019,0x5f9506be,0x7c22003b,0x00000000}},	//   _võis, лиет, _ndor,
  { {0x98a6003b,0x3ea74b43,0xfd640013,0x00000000}},	//   lulă_, tint_, _truớ,
  { {0x0ccb0161,0x645d4b44,0x2bc60053,0x00000000}},	//   ात्म, _hasi, _लड़ा,
  { {0x41e40304,0x645d2fb9,0x3ea74b45,0x00000000}},	//   _віта, _kasi, rint_,
  { {0x799a0051,0x3ea74b46,0x3dcc001f,0x00000000}},	//   dztw, sint_, _dydw_,
  { {0x645d1acc,0x7c840001,0x2d874b47,0x00000000}},	//   _masi, рује, syne_,
  { {0x6eda0042,0x645d2b7d,0x9977005f,0x00000000}},	//   _पीपु, _lasi, rąža_,
  { {0x8c3d01f7,0x4439223e,0x68ed4b48,0x00000000}},	//   lişm, _ocs_, _biad,
  { {0x645d0373,0xe45f0137,0x98a40078,0x00000000}},	//   _nasi, _skön_, įjį_,
  { {0x7bcb01f7,0x68ed014f,0x29180014,0x00000000}},	//   _uygu, _diad, árar_,
  { {0x290500c7,0x645d4782,0x44224b49,0x00000000}},	//   ppla_, _aasi, _sdk_,
  { {0x98a6000c,0x44220089,0x8c3d0058,0x00000000}},	//   gulă_, _pdk_, yişl,
  { {0xa3ea15d3,0x645d4702,0x64a31822,0x00000000}},	//   едба_, _casi, баса,
  { {0x6b9b00bd,0x6b89017e,0x232700fb,0x00000000}},	// [8ee0] nzug, nyeg, лоти_,
  { {0x645d0034,0x68ed0035,0x60db14fa,0x00000000}},	//   _easi, _ziad, _ahum,
  { {0x645d4b4a,0x44220150,0x98a6003b,0x00000000}},	//   _fasi, _tdk_, culă_,
  { {0x60db299e,0x3dcc001f,0x645d4b4b,0x00000000}},	//   _chum, _rydw_, _gasi,
  { {0x8c3d005b,0x1e14000d,0x69ca0053,0x00000000}},	//   rişl, амля, _सुनी,
  { {0x645d4b4c,0x52760e74,0xdfcf0044,0x00000000}},	//   _zasi, _суму, أيه_,
  { {0x765e0035,0x645d4b4d,0x7afd004c,0x00000000}},	//   _mapy, _yasi, ístn,
  { {0x27ed3692,0x6b9b004d,0x6444001a,0x00000000}},	//   ženi_, fzug, nfii,
  { {0x68ed0024,0x7c830076,0x7988001f,0x00000000}},	//   _riad, суще, wydw,
  { {0x3dcc00a3,0x7c240023,0x68ed4b4e,0x00000000}},	//   _tydw_, _ķiru, _siad,
  { {0xaa63000d,0x68ed12c7,0x62770041,0x00000000}},	//   стык, _piad, אגיא_,
  { {0x64b7007d,0x23b40053,0x6aa80137,0x00000000}},	//   ećin, ंपाद, sidf,
  { {0x2ca60146,0x321a00ac,0x57a7255b,0x00000000}},	//   _imod_, kapy_, ушна,
  { {0x68ed0045,0x645d0035,0x00000000,0x00000000}},	//   _wiad, _sasi,   ,
  { {0x68ed0228,0x645d1d56,0x6594000a,0x00000000}},	//   _tiad, _pasi, бару,
  { {0x7528034d,0x6d5a0035,0x24580b0f,0x00000000}},	//   ádza, _msta, лась_,
  { {0x291e001c,0x98a6003b,0x60db0003,0x00000000}},	// [8ef0] lsta_, sulă_, _rhum,
  { {0x645d4b4f,0x60c94b50,0x291e4b51,0x00000000}},	//   _wasi, _skem, osta_,
  { {0x2ca600ac,0x41550062,0x645d11d4,0x00000000}},	//   _omod_, рвес, _tasi,
  { {0x291e0a06,0x765e0051,0x3cfb0053,0x00000000}},	//   ista_, _zapy, _लंबे_,
  { {0x833500b5,0x6d5a1b9e,0xd9d10042,0x00000000}},	//   _דאָס_, _asta, _हर्ट,
  { {0x291e4b52,0x8c3d0058,0x2ca6002b,0x00000000}},	//   ksta_, rişm, _amod_,
  { {0x60db4b53,0x69ce092a,0x291e0605,0x00000000}},	//   _thum, übel, jsta_,
  { {0x291e00c7,0x27e50051,0x9f0501fb,0x00000000}},	//   dsta_, ślny_, _نورو,
  { {0x291e4b54,0x8c3d005b,0x6d5a03db,0x00000000}},	//   esta_, lişk, _esta,
  { {0x39450086,0x6b9b00bd,0x7aa50189,0x00000000}},	//   аног, rzug, риоз,
  { {0xade10161,0x291e4b55,0x6b9b004d,0x00000000}},	//   गेशन_, gsta_, szug,
  { {0x2903001c,0x7d7a016e,0xdda8030b,0x00000000}},	//   īja_, _ברעג, _стул_,
  { {0x291e4b56,0xb8fc0042,0x765e4b57,0x00000000}},	//   asta_, _ती_, _papy,
  { {0x6d5a001f,0xf5060854,0x09e50131,0x00000000}},	//   _ysta, изго, _колн,
  { {0x4416000a,0xc8b60121,0xe61701f6,0x00000000}},	//   ифат, _вспы, рдс_,
  { {0x7786005a,0x765e0035,0x99d403eb,0x00000000}},	//   _влиз, _wapy, _اتها,
  { {0xb87b017d,0xd3872178,0xd6d20021,0x00000000}},	// [8f00] omín, айте_, _وقع_,
  { {0x38600034,0x42070001,0x769000fe,0x00000000}},	//   _hair_, инуо_, _käym,
  { {0xf67b00b5,0x661c0b9c,0x321a47cf,0x00000000}},	//   _סאטמ, mark, rapy_,
  { {0x661c4b58,0x504639c9,0x50f30085,0x00000000}},	//   lark, редб, ізіт,
  { {0x44fc3115,0x386000f1,0xdfcf013a,0x00000000}},	//   _hí_, _mair_, ويم_,
  { {0x66d200b9,0x44fc008b,0x661c4b59,0x00000000}},	//   dækk, _kí_, nark,
  { {0xb87b0080,0x44fc0080,0x66d20014,0x00000000}},	//   dmín, _jí_, tækj,
  { {0x661c00e3,0x44fc394b,0x6d5a04e9,0x00000000}},	//   hark, _mí_, _vsta,
  { {0x6d5a0051,0x44fc4b5a,0x661c340b,0x00000000}},	//   _wsta, _lí_, kark,
  { {0x7f3b014e,0x661c053b,0x291e0019,0x00000000}},	//   _בעמו, jark, tsta_,
  { {0x44fc4b5b,0x6d5a4b5c,0x661c4b5d,0x00000000}},	//   _ní_, _usta, dark,
  { {0x291e4b5e,0x28a70086,0xaba7007e,0x00000000}},	//   rsta_, ршог, اهیم_,
  { {0x44fc33ef,0x38604b5f,0x98b80062,0x00000000}},	//   _aí_, _dair_, рлят_,
  { {0x29860076,0x27fe0080,0x3f42008b,0x00000000}},	//   _выиг, ětna_, _mưu_,
  { {0x3f42001b,0x38600b95,0x45d51dd1,0x00000000}},	//   _lưu_, _fair_, совс,
  { {0x3860001f,0x316d04e9,0x98a4005e,0x00000000}},	//   _gair_, _čez_, _мије,
  { {0x24580b3f,0x7cf50006,0x661c1121,0x00000000}},	// [8f10] шать_, _išre, bark,
  { {0x8c3d005b,0x38604b60,0xe167005e,0x00000000}},	//   tişk, _zair_, иђен,
  { {0xd5b80376,0xd5b100f2,0x387200a3,0x00000000}},	//   _вся_, _رفح_, _ynyr_,
  { {0x3f42008b,0x27ed007c,0x8c3d0058,0x00000000}},	//   _bưu_, ženu_, rişk,
  { {0x32180150,0x753512ed,0x44fc0124,0x00000000}},	//   _fery_, luzz, _zí_,
  { {0xee38019d,0xa137007e,0x51874b61,0x00000000}},	//   ині_, _پرسش, _куба,
  { {0x8c3d005b,0x753501f4,0x44fc0013,0x00000000}},	//   lişi, nuzz, _xí_,
  { {0x40344b62,0x45b80063,0x66d20014,0x00000000}},	//   _месс, יפול_, tækk,
  { {0xdd3b0051,0x661c0949,0x201d017e,0x00000000}},	//   ląże, yark, mawi_,
  { {0x66d20146,0x38600016,0x201d4b63,0x00000000}},	//   rækk, _sair_, lawi_,
  { {0xec15007e,0x9c8300c2,0xb87b0114,0x00000000}},	//   _هواد, _ščur, rmín,
  { {0x44fc0264,0x7e6134e2,0x6c840044,0x00000000}},	//   _rí_, _halp, _وللم,
  { {0x2d8a0199,0x44fc4b64,0x7e614b65,0x00000000}},	//   _über_, _sí_, _kalp,
  { {0x2cad4b66,0x6603037b,0x44fc4b67,0x00000000}},	//   lied_, зпра, _pí_,
  { {0x3860001f,0x201d1472,0x661c02e0,0x00000000}},	//   _tair_, kawi_, rark,
  { {0x38600027,0x2cad0034,0x661c33aa,0x00000000}},	//   _uair_, nied_, sark,
  { {0x201d0397,0xd4672ab5,0x661c2b22,0x00000000}},	// [8f20] dawi_, щите_, park,
  { {0x44fc4b68,0x2cad030c,0x6d434b69,0x00000000}},	//   _tí_, hied_, ktna,
  { {0x32180034,0x44fc0025,0x3f42008b,0x00000000}},	//   _very_, _uí_, _sưu_,
  { {0x30a50086,0x69da0041,0xd019056c,0x00000000}},	//   орів, אַדו, _ceń_,
  { {0x2cad0034,0x6d43001b,0x6456005b,0x00000000}},	//   died_, etna, meyi,
  { {0x645601f7,0x2480017f,0x32184b6a,0x00000000}},	//   leyi, ljim_, _uery_,
  { {0x2cad0037,0x201d4b6b,0x24801235,0x00000000}},	//   fied_, bawi_, ojim_,
  { {0x645601f7,0x2480027c,0x6724007d,0x00000000}},	//   neyi, njim_, _ovij,
  { {0x6d69003d,0x6d430025,0x7c2f006d,0x00000000}},	//   _īpaš, atna, ócra,
  { {0xb87b1997,0x6fb30593,0x7de2013d,0x00000000}},	//   amíl, _عملا, gísé,
  { {0x2cad03a8,0x98b9000a,0x6d43006f,0x00000000}},	//   bied_, илот_, ctna,
  { {0x63bb0014,0x8c3d0058,0x76900050,0x00000000}},	//   _þung, yişi, _häyh,
  { {0x6724017f,0x27ed00fe,0xf804000d,0x00000000}},	//   _cvij, äen_, ячэн,
  { {0x6724017f,0x95cb065b,0x96f82530,0x00000000}},	//   _dvij, губа_, серт_,
  { {0xceb30e2a,0x76550022,0x59cf0042,0x00000000}},	//   ליש_, rezy, _सुपर,
  { {0x3eae4b6c,0x8c3d005b,0x7535206f,0x00000000}},	//   hift_, tişi, ruzz,
  { {0x26ca04d0,0x3eae000e,0x32011f48,0x00000000}},	// [8f30] bobo_, kift_, tchy_,
  { {0x8c3d005b,0x201d0089,0xe7180063,0x00000000}},	//   rişi, wawi_, _החזר_,
  { {0x6724074f,0x32014b6d,0x201d4b6e,0x00000000}},	//   _zvij, rchy_, tawi_,
  { {0x2d81004b,0x228f0058,0x7e614b6f,0x00000000}},	//   ähem_, _sıkı_, _salp,
  { {0x743a00b5,0x643a00b5,0x64ac005b,0x00000000}},	//   _דערװ, _דערנ, işil,
  { {0x171c0047,0x3eae12f5,0x999e0078,0x00000000}},	//   נווע, gift_, netų_,
  { {0x201d00a4,0x999e0078,0x41090063,0x00000000}},	//   pawi_, ietų_, _כִּ֣,
  { {0xcf2e0058,0x6d434b70,0x7e614b71,0x00000000}},	//   üğüm_, rtna, _walp,
  { {0x62870117,0x2cad04bf,0x7e614b72,0x00000000}},	//   _kojo, ried_, _talp,
  { {0xa9254b73,0x6456005b,0x4ea7064b,0x00000000}},	//   одол, zeyi, _урба,
  { {0x3f8f0185,0x6724017f,0x2cad0034,0x00000000}},	//   lygu_, _svij, pied_,
  { {0x776d4b74,0xcd9a0041,0xd7ea1849,0x00000000}},	//   _brax, _דױער, имне_,
  { {0x64560075,0x00000000,0x00000000,0x00000000}},	//   veyi,   ,   ,
  { {0xd491001b,0xa96905fb,0xeb960601,0x00000000}},	//   ền_, _вика_, _фиш_,
  { {0x248000c2,0x6456005b,0x3f8f002b,0x00000000}},	//   tjim_, teyi, hygu_,
  { {0x776d3140,0xdbd40331,0x7c3b4b75,0x00000000}},	//   _frax, _zúñi, ngur,
  { {0x6724017f,0x7c3b4b76,0x64560058,0x00000000}},	// [8f40] _uvij, igur, reyi,
  { {0x6456005b,0xd36f0021,0x24920066,0x00000000}},	//   seyi, ضهم_, skym_,
  { {0xf772007e,0xd677009a,0x1677009d,0x00000000}},	//   _راک_, _ותיק_, _וגיל_,
  { {0xb9cc00b5,0xd46a0001,0x3636007e,0x00000000}},	//   נזאָ, _тиме_, _ارکس,
  { {0x44204b77,0x3eae0e77,0x43670094,0x00000000}},	//   mai_, tift_, _даян_,
  { {0x442005b2,0x7c3b16eb,0xd481005e,0x00000000}},	//   lai_, egur, _шeтњ,
  { {0xbea30002,0x3eae4b78,0x4c940591,0x00000000}},	//   ќајк, rift_, зийс,
  { {0xeb4a09b3,0xc5f30063,0xab5c0041,0x00000000}},	//   ачок_, ודו_, _מאַכן_,
  { {0x61050006,0xee3a0086,0x69d546bb,0x00000000}},	//   _vėle, _внз_, üzen,
  { {0xfa8a0076,0x20e8005b,0x7c3b3dd1,0x00000000}},	//   рсий_, _eşit_, agur,
  { {0x44204b79,0x6d44003b,0x32570063,0x00000000}},	//   kai_, ăias, חסים_,
  { {0x44204b7a,0x776d4b7b,0x48ab224c,0x00000000}},	//   jai_, _prax, ртом_,
  { {0x7cf50006,0x4420373e,0x7c2000a4,0x00000000}},	//   _išra, dai_, mamr,
  { {0x2455008b,0x6f79009a,0xbb3b009d,0x00000000}},	//   _ấm_, צְרו, _כעדי,
  { {0x62874b7c,0x44204b7d,0x999e0078,0x00000000}},	//   _rojo, fai_, retų_,
  { {0x44204b7e,0x48150121,0x62873949,0x00000000}},	//   gai_, _эмис, _sojo,
  { {0x8c3d0683,0x62874675,0xddc12128,0x00000000}},	// [8f50] mişt, _pojo, _palū,
  { {0x442000e8,0x416b0001,0xd25b00d7,0x00000000}},	//   aai_, ијем_, јца_,
  { {0xddc1001c,0x27f40080,0x6f094b7f,0x00000000}},	//   _valū, čanů_, _stec,
  { {0x8c3d000c,0x62870022,0xa911013d,0x00000000}},	//   nişt, _wojo, _tööő_,
  { {0xb4d7016a,0xa2ba0053,0x62874b80,0x00000000}},	//   िती_, ्वश्, _tojo,
  { {0x629e4b81,0x66d20014,0x98720078,0x00000000}},	//   chpo, bæku, yšį_,
  { {0x78ad0004,0x8cc70053,0xa2ba0053,0x00000000}},	//   _omav, ावलो, ्वर्,
  { {0x7c3b2e47,0x7c20013d,0xec7920e5,0x00000000}},	//   ugur, gamr, спи_,
  { {0x7c3b4b82,0xdaa90062,0xbf1503eb,0x00000000}},	//   rgur, йвид_, _رواب,
  { {0x7c3b4b83,0x78ad0a5c,0x7528017c,0x00000000}},	//   sgur, _amav, ádzk,
  { {0x644f0051,0x88ca047e,0x442005d8,0x00000000}},	//   _obci, йлов_, yai_,
  { {0x8c3d003b,0x00000000,0x00000000,0x00000000}},	//   gişt,   ,   ,
  { {0xd5b7001b,0xf772009e,0x44204b84,0x00000000}},	//   ống_, راح_, vai_,
  { {0x44200974,0x442b02dd,0x7ac4005e,0x00000000}},	//   wai_, _adc_, _осје,
  { {0x04960088,0x44204b85,0xd5b20021,0x00000000}},	//   праў, tai_, رفر_,
  { {0x2be20161,0x8c3d4b86,0x44204b87,0x00000000}},	//   _परमा, mişs, uai_,
  { {0x44204b88,0x386f0139,0xb89b0063,0x00000000}},	// [8f60] rai_, _ógra_, _לבקש,
  { {0x27e04b89,0x66d20046,0x44204b8a,0x00000000}},	//   _izin_, tæku, sai_,
  { {0x68e400e3,0x44204b8b,0x672604aa,0x00000000}},	//   _khid, pai_, lskj,
  { {0xe0d201fb,0x4fea33c4,0xe424005d,0x00000000}},	//   رزا_, бмен_, _زکري,
  { {0x67260031,0x6d5c00ea,0x68f60058,0x00000000}},	//   nskj, _áraz, _miyd,
  { {0x5436006a,0x7c2b4b8c,0x42550956,0x00000000}},	//   _برگر, _adgr, _отст,
  { {0x69d50058,0x63a44b8d,0xa06a0590,0x00000000}},	//   üzel, lzin, _лава_,
  { {0x63a44b8e,0xc5f30063,0x59cf0042,0x00000000}},	//   ozin, עדה_, _सुधर,
  { {0x8fa34b8f,0x8c3d003b,0xcb6702d8,0x00000000}},	//   _зате, vişt, зање_,
  { {0x7c2000c7,0x67262caa,0x63a44b90,0x00000000}},	//   samr, dskj, izin,
  { {0xade80053,0x1bb7007e,0x8c3d4b91,0x00000000}},	//   टेशन_, قایع_, tişt,
  { {0x290a003d,0xecea2b4f,0x68e44b92,0x00000000}},	//   ība_, _удел_, _chid,
  { {0x63a40122,0x68e40035,0x8c3d1432,0x00000000}},	//   jzin, _dhid, rişt,
  { {0x7cc1183d,0xf1be0053,0x63a44b93,0x00000000}},	//   mēra, ्थान, dzin,
  { {0x661e00f3,0x63a44b94,0xa4d50454,0x00000000}},	//   _depk, ezin, дові,
  { {0x68e4000c,0xe45f0026,0x672600d1,0x00000000}},	//   _ghid, _mjög_, bskj,
  { {0xa3e70053,0xa2f50085,0x63a44b95,0x00000000}},	// [8f70] यें_, дпач, gzin,
  { {0x979c009a,0x92b70044,0x76b901ce,0x00000000}},	//   _לשחק, أحرا, _флор_,
  { {0x2bbe008b,0x63a44b96,0x442b01e1,0x00000000}},	//   ịch_, azin, _tdc_,
  { {0x78bd00d1,0x21270013,0xa4d90054,0x00000000}},	//   nnsv, ĩnh_, _фдму_,
  { {0x5f94019d,0x644d0089,0x2fcb0044,0x00000000}},	//   ницт, mfai, حباً_,
  { {0x644d2389,0x7a2900ea,0x3e6d013d,0x00000000}},	//   lfai, _kötő, kötő_,
  { {0xc105006a,0x8d540085,0x5f77005d,0x00000000}},	//   _آوري, етыч, _کازر,
  { {0xfd5e008b,0x644d4b40,0x759c0063,0x00000000}},	//   _huyề, nfai, מיוח,
  { {0x769009ff,0xfbc50121,0x68e4002b,0x00000000}},	//   _käyt, ьбио, _rhid,
  { {0x68e40009,0x644d0139,0xa924017c,0x00000000}},	//   _shid, hfai, ĺžny,
  { {0x6285006f,0x8d9501fb,0x9f9c0014,0x00000000}},	//   ijho, _تلاش, læða_,
  { {0x7c2b00b9,0x672600d1,0x7bce004d,0x00000000}},	//   _udgr, tskj, ßbuc,
  { {0x644d0139,0x77830062,0xddc3013d,0x00000000}},	//   dfai, вляз, menő,
  { {0x769009ff,0xddc3000f,0x7afd0512,0x00000000}},	//   _näyt, lenő, ístu,
  { {0x672617d3,0x644d4b97,0xa50702f9,0x00000000}},	//   sskj, ffai, деса_,
  { {0x67260137,0x6e234b98,0x63a44b99,0x00000000}},	//   pskj, hanb, tzin,
  { {0x6e2300f3,0x661e005b,0x7ce500be,0x00000000}},	// [8f80] kanb, _tepk, mórd,
  { {0x236f007a,0x776400e8,0xe1f20021,0x00000000}},	//   ægja_, _isix, نسا_,
  { {0x1139000d,0xe45f0137,0x765c0a8d,0x00000000}},	//   зячы_, _bjöd_, mery,
  { {0x644d0025,0x38ab0051,0x765c2ddb,0x00000000}},	//   cfai, _górę_, lery,
  { {0x9f9c0026,0x61050078,0x320d0058,0x00000000}},	//   gæða_, _vėla, _şeye_,
  { {0x628300fe,0x765c4b9a,0xc333009f,0x00000000}},	//   önot, nery, _בוש_,
  { {0x9103000a,0xadb7007e,0x753c0022,0x00000000}},	//   _апсе, وهها_, nurz,
  { {0x8c43005e,0x91e34b9b,0x2baf0042,0x00000000}},	//   веће, _росе, _जेहा,
  { {0xd00f0049,0x6af42530,0x7f06005d,0x00000000}},	//   _خلق_, нзиф, _آذرم,
  { {0xed5a0054,0xee37167b,0x765c0058,0x00000000}},	//   _моз_, _ону_, jery,
  { {0xe873007e,0x644d162d,0xd9170121,0x00000000}},	//   نندگ, yfai, мья_,
  { {0x9ce50054,0x753c056c,0xadb700de,0x00000000}},	//   _зціл, durz, _تهما_,
  { {0x68110080,0x765c0731,0xfbe20053,0x00000000}},	//   vědč, fery, _परिम,
  { {0xdd860021,0x765c0b9d,0x69ce005b,0x00000000}},	//   هو_, gery, übes,
  { {0x15eb0054,0x644d0072,0x6d4a4b9c,0x00000000}},	//   юємо_, tfai, ntfa,
  { {0x7ce5017d,0x32d40072,0x6d4a0244,0x00000000}},	//   córd, käys_, itfa,
  { {0x7e7a0250,0xf8bf4b28,0x644d4b9d,0x00000000}},	// [8f90] _ontp, mné_, rfai,
  { {0x386903a8,0xfd5e001b,0x644d0164,0x00000000}},	//   _haar_, _quyề, sfai,
  { {0x673d4b9e,0x75d50044,0xa11400de,0x00000000}},	//   lusj, _سيحا, َوْت,
  { {0x38690102,0x9f9c0026,0xf8bf4b9f,0x00000000}},	//   _jaar_, tæða_, nné_,
  { {0x7690024a,0x38690ac8,0xe0d8019d,0x00000000}},	//   _täyt, _maar_, єві_,
  { {0x9f9c0026,0x9e640454,0xf8bf0139,0x00000000}},	//   ræða_, квід, hné_,
  { {0xfaf90006,0xa2cc0053,0x76900072,0x00000000}},	//   yvūs_, तकर्, _käyr,
  { {0x38690b7d,0x2b15005a,0x6ac70161,0x00000000}},	//   _naar_, ньор, रक्र,
  { {0xf8bf016b,0xe4520132,0x9f040044,0x00000000}},	//   dné_, אֶת_, _لوقو,
  { {0xb87b0014,0xf8bf006c,0x673d36b7,0x00000000}},	//   nlíf, ené_, dusj,
  { {0xe9d9011c,0xbd6806da,0x765c4ba0,0x00000000}},	//   яко_, _орце_, very,
  { {0x7cc1003d,0x673d0031,0xf8bf0164,0x00000000}},	//   mēro, fusj, gné_,
  { {0x386904c6,0x69ce00bd,0x6e210006,0x00000000}},	//   _daar_, über, _kelb,
  { {0x2cbf0019,0xddda008f,0x7ce50331,0x00000000}},	//   lnud_, _datņ, sórd,
  { {0x69d800eb,0xf8bf027d,0x386905b9,0x00000000}},	//   _gyve, bné_, _faar_,
  { {0x673d0031,0x2cbf0019,0xf8bf0240,0x00000000}},	//   busj, nnud_, cné_,
  { {0x26d1006d,0xccf20e2a,0x7b0c0041,0x00000000}},	// [8fa0] bozo_, רכן_, ַפאַ,
  { {0x32d400fe,0x7cc8004c,0x05663194,0x00000000}},	//   väys_, měre, _звон,
  { {0x7d010146,0x644b00cd,0x6d4a051c,0x00000000}},	//   _nuls, ògic, xtfa,
  { {0x769000fe,0x30670896,0xd0070085,0x00000000}},	//   _täys, ејшн_, ееце_,
  { {0x76450185,0x2cbf0019,0xf1d00053,0x00000000}},	//   _ychy, dnud_, _तुरन,
  { {0x11d60086,0xf8bf0114,0xdfcf01fb,0x00000000}},	//   _зібр, zné_, حيه_,
  { {0xa0a6019d,0x44220397,0x32d40072,0x00000000}},	//   _завд, _kek_, säys_,
  { {0x6d4a4ba1,0x442201e1,0x0ca70121,0x00000000}},	//   rtfa, _jek_, етьи_,
  { {0xf8bf027d,0x69d84ba2,0x6d4a294f,0x00000000}},	//   vné_, _syve, stfa,
  { {0xc33301d8,0x6e21260a,0x610c005b,0x00000000}},	//   נות_, _gelb, _eğle,
  { {0x442200e8,0x386911c8,0xf8bf4ba3,0x00000000}},	//   _oek_, _paar_, tné_,
  { {0xdd8f006a,0x26f90161,0x7ce50051,0x00000000}},	//   _دوم_, ंद्र_, tóre,
  { {0x38692ab8,0xf8bf246b,0xb87b004c,0x00000000}},	//   _vaar_, rné_, dmít,
  { {0x38690102,0xf8bf108f,0x7c220025,0x00000000}},	//   _waar_, sné_, _heor,
  { {0xf8bf0240,0xf1d00053,0x45d54ba4,0x00000000}},	//   pné_, _तुलन, товс,
  { {0xc4d80001,0x7cc80080,0x44221472,0x00000000}},	//   еђу_, běre, _cek_,
  { {0x628e4ba5,0x2a7c00ca,0x7c2f0516,0x00000000}},	// [8fb0] _bobo, _knvb_, ócri,
  { {0x44220019,0x52d80076,0x628e4ba6,0x00000000}},	//   _eek_, емую_, _cobo,
  { {0xd13b005a,0xf2c40121,0x628e11d2,0x00000000}},	//   яха_, устн, _dobo,
  { {0x6e210199,0x7cc1003d,0xb4950001,0x00000000}},	//   _selb, vēro, _римљ,
  { {0x6e210c64,0x7d0100f3,0x38180063,0x00000000}},	//   _pelb, _suls, תקדם_,
  { {0x7bd9001f,0x7d014ba7,0xed594ba8,0x00000000}},	//   _rywu, _puls, док_,
  { {0x2cbf0019,0xdca50076,0x6e92005e,0x00000000}},	//   tnud_, каки, рију,
  { {0x6e211215,0x2cbf002b,0x628e1a96,0x00000000}},	//   _welb, unud_, _zobo,
  { {0x2cbf0019,0x22960014,0x916c0013,0x00000000}},	//   rnud_, _sæki_, _tộc_,
  { {0x3da71b76,0xb87b0080,0x2cbf0019,0x00000000}},	//   _преб, hlíd, snud_,
  { {0x89f4000d,0x2b58000c,0x98a64ba9,0x00000000}},	//   ляюц, ărca_, вине,
  { {0xf3ff0013,0x61fa3dd4,0x7c224baa,0x00000000}},	//   _ngã_, _útle, _geor,
  { {0xeb8e1340,0x44224bab,0xfb85005d,0x00000000}},	//   _ти_, _rek_, _جدای,
  { {0xfe0e001b,0x2489017d,0x22960026,0x00000000}},	//   hững_, ejam_, _tæki_,
  { {0xceb20132,0x44224bac,0x628e4bad,0x00000000}},	//   בים_, _pek_, _robo,
  { {0x628e4bae,0x161e0042,0x00000000,0x00000000}},	//   _sobo, _बजकर_,   ,
  { {0x442204c9,0x628e4baf,0x2b4d4bb0,0x00000000}},	// [8fc0] _vek_, _pobo, ntec_,
  { {0x64ac0058,0x27fe004c,0xb87b004c,0x00000000}},	//   eşit, ětnu_, smít,
  { {0x44224bb1,0xa69b0063,0x672d00a8,0x00000000}},	//   _tek_, _חשיפ, _zvaj,
  { {0xc057014b,0xdd920043,0x00000000,0x00000000}},	//   віш_, یوش_,   ,
  { {0xdfd20032,0x78bd017d,0x628e4bb2,0x00000000}},	//   جيش_, érvi, _tobo,
  { {0x7c220397,0x5f930095,0x8fa3005e,0x00000000}},	//   _seor, ришт, раље,
  { {0x3f80000c,0xed570459,0x7c224bb3,0x00000000}},	//   ţiu_, вој_, _peor,
  { {0x61e301f7,0x7ce5017d,0x64444bb4,0x00000000}},	//   ünle, vórc, ngii,
  { {0x3dd20051,0x8af80121,0x2d81004d,0x00000000}},	//   ływ_, ннис_, äher_,
  { {0xbbe20161,0x60c20f32,0x7db6005e,0x00000000}},	//   _परीक, lnom, _исец,
  { {0x60c20003,0x69cf003b,0xe895000d,0x00000000}},	//   onom, şcen, гань,
  { {0x60c2076c,0x6d5a01f7,0x64ac005b,0x00000000}},	//   nnom, _ipta, işis,
  { {0x60c24bb5,0xab9a005d,0x00000000,0x00000000}},	//   inom, _تخار_,   ,
  { {0x3f86017d,0xf99200de,0x00000000,0x00000000}},	//   ixou_, _نبع_,   ,
  { {0xddda0080,0xec0f008b,0x98a6008f,0x00000000}},	//   _patř, iếng_, gulē_,
  { {0x2489001c,0x00000000,0x00000000,0x00000000}},	//   ujam_,   ,   ,
  { {0x672d00c3,0xd3700021,0xb87b0331,0x00000000}},	// [8fd0] _uvaj, يهِ_, smís,
  { {0x2247000f,0x60c24bb6,0x644400a4,0x00000000}},	//   ünk_, enom, agii,
  { {0xc6920063,0x98ad0006,0x7ce50139,0x00000000}},	//   _האי_, ardą_, hóra,
  { {0x60c24bb7,0xc9530047,0x80d4012c,0x00000000}},	//   gnom, ימע_, ації,
  { {0xd491001b,0xc43a014e,0x6d5a1b74,0x00000000}},	//   ều_, _אתרי, _apta,
  { {0x4429024a,0x38a20025,0x7cf50006,0x00000000}},	//   laa_, _móra_, _išri,
  { {0xb87b017d,0xf2d20063,0x290a0718,0x00000000}},	//   ilíb, _העם_, íbal_,
  { {0x27ed0080,0x44290f3f,0xa49b01a8,0x00000000}},	//   ženy_, naa_, _diòg,
  { {0xddc10080,0x7ce50139,0x7b7501fb,0x00000000}},	//   _dalš, góra, اطبا,
  { {0x2fc00025,0x44291385,0xc3340063,0x00000000}},	//   úige_, haa_, בוץ_,
  { {0x26c300c3,0x44294bb8,0x2b4d4bb9,0x00000000}},	//   dnjo_, kaa_, stec_,
  { {0x44294bb8,0xddc14bba,0xe73a4bbb,0x00000000}},	//   jaa_, _galš, нем_,
  { {0xa3b3024c,0x7c2901f4,0x44294bbc,0x00000000}},	//   _झेल_, maer, daa_,
  { {0xceb20063,0x7c2900ca,0x98a6008f,0x00000000}},	//   ֖ים_, laer, tulē_,
  { {0x44290009,0x610c0058,0xceb225a4,0x00000000}},	//   faa_, _oğla, זים_,
  { {0xb87b027d,0x26c300c2,0x64ac003b,0x00000000}},	//   smír, anjo_, eşir,
  { {0x78a405b3,0x38a20051,0xb87b004c,0x00000000}},	// [8fe0] _iliv, _góra_, blíb,
  { {0x7c29001f,0x610c005b,0x673b0066,0x00000000}},	//   haer, _ağla, áuje,
  { {0x7c294bbd,0x7ce5013d,0x60c24bbe,0x00000000}},	//   kaer, zóra, tnom,
  { {0x673b1d14,0xc2090063,0xa7fb0331,0x00000000}},	//   šuje, לה_, leña,
  { {0x14d7014e,0x7c294bbf,0x60c24bc0,0x00000000}},	//   _תוכל_, daer, rnom,
  { {0x60c2496f,0xb87b23d1,0xbd6a0816,0x00000000}},	//   snom, olíc, ерие_,
  { {0xc05a000d,0x78a44bc1,0x5c06014b,0x00000000}},	//   _прац_, _oliv, ляпа,
  { {0x35db0161,0xb87b00be,0x69dc0058,0x00000000}},	//   _मुफ़, ilíc, ürem,
  { {0x40930032,0x60e6008f,0xb87b004c,0x00000000}},	//   _القر, ārmē, hlíc,
  { {0x629e10da,0x44294bc2,0xc98602d8,0x00000000}},	//   nkpo, zaa_, гуми,
  { {0x78a44bc3,0x2d9806a5,0x6d5a0168,0x00000000}},	//   _bliv, _ære_, _upta,
  { {0xe3bf006d,0x61e101e1,0x7cc8004c,0x00000000}},	//   _leña_, _ølle, běra,
  { {0x4429024a,0xfcd3007e,0xb87b006d,0x00000000}},	//   vaa_, _اينج, elíc,
  { {0x2d9800ea,0xdce1001c,0x6e2a00ca,0x00000000}},	//   _üres_, _islā, nafb,
  { {0x44294bb8,0x26c300c3,0x2903013d,0x00000000}},	//   taa_, rnjo_, íjat_,
  { {0x6e2a001f,0xb87b004c,0x69c60058,0x00000000}},	//   hafb, slíb, şkes,
  { {0x26c300c3,0x442900fe,0xe29f0026,0x00000000}},	// [8ff0] pnjo_, raa_, _auða_,
  { {0x7ce5007a,0xb6030080,0x44294bc4,0x00000000}},	//   jórn, část, saa_,
  { {0x442900fe,0x27ec0051,0x78a40072,0x00000000}},	//   paa_, ędne_, _yliv,
  { {0x657a00b9,0x6f0d00ed,0x98a6008f,0x00000000}},	//   æthe, íaco, oslā_,
  { {0x7ce50016,0x3aeb00d1,0x68ed0139,0x00000000}},	//   fórn, løpe_, _mhad,
  { {0x1eea006a,0x63ad0379,0x7cc1008f,0x00000000}},	//   نونی_, mzan, mēri,
  { {0x200e0026,0x63ad4bc5,0xd3950085,0x00000000}},	//   ækið_, lzan, лiчэ,
  { {0x63ad00a8,0x3f150054,0x68ed002b,0x00000000}},	//   ozan, _вдас, _nhad,
  { {0x63ad4bc6,0x7c84005e,0xbf1501fb,0x00000000}},	//   nzan, сује, _ضواب,
  { {0xdfd8011c,0x60c902ab,0x7ce500be,0x00000000}},	//   _със_, _hjem, córn,
  { {0x60c90031,0x26c40024,0x7e6300fe,0x00000000}},	//   _kjem, émom_, menp,
  { {0xe45f0137,0x68ed4bc7,0x6d434bc8,0x00000000}},	//   _sjön_, _chad, muna,
  { {0x78a40080,0x6d434bc9,0x6105005f,0x00000000}},	//   _vliv, luna, _dėli,
  { {0x96ba0001,0x63ad1a03,0x7e634bca,0x00000000}},	//   туму_, dzan, nenp,
  { {0x68ed0025,0x6d434bcb,0x63ad007c,0x00000000}},	//   _fhad, nuna, ezan,
  { {0xa7fb02dd,0x60c94bcc,0x78a44bcd,0x00000000}},	//   seña, _njem, _uliv,

  { {0x7ae100bd,0xe3bf006d,0xa7fb006d,0x00000000}},	// [9000] ollt, _peña_, peña,
  { {0x29074bce,0xb87b0530,0x52830416,0x00000000}},	//   _kuna_, plíc, огуб,
  { {0x14c8007e,0x29071a1d,0x629e4472,0x00000000}},	//   _مهدی_, _juna_, rkpo,
  { {0x3ea50a95,0x26d84bcf,0x6724006f,0x00000000}},	//   _allt_, loro_, _kwij,
  { {0x63ad0045,0x29074bd0,0x6e2a00ca,0x00000000}},	//   czan, _luna_, tafb,
  { {0x8d76006a,0x60c9048e,0x6d430026,0x00000000}},	//   لاعا, _ejem, funa,
  { {0x7d78006a,0xed87005a,0x6d434bd1,0x00000000}},	//   امبر_, исък_, guna,
  { {0x60c900d1,0x7ae120e1,0xbf66005d,0x00000000}},	//   _gjem, ellt, _پدرو,
  { {0x7ac6183f,0x26d84bd2,0x290700a4,0x00000000}},	//   исое, koro_, _auna_,
  { {0x781f0161,0x68ed04c2,0x239a0006,0x00000000}},	//   पर्क_, _shad, mąją_,
  { {0x63ad4bd3,0x2907006d,0x26d80aca,0x00000000}},	//   zzan, _cuna_, doro_,
  { {0x7ae1002b,0x7cc8004c,0x63ad17c1,0x00000000}},	//   allt, měro, yzan,
  { {0x610500eb,0xc0530063,0x26d81928,0x00000000}},	//   _vėli, חזר_, foro_,
  { {0x26d800f3,0xdb9b0063,0x2567002b,0x00000000}},	//   goro_, _בסדר, _pŵl_,
  { {0x2907053b,0x98c70076,0x6e282118,0x00000000}},	//   _guna_, _вспл, _medb,
  { {0x63ad23c4,0x7cc1003d,0x79fb0063,0x00000000}},	//   tzan, tēri, _בלוח,
  { {0x78bd021e,0x92590002,0x26d84415,0x00000000}},	// [9010] misv, лаат_, boro_,
  { {0x7d080162,0xa7fb006d,0x6d434bd4,0x00000000}},	//   _ouds, leño, yuna,
  { {0x2f0b010a,0x7cc80080,0x63ad1149,0x00000000}},	//   _søg_, věrn, szan,
  { {0xa49b00cd,0x7cc1001c,0x61140086,0x00000000}},	//   _diòc, pēri, ідчу,
  { {0x7e634bd5,0x7ae14bd6,0x70520021,0x00000000}},	//   tenp, yllt, سنوا,
  { {0x6d434bd7,0x7d080666,0xce490121,0x00000000}},	//   tuna, _buds, узке_,
  { {0x6d430019,0x2ca613e5,0x78bd0014,0x00000000}},	//   uuna, _blod_, kisv,
  { {0x60c90198,0x60db0035,0x629500ea,0x00000000}},	//   _ujem, _ukum, _hozo,
  { {0x6d434bd8,0x2900004b,0xa3d70053,0x00000000}},	//   suna, _riia_, िथि_,
  { {0x6d434bd9,0x29000019,0x29074bda,0x00000000}},	//   puna, _siia_, _puna_,
  { {0x26d802f6,0xf769014e,0x382a0076,0x00000000}},	//   voro_, _רק_, лжно_,
  { {0x78bd0014,0x2ca61e64,0xfc640062,0x00000000}},	//   gisv, _glod_, _мъчн,
  { {0x6f0902dd,0x29000019,0x26d84bdb,0x00000000}},	//   _juec, _viia_, toro_,
  { {0xd63a0088,0x87b90076,0x78bd0078,0x00000000}},	//   ыямі_, руют_, aisv,
  { {0x26d80009,0xaab40021,0x38a90003,0x00000000}},	//   roro_, _بإنش, _sûre_,
  { {0x6724006f,0x394500cd,0x26d84bdc,0x00000000}},	//   _twij, muls_, soro_,
  { {0x26d82b92,0x60d912a9,0x64980014,0x00000000}},	// [9020] poro_, dowm, _síis,
  { {0x7cc1001c,0x645600e5,0xe7b7009a,0x00000000}},	//   mēru, sfyi, _להפר_,
  { {0xb87b0139,0x6e284bdd,0x62950e96,0x00000000}},	//   ilín, _redb, _dozo,
  { {0xef86000d,0x239a0078,0x7ce50331,0x00000000}},	//   йлеп, tąją_, fórm,
  { {0x7d08017f,0x44204bde,0x3ebc3a03,0x00000000}},	//   _suds, mbi_, tivt_,
  { {0x44204bdf,0xf67a0047,0x6f0916cd,0x00000000}},	//   lbi_, ראַמ, _duec,
  { {0x6e2805b9,0x442006d8,0xb05b004c,0x00000000}},	//   _vedb, obi_, ížít,
  { {0x62950009,0x3ebc0b19,0xa06a0062,0x00000000}},	//   _zozo, sivt_, _щаба_,
  { {0x4420005b,0x20870121,0x43bb0047,0x00000000}},	//   ibi_, _уйти_, ָזיג,
  { {0xaab40086,0x3f52001f,0x1d0a005e,0x00000000}},	//   ійні, mâu_, _бежи_,
  { {0x7d08004b,0x195827b8,0x78bd4be0,0x00000000}},	//   _uuds, шаны_, tisv,
  { {0xab2a0635,0x23690051,0x4420007d,0x00000000}},	//   _бода_, ywaj_, jbi_,
  { {0x274b0076,0x98b8005a,0x442002e2,0x00000000}},	//   ычно_, слят_, dbi_,
  { {0x7bdc005b,0xa7fb006d,0xb87b039f,0x00000000}},	//   ğrud, seño, clín,
  { {0x3abb014e,0x62950024,0x7d024be1,0x00000000}},	//   _תמונ, _rozo, _kios,
  { {0x58d4005a,0x44204be2,0xd498023b,0x00000000}},	//   _нощт, gbi_, бру_,
  { {0xb87b0025,0x7d0201f4,0x9972004c,0x00000000}},	// [9030] llío, _mios, věře_,
  { {0x7d020027,0xf8bf0164,0x44204acf,0x00000000}},	//   _lios, lié_, abi_,
  { {0x44200d11,0x6f0916a5,0xda5b0047,0x00000000}},	//   bbi_, _suec, רכבל,
  { {0xe1f00021,0xb87b0025,0xf8bf0003,0x00000000}},	//   رسل_, ilío, nié_,
  { {0x289c00b5,0x6f094be3,0xc0582049,0x00000000}},	//   װיגא, _quec, сіх_,
  { {0x236f0026,0x6f090331,0xfd1100f2,0x00000000}},	//   ægju_, _vuec, وجب_,
  { {0x31350138,0x442b4be4,0xcc890076,0x00000000}},	//   _фебр, _kec_, ибке_,
  { {0x8027007e,0x7ce50051,0xdfd50076,0x00000000}},	//   _درآم, mórk, _добы,
  { {0xf8bf0164,0xcec8008b,0x7d024be5,0x00000000}},	//   dié_, uộc_, _dios,
  { {0x3a990121,0x4420007d,0x7cc1008f,0x00000000}},	//   ртию_, zbi_, eērt,
  { {0xf8bf0164,0x44391531,0x4420001f,0x00000000}},	//   fié_, _ods_, ybi_,
  { {0x2d53017d,0x7d024be6,0x98a60006,0x00000000}},	//   mãe_, _gios, kslą_,
  { {0x2cad010a,0x7a4300ea,0x442000a8,0x00000000}},	//   mhed_, gítü, vbi_,
  { {0x4439359a,0x2cad00b9,0x96b9000d,0x00000000}},	//   _ads_, lhed_, бусу_,
  { {0x9876005e,0xa6e30014,0x94963320,0x00000000}},	//   _дупљ, úðar, ошач,
  { {0x2cad0146,0x032633e7,0xf8bf0164,0x00000000}},	//   nhed_, ждан, cié_,
  { {0x72360021,0x7c2b0090,0x2bf60041,0x00000000}},	// [9040] قراط, _megr, ַמען_,
  { {0x644f17c2,0x36c30121,0x44204be7,0x00000000}},	//   _ecci, _обыг, sbi_,
  { {0x7c390051,0x2d930137,0x7ce50022,0x00000000}},	//   _odwr, äxel_, górk,
  { {0x6ee400cd,0x7c2b0955,0x8fa6007e,0x00000000}},	//   mòbi, _negr, يماه,
  { {0xf8b3014e,0xbe8a14cf,0x2cad05b9,0x00000000}},	//   ושא_, иске_, dhed_,
  { {0xbea30138,0xfd380021,0x7d020051,0x00000000}},	//   мачк, مكتب_, _sios,
  { {0x7c2b2767,0x7d020051,0x7176007e,0x00000000}},	//   _begr, _pios, _بهزا,
  { {0x442b0268,0x2cad08dc,0x61ee007d,0x00000000}},	//   _xec_, ghed_, _izbl,
  { {0x7cc1003d,0x320d005b,0x7c2b2c7c,0x00000000}},	//   vērt, _şeyi_, _degr,
  { {0x23620089,0x7d020051,0xdcea005b,0x00000000}},	//   _mpkj_, _wios, ınır,
  { {0xf8bf0164,0xfbcf007e,0x7d023473,0x00000000}},	//   tié_, فتی_, _tios,
  { {0xb87b0027,0x7c2b11a9,0x2cad2854,0x00000000}},	//   rlío, _gegr, ched_,
  { {0x07a40088,0xf8bf0164,0x2918031c,0x00000000}},	//   даўн, rié_, ūra_,
  { {0x673b00c2,0x6ee401a8,0xda660044,0x00000000}},	//   šujo, fòbi, _ذاتي,
  { {0x442b4be8,0x25a500ea,0xf98f0021,0x00000000}},	//   ицам_, áll_, _لبي_,
  { {0x291e32c9,0x47350a91,0x64c50044,0x00000000}},	//   mpta_, _енис, أيرل,
  { {0xa6db0026,0x442b4be9,0x7ce50022,0x00000000}},	// [9050] arða, _vec_, wórk,
  { {0x7cd3000c,0x98a60006,0xb87b0139,0x00000000}},	//   măre, rslą_, ilím,
  { {0x44392322,0x7cd3003b,0x96f80044,0x00000000}},	//   _tds_, lăre, _بعير_,
  { {0x644f051e,0x26c40024,0x291e0078,0x00000000}},	//   _ucci, émov_, ipta_,
  { {0xddc801d9,0xb4d70053,0x7cd3003b,0x00000000}},	//   _radš, ाकी_, năre,
  { {0x7ce52c88,0xa137007e,0x7c2b4bea,0x00000000}},	//   móri, _ورزش, _segr,
  { {0x7ce54beb,0x6287006c,0x2cad0a76,0x00000000}},	//   lóri, _injo, thed_,
  { {0x7cc1001c,0x27180080,0x6aaa002b,0x00000000}},	//   vērs, něný_, _alff,
  { {0x5f77006a,0x2cad0146,0xce6b0121,0x00000000}},	//   _بازر, rhed_, _вред_,
  { {0x2cad1729,0xa6db0026,0x8d770021,0x00000000}},	//   shed_, yrða, _واضا,
  { {0xa9692377,0x25db0053,0xa6db0014,0x00000000}},	//   щина_, _खुली_, auðk,
  { {0x66150051,0x2904065e,0x6d5c004e,0x00000000}},	//   eczk, öma_, _äraa,
  { {0x291e000c,0x7cd3003b,0x8bb70021,0x00000000}},	//   apta_, găre, _بإضا,
  { {0x6d434bec,0xba390041,0x644d0b97,0x00000000}},	//   orna, _הײַט, egai,
  { {0x98a61d11,0x3171056c,0x69dc009c,0x00000000}},	//   _нике, _nszz_, üret,
  { {0x644d0150,0x7cc8004c,0x6287463b,0x00000000}},	//   ggai, věrk, _anjo,
  { {0x7cd3000c,0x7ce54bed,0x6306007e,0x00000000}},	// [9060] căre, góri, سوال,
  { {0x96960001,0x644d4bee,0x67bb009a,0x00000000}},	//   _хриш, agai, _למפק,
  { {0x8066100b,0xd24f007e,0xa00a0021,0x00000000}},	//   звеж, انم_, مقال_,
  { {0x628716c0,0x6d4300c2,0x765c002b,0x00000000}},	//   _enjo, drna, lfry,
  { {0x44324bef,0x6d4336e7,0x98bf003b,0x00000000}},	//   may_, erna, lută_,
  { {0x7f423141,0x44324bf0,0x60cb00a4,0x00000000}},	//   rroq, lay_, angm,
  { {0xacf8000d,0x98bf000c,0x4c94047e,0x00000000}},	//   онку_, nută_, дийс,
  { {0x443200bb,0x7f420003,0x6eed00ea,0x00000000}},	//   nay_, proq, rúba,
  { {0x6d434bf1,0x66150022,0x9e5a0121,0x00000000}},	//   arna, yczk, _греф_,
  { {0x44324bf2,0x60c24bf3,0xfa8a0121,0x00000000}},	//   hay_, liom, ссий_,
  { {0x05db0235,0x28f90086,0x765c001f,0x00000000}},	//   _मुंब, жень_, dfry,
  { {0x7cd3003b,0x44324bf4,0x60c24bf5,0x00000000}},	//   tăre, jay_, niom,
  { {0x765c001f,0xe7870001,0x443205fc,0x00000000}},	//   ffry, чуно, day_,
  { {0x291e0a2e,0x6d58006f,0x69dc0058,0x00000000}},	//   ppta_, otva, üres,
  { {0xda5b0063,0xa6db0026,0xddd80080,0x00000000}},	//   _הכול, nuði, tevř,
  { {0x44320273,0x7ce54bf6,0xb8820024,0x00000000}},	//   gay_, tóri, šíre,
  { {0x883c0063,0x78ad005b,0x28580021,0x00000000}},	// [9070] _התחו, _ilav, _رؤية_,
  { {0x78ad0512,0x6d4a0035,0x3860007d,0x00000000}},	//   _hlav, kufa, _zbir_,
  { {0x44320389,0x98bf000c,0x7ce5017d,0x00000000}},	//   bay_, cută_, sóri,
  { {0x26c300c3,0xd138126b,0x998c004c,0x00000000}},	//   lijo_, яху_, hadů_,
  { {0x7eaf0031,0x6d58008f,0x6d43002b,0x00000000}},	//   _løpe, etva, wrna,
  { {0x26c300c3,0x7fb60032,0x78ad234b,0x00000000}},	//   nijo_, ظهور_, _llav,
  { {0x6d434bf7,0x78ad4bf8,0x00000000,0x00000000}},	//   urna, _olav,   ,
  { {0x7ae800f5,0xdb00006c,0x5ba90505,0x00000000}},	//   eldt, lymè, жким_,
  { {0x98bf003b,0x1ee7007e,0xa6db0014,0x00000000}},	//   zută_, _فوری_, auði,
  { {0xa9a50444,0x26c300c2,0x44324bf9,0x00000000}},	//   диод, jijo_, zay_,
  { {0x26c3146a,0x78ad20eb,0x7bce004d,0x00000000}},	//   dijo_, _blav, ßbur,
  { {0x78ad4bfa,0x30790047,0x644a00ea,0x00000000}},	//   _clav, קאָנ, őfiz,
  { {0x610c01f7,0x26c34bfb,0x69dc0058,0x00000000}},	//   _işle, fijo_, ürer,
  { {0x26c30057,0x60c20051,0x78ad032e,0x00000000}},	//   gijo_, ziom, _elav,
  { {0x7cd30529,0x9985006a,0x44324bfc,0x00000000}},	//   cărc, _آلبو, tay_,
  { {0x78ad06bb,0x61fa0026,0x7f4b00ac,0x00000000}},	//   _glav, _útli, kugq,
  { {0x26c300c3,0xa8570063,0x6d4a004d,0x00000000}},	// [9080] bijo_, _חיפה_, zufa,
  { {0x26c30198,0x44324bfd,0x98bf003b,0x00000000}},	//   cijo_, say_, pută_,
  { {0x44324bfe,0x211a007e,0x6d580137,0x00000000}},	//   pay_, زتاب_, xtva,
  { {0x394500e5,0x4fea032d,0xf2c9009a,0x00000000}},	//   irls_, омен_, בע_,
  { {0x7ae802ab,0x60c24bff,0x9ffa0044,0x00000000}},	//   yldt, riom, آراء_,
  { {0x412a0054,0xb7db0063,0x60c24c00,0x00000000}},	//   _мого_, חקני, siom,
  { {0x629c0035,0x63a408d2,0x68e4007d,0x00000000}},	//   _ioro, lyin, _okid,
  { {0x26c300c3,0x5ba6013c,0x629c4476,0x00000000}},	//   zijo_, дроз, _horo,
  { {0xcb670259,0x63a44c01,0x6d584c02,0x00000000}},	//   дање_, nyin, stva,
  { {0x3b070164,0x610c01f7,0x68e4053b,0x00000000}},	//   _cinq_, _eşle, _akid,
  { {0x26c300c3,0x629c4c03,0xc27b0063,0x00000000}},	//   vijo_, _moro, קרטי,
  { {0xa9c3019d,0x63a400fe,0x7afd0006,0x00000000}},	//   тськ, kyin, įsta,
  { {0x26c300c3,0x2fc00025,0x7afd0080,0x00000000}},	//   tijo_, úigh_, ůsta,
  { {0x63a40034,0xeb970001,0x7cd3000c,0x00000000}},	//   dyin, _циљ_, măra,
  { {0x26c300c3,0x95c50021,0xddc3003b,0x00000000}},	//   rijo_, ريره, menţ,
  { {0x63a40034,0x26c300c3,0xddc3000c,0x00000000}},	//   fyin, sijo_, lenţ,
  { {0x26c300c3,0x7ce50139,0x92a60022,0x00000000}},	// [9090] pijo_, mórt, _odłą,
  { {0xd25b0088,0x27e91362,0xddc3000c,0x00000000}},	//   ўца_, _iyan_, nenţ,
  { {0x610c0058,0xa6db0014,0x629c4c04,0x00000000}},	//   _oğlu, fuðv, _doro,
  { {0x50b8007e,0x672d4c05,0x6b824c06,0x00000000}},	//   ودند_, _kwaj, _orog,
  { {0x63b60045,0x93b4000d,0x629c4c07,0x00000000}},	//   czyn, _абяц, _foro,
  { {0xd3560063,0x1d090086,0x629c4c08,0x00000000}},	//   _אישי_, пеки_, _goro,
  { {0xddc30529,0x6114000d,0x20120139,0x00000000}},	//   denţ, _адсу, íniú_,
  { {0xf1b20047,0x8b950121,0xeb99350e,0x00000000}},	//   _עסן_, ероч, зии_,
  { {0x68f60185,0x7c840001,0x7cd3003b,0x00000000}},	//   _rhyd, тује, găra,
  { {0xddc3000c,0xdd95000d,0x2ef402d8,0x00000000}},	//   genţ, _пазы, _азур,
  { {0x6b820290,0xa6db0026,0x27e92e10,0x00000000}},	//   _erog, nuðu, _ayan_,
  { {0x2d980268,0x3bb90e82,0x6b824c09,0x00000000}},	//   _àrea_, _нулю_, _frog,
  { {0x6b824c0a,0x63a44c0b,0x27e94c0c,0x00000000}},	//   _grog, xyin, _cyan_,
  { {0xddc3000c,0x9f5600ea,0x27e900a4,0x00000000}},	//   cenţ, égét_, _dyan_,
  { {0x24f6000d,0xf3f7008d,0x68f6002b,0x00000000}},	//   ечар, ệng_, _thyd,
  { {0x629c4c0d,0x68e4007d,0x63a40b70,0x00000000}},	//   _soro, _ukid, tyin,
  { {0x629c11d7,0x88bd0080,0xd8d70047,0x00000000}},	// [90a0] _poro, spěc, _רופט_,
  { {0x7ae11bb2,0x35db0053,0x63b60051,0x00000000}},	//   nolt, _मुक़, rzyn,
  { {0x06570047,0x63b60051,0x629c4c0e,0x00000000}},	//   _אייך_, szyn, _voro,
  { {0xddc3000c,0x69d50058,0xdcfa008f,0x00000000}},	//   zenţ, üzey, _ortā,
  { {0x3fc6007e,0x6eed100f,0xa6db0014,0x00000000}},	//   رگری_, públ, auðu,
  { {0x7cd3000c,0xfe6f0021,0x629c005f,0x00000000}},	//   văra, مدى_, _uoro,
  { {0xddc3003b,0x2a6c00c2,0x6b820022,0x00000000}},	//   venţ, vedb_, _srog,
  { {0x91e303ec,0x1d070001,0x7ae10025,0x00000000}},	//   _сосе, неји_, eolt,
  { {0xddc30529,0x1fb50002,0x7ac605bd,0x00000000}},	//   tenţ, _исфр, есне,
  { {0x394c0268,0x27e9172e,0x7f3b009a,0x00000000}},	//   tuds_, _ryan_, _מעמו,
  { {0x200d01f7,0xddc3000c,0xd2b70063,0x00000000}},	//   şmiş_, renţ, גלית_,
  { {0x0137014e,0xeb9a0431,0x7cd3000c,0x00000000}},	//   ערכת_, _ние_, păra,
  { {0x28c00053,0xddc30266,0xfaa60dc8,0x00000000}},	//   शोधि, menš, _падо,
  { {0x7ae14c0f,0x38a20025,0xcf930047,0x00000000}},	//   colt, _sórt_, אטש_,
  { {0x7ce51397,0xba170041,0x45d44c10,0x00000000}},	//   pórt, _אחוץ_, горс,
  { {0xa6db0014,0x4277005d,0x00000000,0x00000000}},	//   vuðu, کارآ,   ,
  { {0x644b00cd,0x27e9005b,0xcb130041,0x00000000}},	// [90b0] ògiq, _uyan_, ָלע_,
  { {0x7e7a017f,0xa6db0026,0x6448008f,0x00000000}},	//   _natp, tuðu, _ēdie,
  { {0x2167000d,0x7cd300dd,0x3f84004e,0x00000000}},	//   этаг, dărn, _armu_,
  { {0xc5f20132,0x7ae100ea,0xa6db0014,0x00000000}},	//   _כדי_, zolt, ruðu,
  { {0x4429058c,0xef180086,0x64360047,0x00000000}},	//   mba_, емі_, _בארא_,
  { {0x7bdc01f7,0x442947cd,0xa6db0014,0x00000000}},	//   ğrul, lba_, puðu,
  { {0x6917001c,0x7ae14c11,0x2918004c,0x00000000}},	//   _aģen, volt, íral_,
  { {0xfebb007e,0xb062004b,0x4c854990,0x00000000}},	//   _کارت_, äätm, тлив,
  { {0x7ae1013d,0xdb140014,0x44294c12,0x00000000}},	//   tolt, óaðr, iba_,
  { {0x2b4d00cd,0x7ae10072,0x7afd0078,0x00000000}},	//   ruec_, uolt, įsto,
  { {0x2d9a0031,0x98bf232c,0x44294c13,0x00000000}},	//   øpet_, lutę_, kba_,
  { {0x7ae14c14,0xddc3008f,0xdd04003b,0x00000000}},	//   solt, cenš, ăpăd,
  { {0x98bf0915,0x44291bce,0x7ae14c15,0x00000000}},	//   nutę_, dba_, polt,
  { {0x442902dd,0x5ba8000d,0xbb4200e1,0x00000000}},	//   eba_, _якім_, _тешк,
  { {0x87070086,0x65c34c16,0x8a140021,0x00000000}},	//   терв_, абра, _إظها,
  { {0xbd020014,0x44294c17,0x7d1c013d,0x00000000}},	//   _þétt, gba_, _érse,
  { {0x130a000d,0x7c2906ee,0xb8e80042,0x00000000}},	// [90c0] днай_, iber, ोच_,
  { {0x4223000a,0xc87f004d,0x44294c18,0x00000000}},	//   идув, roße_, aba_,
  { {0x644b0297,0x98c60053,0xa2a30053,0x00000000}},	//   ógic, _लगाए, _गवर्,
  { {0xb87b0014,0x64a63266,0x4fa64c19,0x00000000}},	//   blíu, _рама, киев,
  { {0xd007000d,0xddc31e45,0xd348007e,0x00000000}},	//   веце_, venš, _سیاه_,
  { {0xb87b000f,0x6d5c0019,0x7c294c1a,0x00000000}},	//   llít, _ärak, eber,
  { {0x628e4c1b,0x127b00b5,0xbea3018e,0x00000000}},	//   _inbo, _קאלע, рајк,
  { {0x29180016,0xb87b00ea,0xfc660062,0x00000000}},	//   íram_, nlít, тъкн,
  { {0xe29f0026,0xb87b0139,0xaf060085,0x00000000}},	//   _guðs_, ilít, _апал,
  { {0xc333014e,0xa0210026,0x26c400cd,0x00000000}},	//   סות_, _þörf, èmol_,
  { {0x7c294c1c,0x7cd3003b,0x6e380137,0x00000000}},	//   bber, căro, mavb,
  { {0x8c430085,0xa8a702ac,0xb87b013d,0x00000000}},	//   _веце, трок, jlít,
  { {0x58d403d6,0x44294c1d,0x1d07005e,0x00000000}},	//   роят, vba_, _реци_,
  { {0xddda0006,0x6d4a2442,0x628e04aa,0x00000000}},	//   _natū, orfa, _nnbo,
  { {0xdce30051,0x44294c1e,0xbb7c007e,0x00000000}},	//   ewnę, tba_, _ﻣﻴﻠﻪ_,
  { {0x44294c1f,0x628e4c20,0xa6db0014,0x00000000}},	//   uba_, _anbo, irði,
  { {0x6d4a00bd,0xd8d80149,0x93f54c21,0x00000000}},	// [90d0] hrfa, _שוחט_, упац,
  { {0x7c291438,0xf1a70781,0xf1950054,0x00000000}},	//   zber, крен, лизь,
  { {0x25a500c7,0x6d5c004b,0x7c294c22,0x00000000}},	//   älld_, _ärah, yber,
  { {0x30a7005a,0xf1c30006,0x60190121,0x00000000}},	//   ързв, _rašė_, ходя_,
  { {0x7d0b2ef4,0x6d4a00bd,0x6f650021,0x00000000}},	//   _rigs, erfa, اهتم,
  { {0x7d0b00ac,0x999c00ea,0x7c294c23,0x00000000}},	//   _sigs, _levő_, wber,
  { {0x7c294c24,0x0dc8005e,0x6eed00be,0x00000000}},	//   tber, кући_, núbi,
  { {0x7c294c25,0x00000000,0x00000000,0x00000000}},	//   uber,   ,   ,
  { {0x2d9a0031,0x4fd50121,0x7d0b3be1,0x00000000}},	//   øper_, _сжат, _vigs,
  { {0x7c290b94,0x9957011b,0xb3650085,0x00000000}},	//   sber, _záře_, тнiч,
  { {0xb87b00f8,0x20c7002b,0x4aa40082,0x00000000}},	//   roín, nŵio_, _ओवरव,
  { {0x31560047,0x1cbb0021,0x88bd011b,0x00000000}},	//   װישן_, _غاضب_, spěn,
  { {0xcb69000d,0xf7720021,0x4c9a016e,0x00000000}},	//   _чале_, حاج_, _רבנו,
  { {0x2cad0d11,0x1bb80049,0x8aa74c26,0x00000000}},	//   lked_, _جامع_, _шред,
  { {0xd46a000a,0x2cad00e5,0x44fa000d,0x00000000}},	//   ниве_, oked_, ехаў_,
  { {0x2cad010e,0xc952009a,0x88360085,0x00000000}},	//   nked_, _המה_, _сэкц,
  { {0xe61a000a,0x577a0021,0x6d46008f,0x00000000}},	// [90e0] _пдп_, _أصبح_, _ākam,
  { {0xb87b004a,0xa6db0014,0x68e6004c,0x00000000}},	//   slít, yrði, lokd,
  { {0x673b00a2,0x2cad0526,0x67240130,0x00000000}},	//   šujt, kked_, _htij,
  { {0x25a54c27,0xbf0f0042,0x00000000,0x00000000}},	//   älle_, ादून_,   ,
  { {0xde580088,0xe3b200b3,0xbea6236a,0x00000000}},	//   валі_, _طرح_, ладк,
  { {0xb7db0047,0xdee30376,0x61050006,0x00000000}},	//   עקסי, бочи, _mėly,
  { {0xccf80080,0x81780063,0xed5702d8,0x00000000}},	//   _opět_, _בְּק, гој_,
  { {0x6e3800d1,0x26ca00a4,0x6d4a1205,0x00000000}},	//   savb, hibo_, rrfa,
  { {0x61ee1566,0x248000a8,0x9bd40054,0x00000000}},	//   _hybl, idim_, ржпі,
  { {0xee37000d,0x5a34026b,0x9e65007e,0x00000000}},	//   _бнф_, шнот, _نامن,
  { {0xfbcf007e,0xddc810f5,0xd9171224,0x00000000}},	//   قتی_, _hadž, лья_,
  { {0x2cad04ff,0x673d00b8,0x1c0d0042,0x00000000}},	//   cked_, tssj, _हलचल_,
  { {0xcc3b0047,0xdc3b0047,0xa3e40042,0x00000000}},	//   _טעאט, _טעאר, _पुल_,
  { {0x4b7b00b5,0xddc84c28,0xe6100021,0x00000000}},	//   _נאוו, _madž, كشف_,
  { {0x5694005e,0x999c013d,0x25aa00a3,0x00000000}},	//   љаст, _tevő_, gybl_,
  { {0xb4c10053,0xb87b4945,0x895b0063,0x00000000}},	//   ्चे_, rlís, _נדחת,
  { {0x36d50055,0x9259000a,0xd262008f,0x00000000}},	// [90f0] _вопр, каат_, kaņā_,
  { {0xccf80080,0x26ca0460,0x394c4c29,0x00000000}},	//   _zpět_, cibo_, ords_,
  { {0xc0cb0001,0xa4d9000d,0x65950777,0x00000000}},	//   нуде_, _адну_, _тану,
  { {0x3aeb0031,0x61ee001f,0x19570047,0x00000000}},	//   løpt_, _dybl, רבאל_,
  { {0x38694c2a,0xf43a0165,0xc43a3997,0x00000000}},	//   _mbar_, _בגרמ, _שתשי,
  { {0xa3d4000a,0x171c0047,0x8afd0080,0x00000000}},	//   _ѓорч, עווע, otře,
  { {0x403507a1,0xd6580063,0xf2d20063,0x00000000}},	//   _вебс, איות_, _ועם_,
  { {0x0b450d4c,0xae190082,0xad880044,0x00000000}},	//   анин, नुजन_, اضول_,
  { {0x2cad4c2b,0x88bd004c,0x7bc40078,0x00000000}},	//   rked_, rpěl, _žiur,
  { {0x2cad4c2c,0x88bd0080,0x4e7808aa,0x00000000}},	//   sked_, spěl, _محمد_,
  { {0x67244c2d,0x3aeb00d1,0x9f0401fb,0x00000000}},	//   _stij, døpt_, _اولو,
  { {0x254100eb,0xa3b50053,0x76450509,0x00000000}},	//   dėl_, जना_, _adhy,
  { {0x26ca00bb,0x394c4c2e,0xdb230043,0x00000000}},	//   tibo_, ards_, _اوتی,
  { {0x61050078,0xff160063,0xceb20063,0x00000000}},	//   _vėly, יקשת_, ֗ים_,
  { {0xceb20132,0xe5060032,0x6aa30025,0x00000000}},	//   חים_, لبري, _ionf,
  { {0x26ca00a4,0xdce10023,0x6aa301e0,0x00000000}},	//   sibo_, _islē, _honf,
  { {0xa6db0026,0x03232ab5,0xd497008b,0x00000000}},	// [9100] erðu, ждун, ờng_,
  { {0x23600122,0x6d410755,0x7c3b4c2f,0x00000000}},	//   rtij_, _ovla, haur,
  { {0x6aa34c30,0x23604c31,0x78a41b6f,0x00000000}},	//   _monf, stij_, _koiv,
  { {0xef8606b4,0xcfa60f8d,0x7bdc0058,0x00000000}},	//   илеп, ишли, şrui,
  { {0x7ccd003d,0x6fd60021,0x44220ede,0x00000000}},	//   _mērķ, جزائ, _ifk_,
  { {0x44204c32,0x6aa34c33,0x78a40072,0x00000000}},	//   lci_, _nonf, _loiv,
  { {0x61433266,0x5096005e,0x40961e1b,0x00000000}},	//   _мера, _крађ, _крат,
  { {0x44204c34,0x78a4017d,0x9da70062,0x00000000}},	//   nci_, _noiv, ръша_,
  { {0x4420000c,0x3d160053,0xa3d60053,0x00000000}},	//   ici_, _पूरे_, िपि_,
  { {0x9d460062,0x78b60078,0x6aa34c35,0x00000000}},	//   _вежд, _alyv, _conf,
  { {0x3f86017d,0x442022b6,0x64460066,0x00000000}},	//   lvou_, kci_, _odki,
  { {0x3f860260,0x4420389e,0x7c3b2093,0x00000000}},	//   ovou_, jci_, caur,
  { {0x78a40164,0x274b005a,0x44200574,0x00000000}},	//   _doiv, ъчно_, dci_,
  { {0x44204c36,0x6aa34c37,0xa6db0014,0x00000000}},	//   eci_, _gonf, yrðu,
  { {0x78b602ab,0x63a200fe,0x4a310024,0x00000000}},	//   _flyv, äonn, äčší_,
  { {0x61e20058,0xa6db0046,0x499b009a,0x00000000}},	//   ğoll, erðt, _ישוב,
  { {0x8afd02f4,0x43740086,0x68ed007d,0x00000000}},	// [9110] stře, жуєт, _ikad,
  { {0x7c3b1308,0xd5b1008d,0x44204c38,0x00000000}},	//   zaur, ớ_, aci_,
  { {0x7afd0229,0x60cb4c39,0x7c22007d,0x00000000}},	//   ïsti, tigm, _ofor,
  { {0x44201665,0x212a007e,0x7c224c3a,0x00000000}},	//   cci_, اينی_, _nfor,
  { {0x9203001c,0x44394c3b,0xb4fa0063,0x00000000}},	//   _šādi, _ies_, _תפרי,
  { {0x7cd30529,0xaec40636,0x9e3c0066,0x00000000}},	//   mări, обіл, _poďa,
  { {0x443924ed,0x7cd3000c,0xddc80051,0x00000000}},	//   _kes_, lări, _gadż,
  { {0x25d80132,0x63ad4c3c,0x88bd004c,0x00000000}},	//   יוון_, oyan, spěj,
  { {0xdcb100aa,0x7cd3000c,0x60db0035,0x00000000}},	//   _của_, nări, _ijum,
  { {0x44394c3d,0x2b4d0268,0x6aba0034,0x00000000}},	//   _les_, rrec_, ghtf,
  { {0x7c220185,0x44390185,0x63ad053b,0x00000000}},	//   _ffor, _oes_, hyan,
  { {0x26de0024,0xfdf60063,0x443948cd,0x00000000}},	//   čtom_, _הצעת_, _nes_,
  { {0xef190045,0x78a4024a,0x7cd3003b,0x00000000}},	//   _już_, _voiv, jări,
  { {0x63ad2a43,0x645d0150,0xfbd00021,0x00000000}},	//   dyan, _acsi, _تتم_,
  { {0x3ea50994,0x78a40659,0x60c900c2,0x00000000}},	//   _molt_, _toiv, _omem,
  { {0x443903b2,0x25a500c7,0x2d870019,0x00000000}},	//   _ces_, älla_, ivne_,
  { {0x44394c3e,0x7cd3000c,0x63ad4c3f,0x00000000}},	// [9120] _des_, gări, gyan,
  { {0x44204c40,0x7c390089,0x4439152e,0x00000000}},	//   sci_, _lewr, _ees_,
  { {0xc693014e,0x44390268,0x998500eb,0x00000000}},	//   _זאת_, _fes_, malų_,
  { {0x7cd3000c,0x644600b9,0x44394c41,0x00000000}},	//   bări, _udki, _ges_,
  { {0x7cd30529,0x2d8700b9,0x3ea50d11,0x00000000}},	//   cări, evne_, _bolt_,
  { {0x44390122,0x99850006,0x7c224c42,0x00000000}},	//   _zes_, nalų_, _sfor,
  { {0x11da0021,0x6da3018e,0x44393631,0x00000000}},	//   _صورة_, зија, _yes_,
  { {0x2912002c,0x3ce00ecf,0x7c39002b,0x00000000}},	//   _niya_, čivo_, _cewr,
  { {0xdfcf0032,0x99850006,0x2d874c43,0x00000000}},	//   _كيف_, kalų_, avne_,
  { {0x9e66006a,0x68ed2715,0xac98007e,0x00000000}},	//   _دارن, _skad, انکا_,
  { {0x7cd3000c,0x29000139,0x25ed0042,0x00000000}},	//   zări, _bhia_, _आँधी_,
  { {0x2900001b,0x7c224c44,0x7c390d27,0x00000000}},	//   _chia_, _ufor, _gewr,
  { {0x7d1a0474,0x7cd3003b,0x44394c45,0x00000000}},	//   _huts, xări, _res_,
  { {0x44394c46,0x99850006,0x7d1a4c47,0x00000000}},	//   _ses_, galų_, _kuts,
  { {0x2ca60019,0x443940b4,0x7d1a4c48,0x00000000}},	//   _kood_, _pes_, _juts,
  { {0x7cd30529,0x68ed0035,0x63ad4c49,0x00000000}},	//   tări, _ukad, tyan,
  { {0x7eb400cd,0x44394c4a,0x2ca64c4b,0x00000000}},	// [9130] _nàpo, _ves_, _mood_,
  { {0x4439021f,0x7d1a0034,0x7cd3000c,0x00000000}},	//   _wes_, _outs, rări,
  { {0x7d1a021f,0x7cd3000c,0x44394c4c,0x00000000}},	//   _nuts, sări, _tes_,
  { {0x7cd3000c,0x4395005a,0x2ca64c4d,0x00000000}},	//   pări, _дамс, _nood_,
  { {0x7c390034,0x2d8c1ba7,0x987c0aeb,0x00000000}},	//   _rewr, _arde_, טראק,
  { {0x7d1a006c,0x3da90e82,0x9758009a,0x00000000}},	//   _buts, икло_, מידו_,
  { {0x3ea5000f,0x2ca6006f,0x6295006f,0x00000000}},	//   _volt_, _bood_, _inzo,
  { {0x60db10ca,0x60c905b3,0xef190051,0x00000000}},	//   _ujum, _umem, _tuż_,
  { {0x2d8c00bd,0xdb0000fe,0x2ca60173,0x00000000}},	//   _erde_, kymä, _dood_,
  { {0x2912002c,0x23ca0047,0x62854c4e,0x00000000}},	//   _siya_, יצפּ, ndho,
  { {0x6ce70086,0x2ca63bea,0x7d1a004d,0x00000000}},	//   _ліде, _food_, _guts,
  { {0x2ca62c2f,0x6140013d,0x6d430046,0x00000000}},	//   _good_, _hálá, msna,
  { {0x6d4334fe,0x99850078,0x25a500a5,0x00000000}},	//   lsna, talų_, älln_,
  { {0x6d430139,0x6b890014,0x87b90121,0x00000000}},	//   osna, mveg, суют_,
  { {0x6b8921ef,0x99850078,0x2918004c,0x00000000}},	//   lveg, ralų_, írat_,
  { {0x7afd0006,0x6285004d,0x78bd004d,0x00000000}},	//   įstu, edho, chsv,
  { {0xd387047e,0xd6d20021,0x6b894c4f,0x00000000}},	// [9140] ойте_, _يقع_, nveg,
  { {0x7cd30529,0x33d50086,0x7ce50051,0x00000000}},	//   măru, чіст, górz,
  { {0x64a60138,0x998c0045,0x81d6000d,0x00000000}},	//   _дана, wadź_, ццац,
  { {0x3f8d0268,0x62950122,0x6d4330d0,0x00000000}},	//   _breu_, _enzo, dsna,
  { {0x2ca60122,0x3f8d4c50,0x7cd3003b,0x00000000}},	//   _rood_, _creu_, năru,
  { {0xde930001,0x1c0d0053,0x765c00ac,0x00000000}},	//   дашњ, ाइनल_, ngry,
  { {0x6d4301b9,0x2ca60019,0x6b894c51,0x00000000}},	//   gsna, _pood_, eveg,
  { {0x5c98011c,0x6e3a006f,0x44324c52,0x00000000}},	//   ския_, _wetb, nby_,
  { {0xae7a0055,0x3f8d4c53,0xdb000072,0x00000000}},	//   _всех_, _greu_, yymä,
  { {0x2ca604bf,0x2d8c00a8,0xaa58005e,0x00000000}},	//   _wood_, _trde_, љину_,
  { {0x44320051,0xc957000d,0x79f40062,0x00000000}},	//   kby_, оўя_, язох,
  { {0x6d580019,0x7bdc004d,0x7cd300dd,0x00000000}},	//   muva, ßrus, făru,
  { {0xacd900b5,0xdb0000fe,0x6bd60021,0x00000000}},	//   _פֿעי, tymä, _بتار,
  { {0x6d5824a4,0x4814000d,0x98a60078,0x00000000}},	//   ouva, ьмяс, kslė_,
  { {0xa3d00053,0x6283017d,0x79a60002,0x00000000}},	//   _वेब_, ônom, _фрле,
  { {0xda78004c,0xdb000072,0x19bb0063,0x00000000}},	//   leď_, symä, _כמוב,
  { {0x7cd3000c,0x7ce50051,0x6d5841e5,0x00000000}},	// [9150] căru, tórz, huva,
  { {0x6d580d9e,0x291c00fe,0x44323e7e,0x00000000}},	//   kuva, _kuva_, aby_,
  { {0x6d584c54,0xa6960063,0x6285144b,0x00000000}},	//   juva, _זכתה_, rdho,
  { {0x3f8d0268,0x26d10b7e,0x6d580019,0x00000000}},	//   _preu_, lizo_, duva,
  { {0x6d5800ac,0x69c112a9,0x291c4c55,0x00000000}},	//   euva, zzle, _luva_,
  { {0x26d10460,0x6d432909,0xc7d80063,0x00000000}},	//   nizo_, tsna, חודי_,
  { {0x7d020027,0x6d58004b,0x6d4312b8,0x00000000}},	//   _bhos, guva, usna,
  { {0x6d4303a8,0x1c450086,0x765c0051,0x00000000}},	//   rsna, чним, zgry,
  { {0x38a20051,0x3af5000d,0x26d105b3,0x00000000}},	//   _góry_, зянс, kizo_,
  { {0x7cd3003b,0x26d1006d,0x6d4338b9,0x00000000}},	//   văru, jizo_, psna,
  { {0x6b894c56,0x7d020025,0x26d1006d,0x00000000}},	//   sveg, _fhos, dizo_,
  { {0x7d024c57,0x765c001f,0x69c1004d,0x00000000}},	//   _ghos, wgry, rzle,
  { {0x69c1000f,0x7d094c58,0x4432004a,0x00000000}},	//   szle, mmes, vby_,
  { {0x26d10035,0x7d094c59,0xd62705f4,0x00000000}},	//   gizo_, lmes, зоре_,
  { {0x44320512,0x765c1cbf,0x660308b0,0x00000000}},	//   tby_, rgry, епра,
  { {0x03260daf,0xf8bf4c5a,0x7d094c5b,0x00000000}},	//   здан, ché_, nmes,
  { {0xccf2014e,0x27ed0268,0x99870080,0x00000000}},	// [9160] תכן_, üent_, _jenž_,
  { {0x7d0900bd,0x26d1006d,0xb87b1bae,0x00000000}},	//   hmes, cizo_, gníf,
  { {0x7d094c5c,0x361b009a,0x867b009a,0x00000000}},	//   kmes, _לויד, _פרטו,
  { {0x88bd0080,0x4424005b,0xd12f00f2,0x00000000}},	//   spěv, _üm_, امن_,
  { {0x7d02002b,0x7d094c5d,0x6ff60044,0x00000000}},	//   _rhos, dmes, أساط,
  { {0xdfcf00b3,0x33fb0063,0x3f7d0066,0x00000000}},	//   ديه_, _להכנ, _dňu_,
  { {0xda780024,0x7d024c5e,0x20560085,0x00000000}},	//   veď_, _phos, _нтар,
  { {0x672f0051,0x7d0905e7,0x38a2004c,0x00000000}},	//   ypcj, gmes, _tóry_,
  { {0x291c0019,0x6d584c5f,0xda78004c,0x00000000}},	//   _suva_, suva, teď_,
  { {0xc33301d8,0x7d020037,0x760700ea,0x00000000}},	//   עות_, _whos, nézé,
  { {0x7d024c60,0x26d100be,0xf8bf123c,0x00000000}},	//   _thos, vizo_, thé_,
  { {0xc7d5005a,0xf8bf0080,0xd8280085,0x00000000}},	//   джмъ, uhé_, зірк_,
  { {0x26d10009,0x7607013d,0xdb4f0044,0x00000000}},	//   tizo_, kézé, _مَن_,
  { {0xba170032,0x7cc80080,0xe8030053,0x00000000}},	//   _فيها_, věry, रेगा_,
  { {0xcaa50032,0x96080088,0x7cd3000c,0x00000000}},	//   _تصني, зэта_, părt,
  { {0x6aaa4c61,0x26d10035,0x2eee4c62,0x00000000}},	//   _hoff, sizo_, hoff_,
  { {0xd3710021,0x6aaa4c63,0xb87b1358,0x00000000}},	// [9170] ضها_, _koff, eníg,
  { {0x6aaa4c64,0x7d094c65,0x6d480130,0x00000000}},	//   _joff, zmes, _ovda,
  { {0x6aaa4c66,0x2eee0168,0xf652009a,0x00000000}},	//   _moff, doff_, _בצי_,
  { {0x98a6000c,0x7f754047,0x00000000,0x00000000}},	//   mplă_, дукц,   ,
  { {0xfaf8001c,0x2489330d,0x8e850095,0x00000000}},	//   klī_, mdam_, дгле,
  { {0xd2290044,0x24894c67,0xf412009a,0x00000000}},	//   _ذكره_, ldam_, _שפך_,
  { {0xa3b50042,0x7d094c68,0x23692eea,0x00000000}},	//   जनक_, tmes, ltaj_,
  { {0x62874c69,0x24892d16,0x645f37a8,0x00000000}},	//   _hajo, ndam_, ngqi,
  { {0x7d094c6a,0x23694c6b,0x3f8b0003,0x00000000}},	//   rmes, ntaj_, _écu_,
  { {0x7d094c6c,0xeab10021,0xe9d90bf5,0x00000000}},	//   smes, ئعة_, жко_,
  { {0x672d4c6d,0x62874c6e,0x7d0902af,0x00000000}},	//   _ataj, _majo, pmes,
  { {0x2b52005b,0x8d74007e,0xf7460f9a,0x00000000}},	//   üncü_, _ساما, мемо,
  { {0xa49b001b,0x24894c6f,0x9b940121,0x00000000}},	//   _phòn, ddam_, _пицц,
  { {0x6aaa4c70,0x62874897,0x691700dd,0x00000000}},	//   _goff, _najo, _eţea,
  { {0xd5750e82,0x672d00dd,0x7b07005f,0x00000000}},	//   нуть, _etaj, ąstė,
  { {0xa93a009d,0x00000000,0x00000000,0x00000000}},	//   _ותקפ,   ,   ,
  { {0x24860024,0xd5b8001c,0x62874c71,0x00000000}},	// [9180] ľom_, šā_, _bajo,
  { {0x24863bdc,0x63ab0354,0xd36f00de,0x00000000}},	//   žom_, ägna, شهم_,
  { {0x80661406,0x98bf0023,0xa69b009a,0x00000000}},	//   двеж, lstā_, _ושיפ,
  { {0x25870080,0xd4160021,0x26de004c,0x00000000}},	//   sílá_, _يبحث, čtou_,
  { {0x2eee4c72,0x644400a4,0xcf7a0049,0x00000000}},	//   toff_, maii, تصاص_,
  { {0x5f93018e,0x998c004c,0x67000042,0x00000000}},	//   тишт, vadž_, ोगिक_,
  { {0x2eee1675,0x9987005f,0xdcfa0023,0x00000000}},	//   roff_, _menų_, _astā,
  { {0x98bf003d,0x6aaa4c73,0x2eee0089,0x00000000}},	//   kstā_, _soff, soff_,
  { {0xda7a0d64,0x7eb401a8,0x0e661528,0x00000000}},	//   оян_, _làpi, _окан,
  { {0x63ab010a,0x3ce9074f,0x60c24c74,0x00000000}},	//   øgni, čava_, lhom,
  { {0x32570063,0x28f9126b,0x2716004c,0x00000000}},	//   וסים_, зень_, _měně_,
  { {0x23690051,0x60c24c75,0xeb9a0601,0x00000000}},	//   ytaj_, nhom, _мие_,
  { {0x6aaa4c76,0xa08b009a,0x00000000,0x00000000}},	//   _toff, קְטִ,   ,
  { {0x9f550003,0x6aaa05e7,0xe9cf005d,0x00000000}},	//   égée_, _uoff, اغی_,
  { {0x7eb400cd,0x60c20917,0x62874c77,0x00000000}},	//   _càpi, khom, _rajo,
  { {0x62872386,0xb87b00ed,0xd7fb005e,0x00000000}},	//   _sajo, roís, _муп_,
  { {0x3d160053,0x672d4a35,0x7afa0072,0x00000000}},	// [9190] _पूछे_, _utaj, oltt,
  { {0x9987005f,0x23694c78,0xc2c40044,0x00000000}},	//   _genų_, rtaj_, نيقي,
  { {0x64440ddd,0x5184005e,0x2369394e,0x00000000}},	//   baii, куца, staj_,
  { {0xf993069a,0xa0740085,0x7f19014b,0x00000000}},	//   כרע_, вышш, піку_,
  { {0x62874c79,0x44294c7a,0x4e290131,0x00000000}},	//   _tajo, mca_, полн_,
  { {0x44294c7b,0x69c5004b,0x998c0078,0x00000000}},	//   lca_, _üheg, nadų_,
  { {0x3f84001c,0x44294c7c,0x60c201db,0x00000000}},	//   _esmu_, oca_, bhom,
  { {0x60c24c7d,0x5ba90e82,0x3b850b69,0x00000000}},	//   chom, зким_, елиг,
  { {0xfe75000a,0x98bf0006,0x44291073,0x00000000}},	//   _плаќ, lutė_, ica_,
  { {0x3eac31d4,0xde97002a,0x9e150085,0x00000000}},	//   _godt_, _تجرب, _здзі,
  { {0x98bf00eb,0x7e7e0019,0x644f0051,0x00000000}},	//   nutė_, õppe, _odci,
  { {0x7eb40994,0xa1560063,0x18a60e82,0x00000000}},	//   _ràpi, עברה_, хамм,
  { {0xeb9906be,0x442906ce,0x7eb400cd,0x00000000}},	//   _хил_, dca_, _sàpi,
  { {0x09e54c7e,0x98bf001c,0x64444c7f,0x00000000}},	//   _полн, rstā_, waii,
  { {0xc5d50054,0xe8e00013,0x7ae6013d,0x00000000}},	//   віть, _ngủi_, ékte,
  { {0x7c294c80,0x4619000d,0xf8a90044,0x00000000}},	//   ncer, ьцяў_, _يديه_,
  { {0x7c29051e,0x42560ae8,0x7d19002b,0x00000000}},	// [91a0] icer, етет, _miws,
  { {0xd2630076,0xae0f0053,0x03950062,0x00000000}},	//   лкуй, ाधान_, ърся,
  { {0x2726008b,0x44294c81,0x60c24c82,0x00000000}},	//   _hôn_, bca_, thom,
  { {0xb87b0080,0x70f60032,0x5a0c00b5,0x00000000}},	//   mníc, رسائ, קלאַ,
  { {0xb87b01c2,0x7ebd01a8,0x60c23094,0x00000000}},	//   lníc, _sèpa, rhom,
  { {0x2fc6103b,0x7c2b4c83,0x2726316a,0x00000000}},	//   rzog_, _afgr, _môn_,
  { {0xb87b0080,0x91e62f16,0x2726001f,0x00000000}},	//   nníc, _чове, _lôn_,
  { {0x916c008b,0xcb1b0053,0x98bf003b,0x00000000}},	//   _gốc_, नदंड_, istă_,
  { {0xdcfa000c,0x27260013,0x3eac4c84,0x00000000}},	//   _astă, _nôn_, _todt_,
  { {0x44294c85,0x78ad405e,0x7c294c86,0x00000000}},	//   zca_, _soav, acer,
  { {0x2d96000d,0xdbca004b,0x44292531,0x00000000}},	//   _ярас, võõr, yca_,
  { {0xb87b016b,0x7c2902d3,0x60160058,0x00000000}},	//   dníc, ccer, _gümü,
  { {0x629c006f,0x6f1a4c87,0x27260013,0x00000000}},	//   _onro, _kitc, _côn_,
  { {0x44290051,0xdcb10013,0x68e40331,0x00000000}},	//   wca_, _rủi_, _ejid,
  { {0x212d004c,0x7981002b,0x05e80121,0x00000000}},	//   _čeho_, cwlw, ефти_,
  { {0x2726001f,0x629c00cf,0x69c80078,0x00000000}},	//   _fôn_, _anro, mzde,
  { {0x98bf0529,0x44294c88,0x6d580734,0x00000000}},	// [91b0] astă_, rca_, hrva,
  { {0xb87b01c2,0x68fd1b20,0x44294c89,0x00000000}},	//   bníc, llsd, sca_,
  { {0x395e368c,0x442b000c,0x20040222,0x00000000}},	//   nuts_, _tfc_, _azmi_,
  { {0x9f350086,0x6d4a02ea,0x6918003b,0x00000000}},	//   веді, dsfa, _nţel,
  { {0x2d9a00d1,0xc87f004d,0x6d584c8a,0x00000000}},	//   åpen_, ieß_, erva,
  { {0x395e0196,0x6147013d,0x7d1900a3,0x00000000}},	//   kuts_, _célá, _siws,
  { {0xada5005a,0x916c0013,0x6f1a00e5,0x00000000}},	//   тайл, _tốc_, _ditc,
  { {0xeb990795,0x3ce900b2,0x7db4014b,0x00000000}},	//   дии_, čavo_, ысіц,
  { {0x26c1017d,0xb87b0240,0x6d581aa2,0x00000000}},	//   _olho_, zníc, arva,
  { {0x8a380076,0x68f64c8b,0x7c2909b7,0x00000000}},	//   няют_, _skyd, scer,
  { {0x395e0268,0x2726001f,0x6016005b,0x00000000}},	//   guts_, _sôn_, _tümü,
  { {0x2d980fac,0xb87b0114,0x26c100be,0x00000000}},	//   _área_, vníc, _alho_,
  { {0xfd100021,0xb90a0053,0x69c84c8c,0x00000000}},	//   _اجل_, _मद_, azde,
  { {0x395e0bbd,0xb87b0114,0xfaa50095,0x00000000}},	//   buts_, tníc, _јако,
  { {0x26c10024,0xe643335f,0x395e4c8d,0x00000000}},	//   _dlho_, респ, cuts_,
  { {0x2726008b,0x98bf000c,0x63a400cd,0x00000000}},	//   _tôn_, rstă_, txin,
  { {0x46ea0b62,0x935909b3,0x7bc9004d,0x00000000}},	// [91c0] _один_, ерху_, nzeu,
  { {0xea8c0047,0xe61a0062,0x6d4a1780,0x00000000}},	//   ּנאָ, _одп_, ysfa,
  { {0x1139000d,0x26d806c5,0x672406f8,0x00000000}},	//   еячы_, miro_, _huij,
  { {0x63b600fe,0x7eaf00d1,0x67241767,0x00000000}},	//   pyyn, _søpp, _kuij,
  { {0x656e0025,0x6f1a375e,0xc0a90593,0x00000000}},	//   ltbh, _pitc, عامل_,
  { {0x201f0290,0x6d58027d,0x98a60078,0x00000000}},	//   _egui_, trva, kslį_,
  { {0x71a32e5a,0x7b060014,0x6d4a004d,0x00000000}},	//   _карз, yðub, usfa,
  { {0x6f1a2cf0,0x6d4a44d0,0x26d84c8e,0x00000000}},	//   _witc, rsfa, hiro_,
  { {0x7bc900bd,0xcbe60062,0xa6db0014,0x00000000}},	//   gzeu, ъцки, arðy,
  { {0xbe8508aa,0x69c800bd,0x395e4c8f,0x00000000}},	//   _مجمو, tzde, tuts_,
  { {0x02b70047,0xb87b006d,0x26d80150,0x00000000}},	//   דליך_, enía, diro_,
  { {0x98bf00eb,0x26d8039f,0x6724006f,0x00000000}},	//   kstą_, eiro_, _buij,
  { {0x87e70062,0x26d8306b,0x24803872,0x00000000}},	//   тюне, firo_, deim_,
  { {0xbc1b0063,0xb3c10013,0x26d84c90,0x00000000}},	//   _חודש, _ngýờ, giro_,
  { {0xe9f8000d,0xa5f84c91,0x5694007b,0x00000000}},	//   _янкі_, веру_, јаст,
  { {0x54540366,0x2480013d,0xa5070054,0x00000000}},	//   ивст, geim_, тягл,
  { {0x26d84c92,0x4275000d,0x026b0121,0x00000000}},	// [91d0] biro_, лгас, дшей_,
  { {0xc6f80121,0x78bd4c93,0x61fc002b,0x00000000}},	//   _иных_, lksv, _byrl,
  { {0xb0350002,0x92680062,0x61fc00a3,0x00000000}},	//   гнеш, ърта_, _cyrl,
  { {0x61fc01e1,0x55ba009a,0x00000000,0x00000000}},	//   _dyrl, _נמרו,   ,
  { {0x78bd0162,0x8afd0080,0x764500fe,0x00000000}},	//   iksv, stři, _kehy,
  { {0x0e640086,0x62341dd1,0x9e640054,0x00000000}},	//   икін, _веру, ивід,
  { {0x2e480054,0x27fe056c,0x518412c2,0x00000000}},	//   тячо_, ętni_, _кута,
  { {0x7bc9004d,0x7d760044,0xe572009a,0x00000000}},	//   tzeu, امير_, צַו_,
  { {0xec76000d,0x26d80035,0x7eb400cd,0x00000000}},	//   упы_, yiro_, _càps,
  { {0xc9a90076,0x7bc900bd,0xdb140026,0x00000000}},	//   евое_, rzeu, ðaðr,
  { {0x26d84c94,0x186a2046,0x7bc918de,0x00000000}},	//   viro_, нани_, szeu,
  { {0x26d8002b,0xa3b50053,0x98bf0022,0x00000000}},	//   wiro_, ड़ना_, ystą_,
  { {0x67244c95,0x26d83046,0x1cb8007e,0x00000000}},	//   _quij, tiro_, _جالب_,
  { {0xb9c5007e,0x7c3b4c96,0xfaf90078,0x00000000}},	//   _متعه, lbur, rtūs_,
  { {0x7ebd00cd,0xdcfa0051,0x76454c97,0x00000000}},	//   _rèpl, _wstą, _dehy,
  { {0xa922005a,0x66c20024,0x93c50013,0x00000000}},	//   _удъл, _dôka, _trắ,
  { {0xe29a000a,0x78ad0080,0x98bf0078,0x00000000}},	// [91e0] наа_, žová, ustą_,
  { {0x248000ea,0x98bf0078,0x21a61857,0x00000000}},	//   seim_, rstą_, лизм,
  { {0x0219000d,0x3aba0047,0x25a5089f,0x00000000}},	//   віць_, עמענ, ällt_,
  { {0x34fa0054,0x64a64c98,0xe0460142,0x00000000}},	//   _їхню_, _сама, унди,
  { {0xdfd00021,0x7c3b396e,0x6446005f,0x00000000}},	//   غيت_, dbur, _ieki,
  { {0x3ce600b9,0xbebd008f,0x64460745,0x00000000}},	//   _sjov_, _stūr, _heki,
  { {0x72c30001,0x628e00a4,0x2b4d00b2,0x00000000}},	//   _убрз, _iabo, esec_,
  { {0x7c3b4c99,0xcb54005e,0x628e4c9a,0x00000000}},	//   gbur, авић, _habo,
  { {0xe0d50076,0x28a80053,0x628e4c9b,0x00000000}},	//   _тюрь, गानि, _kabo,
  { {0x38690770,0x49743eea,0x628e4c9c,0x00000000}},	//   _scar_, алос, _jabo,
  { {0x6d410185,0x628e4c9d,0xe9f90013,0x00000000}},	//   _gwla, _mabo, _đả_,
  { {0x64464c9e,0x628e4c9f,0x02170063,0x00000000}},	//   _neki, _labo, טחים_,
  { {0x78bd4ca0,0x7c220b57,0xa7740054,0x00000000}},	//   rksv, _igor, бляч,
  { {0x442d1112,0x628e4ca1,0x6448006c,0x00000000}},	//   _że_, _nabo, _œdip,
  { {0x644602b0,0x64590022,0x05bb005d,0x00000000}},	//   _beki, ówio, ردست_,
  { {0x628e00a4,0x69c50019,0x57b50054,0x00000000}},	//   _aabo, _ühea, _вбит,
  { {0xd25b0088,0x2d91004c,0x7d004ca2,0x00000000}},	// [91f0] еце_, _ázev_, ilms,
  { {0xf8bf0080,0x25a500c7,0x628e4ca3,0x00000000}},	//   lké_, älls_, _cabo,
  { {0xb87b0025,0x628e4ca4,0x7bdc0058,0x00000000}},	//   nnío, _dabo, ğruy,
  { {0x644600e8,0x7c22001f,0x3d0e0042,0x00000000}},	//   _geki, _ngor, ागों_,
  { {0xb87b0025,0x49180041,0xa8580063,0x00000000}},	//   hnío, אקאל_, רידה_,
  { {0x7c224ca5,0xed594a3a,0xa927004c,0x00000000}},	//   _agor, вок_, _ježí,
  { {0x56b80047,0xf8bf48b8,0x7c3b4ca6,0x00000000}},	//   רפון_, kké_, tbur,
  { {0x628e0226,0xa927004c,0x7c3b372c,0x00000000}},	//   _zabo, _leží, ubur,
  { {0x4b25005e,0x7c3b0f0d,0xf8bf01c8,0x00000000}},	//   јмов, rbur, dké_,
  { {0x3b090001,0x6ab50062,0x4a450239,0x00000000}},	//   ђено_, рсих, шнов,
  { {0x787c0031,0xceb80045,0xa9690001,0x00000000}},	//   _nåvæ, _więc_, њима_,
  { {0xdcfa0022,0x3958013d,0x6ce40054,0x00000000}},	//   _ostę, ársa_, _ліче,
  { {0x64464ca7,0x903a0047,0xdcfa0078,0x00000000}},	//   _reki, כערה, _artė,
  { {0x7c220198,0x98ab003d,0xf8bf0080,0x00000000}},	//   _zgor, ībā_, aké_,
  { {0x2cbf0080,0xdcfa0022,0x64464ca8,0x00000000}},	//   okud_, _astę, _peki,
  { {0x628e4ca9,0xf8bf0114,0xd1380078,0x00000000}},	//   _sabo, cké_, _įą_,
  { {0x628e002c,0x7b060014,0xc2464caa,0x00000000}},	// [9200] _pabo, iðun, инак,
  { {0xd1960002,0x9196005e,0x8fa6005d,0x00000000}},	//   ишењ, ијеш, یماه,
  { {0x86c6007e,0x60260002,0xf5060121,0x00000000}},	//   _ميکن, адеа, _взно,
  { {0xdfda005a,0x4f660044,0xe1650043,0x00000000}},	//   къл_, لاتف, صدمي,
  { {0xddd80080,0x8e860002,0x2fc000ea,0x00000000}},	//   devš, игде, áig_,
  { {0x62980024,0x7c2218ca,0xf8bf01c2,0x00000000}},	//   ôvod, _sgor, zké_,
  { {0x91e30156,0x7bdd0014,0xbd870021,0x00000000}},	//   _доре, úsun, لنون_,
  { {0x7b060026,0x320a025f,0xfd0f0044,0x00000000}},	//   gðun, _izby_, وجي_,
  { {0xef1a0da9,0x8c4301ce,0x5f2a012c,0x00000000}},	//   _ама_, цење, _розм_,
  { {0x657e0031,0x63ab01bb,0xb87b0139,0x00000000}},	//   _opph, ägni, tnío,
  { {0xd90f007e,0x5d860021,0x4c86012f,0x00000000}},	//   ویت_, _خلال, _влев,
  { {0x7c221556,0xdca307ed,0x26ef0082,0x00000000}},	//   _ugor, _махи, चक्र_,
  { {0xdb020199,0x69c50004,0x27ed005b,0x00000000}},	//   _groß, _ühen, çen_,
  { {0x26c502dd,0xf8bf0114,0xb87b004c,0x00000000}},	//   ólo_, ské_, mním,
  { {0xb87b01da,0x3a3700ff,0xd5b81375,0x00000000}},	//   lním, _דרום_, аст_,
  { {0x0933005d,0x98bf0c3b,0xf9fb009a,0x00000000}},	//   _بروج, ystę_, _שההמ,
  { {0x53990be6,0x04f401dd,0xb87b4cab,0x00000000}},	// [9210] ывая_, ізую, nním,
  { {0x2d870051,0xd7fc0063,0x8afd004c,0x00000000}},	//   ywne_, _בהחל, ouřa,
  { {0xdcfa0051,0x2127008b,0xc1750062,0x00000000}},	//   _wstę, ênh_, слещ,
  { {0x859a0063,0xd0580054,0xa1580085,0x00000000}},	//   _עשרו, арші_, рацу_,
  { {0x644d021e,0xa283007e,0xdcfa0022,0x00000000}},	//   maai, _ویرو, _ustę,
  { {0x644d021f,0x141a0063,0xddc50086,0x00000000}},	//   laai, _תושב, йбли,
  { {0x63ad000c,0xd6580063,0xddd81035,0x00000000}},	//   ţină, ביות_, tevš,
  { {0x0c220062,0x62851859,0x2d870022,0x00000000}},	//   пмън, leho, rwne_,
  { {0x7b060026,0x7ebd00cd,0x2cad388f,0x00000000}},	//   rðun, _lèpi, rjed_,
  { {0x6285076c,0x2cad007d,0x2cbf01e1,0x00000000}},	//   neho, sjed_, skud_,
  { {0x2492001f,0x66c20066,0x5c7506da,0x00000000}},	//   ydym_, _dôkl, _глет,
  { {0x290209c9,0x30790047,0xb87b004c,0x00000000}},	//   ulka_, נאָנ, bním,
  { {0x62854cac,0x8ca40053,0xeaae4cad,0x00000000}},	//   keho, कारो, _ей_,
  { {0xceb20063,0x6b89087d,0x62851a1b,0x00000000}},	//   ֔ים_, mweg, jeho,
  { {0x6285010a,0x6aa317d3,0xceb20ca4,0x00000000}},	//   deho, _innf, הים_,
  { {0x6b890051,0x3f8d00cd,0x644d006f,0x00000000}},	//   oweg, _oseu_, gaai,
  { {0x6b8910ce,0xa507006e,0x083b0047,0x00000000}},	// [9220] nweg, сета_, _געפל,
  { {0x62854cae,0x77830145,0xa3e90042,0x00000000}},	//   geho, _эльз, _बशर_,
  { {0x657e0a95,0xccf90022,0x6b890206,0x00000000}},	//   _upph, koś_, hweg,
  { {0xe80f0082,0x60ea014b,0x00000000,0x00000000}},	//   _सरमा_, ымем_,   ,
  { {0x44320051,0x62854caf,0x7bdd013d,0x00000000}},	//   mcy_, beho, úsul,
  { {0xb87b0080,0x8236007e,0x764e001f,0x00000000}},	//   vním, _درحا, naby,
  { {0x171b0047,0x2d9a175e,0x3f8d1d50,0x00000000}},	//   נוצע, ípe_, _eseu_,
  { {0x44320cfc,0xb87b0080,0xccf90051,0x00000000}},	//   ncy_, tním, goś_,
  { {0xab940086,0xe81a0053,0x6c7700f2,0x00000000}},	//   ципі, नेमा_, صحيح_,
  { {0xa9540001,0x60c217d5,0x78a44cb0,0x00000000}},	//   овољ, lkom, _aniv,
  { {0x69c50019,0xf2970063,0xdc3c0195,0x00000000}},	//   _ühel, זכיר_, láčk,
  { {0x2360017f,0x60c21f3e,0xb87b3dc0,0x00000000}},	//   krij_, nkom, mník,
  { {0x02fa0053,0x44320051,0x7ebd00cd,0x00000000}},	//   ्ताह_, dcy_, _sèpi,
  { {0x98bf0006,0x764e4cb1,0x99e30066,0x00000000}},	//   putį_, gaby, ŕňaj,
  { {0x60c20bb7,0xb87b1994,0xd6d80d82,0x00000000}},	//   kkom, nník, стя_,
  { {0xf98f0032,0x60c24cb2,0x26da2069,0x00000000}},	//   _أبو_, jkom, _empo_,
  { {0x644d0122,0x60c2314f,0x43740086,0x00000000}},	// [9230] raai, dkom, зуєт,
  { {0x7afa4cb3,0x32550454,0x644d4cb4,0x00000000}},	//   nott, івер, saai,
  { {0x644d00e8,0x7ae800b9,0xb87b01c2,0x00000000}},	//   paai, indt, jník,
  { {0x62850037,0xb87b004a,0x60c24cb5,0x00000000}},	//   seho, dník, gkom,
  { {0x68ed0035,0x7afa4cb6,0x62852dc3,0x00000000}},	//   _mjad, kott, peho,
  { {0x60c24cb7,0x7afa1256,0xad593af3,0x00000000}},	//   akom, jott, арих_,
  { {0x7afa4cb8,0x60c2004d,0x7b060014,0x00000000}},	//   dott, bkom, rðul,
  { {0x7ae8069f,0x60c200a5,0xa0c5013a,0x00000000}},	//   endt, ckom, _بيرو,
  { {0xb87b0080,0x60c90035,0x60db00a4,0x00000000}},	//   mníh, _ilem, _imum,
  { {0xb87b0114,0x68ed004b,0x63ad1494,0x00000000}},	//   lníh, _ajad, ixan,
  { {0x6b8905e4,0x44320022,0xb87b0195,0x00000000}},	//   sweg, ycy_, cník,
  { {0xb87b0080,0x69c5004b,0x88d60085,0x00000000}},	//   nníh, _ühem, іўні,
  { {0x69d9016a,0x6609004c,0x7afa4cb9,0x00000000}},	//   _फेरी, řekl, bott,
  { {0x44320045,0x272f005b,0x7afa206f,0x00000000}},	//   wcy_, _dün_, cott,
  { {0x60c90aba,0x60c23c7a,0x443237b6,0x00000000}},	//   _olem, ykom, tcy_,
  { {0xa3ea000a,0x25a500c7,0xb87b0080,0x00000000}},	//   адба_, ålla_, jníh,
  { {0x272f01f7,0xb87b0a63,0x60c24cba,0x00000000}},	// [9240] _gün_, dníh, vkom,
  { {0x44320051,0x60c90764,0x68ed0022,0x00000000}},	//   scy_, _alem, _zjad,
  { {0xd179000d,0x60c24cbb,0x44320022,0x00000000}},	//   йсці_, tkom, pcy_,
  { {0x7afa00ea,0x20560086,0xb87b004a,0x00000000}},	//   zott, ітер, vník,
  { {0x7ae805b9,0x60c23816,0x7afa4cbc,0x00000000}},	//   yndt, rkom, yott,
  { {0x66cb1c97,0x60c94cbd,0xb87b0114,0x00000000}},	//   _tüke, _elem, tník,
  { {0x6da300e1,0xb87b0080,0x7afa4cbe,0x00000000}},	//   дија, bníh, vott,
  { {0x60c90205,0x4127293f,0xb87b01d9,0x00000000}},	//   _glem, _фото_, rník,
  { {0x7afa000f,0x2aaa0f55,0x8e760895,0x00000000}},	//   tott, атно_, _мужч,
  { {0x7afa00fe,0xb87b0061,0x6f79009a,0x00000000}},	//   uott, pník, _לְעו,
  { {0xd8f90086,0xdce30080,0x60c90072,0x00000000}},	//   йної_, ntně, _ylem,
  { {0xa9c30086,0xb87b004c,0xb8340121,0x00000000}},	//   фськ, diíc, меющ,
  { {0xdb240019,0xdc290021,0xc0530063,0x00000000}},	//   öpäe, _اسمه_, וזר_,
  { {0x6b8201f4,0xb87b4cbf,0x81c30023,0x00000000}},	//   _ipog, zníh, _ņēmu,
  { {0xc4db0001,0x344b0169,0x15150054,0x00000000}},	//   ађа_, ичан_, здвя,
  { {0xa5f80054,0x83354a9c,0x21244cc0,0x00000000}},	//   цесу_, знах, _nimh_,
  { {0xb87b0080,0xbec30023,0x28a80042,0x00000000}},	// [9250] vníh, _ņūme, गारि,
  { {0x2d9e00bd,0x60c94cc1,0x8c1b0063,0x00000000}},	//   _orte_, _slem, שומי,
  { {0xb87b31b6,0xdb1100ea,0x60c94cc2,0x00000000}},	//   tníh, égén, _plem,
  { {0x7bc00006,0x397b0047,0x15fa0063,0x00000000}},	//   kymu, שטאנ, _להתע,
  { {0x90280088,0xb87b0080,0x2d9e2c21,0x00000000}},	//   іцца_, rníh, _arte_,
  { {0x7bc00006,0xb87b004c,0x59ca0042,0x00000000}},	//   dymu, sníh, ानार,
  { {0xf2d200b5,0x6b824cc3,0x2d9e007d,0x00000000}},	//   _װען_, _apog, _crte_,
  { {0x60db059e,0x60c933c1,0x2919007d,0x00000000}},	//   _umum, _ulem, jmsa_,
  { {0x62954cc4,0x2d9e0244,0x9f0504a0,0x00000000}},	//   _kazo, _erte_, _فورو,
  { {0x0b420088,0x69c50019,0xdd95014c,0x00000000}},	//   эньн, _ühek, _назы,
  { {0x6abc0cbf,0xe8fa02a1,0x2d9a0137,0x00000000}},	//   örfa, йло_, åpet_,
  { {0x62954cc5,0xcd96009a,0x7d7a009d,0x00000000}},	//   _lazo, _מדעת_, _לנעו,
  { {0x672d006d,0x2489003b,0x47c30062,0x00000000}},	//   _cuaj, deam_, ебяв,
  { {0xdce32ef2,0x62950eb1,0x3ffa0041,0x00000000}},	//   ytně, _nazo, מפרע,
  { {0x7e7e004b,0xd5750054,0x64a60349,0x00000000}},	//   õppi, муть, пава,
  { {0x7ae100fe,0xb87b004c,0x6fbd0042,0x00000000}},	//   lilt, riíc, ्नां,
  { {0xe45f0137,0x672d01f1,0x23690066,0x00000000}},	// [9260] _glöm_, _guaj, guaj_,
  { {0x7ae10072,0xdce3007d,0x130302f9,0x00000000}},	//   nilt, dunč, езум,
  { {0x7bc00051,0xe9f90013,0x91e3034b,0x00000000}},	//   zymu, _đẻ_, нофе,
  { {0xdce30080,0x7ae14cc6,0x2489003b,0x00000000}},	//   rtně, hilt, ceam_,
  { {0x43930088,0xdce30080,0xce940062,0x00000000}},	//   _заўс, stně, далъ,
  { {0x7ae100fe,0x877b0149,0x9993004c,0x00000000}},	//   jilt, מאני, žeři_,
  { {0xb87b0080,0x6b824cc7,0x7ebd00cd,0x00000000}},	//   mnív, _spog, _rèpt,
  { {0x7bc000eb,0x21240025,0x515b0063,0x00000000}},	//   tymu, _uimh_, _לכלו,
  { {0xfc3f02dd,0x66cb0019,0x5b140121,0x00000000}},	//   ñía_, _lüka, ммит,
  { {0x2aaa0001,0x7f3b0063,0x7ae14cc8,0x00000000}},	//   стио_, _לעמו, gilt,
  { {0xe29b0047,0x7bc00078,0xe9e60121,0x00000000}},	//   זשיר, symu, яцио,
  { {0xab5d0051,0x7ae14cc9,0x2db50041,0x00000000}},	//   wyże, ailt, _קלײן_,
  { {0x6cc3295f,0xfaa60571,0x6b8200a8,0x00000000}},	//   _яйца, _надо, _upog,
  { {0x96eb06c3,0x7ae1004c,0x8c1b0063,0x00000000}},	//   сьма_, cilt, _הודי,
  { {0x67250213,0x62954cca,0x7a7b0063,0x00000000}},	//   _vihj, _razo, _הרוס,
  { {0x62954ccb,0xb9250021,0x00000000,0x00000000}},	//   _sazo, _تفعي,   ,
  { {0x7d0201e1,0xa4d40054,0x24894ccc,0x00000000}},	// [9270] _mkos, хоті, ream_,
  { {0x97360041,0x24890c8b,0xa2cd0042,0x00000000}},	//   _קרתא_, seam_, _दॄश्,
  { {0x75150062,0x629525e4,0x5fca0042,0x00000000}},	//   _омоф, _vazo, ़ैसल,
  { {0xc5f2014e,0x2ec50161,0x04670076,0x00000000}},	//   _ידי_, वस्त, _этом,
  { {0x226801da,0x644f008f,0x69c10022,0x00000000}},	//   átké_, _ieci, zyle,
  { {0xc3320047,0xc7d80063,0x7d020066,0x00000000}},	//   _בוך_, הודי_, _akos,
  { {0x644f014f,0xd164005a,0x7ae14ccd,0x00000000}},	//   _keci, _пъти, vilt,
  { {0xdb1b004d,0x32114cce,0x3f9f004b,0x00000000}},	//   szuü, _izzy_, _truu_,
  { {0x3af50086,0x3e5f001c,0x2d9a00d1,0x00000000}},	//   дянс, tātē_, åper_,
  { {0x637f003b,0x7d024ccf,0x69c14cd0,0x00000000}},	//   mână, _ekos, tyle,
  { {0x44390035,0xbe640021,0x7ae14cd1,0x00000000}},	//   _ofs_, _أهمي, rilt,
  { {0xd7f8003b,0x7ae14cd2,0x644f4cd3,0x00000000}},	//   şăm_, silt, _neci,
  { {0x66d00137,0xe20a0042,0xf7460002,0x00000000}},	//   _läke, _वर्ण_, ќего,
  { {0x4df900b5,0x8cab0053,0x3ced004b,0x00000000}},	//   ַפּא, झावो, lnev_,
  { {0xcb12014e,0x66d000fe,0x69c700b9,0x00000000}},	//   _שלו_, _näke, øjed,
  { {0x656100ea,0xe8f60021,0xf50a01dd,0x00000000}},	//   álha, _تستخ, інал_,
  { {0x073a0032,0x64444cd4,0x644f0749,0x00000000}},	// [9280] _بسبب_, rbii, _deci,
  { {0x244c008b,0x7d094cd5,0x27340072,0x00000000}},	//   ếm_, hles, _iän_,
  { {0x2734024a,0x644f4cd6,0xc04f0454,0x00000000}},	//   _hän_, _feci, кі_,
  { {0x7d09000f,0x644f005b,0x7bcd001c,0x00000000}},	//   jles, _geci, _ļaun,
  { {0x7d094cd7,0x7d1b004b,0x5f7304a0,0x00000000}},	//   dles, dmus, ناور,
  { {0x273400c7,0x644f003b,0x7d1b4cd8,0x00000000}},	//   _män_, _zeci, emus,
  { {0x273400c7,0xdcb1008b,0x7d0902d3,0x00000000}},	//   _län_, _hủy_, fles,
  { {0x8d170021,0x9972004c,0x7d094cd9,0x00000000}},	//   وزير_, těže_, gles,
  { {0x2d8504aa,0x9a8a0094,0x765e4cda,0x00000000}},	//   _eple_, ощна_, _odpy,
  { {0x7d1b4cdb,0x7d09462c,0x80da0042,0x00000000}},	//   amus, ales, पोरे,
  { {0x7c390185,0x7d094cdc,0x2d96000d,0x00000000}},	//   _ffwr, bles, _юрас,
  { {0x6d584cdd,0xab2a005e,0x2ba70053,0x00000000}},	//   msva, _дода_, _औपचा,
  { {0xb33b03d9,0xad1b00b5,0x644f0d0f,0x00000000}},	//   _orça, _וואר, _reci,
  { {0x7d00000f,0x5bb701dd,0xfbd30063,0x00000000}},	//   loms, _юлія_, _בתנ_,
  { {0xef0e000d,0x6d584cde,0x644f4cdf,0x00000000}},	//   ымi_, nsva, _peci,
  { {0x7d004ce0,0xf9290041,0xdcfa008f,0x00000000}},	//   noms, _צופּ, _istē,
  { {0x66d001e3,0x644f4ce1,0xe315018e,0x00000000}},	// [9290] _säke, _veci, емањ,
  { {0x32070051,0x7d1b00ea,0x6d584ce2,0x00000000}},	//   żnym_, zmus, ksva,
  { {0x644f017d,0x7d004ce3,0x35f4000d,0x00000000}},	//   _teci, koms, _апэр,
  { {0x645d00b9,0x90150454,0x7d000066,0x00000000}},	//   _udsi, нфлі, joms,
  { {0x6d5a02f0,0x6d584ce4,0x8e8513e1,0x00000000}},	//   _avta, esva, егле,
  { {0x6d580026,0x7d093992,0x2d952267,0x00000000}},	//   fsva, wles, ерис,
  { {0xdce801f7,0x6d583b99,0x7d094ce5,0x00000000}},	//   _ardı, gsva, tles,
  { {0x7d1b002c,0xcf7b0021,0x9f5100ea,0x00000000}},	//   umus, _وإذا_, ából_,
  { {0x76550051,0x7d09495e,0x7d1b4ce6,0x00000000}},	//   kazy, rles, rmus,
  { {0xeab10032,0xaad90161,0x39450619,0x00000000}},	//   اعة_, योंक, нног,
  { {0x88e60076,0xdce3008f,0x7d1b4ce7,0x00000000}},	//   ежне, aunā, pmus,
  { {0x6d4301a8,0xdd030023,0x8d7400de,0x00000000}},	//   mpna, īrēj, _جاكا,
  { {0xfb680021,0x6d430078,0xcbc70044,0x00000000}},	//   _قصوى_, lpna, _تزاي,
  { {0x273400c7,0x76550051,0x8afd004c,0x00000000}},	//   _vän_, gazy, kuři,
  { {0xb87b0066,0x48e608a8,0x98ad0058,0x00000000}},	//   tnít, _покв, ardı_,
  { {0x273400a5,0x89da009a,0x7a31013d,0x00000000}},	//   _tän_, _מחצי, _fűté,
  { {0x38600027,0xc32a0021,0x29020078,0x00000000}},	// [92a0] _idir_, سكان_, moka_,
  { {0x6d5800fe,0x29024ce8,0x68e64ce9,0x00000000}},	//   ysva, loka_, likd,
  { {0x80660062,0x56370041,0xcd01011b,0x00000000}},	//   евеж, _ראטע_, _zvěř_,
  { {0x25a50146,0xab5d0022,0x26150042,0x00000000}},	//   ælle_, zyża, _धरती_,
  { {0x7053006a,0x6d4300ac,0x656e00a4,0x00000000}},	//   انها, epna, lubh,
  { {0x6d584cea,0x66cb005b,0x64564ceb,0x00000000}},	//   tsva, _nükl, layi,
  { {0xe9f9008b,0x6d580072,0x657c002b,0x00000000}},	//   _đế_, usva, ntrh,
  { {0xdddf027d,0x6d582e50,0x2480017d,0x00000000}},	//   ávšt, rsva, nfim_,
  { {0x29024cec,0x1e8606e6,0xaf490021,0x00000000}},	//   doka_, _плам, _يشكل_,
  { {0x6456002c,0xdce3001c,0x656e00ac,0x00000000}},	//   hayi, runā, kubh,
  { {0xfbcf006a,0x645600a4,0x68e61c1d,0x00000000}},	//   لتی_, kayi, fikd,
  { {0x657c004c,0x7655056c,0x00000000,0x00000000}},	//   dtrh, wazy,   ,
  { {0x2fc600a4,0xbb43005e,0x8ae60054,0x00000000}},	//   nyog_, _бечк, _пікл,
  { {0xdb060527,0x6aaa002b,0x65610014,0x00000000}},	//   ämäk, _unff, álho,
  { {0x3a370047,0xc8f50062,0x5a9b0047,0x00000000}},	//   _ארום_, _изкъ, _זשוא,
  { {0x26ca00a4,0x68e60066,0x3ebe4ced,0x00000000}},	//   akbo_, cikd, _lott_,
  { {0x66cb4cee,0x78ad0035,0xc6f90001,0x00000000}},	// [92b0] _yükl, _inav, _оних_,
  { {0xa5350121,0x8234005d,0x00000000,0x00000000}},	//   _иноч, هرما,   ,
  { {0x645600a4,0xa5f90175,0x69c5004b,0x00000000}},	//   bayi, _цену_, _ühet,
  { {0x64564cef,0x3074030b,0x1ee70043,0x00000000}},	//   cayi, гушс, کوتی_,
  { {0xf8b20063,0x3ebe00a5,0xee2e01e4,0x00000000}},	//   ישׁ_, _bott_, ин_,
  { {0x7b060014,0x999e005f,0x8d7502da,0x00000000}},	//   iðus, natų_, نابا,
  { {0x3ebe3092,0xbe980044,0xbbc90082,0x00000000}},	//   _dott_, عضها_, िन्क,
  { {0x6b84003b,0x3eac05e7,0xdce300dd,0x00000000}},	//   _ţiga, _endt_, dună,
  { {0x98a8000c,0x66d00137,0x999e0078,0x00000000}},	//   _lună_, _läka, katų_,
  { {0x6d43220d,0x2369007d,0x78ad4cf0,0x00000000}},	//   ppna, iraj_, _anav,
  { {0x290210ca,0x999e0078,0x68e6388d,0x00000000}},	//   toka_, datų_, tikd,
  { {0x2369074f,0x48e60189,0x6f0322d7,0x00000000}},	//   kraj_, томв, lonc,
  { {0x5bc40021,0x29024cf1,0x68e60f90,0x00000000}},	//   _متوف, roka_, rikd,
  { {0x6f034cf2,0xdce30529,0x98a80529,0x00000000}},	//   nonc, bună, _bună_,
  { {0x64560178,0xb6a3005e,0x7c3b053c,0x00000000}},	//   tayi, јисл, ocur,
  { {0x7bcd001c,0x7c3b34e7,0x78ad01e1,0x00000000}},	//   _ļauj, ncur, _gnav,
  { {0x24780080,0x2480017d,0x68e44cf3,0x00000000}},	// [92c0] _němž_, rfim_, _imid,
  { {0x69c50019,0xd7070121,0x6f034cf4,0x00000000}},	//   _ühes, _иные_, jonc,
  { {0x64560a9f,0x6f034cf5,0xd1390085,0x00000000}},	//   payi, donc, ехі_,
  { {0x00e6005a,0x3ebe01f4,0x6d5e0078,0x00000000}},	//   ъжен, _sott_, špak,
  { {0xcf770032,0x7b060026,0x6d41356b,0x00000000}},	//   نصوص_, iður, _atla,
  { {0x1ee6007e,0x6f034cf6,0x7c3b44e7,0x00000000}},	//   ضوعی_, gonc, ecur,
  { {0x180f016a,0x8d7300f2,0x629c00dd,0x00000000}},	//   _सर्व_, لايا, _iaro,
  { {0x629c4cf7,0xd1970063,0xc5f30063,0x00000000}},	//   _haro, _בכלי_, ידו_,
  { {0xcb6728fd,0x207b0047,0x4f260085,0x00000000}},	//   вање_, _קאמא, _адаб,
  { {0x60c04cf8,0x7c3b003b,0x78ad01af,0x00000000}},	//   _homm, acur, _snav,
  { {0xddc80045,0x629c4cf9,0x6c860021,0x00000000}},	//   _wedł, _maro, _للام,
  { {0x629c4cfa,0x7c3b4cfb,0x63a64cfc,0x00000000}},	//   _laro, ccur, _orkn,
  { {0x48e4000d,0x98a8003b,0x999e0078,0x00000000}},	//   роўв, _sună_, tatų_,
  { {0x98a8003b,0x60c01a24,0x68e400ca,0x00000000}},	//   _pună_, _lomm, _emid,
  { {0xd6d8019d,0xa4d50086,0x999e0006,0x00000000}},	//   ття_, гові, ratų_,
  { {0x236900c3,0x442f0146,0x999e0006,0x00000000}},	//   traj_, øg_, satų_,
  { {0x7b320045,0x59ca0161,0x69c81de3,0x00000000}},	// [92d0] _dług, ानकर, lyde,
  { {0xab5d0022,0x629c1d7a,0x4b7b009a,0x00000000}},	//   zyżo, _caro, ואמו,
  { {0x69da00bd,0xe1f0007e,0x66cb0019,0x00000000}},	//   nzte, يسم_, _lükk,
  { {0x60c00399,0xf2df002b,0x629e0a1e,0x00000000}},	//   _comm, _stâd_, adpo,
  { {0x6f0302dd,0x6d410024,0x60c02d9a,0x00000000}},	//   tonc, _stla, _domm,
  { {0x69c800b9,0xaf04000d,0x629c4cfd,0x00000000}},	//   kyde, апіл, _garo,
  { {0x8d540088,0x7db40062,0x6f034339,0x00000000}},	//   атыч, исъц, ronc,
  { {0x60c04cfe,0x7c3b003b,0x69da008f,0x00000000}},	//   _gomm, ucur, dzte,
  { {0x7c3b4cff,0x6f034d00,0x7afc00a8,0x00000000}},	//   rcur, ponc, črtn,
  { {0x68e42883,0x4a450121,0x7c3b18f5,0x00000000}},	//   _smid, ынов, scur,
  { {0xaad90053,0x6d414d01,0x69c801e1,0x00000000}},	//   योगक, _utla, gyde,
  { {0xf74641af,0xe9a6005d,0x00000000,0x00000000}},	//   лемо, اگون_,   ,
  { {0x69c8005b,0x7b060026,0x20f821e3,0x00000000}},	//   ayde, rður, nčia_,
  { {0x5a470088,0x69c80146,0x7ae300ac,0x00000000}},	//   _рэда, byde, _umnt,
  { {0x7bdb006f,0x629c4d02,0x98b9008f,0x00000000}},	//   lzuu, _raro, ūrā_,
  { {0x68e40383,0x97c60593,0x629c4d03,0x00000000}},	//   _umid, _مقبو, _saro,
  { {0xdd030006,0x60c02b58,0x629c4d04,0x00000000}},	// [92e0] ūrėj, _romm, _paro,
  { {0x14230121,0xe45f0137,0x60c04d05,0x00000000}},	//   сдум, _slöt_, _somm,
  { {0x20f80006,0x4a560047,0x629c4d06,0x00000000}},	//   ečia_, רשעל_, _varo,
  { {0xea160047,0x629c4b6e,0xa09a0021,0x00000000}},	//   אַדי_, _waro, عضاء_,
  { {0x69c80051,0x4424008b,0xd0370086,0x00000000}},	//   zyde, _àm_, узії_,
  { {0xf8bf0164,0x69c800fe,0xa226007e,0x00000000}},	//   mmée_, yyde, _مرزه,
  { {0x8d86007e,0x63a44d07,0x60c00246,0x00000000}},	//   اشتن, lvin, _tomm,
  { {0xdb020003,0x7ae800e5,0xbd87013a,0x00000000}},	//   _croî, widt, انين_,
  { {0x69c800e8,0x66d000c7,0xa0670062,0x00000000}},	//   wyde, _räkn, _щата_,
  { {0x69da0199,0x7afc00c3,0x4a54000a,0x00000000}},	//   tzte, črto, шкос,
  { {0xd2b70063,0x26c105b3,0x9d460002,0x00000000}},	//   אלית_, _roho_, _сеед,
  { {0x66cb004b,0x69da004d,0x63a403d4,0x00000000}},	//   _tükk, rzte, kvin,
  { {0x63a402b0,0x69da000f,0xd7f81003,0x00000000}},	//   jvin, szte, гур_,
  { {0x98bf0006,0x63a44d08,0x99d60049,0x00000000}},	//   ystė_, dvin, _متعا,
  { {0x58d50076,0x63a441fd,0x69c5004b,0x00000000}},	//   _войт, evin, _ühep,
  { {0x84c4000a,0x20f80006,0x290f0139,0x00000000}},	//   бљуд, yčia_, _óga_,
  { {0x395e003d,0x26c1016b,0x63a41837,0x00000000}},	// [92f0] lsts_, _toho_, gvin,
  { {0x5215000d,0x2229007e,0x212d004d,0x00000000}},	//   адзт, نزای_, _sieh_,
  { {0x4615007e,0x24f9007f,0x66d00137,0x00000000}},	//   _خودر, _анны_, _mäkl,
  { {0xbec7008f,0x5f7501fb,0x395e4afa,0x00000000}},	//   idīš, لاتر, ists_,
  { {0xb4c30235,0x926b00e1,0x644d4d09,0x00000000}},	//   ्सी_, _прва_, mbai,
  { {0x395e003d,0x20f82291,0x644d192a,0x00000000}},	//   ksts_, rčia_, lbai,
  { {0xfc310021,0x644d002b,0x69160014,0x00000000}},	//   يحة_, obai, dáen,
  { {0x999c00ea,0x644d002b,0x7bdb00ca,0x00000000}},	//   _nevű_, nbai, tzuu,
  { {0x395e4d0a,0xab760044,0xf8af0042,0x00000000}},	//   ests_, لميا_, टाईय,
  { {0x752f0045,0x644d0089,0x62850139,0x00000000}},	//   _licz, hbai, nfho,
  { {0x395e008f,0x7b060046,0x63a40cff,0x00000000}},	//   gsts_, rðup, zvin,
  { {0x63a40006,0x752f0051,0xe73a030b,0x00000000}},	//   yvin, _nicz, кем_,
  { {0x26d8162d,0xbec7008f,0xe8f7295f,0x00000000}},	//   thro_, adīš, рля_,
  { {0x644d4d0b,0x628500ca,0x5f360041,0x00000000}},	//   ebai, jfho, יטשע_,
  { {0x2d530529,0x09e2000a,0x62850025,0x00000000}},	//   nţe_, _мошн, dfho,
  { {0x8a1400b3,0x47c60086,0x63a44d0c,0x00000000}},	//   _اظها, _вбив, tvin,
  { {0x63a4000c,0x68fd013d,0xb89b009a,0x00000000}},	// [9300] uvin, érde, _יבקש,
  { {0xf8bf0164,0x55e61314,0x644d18a1,0x00000000}},	//   rmée_, _вооб, abai,
  { {0x63a40109,0x21a30062,0x765c0ac3,0x00000000}},	//   svin, жихм, mary,
  { {0x39a50418,0x21670676,0x20f801b3,0x00000000}},	//   _mēs_, рици_, ačin_,
  { {0x98a6005b,0xd007000d,0x93260043,0x00000000}},	//   nslı_, аеце_, _نرسن,
  { {0x644c0051,0x8c9e0053,0xfaf90078,0x00000000}},	//   śnię, _खोजो, irūs_,
  { {0x69c70146,0xdce1005b,0x42e70002,0x00000000}},	//   øjel, _aslı, _тмро_,
  { {0x0ca70076,0x656e0025,0xc19b0063,0x00000000}},	//   атьи_, irbh, _בשלי,
  { {0x22580173,0xdce3008f,0xafe62d7b,0x00000000}},	//   _kerk_, urnā, _тоал,
  { {0x2ac6005e,0x0f7b0047,0x7ac60121,0x00000000}},	//   рљив, _באמב, рсие,
  { {0x765c00eb,0x20f80006,0x22584d0d,0x00000000}},	//   dary, nčio_, _merk_,
  { {0x6d4a004d,0x20f80078,0x765c002b,0x00000000}},	//   mpfa, ičio_, eary,
  { {0x765c001f,0x98bf001c,0x39494d0e,0x00000000}},	//   fary, lstī_, _čase_,
  { {0x20f80078,0xddc8008f,0x96eb0054,0x00000000}},	//   kčio_, _vedņ, тьма_,
  { {0x7afd032a,0x6abc0014,0x95c83f17,0x00000000}},	//   éste, örfu, аута_,
  { {0xb4c30161,0xc4d8005e,0x04c90021,0x00000000}},	//   ्से_, ађу_, دوري_,
  { {0x98bf000c,0x644d4d0f,0xe3b00021,0x00000000}},	// [9310] aptă_, rbai, ورك_,
  { {0xf6990459,0x752400c2,0x25a500a5,0x00000000}},	//   _свој_, amiz, ålls_,
  { {0x62850025,0x28cc0053,0x20f80130,0x00000000}},	//   rfho, ासचि, rčin_,
  { {0x62850027,0x00000000,0x00000000,0x00000000}},	//   sfho,   ,   ,
  { {0x4fa50f92,0x8fa53852,0x351a009a,0x00000000}},	//   силв, сале, _תורנ,
  { {0xdef4000d,0xaaa60053,0x20180021,0x00000000}},	//   опчы, _कोलक, جتمع_,
  { {0x0204000d,0xf1580062,0xad58066e,0x00000000}},	//   _дзён, _висш_, арых_,
  { {0x2d53000c,0x85f83759,0x20f8004a,0x00000000}},	//   rţe_, יצוע_, nčil_,
  { {0x0ab50021,0xcce40021,0xa4b8009a,0x00000000}},	//   محدد, تسوي, שלחה_,
  { {0x9f950019,0x7b320051,0xadbd0085,0x00000000}},	//   _müüa_, _słuc, _пазi,
  { {0x39e90429,0x9f95004b,0x98a62953,0x00000000}},	//   удно_, _lüüa_, бине,
  { {0x20f8004c,0x765c056c,0xfde30082,0x00000000}},	//   jčil_, wary, _केएस_,
  { {0xfaa50088,0xdc360047,0x765c4d10,0x00000000}},	//   _гало, _האנט_, tary,
  { {0x2cbf0019,0x7d09001f,0xe737079b,0x00000000}},	//   ljud_, loes, сер_,
  { {0x765c00a4,0x98bf00dd,0xddc8004c,0x00000000}},	//   rary, uptă_, _bedř,
  { {0xd3ba0086,0xfaf90078,0xf992009f,0x00000000}},	//   лузі_, prūs_, _זרה_,
  { {0x225800ac,0x273d0013,0xd4f5000d,0x00000000}},	// [9320] _perk_, _gìn_, цяры,
  { {0x2cbf004b,0x66d00d65,0x23600078,0x00000000}},	//   hjud_, _mäkk, rsij_,
  { {0x98b90006,0x7d0900ca,0x225839bd,0x00000000}},	//   ūrą_, koes, _verk_,
  { {0x22582396,0x20f816fe,0x649a0054,0x00000000}},	//   _werk_, rčio_, _стор_,
  { {0x0eea019d,0x20f80006,0x7d093543,0x00000000}},	//   льки_, sčio_, does,
  { {0xdb02017d,0xa2d601fb,0x20f80077,0x00000000}},	//   _proí, _ايست, mčim_,
  { {0x64430045,0xddc100ea,0x7d09002b,0x00000000}},	//   śnie, _belő, foes,
  { {0x6d4a051c,0x84d6009a,0x00000000,0x00000000}},	//   rpfa, מֵ֥א_,   ,
  { {0xdad80002,0xe4570047,0x6d4a004d,0x00000000}},	//   имиц_, זיפט_, spfa,
  { {0x63ab05ad,0x7bcd001c,0x98bf0078,0x00000000}},	//   ågni, _ļaut, iptą_,
  { {0x2d980003,0x2cbf0137,0xddc1013d,0x00000000}},	//   _ère_, bjud_, _felő,
  { {0x2d9e4d11,0x02170063,0x2eee4d12,0x00000000}},	//   _iste_, מחים_, liff_,
  { {0x27ff0075,0x57f40094,0x00000000,0x00000000}},	//   çun_, зпят,   ,
  { {0xeaf50161,0x2eee34b2,0x1a930085,0x00000000}},	//   ीकृत_, niff_, _наіў,
  { {0x2d9e0080,0x9f95004b,0x45d50f8d,0x00000000}},	//   _jste_, _süüa_, цовс,
  { {0x2eee00bd,0x9f95004b,0x273d008d,0x00000000}},	//   hiff_, _püüa_, _tìn_,
  { {0xe4e40086,0x083c0041,0x66cb0058,0x00000000}},	// [9330] чірн, _געחל, _süku,
  { {0x8c1b0063,0x24570013,0x290b0e57,0x00000000}},	//   רומי, ầm_, loca_,
  { {0x399a4d13,0x7b1d00cd,0xfaf8008f,0x00000000}},	//   _jūs_, lèuc, inī_,
  { {0x399a001c,0x30150fd0,0xb87b004c,0x00000000}},	//   _mūs_, одер, eníz,
  { {0x6d48001c,0x2d9e165e,0xd009005e,0x00000000}},	//   _atda, _aste_, јеле_,
  { {0x7d0900ca,0x6204013d,0x995701c8,0x00000000}},	//   woes, étlé, _ráže_,
  { {0x7d094d14,0xd0d50062,0x3ced0066,0x00000000}},	//   toes, _довъ, tiev_,
  { {0x62970858,0x2cbf0360,0x2eee002b,0x00000000}},	//   lexo, ujud_, aiff_,
  { {0x8c6408aa,0x2d9e4d15,0x7884013d,0x00000000}},	//   سطين, _este_, hívó,
  { {0x399a003d,0x05ba0161,0x3869001f,0x00000000}},	//   _būs_, _उपलब, _adar_,
  { {0xc7a90063,0x290b1912,0xc27a0063,0x00000000}},	//   _שב_, foca_, ברתי,
  { {0x6abc00c7,0xb9260021,0xa17a0063,0x00000000}},	//   örfr, تفجي, סטרט,
  { {0x9816013a,0xe73a2c5c,0x7b6401ce,0x00000000}},	//   تبدا, рег_, _етје,
  { {0xf3ff017d,0x9f96009a,0xb4d20042,0x00000000}},	//   _adão_, חדשה_, वस्_,
  { {0x845a04bb,0x2b4d00c3,0x62970512,0x00000000}},	//   ират_, lpec_, dexo,
  { {0x6aa32894,0x9e3c0240,0xe946007e,0x00000000}},	//   _hanf, _maďa, _بروی,
  { {0xd3f42049,0xb6a600fb,0x66d0004e,0x00000000}},	// [9340] нiст, _дипл, _läki,
  { {0x78a600a5,0x2216012c,0xe1f214d7,0x00000000}},	//   ldkv, офер, وسا_,
  { {0x9e3c0024,0x6aa3070e,0x78a401cf,0x00000000}},	//   _naďa, _manf, _kaiv,
  { {0x7afc00c2,0x78a61914,0x6aa34d16,0x00000000}},	//   črti, ndkv, _lanf,
  { {0xdfd0006a,0x9ffa0021,0x64430022,0x00000000}},	//   عيت_, جراء_, śnic,
  { {0x78a44d17,0xaf1c0085,0xbd6a4c19,0x00000000}},	//   _laiv, ыплi, арие_,
  { {0x20d704ab,0x2eee4d18,0x66cb013d,0x00000000}},	//   _için_, riff_, _züks,
  { {0x66cb01f7,0xdb0b017d,0x0caa02a1,0x00000000}},	//   _yüks, _urgê, ртки_,
  { {0xfb860088,0x394908ea,0x290b13b3,0x00000000}},	//   цыйн, _časa_, voca_,
  { {0xcb1a0079,0x6aa30185,0x290b002b,0x00000000}},	//   јќи_, _canf, woca_,
  { {0x09f8043b,0x6aa30185,0x4427001b,0x00000000}},	//   صفحة_, _danf, ̀n_,
  { {0x7aef0942,0x28f90121,0x60c20b13,0x00000000}},	//   éctr, семь_, njom,
  { {0x3f8603d9,0x290b4d19,0x6aa34d1a,0x00000000}},	//   ntou_, roca_, _fanf,
  { {0x6aa30185,0x3f860016,0xa3ae0053,0x00000000}},	//   _ganf, itou_, किन_,
  { {0x290b4d1b,0x96f81657,0x58d50899,0x00000000}},	//   poca_, церт_, _нокт,
  { {0x628e4d1c,0x66cb004b,0x38694d1d,0x00000000}},	//   _abbo, _püks, _udar_,
  { {0xdc9b014e,0x442f0137,0x68ed007d,0x00000000}},	// [9350] סימל, äg_, _imad,
  { {0x238e001c,0xcb370041,0xf485005d,0x00000000}},	//   dējā_, קאבי_, _کادی,
  { {0x21670085,0xc2c40044,0xf2c40044,0x00000000}},	//   ютаг, بيلي, بْلُ,
  { {0x41740021,0xc104007e,0x3cf60042,0x00000000}},	//   باكس, وولي, ुकों_,
  { {0x68ed00a4,0xcf9b02f8,0x645d4d1e,0x00000000}},	//   _mmad, рје_, _iesi,
  { {0x6da51e15,0x8ee80054,0x645d4d1f,0x00000000}},	//   зика, омів_, _hesi,
  { {0xb146006a,0x68ed0019,0x645d4d20,0x00000000}},	//   _فیلم_, _omad, _kesi,
  { {0xd5fc0063,0x66d000fe,0xdd8e0021,0x00000000}},	//   יפור, _väki, اوي_,
  { {0x69ce05b9,0x3f860827,0x645d3232,0x00000000}},	//   øben, ctou_, _mesi,
  { {0x78a400fe,0x20f800c2,0x4439271d,0x00000000}},	//   _saiv, ečih_, _lgs_,
  { {0xa9690138,0x4efa0047,0x3ea500b9,0x00000000}},	//   љима_, _פלעג, _ialt_,
  { {0x645d4d21,0x3ea54d22,0xa3ae0042,0x00000000}},	//   _nesi, _halt_, किम_,
  { {0x3ea510bc,0x78a600d1,0xa09a0047,0x00000000}},	//   _kalt_, rdkv, זירט,
  { {0x60db245c,0x78a400e5,0x68ed004b,0x00000000}},	//   _llum, _waiv, _emad,
  { {0x60db005b,0x645d120e,0x2d874d23,0x00000000}},	//   _olum, _besi, ntne_,
  { {0x60c90173,0x2748003b,0x645d4d24,0x00000000}},	//   _noem, _pînă_, _cesi,
  { {0x2d870019,0xbb480047,0xdb0b039f,0x00000000}},	// [9360] htne_, ַנאַ_, _argé,
  { {0x691d0003,0x2d874d25,0x645d004b,0x00000000}},	//   néen, ktne_, _eesi,
  { {0x68ed001f,0x2a6a00ea,0x66cb00ea,0x00000000}},	//   _ymad, óbbi_, _tükr,
  { {0x645d4097,0x238e001c,0x27240026,0x00000000}},	//   _gesi, tējā_, föng_,
  { {0x4463005a,0x7416007e,0x6d450195,0x00000000}},	//   _явяв, _روسا, íhan,
  { {0xa3e5016a,0xdb0b00cd,0xdee30054,0x00000000}},	//   _भेट_, _urgè, ночи,
  { {0x3ea52868,0x60c2001c,0x645d0379,0x00000000}},	//   _dalt_, pjom, _yesi,
  { {0x29000009,0x60db0df3,0xd1320021,0x00000000}},	//   _njia_, _glum, _أمر_,
  { {0x613a0080,0x3ea500d1,0x2d874d26,0x00000000}},	//   _důle, _falt_, atne_,
  { {0x3ea51e05,0x6123004b,0x6da6007b,0x00000000}},	//   _galt_, tõlg, _низа,
  { {0xa7fb0331,0x1ea900f2,0xdd8f009b,0x00000000}},	//   daña, _باقي_, _مول_,
  { {0x3ea5004d,0xfce30133,0x0ca90044,0x00000000}},	//   _zalt_, _похо, _وطني_,
  { {0x645d42b8,0xcce5002a,0xfc3f017c,0x00000000}},	//   _resi, _تسلي, žíc_,
  { {0xa7fb006d,0x645d4d27,0xc87f004d,0x00000000}},	//   gaña, _sesi, eißt_,
  { {0x56780076,0xa3e50053,0x645d0f2b,0x00000000}},	//   ября_, _भेज_, _pesi,
  { {0x7afc00c2,0xba170063,0xb4f90042,0x00000000}},	//   črtu, _מחוץ_, ्केप_,
  { {0x60c90179,0x57f50086,0xd90f007e,0x00000000}},	// [9370] _roem, _іпот, _لیگ_,
  { {0x60db3850,0x60c91643,0x2d870240,0x00000000}},	//   _slum, _soem, ytne_,
  { {0x68fd04d3,0x60db2308,0x60c90725,0x00000000}},	//   onsd, _plum, _poem,
  { {0x68fd04aa,0x3ea54d28,0x00000000,0x00000000}},	//   nnsd, _salt_,   ,
  { {0x7bc600fe,0x27240014,0x68fd4d29,0x00000000}},	//   äkul, bönd_, insd,
  { {0x7c390185,0x63ad00c7,0xa159000d,0x00000000}},	//   _sgwr, mvan, _магу_,
  { {0x3ea508d1,0x60c900ac,0xa1940e6b,0x00000000}},	//   _valt_, _toem, _парч,
  { {0x9f5f00ea,0xa7fb006d,0x60db0089,0x00000000}},	//   áról_, zaña, _ulum,
  { {0xac160001,0x4c920001,0x2d8714d5,0x00000000}},	//   моћу_, тињс, stne_,
  { {0xab5d0051,0xa3ae0053,0x63ad4d2a,0x00000000}},	//   wyżs, कित_, ivan,
  { {0x6dd5007e,0x66d00137,0x691d0003,0x00000000}},	//   _تقاض, _mäkt, réen,
  { {0x66d00137,0x7e630072,0x63ad4d2b,0x00000000}},	//   _läkt, lanp, kvan,
  { {0x691d0164,0xe79c005b,0x2724004d,0x00000000}},	//   péen, _düğü, höne_,
  { {0x63ad4d2c,0x386210f5,0x7e630050,0x00000000}},	//   dvan, sakr_, nanp,
  { {0x044603d6,0xa7fb006d,0x6b8918d2,0x00000000}},	//   дебн, raña, lteg,
  { {0x6b894d2d,0x98b2008f,0x63ad00a5,0x00000000}},	//   oteg, īzē_, fvan,
  { {0xccf20063,0xfa8e008b,0x61230019,0x00000000}},	// [9380] דכן_, _mừng_, kõlb,
  { {0x38600034,0xfa8e0013,0x6b894d2e,0x00000000}},	//   _heir_, _lừng_, iteg,
  { {0x7e63007d,0x63ad4d2f,0x63a900c2,0x00000000}},	//   danp, avan, _šent,
  { {0x6b8918dc,0x657c0072,0xdb024d30,0x00000000}},	//   kteg, murh, _troç,
  { {0x38604d31,0x6aa80185,0x657c0616,0x00000000}},	//   _meir_, yddf, lurh,
  { {0x7e6300a4,0x6b894d32,0xcdda005e,0x00000000}},	//   ganp, dteg, жњи_,
  { {0xc693014e,0x6b89042e,0xadd80086,0x00000000}},	//   דאו_, eteg, ямку_,
  { {0xdc13005b,0xc536009d,0x00000000,0x00000000}},	//   _ağır, וָ֥ה_,   ,
  { {0xfa8e008b,0x6b8900ca,0x7f86005d,0x00000000}},	//   _dừng_, gteg, _زلان,
  { {0x7b320051,0xcdd6005e,0x4d3a01d5,0x00000000}},	//   _tłum, _оцењ, _дядя_,
  { {0xa9c311ec,0x66d0078c,0xa3e00058,0x00000000}},	//   всяк, _läks, yüğü_,
  { {0x657c0026,0x3860001f,0xed5f0024,0x00000000}},	//   durh, _ceir_, ôžem_,
  { {0x38600025,0xd838000d,0x6b89002b,0x00000000}},	//   _deir_, дэр_, cteg,
  { {0x7d0d1035,0x387e005f,0x4648014b,0x00000000}},	//   čase, ėtra_, дзён_,
  { {0x628300cd,0x758802a1,0x79a3000d,0x00000000}},	//   ònom, мств_, _арые,
  { {0x63ad0102,0x3860001f,0x224d004c,0x00000000}},	//   tvan, _geir_, _řek_,
  { {0xa7fb006d,0x63ad4d33,0x20f80006,0x00000000}},	// [9390] maño, uvan, nčiu_,
  { {0x63ad0479,0xa7fb0331,0x98bf004c,0x00000000}},	//   rvan, laño, yptě_,
  { {0x7e634d34,0x6b8900c2,0x63ad1105,0x00000000}},	//   vanp, zteg, svan,
  { {0x6b890022,0x7c224d35,0x909b00de,0x00000000}},	//   yteg, _ozor, تضطر_,
  { {0x752d1d60,0xfa8e008b,0x290300c2,0x00000000}},	//   mmaz, _rừng_, čkah_,
  { {0x752d000f,0xd3f4000d,0xfa8e0013,0x00000000}},	//   lmaz, нiцт, _sừng_,
  { {0x7c2209a7,0x752d005f,0x7e6340c9,0x00000000}},	//   _azor, omaz, ranp,
  { {0x3135000a,0x752d005b,0x6b894d36,0x00000000}},	//   _чебр, nmaz, tteg,
  { {0x7e630150,0x6b890022,0xe452009a,0x00000000}},	//   panp, uteg, נֶה_,
  { {0x6b894d37,0x2001005b,0x1a65005d,0x00000000}},	//   rteg, şhis_, ریبی_,
  { {0xfa8e001b,0x6b894d38,0x752d0058,0x00000000}},	//   _từng_, steg, kmaz,
  { {0xc68901d8,0x6d41002c,0xa7fb006d,0x00000000}},	//   _לא_, _iula, gaño,
  { {0x7e61024a,0x291e003d,0xbd2c00b5,0x00000000}},	//   _kelp, ēta_, _וואָ,
  { {0x6d414d39,0x69c700b9,0x7d1b4d3a,0x00000000}},	//   _kula, øjes, llus,
  { {0x6d41058c,0x5a44000d,0xa7fb0331,0x00000000}},	//   _jula, _рэча, baño,
  { {0x20f80080,0x6d410357,0xa7fb006d,0x00000000}},	//   nčit_, _mula, caño,
  { {0x6d41021a,0x7d1b0341,0x4b4c0047,0x00000000}},	// [93a0] _lula, ilus, ַגאַ,
  { {0x7d1b00bd,0xe9ff001b,0x245e0013,0x00000000}},	//   hlus, _giải_, ắm_,
  { {0x6d414d3b,0x3afa0041,0x7d1b4d3c,0x00000000}},	//   _nula, פּמע, klus,
  { {0x2a65004d,0x63bb0078,0x30a50054,0x00000000}},	//   halb_, _šune, крів,
  { {0x7d1b0004,0x6d414d3d,0xdb020003,0x00000000}},	//   dlus, _aula, _croû,
  { {0xd00f007e,0x6d411d9c,0xce940062,0x00000000}},	//   حله_, _bula, такъ,
  { {0xdb0b017d,0x7d1b2eb3,0x629e4d3e,0x00000000}},	//   _orgâ, flus, mepo,
  { {0x61e10019,0x629e4d3f,0xf8bf00ea,0x00000000}},	//   _ülla, lepo, rmék_,
  { {0xa2c40161,0x6d414d40,0xcb980054,0x00000000}},	//   राप्, _eula, євої_,
  { {0x6d410009,0x7d1b0ff2,0x7c2215df,0x00000000}},	//   _fula, alus, _vzor,
  { {0x5cd60086,0x6d414d41,0x752d027d,0x00000000}},	//   _підх, _gula, ymaz,
  { {0x660901f7,0x629e1013,0x995e004c,0x00000000}},	//   şekk, hepo, _téže_,
  { {0x7c22017f,0x6d4100bd,0x69c700b9,0x00000000}},	//   _uzor, _zula, øjer,
  { {0x66d000c7,0x629e007d,0xa2c40042,0x00000000}},	//   _säkr, jepo, राफ्,
  { {0x65940597,0xa7fb1c50,0x629e4d42,0x00000000}},	//   лару, paño, depo,
  { {0x6aaa4d43,0x57b50330,0x6123004b,0x00000000}},	//   _haff, _абит, kõla,
  { {0x752d02f6,0x6aaa4d44,0xd37101fb,0x00000000}},	// [93b0] rmaz, _kaff, شها_,
  { {0x629e4d45,0x6aaa1433,0xd7fc009a,0x00000000}},	//   gepo, _jaff, _מהחל,
  { {0x7d1b002b,0x6aaa4d46,0x752d0058,0x00000000}},	//   ylus, _maff, pmaz,
  { {0x6d41000c,0x6aaa4d47,0x63c0011b,0x00000000}},	//   _rula, _laff, ózní,
  { {0xf77f005b,0x6d414d48,0x272400a5,0x00000000}},	//   nuç_, _sula, löna_,
  { {0x6d412ff8,0xfe7301fb,0x2d950141,0x00000000}},	//   _pula, ادش_, врис,
  { {0xf2d200b7,0x7d1b0004,0xdcfa01f7,0x00000000}},	//   _דעם_, tlus, _artı,
  { {0xb87b0025,0xdb0b017d,0x7e611a62,0x00000000}},	//   dhío, _orgã, _welp,
  { {0x6d410150,0x7e61008f,0x7d1b4d49,0x00000000}},	//   _wula, _telp, rlus,
  { {0xccf80080,0x6aaa4d4a,0xb87b0139,0x00000000}},	//   _svět_, _caff, fhío,
  { {0x6d41002c,0x7d1b0019,0x9f9b00fe,0x00000000}},	//   _uula, plus, säät_,
  { {0x629e0022,0x2c7a0075,0x97be014b,0x00000000}},	//   zepo, rüdü_, оргi,
  { {0x9cd6014e,0x629506d6,0xa2c40042,0x00000000}},	//   _שונה_, _obzo, राम्,
  { {0x2cad4d4b,0xddc1008f,0xca49005d,0x00000000}},	//   lded_, _nelū, _غلبه_,
  { {0x2cad00e5,0xe7374a59,0x629e4d4c,0x00000000}},	//   oded_, тер_, vepo,
  { {0x2cad4d4d,0x6aaa0290,0xa3ae0053,0x00000000}},	//   nded_, _zaff, किल_,
  { {0xd70a000a,0x2cad4d4b,0x629e4d4e,0x00000000}},	// [93c0] _оние_, ided_, tepo,
  { {0x6123004b,0xf1fa00f2,0x7546030b,0x00000000}},	//   võla, وعات_, _иноз,
  { {0xd6570063,0x290234cf,0x16770063,0x00000000}},	//   _שיטת_, onka_, _בגיל_,
  { {0x3d0b0053,0x29020026,0xe0da000d,0x00000000}},	//   हकों_, nnka_, ьве_,
  { {0xdb0b00cd,0x2cad4d4f,0x29024d50,0x00000000}},	//   _orgà, dded_, inka_,
  { {0x2cad0034,0xf4130063,0xcfd3005e,0x00000000}},	//   eded_, _כפר_, рошћ,
  { {0x7dc40032,0x6aaa4d51,0x5d63000d,0x00000000}},	//   اقعن, _raff, атыз,
  { {0x63a40051,0x2cbd002b,0xfd0f0044,0x00000000}},	//   owin, _cnwd_, يجي_,
  { {0x5b140062,0x63a40518,0xda7a1862,0x00000000}},	//   лмит, nwin, мян_,
  { {0x63ab0146,0x2cad4d52,0x29024d53,0x00000000}},	//   ægni, aded_, enka_,
  { {0xc27b0063,0x63a44d54,0xfbcf007e,0x00000000}},	//   וריי, hwin, متی_,
  { {0x6aaa1a6c,0x63a44d55,0x3eac00ca,0x00000000}},	//   _waff, kwin, _hadt_,
  { {0x64430051,0x6aaa2ce9,0x0a94046e,0x00000000}},	//   śnik, _taff, _балю,
  { {0x6b8001b0,0x63a41865,0x29024d56,0x00000000}},	//   mumg, dwin, anka_,
  { {0x59c30021,0x63a44d57,0x69dc01e1,0x00000000}},	//   _نيوك, ewin, øred,
  { {0xba370063,0x27240137,0x47d5005d,0x00000000}},	//   _בטוח_, röna_, _ميبر,
  { {0x394900c2,0x63a404a1,0x613a004c,0x00000000}},	// [93d0] _časi_, gwin, _půln,
  { {0x2473001b,0x63a2017d,0x78ad0213,0x00000000}},	//   ệm_, çona, _haav,
  { {0x78ad00fe,0x63a420ea,0x8c3d005b,0x00000000}},	//   _kaav, awin, leşe,
  { {0xf2df000c,0xf9930047,0x78ad0072,0x00000000}},	//   _atât_, ירע_, _jaav,
  { {0x7f19000d,0x78ad0ff2,0x747a0063,0x00000000}},	//   ніку_, _maav, _אנרג,
  { {0x644d0003,0x7e540062,0x2cad00e5,0x00000000}},	//   lcai, атъц, wded_,
  { {0x753d00ea,0x644d0d2f,0xfc3f0114,0x00000000}},	//   _kisz, ocai, žím_,
  { {0x644d4d58,0xd0d40062,0x2cad00e5,0x00000000}},	//   ncai, _косъ, uded_,
  { {0x2cad4d59,0x2cb1004c,0x753d1556,0x00000000}},	//   rded_, ězd_, _misz,
  { {0x62854d5a,0x753d0758,0xfaa5005e,0x00000000}},	//   ngho, _lisz, ћано,
  { {0x63a408ae,0x5dd50021,0xa2c40042,0x00000000}},	//   zwin, _حقائ, रात्,
  { {0x63a400e8,0x7c87000a,0x753d0051,0x00000000}},	//   ywin, _јуже, _nisz,
  { {0x8cc00053,0xcbc7005d,0x78ad0050,0x00000000}},	//   वारो, _جزاي, _daav,
  { {0xee450014,0xf7434073,0x99d5009b,0x00000000}},	//   _þýdd_, серо, _متبا,
  { {0x6606005a,0xa50a13da,0x753d13d9,0x00000000}},	//   упва, еева_, _bisz,
  { {0xd5b7008b,0x6aa100ca,0x7cfe008f,0x00000000}},	//   ứng_, lelf, tīri,
  { {0x63a44d5b,0x753d3748,0x2903004c,0x00000000}},	// [93e0] uwin, _disz, čkat_,
  { {0x33d50086,0x63a44d5c,0x644d0139,0x00000000}},	//   шіст, rwin, acai,
  { {0x394f0529,0x68e40080,0xccf90051,0x00000000}},	//   _însă_, _klid, kiś_,
  { {0x7455011c,0x600a000d,0x6aa1087d,0x00000000}},	//   _върх, ннем_, helf,
  { {0x6aa1130e,0x7981004d,0x33d60085,0x00000000}},	//   kelf, hulw, _сінт,
  { {0x3243005a,0xf8bf00ea,0xe1660021,0x00000000}},	//   _герг, lmét_, _مدري,
  { {0x91e638bf,0x68e419fb,0x6aa14d5d,0x00000000}},	//   _сове, _olid, delf,
  { {0x6b801837,0xbb740141,0x2d8e00dd,0x00000000}},	//   tumg, агиј, rtfe_,
  { {0xcb67018e,0xc006237c,0xdcf8008f,0x00000000}},	//   гање_, _спак, guvā,
  { {0x78ad0aba,0xbda601fb,0x8f9b00ff,0x00000000}},	//   _saav, _محصو, _אימי,
  { {0x527b0047,0x78ad0659,0xc27b0047,0x00000000}},	//   ענטא, _paav, ערטי,
  { {0x8c460ae8,0x27e60022,0x28af0042,0x00000000}},	//   _седе, _żona_, _जोखि,
  { {0x6d5800ac,0x765c00b9,0x48e40085,0x00000000}},	//   lpva, fbry, соўв,
  { {0x7bc60072,0x8aa30062,0x68e44d5e,0x00000000}},	//   äkuu, _гръд, _elid,
  { {0x8c3d000c,0x63a20003,0x16350121,0x00000000}},	//   reşe, çonn, ревя,
  { {0x7afa4d5f,0x69da216b,0xa7b90002,0x00000000}},	//   litt, myte, _алиу_,
  { {0x753d00ea,0x7afa00fe,0x644d4d60,0x00000000}},	// [93f0] _visz, oitt, rcai,
  { {0x644d1397,0x35f50086,0x628500e5,0x00000000}},	//   scai, _впор, ugho,
  { {0x7afa00fe,0x753d00ea,0x69da4d61,0x00000000}},	//   iitt, _tisz, nyte,
  { {0x6aa102b0,0x7afa024a,0xf8bf0003,0x00000000}},	//   zelf, hitt, mmés_,
  { {0x7afa00fe,0xddd001c2,0x08780047,0x00000000}},	//   kitt, _češt, רעדט_,
  { {0xf8bf0268,0x7afa00fe,0x69da04aa,0x00000000}},	//   omés_, jitt, kyte,
  { {0x7afa4d62,0x6cc50094,0x00000000,0x00000000}},	//   ditt, ийка,   ,
  { {0x798100e8,0xeb994d63,0x69da4d64,0x00000000}},	//   vulw, вии_, dyte,
  { {0x7afa055b,0xa7fb0331,0xc1040044,0x00000000}},	//   fitt, bañi, _طوكي,
  { {0x7afa4d65,0x29090072,0x2b460013,0x00000000}},	//   gitt, _ajaa_, _duoc_,
  { {0x8a380076,0x765c0807,0x6123004e,0x00000000}},	//   ляют_, vbry, hõlm,
  { {0x6aa12154,0xab95019d,0x3c470032,0x00000000}},	//   self, _виді, _إضاف,
  { {0x394915df,0x7d0418c4,0xf7461594,0x00000000}},	//   _času_, čist, рего,
  { {0xaa880021,0x69da4d66,0x4b7a0149,0x00000000}},	//   _منهم_, byte, _יאנו,
  { {0x48e60062,0x765c06f1,0x9876005e,0x00000000}},	//   _войв, rbry, _купљ,
  { {0x2caf004d,0x765c4d67,0x93c7008d,0x00000000}},	//   _jagd_, sbry, _trặ,

  { {0x6266000a,0xd4550086,0xe8c70062,0x00000000}},	// [9400] иваа, стсь, _ъгъл_,
  { {0x394700e8,0x2caf0829,0xf8bf013d,0x00000000}},	//   _kuns_, _lagd_, smét_,
  { {0xc693014e,0x21a60429,0x61230019,0x00000000}},	//   _ואת_, рием, põll,
  { {0x7afa0122,0xe7b3007e,0xdc340066,0x00000000}},	//   zitt, _امید, _súči,
  { {0x69da08ae,0x44244d68,0x613a011b,0x00000000}},	//   zyte, _ám_, _hůlk,
  { {0xa2e60076,0xdd9a4d69,0xf2df0013,0x00000000}},	//   _тогд, вши_, _huân_,
  { {0x7afa024a,0xf8bf0164,0xbd670121,0x00000000}},	//   vitt, llée_, арые_,
  { {0x61430699,0x7afa2d75,0x69da0050,0x00000000}},	//   _фета, witt, vyte,
  { {0x7afa4d6a,0x6440017d,0x807b0063,0x00000000}},	//   titt, _úmid, _שנמצ,
  { {0xf2d300b5,0xf2df008b,0x1eaa009e,0x00000000}},	//   ַער_, _luân_, _جاري_,
  { {0x7afa4d6b,0xc3330063,0x26d324f3,0x00000000}},	//   ritt, חוז_, _roxo_,
  { {0x7afa024a,0x394908ed,0x6d484d6c,0x00000000}},	//   sitt, _čast_, _iuda,
  { {0xcb5403eb,0x7afa2eb2,0xbb540044,0x00000000}},	//   _انتظ, pitt, _انتب,
  { {0xd7f8093e,0xfaa306f0,0x6d4814f9,0x00000000}},	//   рую_, _мачо, _kuda,
  { {0x99840021,0x39473bea,0xddc3003b,0x00000000}},	//   _العو, _guns_, manţ,
  { {0xddc3000c,0xdb0b00bd,0x6d484d6d,0x00000000}},	//   lanţ, _ergä, _muda,
  { {0xc2990088,0x026b0076,0x68fd25d2,0x00000000}},	// [9410] лках_, вшей_, misd,
  { {0x38690034,0xddc3000c,0xa2c40053,0x00000000}},	//   _hear_, nanţ, राष्,
  { {0xe2980086,0x6f180114,0x6123004b,0x00000000}},	//   рає_, dovc, sõlm,
  { {0x11280086,0xf8bf0003,0x3d100053,0x00000000}},	//   аючи_, blée_, ावों_,
  { {0x2d9e32c9,0x38690139,0x6d484d6e,0x00000000}},	//   _apte_, _mear_, _auda,
  { {0xef180088,0x6d484d6f,0x6f18082a,0x00000000}},	//   амі_, _buda, govc,
  { {0x29194d70,0xa2c40053,0xd13b0854,0x00000000}},	//   kosa_, रार्, _аха_,
  { {0x6d480185,0x39470034,0x38691a74,0x00000000}},	//   _duda, _runs_, _near_,
  { {0xde590086,0x39402bcc,0xbebc008f,0x00000000}},	//   _базі_, _riis_, _rhīv,
  { {0x76450185,0x39400449,0xf3ff017d,0x00000000}},	//   _nghy, _siis_, _leão_,
  { {0x38691898,0xc7a90a7a,0x291901a8,0x00000000}},	//   _bear_, _רב_, fosa_,
  { {0xcd960063,0x69dc00d1,0x29194d71,0x00000000}},	//   _לדעת_, ørea, gosa_,
  { {0x38690592,0x39400019,0x69ce00b9,0x00000000}},	//   _dear_, _viis_, øber,
  { {0xdc3600b5,0xddc3000c,0x7c2b4d72,0x00000000}},	//   _פאסט_, canţ, _izgr,
  { {0x3869057a,0xf77f00cd,0x68fd00ca,0x00000000}},	//   _fear_, arç_, bisd,
  { {0x3991099d,0xf2df001b,0x38694d73,0x00000000}},	//   más_, _quân_, _gear_,
  { {0x3991000f,0xf8bf0003,0x6f180066,0x00000000}},	// [9420] lás_, ulée_, yovc,
  { {0x7b1d00cd,0x24890150,0x78a600ea,0x00000000}},	//   cèut, agam_, lekv,
  { {0x38690037,0xf2df008b,0x78a60104,0x00000000}},	//   _year_, _tuân_, oekv,
  { {0xdfcf007e,0x6d484d74,0xf8bf0003,0x00000000}},	//   کيه_, _ruda, plée_,
  { {0x351b014e,0x6d480801,0x78a60006,0x00000000}},	//   _תוכנ, _suda, iekv,
  { {0x3ce60512,0x6d481fdc,0x679b0047,0x00000000}},	//   _slov_, _puda, רױסג,
  { {0x42e70001,0xddc3000c,0xe45f00ac,0x00000000}},	//   _умро_, vanţ, _koöp_,
  { {0x4422021f,0x3991000f,0xcb540001,0x00000000}},	//   _kyk_, dás_, овић,
  { {0xddc3000c,0x752435dc,0x7cfe0006,0x00000000}},	//   tanţ, iliz, gūra,
  { {0x9998000a,0x6d484d75,0x2ca40026,0x00000000}},	//   акот_, _tuda, semd_,
  { {0x442200e8,0xddc3000c,0xf8bf00ea,0x00000000}},	//   _lyk_, ranţ, jléc_,
  { {0x7aef0268,0xa8eb0021,0xddc300dd,0x00000000}},	//   èctr, اعدك_, sanţ,
  { {0x3f860016,0xddc34d76,0x6c36007e,0x00000000}},	//   nuou_, panţ, _افشا,
  { {0x38690034,0x5b130086,0x15ab0062,0x00000000}},	//   _wear_, _еміт, лъби_,
  { {0x386900e5,0x29194d77,0x58d54c19,0x00000000}},	//   _tear_, posa_, _мокт,
  { {0xddc3001c,0x61310093,0x24894d78,0x00000000}},	//   nanš, målg, ugam_,
  { {0x69dc0137,0x7b1d00cd,0x24894d79,0x00000000}},	// [9430] äref, pèut, rgam_,
  { {0xb87b000f,0x75244d7a,0x2a780139,0x00000000}},	//   ghív, aliz, órbh_,
  { {0x66d0024a,0x1a9b0047,0xddc300a8,0x00000000}},	//   _näky, ריבע, kanš,
  { {0xddc300c2,0x63ae0072,0x442b3116,0x00000000}},	//   janš, ännä, _tzc_,
  { {0x39914d7b,0x98b90006,0x8c420244,0x00000000}},	//   zás_, ūrė_, äßli,
  { {0xb87b45ef,0x5e870085,0x8d550d0a,0x00000000}},	//   chív, судз, отич,
  { {0xed59093e,0x399100be,0xad5827b8,0x00000000}},	//   шой_, xás_, брых_,
  { {0x399100ea,0x7cfe0df9,0x7b320022,0x00000000}},	//   vás_, tūra, _słup,
  { {0xe0e40088,0x69dc0205,0x3f86017d,0x00000000}},	//   _эўро, øren, cuou_,
  { {0x39910882,0xdc1c001c,0x0b160021,0x00000000}},	//   tás_, eņēm, يقية_,
  { {0xa9690138,0xddc300c2,0x3ea710c5,0x00000000}},	//   јима_, banš, ment_,
  { {0x3ea0017f,0x2d874d7c,0x6d424d7d,0x00000000}},	//   đite_, mune_, _gioa,
  { {0x7d240055,0x3ced00d1,0x78a6287a,0x00000000}},	//   _эффе, mhev_, rekv,
  { {0x44221b21,0xaa68006a,0x7d091729,0x00000000}},	//   _ryk_, _همهٔ_, lnes,
  { {0x3ea703b2,0x7d090035,0xba390047,0x00000000}},	//   ient_, ones, _דײַט,
  { {0x75240035,0x61310137,0x7d091508,0x00000000}},	//   uliz, nåld, nnes,
  { {0x3ea74d7e,0x8c360047,0x75244d7f,0x00000000}},	// [9440] kent_, ַטעס_, rliz,
  { {0x3ea74d80,0x7d1b4d81,0x75240460,0x00000000}},	//   jent_, hous, sliz,
  { {0x752400bd,0x41aa06be,0x7d1b4d82,0x00000000}},	//   pliz, рвен_, kous,
  { {0xa99a00b5,0x3f86017d,0x9f960019,0x00000000}},	//   יבער, tuou_, _tüüp_,
  { {0x027f0080,0x2b490025,0x2d870003,0x00000000}},	//   _říše_, _éach_, eune_,
  { {0xdc1c001c,0x3ea74d83,0x7d094d84,0x00000000}},	//   zņēm, gent_, enes,
  { {0x2d870019,0xc0e60086,0x9e33000d,0x00000000}},	//   gune_, _довк, мешч,
  { {0x7d091eda,0x3ea7002b,0x7f860044,0x00000000}},	//   gnes, aent_, _ولأن,
  { {0x3ea74d85,0x6d42003b,0x0ba60054,0x00000000}},	//   bent_, _vioa, ішим,
  { {0x21260150,0x7d094d86,0x2d874d87,0x00000000}},	//   lloh_, anes, bune_,
  { {0x6e93006a,0x39580162,0x2d874d88,0x00000000}},	//   _آلما, ërs_, cune_,
  { {0x5bc60021,0xdcee001c,0x7d1b12fe,0x00000000}},	//   _وقال, ēdēj, cous,
  { {0x37e40085,0x8c3d0058,0xdc1c0023,0x00000000}},	//   доўг, neşl, rņēm,
  { {0x3f50008b,0x61310246,0x7d004d89,0x00000000}},	//   _màu_, måle, lims,
  { {0xfc3f0080,0xd5b812d5,0xe46b0002,0x00000000}},	//   žít_, ост_, ишал_,
  { {0x395e0592,0x3ea74d8a,0x5507000d,0x00000000}},	//   mpts_, zent_, ічва,
  { {0xa3ab0053,0x439402a9,0x3ea70003,0x00000000}},	// [9450] _कैश_, матс, yent_,
  { {0x3ea71b84,0xb4db008b,0x7d0d14d5,0x00000000}},	//   xent_, _giàn, časi,
  { {0x3ea704bc,0x61310137,0x15ab0062,0x00000000}},	//   vent_, håle, _тъпи_,
  { {0x76550051,0x3ea724bf,0x7cfe0078,0x00000000}},	//   lczy, went_, dūro,
  { {0x8cce0053,0xef0e326a,0x98c6007d,0x00000000}},	//   थानो, ем_, šući_,
  { {0x643a0047,0x7d000026,0x0596007e,0x00000000}},	//   _לערנ, eims, _بایگ,
  { {0x69dc0205,0x7d092b9f,0x3ea73653,0x00000000}},	//   ørel, tnes, rent_,
  { {0x63ad0051,0x3ea72fe3,0x3cc9005e,0x00000000}},	//   owan, sent_, слио_,
  { {0xff5301a7,0x7981001f,0x6d5a3f0f,0x00000000}},	//   _آخر_, wrlw, _etta,
  { {0x63a000c7,0xdd00003d,0x2d871052,0x00000000}},	//   _ämne, ētāj, pune_,
  { {0x63ad0d9d,0x3ced00d1,0x76550051,0x00000000}},	//   hwan, phev_, dczy,
  { {0x8c3d005b,0x63ad3c0c,0x39440137,0x00000000}},	//   leşm, kwan, öms_,
  { {0xdb020014,0x63ad1f26,0xbc640085,0x00000000}},	//   _troð, jwan, _цвік,
  { {0x290b4d8b,0x501a0063,0xe73a197b,0x00000000}},	//   anca_, מורו, сег_,
  { {0xd62a4d8c,0xeaf8009e,0xe45f00a5,0x00000000}},	//   сове_, _برنت_, _snöa_,
  { {0x63ad00bd,0xf8bf0331,0x75d3014d,0x00000000}},	//   fwan, llén_, ريقا,
  { {0x29024d8d,0x63ad0d89,0x7cfe0078,0x00000000}},	// [9460] mika_, gwan, zūro,
  { {0x78b6005b,0xb87b0025,0x29024d8e,0x00000000}},	//   _hayv, bhís, lika_,
  { {0xb87b006d,0x78b60089,0x63ad4d8f,0x00000000}},	//   chís, _kayv, awan,
  { {0xb6080114,0x98bd0078,0x29021be2,0x00000000}},	//   alší, _buvę_, nika_,
  { {0x9f53000d,0x6b89006d,0x63ad00ac,0x00000000}},	//   евіч, jueg, cwan,
  { {0x7cfe0006,0x29024d90,0x8c3d0075,0x00000000}},	//   tūro, hika_, reşl,
  { {0x29023a57,0x6aa801f2,0x212600c2,0x00000000}},	//   kika_, vedf, ploh_,
  { {0x29020035,0x6b89006d,0x3f50001b,0x00000000}},	//   jika_, fueg, _tàu_,
  { {0x3f67005a,0x2902058c,0x76550051,0x00000000}},	//   _нито_, dika_, yczy,
  { {0x61311c59,0xdea0005d,0xf9780092,0x00000000}},	//   råle, _شیعی, обој_,
  { {0x4427001b,0xbc6a006a,0xdca60b3f,0x00000000}},	//   ́n_, _همان_, _нажи,
  { {0x63ad0045,0x29024d91,0x76550051,0x00000000}},	//   ywan, gika_, wczy,
  { {0xb4db0268,0x6123004b,0xa09b0047,0x00000000}},	//   _diàl, põlv, זיכט,
  { {0x26da039f,0xa3c20053,0x29024d92,0x00000000}},	//   _copo_, ्मन_, aika_,
  { {0x26da02f6,0xcb1300b5,0x76550051,0x00000000}},	//   _dopo_, _אלס_, rczy,
  { {0xdb0d00ea,0xe81e0053,0xa4d402fe,0x00000000}},	//   óköv, _युवा_, носі,
  { {0xa87c014e,0x63ad0ef2,0x442f0137,0x00000000}},	// [9470] _האחר, uwan, åg_,
  { {0x6eef0d02,0x63ad03ac,0x67460066,0x00000000}},	//   _købe, rwan, ľujú,
  { {0x68ed4d93,0x41e4000d,0x67460066,0x00000000}},	//   _klad, ніца, žujú,
  { {0xf1c000aa,0x6eef05e7,0x93c700dd,0x00000000}},	//   ương_, _møbe, _arăţ,
  { {0x6eef0146,0x68ed064f,0xcf9b02d8,0x00000000}},	//   _løbe, _mlad, сје_,
  { {0x68ed001f,0x29024d94,0xad5917f2,0x00000000}},	//   _llad, zika_, орих_,
  { {0xfe704d95,0x53340ac5,0xd6580063,0x00000000}},	//   اده_, _черт, היות_,
  { {0x29024d96,0xa0c50044,0xf1b2009a,0x00000000}},	//   xika_, _تيرو, _בסל_,
  { {0x2d8a0146,0x60c94d97,0x394e004d,0x00000000}},	//   _åben_, _inem, _aufs_,
  { {0xa91d0024,0xe578001c,0x29022f40,0x00000000}},	//   buľk, šķi_, wika_,
  { {0x68ed4d98,0x6f0302f6,0x29024d99,0x00000000}},	//   _blad, minc, tika_,
  { {0x6eef00b9,0x68ed4d9a,0xae1a0041,0x00000000}},	//   _døbe, _clad, _וועכ,
  { {0x29021336,0x6b894d9b,0x6f03264a,0x00000000}},	//   rika_, queg, oinc,
  { {0x290214ee,0xb4db00cd,0x68ed4d9c,0x00000000}},	//   sika_, _diàm, _elad,
  { {0xceb20a7a,0x60c906b9,0x29020645,0x00000000}},	//   כים_, _onem, pika_,
  { {0xa3ea1001,0x68ed37d8,0x60c90078,0x00000000}},	//   одба_, _glad, _nnem,
  { {0x26da4d9d,0x6f030058,0xa8060054,0x00000000}},	// [9480] _topo_, kinc, _ізол,
  { {0x05560062,0x26da01f4,0xc746005d,0x00000000}},	//   _отмя, _uopo_, _تضعي,
  { {0x60db3d7e,0x6f034d9e,0x104a0a2f,0x00000000}},	//   _boum, dinc, ояли_,
  { {0x23600122,0x2b47001f,0x61e306a5,0x00000000}},	//   ppij_, _linc_, ønla,
  { {0x6f03051e,0x60db1da4,0x4f570593,0x00000000}},	//   finc, _doum, وجود_,
  { {0xd00f006a,0x934615d4,0x60c909e2,0x00000000}},	//   جله_, _інве, _enem,
  { {0x1ea90032,0x273605b9,0x290000fe,0x00000000}},	//   ثاني_, mænd_, _omia_,
  { {0x2d800024,0x629e0c5f,0x9be60054,0x00000000}},	//   čie_, lfpo, діок,
  { {0x6f0300e3,0xdca3005e,0x2b47002b,0x00000000}},	//   binc, тањи, _binc_,
  { {0x2b470268,0xddc60001,0x60c90114,0x00000000}},	//   _cinc_, _обзи, _znem,
  { {0x68ed0146,0x6d5e016b,0xe895000d,0x00000000}},	//   _plad, ípad, нань,
  { {0x63a600f5,0xdccf008d,0xf98f0043,0x00000000}},	//   _opkn, _hỉnh_, گبی_,
  { {0x59b00053,0x68ed21d5,0xc7b8000d,0x00000000}},	//   _जनवर, _vlad, мёр_,
  { {0x68ed4d9f,0x7c2f0058,0xf98f005d,0x00000000}},	//   _wlad, ücre, دبی_,
  { {0x442d0198,0x645a003b,0xfaa30699,0x00000000}},	//   _še_, _ştia, _рајо,
  { {0x39983e26,0x68ed0025,0xe534000d,0x00000000}},	//   més_, _ulad, весь,
  { {0xe6670432,0x3998236e,0xe1f0007e,0x00000000}},	// [9490] _отно, lés_, یسم_,
  { {0x95cb011c,0x51870001,0x60db419d,0x00000000}},	//   _дума_, дуда, _soum,
  { {0x3f99001c,0x60c9006f,0x60db4da0,0x00000000}},	//   _ūsu_, _pnem, _poum,
  { {0x6f030051,0x3998006c,0xf8bf011b,0x00000000}},	//   winc, iés_, klém_,
  { {0x39980164,0x3f86017d,0xdbd6021e,0x00000000}},	//   hés_, grou_, _jääm,
  { {0xc6950047,0x63a00137,0x8ca10053,0x00000000}},	//   גאַ_, _ämna, क्नो,
  { {0x7bc20037,0x6e28002b,0xed560062,0x00000000}},	//   _arou, _cydb, нощ_,
  { {0x2736010a,0x8c3d005b,0x7bc24da1,0x00000000}},	//   mæne_, leşi, _brou,
  { {0x6f034da2,0x2b47002b,0xe0d20041,0x00000000}},	//   pinc, _pinc_, _גײן_,
  { {0xbda70021,0x39984da3,0x7bc21574,0x00000000}},	//   _يحاو, fés_, _drou,
  { {0x39494da4,0x399843cc,0x7bc2003b,0x00000000}},	//   _bias_, gés_, _erou,
  { {0xdc7500b5,0x3949006d,0xf8bf004a,0x00000000}},	//   _װײַז_, _cias_, blém_,
  { {0x394903d9,0x2b470268,0x7bc24da5,0x00000000}},	//   _dias_, _tinc_, _grou,
  { {0x2cad224f,0x39980ebd,0x98a5008f,0x00000000}},	//   leed_, bés_, ēlā_,
  { {0x39983e26,0x13c80053,0x64a60aab,0x00000000}},	//   cés_, रम्भ, нава,
  { {0x2cad00ca,0x3f864da6,0x00000000,0x00000000}},	//   need_, yrou_,   ,
  { {0xccf20047,0x6b9b0014,0x8ca10042,0x00000000}},	// [94a0] אכן_, ntug, क्यो,
  { {0x915e0013,0x2cad4da7,0x22164da8,0x00000000}},	//   _hẳn_, heed_, нфер,
  { {0x22930021,0xd51a0013,0x91e30062,0x00000000}},	//   المس, hẳn, лофе,
  { {0x3f864da9,0x7053007e,0xa3c20053,0x00000000}},	//   trou_, هنما, ्मद_,
  { {0x3998000f,0x2cad0034,0x2d874daa,0x00000000}},	//   zés_, deed_, erne_,
  { {0x7bc400eb,0x39980164,0xe578001c,0x00000000}},	//   _šiuo, yés_, šķu_,
  { {0x61310137,0x399800f4,0xc6930047,0x00000000}},	//   måln, xés_, טאג_,
  { {0x61f2005b,0x613100d1,0x71260021,0x00000000}},	//   ıklı, påla, _أرسل,
  { {0x6b9b002c,0xdccf008b,0xa1370047,0x00000000}},	//   gtug, _tỉnh_, _טאלק_,
  { {0x39984dab,0x7bc20173,0x78a40019,0x00000000}},	//   tés_, _vrou, _abiv,
  { {0xdb0b0025,0x6b9b00a4,0x7bc200e5,0x00000000}},	//   _argó, atug, _wrou,
  { {0xa3c20235,0x2cad0034,0x7bc204bc,0x00000000}},	//   ्मा_, ceed_, _trou,
  { {0x39982370,0x3eae006f,0x69c34dac,0x00000000}},	//   sés_, oeft_, _erne,
  { {0x39984dad,0x7cfe005f,0xdbd60050,0x00000000}},	//   pés_, dūri, _vääm,
  { {0x2d9c00ea,0x628305d5,0x7cf5004c,0x00000000}},	//   ntve_, ónom, _dárf,
  { {0x98a40001,0x612a0014,0x61e501d1,0x00000000}},	//   _биће, býli, vyhl,
  { {0x47350601,0x889c069a,0xa2cd0042,0x00000000}},	// [94b0] _инис, _זבחי, साल्,
  { {0xd5bb000a,0x78a4007d,0x78bd2a38,0x00000000}},	//   _есм_, _zbiv, ldsv,
  { {0x7d020290,0x7afd00cd,0x8c3d1c8a,0x00000000}},	//   _omos, èsti, reşi,
  { {0x3eae0122,0xd4790047,0x82340021,0x00000000}},	//   eeft_, _קאָל, اركا,
  { {0xe9ff008b,0x78bd0353,0x5ff50062,0x00000000}},	//   _khải_, idsv, ъзду,
  { {0x752d104f,0x7d0237ac,0x2d870066,0x00000000}},	//   llaz, _amos, trne_,
  { {0x2cad004b,0x62344dae,0x752d007d,0x00000000}},	//   teed_, _беру, olaz,
  { {0x752d048e,0x7cf5006d,0x6b9b4daf,0x00000000}},	//   nlaz, _márg, ttug,
  { {0x78bd00d1,0x78af003b,0x2d8e004d,0x00000000}},	//   ddsv, decv, aufe_,
  { {0x7d02334f,0x6b9b4db0,0x99d50021,0x00000000}},	//   _emos, rtug, نتجا,
  { {0x3f8f4db1,0x2d9c0066,0x7bcd0078,0x00000000}},	//   lugu_, ctve_, _šaud,
  { {0x69c300c3,0x7cf50139,0xf1b2016e,0x00000000}},	//   _vrne, _sárf, בסט_,
  { {0x1867005e,0x79884db2,0x6d4b013d,0x00000000}},	//   ђари_, ardw, _iiga,
  { {0x6f0d0027,0x7988002b,0x6b894db3,0x00000000}},	//   éach, brdw, mreg,
  { {0x6d4b0035,0x7d02001f,0xd6271321,0x00000000}},	//   _kiga, _ymos, воре_,
  { {0x6b893a19,0x7cfe2401,0x78a40130,0x00000000}},	//   oreg, tūri, _ubiv,
  { {0x6d4b1041,0x442b4db4,0x03263f5d,0x00000000}},	// [94c0] _miga, _cyc_, вдан,
  { {0x6d4b4519,0x752d2efa,0x69c100c2,0x00000000}},	//   _liga, alaz, ovle,
  { {0x63a9001c,0x61310137,0x752d1c79,0x00000000}},	//   _ģene, råln, blaz,
  { {0x6b890122,0x55770047,0x41b5000d,0x00000000}},	//   kreg, _בעטן_, ысут,
  { {0xa857014e,0x60230076,0x4fb30021,0x00000000}},	//   דינה_, адца, لصور,
  { {0x61380080,0x2d8e2475,0x57fb0063,0x00000000}},	//   díle, tufe_, ולנו,
  { {0x6d4b4db5,0x3eae029e,0x6b891f73,0x00000000}},	//   _biga, reft_, ereg,
  { {0x5bb800a0,0x2d8e004d,0x6b894db6,0x00000000}},	//   елия_, rufe_, freg,
  { {0x6d4b462b,0x69c1005b,0xdfa50021,0x00000000}},	//   _diga, evle, _محلي,
  { {0x613101e3,0x2ac60001,0xc43b0063,0x00000000}},	//   håll, тљив, ותפי,
  { {0x6d4b4db7,0x765c002b,0x4dda0044,0x00000000}},	//   _figa, dcry, _توضح_,
  { {0x78bd006f,0x61380025,0x7cf54db8,0x00000000}},	//   udsv, bíle, _cárd,
  { {0xe9ff00aa,0x61380080,0x78bd146b,0x00000000}},	//   _phải_, cíle, rdsv,
  { {0x6d4b004d,0x6d40358d,0x65954db9,0x00000000}},	//   _ziga, lmma, лагу,
  { {0x09e30540,0x35e424ad,0x6d404dba,0x00000000}},	//   _војн, ацтв, omma,
  { {0x6d4e0164,0xe4a7005a,0x65940092,0x00000000}},	//   _ébau, ърго, јату,
  { {0x6d400bb7,0xe9ff008b,0xe3b00021,0x00000000}},	// [94d0] imma, _thải_, يرك_,
  { {0x8c3d000c,0x660e0080,0x752d04ad,0x00000000}},	//   meşt, ánká, slaz,
  { {0x224701e3,0x2d580164,0x8c3d4b91,0x00000000}},	//   änk_, _née_, leşt,
  { {0xf8bf0164,0x66010014,0xccf8011b,0x00000000}},	//   ndé_, úlku, _stěn_,
  { {0x8c3d000c,0x6d4b0409,0x67320014,0x00000000}},	//   neşt, _riga, _ákjó,
  { {0x539a014e,0x6d4b4dbb,0x8c3d000c,0x00000000}},	//   _אישו, _siga, ieşt,
  { {0x69dc0019,0x3f8f004b,0x8c3d00dd,0x00000000}},	//   ärel, sugu_, heşt,
  { {0x7cfe0006,0x7bdd0072,0x6b8911ed,0x00000000}},	//   kūru, äsuo, treg,
  { {0x6d4b4dbc,0x7bcd008f,0x7cf50066,0x00000000}},	//   _viga, _šaub, _náre,
  { {0x6b894dbd,0xe9d94dbe,0x8c3d003b,0x00000000}},	//   rreg, еко_, deşt,
  { {0x61380080,0x39460076,0x7c2b0051,0x00000000}},	//   síle, лног, _wygr,
  { {0x6b894dbf,0x69c14dc0,0xdcbb0054,0x00000000}},	//   preg, rvle, _іще_,
  { {0x7cfe0006,0x7d094dc1,0x7524007d,0x00000000}},	//   gūru, mies, voiz,
  { {0x2cbf0019,0xf8bf0003,0x7d094dc2,0x00000000}},	//   ldud_, adé_, lies,
  { {0xe737005a,0x69dc0ca9,0x2cbf004b,0x00000000}},	//   уер_, øret, odud_,
  { {0x2cbf0019,0x8c3d003b,0x7d094dc3,0x00000000}},	//   ndud_, beşt, nies,
  { {0x8c3d000c,0x7524027c,0x2cbf004b,0x00000000}},	// [94e0] ceşt, roiz, idud_,
  { {0x7d094dc4,0x7bc40006,0x27ed06a5,0x00000000}},	//   hies, _šiuk, øene_,
  { {0x7d094dc5,0xea760047,0x869b0149,0x00000000}},	//   kies, רגער_, _אייז,
  { {0xcf9a0141,0x7d090072,0x4f660021,0x00000000}},	//   ејк_, jies, هاتف,
  { {0x7d094dc6,0xdee64dc7,0xe612007e,0x00000000}},	//   dies, лоди, _خشک_,
  { {0x2d80001c,0x7cf50139,0x63b6002b,0x00000000}},	//   ņiem_, _nárb, mwyn,
  { {0x7d094dc8,0xc6930063,0x63b6001f,0x00000000}},	//   fies, צאה_, lwyn,
  { {0x7d09135f,0x69dc0137,0xbd43007e,0x00000000}},	//   gies, ärem, مچني,
  { {0x7cf50460,0x21260150,0x63b6002b,0x00000000}},	//   _bárb, mooh_, nwyn,
  { {0x8c3d000c,0xe39b0047,0xd00f014d,0x00000000}},	//   veşt, עשיכ, _علل_,
  { {0x63b6001f,0x6eef06a5,0x3915157c,0x00000000}},	//   hwyn, _møbl, имор,
  { {0x8c3d000c,0x3ebe3495,0x2ca600a4,0x00000000}},	//   teşt, _hatt_, _ubod_,
  { {0xead406bc,0x6c7b0047,0xf8bf4dc9,0x00000000}},	//   _воль, _טראד, rdé_,
  { {0x8c3d0529,0xbb830032,0x89d8007e,0x00000000}},	//   reşt, _الوي, _لوتر_,
  { {0x8c3d000c,0x8ca10161,0x7e5707e9,0x00000000}},	//   seşt, क्वो, רסלב_,
  { {0xdb1900bd,0xa99b0063,0x628a0e7c,0x00000000}},	//   _erwä, _נבחר, ófon,
  { {0x63b6001f,0x290b0aca,0xa3d40121,0x00000000}},	// [94f0] gwyn, mica_, ботч,
  { {0x290b4dca,0x7d0925dd,0x3ebe00cf,0x00000000}},	//   lica_, zies, _natt_,
  { {0x3860007a,0x611c4dcb,0x90554dcc,0x00000000}},	//   _yfir_, zčle, авец,
  { {0x290b4dcd,0x7cf51584,0x63b6002b,0x00000000}},	//   nica_, _márc, bwyn,
  { {0xdb090026,0x248e0080,0x7d094dce,0x00000000}},	//   kveð, íjmů_, vies,
  { {0x290b4dcf,0x7d094dd0,0xddc30a1e,0x00000000}},	//   hica_, wies, ranž,
  { {0x3ebe0fd7,0x7d094dd1,0x6e92005e,0x00000000}},	//   _datt_, ties, цију,
  { {0xdcf8008f,0x290b4dd2,0x9987004c,0x00000000}},	//   duvē, jica_, _synů_,
  { {0x7d094dd3,0x290b0aca,0x3ced1d14,0x00000000}},	//   ries, dica_, rkev_,
  { {0x7d094dd4,0x6eef00b9,0x3ced00c2,0x00000000}},	//   sies, _købm, skev_,
  { {0x290b4dd5,0x7cf542d4,0x186a026b,0x00000000}},	//   fica_, _cárc, кани_,
  { {0x61fa0004,0x290b0419,0x7cf5004c,0x00000000}},	//   _ütle, gica_, _dárc,
  { {0x69dc05dd,0x07a60095,0x8836000d,0x00000000}},	//   ører, јагн, рэнц,
  { {0xe73a3a12,0xaa451224,0x684a0078,0x00000000}},	//   тег_, _келл, jūdž,
  { {0x7ae30027,0x649a0088,0xd62a4dd6,0x00000000}},	//   _iont, ктар_, тове_,
  { {0x7ae34dd7,0x44664dd8,0xb4660a2f,0x00000000}},	//   _hont, рвав, ркал,
  { {0xdbd9017d,0xe29a00d7,0x42560189,0x00000000}},	// [9500] _açúc, каа_, атет,
  { {0x577b00b5,0x8ccc0053,0x68e40ff2,0x00000000}},	//   _שטיצ, _दोनो, _hoid,
  { {0x68e4004b,0x7ae34d6e,0x98da0042,0x00000000}},	//   _koid, _mont, _बचाए,
  { {0x68e4024a,0x3ebe3a97,0x7ae34dd9,0x00000000}},	//   _joid, _satt_, _lont,
  { {0x684a0006,0x3ebe34ab,0xb608004c,0x00000000}},	//   būdž, _patt_, boší,
  { {0x68f6001f,0x7ae32322,0x290b4dda,0x00000000}},	//   _llyd, _nont, zica_,
  { {0x8d63005e,0x629c01db,0x80c10053,0x00000000}},	//   овје, _icro, _रोके,
  { {0x7ae30027,0x3ea00080,0xbd43006a,0x00000000}},	//   _aont, řit_, ينوي,
  { {0x3ebe0031,0x2eb60d82,0x290b1bdb,0x00000000}},	//   _tatt_, _всес, vica_,
  { {0x60c200eb,0x6f0d0003,0x8f9b0063,0x00000000}},	//   ldom, éact, _בימי,
  { {0x60c20006,0x290b06d5,0xe873005d,0x00000000}},	//   odom, tica_, يندگ,
  { {0x60c0021f,0x2fc6007d,0x8d74007e,0x00000000}},	//   _jamm, ovog_, _ناچا,
  { {0x4bd7007e,0x68e4017d,0x290b1eb4,0x00000000}},	//   _نبود_, _doid, rica_,
  { {0x290b1bb7,0xbb430141,0x27e40137,0x00000000}},	//   sica_, _дечк, ämna_,
  { {0xbbb60161,0x94d50086,0x68f62883,0x00000000}},	//   _अनुक, бовц, _flyd,
  { {0x2fc6017f,0x629c4ddb,0x98750962,0x00000000}},	//   kvog_, _acro, _улиц,
  { {0x60c24ddc,0x7cf5013d,0x56950899,0x00000000}},	// [9510] ddom, _jára, _лапт,
  { {0x6131000e,0x326702fe,0xe2930021,0x00000000}},	//   måli, ртав, تذر_,
  { {0xb4db0268,0x60550021,0xc348005a,0x00000000}},	//   _diàr, مناط, ряте_,
  { {0x6b82017f,0x60c04ddd,0x60c2314f,0x00000000}},	//   _ovog, _camm, gdom,
  { {0x60c04dde,0xf8bf2986,0x7cf501d9,0x00000000}},	//   _damm, llés_, _nára,
  { {0xaf040086,0x26c10089,0x629c0139,0x00000000}},	//   опіл, _jaho_, _gcro,
  { {0x613802f4,0x645a000c,0x290900fe,0x00000000}},	//   síla, _ştii, _omaa_,
  { {0xa6180063,0x7ae34ddf,0xeb990f34,0x00000000}},	//   יקוד_, _sont, гии_,
  { {0x69ca0185,0x6f0d0139,0x68e40003,0x00000000}},	//   _arfe, éacs, _roid,
  { {0x6b820b59,0x03580041,0x7afa059f,0x00000000}},	//   _dvog, ביזש_, ghtt,
  { {0x7ae30c40,0x68e44de0,0x69dc04aa,0x00000000}},	//   _vont, _poid, ørep,
  { {0xa2c90053,0x7cf5013d,0x98a00078,0x00000000}},	//   _होस्, _fára, _okią_,
  { {0x68e4024a,0x26c100a4,0x7ae31606,0x00000000}},	//   _void, _baho_, _tont,
  { {0x7afa102c,0x96630062,0x60c24de1,0x00000000}},	//   chtt, зкре, zdom,
  { {0xf8bf048e,0x68e40004,0xb9950021,0x00000000}},	//   glés_, _toid, _العب,
  { {0x62870d11,0xa9050021,0x629c03a3,0x00000000}},	//   _adjo, _وبين, _scro,
  { {0xb8fc016a,0x7cfc00ea,0xb8de0053,0x00000000}},	// [9520] ठा_, _férf, ुए_,
  { {0x60c01781,0xf8bf0003,0x61fe004d,0x00000000}},	//   _samm, blés_, tzpl,
  { {0x60c2102b,0x106a0121,0x7981002b,0x00000000}},	//   tdom, гией_, nslw,
  { {0x69dc0072,0x7bcb4de2,0x2fc6007d,0x00000000}},	//   ärei, _orgu, tvog_,
  { {0x4424001b,0x7bcd0006,0x60c20246,0x00000000}},	//   _âm_, _šaun, rdom,
  { {0x2fc6007d,0x60c23c73,0x63a44de3,0x00000000}},	//   rvog_, sdom, mtin,
  { {0xdbf10080,0xa3c20161,0x6b824de4,0x00000000}},	//   _dřív, ्मक_, _svog,
  { {0xd217014e,0x915e008b,0xa3bc0053,0x00000000}},	//   _הקלק_, _gắn_, _आना_,
  { {0x9b580002,0x63a43040,0xf8bf3887,0x00000000}},	//   јиот_, ntin, klér_,
  { {0x13bb0047,0x7cf500ea,0x290900b9,0x00000000}},	//   נזיע, _vára, _smaa_,
  { {0x395800e8,0x7bcb4de5,0x58d9000d,0x00000000}},	//   êrs_, _ergu, адня_,
  { {0x7cfc007a,0x63a44de6,0xc8640062,0x00000000}},	//   _sérf, ktin, зтри,
  { {0x6d5a14eb,0x63a44de7,0x7bcb0130,0x00000000}},	//   _huta, jtin, _grgu,
  { {0x6d5a10ca,0x613106a5,0x63a4004b,0x00000000}},	//   _kuta, råli, dtin,
  { {0x26c30150,0x6d5a2fb3,0xf8bf0003,0x00000000}},	//   rdjo_, _juta, ulés_,
  { {0xa4f1005b,0xf8bf00ea,0x7cf50139,0x00000000}},	//   _dışı_, rlés_, _lárn,
  { {0x63a44de8,0x28d60161,0x6d5a4de9,0x00000000}},	// [9530] gtin, धारि, _luta,
  { {0x7cf5017d,0x6d5a4dea,0x3ce6004b,0x00000000}},	//   _nárn, _outa, _loov_,
  { {0x7cfc000f,0x63a44deb,0x6d5a4dec,0x00000000}},	//   _kérd, atin, _nuta,
  { {0x999b0047,0xa99b0041,0xd011013a,0x00000000}},	//   רבאט, רבאר, ولا_,
  { {0x63a428f0,0x29194ded,0x6d5a4dee,0x00000000}},	//   ctin, insa_, _auta,
  { {0x3983005b,0x628700ea,0x6d5a4def,0x00000000}},	//   yıs_, _udjo, _buta,
  { {0x7bc7003d,0x78ad24a3,0x3f760051,0x00000000}},	//   ājum, _obav, ału_,
  { {0x29190003,0x55780047,0x2ee52e38,0x00000000}},	//   éral_, זעהן_, _wolf_,
  { {0x6d5a4df0,0x69c804aa,0x7c84005e,0x00000000}},	//   _euta, evde, чује,
  { {0x29194df1,0xf98501a4,0x89a911c7,0x00000000}},	//   ensa_, огоо, аков_,
  { {0xd94605d2,0x7afd008f,0xdc3c008f,0x00000000}},	//   жени, ūsto, ršāk,
  { {0x63a4007a,0x7cf5013d,0x39830058,0x00000000}},	//   ytin, _zárn, rıs_,
  { {0xa8030088,0xe73a139e,0x386d006d,0x00000000}},	//   дзял, ием_, ñera_,
  { {0x78ad004b,0x7cf5013d,0x29194df2,0x00000000}},	//   _ebav, _káro, ansa_,
  { {0x394003e9,0x691600c3,0x954a0021,0x00000000}},	//   _this_, jšeg, لشرق_,
  { {0x63a40d11,0x68fd087d,0x8afd004c,0x00000000}},	//   ttin, chsd, dpři,
  { {0x03a300d7,0x130a000d,0x23690021,0x00000000}},	// [9540] мито, анай_, محلي_,
  { {0x29f5008b,0x78ad01c2,0x63a44df3,0x00000000}},	//   óa_, _zbav, rtin,
  { {0x02190088,0x7cf5108f,0x645a003b,0x00000000}},	//   біць_, _náro, _ştiu,
  { {0x7cfc000f,0x6d5a4df4,0x2fcd00c2,0x00000000}},	//   _kére, _ruta, _breg_,
  { {0x691600c3,0x6d5a4df5,0x7cf50066,0x00000000}},	//   ašeg, _suta, _párn,
  { {0x24800027,0x7cfc00ea,0x3ce60019,0x00000000}},	//   laim_, _mére, _soov_,
  { {0xccfa0001,0x3f760051,0x7cf5013d,0x00000000}},	//   ићи_, słu_, _várn,
  { {0x24800025,0x9cca000d,0x6d5c0516,0x00000000}},	//   naim_, рыка_, _éram,
  { {0x6d5a004d,0xd01201fb,0x2fcd1014,0x00000000}},	//   _wuta, _غلط_, _greg_,
  { {0x3f800006,0x6d5a4df6,0x79a613a2,0x00000000}},	//   šius_, _tuta, орме,
  { {0xed5a0088,0x7cfc06b2,0xdca60635,0x00000000}},	//   _тое_, _pérd, _мажи,
  { {0x248000ea,0x29194df7,0x69c800a5,0x00000000}},	//   jaim_, unsa_, rvde,
  { {0x7cfc017d,0x7cf52d5d,0x613101e1,0x00000000}},	//   _cére, _záro, målt,
  { {0xc87f004d,0xdcf80078,0x7536013d,0x00000000}},	//   saß_, tuvė, elyz,
  { {0x6d4200aa,0xa4d5019d,0x7cfc013d,0x00000000}},	//   _khoa, пові, _térd,
  { {0x69dc00fe,0x24580376,0x290f0137,0x00000000}},	//   äreu, жать_, _öga_,
  { {0x7cfc0164,0x2bcd0053,0xd25b0dc8,0x00000000}},	// [9550] _gére, ़िया, аце_,
  { {0x026b000d,0xa2db0042,0x28ac0042,0x00000000}},	//   ршай_, नाध्, ट्ठि,
  { {0x116a006a,0x51840785,0x76ba009a,0x00000000}},	//   مللی_, дуча, _המתפ,
  { {0x915e008b,0x2fcd00d1,0x00000000,0x00000000}},	//   _sẵn_, _preg_,   ,
  { {0x9f350086,0x7cf5009c,0xa2db0082,0x00000000}},	//   педі, _sáro, नाद्,
  { {0x63b90058,0xed590541,0xc105005d,0x00000000}},	//   ğanı, бок_, _کوري,
  { {0x40870002,0xad58026c,0x63b90058,0x00000000}},	//   _муаб, орых_, şanı,
  { {0x7cf5000f,0x2fcd00d1,0x20d70021,0x00000000}},	//   _váro, _treg_, _بتسج,
  { {0x3ec4024a,0x2d9800c7,0x7bc4005f,0x00000000}},	//   östä_, _åren_, _šiur,
  { {0x7bc903b2,0x4fc4000d,0x7cf500ea,0x00000000}},	//   rveu, _ўста, _táro,
  { {0xdcf70021,0x7cfc013d,0x7c220cd2,0x00000000}},	//   _وأصب, _sére, _exor,
  { {0x7cfc3141,0x613102c0,0xecbb0044,0x00000000}},	//   _pére, måls, _خططت_,
  { {0x7cf5013d,0x6d494df8,0x7af6013d,0x00000000}},	//   _járm, mmea, ágtó,
  { {0xb8f30394,0xf6d50086,0x7cf50460,0x00000000}},	//   _हो_, міся, _márm,
  { {0x7d1b005b,0x248000ea,0x6d4900be,0x00000000}},	//   onus, taim_, omea,
  { {0x04570032,0x7d1b037e,0x6d490139,0x00000000}},	//   كلفة_, nnus, nmea,
  { {0x7d1b4df9,0x7cfc05ab,0x24804dfa,0x00000000}},	// [9560] inus, _hérc, raim_,
  { {0x662700ea,0x6d490aee,0x24804dfb,0x00000000}},	//   érké, hmea, saim_,
  { {0xc2190086,0xa9250066,0x41aa0cb2,0x00000000}},	//   оєї_, spľň, свен_,
  { {0x7cf5000f,0x00e60076,0x27e60022,0x00000000}},	//   _bárm, яжен, _żony_,
  { {0x6d49004b,0x9f980054,0xd0590054,0x00000000}},	//   dmea, івку_, ірці_,
  { {0x7d1b0019,0x083b0047,0x6e940d34,0x00000000}},	//   enus, זענל, фику,
  { {0x43434dfc,0x1ea900f2,0xdd8f030b,0x00000000}},	//   _черв, تاني_, эш_,
  { {0x7cf50e7c,0x7d1b4dfd,0x5095005e,0x00000000}},	//   _fárm, gnus, _оруђ,
  { {0x395c4dfe,0x672e21ef,0xdd90005d,0x00000000}},	//   _suvs_, kobj, روک_,
  { {0xfee90021,0xb4db0013,0x7d1b486d,0x00000000}},	//   _وعلى_, _nhàn, anus,
  { {0x672e0198,0x61310831,0x6d42001b,0x00000000}},	//   dobj, målr, _thoa,
  { {0xeb9a0330,0xd7fe008d,0x02170063,0x00000000}},	//   _гид_, đăng_, לחים_,
  { {0x2c08007e,0x3f86017d,0x57f4047e,0x00000000}},	//   _بعضی_, nsou_, епят,
  { {0xddc80006,0x3f86017d,0xb4db0013,0x00000000}},	//   _medž, isou_, _chàn,
  { {0xa2db0042,0xa5f84dff,0x45d42763,0x00000000}},	//   नास्, перу_, норс,
  { {0xa99b014e,0x645a0529,0x2eb90161,0x00000000}},	//   _הבהר, _ştir, _इस्त,
  { {0x3f860080,0x69c50026,0x98a40001,0x00000000}},	// [9570] jsou_, _áher, _чиње,
  { {0xd7fc0063,0x7bcd0006,0x6aba4e00,0x00000000}},	//   _להחל, _šauk, netf,
  { {0xf1c2008f,0xc6920063,0x4aae0042,0x00000000}},	//   jušā_, _באי_, ज्यव,
  { {0x7aea0b9c,0x613104aa,0xdce3008f,0x00000000}},	//   _loft, våls, rsnī,
  { {0x926b005e,0x8fa506da,0x611c00a8,0x00000000}},	//   _грба_, фале, očlj,
  { {0x2d510080,0xe8da0053,0x3ea11548,0x00000000}},	//   _všem_, _बच्च, üht_,
  { {0xb0f60026,0xdd1f0066,0x38690014,0x00000000}},	//   þýða, rížs, _ofar_,
  { {0xed56011c,0x7cf500ea,0xd5fc009a,0x00000000}},	//   мощ_, _zárj, מפור,
  { {0x7cf50066,0x6d494e01,0x3f86006c,0x00000000}},	//   _hárk, rmea, csou_,
  { {0x799a0009,0xcda90021,0x31790047,0x00000000}},	//   futw, _وهذه_, ֿאָד,
  { {0xf8f90013,0x7aea1ae6,0x260d0042,0x00000000}},	//   ượt_, _doft, _डेली_,
  { {0xc6890ee1,0x7cf500ea,0xd9460002,0x00000000}},	//   _כא_, _márk, ќеми,
  { {0x99d5007e,0xe9db007e,0x69dc01bb,0x00000000}},	//   ستگا, _گذشت_, ärer,
  { {0x2cad0ac9,0x2d8744cc,0xa3c10042,0x00000000}},	//   lfed_, osne_, ंबन_,
  { {0x672e4e02,0xe7372046,0x7cfc4e03,0x00000000}},	//   robj, фер_, _héra,
  { {0x6eef00b9,0x6926000d,0x7cfc0003,0x00000000}},	//   _købs, _імпа, _kéra,
  { {0xb4db00aa,0xb4be0053,0x6138004c,0x00000000}},	// [9580] _thàn, _इसी_, sílk,
  { {0x613813a3,0x7cf500ea,0x2d874e04,0x00000000}},	//   míli, _bárk, ksne_,
  { {0xb97a00b5,0x7cf500ea,0x0219000d,0x00000000}},	//   ַנסי, _várj, піць_,
  { {0xdfda0062,0x7cf5004c,0x31be004c,0x00000000}},	//   жък_, _dárk, _vůz_,
  { {0x6ef400cd,0xddd8007d,0x2cad002b,0x00000000}},	//   _hàbi, davš, dfed_,
  { {0x3f86017d,0x69c300c2,0xbd6a0854,0x00000000}},	//   rsou_, _osne, орие_,
  { {0x3f860f01,0x2cad00e5,0x7cfc0003,0x00000000}},	//   ssou_, ffed_, _aéra,
  { {0x6721082a,0x799a0035,0xb4fb0047,0x00000000}},	//   člji, vutw, ַליר,
  { {0x6b9b00a4,0x7aea003b,0x7cfc1a05,0x00000000}},	//   guug, _poft, _céra,
  { {0x7cfc0003,0x290200a8,0xbb4714d7,0x00000000}},	//   _déra, ehka_, ولين_,
  { {0xdee30062,0xd915026c,0x611c00a8,0x00000000}},	//   _шофи, едны, včlj,
  { {0x61e300c7,0x61384e05,0xf7950085,0x00000000}},	//   änli, fíli, намэ,
  { {0xacf70086,0x7cfc4e06,0x2d9c0066,0x00000000}},	//   _іншу_, _géra, luve_,
  { {0x2d9c017d,0xaff90047,0x3eae004d,0x00000000}},	//   ouve_, פּרי, nfft_,
  { {0x3eae001f,0x163403d6,0x7cf500ea,0x00000000}},	//   ifft_, веря, _bárh,
  { {0x628e001f,0x3ea9007d,0x613800be,0x00000000}},	//   _adbo, đati_, bíli,
  { {0x43740086,0xa87c0063,0x61384e07,0x00000000}},	// [9590] вуєт, _ואחר, cíli,
  { {0x98a222b4,0xddd80130,0x78bd4e08,0x00000000}},	//   roką_, zavš, lesv,
  { {0x2cad002b,0x98a20022,0x50b536ed,0x00000000}},	//   yfed_, soką_, еслу,
  { {0x659a0041,0x78bd4e09,0x1dc20042,0x00000000}},	//   _צירק, nesv, _वैधत,
  { {0x7afd001c,0x3f890003,0xdfa40044,0x00000000}},	//   ūsti, éau_, نحوي,
  { {0x68ed4e0a,0x7bdf03ea,0x2cad002b,0x00000000}},	//   _load, _àqui, wfed_,
  { {0x6285210b,0xddd8007d,0x7cfc4e0b,0x00000000}},	//   maho, tavš, _séra,
  { {0xd658014e,0x62854e0c,0x44393c0e,0x00000000}},	//   ויות_, laho, _kys_,
  { {0x6138017d,0x443900ac,0x40340121,0x00000000}},	//   xíli, _jys_, _аетс,
  { {0x628500bb,0x78a40290,0x7cf54e0d,0x00000000}},	//   naho, _sciv, _mári,
  { {0x44394e0e,0x7cf50025,0x68ed1795,0x00000000}},	//   _lys_, _lári, _boad,
  { {0xb4be0053,0x60c9004b,0x7cfc0014,0x00000000}},	//   _इसे_, _jaem, _hérn,
  { {0xb8e80161,0x68ed017d,0x6d5900a4,0x00000000}},	//   _उस_, _doad, _iiwa,
  { {0x6d59002c,0x645d00a4,0x29024e0f,0x00000000}},	//   _hiwa, _agsi, shka_,
  { {0x6d590009,0x61384e10,0x7cf500ea,0x00000000}},	//   _kiwa, síli, _párh,
  { {0x045a0021,0x6b890ad5,0x6d59017e,0x00000000}},	//   سلطة_, oseg, _jiwa,
  { {0x442603d9,0x2bd20053,0x6b894e11,0x00000000}},	// [95a0] ço_, तिया, nseg,
  { {0x60db4e12,0x6d590380,0xacd90013,0x00000000}},	//   _anum, _liwa, _đươị,
  { {0x29000089,0xd335000d,0xdb00013d,0x00000000}},	//   _klia_, тэты, ntmá,
  { {0xdfa60002,0x6b894e13,0x4439002b,0x00000000}},	//   ејко, kseg, _fys_,
  { {0x08770047,0x628500a4,0x60c94e14,0x00000000}},	//   גענט_, baho, _daem,
  { {0x8f75019d,0x2d9c4e15,0x040b0013,0x00000000}},	//   туці, tuve_, _lưỡn,
  { {0x6da3018e,0x6b893492,0x7ec8008f,0x00000000}},	//   гија, eseg, _rūpē,
  { {0xed570138,0x6b460046,0xf8ca0042,0x00000000}},	//   ној_, iðge, ियोप,
  { {0x68ed4e16,0x6d5916b0,0x4f26000d,0x00000000}},	//   _road, _diwa, _здаб,
  { {0x8aa60caa,0x3dc90022,0x29003112,0x00000000}},	//   хрид, ława_, _alia_,
  { {0x1317014e,0xdb23013d,0x78bd4e17,0x00000000}},	//   תחיל_, óság, tesv,
  { {0x6285366a,0x040b0013,0x6b8901a8,0x00000000}},	//   zaho, _cưỡn, bseg,
  { {0x7cfc00e9,0xa8a4000d,0x69c1316f,0x00000000}},	//   _héro, ырэк, awle,
  { {0x78bd00ac,0x290001f4,0x7bdb0063,0x00000000}},	//   sesv, _elia_, _מקדו,
  { {0x6d590035,0x752100ea,0x27360026,0x00000000}},	//   _yiwa, élzo, vænt_,
  { {0x6285001f,0x7cf500ea,0x7cfc1090,0x00000000}},	//   waho, _pári, _méro,
  { {0x62850080,0x54550189,0x6924007d,0x00000000}},	// [95b0] taho, тват, ođen,
  { {0x7cf503d9,0x2d8c017f,0x51870074,0x00000000}},	//   _vári, _ovde_, еуда,
  { {0x39490c64,0x4439021f,0x7cfc0003,0x00000000}},	//   _khas_, _wys_, _néro,
  { {0x6285027d,0x4439232d,0x628a013d,0x00000000}},	//   saho, _tys_, ófor,
  { {0x7cfc0164,0x6d590397,0x443900ac,0x00000000}},	//   _aéro, _riwa, _uys_,
  { {0x9f400026,0xc6950047,0xa3c00053,0x00000000}},	//   áið_, דאַ_, ूटर_,
  { {0xa9280024,0x63ad4e18,0x6da20062,0x00000000}},	//   nažé, ltan, аища,
  { {0x925833e7,0x7cfc0164,0x60db004d,0x00000000}},	//   _част_, _déro, _unum,
  { {0x6d590035,0x2d8c0058,0x63ad4e19,0x00000000}},	//   _viwa, _evde_, ntan,
  { {0xa3d20053,0xe6cb0053,0x7cfc24a4,0x00000000}},	//   वित_, ायोज, _féro,
  { {0x6d594857,0x7cfc01ca,0x6b894e1a,0x00000000}},	//   _tiwa, _kérl, sseg,
  { {0x6b8901cd,0x691600a8,0xdb000195,0x00000000}},	//   pseg, ašen, rtmá,
  { {0x63ad4e1b,0x7bc7008f,0x7cfc01e0,0x00000000}},	//   jtan, ājus, _mérl,
  { {0xf8c700ea,0x7c240078,0x24820078,0x00000000}},	//   áért_, _žirg, _sekm_,
  { {0x63ad0aa8,0xdcf8004c,0x7a88009d,0x00000000}},	//   etan, jsvě, _נָסַ,
  { {0x2cbf0185,0xe5230002,0x2919006c,0x00000000}},	//   neud_, адсп, érat_,
  { {0xa3d20235,0x63ad4e1c,0x6f010139,0x00000000}},	// [95c0] विध_, gtan, _ollc,
  { {0x273601e1,0x13034e1d,0xb87b004c,0x00000000}},	//   ræns_, азум, ejíh,
  { {0x4256000a,0x63ad0bbf,0x3f8d0003,0x00000000}},	//   ттат, atan, _aveu_,
  { {0xa3d20053,0xc4830330,0x25d7009a,0x00000000}},	//   विद_, _клюк, _סוכן_,
  { {0x10a328ff,0x63ad0da1,0x7cfc12a2,0x00000000}},	//   ричн, ctan, _séro,
  { {0xcdda0001,0x776400cd,0xf8bf0003,0x00000000}},	//   дњи_, _muix, mnée_,
  { {0xe2970079,0x78b6004a,0xc6930063,0x00000000}},	//   _јас_, _obyv, באו_,
  { {0x7cfc1a05,0x5f960021,0x6138013d,0x00000000}},	//   _véro, _للرئ, tílu,
  { {0x9eaa0079,0xfd0f006a,0xf8bf0164,0x00000000}},	//   _оваа_, تجو_, nnée_,
  { {0x38601db1,0x6916004c,0x8c43007b,0x00000000}},	//   _agir_, ušen, шење,
  { {0x29fc001b,0x6924017f,0x39490139,0x00000000}},	//   ủa_, rđen, _phas_,
  { {0x63ad4e1e,0xd90f007e,0x6f180a1e,0x00000000}},	//   ytan, تیب_, livc,
  { {0x63ad4e1f,0x776400cd,0x69161ee9,0x00000000}},	//   xtan, _cuix, pšen,
  { {0x8c43184a,0xdcf8004c,0xd7f82125,0x00000000}},	//   _тече, ysvě, тую_,
  { {0xf8bf00ea,0x29190003,0x6d5c0153,0x00000000}},	//   tnéd_, éras_, _éras,
  { {0x6924017f,0x63ad4e20,0x5a550062,0x00000000}},	//   nđel, ttan, _съчу,
  { {0xf8bf0164,0x63ad4e21,0x67d50121,0x00000000}},	// [95d0] gnée_, utan, _сопу,
  { {0x7d024be2,0x6f1800b2,0x7cfc0014,0x00000000}},	//   _llos, jivc, _sérl,
  { {0xe2980086,0x2919017d,0xc1a40699,0x00000000}},	//   тає_, oisa_, ијци,
  { {0x29194e22,0x7cf5013d,0x67350022,0x00000000}},	//   nisa_, _járt, lozj,
  { {0x7cf54e23,0x2919004e,0x799a0244,0x00000000}},	//   _márt, iisa_, hrtw,
  { {0x2cbf001f,0x24894e24,0xe8d90013,0x00000000}},	//   weud_, laam_, _biị_,
  { {0x29194e25,0x62190047,0x609b0021,0x00000000}},	//   kisa_, _װוּק, _يخرج_,
  { {0x7d020034,0x248903a8,0x68fd006f,0x00000000}},	//   _clos, naam_, jksd,
  { {0x7cfc000f,0x69dc0e5a,0x29194e26,0x00000000}},	//   _kérj, åren, disa_,
  { {0x7d02193c,0x3f890078,0x776401a8,0x00000000}},	//   _elos, šaus_, _ruix,
  { {0x291905b3,0x20100078,0x7d024e27,0x00000000}},	//   fisa_, ėlių_, _flos,
  { {0xc19a0047,0x291924c3,0x776400cd,0x00000000}},	//   עשרי, gisa_, _puix,
  { {0x77642520,0xfd560041,0xe8f722f5,0x00000000}},	//   _quix, _עשני_, уля_,
  { {0x8c1a00ff,0x7d024e28,0xa3d20042,0x00000000}},	//   _אוני, _zlos, विस_,
  { {0x29194e29,0xd6270da9,0x64460022,0x00000000}},	//   bisa_, горе_, _szki,
  { {0x29194e2a,0x248900ac,0x7cf5013d,0x00000000}},	//   cisa_, gaam_, _táru,
  { {0xe3ba0088,0x61380066,0x154306da,0x00000000}},	// [95e0] эба_, zíls, сетм,
  { {0xf8bf3de3,0x36c60062,0x7cf5013d,0x00000000}},	//   rnée_, _сбог, _zárt,
  { {0x6916004c,0x25ba4e2b,0x6b9b00a3,0x00000000}},	//   yšel, _uppl_, hrug,
  { {0x459b00b5,0x104a0071,0x6b9b007d,0x00000000}},	//   _אױטא, няли_, krug,
  { {0xd12f0032,0x75244e2c,0xb4c00053,0x00000000}},	//   أمن_, mniz, ंजी_,
  { {0xa3c10053,0x29194e2d,0x7d0204aa,0x00000000}},	//   ंबर_, zisa_, _slos,
  { {0x6b9b4e2e,0x7d024e2f,0x3ce00042,0x00000000}},	//   erug, _plos, काले_,
  { {0x7cfc1e1a,0x75244970,0x7cd80239,0x00000000}},	//   _térm, nniz, тмир_,
  { {0x7bcd001c,0x29194e30,0x9f510114,0x00000000}},	//   _šaur, visa_, žbám_,
  { {0x24890122,0xba0a0062,0x0ac601d5,0x00000000}},	//   zaam_, ехме_, ущим,
  { {0x6ef400cd,0x7cf500ea,0x69164e31,0x00000000}},	//   _fàbr, _párt, pšel,
  { {0x6b9b3331,0x7d0200fe,0x7cfc00ea,0x00000000}},	//   brug, _ulos, _mérk,
  { {0x68fd4e32,0x2fc6002b,0x29194e33,0x00000000}},	//   rksd, nwog_, risa_,
  { {0x29190da5,0x6d401aaf,0x75240075,0x00000000}},	//   sisa_, llma, eniz,
  { {0x2919027c,0xdb000019,0x60c227e8,0x00000000}},	//   pisa_, rtmä, keom,
  { {0x75242b71,0xe4750002,0x95640062,0x00000000}},	//   gniz, рлањ, сърд,
  { {0x6d400d68,0x24891c42,0xe315005e,0x00000000}},	// [95f0] ilma, raam_, амањ,
  { {0x722b0b3f,0x0bb50047,0xd347007e,0x00000000}},	//   нцев_, יִער_, ایسه_,
  { {0x5215000a,0x26c300c2,0xf770005d,0x00000000}},	//   јдет, mejo_, _وای_,
  { {0x26c31143,0xe5c40086,0x897b0041,0x00000000}},	//   lejo_, _усьо, גראצ,
  { {0x7cfc00ea,0x8e854e34,0xafe501d5,0x00000000}},	//   _térj, агле, ролл,
  { {0x26c34e35,0xa3d20053,0x539a0063,0x00000000}},	//   nejo_, विर_, _בישו,
  { {0xf4ba0026,0x7cfc00ea,0x26c30331,0x00000000}},	//   _þýða_, _kérh, iejo_,
  { {0xcdcf005e,0x691600a8,0x6b9b275a,0x00000000}},	//   тњa_, ašej, trug,
  { {0x69d80004,0x628700e3,0x60c40019,0x00000000}},	//   _arve, _kejo, õime,
  { {0x26c30198,0xdb0000cd,0x8d870b3f,0x00000000}},	//   jejo_, numè, _будд,
  { {0x6287048e,0x69d8017f,0x26c300c3,0x00000000}},	//   _mejo, _crve, dejo_,
  { {0x69de034d,0x62870fbb,0x69d8017f,0x00000000}},	//   _špec, _lejo, _drve,
  { {0x629500c2,0x69ca06d5,0xf7462b4f,0x00000000}},	//   _odzo, _esfe, иемо,
  { {0x7cf5000f,0x3ced08ea,0x0c240054,0x00000000}},	//   _társ, ljev_, _умін,
  { {0x2d9831c8,0xa5160002,0xba390041,0x00000000}},	//   _året_, аќај, _בײַט,
  { {0x8883005a,0xb4c0016a,0xc1780078,0x00000000}},	//   _длъж, ंजे_, _įė_,
  { {0x75244e36,0x6b950047,0x53a606b4,0x00000000}},	// [9600] rniz, יכּף_, разб,
  { {0xa25a0021,0x7d1b37c7,0x7cf54e37,0x00000000}},	//   نشاء_, hius, _márq,
  { {0x7d1b4e38,0xa2a70053,0x7cfc00ea,0x00000000}},	//   kius, _चार्, _férh,
  { {0x61430121,0x19b60041,0x42553279,0x00000000}},	//   оеха, יפער_, стут,
  { {0x7d090009,0x43754e39,0x394200a4,0x00000000}},	//   dhes, _густ, ilks_,
  { {0x9ea70138,0x98ab0045,0xe29a0076,0x00000000}},	//   авља_, mocą_, _шаг_,
  { {0x7cfc0164,0xb23a0021,0x63a44e3a,0x00000000}},	//   _héri, _شكرا_, luin,
  { {0x92a60045,0x7d09055b,0x7d1b2acf,0x00000000}},	//   _wyłą, ghes, gius,
  { {0x7cf5006d,0x63a44e3b,0x4ae6000d,0x00000000}},	//   _párr, nuin, аўна,
  { {0x2d9c0080,0x7cfc249d,0x69d80d58,0x00000000}},	//   prve_, _méri, _prve,
  { {0xf2d900b5,0x6ce6000d,0x26c34e3c,0x00000000}},	//   אַרל, _віле, vejo_,
  { {0x5dfb0047,0x63a44e3d,0x7d0926ce,0x00000000}},	//   _שפאנ, kuin, ches,
  { {0x31570047,0xe6671137,0x8c432800,0x00000000}},	//   ייטן_, итво, _деце,
  { {0x63a44e3e,0x7cfc0026,0x89d8005d,0x00000000}},	//   duin, _sérh, _موتر_,
  { {0x26d10045,0x7cfc0164,0x69dc00b9,0x00000000}},	//   rdzo_, _aéri, æred,
  { {0x3f8f001f,0x26c34e3f,0x63a40264,0x00000000}},	//   ysgu_, sejo_, fuin,
  { {0x63a44e40,0x26c34e41,0xf267005e,0x00000000}},	// [9610] guin, pejo_, ађем,
  { {0x6e2d01f7,0x7cfc0164,0x883c0063,0x00000000}},	//   şabi, _déri, _בתחו,
  { {0x75d503eb,0xd25b007f,0x7cfc013d,0x00000000}},	//   _ايجا, тца_, _térh,
  { {0x7cfc22e5,0x63a4306c,0xa069005e,0x00000000}},	//   _féri, buin, ћала_,
  { {0x63a4003b,0x7f190454,0x7cfc006c,0x00000000}},	//   cuin, ліку_, _géri,
  { {0x69160080,0x60080500,0x4177005d,0x00000000}},	//   ašeh, шнім_, _نارس,
  { {0x92940259,0x3ced007d,0x3cff004b,0x00000000}},	//   _фасц, tjev_, tkuv_,
  { {0x7d0900a4,0x518433c4,0x5ba90200,0x00000000}},	//   uhes, _фура, гким_,
  { {0x3ced0198,0x7d1b4e42,0x3ec70054,0x00000000}},	//   rjev_, rius, _всеб,
  { {0xfaa50259,0x5f450021,0x6a940054,0x00000000}},	//   љано, _انطل, орює,
  { {0x5dd50021,0x7d0916c3,0x63a438fd,0x00000000}},	//   _دقائ, phes, zuin,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xdb0b00b9,0xeb990499,0x2d9804aa,0x00000000}},	//   _opgø, _сил_, _årer_,
  { {0xa3c10235,0xda7b0376,0x63a44e43,0x00000000}},	//   ंबई_, _ряд_, vuin,
  { {0x7ae3076c,0x7cfc4e44,0x7afc4e45,0x00000000}},	//   _innt, _séri, örte,
  { {0x7cfc03b2,0x6efd0268,0x99360021,0x00000000}},	//   _péri, _dèbi, _دفعت,
  { {0x044a4e46,0x21260130,0xc953009a,0x00000000}},	// [9620] упак_, vnoh_, _צמח_,
  { {0x7cfc03b2,0x7c2e00bd,0x63a44e47,0x00000000}},	//   _véri, ßbri, ruin,
  { {0x68f6005b,0x29020072,0xa75b0063,0x00000000}},	//   _koyd, okka_, _תדיר,
  { {0x94790054,0x290201cf,0xd1390085,0x00000000}},	//   _всру_, nkka_, ахі_,
  { {0x29020659,0x1fb60b3f,0x63a40b16,0x00000000}},	//   ikka_, ссер, quin,
  { {0xb0330086,0x7bc9002b,0x5f930141,0x00000000}},	//   чніш, dweu, чишт,
  { {0x21750062,0x93c3003b,0x7cf50331,0x00000000}},	//   _мутр, ţătu, _párp,
  { {0xbb7402a9,0xd1970063,0x644b4e48,0x00000000}},	//   огиј, _לכלי_, ügig,
  { {0x30060086,0xcb670092,0xc4d30063,0x00000000}},	//   _узаг, бање_, לגה_,
  { {0x78ad0b27,0x68e44e49,0x539b0041,0x00000000}},	//   _scav, _anid, װיטו,
  { {0xdd92007e,0x4427008b,0x69cf0051,0x00000000}},	//   _روش_, ̃n_, łcen,
  { {0x8c18005d,0x69c800a3,0xd843004c,0x00000000}},	//   _پيتر_, rwde, _ničí_,
  { {0x07a4000d,0x3835045b,0x28aa0082,0x00000000}},	//   паўн, інгр, _कारि,
  { {0x98be001c,0x7cfc01a8,0x29020014,0x00000000}},	//   ētā_, _cérv, akka_,
  { {0x8aa50054,0x95c50044,0x4efb009a,0x00000000}},	//   _фрід, غيره, נהלו,
  { {0xdcf80023,0x44b50085,0x00000000,0x00000000}},	//   msvē, ўбас,   ,
  { {0x36d520cf,0xdb090139,0x49180063,0x00000000}},	// [9630] _допр, lteá, _לקהל_,
  { {0x4427008b,0x8c41004d,0x2f0b01e1,0x00000000}},	//   ăn_, ößig, _køge_,
  { {0x2bcf0053,0xdb090025,0x61150636,0x00000000}},	//   _तैना, nteá, оджу,
  { {0xdb090027,0x753d0022,0xd2580fce,0x00000000}},	//   iteá, _uksz, сцу_,
  { {0xcf9b0138,0x60c40019,0x7cfc0164,0x00000000}},	//   ује_, õima, _jéru,
  { {0x13ba0047,0xdb1b0014,0xdb090058,0x00000000}},	//   _דזשע, lvuö, önün,
  { {0xace92785,0x28aa0042,0x61fe056c,0x00000000}},	//   имка_, _कालि, cypl,
  { {0x28d90053,0x69164acd,0x8b954e4a,0x00000000}},	//   _बोलि, lšev, ороч,
  { {0x5f740021,0xf8bf013d,0xfaa502fa,0x00000000}},	//   _فالر, tnén_, оапо,
  { {0x29090072,0x3dd20022,0x68e426fe,0x00000000}},	//   _alaa_, ływa_, _snid,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x7cfc12d6,0x29020050,0x71d6009a,0x00000000}},	//   _sérv, ukka_, קורד_,
  { {0x290200fe,0x3c470242,0xf8bf013d,0x00000000}},	//   rkka_, _اضاف, mnél_,
  { {0x7ae30031,0x2bcf0053,0xead40121,0x00000000}},	//   _unnt, _तैया, _ночь,
  { {0x96634e4b,0x96040053,0x273f3438,0x00000000}},	//   дкре, रनेट_, vînt_,
  { {0x68e44e4c,0x681c001c,0xf8bf013d,0x00000000}},	//   _unid, tādī, nnél_,
  { {0xd7ef0032,0x2480003b,0xf8bf013d,0x00000000}},	// [9640] _لكي_, rbim_, inél_,
  { {0x681c0418,0x6b4f00b9,0xea8c0041,0x00000000}},	//   rādī, bøge, ָנאָ,
  { {0x7c2d007a,0xf8bf00ea,0x673c4e4d,0x00000000}},	//   _þarf, knél_, morj,
  { {0xb9ac0047,0x11390085,0x00000000,0x00000000}},	//   רבאָ, бячы_,   ,
  { {0x7cfc00ea,0x67490014,0x5f73005d,0x00000000}},	//   _mért, _ásjó, واور,
  { {0x644b004b,0xb7db0063,0x7c244e4e,0x00000000}},	//   ügie, יקני, _žiro,
  { {0xbd670076,0x4c940ac5,0xa3d20053,0x00000000}},	//   орые_, пийс, विक_,
  { {0x61e1000f,0x3ea04e4f,0xe628008b,0x00000000}},	//   _álla, şit_, _đồ_,
  { {0x2f0b010a,0x63b64e50,0xd0070336,0x00000000}},	//   _søge_, ntyn, _дете_,
  { {0x39400078,0x673c00a8,0xb3d80085,0x00000000}},	//   _akis_, jorj, рмiр,
  { {0x673c00c2,0x63b60072,0xf3ff008d,0x00000000}},	//   dorj, htyn, _ngãn_,
  { {0x88b1006a,0x7cfc006c,0x63b60d07,0x00000000}},	//   ریخچ, _péru, ktyn,
  { {0xc864019d,0xdb090139,0xc1b70042,0x00000000}},	//   дтри, steá, _इङ्ग,
  { {0xf8bf004c,0x673c4e51,0xdcf8008f,0x00000000}},	//   mném_, gorj, psvē,
  { {0xf8bf0080,0x7cfc0460,0x45d43d71,0x00000000}},	//   lném_, _fért, морс,
  { {0x92a90045,0x6b4f0146,0x27e60078,0x00000000}},	//   kułó, røge, _šone_,
  { {0x6b4f010a,0x026b0076,0xc29909b3,0x00000000}},	// [9650] søge, ашей_, йках_,
  { {0x32b80021,0x5b7b0047,0x69164e52,0x00000000}},	//   قدمة_, ירמא, ušev,
  { {0x6924007d,0xc1b90062,0x6916085a,0x00000000}},	//   rđev, слех_, ršev,
  { {0x657a00ea,0x55da0047,0x7af8130e,0x00000000}},	//   íthe, _פֿינ, _lovt,
  { {0xf8bf0080,0xc8dc0041,0x3f690e82,0x00000000}},	//   jném_, יקאט, щило_,
  { {0xf8bf0080,0xef180086,0x644f4e53,0x00000000}},	//   dném_, омі_, _izci,
  { {0xf8bf00ea,0x69240130,0xb6bc009a,0x00000000}},	//   tnél_, ođet, יצגי,
  { {0x673c085a,0x7d760021,0x38690014,0x00000000}},	//   zorj, أمير_, _ngar_,
  { {0xe0d200b5,0x764500fe,0xdb09017d,0x00000000}},	//   _אײן_, _lyhy, nteç,
  { {0x3869014f,0x7cfc21bc,0xf8bf013d,0x00000000}},	//   _agar_, _sért, snél_,
  { {0x7afc0137,0x673c085a,0x7af80066,0x00000000}},	//   örta, vorj, _dovt,
  { {0x63b600fe,0x2fdf4e54,0xf8bf004c,0x00000000}},	//   ytyn, _krug_, bném_,
  { {0x673c0198,0xe7d50086,0x7d0b008f,0x00000000}},	//   torj, мірю, _ilgs,
  { {0xa3cf0053,0x2a35000d,0x4e1f0053,0x00000000}},	//   _वैध_, _нэйр, _बधाई_,
  { {0xec2d001c,0x386d0be1,0x7645002b,0x00000000}},	//   šķām_, žera_, _cyhy,
  { {0x2cad00f6,0x673c00c3,0x63b600fe,0x00000000}},	//   nged_, sorj, ttyn,
  { {0xf42a0024,0x644f0051,0xdb00004c,0x00000000}},	// [9660] _opäť_, _czci, zumí,
  { {0x43460062,0x7bdb0072,0x93430121,0x00000000}},	//   чезв, ivuu, енуе,
  { {0x7bdb0072,0x39650058,0x63b64e55,0x00000000}},	//   hvuu, _üssü_, styn,
  { {0x2fdf010a,0x26ca034d,0x63b60006,0x00000000}},	//   _brug_, lebo_, ptyn,
  { {0x2cad4e56,0x61e100ea,0x09a80053,0x00000000}},	//   dged_, _álln, _कम्य,
  { {0x69c30122,0xf67a00b5,0x2fdf330c,0x00000000}},	//   _opne, זאַמ, _drug_,
  { {0x2fdf0250,0x629c4e57,0x65660035,0x00000000}},	//   _erug_, _idro, _kikh,
  { {0x2cad0592,0x644600ac,0x628e0096,0x00000000}},	//   gged_, _kyki, _hebo,
  { {0x7cfc007a,0x628e003e,0xcb670259,0x00000000}},	//   _sérs, _kebo, пање_,
  { {0x9998000a,0x65664e58,0x628e0150,0x00000000}},	//   окот_, _likh, _jebo,
  { {0x6446007a,0x02b70063,0x7bdb00fe,0x00000000}},	//   _lyki, הליך_, avuu,
  { {0x63a44e59,0x27e04e5a,0x26d84e5b,0x00000000}},	//   krin, _brin_, edro_,
  { {0x63a40146,0x69160024,0x7cfc0e7c,0x00000000}},	//   jrin, všet, _férr,
  { {0x63a44e5c,0x7cfc00ea,0x628e4e5d,0x00000000}},	//   drin, _térs, _nebo,
  { {0x3abb0063,0x27e04e5e,0xd49b1915,0x00000000}},	//   _המונ, _erin_, йра_,
  { {0xf8bf0164,0x629c0185,0xca470067,0x00000000}},	//   fiée_, _adro, _عليه_,
  { {0x24580076,0x889c0063,0x65660397,0x00000000}},	// [9670] зать_, _הבחי, _dikh,
  { {0xd25b0076,0x628e0e7c,0x26ca161d,0x00000000}},	//   бце_, _cebo, cebo_,
  { {0x3f80000c,0x63a40465,0x69160080,0x00000000}},	//   ţiul_, arin, pšet,
  { {0xf42a0024,0x63a44e5f,0xf8bf013d,0x00000000}},	//   _späť_, brin, dnék_,
  { {0xf8bf0164,0x3fc9007e,0x752d4e60,0x00000000}},	//   ciée_, تدای_, mnaz,
  { {0x628e4e61,0x61e100ea,0x8d750021,0x00000000}},	//   _gebo, _állo, وابا,
  { {0x752d051e,0x30a7047e,0xddcb0078,0x00000000}},	//   onaz, _нрав, _čiųj,
  { {0x78bd006f,0x2fdf00bd,0x26ca0222,0x00000000}},	//   jfsv, _trug_, zebo_,
  { {0x752d0035,0x69dc0831,0x2cad120f,0x00000000}},	//   inaz, æren, rged_,
  { {0x78bd007a,0x1a05005a,0x7c260014,0x00000000}},	//   efsv, дпом, úkra,
  { {0x6ce70054,0x78bd004d,0x98a60320,0x00000000}},	//   _ніде, ffsv, мине,
  { {0x27e00529,0xec6e000a,0x63a44e62,0x00000000}},	//   _prin_, _јп_, yrin,
  { {0x87fa0085,0x65660072,0xcaf50044,0x00000000}},	//   цэнт_, _rikh, _يستب,
  { {0x6d4938fb,0xdb2300fe,0x752d2f33,0x00000000}},	//   llea, äräi, enaz,
  { {0xe643050f,0x15460002,0x628e4e63,0x00000000}},	//   верп, девм, _rebo,
  { {0x27e04e64,0x752d051e,0x6d490025,0x00000000}},	//   _trin_, gnaz, nlea,
  { {0x6d490025,0xdb000026,0x6d5b0150,0x00000000}},	// [9680] ilea, lumá, imua,
  { {0x752d0035,0xf8bf0003,0x63a44e65,0x00000000}},	//   anaz, riée_, rrin,
  { {0x63a44e66,0x6d494e67,0xd00f005d,0x00000000}},	//   srin, klea, یلم_,
  { {0xc5f30ca4,0x8fa60189,0x63a44e68,0x00000000}},	//   _סדר_, даде, prin,
  { {0xc0570054,0xdce3005f,0x628e4e69,0x00000000}},	//   міш_, lpnė, _tebo,
  { {0xf8bf00ea,0x6d5b017e,0x6d494e6a,0x00000000}},	//   tnék_, emua, elea,
  { {0xdee3005e,0x672e0014,0x62631dd0,0x00000000}},	//   тоји, inbj, _авра,
  { {0xe8e00013,0xed570092,0x6d494e6b,0x00000000}},	//   _trội_, мој_, glea,
  { {0xaf2a1915,0xe04319f7,0xefb3005d,0x00000000}},	//   _джаз_, _анти, _لینگ,
  { {0xadba0032,0xe45700b5,0x6d49004e,0x00000000}},	//   _وهذا_, ויפט_, alea,
  { {0xf2d301f9,0x6d491db7,0xdb000026,0x00000000}},	//   דעת_, blea, gumá,
  { {0xcb6a0ab1,0xf787017d,0xc2370041,0x00000000}},	//   _даде_, íços_, םאיז_,
  { {0xac97006a,0x6d404e6c,0xbd5b009a,0x00000000}},	//   _آنها_, moma, _וכאש,
  { {0xdc02004c,0x6d404e6d,0xdb00013d,0x00000000}},	//   nčíc, loma, bumá,
  { {0xdb0005d5,0x6d400bda,0x752d0244,0x00000000}},	//   cumá, ooma, tnaz,
  { {0x57b50086,0x657a00ea,0x66f8005b,0x00000000}},	//   _збит, ítha, _aşkı,
  { {0x752d051e,0xc355005e,0xf66b0021,0x00000000}},	// [9690] rnaz, екај, _وحده_,
  { {0x60cb00ca,0x6d404e6e,0xa227005d,0x00000000}},	//   wegm, homa, وراه,
  { {0x224700b9,0xda0e0053,0x7cf500be,0x00000000}},	//   ænk_, ानित_, _várz,
  { {0x6d404e6f,0x55760041,0x798d0022,0x00000000}},	//   joma, _רערן_, _ławk,
  { {0x25750137,0x6d404e70,0x2f0b01f2,0x00000000}},	//   _hål_, doma, _døgn_,
  { {0x63ad053b,0xa5c5013d,0x60cb4e71,0x00000000}},	//   muan, cióé, segm,
  { {0x63ad0397,0x6d490025,0x69dc000e,0x00000000}},	//   luan, tlea, ærel,
  { {0x2575287a,0x6d4949f4,0x6d404e72,0x00000000}},	//   _mål_, ulea, goma,
  { {0x6d5b0397,0x31710089,0x6d494e73,0x00000000}},	//   rmua, _huzz_, rlea,
  { {0xfaf10032,0xa3e00053,0xdb003d05,0x00000000}},	//   اثة_, थित_, tumá,
  { {0x6d494e74,0x6d4009e9,0xf8bf1094,0x00000000}},	//   plea, boma, ffé_,
  { {0xdb0903d9,0x6d40065d,0x63ad3e35,0x00000000}},	//   nteú, coma, kuan,
  { {0x63ad1366,0xc7960085,0xfaa518ea,0x00000000}},	//   juan, эрны, _зало,
  { {0x63ad4e75,0x7d09115c,0x6a64005d,0x00000000}},	//   duan, lkes, عطیل,
  { {0x7d090006,0x63ad0370,0xe73704f2,0x00000000}},	//   okes, euan, хер_,
  { {0x7d094e76,0x7c240734,0x1da70042,0x00000000}},	//   nkes, _žiri, _गिनत,
  { {0x63ad4e77,0x61e1013d,0x03a30f50,0x00000000}},	// [96a0] guan, _állj, лито,
  { {0xdbc60004,0x06860088,0x2cbf0150,0x00000000}},	//   _tööa, _ягон, hfud_,
  { {0x7d094e78,0xd8da0063,0x39424e79,0x00000000}},	//   kkes, ּקְר, ooks_,
  { {0x26da0009,0x660100fe,0xdfda0062,0x00000000}},	//   _hapo_, älke, зък_,
  { {0x43750001,0xc6fa0063,0x63ad1358,0x00000000}},	//   _ауст, ּלֶך, cuan,
  { {0x7d090035,0x6d4000e5,0x479b009a,0x00000000}},	//   ekes, woma, לינס,
  { {0x26da00c3,0x27420080,0x2d9a33bf,0x00000000}},	//   _mapo_, méně_, épe_,
  { {0x55db00b5,0x6d4000fe,0x91bb0063,0x00000000}},	//   פֿונ, uoma, _ממלי,
  { {0x5ce30076,0x6d404e7a,0x39424e7b,0x00000000}},	//   ующа, roma, doks_,
  { {0x6b4f010a,0x2d6e0080,0x6d404e7c,0x00000000}},	//   søgn, _před_, soma,
  { {0x6d404e7d,0xddc80051,0xb87b1a76,0x00000000}},	//   poma, _wzdł, ndíg,
  { {0x69b10161,0x386d06a5,0x63ad4e7e,0x00000000}},	//   _अमरी, øer_, yuan,
  { {0xa2c10053,0xf8bf336c,0xfca904a0,0x00000000}},	//   र्ड्, rfé_, _زانو_,
  { {0x26da051e,0x6b4f00b9,0x3942004b,0x00000000}},	//   _capo_, nøgl, aoks_,
  { {0x39423adb,0x692b0080,0x95c8012d,0x00000000}},	//   boks_, třed, нута_,
  { {0x290b003d,0xa4d40086,0x63ad4e7f,0x00000000}},	//   ības_, лосі, tuan,
  { {0x68ed4592,0x799a0022,0x8d5b0063,0x00000000}},	// [96b0] _inad, lstw, לכלי,
  { {0x63ad10b4,0xd25b3320,0x257500a5,0x00000000}},	//   ruan, пце_, _tål_,
  { {0x692b0080,0x31c7000d,0x41e40603,0x00000000}},	//   před, эсав, ліца,
  { {0xdb00078c,0xc60d0042,0xa98b009a,0x00000000}},	//   lumä, सनीय_, לָדִ,
  { {0x63ad4e80,0x24894e81,0x389c00ff,0x00000000}},	//   quan, mbam_, ליאנ,
  { {0xf77400b5,0x24890025,0xa49b00cd,0x00000000}},	//   אקס_, lbam_, _glòr,
  { {0x7d09021e,0x68ed4a1b,0xd378007d,0x00000000}},	//   tkes, _onad, _čći_,
  { {0x692b004c,0xdb00004b,0xad58014b,0x00000000}},	//   hřeb, humä, нрых_,
  { {0x7d090d11,0xdb000659,0x3942005f,0x00000000}},	//   rkes, kumä, voks_,
  { {0xf8aa0161,0x7d094e82,0x68ed4e83,0x00000000}},	//   कल्प, skes, _anad,
  { {0x799a006f,0x60db12ca,0xc27a0063,0x00000000}},	//   gstw, _kaum, ורתי,
  { {0x60db2ce8,0x63691ed1,0x26da1358,0x00000000}},	//   _jaum, _ožno, _sapo_,
  { {0x26da0016,0x644b0019,0x5ba70076,0x00000000}},	//   _papo_, ügil, _чрез,
  { {0xfaa510a3,0x6b9b006f,0x68ed4e84,0x00000000}},	//   _рако, msug, _enad,
  { {0xceb201d8,0xd62a16fc,0x61e1013d,0x00000000}},	//   יים_, фове_, _állh,
  { {0x26da0035,0x68ed00bd,0x60db4e85,0x00000000}},	//   _wapo_, _gnad, _naum,
  { {0x26da46da,0x036a0330,0xf8bf013d,0x00000000}},	// [96c0] _tapo_, диак_, tnév_,
  { {0x68ed007d,0x7d1e00ea,0x2900004b,0x00000000}},	//   _znad, épsz, _hoia_,
  { {0x60db2e3a,0x68ed002b,0x2126194f,0x00000000}},	//   _baum, _ynad, tioh_,
  { {0x6b9b0019,0xdcfe001c,0x6066007e,0x00000000}},	//   ksug, īvīb, نهال,
  { {0xa0670001,0x08770047,0xdefa05ac,0x00000000}},	//   ваца_, דענט_, дый_,
  { {0xa3c10161,0x799a0051,0x6443003b,0x00000000}},	//   ूबर_, ystw, şnic,
  { {0x5db30044,0xa3e00042,0x30860044,0x00000000}},	//   لإير, थिव_, _للأف,
  { {0x6d590185,0x29004e86,0x60db4e87,0x00000000}},	//   _chwa, _noia_, _gaum,
  { {0x6b9b0455,0x272d00a8,0x50460d82,0x00000000}},	//   gsug, lžne_, _реаб,
  { {0x6d5900e3,0x68ed22b6,0x272d00c2,0x00000000}},	//   _ehwa, _snad, ožne_,
  { {0x3f86017d,0x290001f4,0x7c2d0014,0x00000000}},	//   lpou_, _boia_, _þarn,
  { {0x799a0051,0xe8e0008b,0x5d750121,0x00000000}},	//   rstw, _trời_, _суфф,
  { {0x692b0080,0xf8bf02dd,0xc7f80054,0x00000000}},	//   třeb, bién_, вняє_,
  { {0xf8bf006d,0x644b004b,0x799a161f,0x00000000}},	//   cién_, ügim, pstw,
  { {0xdb0000c7,0xf6280086,0x442d003b,0x00000000}},	//   rumä, віти_, _ţe_,
  { {0x69d80058,0xdb00078c,0x68ed0168,0x00000000}},	//   _isve, sumä, _unad,
  { {0x60db4e88,0x24894e89,0x54550776,0x00000000}},	// [96d0] _raum, rbam_, уват,
  { {0x36d50076,0xe3b00021,0x722b0121,0x00000000}},	//   _соор, ترف_, мцев_,
  { {0x60db00bb,0x7c360014,0x41740593,0x00000000}},	//   _paum, _þyrf, لانس,
  { {0x26d10009,0xf8bf0003,0x4087005e,0x00000000}},	//   lezo_, mnés_, тужб,
  { {0xe8d900aa,0x443f001b,0xd91c0047,0x00000000}},	//   _chỉ_, _âu_, וואל,
  { {0x69ca00bd,0x26d10035,0xb87b1bae,0x00000000}},	//   _opfe, nezo_, ndíb,
  { {0xf8bf0164,0x2d94000d,0xddda00ea,0x00000000}},	//   nnés_, арыс, _betű,
  { {0x3ea9000c,0x26d10035,0x9258018e,0x00000000}},	//   şat_, hezo_, _раст_,
  { {0x26d10009,0xdc3101f7,0xfc050076,0x00000000}},	//   kezo_, _düğm, уппо,
  { {0xf8bf006d,0x6b820139,0x629500c2,0x00000000}},	//   uién_, _dtog, _jezo,
  { {0xdb0900ac,0x6b9b0019,0x6f01002b,0x00000000}},	//   lreë, ssug, _iolc,
  { {0xdb0000cd,0x61f80db3,0xdb1b0003,0x00000000}},	//   armà, ävli, itué,
  { {0x2900003b,0x69d83b52,0x60d60063,0x00000000}},	//   _voia_, _esve, נושא_,
  { {0x62950a63,0x316d006c,0xe4da0043,0x00000000}},	//   _nezo, _liez_, کورت_,
  { {0xf8bf0164,0x64a64e8a,0x6fd50042,0x00000000}},	//   gnés_, лава, _मैसू,
  { {0x2d5a002b,0x98a20022,0xf484005d,0x00000000}},	//   rëeg_, ynkę_, شاری,
  { {0x62953848,0xdce1008f,0xe7d50043,0x00000000}},	// [96e0] _bezo, _atlī, _نميگ,
  { {0xdb004e8b,0x070a0021,0xb4630899,0x00000000}},	//   stmö, _أيدي_, скул,
  { {0xd24f0032,0x62954e8c,0xc0e60591,0x00000000}},	//   كنك_, _dezo, ложк,
  { {0x19b60047,0xe8d90013,0xc0960044,0x00000000}},	//   טפער_, _phỉ_, اجات,
  { {0x316d02dd,0x60c2003b,0x6f014e8d,0x00000000}},	//   _diez_, rfom, _bolc,
  { {0xa857014e,0x6295102c,0x6f010bea,0x00000000}},	//   ניסה_, _gezo, _colc,
  { {0xdb1b0164,0x6b822f23,0x6f014e8e,0x00000000}},	//   ctué, _stog, _dolc,
  { {0x5d54000a,0x78a428a6,0x386d007d,0x00000000}},	//   јкит, _ndiv, žeri_,
  { {0x10160088,0xdb09006f,0x6f0114a9,0x00000000}},	//   _сьвя, creë, _folc,
  { {0x78a44582,0x6f01002b,0x2d96005e,0x00000000}},	//   _adiv, _golc, _брдс,
  { {0x26d100c2,0x9983005d,0x0d861377,0x00000000}},	//   vezo_, یلیو, _слен,
  { {0x644b0019,0x26d10035,0xec774e8f,0x00000000}},	//   ügik, wezo_, _бпц_,
  { {0xe8d9001b,0xdb000025,0x6f01005b,0x00000000}},	//   _giờ_, armá, _yolc,
  { {0x3dd20051,0x8c1b0063,0x7d0208d2,0x00000000}},	//   ływu_, _אודי, _hoos,
  { {0x7d020449,0x62952add,0x26d100ed,0x00000000}},	//   _koos, _rezo, rezo_,
  { {0x99830032,0xa7750156,0xf8bf109c,0x00000000}},	//   _اليو, _клич, rnés_,
  { {0xd839000a,0xdb00004b,0x893400f2,0x00000000}},	// [96f0] _шпиц_, stmõ, _دعوا,
  { {0x7d024e90,0x98a2008f,0x7bc04e91,0x00000000}},	//   _loos, mikā_, itmu,
  { {0xe8d9008b,0x62954e92,0x3f52003b,0x00000000}},	//   _nhị_, _vezo, râul_,
  { {0x6f010199,0x19b70047,0xdb0900ac,0x00000000}},	//   _solc, רפאר_, treë,
  { {0xa069005e,0x6f014e93,0x1fa70094,0x00000000}},	//   њала_, _polc, урег,
  { {0xaec4019d,0x656f0009,0xa2c10053,0x00000000}},	//   йбіл, _hich, र्श्,
  { {0x656f3ff8,0x41e4126b,0xe8d9008b,0x00000000}},	//   _kich, _літа, _chị_,
  { {0xdb0900ac,0x63ad4e94,0x27e94e95,0x00000000}},	//   preë, oran, _oran_,
  { {0x9ed9011c,0x656f1b1c,0x644b004b,0x00000000}},	//   _имат_, _mich, ügih,
  { {0x656f4e96,0x63ad4e97,0xfaa502f8,0x00000000}},	//   _lich, iran, јано,
  { {0x63ad0574,0x27e94e98,0x69de0061,0x00000000}},	//   hran, _aran_, _šper,
  { {0x656f0cd4,0x3e55008b,0x63ad4e99,0x00000000}},	//   _nich, _ít_, kran,
  { {0x63ad10a9,0x6d4b008f,0x2fcd4e9a,0x00000000}},	//   jran, _ikga, _jpeg_,
  { {0x2fcd4e9b,0xcb3900b5,0x6b893b25,0x00000000}},	//   _mpeg_, _שײַכ, mpeg,
  { {0x27e94e9c,0x98a2001c,0x63ad1ebd,0x00000000}},	//   _eran_, aikā_, eran,
  { {0x7de0000f,0x2a3a0063,0x656f0051,0x00000000}},	//   lásá, _בעצמ, _cich,
  { {0x27e94e9d,0x656f4e9e,0xb6020080,0x00000000}},	// [9700] _gran_, _dich, _řádn,
  { {0x656f4e9f,0x7de0013d,0xdb0001e1,0x00000000}},	//   _eich, násá, armæ,
  { {0x656f4ea0,0x63ad3603,0x69c14ea1,0x00000000}},	//   _fich, aran, ntle,
  { {0x2ba60161,0x3fe60095,0xe1650021,0x00000000}},	//   _खिला, ижев, مدني,
  { {0x69c10019,0xb87b006d,0xdb093ea2,0x00000000}},	//   htle, ndía, nteó,
  { {0x656f0122,0xfda60001,0x7d021b35,0x00000000}},	//   _zich, ајим, _soos,
  { {0x7de0000f,0x692b0080,0x60c4004b,0x00000000}},	//   dásá, dřen, õims,
  { {0x9cca0088,0x5bb8042c,0x6b5400cd,0x00000000}},	//   тыка_, глия_, tàgo,
  { {0x69c10045,0xa067080b,0x254a005f,0x00000000}},	//   etle, _вата_, mėlę_,
  { {0xe8d9001b,0xada60086,0x317833ec,0x00000000}},	//   _thị_, _важл, _kurz_,
  { {0x257c0027,0xbca6006a,0x61e1013d,0x00000000}},	//   _níl_, _نماي, _állt,
  { {0x98a2008f,0xfc660062,0x63ad4ea2,0x00000000}},	//   tikā_, _кълн, yran,
  { {0x656f177d,0xdb1b01a8,0x7de0013d,0x00000000}},	//   _rich, ctuï, básá,
  { {0x656f0199,0x66010137,0x69c100e5,0x00000000}},	//   _sich, älko, btle,
  { {0x656f10ca,0x257c0080,0x7afc0026,0x00000000}},	//   _pich, _cíl_, örtu,
  { {0x79690051,0xf9930063,0x257c004c,0x00000000}},	//   _oświ, _ורק_, _díl_,
  { {0x656f0009,0x63ad4361,0xd371013a,0x00000000}},	// [9710] _vich, uran, سها_,
  { {0x656f0ad2,0x257c0139,0x7c2d02f7,0x00000000}},	//   _wich, _fíl_, _žark,
  { {0x644f0051,0x63ad4ea3,0x81a7007e,0x00000000}},	//   _wyci, sran, شحال,
  { {0x7de0000f,0x692b004c,0x63ad4ea4,0x00000000}},	//   zásá, zřen, pran,
  { {0x6b5d0003,0xd8ba0047,0xe8d90013,0x00000000}},	//   lège, טצײכ, _nhọ_,
  { {0x2d950138,0x752d235d,0x1167007e,0x00000000}},	//   брис, liaz, _چلسی_,
  { {0x692b0080,0xdb090019,0x7de000ea,0x00000000}},	//   vřen, rteü, vásá,
  { {0xdb090019,0x752d4ea5,0x657a0139,0x00000000}},	//   steü, niaz, íthi,
  { {0x7de0000f,0x2ca60185,0x692b0080,0x00000000}},	//   tásá, _ddod_, třen,
  { {0x6b894ea6,0xe9d90376,0x69c14ea7,0x00000000}},	//   rpeg, гко_, ttle,
  { {0x7de000ea,0x6b894ea8,0x39460065,0x00000000}},	//   rásá, speg, йног,
  { {0x89360021,0xcdf40021,0x6d440066,0x00000000}},	//   إعدا, _بأكث, čiac,
  { {0x692b31b6,0xbb850021,0x752d4ea9,0x00000000}},	//   mřel, _التي, diaz,
  { {0xb87b12c7,0x7d1b00a5,0x69c1470e,0x00000000}},	//   rdía, lhus, ptle,
  { {0xba9a0063,0x7d1b0019,0x2d9800d1,0x00000000}},	//   _עסקי, ohus, _æret_,
  { {0x65641102,0x272d00a8,0xd943130d,0x00000000}},	//   umih, ržna_, _нещи,
  { {0xe2920021,0xe45a469c,0x13ea0085,0x00000000}},	// [9720] كذا_, ужа_, ымай_,
  { {0x57fb0063,0x257c0139,0x63ab013d,0x00000000}},	//   _עליו, _tíl_, ágna,
  { {0x8b5600b5,0xe612007e,0x7d1b1b1d,0x00000000}},	//   ציעס_, _رشد_, khus,
  { {0x752d0918,0xd83f00c3,0x14d604a0,0x00000000}},	//   ciaz, šček_, _ازدح,
  { {0x7d1b13e5,0x90970054,0xd9a40082,0x00000000}},	//   dhus, світ_, _खट्ट,
  { {0xd0070138,0x6e934eaa,0xdb0005b9,0x00000000}},	//   сеље_, пишу, ormå,
  { {0xacf80065,0x644b004b,0x629e4eab,0x00000000}},	//   инку_, ügiv, mapo,
  { {0xc5f30063,0x7d1b4eac,0x629e4ead,0x00000000}},	//   לדו_, ghus, lapo,
  { {0x44204eae,0x79690022,0xbc4a030b,0x00000000}},	//   nzi_, _uświ, ычке_,
  { {0x5a3406be,0x752d4eaf,0x7d1b4eb0,0x00000000}},	//   жнот, ziaz, ahus,
  { {0x9cca03e6,0xaa582e1a,0x6ce6046e,0x00000000}},	//   _была_, рину_, _гіле,
  { {0xe8d90013,0x629e4eb1,0x7d1b4eb2,0x00000000}},	//   _thọ_, hapo, chus,
  { {0x395f003d,0x629e1668,0x442000ea,0x00000000}},	//   ķus_, kapo, jzi_,
  { {0x3bbb0063,0xdc3b0047,0x44204eb3,0x00000000}},	//   _עמוד, _געדר, dzi_,
  { {0x75880076,0x44204d9e,0xdb0000a5,0x00000000}},	//   йств_, ezi_, rrmä,
  { {0x7c2d0734,0xa3e50042,0x25ac01c8,0x00000000}},	//   _žari, पटल_, ádla_,
  { {0x752d0918,0x93970021,0xc2990071,0x00000000}},	// [9730] riaz, إجرا, иках_,
  { {0x394b0268,0x692b0080,0x20d30013,0x00000000}},	//   locs_, zřel, _ải_,
  { {0x44200a1a,0xe5c70169,0x272d00a8,0x00000000}},	//   azi_, _успо, lžno_,
  { {0x90550bf5,0xb87b0139,0x272d2205,0x00000000}},	//   овец, idío, ožno_,
  { {0x692b0080,0x493c0063,0x44204eb4,0x00000000}},	//   vřel, נגדו, czi_,
  { {0xa1950088,0x629e0dd2,0x98a2260f,0x00000000}},	//   _магч, capo, miką_,
  { {0xe8d9001b,0x6d49006f,0x7d1b45cb,0x00000000}},	//   _nhỏ_, toea, thus,
  { {0x7d1b0035,0x394b00cd,0xdb850854,0x00000000}},	//   uhus, jocs_, огии,
  { {0xfc310032,0x212f0025,0x60c60137,0x00000000}},	//   بحث_, migh_, _ökma,
  { {0x212f4b46,0xaa490121,0x8b250054,0x00000000}},	//   ligh_, иппа_, ідне,
  { {0x44202d2e,0xb87b0025,0x212f0025,0x00000000}},	//   zzi_, rdín, oigh_,
  { {0x212f0027,0xc6890ee1,0xdb09006d,0x00000000}},	//   nigh_, _יא_, rteñ,
  { {0x69dc000e,0xfaa50085,0xdce8004c,0x00000000}},	//   ærer, _дало, _ludě,
  { {0x9f44017d,0x212f4eb5,0x4fd6009a,0x00000000}},	//   _irmã_, high_, חושב_,
  { {0xe7370088,0xdb09006d,0x4da90063,0x00000000}},	//   цер_, nreí, יֹּ֣,
  { {0x442003af,0x7ae34eb6,0x98a20c3b,0x00000000}},	//   tzi_, _hant, fiką_,
  { {0x629e00bb,0x7306005a,0x4426001b,0x00000000}},	// [9740] tapo, опаз, ào_,
  { {0x2902074f,0x7ae34eb7,0x6b840025,0x00000000}},	//   ljka_, _jant, _éige,
  { {0x442000ea,0x68e44eb8,0x7546026b,0x00000000}},	//   szi_, _kaid, _мноз,
  { {0x290208ea,0x4fea065b,0x7ae34c01,0x00000000}},	//   njka_, имен_, _lant,
  { {0x7e9a0032,0x68e4057a,0x644b0019,0x00000000}},	//   لنشر_, _maid, ügit,
  { {0x212f0027,0xf413014e,0x7ae33397,0x00000000}},	//   aigh_, _חפש_, _nant,
  { {0x629c003d,0x2919143b,0x25b801db,0x00000000}},	//   _iero, ūrai_, nurl_,
  { {0x7ae30ac8,0x1d070001,0x68e44eb9,0x00000000}},	//   _aant, жећи_, _naid,
  { {0x7ae3014f,0x629c0ff0,0xa2ca0053,0x00000000}},	//   _bant, _kero, स्थ्,
  { {0x7ae34eba,0x26d83358,0xddc9003b,0x00000000}},	//   _cant, jero_, înţe,
  { {0xdb09006d,0x26d84ebb,0x394b00cd,0x00000000}},	//   creí, dero_, tocs_,
  { {0x7c65007e,0x2d8e00bd,0xa2ca0053,0x00000000}},	//   _کامل, mpfe_, स्त्,
  { {0x26d84ebc,0x7ae34ebd,0x2fc64ebe,0x00000000}},	//   fero_, _fant, ntog_,
  { {0x63a4314f,0x26d83d06,0x7ae34ebf,0x00000000}},	//   dsin, gero_, _gant,
  { {0xfb1b014e,0xc1c90053,0xd49b05f9,0x00000000}},	//   _דוגמ, _रहेग, ира_,
  { {0x2fc610e9,0x692b0080,0x6b4f0146,0x00000000}},	//   ktog_, zřej, søgt,
  { {0x26d8051e,0x7ae34ec0,0x212f0139,0x00000000}},	// [9750] bero_, _yant, vigh_,
  { {0x68e410ca,0x2fc60146,0x660e0080,0x00000000}},	//   _zaid, dtog_, ínká,
  { {0x212f0027,0x63a44ec1,0xdb1b4ec2,0x00000000}},	//   tigh_, asin, ntuá,
  { {0x6f1a000c,0x644b0019,0x63a4148c,0x00000000}},	//   _altc, ügis, bsin,
  { {0x212f0027,0xdb09017d,0x61ee004d,0x00000000}},	//   righ_, queç, _erbl,
  { {0x212f0027,0x27e40014,0x629c4ec3,0x00000000}},	//   sigh_, æmni_, _gero,
  { {0x7ae31f21,0x6d4421e3,0xf5ab009a,0x00000000}},	//   _rant, čian, ׁבַּ,
  { {0x7ae34ec4,0x26d82b91,0x62854ec5,0x00000000}},	//   _sant, zero_, lcho,
  { {0x26c102dd,0x68e40498,0x692b0080,0x00000000}},	//   _ocho_, _raid, přej,
  { {0x68e40dbb,0xb4360063,0x78bd004d,0x00000000}},	//   _said, לָיו_, egsv,
  { {0xfc46007a,0x26d84ec6,0x63a4005b,0x00000000}},	//   _þíns_, vero_, zsin,
  { {0x63a44ec7,0x2ee54ec8,0x26c10016,0x00000000}},	//   ysin, _half_, _acho_,
  { {0x68e44ec9,0x7ae30419,0x26d84eca,0x00000000}},	//   _vaid, _tant, tero_,
  { {0xbbe9007e,0x6924013d,0x68e40244,0x00000000}},	//   _پرچم_, tőes, _waid,
  { {0x6b4f0146,0x8afa0063,0x26d84ecb,0x00000000}},	//   søgs, _להסי, rero_,
  { {0xb4e60235,0x629c3fd7,0x26d80204,0x00000000}},	//   पये_, _sero, sero_,
  { {0x26d81095,0x629c1366,0xa5073161,0x00000000}},	// [9760] pero_, _pero, чета_,
  { {0x63a44ecc,0x6aa12755,0x64410022,0x00000000}},	//   rsin, nalf, _ślic,
  { {0x63a40112,0x629c34bf,0xf67b0063,0x00000000}},	//   ssin, _vero, _לאימ,
  { {0x2fc60137,0x63a44ecd,0xd5fb0063,0x00000000}},	//   ttog_, psin, _הפטר,
  { {0xd5b1001b,0x6f080886,0x4abd0053,0x00000000}},	//   ớc_, _podc, ्भाव,
  { {0x657e00ac,0x2fc64ece,0x121a000d,0x00000000}},	//   _kuph, rtog_, _любы_,
  { {0x39814ecf,0x2fc64ed0,0x6f08175e,0x00000000}},	//   _nós_, stog_, _vodc,
  { {0x718b0063,0xb23b0041,0x823b0041,0x00000000}},	//   _לְמַ, _העלז, _העלצ,
  { {0x61430bd8,0xd1750085,0x8bd30085,0x00000000}},	//   _чета, _цыры, ежыц,
  { {0xef170055,0xeb970002,0x692b004c,0x00000000}},	//   _ему_, џиќ_, přek,
  { {0x98a228d2,0xf2d30041,0xa2c10042,0x00000000}},	//   likę_, ײער_, र्ट्,
  { {0x18a4018e,0x6aa121ef,0xdb1b4ed1,0x00000000}},	//   наџм, aalf, rtuá,
  { {0x48e4000d,0xdb1b017d,0x8c3d003b,0x00000000}},	//   хоўв, stuá, taşe,
  { {0x39810027,0x6aa100cd,0x87040085,0x00000000}},	//   _fós_, calf, нясе,
  { {0x6614004c,0xdb090137,0xe3b30043,0x00000000}},	//   _čeká, tteö, کرز_,
  { {0xe945007e,0x2a3b0063,0x9a3b0063,0x00000000}},	//   _ترتی, _לעומ, _לתוק,
  { {0x657e093c,0x644a0075,0x57b40085,0x00000000}},	// [9770] _euph, şfin, _збыт,
  { {0xc3540001,0x62854ed2,0x212d085a,0x00000000}},	//   екуј, ucho, _smeh_,
  { {0xcb1300b5,0x69c84ed3,0x7b16003b,0x00000000}},	//   עלע_, ntde, _râul,
  { {0xf8bf0164,0x62854ed4,0x98a20051,0x00000000}},	//   ngé_, scho, fikę_,
  { {0xf8bf0164,0xdb2300ea,0x9f840054,0x00000000}},	//   liés_, űség, егід,
  { {0x69c801b9,0x7528001c,0x66220058,0x00000000}},	//   ktde, īdze, _öykü,
  { {0x6aa100ac,0x78ad4ed5,0xf2d20063,0x00000000}},	//   valf, _odav, _שעל_,
  { {0x6aa1002b,0x78ad4ed6,0x85f8009a,0x00000000}},	//   walf, _ndav, למוס_,
  { {0x1c450086,0xfc310021,0x6aa14ed7,0x00000000}},	//   ьним, ضحة_, talf,
  { {0x39810016,0xc9a90076,0x89a90e51,0x00000000}},	//   _pós_, овое_, оков_,
  { {0xd94605d2,0xa96a0a90,0x6aa14ed8,0x00000000}},	//   дени, жина_, ralf,
  { {0x398114b1,0xf8bf4ed9,0x07a60601,0x00000000}},	//   _vós_, diés_, мамн,
  { {0x200b00cd,0x69c8006f,0xbbeb005d,0x00000000}},	//   _àcid_, atde, _درام_,
  { {0xab640086,0xf8bf0164,0xdb094512,0x00000000}},	//   _звіл, fiés_, breá,
  { {0xf8bf0003,0x7bc90805,0xbb520049,0x00000000}},	//   giés_, lteu, _جنوب,
  { {0x2cbf0004,0x2d53017d,0x7d0b013d,0x00000000}},	//   ngud_, mães_, _jogs,
  { {0x7bc94eda,0x644b0019,0x130a000d,0x00000000}},	// [9780] nteu, ügip, онай_,
  { {0xe8d900aa,0x446315d3,0xa3cf0053,0x00000000}},	//   _thể_, твув, _शहर_,
  { {0x4256000a,0xf8bf4edb,0xa50a05fb,0x00000000}},	//   фтат, ciés_, _дена_,
  { {0x7bc94149,0x98a20078,0xf4960044,0x00000000}},	//   kteu, tikę_, _تشدد,
  { {0xdfd0006a,0xd12f006a,0x10a34edc,0x00000000}},	//   ايت_, جمن_, тичн,
  { {0x6d440006,0xdee3005e,0xdb09013d,0x00000000}},	//   čiam, вољи, yreá,
  { {0x7d0b010a,0x69c80137,0xe8d9008d,0x00000000}},	//   _bogs, xtde, _giỗ_,
  { {0xfbaa0121,0xb87b004c,0xe0d7012c,0x00000000}},	//   отой_, rdík, _овс_,
  { {0xaec60001,0x628300a8,0xbb74005e,0x00000000}},	//   _обал, žnoe, нгиј,
  { {0x98a00051,0x69c84edd,0xf1d20042,0x00000000}},	//   _imię_, ttde, _सहान,
  { {0x6935093e,0x1959014c,0x7bc90003,0x00000000}},	//   енну, заны_, ateu,
  { {0x27f2001f,0x69c80f8c,0xdbd80046,0x00000000}},	//   _bryn_, rtde, _fæða,
  { {0x7bc93104,0xf8bf2614,0x272d00c3,0x00000000}},	//   cteu, rgé_, lžni_,
  { {0xf8bf0003,0x38c8009c,0x52d80082,0x00000000}},	//   tiés_, tíró_, ड़ोस,
  { {0xb9e60086,0x94d54ede,0xa4d50500,0x00000000}},	//   _ціли, новц, нові,
  { {0xf8bf0164,0x63b6001f,0x8c3d005b,0x00000000}},	//   riés_, fryn, laşa,
  { {0x24580076,0x29190df9,0x27f2002b,0x00000000}},	// [9790] дать_, ūras_, _gryn_,
  { {0xae1e0053,0xf8bf006c,0xd25b4edf,0x00000000}},	//   बनान_, piés_, оце_,
  { {0x673500c3,0x51840088,0x85750076,0x00000000}},	//   mizj, вуча, _плох,
  { {0x3395000d,0xa5d8005d,0x6735056c,0x00000000}},	//   _памё, _کبیر_, lizj,
  { {0xf8bf0164,0x9f350086,0x24b6009f,0x00000000}},	//   chée_, неді, _אהרן_,
  { {0x2f180055,0xdbc70072,0x656d0656,0x00000000}},	//   мочь_, _kööp, lmah,
  { {0xa3e70053,0x4ea40141,0x31c40ada,0x00000000}},	//   भिक_, трча, _иств,
  { {0x50f4005a,0x248934e9,0xeb991d6d,0x00000000}},	//   _изст, ncam_, пии_,
  { {0x24894ee0,0x7bc94ee1,0x2cbf004b,0x00000000}},	//   icam_, uteu, rgud_,
  { {0x656d0089,0x7bc94ee2,0x2d5300be,0x00000000}},	//   hmah, rteu, tães_,
  { {0xf2d20047,0x656d0089,0xaf340021,0x00000000}},	//   נעט_, kmah, _شركت,
  { {0x7bc90164,0x2d53017d,0xd8261810,0x00000000}},	//   pteu, rães_, едми,
  { {0x395e001c,0xdce10078,0x38550062,0x00000000}},	//   ēts_, _sulė, върс,
  { {0xdb0900cd,0x29194ee3,0x656d20af,0x00000000}},	//   dreç, aksa_, emah,
  { {0xceb2014e,0xf8bf0195,0x6d5b0dcf,0x00000000}},	//   טים_, riér_, olua,
  { {0x63b60045,0x656d00a4,0xf8bf0003,0x00000000}},	//   tryn, gmah, thée_,
  { {0xc2b60001,0xe3ba0062,0x6d5b0072,0x00000000}},	// [97a0] ељењ, яба_, ilua,
  { {0x656d0c55,0x24890360,0x20ec0013,0x00000000}},	//   amah, acam_, _ới_,
  { {0x217a0021,0x569b0063,0xf9920041,0x00000000}},	//   سحاب_, _מייצ, ָרד_,
  { {0x98ab000c,0xf8bf0003,0x6d442291,0x00000000}},	//   mică_, phée_, čiak,
  { {0x98ab000c,0x9f4d00cd,0xdb09017d,0x00000000}},	//   lică_, _creï_, creç,
  { {0x6d5b053b,0xde5802fe,0xdb000046,0x00000000}},	//   elua, малі_, lumö,
  { {0x98ab0529,0x78a6017f,0xe3570063,0x00000000}},	//   nică_, kakv, _נשלח_,
  { {0xe47b00b5,0xdb090072,0x78a60014,0x00000000}},	//   ּריכ, hreä, jakv,
  { {0x8c3d003b,0xcf4635ce,0xb87b004c,0x00000000}},	//   taşa, _знай, odív,
  { {0x6d5b4ee4,0x60c245bb,0xb87b00be,0x00000000}},	//   alua, lgom, ndív,
  { {0xe8950088,0x8c3d0058,0x7e82008f,0x00000000}},	//   кань, raşa, ātpā,
  { {0x98ab000c,0x67350051,0xaa63000d,0x00000000}},	//   dică_, wizj, ытык,
  { {0xd7fb0138,0xac970021,0x75240066,0x00000000}},	//   чун_, _أنها_, dhiz,
  { {0x98ab0529,0x291900a4,0xd763005d,0x00000000}},	//   fică_, sksa_, انسی,
  { {0x98ab000c,0x09e30856,0x6d404ee5,0x00000000}},	//   gică_, _бојн, onma,
  { {0x7aea46e8,0x6d404ee6,0x656d00a4,0x00000000}},	//   _haft, nnma, umah,
  { {0x656d4ee7,0x248912a1,0x7aef0139,0x00000000}},	// [97b0] rmah, rcam_, _áitú,
  { {0xdbc70004,0x2489017d,0xdb090555,0x00000000}},	//   _tööp, scam_, rreç,
  { {0x6b82051e,0xb87b006d,0x7aea0150,0x00000000}},	//   _luog, seíd, _maft,
  { {0x75244ee8,0xdb000046,0x3015012c,0x00000000}},	//   chiz, ormó, кдер,
  { {0x6b820006,0x3d040053,0xef0e4ee9,0x00000000}},	//   _nuog, वाने_, ам_,
  { {0x44292422,0x6d404eea,0x7aea4eeb,0x00000000}},	//   mza_, enma, _naft,
  { {0x40950021,0x442913b3,0xe570005d,0x00000000}},	//   _للأر, lza_, _خطی_,
  { {0x25ac0195,0x5ff5080b,0x44294eec,0x00000000}},	//   ádli_, _избу, oza_,
  { {0x6d5b0974,0x44294eed,0x98ab000c,0x00000000}},	//   rlua, nza_, zică_,
  { {0x6d404eee,0x7aea0331,0x44290e06,0x00000000}},	//   anma, _caft, iza_,
  { {0x7aea1d1a,0x2726008b,0x3ea74eef,0x00000000}},	//   _daft, _hông_, mant_,
  { {0x2726008b,0x61f5085a,0xe8f70156,0x00000000}},	//   _kông_, _mrzl, влю_,
  { {0x7d09017f,0x692b0080,0x6b5400cd,0x00000000}},	//   mjes, vřet, ràgr,
  { {0x98ab0529,0xcc3a0047,0x2726008b,0x00000000}},	//   tică_, _קעסט, _mông_,
  { {0x64a60088,0x27260013,0x7c29004d,0x00000000}},	//   кава, _lông_, lzer,
  { {0x7d0902ea,0x98ab000c,0x7d1b4ef0,0x00000000}},	//   njes, rică_, nkus,
  { {0xd4f50088,0x2726008b,0x7d09007d,0x00000000}},	// [97c0] ыяры, _nông_, ijes,
  { {0x3ea74ef1,0x7d1b0019,0x6d440006,0x00000000}},	//   jant_, hkus, čiai,
  { {0x7d1b4ef2,0x0219000d,0xf1a9007e,0x00000000}},	//   kkus, ніць_, فانه_,
  { {0x60c20006,0x6ec40053,0x27260013,0x00000000}},	//   ugom, _राहु, _bông_,
  { {0x272600aa,0x44290045,0x7c290122,0x00000000}},	//   _công_, cza_, jzer,
  { {0x626600d7,0x7d090051,0x3ea74ef3,0x00000000}},	//   _авга, ejes, gant_,
  { {0x20000469,0x7afe0268,0x98ab0022,0x00000000}},	//   ţii_, _òpti, licą_,
  { {0x6fb60021,0x7d0904aa,0x6d400058,0x00000000}},	//   _لمرا, gjes, unma,
  { {0x6d404ef4,0xb87b000f,0x3ea74ef5,0x00000000}},	//   rnma, ndít, bant_,
  { {0x2d6e0080,0x9998000a,0x3ea74ef6,0x00000000}},	//   _přes_, нкот_, cant_,
  { {0xc3330132,0x3f840035,0x44294ef7,0x00000000}},	//   שות_, _humu_, zza_,
  { {0x6aa300ca,0x64410022,0x3f8444cc,0x00000000}},	//   _eenf, _ślim, _kumu_,
  { {0x7c290051,0xead403e6,0x78a4143b,0x00000000}},	//   czer, _боль, _deiv,
  { {0x692b0080,0x7bc04ef8,0x6aa34ef9,0x00000000}},	//   třes, mumu, _genf,
  { {0x4b7b00b5,0x69d8006f,0x5b7b0063,0x00000000}},	//   _קאוו, _upve, _קרוא,
  { {0x44290994,0x628e006f,0x39ae0078,0x00000000}},	//   tza_, _afbo, męs_,
  { {0xf94a0047,0x3ea74efa,0x7bc04efb,0x00000000}},	// [97d0] _רעפֿ, yant_, numu,
  { {0x7d1b00c3,0x8c3d01f7,0x3ea71b84,0x00000000}},	//   zkus, daşl, xant_,
  { {0x7c290fbc,0x4429128b,0x2726008b,0x00000000}},	//   zzer, sza_, _sông_,
  { {0x7bc0003d,0x3ea74efc,0x7c294efd,0x00000000}},	//   kumu, want_, yzer,
  { {0x7d09017f,0x7bc04efe,0xdb0000b9,0x00000000}},	//   vjes, jumu, msmæ,
  { {0x657d00e3,0xa2940086,0x39ae0006,0x00000000}},	//   _hish, _варі, kęs_,
  { {0x63ad02f6,0x3ea74eff,0x39ae0006,0x00000000}},	//   lsan, rant_, jęs_,
  { {0x1be90055,0x61fa00ea,0x27e900fe,0x00000000}},	//   едии_, _átla, _osan_,
  { {0x7d09483c,0xa2ca0053,0x6aa3001f,0x00000000}},	//   rjes, स्क्, _penf,
  { {0x657d0035,0x7c292082,0x7d094f00,0x00000000}},	//   _lish, rzer, sjes,
  { {0x68ed0009,0x7c29367f,0x636b09ad,0x00000000}},	//   _baad, szer, münd,
  { {0x63ad4f01,0x8c3d01f7,0x3ea506a3,0x00000000}},	//   ksan, laşm, _helt_,
  { {0x78a44f02,0x68ed006f,0xdb0005b9,0x00000000}},	//   _veiv, _daad, dsmæ,
  { {0x8afc0045,0x63ad2f75,0xbb450076,0x00000000}},	//   ględ, dsan, _щелк,
  { {0x657d0359,0xd62a180e,0x63ad4f03,0x00000000}},	//   _bish, хове_, esan,
  { {0xf4950076,0x6362017d,0x7ae13928,0x00000000}},	//   ирую, tôno, lelt,
  { {0x657d0969,0x63ad4f04,0x645d002b,0x00000000}},	// [97e0] _dish, gsan, _cysi,
  { {0x8c3d005b,0x68ed4d55,0x69c1066d,0x00000000}},	//   vaşl, _zaad, oule,
  { {0x2b89001b,0xe8d9008b,0x69c14f05,0x00000000}},	//   _lúc_, _nhớ_, nule,
  { {0x2912006d,0x63ad17ed,0x7ae14f06,0x00000000}},	//   _joya_, bsan, helt,
  { {0x3ea50706,0x7ae14f07,0x69c10f3e,0x00000000}},	//   _belt_, kelt, hule,
  { {0x69c14f08,0x9f4d00cd,0x2d854f09,0x00000000}},	//   kule, _creà_, _bule_,
  { {0x3ea502ab,0x6da30d34,0xe8d90013,0x00000000}},	//   _delt_, бија, _chớ_,
  { {0x39ae0006,0xed570001,0x7e640080,0x00000000}},	//   vęs_, лој_, řipo,
  { {0x68ed017a,0x7ae14f0a,0x69c10003,0x00000000}},	//   _raad, felt, eule,
  { {0x68ed0aba,0x636b1fa3,0x6d594f0b,0x00000000}},	//   _saad, rüng, _ekwa,
  { {0x28c60235,0x68ed0019,0x69c14f0c,0x00000000}},	//   _वाशि, _paad, gule,
  { {0x7ae112be,0x39ae0078,0x63ad4188,0x00000000}},	//   aelt, ręs_, ysan,
  { {0x29000051,0x9cd70063,0x68ed047f,0x00000000}},	//   _dnia_, _תודה_, _vaad,
  { {0x6d440006,0x7ae13fba,0x63ad05e7,0x00000000}},	//   čiau, celt, vsan,
  { {0xdb0000b9,0x69c1109a,0x63ad002b,0x00000000}},	//   tsmæ, cule, wsan,
  { {0x29124f0d,0x636b1b89,0x63ad3d99,0x00000000}},	//   _goya_, zünd, tsan,
  { {0x27e9006d,0xb97c0047,0x2b89008b,0x00000000}},	// [97f0] _usan_, _אנהי, _xúc_,
  { {0x6b5d0268,0x645d0024,0x60c90290,0x00000000}},	//   tègi, _vysi, _scem,
  { {0x645d4f0e,0x63ad4f0f,0x8c3d0058,0x00000000}},	//   _wysi, ssan, vaşm,
  { {0x2d850969,0x645d0051,0x7ae1005b,0x00000000}},	//   _rule_, _tysi, zelt,
  { {0x69c14f10,0x636b09ad,0x2ca90066,0x00000000}},	//   zule, tünd, _ľad_,
  { {0xdb000354,0xadb50121,0x2d854f11,0x00000000}},	//   nsmä, ащищ, _pule_,
  { {0xdce80006,0x636b4f12,0x7ae10887,0x00000000}},	//   _judė, ründ, velt,
  { {0x3ea500bd,0x7ae100bd,0x636b4f13,0x00000000}},	//   _welt_, welt, sünd,
  { {0xdcfa003d,0x7ae133d0,0x69c100ac,0x00000000}},	//   _attē, telt, wule,
  { {0x2d85065c,0x7ae123b6,0x29124f14,0x00000000}},	//   _tule_, uelt, _soya_,
  { {0x8e840032,0x7dfc000c,0xdb000137,0x00000000}},	//   _المه, _căsă, dsmä,
  { {0xdb000019,0x2b89008b,0x0936000d,0x00000000}},	//   esmä, _túc_, рхоў,
  { {0x6d4416ff,0x98ab0051,0x47c30062,0x00000000}},	//   čiat, nicę_, обяв,
  { {0xf7720032,0xf8630086,0x69c14f15,0x00000000}},	//   تاج_, івро, pule,
  { {0xe8d9001b,0xe5a60320,0xf7430f63,0x00000000}},	//   _giữ_, риби, церо,
  { {0xb87b006d,0x7786005e,0x29004f16,0x00000000}},	//   seía, _клиз, _unia_,

  { {0xdb090e7c,0x636b00ea,0xd387130d,0x00000000}},	// [9800] queó, züne, ийте_,
  { {0x13030086,0xdce20013,0xe29a1a6b,0x00000000}},	//   озум, _khoă, таж_,
  { {0x673c376b,0xd62a005e,0x9c82011b,0x00000000}},	//   mirj, _роне_, áčko,
  { {0x316d03b2,0x6fb60044,0x661c0050,0x00000000}},	//   _chez_, لمصا, myrk,
  { {0xe8d9008b,0xdb000d1a,0x9c8200a8,0x00000000}},	//   _nhờ_, lsmå, ščko,
  { {0x2f56000a,0x6b840025,0x673c00c2,0x00000000}},	//   штес, _éigi, nirj,
  { {0x3207024a,0x5f19000d,0xdb0001e1,0x00000000}},	//   änyt_, ыццё_, nsmå,
  { {0x636b01f7,0x7dfc003b,0x9fe6005d,0x00000000}},	//   rüne, _răsă, _پسره,
  { {0xe8d9008b,0x673c0aba,0x8eea0002,0x00000000}},	//   _chờ_, kirj, _имав_,
  { {0x7dfc000c,0xdb0004c7,0x661c0137,0x00000000}},	//   _păsă, ksmå, kyrk,
  { {0xd5b1001b,0xdb000137,0x5a46000d,0x00000000}},	//   ới_, vsmä, рэпа,
  { {0xdb0010c4,0x7afd001c,0xd91b0062,0x00000000}},	//   dsmå, ēsta, тьо_,
  { {0xab940032,0xdce80006,0x9b940021,0x00000000}},	//   _التغ, _sudė, _التت,
  { {0x69cf000c,0xd7240086,0x7bdb0149,0x00000000}},	//   ăcer, офсп, _סקוו,
  { {0xdb004f17,0x74a70002,0xe45f0072,0x00000000}},	//   gsmå, ијае, _syö_,
  { {0x8a7b014e,0x38600014,0xd4981b06,0x00000000}},	//   _באות, _fyir_, иру_,
  { {0xdb000137,0x6283005f,0x00000000,0x00000000}},	// [9810] psmä, žnom,   ,
  { {0xa37b017d,0x39590206,0x636b0378,0x00000000}},	//   _opõe, loss_, dünc,
  { {0x7d0200c2,0x64490078,0xeab1089e,0x00000000}},	//   _onos, _žeid, לֹא_,
  { {0xe45f0072,0x3959004d,0xed46005d,0x00000000}},	//   _työ_, noss_, _رپ_,
  { {0x2f190086,0x2ef50085,0x8fe704f2,0x00000000}},	//   лодь_, йздр, рцед,
  { {0xc6950047,0x3959004d,0x6fb20021,0x00000000}},	//   זאַ_, hoss_, أموا,
  { {0xcdc80021,0x8c3d003b,0x7de40044,0x00000000}},	//   لذين_, maşi, قسيم,
  { {0xdcf9007e,0xf5320063,0xcd050456,0x00000000}},	//   افظت_, ּ֥ה_, спий,
  { {0x7b16003b,0x39591f96,0x5f9404d6,0x00000000}},	//   _râur, doss_, _митт,
  { {0x7d0200c3,0xb87b22da,0x8c3d00dd,0x00000000}},	//   _enos, teín, naşi,
  { {0x6d440024,0x673c00c3,0x5d850021,0x00000000}},	//   čiar, virj, _الصل,
  { {0xe8d9008b,0x7d024f18,0xb079013d,0x00000000}},	//   _thờ_, _gnos, _íósá,
  { {0xdb09006d,0xed591035,0xe8d9008d,0x00000000}},	//   sueñ, mož_, _giử_,
  { {0x63704f19,0x661c1c38,0xdb0002c0,0x00000000}},	//   mäng, tyrk, tsmå,
  { {0xdb09048e,0xd62714cf,0xb99501fb,0x00000000}},	//   queñ, боре_, _اشتغ,
  { {0x6362048c,0x2cad001f,0x60db00a4,0x00000000}},	//   môni, naed_, _nbum,
  { {0x63620016,0x673c00c2,0x138a0021,0x00000000}},	// [9820] lôni, pirj, اخرى_,
  { {0xed590080,0xadf90053,0xdb0000b8,0x00000000}},	//   hož_, ्मान_, psmå,
  { {0x63620016,0x61460076,0x63700c38,0x00000000}},	//   nôni, бежа, häng,
  { {0xba3a0047,0xf9920063,0xdde00078,0x00000000}},	//   װײנט, פרד_, štūn,
  { {0x63aa004c,0xb39b0013,0x68e63000,0x00000000}},	//   álně, _trýớ, iekd,
  { {0x6564007a,0x26d8001f,0x7d02007d,0x00000000}},	//   llih, nfro_, _snos,
  { {0x6da3018e,0xe8d90013,0xf2a3005e,0x00000000}},	//   пија, _nhở_, _хисп,
  { {0x6362017d,0x5bb8042c,0x63700c38,0x00000000}},	//   dôni, алия_, fäng,
  { {0x63701b58,0x7d0200c3,0x65640228,0x00000000}},	//   gäng, _vnos, ilih,
  { {0x6362017d,0x7b3901da,0x49d80086,0x00000000}},	//   fôni, lňuj, адою_,
  { {0xe8d9008b,0xbca6007e,0xfbcf007e,0x00000000}},	//   _chở_, _هماي, وتی_,
  { {0xa49b0268,0x6c860021,0x7d0214d8,0x00000000}},	//   _anòn, _الإم, _unos,
  { {0x39590037,0x26d8001f,0x7d1d4f1a,0x00000000}},	//   ross_, ffro_, össe,
  { {0x6564053b,0x569414db,0x6370004d,0x00000000}},	//   elih, зарт, nänd,
  { {0xa3cb4f1b,0x628300b2,0xd9ec0042,0x00000000}},	//   रून_, žnok, _जनित_,
  { {0x3eae051d,0x656400a4,0x6370092e,0x00000000}},	//   haft_, glih, händ,
  { {0x61ee021f,0x637000c7,0xdb1b00cd,0x00000000}},	// [9830] _asbl, känd, ctuó,
  { {0x8c1b0063,0x6b5d00c6,0x6aaa4f1c,0x00000000}},	//   אומי, lègr, _jeff,
  { {0xd370006a,0x2fc6002b,0xed690014,0x00000000}},	//   رهٔ_, euog_, nnþá_,
  { {0xe8d90013,0xddd40058,0x2ee10042,0x00000000}},	//   _khố_, _şaşk, फ़्त,
  { {0x6362017d,0xb3670062,0x6370004d,0x00000000}},	//   zôni, _гъвк, fänd,
  { {0xa2d80161,0x7bdc003b,0x6aaa4f1d,0x00000000}},	//   न्द्, ărul, _neff,
  { {0x171c0047,0x7bc04f1e,0x7b390124,0x00000000}},	//   רווע, ermu, bňuj,
  { {0x637000c7,0xa63c0063,0x752d00be,0x00000000}},	//   täng, טגור, nhaz,
  { {0x798a00bd,0x6aaa4f1f,0x637000e0,0x00000000}},	//   _aufw, _beff, bänd,
  { {0x63621f32,0x63700502,0x9dab005a,0x00000000}},	//   tôni, räng, _бъда_,
  { {0x6b9b0290,0xc8690063,0x63704f1a,0x00000000}},	//   spug, _סן_, säng,
  { {0x63700d88,0x62830024,0x6362017d,0x00000000}},	//   mäne, ľnoh, rôni,
  { {0x6d494f20,0xbf87008b,0x2904005b,0x00000000}},	//   mnea, _điển_, ıma_,
  { {0xd5b8001c,0x907a0063,0xe8d90013,0x00000000}},	//   šām_, יטרי, _thở_,
  { {0x6d49000c,0x6b8300a4,0xe5060044,0x00000000}},	//   onea, _iing, يبري,
  { {0x62950122,0x39b5003d,0x6b831acc,0x00000000}},	//   _afzo, mās_, _hing,
  { {0x6d490027,0x39b5003d,0x6564003e,0x00000000}},	// [9840] inea, lās_, rlih,
  { {0x6b834f21,0x65643a61,0x70b40053,0x00000000}},	//   _jing, slih, ुल्ल,
  { {0x63704f22,0x39b5003d,0x6b830029,0x00000000}},	//   vänd, nās_, _ming,
  { {0x8066005a,0x752d4f23,0x6b8330b0,0x00000000}},	//   овеж, chaz, _ling,
  { {0xb4e60161,0x69c100bd,0x637004c1,0x00000000}},	//   फ़ी_, hrle, tänd,
  { {0x39b5003d,0x6b834f24,0xa8570063,0x00000000}},	//   kās_, _ning, חינה_,
  { {0x39b5003d,0x272f00bd,0x637004c1,0x00000000}},	//   jās_, _fünf_, ränd,
  { {0x39b5003d,0x6d490205,0x63700502,0x00000000}},	//   dās_, gnea, sänd,
  { {0x4ae60088,0x442038bd,0x752416ae,0x00000000}},	//   оўна, nyi_, ikiz,
  { {0x6b834f25,0xa3cb0053,0x63a90058,0x00000000}},	//   _cing, रंत_, _çene,
  { {0x39b5001c,0x6aaa0026,0x6b5d0003,0x00000000}},	//   gās_, _veff, tègr,
  { {0x394d03d9,0x6b834f26,0xe8d9001b,0x00000000}},	//   ões_, _eing, _phố_,
  { {0x2d8c00c2,0x6b8340e1,0x6d404f27,0x00000000}},	//   _hude_, _fing, mima,
  { {0x44320051,0x7bd5000c,0x39b5001c,0x00000000}},	//   dzy_, ăzut, bās_,
  { {0x6d4000fe,0x39b5001c,0xdce20022,0x00000000}},	//   oima, cās_, _choć,
  { {0x6b8334c5,0x2d8c017d,0x6d404f28,0x00000000}},	//   _zing, _mude_, nima,
  { {0x69c813b4,0x6d40078c,0x98a20078,0x00000000}},	// [9850] lude, iima, eikė_,
  { {0x2d8c0122,0x69c80122,0x78ad2d47,0x00000000}},	//   _oude_, oude, _heav,
  { {0x2d8c4f29,0x7c200185,0x8c3d005b,0x00000000}},	//   _nude_, hymr, laşt,
  { {0x6d4000eb,0xdb090025,0x7c2017d5,0x00000000}},	//   jima, iseá, kymr,
  { {0x44320045,0x6d401d56,0x3eac0831,0x00000000}},	//   czy_, dima, _bedt_,
  { {0x78ad0034,0xf3ff0016,0x637000fe,0x00000000}},	//   _leav, _irã_, täne,
  { {0x6d490025,0xdb02004d,0x69c84f2a,0x00000000}},	//   tnea, _stoß, jude,
  { {0xdb1b0268,0x39b5003d,0x69c80019,0x00000000}},	//   truï, vās_, dude,
  { {0x6b8306e1,0x6d5b4f2b,0x3eac01e1,0x00000000}},	//   _ping, roua, _fedt_,
  { {0x39b5003d,0x49c91702,0x39a7013d,0x00000000}},	//   tās_, блон_, tős_,
  { {0x6b834f2c,0xc4cb0053,0x69c84f2d,0x00000000}},	//   _ving, िलाओ, gude,
  { {0x39b5003d,0x6b83077d,0x39a700ea,0x00000000}},	//   rās_, _wing, rős_,
  { {0x3f8d00cd,0x39b5001c,0x6b830520,0x00000000}},	//   _jueu_, sās_, _ting,
  { {0x39b5003d,0x6b830035,0xdb09006d,0x00000000}},	//   pās_, _uing, rreó,
  { {0xe73741db,0x8c3d003b,0x69c80955,0x00000000}},	//   чер_, raşu, cude,
  { {0x1a65006a,0x78ad0122,0x49ba014e,0x00000000}},	//   _ویکی_, _geav, _המקס,
  { {0x4426001b,0x636b004b,0x394240d5,0x00000000}},	// [9860] áo_, rünn, miks_,
  { {0x44321e13,0x6d404f2e,0x39424f2f,0x00000000}},	//   rzy_, zima, liks_,
  { {0x68f601f7,0x44320045,0x672100c7,0x00000000}},	//   _kayd, szy_, ölje,
  { {0x66010146,0x39424f30,0x7d190051,0x00000000}},	//   ælke, niks_, _nows,
  { {0x6d4000eb,0xf3ff0016,0x69c8004d,0x00000000}},	//   vima, _grã_, zude,
  { {0x39420019,0x2d8c0460,0xdef3000d,0x00000000}},	//   hiks_, _pude_, епшы,
  { {0x10a60079,0x7ae807e6,0x63b64f31,0x00000000}},	//   _нивн, vedt, lsyn,
  { {0x69c82726,0x2cea0086,0x1d07005e,0x00000000}},	//   vude, сько_, зећи_,
  { {0x7bc90164,0x7c93007e,0x3942004b,0x00000000}},	//   gueu, رشيا, diks_,
  { {0xab970021,0x6d404f32,0x69c84f33,0x00000000}},	//   أخير_, sima, tude,
  { {0x78ad0004,0x7ae84f34,0x69c80ff2,0x00000000}},	//   _peav, redt, uude,
  { {0xdb090027,0x63b600fe,0x39420019,0x00000000}},	//   rseá, ksyn, giks_,
  { {0x69c84f35,0x7ae8013d,0x07a40085,0x00000000}},	//   sude, pedt, наўн,
  { {0x63b64f36,0xdb090025,0x3942008f,0x00000000}},	//   dsyn, pseá, aiks_,
  { {0x78ad0004,0x68f6005b,0x39421013,0x00000000}},	//   _teav, _fayd, biks_,
  { {0x661a078c,0x272f1013,0x9a670044,0x00000000}},	//   ätka, _sünd_, _عميل_,
  { {0xdcfa001c,0xe454000d,0x88bc0063,0x00000000}},	// [9870] _attī, екты, _המחז,
  { {0x6f1a00e5,0xc7b2009a,0x940400de,0x00000000}},	//   _notc, _שבי_, عوله,
  { {0xa3b90042,0x81c70121,0x68f60075,0x00000000}},	//   _घटक_, ящае, _yayd,
  { {0x3f854f37,0xf8bf0042,0x5274005d,0x00000000}},	//   _silu_, ्लिय, رالز,
  { {0x9f350086,0x636b005b,0xb97c0047,0x00000000}},	//   меді, lünm, צנדי,
  { {0xdb1b1088,0x7afd008f,0x8237005d,0x00000000}},	//   truí, ēstk, _فرزا,
  { {0x7d190045,0x272f005b,0xb87b0014,0x00000000}},	//   _pows, _güne_, lfíd,
  { {0x3b95000a,0xe8d9008b,0x7bc90003,0x00000000}},	//   мјот, _khổ_, tueu,
  { {0x39424f38,0xab5d0022,0x4034005e,0x00000000}},	//   viks_, erża, _зетс,
  { {0x68f60058,0x80d90042,0x636b0075,0x00000000}},	//   _sayd, फ्रे, künm,
  { {0x394220ae,0xdb20013d,0x1dc60042,0x00000000}},	//   tiks_, ótáj, रूआत,
  { {0x186a0156,0xdb090331,0x7f432a42,0x00000000}},	//   жами_, rreñ, linq,
  { {0x39420019,0x636b005b,0x7bc91932,0x00000000}},	//   riks_, tünl, queu,
  { {0x39420019,0x7c2600d1,0x59c50042,0x00000000}},	//   siks_, økre, _विपर,
  { {0x212d014f,0x63700137,0xb956005e,0x00000000}},	//   _oleh_, jäna, _отић,
  { {0xa5070854,0x63b64f39,0x24f504d6,0x00000000}},	//   меса_, tsyn, нчур,
  { {0xe8d90013,0x61e9007d,0xd4670d4c,0x00000000}},	// [9880] _chổ_, _ćela, дите_,
  { {0x63b64f3a,0xdb0900b9,0xd5b1008b,0x00000000}},	//   rsyn, sseæ, ớp_,
  { {0x6f1a0b13,0x7bdc003b,0x63b64f3b,0x00000000}},	//   _rotc, ărui, ssyn,
  { {0x98b9000c,0xd046007e,0xdb0900be,0x00000000}},	//   misă_, وپاي, bseç,
  { {0x6f1a4f3c,0x7c2d0022,0xdb24013d,0x00000000}},	//   _potc, _żarn, _ősít,
  { {0x2d86001f,0x6e23002b,0xdd9a01f6,0x00000000}},	//   _sioe_, fynb, оши_,
  { {0xdd900021,0x66e00042,0xe297167b,0x00000000}},	//   دوب_, ख्यक_, _цас_,
  { {0xe73f017d,0x7bc70078,0x91e3130d,0x00000000}},	//   mpõe_, ąjun, _шосе,
  { {0x98b9000c,0x6f930044,0x636b0075,0x00000000}},	//   hisă_, _للقض, zünm,
  { {0x39400164,0x7f430290,0x7e970021,0x00000000}},	//   _amis_, cinq, _ينقر_,
  { {0x8c18007e,0x28f90500,0xbebc008f,0x00000000}},	//   زيگر_, пень_, _blīv,
  { {0x9c260002,0x0c2612b9,0x25480058,0x00000000}},	//   _одед, _омен, oğlu_,
  { {0x1bf20053,0xd7f812a5,0xcaf30043,0x00000000}},	//   _अनिल_, мур_, رسیب,
  { {0xf53f04b1,0x39930016,0x3940003b,0x00000000}},	//   _små_, _fãs_, _emis_,
  { {0x66f40062,0x5694231a,0xa5f841be,0x00000000}},	//   ъпру, таст, меру_,
  { {0x636b01f7,0xe8d9008b,0x2fc600c2,0x00000000}},	//   rünm, _phổ_, krog_,
  { {0xa3c6016a,0x57f4000d,0x7e6805a5,0x00000000}},	// [9890] ईंग_, _апыт, _lydp,
  { {0xa3cb024c,0x2d9e00b9,0x026b0156,0x00000000}},	//   रूष_, _otte_, ошей_,
  { {0x69cf0051,0x69da2841,0x98b9003b,0x00000000}},	//   ąceg, ntte, cisă_,
  { {0x69da09ff,0xe8d9008b,0x69c700c2,0x00000000}},	//   itte, _thổ_, šjeg,
  { {0x637003be,0x2d9e01f4,0xdb090838,0x00000000}},	//   männ, _atte_, lseå,
  { {0x7af84f3d,0x98a50078,0x63700ef1,0x00000000}},	//   _navt, ėlę_, länn,
  { {0xa3cb0235,0x62830024,0x212d00c2,0x00000000}},	//   रूर_, ľnos, _tleh_,
  { {0x62831625,0x2fc64f3e,0x98a0007d,0x00000000}},	//   žnos, brog_, _ilić_,
  { {0x2d9e490a,0x5e59007e,0x8b250062,0x00000000}},	//   _ette_, _کلاس_, едпе,
  { {0x69da16c2,0x6d5c0046,0x8c9f0042,0x00000000}},	//   ftte, _íran, _ग्रो,
  { {0x637000c7,0xb06200fe,0x3869005b,0x00000000}},	//   känn, _ääri, _ayar_,
  { {0x38690147,0x20140051,0x63700072,0x00000000}},	//   _byar_, ścił_, jänn,
  { {0xdb0b08a9,0x636b46bb,0x63700072,0x00000000}},	//   _avgå, günk, dänn,
  { {0x61f500ea,0x7bdb0026,0xdb1b18a8,0x00000000}},	//   _oszl, mtuu, bruá,
  { {0x672100c7,0x6600001c,0x7bdb4f3f,0x00000000}},	//   ölja, āmko, ltuu,
  { {0x98b9003b,0x2a3a009a,0x386d056c,0x00000000}},	//   risă_, _מעצמ, żera_,
  { {0x7bdb2a3f,0xf2a60062,0x8cd70042,0x00000000}},	// [98a0] ntuu, еизп, _यानो,
  { {0x7bdb0072,0xb4630062,0x42561b5f,0x00000000}},	//   ituu, укул, нтет,
  { {0xf8bf0164,0xe8d9008b,0x7bdb00fe,0x00000000}},	//   chés_, _chỗ_, htuu,
  { {0x7bdb4f40,0xa99a0047,0x2257007e,0x00000000}},	//   ktuu, לבער, رلند_,
  { {0xe73f017d,0x251b0047,0x351b0047,0x00000000}},	//   spõe_, _זוכא, _זוכנ,
  { {0x69da02ab,0x63a44f41,0x2fc600f1,0x00000000}},	//   ytte, mpin, rrog_,
  { {0x63a40498,0x68e41c0d,0x4ea50086,0x00000000}},	//   lpin, _obid, тріа,
  { {0x2fc60146,0x63a43846,0x98a90605,0x00000000}},	//   prog_, opin, _plač_,
  { {0x27340137,0x7bdb13b0,0xb87b16eb,0x00000000}},	//   _känd_, gtuu, ifíc,
  { {0x7e6800e8,0x30750bb3,0x20190268,0x00000000}},	//   _tydp, _русс, _àsia_,
  { {0xc3334f42,0x2d9e0290,0x7bdb0983,0x00000000}},	//   רות_, _utte_, atuu,
  { {0x98a90024,0xf795000d,0x69da4f43,0x00000000}},	//   _tlač_, камэ, rtte,
  { {0x7bdb02b0,0x63704f44,0x628e006f,0x00000000}},	//   ctuu, jäno, _ogbo,
  { {0x999e00ea,0x636b00ea,0x61330058,0x00000000}},	//   sztő_, rünk, _içle,
  { {0x637000fe,0x7d0b130e,0x63a44e90,0x00000000}},	//   tänn, _yngs, epin,
  { {0x59c50161,0x636b005b,0x629c4f45,0x00000000}},	//   _वितर, müni, _afro,
  { {0x63a4002c,0x38690058,0xd5540062,0x00000000}},	// [98b0] gpin, _uyar_, уктъ,
  { {0x69c802b0,0x637000fe,0x68fd2e58,0x00000000}},	//   orde, sänn, ldsd,
  { {0x2004051e,0xd2510032,0x0635018e,0x00000000}},	//   _armi_, جنا_, _ренџ,
  { {0x69c8000f,0x25ba0063,0x629c001f,0x00000000}},	//   irde, _קצרמ, _efro,
  { {0x656d014f,0x69c800bd,0x68fd0104,0x00000000}},	//   mlah, hrde, idsd,
  { {0x656d4f46,0xd006019c,0x66050605,0x00000000}},	//   llah, теше_, _krhk,
  { {0xb3540699,0x8265005d,0xed59208c,0x00000000}},	//   _скрш, _شهرن, мок_,
  { {0x7bdb00fe,0x68fd1244,0x27340137,0x00000000}},	//   ttuu, jdsd, _täng_,
  { {0x7f95011c,0x69c83bd3,0x656d0058,0x00000000}},	//   _разх, erde, ilah,
  { {0xeab10021,0xdde3013d,0x2bc20042,0x00000000}},	//   جعة_, űrők, _शिरा,
  { {0x7bdb4f47,0x2fcf04aa,0x656d36b8,0x00000000}},	//   stuu, lugg_, klah,
  { {0x672100c7,0x63a43e7e,0xdb090331,0x00000000}},	//   öljn, ypin, nseú,
  { {0xf8bf0080,0x69c84f48,0x3f8b0003,0x00000000}},	//   ckém_, arde, _écus_,
  { {0x7bdc003b,0x656d07b7,0x07a337f5,0x00000000}},	//   ărut, elah, рарн,
  { {0x63bd01e3,0xa3d4016a,0x9a690021,0x00000000}},	//   _avsn, सून_, _تمثل_,
  { {0x7afd001c,0x656d1120,0x27340137,0x00000000}},	//   ēstu, glah, _sänd_,
  { {0xb87b14b1,0xc2b6005e,0x7bc92667,0x00000000}},	// [98c0] rfíc, вљењ, nreu,
  { {0x63a44f49,0x577a0021,0x1877009d,0x00000000}},	//   rpin, _تصبح_, _בעפר_,
  { {0x63a44f4a,0x27340137,0x35a60a29,0x00000000}},	//   spin, _vänd_, _шанг,
  { {0xd5b8003d,0x7bc9004d,0x63a4331c,0x00000000}},	//   šās_, kreu, ppin,
  { {0x65640072,0x273400a5,0xb4c00042,0x00000000}},	//   moih, _tänd_, ीली_,
  { {0x8fa30001,0x2c6c0025,0xb87b006d,0x00000000}},	//   шаље, hódú_, nfía,
  { {0xe1f70076,0x2eee4f4b,0x41aa0454,0x00000000}},	//   _игр_, reff_, _іван_,
  { {0xed570540,0x656400fe,0x7bc9166b,0x00000000}},	//   кој_, noih, freu,
  { {0x9f4d02dd,0x69c8002b,0x7bc94f4c,0x00000000}},	//   _creó_, wrde, greu,
  { {0x69c8007d,0x2905008f,0x1ec70131,0x00000000}},	//   trde, ēlam_, _алфи_,
  { {0x27e94c1b,0x637000c7,0xf8bf0080,0x00000000}},	//   _span_, vänl, ském_,
  { {0xf8bf00ea,0x7bc94539,0x91bb0063,0x00000000}},	//   mkék_, breu, ומטי,
  { {0x272f004d,0x7bc9271a,0xc7c70062,0x00000000}},	//   _dünn_, creu, ъсни,
  { {0xcf930149,0x2c37089e,0xaa580054,0x00000000}},	//   יטש_, _שָׁם_, _пилу_,
  { {0xcb670001,0x80d30053,0xb87b1358,0x00000000}},	//   _шаље_, _डाले, teís,
  { {0xdb1b0016,0x3dfb0047,0x3f8c004c,0x00000000}},	//   truç, וללד, _lidu_,
  { {0x656d053b,0xa9580063,0x63700072,0x00000000}},	// [98d0] rlah, _שיחק_, mänj,
  { {0x656d0dbb,0x43040086,0x764e00ea,0x00000000}},	//   slah, иїха, ányá,
  { {0x6728087b,0xc692009a,0xb147005d,0x00000000}},	//   ödje, _לאי_, نیسم_,
  { {0xd5b1008b,0x7bc90496,0x4155082d,0x00000000}},	//   ấu_, yreu, ывес,
  { {0xdce90075,0x4fc401ce,0xef0e4f4d,0x00000000}},	//   emeğ, асја, бм_,
  { {0x543a00b5,0x7bc90edc,0x61e10137,0x00000000}},	//   _טערא, vreu, _ällo,
  { {0x44294f4e,0x3f8c0150,0x9f46004d,0x00000000}},	//   lya_, _didu_, stoß_,
  { {0x9f4d0290,0x7bc94f4f,0xc10500de,0x00000000}},	//   _creò_, treu, _حوري,
  { {0xa0550088,0x7bc90164,0x44290859,0x00000000}},	//   _сваі, ureu, nya_,
  { {0x7bc94f50,0x442900a4,0x89a91585,0x00000000}},	//   rreu, iya_, нков_,
  { {0x65640035,0x4429059e,0x5cd500f2,0x00000000}},	//   yoih, hya_, _مقاط,
  { {0x7bc9000c,0x89360021,0x798d0150,0x00000000}},	//   preu, اعدا, _ciaw,
  { {0x59c50161,0x752d004a,0x31560047,0x00000000}},	//   _विवर, dkaz, רירן_,
  { {0x44294f51,0x3cff004b,0xa03a0047,0x00000000}},	//   dya_, lduv_, געשפ,
  { {0x442901f7,0xceb20132,0x656400fe,0x00000000}},	//   eya_, מים_, toih,
  { {0x44294f52,0x69dc00cd,0x3cff004b,0x00000000}},	//   fya_, àree, nduv_,
  { {0x6b8d0025,0xeb960047,0x7c29036c,0x00000000}},	// [98e0] _éags, ָדער_, nyer,
  { {0x7d1b0004,0x57fb0063,0x752d01f0,0x00000000}},	//   hjus, _טלפו, akaz,
  { {0xd5b1001b,0x637000c7,0xf772007e,0x00000000}},	//   ất_, länk, _پاک_,
  { {0x44294f53,0xa3d40042,0xc329009a,0x00000000}},	//   bya_, संद_, הו_,
  { {0x78b60058,0x3f8c004b,0xe8070053,0x00000000}},	//   _meyv, _pidu_, शिया_,
  { {0x7d1b34fb,0x00000000,0x00000000,0x00000000}},	//   ejus,   ,   ,
  { {0x3d8a0076,0x7afe0460,0x316c001c,0x00000000}},	//   нщин_, _ópti, _ūdzu_,
  { {0x867b00b5,0x7c3b004d,0x7d1b0137,0x00000000}},	//   ערקו, fzur, gjus,
  { {0xdce2007d,0x8afc0022,0x63700050,0x00000000}},	//   _ukoč, klęt, jänk,
  { {0x798d002b,0xb4db01a8,0xef831527,0x00000000}},	//   _siaw, _amàl, _глуп,
  { {0x6e930032,0x5e930032,0x798d1472,0x00000000}},	//   _الما, _المط, _piaw,
  { {0x7c29002c,0xe8d9008b,0x286b02a1,0x00000000}},	//   byer, _khứ_, ерго_,
  { {0x386d00b9,0xac970021,0xab2a20e5,0x00000000}},	//   æer_, _إنها_, _пода_,
  { {0x7bfb0063,0x4aba0062,0x44294f54,0x00000000}},	//   _נפוצ, _чудя_, vya_,
  { {0x63700bb7,0x4429002b,0x752d007d,0x00000000}},	//   mänh, wya_, tkaz,
  { {0x6aba000f,0x63704f55,0xdb000989,0x00000000}},	//   latf, bänk, gsmö,
  { {0xb8f90235,0x29270051,0x44290e1a,0x00000000}},	// [98f0] ाल_, ętać_, uya_,
  { {0x752d046c,0xdce904e9,0x442903f9,0x00000000}},	//   skaz, vleč, rya_,
  { {0xdce9017f,0x7c3b0290,0x32070114,0x00000000}},	//   zmeđ, zzur, íny_,
  { {0x442926b2,0x394b4f56,0xbebc008f,0x00000000}},	//   pya_, nics_, _slīp,
  { {0xe8d9008b,0xa2950086,0x6aba0119,0x00000000}},	//   _chứ_, _вагі, katf,
  { {0x394b0969,0x00000000,0x00000000,0x00000000}},	//   hics_,   ,   ,
  { {0xf204005a,0x6d494f57,0xad590062,0x00000000}},	//   _лято, tiea, крих_,
  { {0xdce90078,0x661a0072,0xfbc50239,0x00000000}},	//   pleč, ätki, абио,
  { {0x75ec000f,0x394b368c,0xec79005a,0x00000000}},	//   _közö, dics_, ъпи_,
  { {0xef67005a,0xbbe8007e,0x7d1b4f58,0x00000000}},	//   _събо, اريم_, sjus,
  { {0x394b368c,0x7c2900a4,0x7c3b3db1,0x00000000}},	//   fics_, syer, szur,
  { {0x637000c7,0x394b0295,0xb87b0046,0x00000000}},	//   tänk, gics_, rfín,
  { {0x2ba7005e,0x2cad4f59,0x5ba73f17,0x00000000}},	//   _сјев, mbed_, _срез,
  { {0x63700c38,0x69950054,0xfaa53df9,0x00000000}},	//   ränk, _крих, _тако,
  { {0x2956011c,0x60db4f5a,0x366a1849,0x00000000}},	//   _въпр, _ocum, таво_,
  { {0x636b4f5b,0x6370092e,0x2cad002b,0x00000000}},	//   zünt, mäni, nbed_,
  { {0xdb000b68,0x93464f5c,0xe29a06c9,0x00000000}},	// [9900] rsmö, анае, ваз_,
  { {0x2d8f0388,0x60db4622,0x290004a5,0x00000000}},	//   _lige_, _acum, _haia_,
  { {0x4add0053,0x80a6002a,0xaadd0042,0x00000000}},	//   _मानव, لمان, _मानक,
  { {0xdfa600d7,0x7a7a0047,0xcfa601f6,0x00000000}},	//   ајко, דרעס, ашки,
  { {0xdefa0055,0x636b2440,0x2fc000ea,0x00000000}},	//   вый_, güns, éig_,
  { {0x2d8f0027,0xeea7005a,0x26d84f5d,0x00000000}},	//   _aige_, атък_, ngro_,
  { {0x636b01f7,0x637000fe,0x2dd70021,0x00000000}},	//   rünt, jäni, لبية_,
  { {0xe8d9001b,0x6e2a00ac,0x60db0025,0x00000000}},	//   _thứ_, ryfb, _gcum,
  { {0x61e9017f,0xdb0a007e,0x61330058,0x00000000}},	//   _ćeli, نزده_, _uçla,
  { {0x7bc60078,0x29020066,0x69cf0022,0x00000000}},	//   škuo, edka_, ącen,
  { {0x2cad0034,0x2bc20053,0x29004f5e,0x00000000}},	//   bbed_, _शिका, _baia_,
  { {0x38c9007e,0x29004f5f,0xdd8f002a,0x00000000}},	//   دادی_, _caia_, _قول_,
  { {0x29050080,0x2d8400ac,0x394b4f60,0x00000000}},	//   ěla_, mmme_, rics_,
  { {0x28a70161,0x394b4f61,0x29050051,0x00000000}},	//   _क्रि, sics_, śla_,
  { {0x394b4f62,0x6893007e,0x2d844f63,0x00000000}},	//   pics_, _ویدئ, omme_,
  { {0xef190051,0x29004f64,0x52af0042,0x00000000}},	//   _duży_, _gaia_, टर्स,
  { {0x44980076,0x2d840bb7,0x78bd0014,0x00000000}},	// [9910] рвую_, imme_, masv,
  { {0x27340019,0x60db4f65,0x63a20025,0x00000000}},	//   _täna_, _scum, íona,
  { {0xa2dd0161,0x636b00bd,0xa2940086,0x00000000}},	//   _पाठ्, wüns, іаці,
  { {0x7bc00006,0x30150156,0x8144005d,0x00000000}},	//   ksmu, йдер, يپلم,
  { {0x2d8f4f66,0x8387014c,0x7bc20003,0x00000000}},	//   _rige_, _выве, _nvou,
  { {0x2d8f4f67,0x7bdf004d,0xb3640062,0x00000000}},	//   _sige_, _äqui, _дъск,
  { {0x7bc20164,0x2d8f00b9,0xf15906f0,0x00000000}},	//   _avou, _pige_, _бивш_,
  { {0x28a70053,0xf6580063,0x067c0063,0x00000000}},	//   _क्लि, יסוי_, כנול,
  { {0x29000035,0x2cad0898,0x2d8f4f68,0x00000000}},	//   _raia_, rbed_, _vige_,
  { {0x7de7019d,0xada40024,0x2d8400fe,0x00000000}},	//   _відд, _spĺň, amme_,
  { {0xe8d9001b,0x290001f4,0x2d8f1db5,0x00000000}},	//   _chữ_, _paia_, _tige_,
  { {0x7c950021,0x6d950124,0x78bd0014,0x00000000}},	//   _الإص, _všad, gasv,
  { {0x6c850032,0xfc670062,0x6f011286,0x00000000}},	//   _الشم, _тъжн, _kalc,
  { {0x39490397,0x6d500022,0x46a30085,0x00000000}},	//   _emas_, ądał, зарв,
  { {0x5b7a014e,0xd5b1001b,0xf7430091,0x00000000}},	//   _גרסא, ấp_, черо,
  { {0x1543005e,0x66d1013d,0x580600de,0x00000000}},	//   песм, tókü, _هوبك,
  { {0x69c139a7,0xd4690021,0xdb9a0041,0x00000000}},	// [9920] lsle, لحكم_, ָסער,
  { {0x63700137,0x69c14f69,0xa2dd0042,0x00000000}},	//   hänv, osle, _पाण्,
  { {0x2d8404e1,0xdb090025,0x69c131b3,0x00000000}},	//   ymme_, lseó, nsle,
  { {0x7bc00072,0x69c14f6a,0x661a078c,0x00000000}},	//   ysmu, isle, ätku,
  { {0x987a00b5,0x601809b3,0xa87a0047,0x00000000}},	//   װאַט, роля_, װאַר,
  { {0x02d50062,0xdce0001c,0xc7b30063,0x00000000}},	//   _мюсю, domā, לבד_,
  { {0x20060072,0xddea0021,0x10a60121,0x00000000}},	//   svoi_, ارته_, _гибн,
  { {0x7bc60006,0x69c107e4,0x5c980062,0x00000000}},	//   škum, dsle, шкия_,
  { {0x6f014f6b,0x251b0063,0x7bc006f8,0x00000000}},	//   _falc, רופא, usmu,
  { {0x7bc00078,0x93fb009f,0x25a600a8,0x00000000}},	//   rsmu, נליי, _čoln_,
  { {0x69c14f6c,0x99520080,0xb4c80053,0x00000000}},	//   gsle, lář_, _ईयू_,
  { {0x48ab007f,0x7d1d004d,0x7603013d,0x00000000}},	//   ытом_, össt, hízá,
  { {0xc8671087,0x672500fe,0x69c306a5,0x00000000}},	//   стни, _pohj, _evne,
  { {0x69c1164d,0x78bd008f,0x7bdb0041,0x00000000}},	//   bsle, sasv, _עקוו,
  { {0x9577007e,0x63a20139,0x9952004c,0x00000000}},	//   مدرض, íonn, hář_,
  { {0x3949017d,0x55750086,0xe8d90013,0x00000000}},	//   _umas_, ігат, _khử_,
  { {0x2418014c,0x68ed28bb,0x9952004c,0x00000000}},	// [9930] боты_, _ibad, jář_,
  { {0x2b110053,0x7d024f6d,0xe3b00044,0x00000000}},	//   ़ाएँ_, _laos, عرق_,
  { {0x3495000d,0xd0950121,0x90994218,0x00000000}},	//   _манр, ошлы, авет_,
  { {0x6f014f6e,0x7ff5005d,0x82340044,0x00000000}},	//   _salc, قستا, أركا,
  { {0x6754007e,0xa0690259,0xe04b007e,0x00000000}},	//   _ذخیر, јала_, دشاه_,
  { {0x7a3f00ea,0xc7d80063,0x63ad4f6f,0x00000000}},	//   _játé, מודי_, mpan,
  { {0x63ad4f70,0x0d850076,0x26dc0041,0x00000000}},	//   lpan, олкн, אקומ,
  { {0xdce0003d,0x6f010051,0x69c70080,0x00000000}},	//   tomā, _walc, ájem,
  { {0xeb990001,0x69c106b8,0x63ad4f71,0x00000000}},	//   јио_, wsle, npan,
  { {0x7c260137,0x200d017d,0x68ed4f72,0x00000000}},	//   äkra, _irei_, _abad,
  { {0x61e50034,0x8d74007e,0x69c1004d,0x00000000}},	//   nthl, _کالا, usle,
  { {0x69c11607,0xa96a05c5,0xa88a0062,0x00000000}},	//   rsle, рима_, ийна_,
  { {0x63ad006f,0x69c14f73,0xec6e0200,0x00000000}},	//   jpan, ssle, _цп_,
  { {0x69c102ab,0x68ed4f74,0xf746005e,0x00000000}},	//   psle, _ebad, цего,
  { {0x63ad4f75,0x60c91f26,0x66034f76,0x00000000}},	//   epan, _odem, мпра,
  { {0x200d003b,0x2cbf14a4,0x05560085,0x00000000}},	//   _orei_, naud_, ітвя,
  { {0x63ad4b1a,0xccf212cd,0x63700137,0x00000000}},	// [9940] gpan, וכן_, känt,
  { {0x60c9048e,0x63700072,0x9952004c,0x00000000}},	//   _adem, jänt, vář_,
  { {0xdb09006d,0xf8bf0003,0x63ad4f77,0x00000000}},	//   nseñ, ckés_, apan,
  { {0xbfaa0001,0x200d083f,0xdb090331,0x00000000}},	//   атке_, _brei_, iseñ,
  { {0x200d4f78,0xf1aa007e,0x6561013d,0x00000000}},	//   _crei_, _چاره_, élhe,
  { {0x200d0199,0x73f900b5,0x60c9005b,0x00000000}},	//   _drei_, _פּרו, _edem,
  { {0x6449007a,0x99520080,0xdd97000d,0x00000000}},	//   _þeir, sář_, ошы_,
  { {0x253700b5,0xe0d70086,0x200d4f79,0x00000000}},	//   ַניש_, _мвс_, _frei_,
  { {0x853b0047,0x200d4f7a,0xee94005d,0x00000000}},	//   יגקי, _grei_, _فداک,
  { {0xba0a005a,0x7d020035,0x6370086f,0x00000000}},	//   ахме_, _waos, mäns,
  { {0x2cbf006c,0xdcfa008f,0xdb0e013d,0x00000000}},	//   baud_, _jutī, _újít,
  { {0xe8d9001b,0x63ad4f7b,0xe8070082,0x00000000}},	//   _thử_, ypan, शिला_,
  { {0x87070062,0x63700072,0xb89a004c,0x00000000}},	//   ояве, näns, _šťáv,
  { {0x61e5002b,0xcc77009a,0xdbf80082,0x00000000}},	//   ythl, _ועדה_, ्टीड_,
  { {0xda6f0086,0xbb83007e,0xda66007e,0x00000000}},	//   _ця_, _تلوي, _باشي,
  { {0x2905001c,0x68ed0ab2,0xa6340054,0x00000000}},	//   ēlas_, _ubad, єнті,
  { {0x637000c7,0x63ad4f7c,0x73390054,0x00000000}},	// [9950] jäns, upan, бзар_,
  { {0xc7b20ca4,0x63ad4f7d,0xd37108aa,0x00000000}},	//   _רבי_, rpan, رها_,
  { {0x63700c16,0x877c0047,0xdb000137,0x00000000}},	//   vänt, _דאזי, mpmä,
  { {0xc0cb005e,0x200d4f7e,0x26080042,0x00000000}},	//   руже_, _prei_, हिरी_,
  { {0x251a0063,0x637000fe,0xbea51ce7,0x00000000}},	//   _הורא, tänt, палк,
  { {0x70520032,0xe3b200b5,0x200d000c,0x00000000}},	//   عنوا, _אױך_, _vrei_,
  { {0x31c400e1,0x439421e8,0x6da21406,0x00000000}},	//   _оств, _царс, нища,
  { {0x200d000c,0x63700072,0x60c908f3,0x00000000}},	//   _trei_, sänt, _udem,
  { {0xdb1b017d,0xdb090026,0x63700137,0x00000000}},	//   ssuí, fseð, mänr,
  { {0x0b420088,0x539c0041,0x4a450f50,0x00000000}},	//   еньн, בסזא, знов,
  { {0xc8690047,0xce380021,0x2cbf006c,0x00000000}},	//   _ען_, _وأما_, paud_,
  { {0x6d4b1a6c,0xd7f10013,0x29040046,0x00000000}},	//   _umga, ẵn_, þma_,
  { {0x4c9a009a,0x17fa0044,0x2c09005d,0x00000000}},	//   _הבנו, حرجة_, _دعای_,
  { {0x63a20139,0xdbc6004b,0xaa4501d5,0x00000000}},	//   íonm, tööj, _нелл,
  { {0x06830002,0x2aba009a,0x4b36009a,0x00000000}},	//   егрн, _המצא, _מרסל_,
  { {0xe9a803eb,0xccf90051,0x6d5b42cf,0x00000000}},	//   _بدون_, neś_, nnua,
  { {0xade2016a,0x68fb0019,0xf9930063,0x00000000}},	// [9960] _गमभन_, õude, _ארה_,
  { {0x6d5b0025,0xe8d90013,0x63700072,0x00000000}},	//   hnua, _thợ_, väns,
  { {0x273401e3,0xa2dd0161,0xa69b0063,0x00000000}},	//   _länk_, _पार्, _לשיפ,
  { {0x2367007d,0x63700d90,0x79b6009d,0x00000000}},	//   čnja_, täns, פלנד_,
  { {0x21670a74,0x6b83004d,0xa193012c,0x00000000}},	//   чици_, _ohng, хаїч,
  { {0x637001e3,0x4393000d,0x62010072,0x00000000}},	//   räns, _паўс, äylä,
  { {0xde930001,0x44320072,0xa3c60053,0x00000000}},	//   нашњ, lyy_, ैंक_,
  { {0xc5f300ff,0xdce00078,0x75240130,0x00000000}},	//   גדה_, komą, njiz,
  { {0x4e96007e,0x44204f7f,0xe8d9008d,0x00000000}},	//   _فشار, nxi_, _nhỡ_,
  { {0x44200268,0xa03b00b5,0xbec2001c,0x00000000}},	//   ixi_, _הײמז, šība,
  { {0x6d950006,0x75240089,0xdb090046,0x00000000}},	//   _išan, kjiz, rseð,
  { {0x443200fe,0x395f0019,0x60c20035,0x00000000}},	//   kyy_, õus_, naom,
  { {0x2fc60014,0xd8380085,0xfc2f043e,0x00000000}},	//   nsog_, пэр_, _محو_,
  { {0x2d53003b,0xaae6005d,0x2c17009a,0x00000000}},	//   mţea_, _رستو, _מקדש_,
  { {0x7afa4f80,0x6d400089,0x25ba002b,0x00000000}},	//   mett, ohma, _cwpl_,
  { {0xb4d70235,0x3ebe4f81,0x60c20019,0x00000000}},	//   सले_, _lett_, jaom,
  { {0x6d4a008b,0xb4db00cd,0xdb000504,0x00000000}},	// [9970] _đoá, _llàg, ppmä,
  { {0x21fe0080,0x3ebe4f82,0x7afa4f83,0x00000000}},	//   _bůh_, _nett_, nett,
  { {0x26c300c3,0x6d400509,0x69da0712,0x00000000}},	//   majo_, khma, nute,
  { {0x7afa0f22,0x26c300c3,0x69da0019,0x00000000}},	//   hett, lajo_, iute,
  { {0x3ebe0ae2,0x7afa4f84,0x2d9e017c,0x00000000}},	//   _bett_, kett, _aute_,
  { {0x7afa4f85,0x26c300c2,0x6d5e0003,0x00000000}},	//   jett, najo_, épan,
  { {0x4177006a,0x69da4f86,0x27340137,0x00000000}},	//   _فارس, jute, _sänk_,
  { {0x26c300c2,0x69da112c,0x9294000d,0x00000000}},	//   hajo_, dute, _часц,
  { {0x7afa02f6,0x26c300c3,0x6f65007e,0x00000000}},	//   fett, kajo_, _قهرم,
  { {0x26c30198,0x7afa4f87,0x6fd20161,0x00000000}},	//   jajo_, gett, _सितं,
  { {0x26c300c3,0x2d9e00bd,0x753d0051,0x00000000}},	//   dajo_, _gute_, _olsz,
  { {0x273400c7,0x6d404f88,0x7afa01cf,0x00000000}},	//   _tänk_, chma, aett,
  { {0xf8bf00ea,0x69da4f89,0x7d091871,0x00000000}},	//   rkép_, aute, mdes,
  { {0x7afa3d2a,0x26c300c3,0xdb0b00c7,0x00000000}},	//   cett, gajo_, _avgö,
  { {0x55e30b3f,0x64a6000d,0x69da02a0,0x00000000}},	//   корб, даба, cute,
  { {0x443200fe,0xe3ba2254,0x442001a8,0x00000000}},	//   tyy_, жба_, txi_,
  { {0x26c3048e,0x7306000d,0x8c3d003b,0x00000000}},	// [9980] bajo_, мпаз, icşo,
  { {0x32110080,0x7d0900fe,0x2b160053,0x00000000}},	//   _brzy_, hdes, ताएँ_,
  { {0x00e6019d,0x3ebe1609,0x443200fe,0x00000000}},	//   джен, _rett_, syy_,
  { {0x3ebe2746,0x3cf90053,0x3f850150,0x00000000}},	//   _sett_, ्यों_, _ahlu_,
  { {0x2d9e000c,0x7d091a8d,0x48e30053,0x00000000}},	//   _sute_, ddes, ट्टो_,
  { {0x4375019d,0x69da00a4,0x7d090fea,0x00000000}},	//   _зуст, yute, edes,
  { {0x68e40016,0x7afa4f8a,0x7d090229,0x00000000}},	//   _ocid, vett, fdes,
  { {0x26c300c3,0x1d070001,0x69da0659,0x00000000}},	//   zajo_, дећи_, vute,
  { {0x7afa4f8b,0x3ebe4f8c,0x3ed60044,0x00000000}},	//   tett, _tett_, _يقرر,
  { {0x2004005b,0x6d404f8d,0xcb670d34,0x00000000}},	//   _ismi_, shma, мање_,
  { {0x7afa31d4,0x26c300c3,0x2d9e0019,0x00000000}},	//   rett, vajo_, _uute_,
  { {0x7afa4f8e,0x69da4f8f,0x60c00d18,0x00000000}},	//   sett, rute, _jemm,
  { {0x8b26000a,0x7afa4f90,0xb9070053,0x00000000}},	//   _одде, pett, _पा_,
  { {0x69da4f91,0xab770021,0x60c03f2f,0x00000000}},	//   pute, _قمنا_, _lemm,
  { {0x26c30198,0xf794000d,0xe5c405d2,0x00000000}},	//   rajo_, тарэ, ксто,
  { {0x60c04f92,0xab5d0051,0x20044f93,0x00000000}},	//   _nemm, duży, _osmi_,
  { {0x26c300c3,0xc2cb0021,0x69c82e58,0x00000000}},	// [9990] pajo_, قبال_, lsde,
  { {0x32110045,0xd37b0088,0xdb09017d,0x00000000}},	//   _przy_, іча_, mpeã,
  { {0xd25b0597,0xe8d9001b,0x7d09024a,0x00000000}},	//   цца_, _chủ_, ydes,
  { {0x69c809fe,0x6b980203,0x59df0042,0x00000000}},	//   isde, _livg, पंतर,
  { {0xf4090021,0x7d094f94,0x2eee1475,0x00000000}},	//   _عيسى_, vdes, ffff_,
  { {0x32110051,0x84160047,0x26c10114,0x00000000}},	//   _trzy_, _אַלף_, _jeho_,
  { {0x60c0247a,0xd0d5005a,0x7d0900c2,0x00000000}},	//   _femm, _повъ, tdes,
  { {0x60c0010a,0xd5b1001b,0x7d0900fe,0x00000000}},	//   _gemm, ấy_, udes,
  { {0x7d094f95,0xe4a80063,0x00000000,0x00000000}},	//   rdes, וֹתָ,   ,
  { {0x26c10024,0x23630104,0xba254f96,0x00000000}},	//   _neho_, _jjjj_, едок,
  { {0x9f8a024a,0x69c84412,0x7d0901e1,0x00000000}},	//   töön_, gsde, pdes,
  { {0x186a079f,0xfe36009a,0xcdb6009a,0x00000000}},	//   зами_, _ארעי_, _נפנה_,
  { {0xdd94000d,0x66054f97,0x69c8005f,0x00000000}},	//   _рацы, _ashk, asde,
  { {0x613a0268,0xdb090019,0x9f8a00fe,0x00000000}},	//   _aïll, tseõ, söön_,
  { {0xd62a0d64,0xa3e20053,0xf53f0d7d,0x00000000}},	//   чове_, नून_, _blå_,
  { {0x68e4003b,0x629c002b,0x00000000,0x00000000}},	//   _ucid, _sgro,   ,
  { {0xb3860076,0xb7960001,0x7bc94f98,0x00000000}},	// [99a0] елал, _проћ, nseu,
  { {0xe8d9001b,0x60c0193c,0xd83f01da,0x00000000}},	//   _phủ_, _semm, íček_,
  { {0x394000a4,0xda1f0053,0xb6bb0063,0x00000000}},	//   _klis_, यमित_, _מציי,
  { {0x7bd50051,0x7a462abf,0xab5d0022,0x00000000}},	//   ązuj, _hété, ruży,
  { {0x7bcf0297,0x6f0800c2,0xf9930047,0x00000000}},	//   ácul, _padc, ארא_,
  { {0xe8d9001b,0xe45700b5,0x629c4f99,0x00000000}},	//   _thủ_, _װילט_, _ugro,
  { {0x7a460164,0x7bcb4659,0x60c04f9a,0x00000000}},	//   _mété, _avgu, _temm,
  { {0xe2974f9b,0x127b0041,0xd43f0085,0x00000000}},	//   _час_, _זאלע, лiшч,
  { {0x1be70138,0xdb1b0046,0xa2b40042,0x00000000}},	//   едњи_, truð, इडप्,
  { {0x39404f9c,0x68fd00ac,0x69c84f9d,0x00000000}},	//   _alis_, wesd, tsde,
  { {0x68fd4f9e,0x7f2b009a,0x418a009a,0x00000000}},	//   tesd, _מֵאֶ, ּנָ֑,
  { {0xfc66011c,0x224501f7,0x69c80524,0x00000000}},	//   _пълн, _ülke_, rsde,
  { {0xd0060021,0x48640062,0xcc330044,0x00000000}},	//   جل_, гърб, _مروع,
  { {0xf53f17d5,0x8c1b0063,0x39404f9f,0x00000000}},	//   _slå_, _מודי, _elis_,
  { {0x7a460003,0xee2e0054,0xc6681313,0x00000000}},	//   _dété, инi_, еште_,
  { {0x4a7b0063,0x25ac027d,0xe8ff0003,0x00000000}},	//   _מרוב, ídla_, goût_,
  { {0x28b40021,0x26c14fa0,0x34950085,0x00000000}},	// [99b0] _صحيح, _teho_, таар,
  { {0x86270088,0xb6040078,0x26cc013d,0x00000000}},	//   _зьме, ššau, ódot_,
  { {0xcad7014e,0x54b90121,0x3267000d,0x00000000}},	//   תובת_, _огня_, хтав,
  { {0x41550062,0x7fd50054,0xd0d50062,0x00000000}},	//   ъвес, вікі, тодъ,
  { {0xe134000d,0xb4cd0053,0xcf9b0092,0x00000000}},	//   ынцы, रणी_, чје_,
  { {0xbec2001c,0x25770058,0xbdf5005e,0x00000000}},	//   šīna, rçlu_, вчић,
  { {0x7bc90013,0xee090062,0xfd110021,0x00000000}},	//   wseu, фейл_, لجة_,
  { {0xfe7000b3,0x2d991cef,0x27340137,0x00000000}},	//   حده_, öse_, _hänt_,
  { {0x2d8d03a8,0x273400c7,0xcd04005e,0x00000000}},	//   rmee_, _känt_, учји,
  { {0x78ad00cd,0x7bc92a81,0x89a90081,0x00000000}},	//   _afav, rseu, мков_,
  { {0x7bc94fa1,0xa96a1c5e,0x39402336,0x00000000}},	//   sseu, дина_, _plis_,
  { {0x9c390001,0x7db40021,0xbdf8005d,0x00000000}},	//   _опет_, _إصلا, _سرما_,
  { {0x69de0031,0xeb8e0615,0xc052009d,0x00000000}},	//   _åpen, _ви_, ֹ֖ר_,
  { {0x4b7900b5,0x661a00c7,0x41d10053,0x00000000}},	//   _קאַו, åtko, _हिंस,
  { {0xc8b60076,0xb87b006d,0x752f0051,0x00000000}},	//   _испы, rgía, _bocz,
  { {0xe8d9001b,0xc5630612,0x8579030b,0x00000000}},	//   _phụ_, акск, есут_,
  { {0x7d0b00bb,0x130a000d,0x752f0022,0x00000000}},	// [99c0] _mags, мнай_, _docz,
  { {0xe73a0001,0x7d0b2d60,0x7c260137,0x00000000}},	//   _цео_, _lags, äkri,
  { {0xb6d900b7,0xb87b017d,0xddc8056c,0x00000000}},	//   _אַרט, ngín, _wydź,
  { {0x7d0b00bb,0xe8d9008b,0xa3e20042,0x00000000}},	//   _nags, _thụ_, नंद_,
  { {0x78890023,0xc0e34fa2,0xf8bf009c,0x00000000}},	//   _tūvū, рочк, djél_,
  { {0x27340019,0xdbdb0014,0x30330121,0x00000000}},	//   _tänu_, _ráðg, решё,
  { {0x7d0b00b9,0x5d660131,0x68f64fa3,0x00000000}},	//   _bags, ктиз, _obyd,
  { {0x90a50021,0x68f6002b,0x00000000,0x00000000}},	//   _محكم, _nbyd,   ,
  { {0x7d0b4fa4,0xbb74018e,0x6aad0075,0x00000000}},	//   _dags, лгиј, _şafa,
  { {0x20190016,0x78ad0290,0x7d0b0139,0x00000000}},	//   _ásia_, _sfav, _eags,
  { {0x1b770021,0x27340137,0x7d0b0f49,0x00000000}},	//   خصية_, _läns_, _fags,
  { {0xdd96043e,0x0e57009a,0xe945005d,0x00000000}},	//   _شجاع, _בשבט_, اردی,
  { {0xdb090027,0x752f0051,0x1b2a0021,0x00000000}},	//   speá, _rocz, _يأتي_,
  { {0xec370063,0xc5ff008f,0xbb430092,0x00000000}},	//   _באדר_, ņēmu_, _вељк,
  { {0x752f0045,0x7e860080,0xa4d51c15,0x00000000}},	//   _pocz, _úspě, лові,
  { {0x35440086,0x7d004fa5,0x27340137,0x00000000}},	//   ахув, nems, _sänt_,
  { {0x24580055,0x6ab1013d,0x286b0054,0x00000000}},	// [99d0] вать_, _éjfé, _юрко_,
  { {0x7d1d00ea,0x6d4201a8,0x7d004fa6,0x00000000}},	//   össz, _lloa, hems,
  { {0x10d5000d,0x752f0022,0x273400a5,0x00000000}},	//   гілё, _tocz, _vänt_,
  { {0x69da0027,0xdce0004c,0x39594fa7,0x00000000}},	//   irte, romě, niss_,
  { {0x69da00bd,0x63a20025,0x7d004fa8,0x00000000}},	//   hrte, íont, dems,
  { {0xaed20001,0x6d42003b,0x7d0b2109,0x00000000}},	//   бољш, _aloa, _sags,
  { {0x7d0b00bb,0xb06200fe,0x69da00b9,0x00000000}},	//   _pags, _ääni, jrte,
  { {0x6d4222a1,0x644a0022,0xdce0005f,0x00000000}},	//   _cloa, źliś, ilmė,
  { {0xa1580001,0xeb99139e,0x69da4fa9,0x00000000}},	//   _рату_, нии_, erte,
  { {0x4add0053,0x629a004c,0x4b250ef3,0x00000000}},	//   _माओव, _útoc, умов,
  { {0x6d424183,0x7d0b0d21,0x2bc40053,0x00000000}},	//   _floa, _tags, लीबा,
  { {0x2e3a0047,0x4a420086,0xb87b46f3,0x00000000}},	//   _אגענ, снюв, rgín,
  { {0xed59004c,0x69da4faa,0x03030042,0x00000000}},	//   miž_, arte, रजाह_,
  { {0x25ac0114,0xc7a302b3,0x06760062,0x00000000}},	//   ídlo_, сирк, губя,
  { {0x39594fab,0x2904006c,0x7af4013d,0x00000000}},	//   biss_, ômas_, égtő,
  { {0x2cad403a,0x6995000d,0xed591824,0x00000000}},	//   nced_, _крых, niž_,
  { {0xc9530063,0x6d5e0003,0xf2da0044,0x00000000}},	// [99e0] _למה_, épai, فظات_,
  { {0x3706150f,0x27340137,0x29024a35,0x00000000}},	//   _спог, _väns_, leka_,
  { {0x24860066,0xe0da4fac,0x78a900c2,0x00000000}},	//   ťom_, еве_, ževe,
  { {0x9fca0076,0x63b600ac,0x290236e7,0x00000000}},	//   егда_, ppyn, neka_,
  { {0x2902005f,0xed59004c,0x43860044,0x00000000}},	//   ieka_, diž_, _ملحق,
  { {0x643b0047,0x69da0093,0xde580603,0x00000000}},	//   _טעכנ, yrte, калі_,
  { {0x7bdb00fe,0x7d000f4a,0x6d424fad,0x00000000}},	//   eruu, tems, _ploa,
  { {0x2902017f,0x65640026,0x69da0080,0x00000000}},	//   jeka_, nnih, vrte,
  { {0x6564002c,0x69d50080,0x63a60150,0x00000000}},	//   inih, ázen, _jukn,
  { {0x69da00c2,0x395903a7,0x7d0000a8,0x00000000}},	//   trte, wiss_, sems,
  { {0x657600fe,0xfbcf007e,0x69da3c1c,0x00000000}},	//   koyh, يتی_, urte,
  { {0x637000bd,0x69da004d,0x98a50078,0x00000000}},	//   gänz, rrte, ėlį_,
  { {0x3f9e4fae,0xb954015a,0xdce9005b,0x00000000}},	//   _kitu_, свящ, lleğ,
  { {0x69da00c2,0x3f9e1472,0x26de01a8,0x00000000}},	//   prte, _jitu_, òtop_,
  { {0x3f9e0019,0x63a60026,0x7b06008f,0x00000000}},	//   _mitu_, _aukn, ārtī,
  { {0x3f9e0046,0x44b5012c,0x00000000,0x00000000}},	//   _litu_, рбас,   ,
  { {0x5499000d,0x32181785,0x26050042,0x00000000}},	// [99f0] тваў_, _arry_, _हैरी_,
  { {0xb4db01a8,0x94740021,0x98be0078,0x00000000}},	//   _glàn, صدقا, ėtą_,
  { {0x798d00f3,0x1368000a,0x325500e1,0x00000000}},	//   _khaw, ушти_, јвер,
  { {0x1128005a,0x1fb5000d,0x30151b9c,0x00000000}},	//   лючи_, аскр, идер,
  { {0xf1050042,0x3f9e4faf,0x3897004c,0x00000000}},	//   _रसीद_, _bitu_, běrů_,
  { {0x3f9e003d,0xddc80006,0x29021147,0x00000000}},	//   _citu_, _dydž, zeka_,
  { {0xddc2047e,0xed590114,0xdcfa0058,0x00000000}},	//   общи, tiž_, _attı,
  { {0xd658014e,0x96580041,0x7bdb4fb0,0x00000000}},	//   טיות_, טשוא_, truu,
  { {0x2d530529,0x2cad3bf1,0x6ee7007e,0x00000000}},	//   nţei_, rced_, _مسال,
  { {0x29020009,0x3f9e014f,0xab350095,0x00000000}},	//   weka_, _gitu_, рхиј,
  { {0x29024fb1,0x7bdb021e,0x69264fb2,0x00000000}},	//   teka_, sruu, амна,
  { {0x273d001b,0x60cb4fb3,0xb33b005b,0x00000000}},	//   _hình_, nagm, _suçl,
  { {0x29020397,0x6d490025,0xb4db00cd,0x00000000}},	//   reka_, mhea, _plàn,
  { {0x6d5b01f4,0xdcfb0078,0x6f034d6e,0x00000000}},	//   liua, iluč, nenc,
  { {0x26ca0198,0x273d001b,0x6f03006d,0x00000000}},	//   rabo_, _mình_, ienc,
  { {0x6f032087,0x6d494fb4,0x63a60130,0x00000000}},	//   henc, nhea, _pukn,
  { {0x7c3b014f,0x7c2900cd,0x6d490072,0x00000000}},	// [9a00] nyur, nxer, ihea,
  { {0xdcfb017f,0x60cb0025,0x7c2900cd,0x00000000}},	//   dluč, eagm, ixer,
  { {0x6b814203,0x0219000d,0x6f0318b4,0x00000000}},	//   illg, ліць_, denc,
  { {0x3f9e0397,0x61460001,0x7c3b00a4,0x00000000}},	//   _situ_, једа, kyur,
  { {0x6f030034,0x273d001b,0x20560635,0x00000000}},	//   fenc, _bình_, јтер,
  { {0x69c34fb5,0x2d9300cd,0x9f530603,0x00000000}},	//   _owne, ïxen_, овіч,
  { {0x3f9e0009,0x69d50080,0xbd6a026b,0x00000000}},	//   _vitu_, ázel, крие_,
  { {0x6d493720,0x78a405b9,0xc0e30be8,0x00000000}},	//   ghea, _ngiv, _моск,
  { {0xdee600e1,0x6f030b21,0x3f9e3f4c,0x00000000}},	//   _вози, benc, _titu_,
  { {0x637000fe,0x6f034fb6,0xef170054,0x00000000}},	//   täny, cenc, _кму_,
  { {0x6d490025,0xc987000a,0x999906da,0x00000000}},	//   bhea, иуми, лкот_,
  { {0x6d494fb7,0xd83f0066,0x5a330054,0x00000000}},	//   chea, íčok_, інят,
  { {0x386d005b,0x5887000d,0x78a401e1,0x00000000}},	//   çer_, рына, _dgiv,
  { {0x1bfb0063,0x79a6019c,0x6ffa008f,0x00000000}},	//   _סלוב, _крие, mācā,
  { {0x69c30185,0x7aef0240,0x84c7005e,0x00000000}},	//   _gwne, žitý, иљад,
  { {0x44290268,0x6d404fb8,0xdcfb027d,0x00000000}},	//   txa_, nkma, yluč,
  { {0xf8bf0994,0x6d400122,0xd6db000a,0x00000000}},	// [9a10] mbé_, ikma, _итн_,
  { {0x44290994,0xec7100b5,0x2d53003b,0x00000000}},	//   rxa_, פֿן_, rţei_,
  { {0x5559005a,0x6f034fb9,0x6d4004aa,0x00000000}},	//   _баня_, venc, kkma,
  { {0x6d40006f,0x5555005d,0xd1780085,0x00000000}},	//   jkma, _چپگر, асіі_,
  { {0x6b81001f,0xa0540086,0x6f030eb8,0x00000000}},	//   yllg, овці, tenc,
  { {0x6f030331,0x6d49059f,0x6d404fba,0x00000000}},	//   uenc, whea, ekma,
  { {0x6d4938fb,0x60cb00a4,0x6f0318b4,0x00000000}},	//   thea, pagm, renc,
  { {0x7c290268,0x9f5f0014,0x6f0318b4,0x00000000}},	//   txer, _eruð_, senc,
  { {0x273d001b,0x7c29017d,0x6d494fbb,0x00000000}},	//   _tình_, uxer, rhea,
  { {0x6aa401f7,0x3b090001,0xf8bf01a8,0x00000000}},	//   _şifr, ћено_, ebé_,
  { {0xdce9007d,0x60c94fbc,0x7c3b4fbd,0x00000000}},	//   sleđ, _keem, syur,
  { {0x6d4045cb,0xa3e20042,0xfc3304a0,0x00000000}},	//   ckma, नूँ_, _وحش_,
  { {0x2cbf0146,0x7d740021,0x8d7408aa,0x00000000}},	//   mbud_, _بالط, _بالا,
  { {0xf1a70161,0x2cbf0205,0x60c900ea,0x00000000}},	//   गदान, lbud_, _leem,
  { {0x78a90198,0xf8bf00ea,0xe64302a1,0x00000000}},	//   ževa, bbé_, перп,
  { {0x60c90122,0x6d950078,0xc56900de,0x00000000}},	//   _neem, _tšau, لحقل_,
  { {0x442603d9,0x2398007e,0x0446005e,0x00000000}},	// [9a20] ão_, لمرگ_, љезн,
  { {0x29124fbe,0xd24f007e,0xe29a037b,0x00000000}},	//   _haya_, کنم_, газ_,
  { {0x291218a5,0xf1a901fb,0x113a082d,0x00000000}},	//   _kaya_, لانه_, ляды_,
  { {0x2912053b,0xc6930063,0xda7a0047,0x00000000}},	//   _jaya_, _מאת_, אנער,
  { {0x69d50080,0x60c94d4b,0x8ff70021,0x00000000}},	//   ázej, _deem, مرور_,
  { {0x4253007e,0x291200a4,0x6d590d52,0x00000000}},	//   _کنفر, _laya_, _amwa,
  { {0x200d0089,0x2dd70044,0xd0e80043,0x00000000}},	//   _esei_, مبية_, _نکشم_,
  { {0x6d402ef6,0xfc4601c8,0x7d1c008f,0x00000000}},	//   ukma, šími_, ērso,
  { {0x6d400115,0x3cf70044,0xcbc60044,0x00000000}},	//   rkma, صعيد_, حزبي,
  { {0x68ed1386,0x9b58000a,0x6e93007e,0x00000000}},	//   _scad, риот_, _کلما,
  { {0x3f9b0164,0x29121167,0x7c240006,0x00000000}},	//   ïque_, _baya_, _šird,
  { {0xa8990001,0xdd8f0044,0x00000000,0x00000000}},	//   икну_, _كول_,   ,
  { {0x291206c2,0xf8bf0003,0xdfc60044,0x00000000}},	//   _daya_, rbé_, بي_,
  { {0xf8bf00ea,0xec67009a,0x00000000,0x00000000}},	//   sbé_, _ל֑וֹ_,   ,
  { {0x6d59002b,0x6d9516fe,0x2d8401a9,0x00000000}},	//   _ymwa, _išar, olme_,
  { {0x29120645,0x142b0054,0x00000000,0x00000000}},	//   _gaya_, лізо_,   ,
  { {0x60c91bb7,0x99480242,0x7c240139,0x00000000}},	// [9a30] _reem, _دليل_, _áird,
  { {0x60c90898,0x39490114,0x02a70b69,0x00000000}},	//   _seem, _hlas_, срам,
  { {0xe5350076,0x8afc0051,0x5187000d,0x00000000}},	//   _день, międ, буда,
  { {0xf992009d,0x49ab009d,0x00000000,0x00000000}},	//   ֵ֨א_, אשׁ֑,   ,
  { {0x60c94fbf,0x3dc5002b,0x9f99224c,0x00000000}},	//   _veem, _swlw_, авду_,
  { {0x60c909e9,0x8afc0051,0x43940062,0x00000000}},	//   _weem, nięd, _наяс,
  { {0x60c90449,0x39490b9b,0xcd29030b,0x00000000}},	//   _teem, _olas_, ижке_,
  { {0x2bd40161,0xdce0008f,0x1c450054,0x00000000}},	//   _दिखा, domē, жним,
  { {0x29120974,0x6fe00053,0x2cbf02e0,0x00000000}},	//   _raya_, _नियं, rbud_,
  { {0x2912014f,0x6d5e0164,0x39494fc0,0x00000000}},	//   _saya_, épar, _alas_,
  { {0x29121b19,0x39494ec5,0x7cd9043e,0x00000000}},	//   _paya_, _blas_, _نواز_,
  { {0x7c24017f,0x69dc006d,0x78a901b3,0x00000000}},	//   _šire, área, ževn,
  { {0x291202dd,0x224d0080,0x317a0041,0x00000000}},	//   _vaya_, _řekl_, שארד,
  { {0x39494fc1,0x409a0063,0xf8630054,0x00000000}},	//   _elas_, יברס, євро,
  { {0x0b780021,0x3949002b,0x45364fc2,0x00000000}},	//   _اصنع_, _flas_, охат,
  { {0x91b00013,0x785c008f,0x672500a5,0x00000000}},	//   _đào_, tāvī, _enhj,
  { {0xe5770454,0x78ad004c,0xe2ca0054,0x00000000}},	// [9a40] ізу_, ťová, илад_,
  { {0x7c240027,0xf77f017d,0x7dd0013d,0x00000000}},	//   _áire, puça_, _jósá,
  { {0x321c01d9,0x8afc0051,0x64a64fc3,0x00000000}},	//   ívy_, sięg, _мана,
  { {0x10a60416,0x008601ce,0x2eb40042,0x00000000}},	//   цидн, олео, ुर्त,
  { {0xee020161,0x34a70086,0xc9530063,0x00000000}},	//   लब्ध_, _євро_, ומא_,
  { {0xcdda0095,0xf8bf013d,0x2cb20022,0x00000000}},	//   ањи_, ljét_, _żyd_,
  { {0x79460045,0x12190088,0x7f75000d,0x00000000}},	//   _równ, _люты_, чуцц,
  { {0x628e06bb,0x91030095,0xf8bf00ea,0x00000000}},	//   _izbo, _опсе, njét_,
  { {0xeb060fd0,0x60c24fc4,0xddce0051,0x00000000}},	//   очно, mbom, ódło,
  { {0x60c20006,0x798600ac,0xba540d34,0x00000000}},	//   lbom, elkw, звој,
  { {0x39491e40,0x8f9b0063,0xb87b00be,0x00000000}},	//   _plas_, _כימי, ngív,
  { {0x8ba61406,0xd126005d,0x60c231fa,0x00000000}},	//   _дидж, رم_, nbom,
  { {0xcb6a0079,0xf8bf009c,0x7aeb009c,0x00000000}},	//   _каде_, djét_, últá,
  { {0xdb2000fe,0x3b070062,0x00000000,0x00000000}},	//   ätäm, _мечо_,   ,
  { {0xcf570063,0xb5951528,0x4db8009a,0x00000000}},	//   קבלת_, зивш, מֶּנ,
  { {0x39490089,0x93b53320,0x8afc056c,0x00000000}},	//   _ulas_, збац, sięd,
  { {0xe873006a,0xb2ab0076,0x545506be,0x00000000}},	// [9a50] _زندگ, атеж_, чват,
  { {0x60c20031,0x2bdd0053,0x237401f3,0x00000000}},	//   ebom, _मिसा, والح,
  { {0xa2ad0394,0xd378000d,0xdb0300ac,0x00000000}},	//   जशब्, ічу_, _binê,
  { {0x7ff50021,0xa1590001,0x26d14fc5,0x00000000}},	//   كستا, љаду_, lazo_,
  { {0x6fc60053,0xf4842b2b,0xf7700043,0x00000000}},	//   रीलं, _журн, _سای_,
  { {0x26d10035,0xdb0b017d,0x60c201f4,0x00000000}},	//   nazo_, _eugê, abom,
  { {0xc3320149,0xa2a20042,0xbea24f5c,0x00000000}},	//   _אום_, _कृप्, нашк,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x399b0418,0x26d10035,0x69dc00ea,0x00000000}},	//   _jūsu_, kazo_, áren,
  { {0x399b003d,0x26d10035,0xdb070075,0x00000000}},	//   _mūsu_, jazo_, _ölün,
  { {0x26d1006d,0x98b0007d,0x69dc005f,0x00000000}},	//   dazo_, šača_, šren,
  { {0xa96a05c5,0xf9920021,0x3a380137,0x00000000}},	//   сима_, عبد_, ärpa_,
  { {0x31560047,0x6d4b4fc6,0x7d094fc7,0x00000000}},	//   פישן_, _ilga, mees,
  { {0x26cc03d9,0x26d135dc,0x7d094fc8,0x00000000}},	//   údo_, gazo_, lees,
  { {0x65c6005a,0xd9461321,0xf8bf013d,0x00000000}},	//   ябва, _неки, tjét_,
  { {0xb33b0016,0x2a3a0063,0x7d094fc9,0x00000000}},	//   _muçu, _לעצמ, nees,
  { {0x26d10009,0x43460002,0xf8bf013d,0x00000000}},	// [9a60] bazo_, пеав, rjét_,
  { {0x7d09024a,0x8afc0051,0x629a004a,0x00000000}},	//   hees, mięc, _útok,
  { {0x7d090072,0xdb000137,0xf41f0072,0x00000000}},	//   kees, ppmö, _erä_,
  { {0x7d090072,0xfaf8008f,0x99810078,0x00000000}},	//   jees, lnīt_, _čiū_,
  { {0x8afc0045,0x98a7007d,0xc9530063,0x00000000}},	//   nięc, šića_, עמד_,
  { {0x6d4b4fca,0xb33b0058,0xff23005e,0x00000000}},	//   _alga, _buçu, емљо,
  { {0xa91b0026,0xfaf8001c,0x7d09006f,0x00000000}},	//   amþy, inīt_, fees,
  { {0x6da300e1,0x7d092a76,0x3f87007d,0x00000000}},	//   нија, gees, alnu_,
  { {0x6fb6013a,0x404a005e,0x5bb70085,0x00000000}},	//   _رمضا, _упао_, плыя_,
  { {0x2900000c,0x49d80086,0xff24007e,0x00000000}},	//   _abia_, одою_, _تبری,
  { {0xf1c3008b,0xc3332177,0x09e30131,0x00000000}},	//   _nhớ_, תות_, ноќн,
  { {0x26d10035,0xce050044,0x00000000,0x00000000}},	//   wazo_, _تذكي,   ,
  { {0x26d10035,0x315707e9,0x7c8304f2,0x00000000}},	//   tazo_, ליטן_, _пуше,
  { {0xd7f84fcb,0x4c9b009a,0x8beb009d,0x00000000}},	//   чую_, _הבדו, _הַה֗,
  { {0x8afb0063,0xb87b00ea,0x26d10e7c,0x00000000}},	//   _להגי, egít, razo_,
  { {0xe8d90013,0xe5340085,0xfaf80023,0x00000000}},	//   _thự_, несь, anīt_,
  { {0x290b213a,0x8afc0022,0xf74b005d,0x00000000}},	// [9a70] meca_, cięc, _هجده_,
  { {0xe9ff0013,0x722b01d5,0xdb0301a8,0x00000000}},	//   _hoại_, йцев_, _cinè,
  { {0xdb0b02eb,0x224700ea,0x32b80021,0x00000000}},	//   _utgå, ánk_, سدلة_,
  { {0x2bdd0235,0xe2980086,0xa3b50086,0x00000000}},	//   _मिला, чає_, _обмі,
  { {0xdb1b048e,0x29d8001b,0xdb0300cd,0x00000000}},	//   spué, hĩa_, _finè,
  { {0x7d090122,0x69d8051e,0xe9ff001b,0x00000000}},	//   wees, _ovve, _loại_,
  { {0x7d09024a,0x8afc0051,0xed5902dc,0x00000000}},	//   tees, zięc, жой_,
  { {0x68fd006f,0x7c24007c,0x290b007d,0x00000000}},	//   jfsd, _šira, jeca_,
  { {0x69d84fcc,0x656d002c,0x7d091974,0x00000000}},	//   _avve, inah, rees,
  { {0xdb034fcd,0x99060053,0x7d09003a,0x00000000}},	//   _xinè, षज्ञ_, sees,
  { {0x63a70122,0xdb030080,0xdb0b0003,0x00000000}},	//   _mijn, _jiné, _jugé,
  { {0x63a70122,0xdce00006,0xd95a0086,0x00000000}},	//   _lijn, domė, ішні_,
  { {0x7d5600b5,0x0c25000d,0xdb030003,0x00000000}},	//   _קינד_, _імкн, _liné,
  { {0x656d2b40,0x63a700ca,0x4c9a0063,0x00000000}},	//   enah, _nijn, _ובנו,
  { {0x8afc0045,0x656d00bd,0x64b3004c,0x00000000}},	//   sięc, fnah, křič,
  { {0x1987005a,0x29000035,0x8afc0022,0x00000000}},	//   _общи_, _ubia_, pięc,
  { {0x63a70122,0x79840009,0x69c14fce,0x00000000}},	// [9a80] _bijn, _ikiw, lple,
  { {0xdb0902dd,0x656d4fcf,0x69c14fd0,0x00000000}},	//   mpeó, anah, ople,
  { {0xdb03249d,0x69c110da,0x656d004d,0x00000000}},	//   _ciné, nple, bnah,
  { {0xa87a00b5,0x69c12dd6,0x63a700ca,0x00000000}},	//   ֿאַר, iple, _eijn,
  { {0x63a7006f,0xb4db00cd,0xdb0b4fd1,0x00000000}},	//   _fijn, _clàu, _eugé,
  { {0x69c10104,0xce940062,0xcfa90021,0x00000000}},	//   kple, налъ, ساهم_,
  { {0x53a70161,0x69c100ca,0x7769006c,0x00000000}},	//   _कूटश, jple, éexi,
  { {0x63a70122,0x69c1016d,0x290b00cd,0x00000000}},	//   _zijn, dple, xeca_,
  { {0xcd330021,0x0083005e,0xa2a20042,0x00000000}},	//   ضريب, _алто, _कृत्,
  { {0x79840035,0x5a340189,0x4422085a,0x00000000}},	//   _akiw, енот, _mrk_,
  { {0x290b0a54,0xcf930041,0x6e460044,0x00000000}},	//   teca_, _סטע_, _تنام,
  { {0x1c460001,0xdb1b0014,0x7996002b,0x00000000}},	//   _онем, ssuð, _chyw,
  { {0x6b4400cd,0x442200d1,0xf77f017d,0x00000000}},	//   _lògi, _nrk_, erça_,
  { {0x290b01b3,0x39920139,0x44250d6d,0x00000000}},	//   seca_, tásc_, _čl_,
  { {0x63a709fe,0x656d004d,0xb87b01a8,0x00000000}},	//   _rijn, tnah, tgís,
  { {0x994401f7,0x63a7006f,0x63af007d,0x00000000}},	//   mış_, _sijn, _pucn,
  { {0x7d020027,0x63a7006f,0x656d3a98,0x00000000}},	// [9a90] _mbos, _pijn, rnah,
  { {0x656d4fd2,0x8c1b0063,0x61e501c8,0x00000000}},	//   snah, חומי, trhl,
  { {0x3992000f,0x44223073,0x64b30080,0x00000000}},	//   lása_, _erk_, třič,
  { {0x63a7006f,0xe9ff0013,0xe4eb0021,0x00000000}},	//   _wijn, hiếm_, _بعده_,
  { {0x80270021,0x399200ea,0xd49b0054,0x00000000}},	//   برام, nása_, _фрн_,
  { {0x9944005b,0x39b7003b,0x291e008f,0x00000000}},	//   kış_, _lăsa_, ētai_,
  { {0x753d0045,0xce490121,0xc1770049,0x00000000}},	//   _kosz, язке_, _قدرت,
  { {0xa2940088,0x7c22130e,0x3992013d,0x00000000}},	//   _расі, _bror, kása_,
  { {0x79960185,0x51840141,0x753d13d9,0x00000000}},	//   _rhyw, _рура, _mosz,
  { {0x7d020185,0x3992000f,0xfeb80021,0x00000000}},	//   _ebos, dása_, _قامت_,
  { {0x7c22000c,0xdcfb0080,0xc3320063,0x00000000}},	//   _eror, louč, אוי_,
  { {0x69c12ff4,0xdce90195,0x753d36bb,0x00000000}},	//   rple, oneč, _nosz,
  { {0x291e0080,0x69c14fd3,0x7c2204aa,0x00000000}},	//   ěta_, sple, _gror,
  { {0x7d1b0004,0xcc3a00b5,0x79460051,0x00000000}},	//   ldus, _מענט, _mówi,
  { {0x6b4d0139,0x7d1b004b,0x753d013d,0x00000000}},	//   _gúga, odus, _bosz,
  { {0x7d1b1fc9,0xdb0902dd,0x79840035,0x00000000}},	//   ndus, mpeñ, _ukiw,
  { {0x753d0051,0x6d4900fe,0x27e64fd4,0x00000000}},	// [9aa0] _dosz, ikea, _íon_,
  { {0x7d190034,0x7d1b00fe,0xe2920021,0x00000000}},	//   _laws, hdus, هذا_,
  { {0xb4db00cd,0x6d4900fe,0x61460785,0x00000000}},	//   _clàs, kkea, нежа,
  { {0x61e3000f,0x6b814fd5,0xe0d2043e,0x00000000}},	//   ánla, holg, ازا_,
  { {0x14d70063,0x673e4fd6,0xd0830121,0x00000000}},	//   _אוכל_, _kopj, лыши,
  { {0x44200035,0x7c222264,0x99440058,0x00000000}},	//   mvi_, _rror, yış_,
  { {0x3992000f,0x6b660164,0x6b814fd7,0x00000000}},	//   zása_, _légè, dolg,
  { {0x21a30001,0x7c224fd8,0x39ac0080,0x00000000}},	//   _бисм, _pror, _měst_,
  { {0x6b810199,0x44200268,0x60d70063,0x00000000}},	//   folg, nvi_, _רומא_,
  { {0x7d1b0019,0x9944005b,0xf063018b,0x00000000}},	//   adus, tış_, _скуп,
  { {0x44200004,0x20190046,0xb3560085,0x00000000}},	//   hvi_, _ásir_, ьнiц,
  { {0x3992000f,0x6d4600c7,0x44200253,0x00000000}},	//   tása_, ökad, kvi_,
  { {0x753d0022,0x6d850014,0x60cd0014,0x00000000}},	//   _rosz, róat, ðami,
  { {0x07a40088,0x7d190051,0xdca30001,0x00000000}},	//   лаўн, _zaws, _сачи,
  { {0x753d4fd9,0xd5b1008b,0x44204fda,0x00000000}},	//   _posz, ế_, evi_,
  { {0x69da216d,0xdce01bba,0x6f1a4a7b,0x00000000}},	//   mste, domī, _latc,
  { {0xb97c0063,0x69da3846,0x97a71579,0x00000000}},	// [9ab0] _מנהי, lste, _прол,
  { {0xb4db00cd,0x69da1517,0xe4a41567,0x00000000}},	//   _plàs, oste, урсо,
  { {0x44204fdb,0x69da4fdc,0x20cc0042,0x00000000}},	//   avi_, nste, ारूढ,
  { {0x6b81000f,0x7bdd013d,0x69da4fdd,0x00000000}},	//   zolg, ásuk, iste,
  { {0x69da00bd,0xf9940047,0x12e70054,0x00000000}},	//   hste, ארף_, _півг,
  { {0x6f1a031b,0x23650137,0x69da4fde,0x00000000}},	//   _catc, _ölj_, kste,
  { {0x6b814fdf,0x69da4fe0,0x2eb4000d,0x00000000}},	//   volg, jste, усіс,
  { {0x69da4fe1,0x6db1008f,0xdc340124,0x00000000}},	//   dste, _jāai, aúčt,
  { {0x69da4fe2,0x6d494ee4,0xeb99101a,0x00000000}},	//   este, rkea, мии_,
  { {0x26d305d5,0xaab7007e,0x69da1855,0x00000000}},	//   _nexo_, رگتر_, fste,
  { {0x2bd10235,0x628b0051,0x69da404f,0x00000000}},	//   _दौरा, ęgow, gste,
  { {0x8afc0045,0x44200006,0x6e64000d,0x00000000}},	//   wnęt, yvi_, _стуж,
  { {0xdd940088,0x2d8d00e3,0x8c450259,0x00000000}},	//   _сацы, mlee_, _јеле,
  { {0x69da08dc,0x6295013d,0x6a850121,0x00000000}},	//   bste, _ozzo, _илла,
  { {0xf77f017d,0x9a2400f2,0x7bdb4fe3,0x00000000}},	//   arço_, _معين, lsuu,
  { {0xa2a20235,0x442005c9,0x7bdb0050,0x00000000}},	//   _कृष्, tvi_, osuu,
  { {0x2813006a,0x7bdb021e,0x62954fe4,0x00000000}},	// [9ac0] _نويس, nsuu, _azzo,
  { {0x212d014f,0x7bdb00fe,0x44204fe5,0x00000000}},	//   _aneh_, isuu, rvi_,
  { {0x2d8d00e8,0x26d80787,0xcb120063,0x00000000}},	//   klee_, maro_, שלב_,
  { {0x26d84fe6,0x106a0121,0x7bdb01cf,0x00000000}},	//   laro_, мией_, ksuu,
  { {0x39400164,0x212d00c3,0x5fb30021,0x00000000}},	//   _mois_, _dneh_, لمنط,
  { {0x69dc003d,0x69da4fe7,0x3952001f,0x00000000}},	//   šrei, yste, _llys_,
  { {0x3999000f,0x67040161,0x216a22c4,0x00000000}},	//   lése_, श्यक_, _живи_,
  { {0x6f1a0969,0x394000cd,0x4c94042c,0x00000000}},	//   _watc, _nois_, лийс,
  { {0x399900ea,0x8bd3000d,0x25a00014,0x00000000}},	//   nése_, ажыц, imil_,
  { {0x39400025,0x26d8006d,0x69da135e,0x00000000}},	//   _aois_, jaro_, tste,
  { {0x3940260c,0x28f90086,0x26d84fe8,0x00000000}},	//   _bois_, нень_, daro_,
  { {0x26d30b23,0x69da070f,0x29e70014,0x00000000}},	//   _sexo_, rste, _síað_,
  { {0x39404638,0xdb030016,0x69da4fe9,0x00000000}},	//   _dois_, _dinâ, sste,
  { {0x399900ea,0x69da4fea,0xe6bf0053,0x00000000}},	//   dése_, pste, ्रेज,
  { {0x394003b2,0x3f420026,0x98c700e1,0x00000000}},	//   _fois_, _yður_, _испл,
  { {0x7aea0047,0x2d844feb,0xb7d90021,0x00000000}},	//   _אַװעק, nome_, _كوبا_,
  { {0x7c2400c2,0x6d5e0003,0x539905ac,0x00000000}},	// [9ad0] _širj, épay, евая_,
  { {0x61e300ea,0x25a04fec,0x2d8d0089,0x00000000}},	//   ánlo, amil_, zlee_,
  { {0x6d5c00eb,0x2d844fed,0x99520061,0x00000000}},	//   _įran, kome_, láš_,
  { {0xe5350076,0x2d840006,0x7bdb0072,0x00000000}},	//   _семь, jome_, ysuu,
  { {0x2d8401c7,0xb4c10042,0x00e40054,0x00000000}},	//   dome_, ुरी_, ржін,
  { {0x20d1001b,0xf4120063,0x996d004c,0x00000000}},	//   ại_, _הפך_, _něž_,
  { {0x62340086,0x81d4183f,0x7bc20003,0x00000000}},	//   _керу, _восх, _atou,
  { {0x2d8d00fe,0x26d84e37,0x7bdb0072,0x00000000}},	//   ulee_, zaro_, tsuu,
  { {0x39400164,0x26d800a4,0xfc310021,0x00000000}},	//   _rois_, yaro_, صحة_,
  { {0x8fa40001,0x7c840001,0x7bdb02a8,0x00000000}},	//   _вађе, јуће, rsuu,
  { {0x3999000f,0x39404fee,0x2d8d006d,0x00000000}},	//   zése_, _pois_, plee_,
  { {0x2d840037,0x7bdb0072,0x09360085,0x00000000}},	//   come_, psuu, ухоў,
  { {0xeb8e4fef,0x39400164,0x2bdd0053,0x00000000}},	//   _ги_, _vois_, _मिटा,
  { {0x3999013d,0x1a65005d,0xe9d900de,0x00000000}},	//   vése_, _میخی_, _كذبت_,
  { {0xb4c10053,0xa50a2c16,0xf7430456,0x00000000}},	//   ुरू_, нева_, щеро,
  { {0x399903e8,0x291e003d,0x26d82650,0x00000000}},	//   tése_, ētas_, saro_,
  { {0xdce0003d,0x4426006d,0x68e400a4,0x00000000}},	// [9ae0] nimā, ío_, _idid,
  { {0x46f60245,0xb4db00cd,0x399900ea,0x00000000}},	//   _счит, _poàc, rése_,
  { {0x399900ea,0x60ea0062,0x72960094,0x00000000}},	//   sése_, емем_, ушах,
  { {0xdb09017d,0x61fe21e1,0x3999013d,0x00000000}},	//   mpeõ, rtpl, pése_,
  { {0x2d8400fc,0x61fe4ff0,0xe3b2007e,0x00000000}},	//   vome_, stpl, _درج_,
  { {0x1f730088,0x6df40021,0x61fe1b3e,0x00000000}},	//   блія, لكتا, ptpl,
  { {0x29d100c3,0x5fe00053,0x7bc24ff1,0x00000000}},	//   jša_, _निकल, _stou,
  { {0xf653009a,0x00000000,0x00000000,0x00000000}},	//   מצו_,   ,   ,
  { {0x69c3109f,0xdb0301a8,0x2d844ff2,0x00000000}},	//   _atne, _binà, rome_,
  { {0xdd04005b,0x2d841b1c,0x93fb0149,0x00000000}},	//   ırıy, some_, עליי,
  { {0xdb030268,0x69350076,0x19590475,0x00000000}},	//   _dinà, анну, ваны_,
  { {0x628e1761,0x798600ac,0x9f4f0137,0x00000000}},	//   _mybo, gokw, rtgå_,
  { {0x68e4001f,0xdce0008f,0xf773013a,0x00000000}},	//   _ddid, cimā, ماس_,
  { {0x29d100c2,0x6d42004b,0xab27005e,0x00000000}},	//   bša_, _hooa, _боља_,
  { {0xe5c4005a,0x3abb00ff,0x27e00058,0x00000000}},	//   йсто, _אמונ, _evin_,
  { {0x63a20003,0x2b99006c,0x69c83112,0x00000000}},	//   ïonn, rèce_, mpde,
  { {0x24580076,0x7afd007d,0x60dd0066,0x00000000}},	// [9af0] гать_, đstv, _ôsmi,
  { {0x2b990164,0x45d50001,0x6e280246,0x00000000}},	//   pèce_, _коос, _ordb,
  { {0x6db1001c,0xc2c40021,0x86270085,0x00000000}},	//   _jāat, صيني, _сьпе,
  { {0xf8bf0164,0xdd860021,0x7ff5005d,0x00000000}},	//   ncé_, _ذو_, لستا,
  { {0xc978009a,0x00000000,0x00000000,0x00000000}},	//   נגדי_,   ,   ,
  { {0xddc50054,0xdce9008f,0x63ae00a3,0x00000000}},	//   абки, smeļ, _gibn,
  { {0x93c6000c,0xb354167b,0xde350085,0x00000000}},	//   rtăş, _укрш, рэль,
  { {0xdce0008f,0x29d10734,0xf1a44ff3,0x00000000}},	//   timā, vša_, _грун,
  { {0x32010034,0x6e28004d,0xa158005e,0x00000000}},	//   lthy_, _erdb, _сату_,
  { {0x3b090001,0xdb034ff4,0xdce0008f,0x00000000}},	//   њено_, _biná, rimā,
  { {0xdce0001c,0x3f874ff5,0x29d10249,0x00000000}},	//   simā, monu_, uša_,
  { {0xfe700032,0xa96a2956,0xb4e40053,0x00000000}},	//   _عدل_, тима_, _नये_,
  { {0x61e300ea,0x2f2400ea,0x38550062,0x00000000}},	//   ánlj, ségű_, бърс,
  { {0x6d42006f,0x7bc94ff6,0xdb030061,0x00000000}},	//   _zooa, mpeu, _finá,
  { {0x69c300d1,0xdb03017d,0x8afc0051,0x00000000}},	//   _utne, _giná, zięk,
  { {0x7c2401b3,0x7bc90072,0xda7a0165,0x00000000}},	//   _širi, opeu, _שנקר,
  { {0x25a500cd,0x3366000d,0x9599173e,0x00000000}},	// [9b00] ïlla_, аваг, утру_,
  { {0xa2e603d1,0xb7db0063,0x42c70505,0x00000000}},	//   рожд, _שקיי, игун_,
  { {0x8b5600b5,0x8afc0051,0x200d003b,0x00000000}},	//   סיעס_, więk, _apei_,
  { {0xb4db001b,0x27ed4dd2,0x98be0078,0x00000000}},	//   _hoàn, šene_, ėtė_,
  { {0x628e4ff7,0x44244ff8,0xb6a30013,0x00000000}},	//   _wybo, _ém_, huẩ,
  { {0x7c240027,0x657610ed,0x6fd50085,0x00000000}},	//   _áiri, lnyh, сіцц,
  { {0x43670074,0x91e30af0,0xd6e9009d,0x00000000}},	//   _тарн_, _море, אַפָ,
  { {0x2d9d001f,0x1d340062,0x2247004d,0x00000000}},	//   _chwe_, сния, änke_,
  { {0xf8bf0164,0x9c37005a,0x20090003,0x00000000}},	//   ndée_, ипът_, çait_,
  { {0xd00f0032,0xda260086,0xf2d30047,0x00000000}},	//   _تلك_, аємо, ֿער_,
  { {0xd2b70063,0x65760137,0xdebb0041,0x00000000}},	//   ילית_, knyh, _סמאל,
  { {0xed590080,0xdb1b0164,0xbc67005d,0x00000000}},	//   chž_, nquê, امین_,
  { {0xf8bf135d,0xdca6006e,0x65760137,0x00000000}},	//   rcé_, _тади, dnyh,
  { {0xe78725ea,0x69c81310,0x5bc30021,0x00000000}},	//   румо, ppde, _بقول,
  { {0xdcfb005b,0xdb0306a5,0xaa570054,0x00000000}},	//   nluğ, _binæ, _вищу_,
  { {0x4867005a,0x241905ac,0x29880054,0x00000000}},	//   _въоб, лобы_, _всьо_,
  { {0x9627003d,0x798d0c55,0x3f87005b,0x00000000}},	// [9b10] _saņē, _ikaw, yonu_,
  { {0xdcfb0058,0x9627008f,0xdb1b006c,0x00000000}},	//   kluğ, _paņē, equê,
  { {0x877c0047,0xd1b8002a,0xf8bf006c,0x00000000}},	//   _באזי, لانا_, adée_,
  { {0x3201050b,0xe610007e,0xc1040021,0x00000000}},	//   rthy_, _کشی_, قومي,
  { {0x656d07b7,0xf5360063,0x3f874ff9,0x00000000}},	//   miah, _הנרי_, tonu_,
  { {0x442b0bbc,0x20e7008b,0x656d4ffa,0x00000000}},	//   _irc_, ối_, liah,
  { {0x644d0072,0x3f874ffb,0x7db40085,0x00000000}},	//   lyai, ronu_, осыц,
  { {0x387e000c,0x9f460026,0xe6780063,0x00000000}},	//   ştri_, stoð_, יתוח_,
  { {0x644d4ffc,0x3f874ffd,0x2cbf00a3,0x00000000}},	//   nyai, ponu_, rcud_,
  { {0x798d4ffe,0xdce0000c,0x5ac90145,0x00000000}},	//   _akaw, timă, ылом_,
  { {0x3992000f,0x63a50025,0x5e950021,0x00000000}},	//   lási_, imhn, _الاط,
  { {0x7bc92226,0x644d0072,0xb956005e,0x00000000}},	//   ppeu, kyai, стоћ,
  { {0x656d4fff,0xe81b0053,0x442b0d1e,0x00000000}},	//   diah, _पैदा_, _nrc_,
  { {0xfbd0005d,0x7c94043e,0xceb2009a,0x00000000}},	//   _آتن_, _بشما, ֜ים_,
  { {0xceb24f42,0x75d60021,0xa6e30026,0x00000000}},	//   לים_, إيرا, íðar,
  { {0x3992004c,0xe8fa01ce,0xba740044,0x00000000}},	//   kási_, _сли_, _باهت,
  { {0x64a3000d,0xdcfb0058,0x657603d4,0x00000000}},	// [9b20] зата, zluğ, rnyh,
  { {0x399200ea,0xf8bf0003,0x657606a5,0x00000000}},	//   dási_, rdée_, snyh,
  { {0x6d5b0089,0x442b02c3,0x657601e1,0x00000000}},	//   khua, _erc_, pnyh,
  { {0x10a60940,0x63a50025,0x9fe60021,0x00000000}},	//   биен, amhn, مسته,
  { {0xdb1b017d,0xb87b0e7c,0xdce00078,0x00000000}},	//   rquê, caíd, nimą,
  { {0x21200b59,0xe2aa0044,0x75245000,0x00000000}},	//   žih_, _مازن_, ldiz,
  { {0x0ef90088,0x7c2b001f,0xdb030072,0x00000000}},	//   рэчы_, _argr, _minä,
  { {0x2fda006a,0x6fb6006a,0x39b7000c,0x00000000}},	//   _مورد_, _همرا, _găsi_,
  { {0x75240009,0xdce00078,0x60c25001,0x00000000}},	//   idiz, jimą, mcom,
  { {0x60c20706,0x20570047,0x656d0066,0x00000000}},	//   lcom, _הימל_, ziah,
  { {0x7c2b00bd,0xd91508a6,0x6d5b0139,0x00000000}},	//   _ergr, одны, bhua,
  { {0xf53f00c7,0x127b0047,0xd7fb5002,0x00000000}},	//   _ihåg_, ראטע, луг_,
  { {0xbfb6001b,0x75240290,0x60c25003,0x00000000}},	//   _điểm_, ddiz, icom,
  { {0x442b0150,0x4aba0121,0x60c200e5,0x00000000}},	//   _rrc_, _судя_, hcom,
  { {0x3992000f,0x656d0024,0x60c200ca,0x00000000}},	//   zási_, tiah, kcom,
  { {0x6db1001c,0x442b5004,0x6d402502,0x00000000}},	//   _jāap, _prc_, njma,
  { {0x52d90121,0x656d1b9f,0xb4b90053,0x00000000}},	// [9b30] имаю_, riah, _चली_,
  { {0x656d0024,0xb87b0460,0x60c22253,0x00000000}},	//   siah, raíd, ecom,
  { {0x644d0052,0x50b50d82,0xb87b0139,0x00000000}},	//   syai, ослу, saíd,
  { {0x6d46024a,0x3992000f,0xdb0b00bd,0x00000000}},	//   ökal, tási_, _zugä,
  { {0x657d00ca,0x442b002b,0xd91c0063,0x00000000}},	//   _ijsh, _urc_, טואל,
  { {0x399200ea,0xf41f0072,0x44290326,0x00000000}},	//   rási_, _isä_, mva_,
  { {0x6d5b22a4,0xe81b0053,0xbea20603,0x00000000}},	//   thua, _पैसा_, машк,
  { {0x60c20191,0xd6580063,0xdb0a0b16,0x00000000}},	//   ccom, מיות_, _difí,
  { {0x764e0051,0xd045005d,0xc05b0054,0x00000000}},	//   zyby, _بپذي, _сів_,
  { {0x3d29007e,0xdce90078,0x6d40376b,0x00000000}},	//   اتژی_, mieč, ajma,
  { {0xdb1b0003,0x44290ff2,0xdce95005,0x00000000}},	//   nqué, hva_, lieč,
  { {0x44295006,0xdb030072,0xdce0005f,0x00000000}},	//   kva_, _sinä, timą,
  { {0x26da0035,0x764e001f,0xdce90006,0x00000000}},	//   _pepo_, wyby, nieč,
  { {0x7c295007,0x44295008,0x7d095009,0x00000000}},	//   mver, dva_, lfes,
  { {0x657a0003,0x4429500a,0x65c60062,0x00000000}},	//   étho, eva_, юбва,
  { {0xdce90006,0x7c29500b,0x442901e9,0x00000000}},	//   kieč, over, fva_,
  { {0xdce90006,0x7d0901f4,0x7c292090,0x00000000}},	// [9b40] jieč, ifes, nver,
  { {0xb2960001,0x75240290,0x7c2920c1,0x00000000}},	//   ојећ, sdiz, iver,
  { {0x8afc0045,0xe8220053,0x7c29500c,0x00000000}},	//   mięt, मिका_, hver,
  { {0x7c29500d,0x629c0def,0x22470137,0x00000000}},	//   kver, _vzro, änka_,
  { {0x629c0051,0xb4d60053,0xcfa6018e,0x00000000}},	//   _wzro, हरी_, ошки,
  { {0x8afc0045,0x6d591db4,0x60c2500e,0x00000000}},	//   nięt, _alwa, scom,
  { {0x629c017f,0x7d092f1d,0x60c2500f,0x00000000}},	//   _uzro, ffes, pcom,
  { {0x6da300d7,0xd1320044,0x7c295010,0x00000000}},	//   мија, _تمر_, fver,
  { {0x8b660021,0x7c292c36,0x6b4d1358,0x00000000}},	//   قادم, gver, _lúgu,
  { {0x3f760045,0x20dd0078,0x501b0063,0x00000000}},	//   dług_, ršių_, _דומו,
  { {0x2b4703b2,0x09e30002,0x442945ef,0x00000000}},	//   _donc_, моќн, zva_,
  { {0xa9c3019d,0xedd3006a,0x2c830006,0x00000000}},	//   ьськ, _آيند, _būdą_,
  { {0x2b4701a8,0x20065011,0xc7f8012c,0x00000000}},	//   _fonc_, ntoi_, оняє_,
  { {0x46e80121,0x8afc0022,0x3992013d,0x00000000}},	//   ждён_, gięt, dásu_,
  { {0xb4d60235,0xf41f00fe,0xdce90078,0x00000000}},	//   हरू_, _ssä_, zieč,
  { {0xb87b017d,0xe534000d,0x442931a1,0x00000000}},	//   raíb, месь, tva_,
  { {0x29195012,0xd7fb0062,0x44295013,0x00000000}},	// [9b50] mesa_, _туй_, uva_,
  { {0x60db0397,0x29195014,0x68fd01f2,0x00000000}},	//   _seum, lesa_, lgsd,
  { {0x55950079,0xa2dc0053,0x7c293a7a,0x00000000}},	//   _наоѓ, _फ़र्, zver,
  { {0xdb0b00c7,0xdce90006,0xdb1b5015,0x00000000}},	//   _utgö, tieč, rqué,
  { {0x67250004,0x25a95016,0xc9540047,0x00000000}},	//   _kahj, mmal_, ומף_,
  { {0x7c295017,0x60db0035,0x399200ea,0x00000000}},	//   vver, _weum, lást_,
  { {0x67255018,0x63bd2595,0xdce9005f,0x00000000}},	//   _mahj, _husn, sieč,
  { {0x25a900bd,0x7c295019,0x67250659,0x00000000}},	//   nmal_, tver, _lahj,
  { {0x29190994,0x69ca2b83,0x25a900bd,0x00000000}},	//   desa_, _atfe, imal_,
  { {0x25a900bd,0x63bd501a,0x290001f4,0x00000000}},	//   hmal_, _musn, _scia_,
  { {0x39490016,0x25a9501b,0x2919501c,0x00000000}},	//   _boas_, kmal_, fesa_,
  { {0x291900e3,0x7c291203,0x6d5900ac,0x00000000}},	//   gesa_, pver, _ulwa,
  { {0x399200ea,0xab2906b4,0xdb03501d,0x00000000}},	//   dást_, _гола_, _minú,
  { {0x63b51fdb,0x25a9501e,0xf7560044,0x00000000}},	//   _nizn, emal_, أنسج,
  { {0x63bd00bd,0x8f9a0063,0x3f760022,0x00000000}},	//   _ausn, מישי, sług_,
  { {0x63bd0185,0x2919501f,0xf99203eb,0x00000000}},	//   _busn, cesa_, _ثبت_,
  { {0x29c1001b,0x8afc0022,0xf484005d,0x00000000}},	// [9b60] _hóa_, pięt, ذاری,
  { {0x9479013c,0x7ae13641,0x25a9199a,0x00000000}},	//   істу_, nalt, amal_,
  { {0xb6bb0063,0x7ae15020,0x3d1c0053,0x00000000}},	//   _לציי, ialt, _मसले_,
  { {0x7ae10199,0x2d800024,0x63bd001f,0x00000000}},	//   halt, čiek_, _fusn,
  { {0x7ae15021,0xf53f00d1,0xaedc000d,0x00000000}},	//   kalt, _tiår_, аблi,
  { {0x7ae100fe,0x200600fe,0x29190022,0x00000000}},	//   jalt, rtoi_, zesa_,
  { {0x200634cf,0x7bcb0023,0xc87f0244,0x00000000}},	//   stoi_, _atgu, maße_,
  { {0x6360000f,0x7cf6005b,0x63bd0089,0x00000000}},	//   _böng, dürü, _yusn,
  { {0x7ae15022,0x29195023,0x8e86005d,0x00000000}},	//   falt, vesa_, _کلاه,
  { {0x7ae10025,0x399200ea,0x25a90089,0x00000000}},	//   galt, zást_, zmal_,
  { {0x4427001b,0x29195024,0xc3332177,0x00000000}},	//   ̉n_, tesa_, גות_,
  { {0x7ae10ff2,0x63600014,0x984b0062,0x00000000}},	//   aalt, _hönd, бяга_,
  { {0x63600014,0x29195025,0x7ae15026,0x00000000}},	//   _göng, resa_, balt,
  { {0x291920ea,0x27ed0993,0xbb435027,0x00000000}},	//   sesa_, šeno_, _печк,
  { {0x3992000f,0x44224d52,0x3949004b,0x00000000}},	//   tást_, _ask_, _toas_,
  { {0x63600026,0x69fb0063,0xa5f8005e,0x00000000}},	//   _lönd, _הלהק, џету_,
  { {0x18680001,0x68ed5028,0x3f8e05b3,0x00000000}},	// [9b70] _наћи_, _idad, kofu_,
  { {0x798f002b,0x43740054,0x02a7012d,0x00000000}},	//   locw, нуєт, прем,
  { {0x29c1001b,0x2b0e0042,0x3992013d,0x00000000}},	//   _xóa_, त्यु_, pást_,
  { {0xf8bf0003,0x7ae129cf,0x7c223322,0x00000000}},	//   idéo_, zalt, _osor,
  { {0xe1340088,0x656f0025,0x63600137,0x00000000}},	//   энцы, _imch, _bönd,
  { {0x7d025029,0x63600014,0xf2070085,0x00000000}},	//   _acos, _röng, _нябо,
  { {0x7ae1024a,0x636020d4,0x7c22502a,0x00000000}},	//   valt, _dönd, _asor,
  { {0x27e900c7,0xe7ee0053,0x301500e1,0x00000000}},	//   _ovan_, _जिला_, _одбр,
  { {0x7ae1502b,0x3af50766,0x636b0022,0x00000000}},	//   talt, мянс, eżni,
  { {0x636004ab,0x224d0080,0x7cf6005b,0x00000000}},	//   _gönd, _řeky_, türü,
  { {0x7c22502c,0x98700066,0x7ae1502d,0x00000000}},	//   _esor, rúča_, ralt,
  { {0x7ae1502e,0x29e7007d,0x7d020139,0x00000000}},	//   salt, rđa_, _gcos,
  { {0x68ed001f,0x6360005b,0x7d1b502f,0x00000000}},	//   _ddad, _yönd, meus,
  { {0x26de0024,0x68ed006d,0x6d4b5030,0x00000000}},	//   úto_, _edad, _hoga,
  { {0xab280754,0xdb1b032a,0x44225031,0x00000000}},	//   _رسول_, nquí, _ssk_,
  { {0x6d4b5032,0xe5a35033,0x7d1b5034,0x00000000}},	//   _joga, виси, neus,
  { {0x9f5f1e32,0x6d4b5035,0x63600137,0x00000000}},	// [9b80] _aquí_, _moga, _löne,
  { {0x6d4b03a9,0x7d1b5036,0x98a90022,0x00000000}},	//   _loga, heus, _snać_,
  { {0xc87f00bd,0x7d1b00fe,0x6146000d,0x00000000}},	//   raße_, keus, межа,
  { {0x63605037,0xc4fa007e,0x44225038,0x00000000}},	//   _sönd, _بعدا_, _tsk_,
  { {0xbfaa0121,0x10470062,0xd0100242,0x00000000}},	//   отке_, дящи_, الت_,
  { {0x3eba0031,0x7d020b10,0x20ee008b,0x00000000}},	//   øpt_, _scos, ội_,
  { {0x656f0185,0x4420001f,0x6d4b5039,0x00000000}},	//   _ymch, lwi_, _boga,
  { {0x636001f7,0x6d4b0027,0x7d1b503a,0x00000000}},	//   _döne, _coga, geus,
  { {0x6d4b055e,0x4420001f,0xa91b0014,0x00000000}},	//   _doga, nwi_, nnþe,
  { {0xba0a0062,0x7e56503b,0x8e3a0044,0x00000000}},	//   охме_, _отец, _وسار_,
  { {0x6d4b000f,0x7d2700c7,0x399900ea,0x00000000}},	//   _foga, örsä, lési_,
  { {0xbfa3008b,0x7afd0078,0x6d4b002b,0x00000000}},	//   hiế, ėsta, _goga,
  { {0x44200035,0x399900ea,0x984b000d,0x00000000}},	//   jwi_, nési_, цяна_,
  { {0x636001f7,0xc0530047,0x4420503c,0x00000000}},	//   _yöne, דזש_, dwi_,
  { {0x7dc7005b,0xb87b00f8,0x4420002b,0x00000000}},	//   _kısa, caín, ewi_,
  { {0x7c2d503d,0x39991329,0xe945005d,0x00000000}},	//   _šari, kési_, _سربی,
  { {0x63ab00e8,0x2d580164,0xb87b0025,0x00000000}},	// [9b90] ïgno, _réel_, maío,
  { {0xb87b0027,0x399900ea,0xdb010405,0x00000000}},	//   laío, dési_, omlá,
  { {0x2fcd503e,0x44200089,0x50f506be,0x00000000}},	//   _steg_, awi_, езет,
  { {0xb87b0027,0x63600058,0x02a43821,0x00000000}},	//   naío, _röne, трум,
  { {0x63601051,0x442d4ed9,0x7d1b006c,0x00000000}},	//   _söne, _ée_, veus,
  { {0x6d4b00bd,0xb87b0027,0xde050f8d,0x00000000}},	//   _soga, haío, епки,
  { {0x3eb30137,0xed590121,0x6d4b503f,0x00000000}},	//   äxt_, зой_, _poga,
  { {0xdb1b02dd,0x6da2130d,0x0c2505ef,0x00000000}},	//   rquí, лища, емин,
  { {0xb87b0025,0x7d1b5040,0x27ed00c2,0x00000000}},	//   daío, reus, šenj_,
  { {0xf1b900c2,0x6360004d,0x4a452254,0x00000000}},	//   _hiš_, _töne, енов,
  { {0x44200051,0x6d4b2946,0x8f680021,0x00000000}},	//   zwi_, _toga, _تملك_,
  { {0xdc330024,0xb87b0d5d,0x9f4f0139,0x00000000}},	//   lúče, gaío, irgí_,
  { {0xf1b9007d,0x31560041,0x9734005d,0x00000000}},	//   _miš_, גירן_, نکدا,
  { {0x636000bd,0xa9240078,0x6d46004b,0x00000000}},	//   _mönc, _ąžuo, ökav,
  { {0x3999000f,0x59c60053,0x9f560003,0x00000000}},	//   zési_, _रूपर, égés_,
  { {0xb87b0027,0xf1b9007d,0x44200022,0x00000000}},	//   caío, _niš_, twi_,
  { {0x958305ce,0x27b601ce,0xa989009d,0x00000000}},	// [9ba0] улте, _пљос, _קָצִ,
  { {0x1423000d,0x76260054,0x44205041,0x00000000}},	//   ыдум, _змоз, rwi_,
  { {0xb87b0025,0x764100fe,0x26d85042,0x00000000}},	//   haíl, älyt, mbro_,
  { {0x399903e8,0x68e6002c,0x29020397,0x00000000}},	//   tési_, nakd, ngka_,
  { {0x65760072,0xc0e70021,0x7d040050,0x00000000}},	//   miyh, رفون_, _öisi,
  { {0x399900ea,0xdb0101e1,0x65760072,0x00000000}},	//   rési_, lmlæ, liyh,
  { {0x3999000f,0x6383005a,0xdb030139,0x00000000}},	//   sési_, _сгра, _ghné,
  { {0x1d34005a,0x399900ea,0x9cca000d,0x00000000}},	//   тния, pési_, чыка_,
  { {0xfbcf007e,0xfd660013,0x9f860454,0x00000000}},	//   یتی_, _khuế, _згад,
  { {0x5a343088,0xdce20130,0x61fe1574,0x00000000}},	//   внот, _omoć, oupl,
  { {0xb87b0025,0x65760072,0xf8bf00be,0x00000000}},	//   taío, kiyh, sdém_,
  { {0x7c860932,0x3ea102d2,0x89b40085,0x00000000}},	//   _пуле, ühte_, лёўш,
  { {0xb87b0027,0xdd8f007e,0x2bb20042,0x00000000}},	//   raío, _اون_, ीददा,
  { {0xb87b0025,0x290200a4,0x61fe5043,0x00000000}},	//   saío, agka_, kupl,
  { {0xdb030080,0xb87b0139,0xe6950121,0x00000000}},	//   _jiný, paío, тивы,
  { {0xba9b014e,0x6564002c,0x1a9b0063,0x00000000}},	//   _מסוי, ghih, _מיוע,
  { {0x26d840cb,0x24f8000d,0x61fe0003,0x00000000}},	// [9bb0] bbro_, энты_, eupl,
  { {0xd6db0055,0x65640c55,0x799d35bd,0x00000000}},	//   _эти_, ahih, llsw,
  { {0xa4d90376,0x52e10053,0x75d50044,0x00000000}},	//   _одну_, _फ़ीस, _جيجا,
  { {0x65645044,0x60b500f2,0x3075005e,0x00000000}},	//   chih, نمائ, кулс,
  { {0x61fe004b,0x753d12dc,0x212a005d,0x00000000}},	//   aupl, _insz, بينی_,
  { {0x0eac0053,0x61fe00ca,0xa3f6009a,0x00000000}},	//   टइंड, bupl, _במשק_,
  { {0x68e600a4,0x62340062,0x61fe290c,0x00000000}},	//   yakd, _йеру, cupl,
  { {0x69c7027d,0xdc330066,0xa63c009a,0x00000000}},	//   íjem, súče, לגור,
  { {0x6c52005e,0x5184082d,0xdfd1005d,0x00000000}},	//   икћу, _сура, _ضيا_,
  { {0x799d0199,0x999f0006,0xeac50062,0x00000000}},	//   elsw, kytų_, ъбоп,
  { {0x68e60275,0xb87b0139,0xc3320063,0x00000000}},	//   takd, saíl, בוי_,
  { {0x999f0006,0x4ad10053,0xdb03004d,0x00000000}},	//   dytų_, _द्रव, _hinü,
  { {0xf1b211b4,0x8b250603,0xfd56009a,0x00000000}},	//   יסט_, _адле, _ששני_,
  { {0x2905000f,0xdcfb0078,0x6d5b0072,0x00000000}},	//   őlap_, inuč, lkua,
  { {0x6606005a,0xa5960612,0x26d83f9b,0x00000000}},	//   ъпва, вращ, rbro_,
  { {0x6d5b00e3,0x7ae32a38,0x6d495045,0x00000000}},	//   nkua, _hent, njea,
  { {0xc953014e,0x7ae35046,0x69c35047,0x00000000}},	// [9bc0] _כמה_, _kent, _hune,
  { {0xd7fb01f9,0x7ae35048,0x69c35049,0x00000000}},	//   _קהיל, _jent, _kune,
  { {0x7ae3196b,0x00e60054,0x2cb1004c,0x00000000}},	//   _ment, вжен, ězdy_,
  { {0xb2950001,0x61fe504a,0x7ae3504b,0x00000000}},	//   ујућ, rupl, _lent,
  { {0xdb0b005b,0x69c3504c,0x68e4217b,0x00000000}},	//   _bugü, _lune, _meid,
  { {0x68e412fa,0x399900ea,0x6d5b017e,0x00000000}},	//   _leid, lést_, ekua,
  { {0x69c3504d,0x91e33fe2,0x35a70042,0x00000000}},	//   _nune, _восе, _कीड़,
  { {0x68e40333,0xdce9005b,0xdb190051,0x00000000}},	//   _neid, rneğ, _otwó,
  { {0x7ae31acc,0x316600ea,0x7b660054,0x00000000}},	//   _bent, mhoz_, втне,
  { {0xdb1800ea,0x316600ea,0xda7a0376,0x00000000}},	//   _kivé, lhoz_, дям_,
  { {0x27e000a4,0x69c301e7,0x63bc1981,0x00000000}},	//   _awin_, _cune, _mirn,
  { {0x68e4001f,0x5e790047,0x7ae3006f,0x00000000}},	//   _ceid, _אָנד, _eent,
  { {0x60cd006d,0x399900ea,0x27ed504e,0x00000000}},	//   ñami, dést_, éen_,
  { {0x999f0006,0x7ae3193b,0x644b004b,0x00000000}},	//   tytų_, _gent, ägim,
  { {0x68e40027,0x3166000f,0x3774000d,0x00000000}},	//   _feid, khoz_, рыўс,
  { {0x7ae300bd,0xd9440001,0x63bc0150,0x00000000}},	//   _zent, _већи, _airn,
  { {0xe4540088,0x69c300bd,0x629c002c,0x00000000}},	// [9bd0] акты, _zune, _ayro,
  { {0x68e4006f,0x7ae80051,0xe889013d,0x00000000}},	//   _zeid, nadt, _égőá,
  { {0xa6e30014,0x4432371f,0x63bc504f,0x00000000}},	//   íður, avy_, _dirn,
  { {0xa4d50086,0xb65a0063,0x3166013d,0x00000000}},	//   _щомі, _נדרש, ghoz_,
  { {0xe0d80086,0xddd80066,0x63bc5050,0x00000000}},	//   тві_, lyvň, _firn,
  { {0x63600026,0xaf040054,0x63bc0014,0x00000000}},	//   _hönn, ипіл, _girn,
  { {0x63600199,0x6d5b0089,0x60c400fc,0x00000000}},	//   _könn, tkua, žima,
  { {0x7ae35051,0x1d25005e,0x2909487f,0x00000000}},	//   _sent, умим, _ncaa_,
  { {0x6d5b0974,0x7ae35052,0x63600014,0x00000000}},	//   rkua, _pent, _mönn,
  { {0x7ae8000f,0x69c3000c,0x69c40024,0x00000000}},	//   gadt, _pune, _čier,
  { {0xdb0302dd,0xc33200b5,0xe9e90024,0x00000000}},	//   _sinó, זוי_, knúť_,
  { {0x2909034e,0x7ae35053,0x44325054,0x00000000}},	//   _ccaa_, _went, yvy_,
  { {0x68e40418,0x39990080,0xe9e90024,0x00000000}},	//   _veid, vést_, dnúť_,
  { {0xa8750076,0x7ae3006d,0x44325055,0x00000000}},	//   рующ, _uent, vvy_,
  { {0x3999000f,0x68e40027,0x2bdf0053,0x00000000}},	//   tést_, _teid, पीरा,
  { {0x27e05056,0x3a3801e1,0x44325057,0x00000000}},	//   _twin_, ærpe_, tvy_,
  { {0xdb190051,0x15b9000d,0x399900ea,0x00000000}},	// [9be0] _utwó, тыры_, rést_,
  { {0x87260076,0x443201c2,0x399900ea,0x00000000}},	//   _смож, rvy_, sést_,
  { {0x316600ea,0x399900ea,0x44320137,0x00000000}},	//   thoz_, pést_, svy_,
  { {0xf2c90047,0x629c0114,0x6360004d,0x00000000}},	//   לע_, _vyro, _gönn,
  { {0xdfcf0021,0x629c0051,0x63bc00c2,0x00000000}},	//   كين_, _wyro, _tirn,
  { {0x3166000f,0x25a00019,0x2ee5001f,0x00000000}},	//   shoz_, llil_, _celf_,
  { {0x3166013d,0x2d9f006c,0xe3631134,0x00000000}},	//   phoz_, flue_, _укри,
  { {0x5d54026b,0x9bf42b4f,0x2567004b,0x00000000}},	//   ркит, азич, _võlg_,
  { {0x54770047,0x21670fec,0x7ae85058,0x00000000}},	//   ָגיע_, _сити_, tadt,
  { {0x96d40235,0x9b58000a,0xdb0300cd,0x00000000}},	//   _ब्लॉ, тиот_, _sinò,
  { {0x39525059,0xdb030025,0xdb230139,0x00000000}},	//   _boys_, _ghní, árái,
  { {0x2ee50122,0x02b70047,0x1995000d,0x00000000}},	//   _zelf_, טליך_, рамя,
  { {0x8d930032,0x9c57006a,0x63600137,0x00000000}},	//   _النش, _مجوز_, _rönn,
  { {0x63600014,0x86270503,0x00000000,0x00000000}},	//   _sönn, льбе,   ,
  { {0x58d5011c,0xe9e90024,0xda6601fb,0x00000000}},	//   _койт, tnúť_, _حاشي,
  { {0x39400034,0x583900a0,0xb4d50ac5,0x00000000}},	//   _gnis_, _азия_, ржащ,
  { {0xa9bc0063,0xdce0008f,0x3375505a,0x00000000}},	// [9bf0] _אזהר, limē, агар,
  { {0xe9e90066,0x6cab009d,0x00000000,0x00000000}},	//   snúť_, תֹלְ,   ,
  { {0xe9e90024,0x82a70121,0xdce0008f,0x00000000}},	//   pnúť_, ушае, nimē,
  { {0xda7b00b5,0x2ee5015e,0xb0350002,0x00000000}},	//   ענאר, _self_, инеш,
  { {0x09b80047,0xb0af0053,0x50450854,0x00000000}},	//   אפאט_, जेंग, релб,
  { {0xb3640062,0x442b01db,0x4439505b,0x00000000}},	//   _лъск, _isc_, _irs_,
  { {0x6b5f00ac,0x752f505c,0xf1a705ce,0x00000000}},	//   _sêgo, _kacz, _бран,
  { {0x52840021,0x2d990003,0x3999013d,0x00000000}},	//   _الفك, ôse_, zésr_,
  { {0x69ce004c,0x442b01a8,0x5067505d,0x00000000}},	//   íben, _jsc_, _ства,
  { {0x443904bf,0xce6b05f9,0x442b3bca,0x00000000}},	//   _mrs_, _пред_, _msc_,
  { {0xd9460002,0xc3320063,0xa96a202f,0x00000000}},	//   аени, קוט_, вина_,
  { {0x752f0051,0x3992013d,0xc7a9009f,0x00000000}},	//   _nacz, lász_, _חב_,
  { {0x7db403eb,0x44390f16,0xbb4502b3,0x00000000}},	//   _اصلا, _nrs_, _велк,
  { {0x7c2b002b,0xcb08005d,0xeb080044,0x00000000}},	//   _isgr, _ميهن_, _مقهى_,
  { {0x4b7a1469,0x39521098,0x7bca008f,0x00000000}},	//   _שאצו, _toys_, ēmuš,
  { {0x39400164,0x442b505e,0xc563030b,0x00000000}},	//   _unis_, _bsc_, окск,

  { {0x442b505f,0x33b60044,0x23b60044,0x00000000}},	// [9c00] _csc_, لمرأ, لمرس,
  { {0x44393cd9,0x25a05060,0x2bb60022,0x00000000}},	//   _drs_, slil_, _płci_,
  { {0x44395061,0xb87b0080,0xe5a60ef3,0x00000000}},	//   _ers_, abíd, _вини,
  { {0x44390d7c,0x5a160041,0x6a3a0041,0x00000000}},	//   _frs_, יקען_, כגעפ,
  { {0x33d5126b,0x6360005b,0x30340121,0x00000000}},	//   _гіст, _yönl, селё,
  { {0x752f0045,0x75242780,0xa067005e,0x00000000}},	//   _zacz, leiz, раља_,
  { {0x22470c38,0x7e2a0054,0x7c39002b,0x00000000}},	//   änkt_, тіла_, _arwr,
  { {0x23720051,0x68f60078,0x44390b7c,0x00000000}},	//   żają_, _ndyd, _yrs_,
  { {0x8c430259,0x9959004c,0x5f46005d,0x00000000}},	//   жење, též_, _پنال,
  { {0x69ca016a,0x61fe00e8,0x661e00d1,0x00000000}},	//   _संदी, orpl, _oppk,
  { {0x77770089,0xeb970002,0x7c2b2321,0x00000000}},	//   _rmxx, риќ_, _esgr,
  { {0x1eea005d,0x61fe0168,0x00000000,0x00000000}},	//   _سوچی_, irpl,   ,
  { {0x68f60185,0xb8cf0053,0x752f0051,0x00000000}},	//   _ddyd, _कर_, _racz,
  { {0x0b930593,0x8c1b009a,0xdb18013d,0x00000000}},	//   _وجود, _סווי, _kiví,
  { {0x99420051,0x56780121,0x45d51406,0x00000000}},	//   _dół_, абря_, собс,
  { {0x7c2b0185,0x99d3006a,0xcdf70063,0x00000000}},	//   _ysgr, _بتوا, ימלי_,
  { {0x61fe5062,0x69da5063,0xf2c7342a,0x00000000}},	// [9c10] erpl, lpte, асен,
  { {0xdb0a0025,0x34a70053,0xd25b000d,0x00000000}},	//   _bhfé, _खरीद, кце_,
  { {0x6d42003b,0x76480072,0x752f0022,0x00000000}},	//   _onoa, ädyt, _tacz,
  { {0xdd86006a,0x7afd0006,0x91ac008b,0x00000000}},	//   _رو_, ėsti, _đọc_,
  { {0xf770006a,0x44395064,0x6e3a5065,0x00000000}},	//   _رای_, _urs_, _artb,
  { {0x44290009,0xf8bf00ea,0xf1c90021,0x00000000}},	//   mwa_, ldés_, _موسى_,
  { {0x44295066,0x61fe007d,0x2eb40062,0x00000000}},	//   lwa_, crpl, осъс,
  { {0xcd290076,0xf8bf5067,0x44290051,0x00000000}},	//   ужие_, ndés_, owa_,
  { {0xdd2f0080,0x442902e5,0x69da2cd6,0x00000000}},	//   _těžk, nwa_, epte,
  { {0x44290301,0xcb69005d,0xe452009a,0x00000000}},	//   iwa_, امده_, לֶת_,
  { {0x44295068,0x00000000,0x00000000,0x00000000}},	//   hwa_,   ,   ,
  { {0x4429058c,0xce6805f1,0x00000000,0x00000000}},	//   kwa_, _труд_,   ,
  { {0x44290009,0x99420051,0xdc740121,0x00000000}},	//   jwa_, _pół_, _мышь,
  { {0x59cf0161,0x7c292556,0x44293900,0x00000000}},	//   _संपर, mwer, dwa_,
  { {0xdb030025,0x7bdb0072,0x44290022,0x00000000}},	//   _ghná, lpuu, ewa_,
  { {0x7d0924f5,0x7c295069,0x16a80042,0x00000000}},	//   nges, ower, _गरीब,
  { {0x7524003d,0x44290035,0x7c29506a,0x00000000}},	// [9c20] reiz, gwa_, nwer,
  { {0x7d0900bd,0x61fe08ea,0xc2b6005e,0x00000000}},	//   hges, trpl, бљењ,
  { {0x7c290199,0x7d091a20,0xe1fa14c6,0x00000000}},	//   hwer, kges, уге_,
  { {0x44290009,0x7d090122,0xf53f0024,0x00000000}},	//   bwa_, jges, áťte_,
  { {0x7c290122,0x7bcf2b2e,0x63600e04,0x00000000}},	//   jwer, ícul, _jönk,
  { {0x7d090333,0x7c2938e9,0x69da3588,0x00000000}},	//   eges, dwer, ypte,
  { {0xdef90088,0x7c290194,0x11d5000d,0x00000000}},	//   рыі_, ewer, _мітр,
  { {0xdb18006d,0x3f87001f,0xbebc001c,0x00000000}},	//   _viví, annu_, _saīs,
  { {0xb87b0025,0xdb030139,0x7c293816,0x00000000}},	//   naít, _shná, gwer,
  { {0x6e3c02dd,0x26190161,0xf8bf013d,0x00000000}},	//   _árbo, _पहली_, zdés_,
  { {0x4429506b,0xdc55007e,0xdb010003,0x00000000}},	//   zwa_, مریک, illè,
  { {0x7c29021f,0xd90f006a,0x44290051,0x00000000}},	//   bwer, ریخ_, ywa_,
  { {0x87e40085,0x00000000,0x00000000,0x00000000}},	//   зюсе,   ,   ,
  { {0xd7f80076,0x69da49de,0xb87b0025,0x00000000}},	//   щую_, ppte, daít,
  { {0x7aea003b,0x4b7b0149,0x26d10022,0x00000000}},	//   _ieft, _תאוו, rczo_,
  { {0x4429506c,0x6b9a00cd,0xdce200c2,0x00000000}},	//   twa_, lotg, _oloč,
  { {0x44290009,0x3f87001f,0x69cd001c,0x00000000}},	// [9c30] uwa_, ynnu_, ēneš,
  { {0xe2f90086,0x4429506d,0x7aea0dd4,0x00000000}},	//   режі_, rwa_, _jeft,
  { {0x7d0900e8,0x442914f1,0x201f003b,0x00000000}},	//   yges, swa_, _spui_,
  { {0x44290380,0x80e30053,0xe2980054,0x00000000}},	//   pwa_, खरेख_, щає_,
  { {0x44290089,0x7af80066,0xf1940054,0x00000000}},	//   qwa_, _odvt, чиць,
  { {0xef180054,0x9e090044,0x00000000,0x00000000}},	//   ймі_, ليتك_,   ,
  { {0x7d09301c,0x7c29006f,0x6735006f,0x00000000}},	//   tges, wwer, idzj,
  { {0x7c293ed9,0x7f9f0003,0xed5905bd,0x00000000}},	//   twer, vêqu, рои_,
  { {0x69ca00bd,0x7c2910ce,0x69d8031c,0x00000000}},	//   _aufe, uwer, _atve,
  { {0x7c29506e,0xdce00006,0x7d09135e,0x00000000}},	//   rwer, kimė, sges,
  { {0x7aea005b,0xdd9901d9,0x7d090983,0x00000000}},	//   _deft, poň_, pges,
  { {0x7bdb00fe,0x98a6005a,0xdb01506f,0x00000000}},	//   ppuu, жиме, illé,
  { {0xb87b0460,0x6ca7005d,0x69ca5070,0x00000000}},	//   daís, _اصال, _eufe,
  { {0xe73a0138,0xd6da005d,0xacb6009d,0x00000000}},	//   шег_, شورش_, _והנח_,
  { {0x857a0002,0x7bcb0294,0xd62a20e5,0x00000000}},	//   асат_, _hugu, шове_,
  { {0x656d0273,0x7bcb0035,0x7bc35071,0x00000000}},	//   ghah, _kugu, _hinu,
  { {0x64a31a58,0x7bc35072,0x7bcb3e27,0x00000000}},	// [9c40] дата, _kinu, _jugu,
  { {0x63600199,0xdb18000f,0xb87b0025,0x00000000}},	//   _köni, _kivá, raít,
  { {0x7bcb2bfd,0x24960078,0x7bc35073,0x00000000}},	//   _lugu, _žemę_, _minu,
  { {0x7bc338a1,0x5a0c00b5,0xdce25074,0x00000000}},	//   _linu, רלאַ, _ploč,
  { {0x644b0019,0xdb010003,0x2eee3eee,0x00000000}},	//   ägit, allé, taff_,
  { {0x44220089,0x7bc35075,0xb033013c,0x00000000}},	//   _ipk_, _ninu, ьніш,
  { {0xdbd10016,0x2eee5076,0x7bcb5077,0x00000000}},	//   qüên, raff_, _augu,
  { {0x442200f3,0x7bc32c84,0x98ab000c,0x00000000}},	//   _kpk_, _ainu, ndcă_,
  { {0xdca30138,0x7bc3002c,0x69ca000c,0x00000000}},	//   маћи, _binu, _sufe,
  { {0xb4db0268,0x7bcb5078,0x44225079,0x00000000}},	//   _anàl, _dugu, _mpk_,
  { {0x78ad00ea,0xf2d30063,0x7aea0014,0x00000000}},	//   _szav, ועת_, _veft,
  { {0x7bc3007a,0xdb030016,0xfc660062,0x00000000}},	//   _einu, _sinô, _мълн,
  { {0x7bcb2983,0x75360022,0xf8b00021,0x00000000}},	//   _gugu, ddyz, َةُ_,
  { {0x02aa016a,0x7bc3507a,0x60210026,0x00000000}},	//   _करून, _ginu, _hámö,
  { {0x69d8507b,0x44220150,0x7bcb004d,0x00000000}},	//   _utve, _apk_, _zugu,
  { {0xb87b048e,0x3f9c017f,0x4422419f,0x00000000}},	//   abía, hovu_, _bpk_,
  { {0xb87b0460,0x78ad0114,0x4422007d,0x00000000}},	// [9c50] raís, _uzav, _cpk_,
  { {0x7c22115c,0x68ed507c,0x43740054,0x00000000}},	//   _mpor, _head, муєт,
  { {0x68ed0974,0x64400026,0x69ce0066,0x00000000}},	//   _kead, _ámin, íbeh,
  { {0x4174007e,0x7c220955,0x81c80054,0x00000000}},	//   وانس, _opor, ігів_,
  { {0x68ed45ce,0xb3670062,0xb97c0047,0x00000000}},	//   _mead, _дъвк, סנדי,
  { {0x3f9c017f,0xdfce04f6,0x68ed11a0,0x00000000}},	//   govu_, ديو_, _lead,
  { {0x7bc30b10,0x7bcb27fe,0xa6fc0063,0x00000000}},	//   _rinu, _sugu, שִׂי,
  { {0x7bcb0994,0x7bc3507d,0x7c220139,0x00000000}},	//   _pugu, _sinu, _bpor,
  { {0x7bc3002c,0x9c220076,0xec790002,0x00000000}},	//   _pinu, едыд, спп_,
  { {0x3b090138,0x59cf0053,0x7c220066,0x00000000}},	//   љено_, _संदर, _dpor,
  { {0x27e92133,0xdcfb0078,0x7bc3507e,0x00000000}},	//   _awan_, liuč, _vinu,
  { {0x68ed0025,0xbea8007e,0x799d002b,0x00000000}},	//   _cead, _بهمن_, gosw,
  { {0x7bc3002c,0x69c40019,0x68ed507f,0x00000000}},	//   _tinu, _viie, _dead,
  { {0x60c90983,0x44225080,0x7bc3004b,0x00000000}},	//   _lgem, _rpk_, _uinu,
  { {0x68ed0025,0xdcfb007d,0x442207b7,0x00000000}},	//   _fead, gnuć, _spk_,
  { {0x68ed1294,0x3f9c007c,0x442201ec,0x00000000}},	//   _gead, zovu_, _ppk_,
  { {0x27e9002f,0x7c225081,0xa2be0042,0x00000000}},	// [9c60] _gwan_, _xpor, वेन्,
  { {0x083b014e,0xc2b6005e,0x6b810058,0x00000000}},	//   _פעיל, пљењ, nilg,
  { {0xb6a30164,0xa2ce0053,0x35a62017,0x00000000}},	//   éâtr, तशब्, _наог,
  { {0x4fc65082,0x7c3b00b9,0x69fa0047,0x00000000}},	//   пска, kvur, מלעק,
  { {0xdbd10268,0x6b810026,0x3f9c5083,0x00000000}},	//   qüèn, kilg, tovu_,
  { {0x60c95084,0x33b50121,0x7d1b44b8,0x00000000}},	//   _egem, _жёст, efus,
  { {0x7d1b5085,0x7c225086,0x60cd008f,0x00000000}},	//   ffus, _spor, žama,
  { {0x3f9c0743,0x6b810025,0x7d780021,0x00000000}},	//   sovu_, eilg, تمبر_,
  { {0x2055000a,0x69d50080,0x68ed3fb3,0x00000000}},	//   _отфр, ízen, _read,
  { {0x68ed1fc9,0x4477014e,0x3ea500d1,0x00000000}},	//   _sead, פעיל_, _fylt_,
  { {0x68ed4a1d,0xd5be0053,0x27e95087,0x00000000}},	//   _pead, ्दाज, _swan_,
  { {0x523b0047,0xe9810085,0x3999013d,0x00000000}},	//   צײכנ, тамi_, lész_,
  { {0x7c220fbf,0x68ed017d,0xfce30002,0x00000000}},	//   _upor, _vead, _чочо,
  { {0xc7c407b0,0x68e00058,0x6d5900ca,0x00000000}},	//   есси, ımda, _zowa,
  { {0x68ed0004,0x66b40001,0x3a3a013d,0x00000000}},	//   _tead, ебру, _épp_,
  { {0xd49b0002,0xa634000d,0xc87f004d,0x00000000}},	//   брз_, энсі, faßt_,
  { {0xdcfb007d,0x78fc009a,0x3999013d,0x00000000}},	// [9c70] snuć, _הפחו, kész_,
  { {0x6e2d0022,0x8afc0022,0x60c9002b,0x00000000}},	//   łabi, chęt, _sgem,
  { {0x35b5123e,0x3999013d,0x0667005d,0x00000000}},	//   _обор, dész_, _رادپ,
  { {0x92b40044,0x2509005d,0x00000000,0x00000000}},	//   رحلا, _بردی_,   ,
  { {0xf99f0290,0x261700be,0xdb180072,0x00000000}},	//   ioè_, lço_, _kivä,
  { {0x6d5900e8,0xbea51001,0x25a95088,0x00000000}},	//   _sowa, малк, llal_,
  { {0x26170016,0x6d590051,0x39490025,0x00000000}},	//   nço_, _powa, _onas_,
  { {0x61fa0026,0xc2120063,0x1c450499,0x00000000}},	//   _ætla, _שהן_, дним,
  { {0x6b815089,0x7d1b255a,0x104b0054,0x00000000}},	//   tilg, rfus, _уяви_,
  { {0x7c3b508a,0x39494f5d,0x25a90058,0x00000000}},	//   rvur, _anas_, hlal_,
  { {0x6d590886,0x6e670121,0x7c3b4d2b,0x00000000}},	//   _towa, _этаж, svur,
  { {0xb87b01c8,0x5e9a009a,0xf769009a,0x00000000}},	//   rbín, _ובעק, _דק_,
  { {0x02aa0053,0x6b811013,0x59cf0042,0x00000000}},	//   _कर्न, pilg, _संवर,
  { {0x3ea0000c,0xae210053,0x394900a5,0x00000000}},	//   şite_, _महान_, _enas_,
  { {0x637200b9,0x46a31dd6,0xe5a60c46,0x00000000}},	//   _hæng, варв, диви,
  { {0xdb18024a,0x6995000d,0x05aa000d,0x00000000}},	//   _eivä, _прых, івай_,
  { {0xfc4a0014,0xe5a34890,0x2d8d0168,0x00000000}},	// [9c80] mtíð_, тити, inee_,
  { {0x63720146,0x7413007e,0x91e603d6,0x00000000}},	//   _mæng, ئولا, доже,
  { {0x6372010a,0x3999013d,0x21761b43,0x00000000}},	//   _læng, vész_, мудр,
  { {0x26d82443,0x290f0137,0x6e3c0460,0x00000000}},	//   lcro_, _ögat_, _árbi,
  { {0xdfcf08aa,0x2d9f0003,0x3999013d,0x00000000}},	//   لين_, doue_, tész_,
  { {0x6d5d01e9,0x26d8508b,0xcdda005e,0x00000000}},	//   ösan, ncro_, оњи_,
  { {0x636000ea,0xde93005e,0x216a049f,0x00000000}},	//   _dönt, кашњ, _диви_,
  { {0x60260001,0x8c660054,0x2cea071f,0x00000000}},	//   _одба, дтод, цько_,
  { {0x39490168,0xc0d30044,0x00000000,0x00000000}},	//   _rnas_, _شيلب,   ,
  { {0x25a00025,0xdb0a0139,0xba540092,0x00000000}},	//   hoil_, _bhfá, евој,
  { {0xc3330132,0x2d9f00ac,0xdb180ddc,0x00000000}},	//   דות_, boue_, _nivå,
  { {0x63721c2b,0x63600137,0x2d9f006c,0x00000000}},	//   _hænd, _köns, coue_,
  { {0x6360508c,0xa3c00053,0xa2be0053,0x00000000}},	//   _yönt, ुदा_, वेत्,
  { {0x636000c7,0x0a940088,0x2d84508d,0x00000000}},	//   _möns, _палю, lime_,
  { {0x637200b9,0x63600137,0x2d84004b,0x00000000}},	//   _mænd, _löns, oime_,
  { {0x26170016,0x394902dd,0x636000c7,0x00000000}},	//   rço_, _unas_, _oöns,
  { {0x93b50001,0x4255007e,0x2d840072,0x00000000}},	// [9c90] ебац, کنار, iime_,
  { {0x2006002b,0xdb0a004d,0x2019008f,0x00000000}},	//   droi_, _eifö, _īsi_,
  { {0x15e80161,0x2d84508e,0x466b0054,0x00000000}},	//   टीआर_, kime_, _єром_,
  { {0x02df0161,0x25a0057a,0x20060003,0x00000000}},	//   _प्रभ, coil_, froi_,
  { {0x63600026,0x752d3b6d,0x60cd008f,0x00000000}},	//   _pönt, meaz, žamo,
  { {0x752d000c,0x63600014,0x2d8d508f,0x00000000}},	//   leaz, _döns, wnee_,
  { {0x62340076,0x69ca0053,0x11d40021,0x00000000}},	//   _иеру, _संगी, _لتقد,
  { {0x636001e3,0x752d000c,0x212b0139,0x00000000}},	//   _föns, neaz, _úch_,
  { {0x7e99006a,0x2d9f00ac,0x2d8d5090,0x00000000}},	//   _کنار_, roue_, rnee_,
  { {0x752d003b,0x6e67007b,0x2d845091,0x00000000}},	//   heaz, _отеж, aime_,
  { {0xd910007e,0x2d840078,0x60c40078,0x00000000}},	//   لیغ_, bime_, žimt,
  { {0x752d000c,0x2d845092,0x5c750867,0x00000000}},	//   jeaz, cime_, _плет,
  { {0xc7960076,0x60db0035,0x26cc0024,0x00000000}},	//   ервы, _mfum, ždom_,
  { {0x907a0149,0x3f790041,0x656f5093,0x00000000}},	//   לטרי, לאָס, _alch,
  { {0x25a0004e,0xf5b60085,0xa96a5094,0x00000000}},	//   toil_, есаю, _ника_,
  { {0xc6c3000d,0x7dc700ea,0xe5a6197b,0x00000000}},	//   уйск, _műso, хиби,
  { {0x0903000d,0x09b7009a,0x00000000,0x00000000}},	// [9ca0] _спын, _אפקט_,   ,
  { {0x138a0021,0x27e00006,0x79865095,0x00000000}},	//   أخرى_, _itin_, likw,
  { {0x32170021,0x2bb20053,0x42560044,0x00000000}},	//   فيلد_, ुगता, عنصر,
  { {0x2d845096,0x798602ae,0x6d4b00d1,0x00000000}},	//   xime_, nikw, _nnga,
  { {0x40340431,0xa0670001,0x2d845097,0x00000000}},	//   телс, наца_, vime_,
  { {0x6d4b5098,0x2006006c,0x443200a3,0x00000000}},	//   _anga, rroi_, mwy_,
  { {0x2d841b2d,0x2900213a,0x4432057c,0x00000000}},	//   time_, _odia_, lwy_,
  { {0x6da300e1,0xf6530063,0x44320051,0x00000000}},	//   лија, רצה_, owy_,
  { {0x79860009,0x63720146,0x4432001f,0x00000000}},	//   dikw, _tænd, nwy_,
  { {0x752d0529,0x637200b9,0x543b0047,0x00000000}},	//   zeaz, _uænd, לעפא,
  { {0x672e0146,0x2a6a000f,0x27e05099,0x00000000}},	//   debj, ább_, _atin_,
  { {0x752d003b,0x67d50815,0x092b00de,0x00000000}},	//   xeaz, кому, أسدي_,
  { {0x752d000c,0xb87b0066,0x38c9005d,0x00000000}},	//   veaz, mbík, بادی_,
  { {0x44320185,0x66012a2e,0xdb4f0085,0x00000000}},	//   dwy_, álko, _ёю_,
  { {0x752d0529,0x79a7323e,0x27e00058,0x00000000}},	//   teaz, _прие, _etin_,
  { {0x5558005a,0xe5340fdc,0x00000000,0x00000000}},	//   нася_, лесь,   ,
  { {0x7bca0009,0x752d0529,0x6aaa001f,0x00000000}},	// [9cb0] _kifu, reaz, _hyff,
  { {0x7bca0035,0x752d000c,0x60db0290,0x00000000}},	//   _jifu, seaz, _sfum,
  { {0x61ee001f,0x7bca0035,0x5187018e,0x00000000}},	//   _cwbl, _mifu, нуда,
  { {0x7ff54d95,0x92b40021,0xe0d001f3,0x00000000}},	//   نستا, احكا, مزه_,
  { {0xfbe7008b,0x78fc0041,0xb1990046,0x00000000}},	//   _chế_, לפאו, _þðmá,
  { {0x257e004c,0x083c0063,0xb68b009d,0x00000000}},	//   vůli_, פעול, ּרֵ֥,
  { {0xed59014c,0x61ee001f,0x6aaa001f,0x00000000}},	//   дой_, _gwbl, _nyff,
  { {0x27ed0080,0x60db00ac,0x61e5509a,0x00000000}},	//   šeny_, _ufum, mphl,
  { {0x10040062,0x7bca1bae,0xdfd50766,0x00000000}},	//   _бяхм, _bifu, _розы,
  { {0x0b420597,0x4a450d82,0x200f40d5,0x00000000}},	//   аньн, внов, mugi_,
  { {0x6aaa0185,0x44320051,0x200f3490,0x00000000}},	//   _cyff, zwy_, lugi_,
  { {0x6d4b509b,0x6aaa001f,0x69dc0025,0x00000000}},	//   _unga, _dyff, írea,
  { {0x5d7a0041,0xdb01013d,0x31560041,0x00000000}},	//   _קאנק, allá, דירן_,
  { {0x3f87509c,0xa91b0046,0x79860244,0x00000000}},	//   ninu_, niþj, sikw,
  { {0x6aaa001f,0xf8c700ea,0x200f004b,0x00000000}},	//   _gyff, éért_, hugi_,
  { {0x16140161,0x7bca0035,0x44320051,0x00000000}},	//   तंबर_, _zifu, twy_,
  { {0xf773006a,0x3f87007a,0xccf20e2a,0x00000000}},	// [9cc0] _چاپ_, kinu_, יכן_,
  { {0x200f0019,0xc88700bd,0x44321ac6,0x00000000}},	//   dugi_, ößer_, rwy_,
  { {0x7ae50019,0xf5062c47,0x3f870d9a,0x00000000}},	//   _õhtu, _изно, dinu_,
  { {0x4a5a01d8,0xafe60088,0x61430076,0x00000000}},	//   ודעו, водл, иеха,
  { {0x3f870026,0x200f0019,0xb87b05ab,0x00000000}},	//   finu_, gugi_, acíf,
  { {0xa0670001,0x3f87509d,0x9207008f,0x00000000}},	//   ђаја_, ginu_, _stāš,
  { {0x7bca0290,0xdb0100ac,0x61e50139,0x00000000}},	//   _rifu, polê, cphl,
  { {0xfbe7001b,0x224700b9,0xc5f30063,0x00000000}},	//   _thế_, ænke_, בדה_,
  { {0xdb0101e1,0x3f87371c,0xbfc634ba,0x00000000}},	//   illæ, binu_, _абак,
  { {0x3f87509e,0x81c7008f,0x3ce20042,0x00000000}},	//   cinu_, amēģ, _ट्रे_,
  { {0x7bca0009,0xe9f8000d,0x6a6b0014,0x00000000}},	//   _vifu, энні_, vöfö,
  { {0x79a40121,0x6446509f,0xfce64107,0x00000000}},	//   иряе, _orki, _родо,
  { {0x7d02017d,0x3834130d,0x7bca50a0,0x00000000}},	//   _idos, аняр, _tifu,
  { {0x25750831,0xe7870699,0x248d0078,0x00000000}},	//   _måle_, тумо, _žemo_,
  { {0xfbb7014e,0x644650a1,0xba550013,0x00000000}},	//   _שפות_, _arki, _vắcx,
  { {0x3f871ff8,0x69cb0053,0x39154345,0x00000000}},	//   zinu_, _सूची, _смир,
  { {0xf8bf0003,0x257501e1,0x83f806da,0x00000000}},	// [9cd0] ffée_, _nåle_, кетс_,
  { {0x38640137,0x81c7001c,0x41e701dd,0x00000000}},	//   ämre_, zmēģ, віда,
  { {0x7d02034d,0x3f87147d,0x644650a2,0x00000000}},	//   _odos, vinu_, _erki,
  { {0xe4e40086,0x200f004b,0xe1f00044,0x00000000}},	//   _вірн, tugi_, تسك_,
  { {0x2bce0235,0x3f871613,0x25750137,0x00000000}},	//   _हंगा, tinu_, _våld_,
  { {0x753d03e8,0x61e50014,0x443950a3,0x00000000}},	//   _hasz, pphl, _iss_,
  { {0x753d101d,0x443940e9,0x3f8750a4,0x00000000}},	//   _kasz, _hss_, rinu_,
  { {0x2294019d,0x442b00f3,0x63a5004d,0x00000000}},	//   _тися, _kpc_, lohn,
  { {0x69dc034d,0x7d02001f,0x753d1149,0x00000000}},	//   íren, _ddos, _masz,
  { {0x442b50a5,0x7d0250a6,0x765a0072,0x00000000}},	//   _mpc_, _edos, ätyk,
  { {0x198a0794,0x656d4645,0x6a940054,0x00000000}},	//   ебни_, kkah, ирює,
  { {0x753d0045,0x44391699,0xe71a005d,0x00000000}},	//   _nasz, _oss_, کيست_,
  { {0x291e0051,0x69cd1e3d,0x8884005d,0x00000000}},	//   ęta_, _diae, شیدن,
  { {0xf746005e,0x7d020066,0x8c28009a,0x00000000}},	//   ћево, _zdos, _יֵצֵ,
  { {0x7bc10199,0xdb2200ea,0x443950a7,0x00000000}},	//   mmlu, _óráb, _ass_,
  { {0x6d5b06a7,0x656d002c,0x798400a4,0x00000000}},	//   njua, gkah, _umiw,
  { {0x9f4f0026,0xe3ba197a,0x753d0022,0x00000000}},	// [9ce0] yrgð_, еба_, _dasz,
  { {0x656d00a4,0x74130021,0x44390c1c,0x00000000}},	//   akah, صوما, _dss_,
  { {0xe2160032,0x442b0222,0x471b0149,0x00000000}},	//   طباع, _epc_, _אויג,
  { {0x7c2b50a8,0xa49b00cd,0xdb010003,0x00000000}},	//   _opgr, _idòn, solè,
  { {0x673e00ea,0x68f6005b,0xd0d70054,0x00000000}},	//   _kapj, _meyd, удії_,
  { {0x27f20185,0x753d0051,0x8fa308ac,0x00000000}},	//   _mwyn_, _zasz, баче,
  { {0x7bdd007a,0x09cf0053,0xdb0150a9,0x00000000}},	//   ísun, _संगठ, illä,
  { {0x442000eb,0x9f960019,0x673e00ea,0x00000000}},	//   oti_, lüüs_, _lapj,
  { {0x442050aa,0x752400ea,0x61fe50ab,0x00000000}},	//   nti_, ifiz, lspl,
  { {0xf0630138,0x673e1954,0x409502d8,0x00000000}},	//   _укуп, _napj, _трст,
  { {0x44200aba,0x6b884d81,0x28c70053,0x00000000}},	//   hti_, ridg, रेनि,
  { {0x7d020051,0x442050ac,0x61fe50ad,0x00000000}},	//   _udos, kti_, ispl,
  { {0x4420280e,0x7e6a00ac,0x27f2002b,0x00000000}},	//   jti_, lyfp, _cwyn_,
  { {0x443950ae,0x752400ea,0x27f2001f,0x00000000}},	//   _rss_, efiz, _dwyn_,
  { {0x7afa024a,0x752400bd,0x63a50124,0x00000000}},	//   matt, ffiz, vohn,
  { {0x63a500bd,0x61fe0f4b,0x44394ca4,0x00000000}},	//   wohn, dspl, _pss_,
  { {0x656d3fce,0x27f2001f,0xdb030025,0x00000000}},	// [9cf0] rkah, _gwyn_, _ghnó,
  { {0x2d81000f,0x753d0051,0x7bdf0003,0x00000000}},	//   éhez_, _wasz, _éque,
  { {0x7afa0290,0x44203873,0x6440008f,0x00000000}},	//   iatt, ati_, _šmit,
  { {0x7afa50af,0x442050b0,0x6d4000ca,0x00000000}},	//   hatt, bti_, jdma,
  { {0xb97c00b5,0xdb0150b1,0xa0a5007b,0x00000000}},	//   ענדי, solé, јалд,
  { {0x6d47003d,0x7afa00fe,0xdb0138db,0x00000000}},	//   ējam, jatt, polé,
  { {0x7afa0f22,0x539a0063,0x6d40006f,0x00000000}},	//   datt, _יישו, fdma,
  { {0xdb0100c7,0x63bc0066,0x6d5b017e,0x00000000}},	//   illå, _zhrn, ujua,
  { {0x6d5b0974,0x7afa4789,0xeb990f9f,0x00000000}},	//   rjua, fatt, кии_,
  { {0x8b690002,0xf53f1310,0x27f2002b,0x00000000}},	//   тиов_, _skål_, _rwyn_,
  { {0x442000ea,0x27f2002b,0x5fba0041,0x00000000}},	//   zti_, _swyn_, _סצענ,
  { {0x213f06a7,0x44202d02,0x6443003d,0x00000000}},	//   _jauh_, yti_, ānij,
  { {0x7afa50b2,0x442050b3,0x7c2b50b4,0x00000000}},	//   batt, xti_, _upgr,
  { {0xcf9200b5,0x1ae5000a,0x7afa50b5,0x00000000}},	//   ַטן_, _токм, catt,
  { {0x24f60f55,0x96630b4c,0x6146013d,0x00000000}},	//   ичар, окре, lélő,
  { {0x442050b6,0x1a9a00ff,0x63bc004c,0x00000000}},	//   tti_, _שיקע, _shrn,
  { {0x31bc0080,0xd4670189,0x63860002,0x00000000}},	// [9d00] níze_, аите_, агаа,
  { {0x261e001f,0x44204569,0x752400be,0x00000000}},	//   pïo_, rti_, sfiz,
  { {0x201f03d9,0x4256064b,0x6444065c,0x00000000}},	//   _aqui_, штат, svii,
  { {0x442050b7,0x394013f5,0x7afa00ea,0x00000000}},	//   pti_, _jais_, zatt,
  { {0x394011eb,0x61e91260,0x7afa0058,0x00000000}},	//   _mais_, _čele, yatt,
  { {0x42e70079,0x26cc01c2,0x3940002b,0x00000000}},	//   _вмро_, ždou_, _lais_,
  { {0x7afa50b8,0xdd9a173e,0x3ec30094,0x00000000}},	//   vatt, кши_, осъб,
  { {0x2caf1609,0x394000bb,0x5d5406cb,0x00000000}},	//   _bygd_, _nais_, скит,
  { {0x1be7005e,0x6d4050b9,0x7afa50ba,0x00000000}},	//   адњи_, rdma, tatt,
  { {0x39520994,0x25750147,0x7ac6064b,0x00000000}},	//   _anys_, _måla_, исне,
  { {0x7afa50bb,0xfe720021,0x39400150,0x00000000}},	//   ratt, _بدء_, _bais_,
  { {0x39400185,0x64490006,0x7afa50bc,0x00000000}},	//   _cais_, _šeim, satt,
  { {0xb87b0080,0xc86450bd,0x3940006c,0x00000000}},	//   dcíc, отри, _dais_,
  { {0x3ea90529,0x38640137,0xd7f80895,0x00000000}},	//   şate_, ämra_, шую_,
  { {0xf1bf0024,0x39400164,0x3bbb0063,0x00000000}},	//   žšia_, _fais_, _שמוד,
  { {0xda5b014e,0x394027eb,0x224d08ed,0x00000000}},	//   _יכול, _gais_, _ček_,
  { {0xa99c0063,0x54b90895,0x213f0244,0x00000000}},	// [9d10] _שבחר, угая_, _rauh_,
  { {0xddce0024,0x28c70053,0xb35450be,0x00000000}},	//   ždňo, रेणि, окуш,
  { {0x3952001f,0x213f0d52,0x69d82e47,0x00000000}},	//   _ynys_, _pauh_, _juve,
  { {0x29190e53,0xb87b00ea,0x637200b9,0x00000000}},	//   ngsa_, bbít, _fæno,
  { {0x5045000a,0x59d00053,0x69d800ac,0x00000000}},	//   селб, _संघर, _luve,
  { {0x69d80164,0x543a0047,0x6fd40086,0x00000000}},	//   _ouve, _געשא, іціє,
  { {0xc293007e,0x925809b3,0x69d850bf,0x00000000}},	//   _بیاب, _карт_, _nuve,
  { {0x59dd0042,0x68fd008f,0x0698009a,0x00000000}},	//   _नंबर, jasd, ידום_,
  { {0x39400ebe,0x69d81e92,0x4d460085,0x00000000}},	//   _rais_, _auve, спын_,
  { {0x394050c0,0x4ea715ba,0x69d850c1,0x00000000}},	//   _sais_, _креа, _buve,
  { {0x39400577,0xd9460b4a,0xa96a0fec,0x00000000}},	//   _pais_, бени, гина_,
  { {0x69d850c2,0x59831213,0xdd8f005d,0x00000000}},	//   _duve, злюб, _کوچ_,
  { {0x9cda0047,0x394050c3,0xc19a0047,0x00000000}},	//   _עקספ, _vais_, רשרי,
  { {0xdb18017d,0x6a25005d,0x6608243c,0x00000000}},	//   _divó, _هفتم, ádko,
  { {0x69d850c4,0x394050c5,0x26180053,0x00000000}},	//   _guve, _tais_, बंधी_,
  { {0x3940017d,0xdb1a0014,0xb87b004c,0x00000000}},	//   _uais_, mmtá, ucíc,
  { {0xb87b18dd,0x69d800bd,0x3164004b,0x00000000}},	// [9d20] rcíc, _zuve, _romz_,
  { {0x67350051,0x26180053,0xb87b50c6,0x00000000}},	//   cezj, बंदी_, scíc,
  { {0xb87b37c9,0xe5a60141,0x69c600ca,0x00000000}},	//   sbít, _гини, omke,
  { {0xd0e8005d,0xa1130044,0x00000000,0x00000000}},	//   شکرم_, كومت,   ,
  { {0x30140086,0x7f410089,0xb87b00ea,0x00000000}},	//   ідкр, _balq, lbír,
  { {0xb87b006d,0xb7db0047,0x98ab00dd,0x00000000}},	//   ncía, אקסי, lecă_,
  { {0x41b6007e,0xddd40066,0x637b00dd,0x00000000}},	//   _همسر, ťažu, _sîng,
  { {0x2d8d00ac,0x8cc40053,0x98ab003b,0x00000000}},	//   giee_, ाइलो, necă_,
  { {0x65660089,0x205600e1,0x69d850c7,0x00000000}},	//   _mokh, _утвр, _suve,
  { {0x4f650021,0x68e4251e,0xc43b0063,0x00000000}},	//   _والف, _afid, נתיי,
  { {0x99990079,0x25a90150,0x6935026c,0x00000000}},	//   икот_, yoal_, онну,
  { {0x3f8e0035,0xd2b70063,0x61fa0014,0x00000000}},	//   lifu_, מלית_, _ætlu,
  { {0x98ab003b,0xbda50021,0x68fd005f,0x00000000}},	//   decă_, _بحلو, rasd,
  { {0x3f8e0035,0x7bdf0164,0x69c60014,0x00000000}},	//   nifu_, _équa, amke,
  { {0xa5f90001,0x656650c8,0x68e4002b,0x00000000}},	//   ребу_, _bokh, _ffid,
  { {0xb87b0331,0x56940f50,0x3d060042,0x00000000}},	//   acía, част, _षयों_,
  { {0x981701fb,0xdd1c0061,0x24190766,0x00000000}},	// [9d30] _ابعا, kážk, розы_,
  { {0x25a950c9,0x6d47001c,0x6360013d,0x00000000}},	//   soal_, ējai, _köny,
  { {0xa4d50636,0xd2510021,0x765a0072,0x00000000}},	//   _моні, بنا_, ätyt,
  { {0xdb0150ca,0x66010014,0x2127005d,0x00000000}},	//   volí, álku, صيتی_,
  { {0x237800a8,0xdcee004c,0x1ee7005d,0x00000000}},	//   _flrj_, žděl, موشی_,
  { {0x2127007e,0x2d9a00ea,0xdb01027d,0x00000000}},	//   _گيری_, épen_, tolí,
  { {0x171c0bd9,0xdb18004a,0x01e9009a,0x00000000}},	//   אווע, _chví, _כַּֽ,
  { {0x637b0003,0x27e950cb,0xdb0150cc,0x00000000}},	//   _dîne, _otan_, rolí,
  { {0x3f8e0035,0x2d8d00ac,0x3ea90051,0x00000000}},	//   bifu_, riee_, łat_,
  { {0x68e408c8,0x3b090001,0x1a050d82,0x00000000}},	//   _sfid, јено_, опом,
  { {0xeab10032,0x2d8d00ac,0x27e92eea,0x00000000}},	//   بعة_, piee_, _atan_,
  { {0x3a980076,0xd8260131,0x0dcb05e0,0x00000000}},	//   стью_, одми, _сузи_,
  { {0xa13a0047,0x913a0041,0xeb8e0a55,0x00000000}},	//   בערח, בערק, _жи_,
  { {0x7d1b0019,0x257c50cd,0xdb1f0072,0x00000000}},	//   lgus, _míle_, äväp,
  { {0x212d2414,0x98ab003b,0x7d1b40d5,0x00000000}},	//   _obeh_, tecă_, ogus,
  { {0x7c2400dd,0x7d1b50ce,0x057a0044,0x00000000}},	//   _ţiri, ngus, جمرة_,
  { {0x7d1b0019,0x61e91035,0x7c3b004d,0x00000000}},	// [9d40] igus, _čela, nwur,
  { {0x257500c7,0x656600e8,0xc2b6005e,0x00000000}},	//   _håll_, _wokh, ољењ,
  { {0xe0da50cf,0x021a0054,0x7c3b0244,0x00000000}},	//   аве_, різь_, hwur,
  { {0x64430051,0x27e90137,0xc1780078,0x00000000}},	//   łnia, _ytan_, _įės_,
  { {0x3f8e0035,0x257c0080,0x4fc609b4,0x00000000}},	//   tifu_, _cíle_, оска,
  { {0xe45101f9,0x7d1b1711,0xdce2005b,0x00000000}},	//   _אֶל_, egus, _bloğ,
  { {0x3f8e0009,0xdd1c0061,0x7d1b004d,0x00000000}},	//   rifu_, rážk, fgus,
  { {0x7176014d,0xdb08006c,0x7d1b337e,0x00000000}},	//   _بهرا, modé, ggus,
  { {0xe8160082,0x00000000,0x00000000,0x00000000}},	//   _तमगा_,   ,   ,
  { {0x7d1b002c,0xe45700b5,0x8afc0051,0x00000000}},	//   agus, קייט_, djęc,
  { {0x27e950d0,0xd006005d,0x4ce6089a,0x00000000}},	//   _stan_, کل_, _джеб,
  { {0x49740085,0xf8bf013d,0x00000000,0x00000000}},	//   длюс, bfél_,   ,
  { {0x7dd500eb,0xd7fb0001,0x798f002b,0x00000000}},	//   _išsa, јум_, ricw,
  { {0x7d0050d1,0x28c70053,0x290405ec,0x00000000}},	//   lams, रेषि, ómar_,
  { {0x5559005a,0xb7bb017d,0x86240076,0x00000000}},	//   бавя_, stão, мьте,
  { {0x7d0050d2,0x66020022,0xdb01013d,0x00000000}},	//   nams, _łokc, molá,
  { {0x27e950d3,0xd3750001,0x43070044,0x00000000}},	// [9d50] _utan_, плаћ, قذاف,
  { {0x27e9001c,0x6b9a004d,0x7d1b003b,0x00000000}},	//   ķinā_, nntg, zgus,
  { {0x35f4000d,0x7d1b0058,0x28c70053,0x00000000}},	//   _опэр, ygus, रेरि,
  { {0xe9380047,0x3634007e,0xf5590021,0x00000000}},	//   ַנוץ_, _کریس, _الحب_,
  { {0xdbd60072,0x7d1b08ed,0xdee52977,0x00000000}},	//   nään, vgus, поли,
  { {0x3fab005e,0xa3f60063,0xa5d8007e,0x00000000}},	//   шњем_, _ממשק_, _دبیر_,
  { {0x7d00001f,0xdb080331,0x9156004c,0x00000000}},	//   fams, codé, áříc,
  { {0xdb0100ea,0x7c3b0321,0x7d1b50d4,0x00000000}},	//   dolá, twur, ugus,
  { {0xdbd60ff2,0x7d1b50d5,0x1c450054,0x00000000}},	//   jään, rgus, їном,
  { {0x3f140001,0x547c0063,0x7c3b004d,0x00000000}},	//   _одус, יטחו, rwur,
  { {0x63720146,0xd9461a5c,0x8d770021,0x00000000}},	//   _sænk, пени, _واصا,
  { {0xac1908a6,0xdb0a0025,0x7d25007e,0x00000000}},	//   _году_, _bhfó, _رفتن,
  { {0xb87b0025,0x48b60062,0x28c70042,0x00000000}},	//   scín, ящот, रेलि,
  { {0xb87b0025,0x61e9059d,0x2b180042,0x00000000}},	//   pcín, _čeln, _दाएँ_,
  { {0x644b0026,0xdb0105d5,0x644f50d6,0x00000000}},	//   ægin, colá, _arci,
  { {0x63720146,0x7ae60080,0x6abc004d,0x00000000}},	//   _tænk, ěkte, ürfe,
  { {0x130a000d,0xb87b017d,0xf3f10013,0x00000000}},	// [9d60] йнай_, ncíl, _ặc_,
  { {0x29020c96,0x6e2d0022,0x69d60058,0x00000000}},	//   laka_, łaby, _hiye,
  { {0x11d6006a,0x7dc5006d,0xdce200c2,0x00000000}},	//   ستاد, mósf, _sooč,
  { {0x290250d7,0xe5a603d6,0x6a9a0047,0x00000000}},	//   naka_, _хими, זשענ,
  { {0x69d600bb,0xdb0100ea,0x65620019,0x00000000}},	//   _miye, zolá, öohu,
  { {0x78b60072,0x7f1a071f,0x90530085,0x00000000}},	//   _myyv, сіду_, эвіц,
  { {0x2902002c,0x7fd50054,0x7ee30021,0x00000000}},	//   kaka_, фіці, ركين,
  { {0x290250d8,0xd29b0063,0x6143019b,0x00000000}},	//   jaka_, _השלט, _песа,
  { {0x290250d9,0x7d0050da,0x321a004c,0x00000000}},	//   daka_, rams, lupy_,
  { {0xdb0100ea,0x807b0063,0x7d003fed,0x00000000}},	//   tolá, _הנמצ, sams,
  { {0x69d600a4,0x290250db,0x7bc800df,0x00000000}},	//   _biye, faka_, rmdu,
  { {0xdc2a006a,0xdb0100ea,0x644a001c,0x00000000}},	//   _هسته_, rolá, āfij,
  { {0xdb01000f,0x6c34007e,0x69d6005b,0x00000000}},	//   solá, _آفتا, _diye,
  { {0x29020050,0xdb0150dc,0x321a3ebb,0x00000000}},	//   aaka_, polá, kupy_,
  { {0x290250dd,0x8b8b0063,0xdbd60656,0x00000000}},	//   baka_, _לָהֶ, rään,
  { {0x2006024a,0xdbd6024a,0x79a4000d,0x00000000}},	//   ksoi_, sään, _прые,
  { {0x24580121,0x24f8000d,0x7d1d01a8,0x00000000}},	// [9d70] пать_, янты_, òssi,
  { {0xd25b0088,0xa87c014e,0xf2c7000a,0x00000000}},	//   йце_, _לאחר, псен,
  { {0x799d004d,0x69d60058,0xe3b00021,0x00000000}},	//   onsw, _yiye, ارق_,
  { {0x637301f7,0x4095043e,0x00000000,0x00000000}},	//   _sını, ولار,   ,
  { {0x6443008f,0xb4d90042,0xc0e2005e,0x00000000}},	//   ānis, ाशी_, њошк,
  { {0x442950de,0x290250df,0x00000000,0x00000000}},	//   mta_, zaka_,   ,
  { {0xee39019d,0xc3320047,0x321a00e5,0x00000000}},	//   іни_, _שול_, cupy_,
  { {0xd6580063,0x442950e0,0x63720046,0x00000000}},	//   ליות_, ota_, _ræni,
  { {0x2d830006,0x69c4001f,0x44294d71,0x00000000}},	//   ėje_, _rhie, nta_,
  { {0x442950e1,0x69c42cf0,0x69d600a4,0x00000000}},	//   ita_, _shie, _siye,
  { {0x29023253,0x22430089,0x8e990021,0x00000000}},	//   taka_, _jsjk_, _بناء_,
  { {0x442950e2,0xdde9007e,0x6f03283c,0x00000000}},	//   kta_, _هرچه_, lanc,
  { {0x6d590886,0x8c450ac5,0x290250e3,0x00000000}},	//   _inwa, _целе, raka_,
  { {0x6d4950e4,0x290250e5,0x6f0350e6,0x00000000}},	//   ldea, saka_, nanc,
  { {0x6f030314,0x45d60121,0x290250e7,0x00000000}},	//   ianc, дцат, paka_,
  { {0x442950e8,0x60db00ac,0x60d60006,0x00000000}},	//   fta_, _ngum, žymi,
  { {0x6d490025,0x6f030fae,0x6564017e,0x00000000}},	// [9d80] idea, kanc, rjih,
  { {0x257c0080,0x6d4900fe,0x6f030c7c,0x00000000}},	//   _díla_, hdea, janc,
  { {0xa6ca006a,0x673c155a,0x442950e9,0x00000000}},	//   _گوگل_, merj, ata_,
  { {0x27e0024a,0x673c3214,0x321a0051,0x00000000}},	//   _kuin_, lerj, rupy_,
  { {0xc4830088,0x27e00164,0x29000016,0x00000000}},	//   _аляк, _juin_, _meia_,
  { {0x290050ea,0x6d59282c,0x673c2bd4,0x00000000}},	//   _leia_, _anwa, nerj,
  { {0x7c290837,0x6458008d,0x658c0058,0x00000000}},	//   eter, ̉aị, eşhi,
  { {0x27ed000c,0x7c2950eb,0x6da302f8,0x00000000}},	//   ţeni_, fter, кија,
  { {0x4f260138,0x673c014f,0x2b4750ec,0x00000000}},	//   _одаб, kerj, _banc_,
  { {0x661c0006,0x6d59001f,0x2d9800ea,0x00000000}},	//   kurk, _enwa, őre_,
  { {0x644d001c,0x661c0089,0x44290758,0x00000000}},	//   zvai, jurk, zta_,
  { {0x298b0086,0x44290835,0xdb08006d,0x00000000}},	//   існо_, yta_, modí,
  { {0xdb08006d,0x290000cd,0x61ee50ed,0x00000000}},	//   lodí, _deia_, _ltbl,
  { {0x673c171b,0x27e0006f,0x8c43005e,0x00000000}},	//   gerj, _duin_, _реље,
  { {0x67d40076,0x290047e3,0x0a6a0002,0x00000000}},	//   тору, _feia_, _фрли_,
  { {0xb4d9016a,0x628500c3,0x2cfb0041,0x00000000}},	//   ाशे_, vzho, ַלבא,
  { {0x644d2226,0x442950ee,0xf99f00cd,0x00000000}},	// [9d90] uvai, uta_, mnè_,
  { {0x752d50ef,0x661c3665,0x644d0f35,0x00000000}},	//   sfaz, burk, rvai,
  { {0xb1150001,0x661c0150,0xa1150021,0x00000000}},	//   емеш, curk, فوات,
  { {0x6f030b21,0xf9d900b5,0x7c2950f0,0x00000000}},	//   wanc, פֿעל, yter,
  { {0xd47900b5,0xe4a70095,0xdbd60072,0x00000000}},	//   _זאָל, _црно, _kääj,
  { {0x394900e8,0xa2950603,0x61fc002b,0x00000000}},	//   _laas_, _загі, _fwrl,
  { {0x6d49000c,0x2b47002b,0x6f0350f1,0x00000000}},	//   tdea, _ranc_, ranc,
  { {0x6f03236f,0x394900e8,0x7c2950f2,0x00000000}},	//   sanc, _naas_, tter,
  { {0xfc48001b,0x7c2950f3,0x2900003b,0x00000000}},	//   _cử_, uter, _reia_,
  { {0x290050f4,0x7c2906f1,0xfaf10021,0x00000000}},	//   _seia_, rter, دثة_,
  { {0xc3320047,0x7bd850f5,0x673c50f6,0x00000000}},	//   נוט_, _divu, verj,
  { {0x7aea00b9,0x6d5950f7,0x7c293849,0x00000000}},	//   _efft, _unwa, pter,
  { {0x27e00268,0x673c50f8,0x29000858,0x00000000}},	//   _quin_, terj, _veia_,
  { {0xa8750121,0xfbc51224,0xfaa51fa4,0x00000000}},	//   тующ, _ябло, _пало,
  { {0xcb120063,0x8f9a0063,0xdb010137,0x00000000}},	//   _עלה_, לישי, rolä,
  { {0x2d9f0164,0x661c005b,0x27e00983,0x00000000}},	//   nnue_, rurk, _tuin_,
  { {0xfc48001b,0x673c3414,0xa99b0063,0x00000000}},	// [9da0] _xử_, perj, _מבקר,
  { {0x74130021,0xe3b7023b,0xf7460131,0x00000000}},	//   اولا, ебу_, _џено,
  { {0xf6260085,0x8afc0022,0xd2600023,0x00000000}},	//   _ядно, djęl, āņos_,
  { {0xa87a0149,0xdb080061,0xc0e61862,0x00000000}},	//   ּאַר, vodí, ходк,
  { {0x25a000c2,0x26c7004c,0xdd90005d,0x00000000}},	//   mnil_, _únor_, یوت_,
  { {0x3dc650f9,0xdfcf04f6,0x6f01017e,0x00000000}},	//   _show_, مين_, _celc,
  { {0xfc4800aa,0x6f0150fa,0x25a011c0,0x00000000}},	//   _sử_, _delc, onil_,
  { {0x7bd809ff,0x5d54065b,0xc106005d,0x00000000}},	//   _sivu, ткит, _سوئي,
  { {0xdca3005e,0x10a3157c,0x25a0004e,0x00000000}},	//   лаћи, _битн, inil_,
  { {0xf8bf0164,0x25a000c2,0xdb08011b,0x00000000}},	//   ngée_, hnil_, podí,
  { {0xc3330132,0x25a000c2,0xddcf011b,0x00000000}},	//   אות_, knil_, řešo,
  { {0xbfa5001b,0xfc48001b,0x4c860429,0x00000000}},	//   hiệ, _tử_, _плев,
  { {0xdb08017d,0xdbd60072,0xb9090053,0x00000000}},	//   godã, _pääj, _बल_,
  { {0x394900ca,0x7dc50014,0xcb670505,0x00000000}},	//   _waas_, róse, _паче_,
  { {0x394950fb,0x6a860003,0x644648cb,0x00000000}},	//   _taas_, _défé, _aski,
  { {0x257c0080,0x25a000c2,0xd5b81578,0x00000000}},	//   _dílo_, gnil_, есу_,
  { {0x68ed005b,0x7dc50139,0x28c70042,0x00000000}},	// [9db0] _ifad, lósc, रेखि,
  { {0x889c0063,0x25a0004b,0x339b0044,0x00000000}},	//   _מבחי, anil_, أخرة_,
  { {0x22590021,0x644650fc,0x99870023,0x00000000}},	//   بلاد_, _eski, ļiņa_,
  { {0xd1780085,0xc0d50044,0x7d023dbb,0x00000000}},	//   нсіі_, نياب, _neos,
  { {0xe0ce0699,0xb87b004c,0x00e40054,0x00000000}},	//   рв_, ucíh, ужін,
  { {0x7bdf03b2,0x656f0199,0x4439314e,0x00000000}},	//   _équi, _hoch, _ips_,
  { {0xb87b00ea,0x44390150,0x63720026,0x00000000}},	//   gbíz, _hps_, _vænt,
  { {0x7dd500eb,0x6f010359,0xb6040066,0x00000000}},	//   _išsk, _welc, ýšit,
  { {0x7d02000c,0x656f50fd,0x44390089,0x00000000}},	//   _deos, _moch, _jps_,
  { {0x656f1fbf,0x2489007d,0x443950fe,0x00000000}},	//   _loch, izam_, _mps_,
  { {0x6a8603b2,0x257c0014,0xdc28005d,0x00000000}},	//   _réfé, _bíll_, وسیه_,
  { {0x656f50ff,0x44395100,0xdc53005d,0x00000000}},	//   _noch, _ops_, _مرتک,
  { {0x8ccd0053,0x5d780086,0x35db0053,0x00000000}},	//   देशो, _яйця_, _मंज़,
  { {0x6d4b030d,0xf53f0137,0x24895101,0x00000000}},	//   _haga, _skåp_, dzam_,
  { {0x6d4b00bb,0xd62707b0,0x85b6005e,0x00000000}},	//   _kaga, коре_, вљач,
  { {0x443931e5,0x6d4b3e35,0xceb20063,0x00000000}},	//   _bps_, _jaga, ׁים_,
  { {0x6d4b5102,0x25a5006d,0x27f50066,0x00000000}},	// [9dc0] _maga, élla_, čaný_,
  { {0x6d4b37f7,0x656f0025,0x25ad01b3,0x00000000}},	//   _laga, _eoch, čela_,
  { {0xf8bf0164,0x216a0002,0x63720014,0x00000000}},	//   rgée_, мижи_, _sæns,
  { {0x6d4b5103,0xa3ea0002,0xa113002a,0x00000000}},	//   _naga, _одма_, لومت,
  { {0x60230121,0x60f7000d,0x7d0201cd,0x00000000}},	//   идца, тнія_, _reos,
  { {0xa0670001,0x7d02170d,0x656f5104,0x00000000}},	//   таља_, _seos, _zoch,
  { {0x9e03000d,0x44205105,0x2d840164,0x00000000}},	//   ачыл, lui_, thme_,
  { {0x75245106,0x3ea0003b,0x6d4b5107,0x00000000}},	//   ngiz, ăit_, _caga,
  { {0x98be0080,0x6d4b5108,0xdb1a0025,0x00000000}},	//   ětě_, _daga, llté,
  { {0x6d4b0027,0x2bba0021,0x8e3a0044,0x00000000}},	//   _eaga, باعة_, _يسار_,
  { {0x442006a7,0xeb97000a,0x3f9b0164,0x00000000}},	//   hui_, тиќ_, èque_,
  { {0x6d4b38c4,0x44200800,0x7c470072,0x00000000}},	//   _gaga, kui_, ärrä,
  { {0x257506a5,0x96eb0121,0x6d405109,0x00000000}},	//   _målt_, дьба_, mema,
  { {0x6d40510a,0x4420510b,0x656f510c,0x00000000}},	//   lema, dui_, _soch,
  { {0x35e4019d,0xda6f011c,0x4439510d,0x00000000}},	//   ицтв, _тя_, _sps_,
  { {0x6d40010e,0x7c2d003b,0x88c8004c,0x00000000}},	//   nema, _ţari, _stěž,
  { {0x44200a6b,0x656f0122,0x54550475,0x00000000}},	// [9dd0] gui_, _voch, ыват,
  { {0x656f00bd,0x6d40510e,0xbebc008f,0x00000000}},	//   _woch, hema, _acīm,
  { {0x4439510f,0x52150541,0x656f5110,0x00000000}},	//   _wps_, удет, _toch,
  { {0x44203940,0x1a9b0047,0x6d405111,0x00000000}},	//   bui_, ויבע, jema,
  { {0x6d4b5112,0x442023d8,0x44395113,0x00000000}},	//   _raga, cui_, _ups_,
  { {0x7dd500eb,0x6d40004b,0x6d4b5114,0x00000000}},	//   _išsi, eema, _saga,
  { {0x6d4b5115,0x3e320044,0x43940f44,0x00000000}},	//   _paga, مفور, _тарс,
  { {0x6d4039d3,0xed450002,0x26dc0149,0x00000000}},	//   gema, унип, וקומ,
  { {0x7bca018d,0xdb010026,0x6d4b068b,0x00000000}},	//   _bhfu, illö, _vaga,
  { {0xc0c8005a,0x9ee90021,0x3c2b06a5,0x00000000}},	//   _русе_, _أفضل_, røv_,
  { {0xadf5042c,0x6d405116,0x6d4b5117,0x00000000}},	//   _спеш, bema, _taga,
  { {0x6d405118,0x29045119,0xdb08511a,0x00000000}},	//   cema, úma_, rodá,
  { {0x30790047,0x3ced00c2,0x7d091ff0,0x00000000}},	//   גאָנ, mcev_, maes,
  { {0x3ced0198,0xdb0819e6,0x4420511b,0x00000000}},	//   lcev_, podá, vui_,
  { {0xdbd10019,0x98a4005b,0x2a15000d,0x00000000}},	//   _müüj, ımı_, _сьлё,
  { {0x3ced00c3,0x7d09017f,0x75240035,0x00000000}},	//   ncev_, naes, ugiz,
  { {0x79840035,0x3942004b,0xb3ca005e,0x00000000}},	// [9de0] _iliw, meks_, елаз_,
  { {0x7d090150,0x4420511c,0x3942511d,0x00000000}},	//   haes, rui_, leks_,
  { {0xeb9600b5,0x6b7a00b5,0x79840150,0x00000000}},	//   נדער_, ערענ, _kliw,
  { {0x673b017f,0x39420019,0x11d70021,0x00000000}},	//   đuje, neks_, هولة_,
  { {0x644a001c,0x4420511e,0x26c50066,0x00000000}},	//   āfis, qui_, ýlov_,
  { {0x39420019,0xd8d70047,0x7984001f,0x00000000}},	//   heks_, אונט_, _lliw,
  { {0x63830001,0x63ab00ea,0x3942004b,0x00000000}},	//   _угра, égne, keks_,
  { {0x644d0019,0xc0d6007e,0xec6a0bd5,0x00000000}},	//   _üliõ, _ميزب, ерок_,
  { {0xd1b3006a,0x6d40511f,0x39425120,0x00000000}},	//   _اینک, rema, deks_,
  { {0x6d87048e,0x79840c55,0x5a340189,0x00000000}},	//   _añad, _aliw, анот,
  { {0xee290021,0x6d400019,0x2d9a00ea,0x00000000}},	//   _لأنه_, pema, épes_,
  { {0x39420019,0x984b000d,0x7984002b,0x00000000}},	//   geks_, няга_, _cliw,
  { {0x0c76014d,0x0c77005d,0xd838030b,0x00000000}},	//   _حداد, _مصوب_, лэр_,
  { {0xead45121,0xba0a0021,0x60dd017c,0x00000000}},	//   _коль, _كتبك_, _úsme,
  { {0x5b7b0047,0x6b9a004d,0x6b7b0063,0x00000000}},	//   _ארגא, mitg, _ארגנ,
  { {0x25ad01b3,0x6b9a07fc,0x79845122,0x00000000}},	//   čelo_, litg, _gliw,
  { {0x3ebe00d1,0x290b5123,0xa49b01a8,0x00000000}},	// [9df0] _lytt_, maca_, _geòl,
  { {0xf8bf00cd,0x290b5124,0x98b9001c,0x00000000}},	//   sfés_, laca_, cesā_,
  { {0x3ebe0707,0xd6db0086,0xdb080014,0x00000000}},	//   _nytt_, _яти_, lldó,
  { {0x31350086,0x290b32c2,0xe4e40086,0x00000000}},	//   редр, naca_, _гірн,
  { {0x3ced00c3,0x7d09078c,0x9f05005d,0x00000000}},	//   vcev_, vaes, لوشو,
  { {0x3ebe02f0,0x9e090021,0x29c40331,0x00000000}},	//   _bytt_, نيتك_, eñal_,
  { {0x27780063,0x7d0900fe,0x6b9a5125,0x00000000}},	//   רגון_, taes, ditg,
  { {0x656d5126,0x290b5127,0x6b9a5128,0x00000000}},	//   njah, jaca_, eitg,
  { {0x3ebe007a,0x0d820726,0x3ced00c2,0x00000000}},	//   _eytt_, ільн, rcev_,
  { {0x30840021,0x15e50042,0x00000000,0x00000000}},	//   _الكف, कदार_,   ,
  { {0x39420004,0x3ced00c3,0x5ac60121,0x00000000}},	//   teks_, pcev_, ильм_,
  { {0x69cd001f,0xac96006a,0x7e7e00d1,0x00000000}},	//   _chae, انیا_, øppe,
  { {0x39420019,0x6b650376,0x7dc542d7,0x00000000}},	//   reks_, _вкла, lóso,
  { {0x39421fc9,0x656d0150,0xcb69005e,0x00000000}},	//   seks_, ejah, _јаке_,
  { {0x290b014f,0x3942004b,0x63b701d1,0x00000000}},	//   baca_, peks_, doxn,
  { {0x60c900c3,0x69cd0025,0x99900051,0x00000000}},	//   _ozem, _ghae, żała_,
  { {0x19bb0063,0x3f850014,0x13065129,0x00000000}},	// [9e00] _במקב, _ollu_, изам,
  { {0x7bc10185,0x69df0003,0xddd80006,0x00000000}},	//   nllu, _éper, tyvū,
  { {0x00e61518,0x171b0047,0x7bc1512a,0x00000000}},	//   ажен, _בויע, illu,
  { {0x3f85001f,0x7dc5013d,0x00000000,0x00000000}},	//   _allu_, dóso,   ,
  { {0x33d60086,0x60c90051,0x70540021,0x00000000}},	//   _вівт, _czem, إنتا,
  { {0xa8570063,0x60c9008f,0x290b512b,0x00000000}},	//   יינה_, _dzem, zaca_,
  { {0x4432512c,0xe8e00013,0x290b0075,0x00000000}},	//   lty_, _muối_, yaca_,
  { {0x3f850019,0x290b512d,0x443213e4,0x00000000}},	//   _ellu_, xaca_, oty_,
  { {0x290b512e,0x443205ea,0x257c004c,0x00000000}},	//   vaca_, nty_, _cíli_,
  { {0x61e0512f,0xda7a0062,0x2fde00ca,0x00000000}},	//   _himl, вям_, _uitg_,
  { {0x61e001f7,0x44320b70,0xac73007e,0x00000000}},	//   _kiml, hty_, مایش,
  { {0x6b9a0268,0x60c000fe,0x61e00150,0x00000000}},	//   sitg, _kymm, _jiml,
  { {0xdbdc0080,0x290b5130,0x63bc00a8,0x00000000}},	//   lšíh, raca_, _okrn,
  { {0xe8e0001b,0x68e45131,0x290b5132,0x00000000}},	//   _cuối_, _egid, saca_,
  { {0xada50024,0x290b426a,0x603a001c,0x00000000}},	//   skúš, paca_, lāmā,
  { {0x44320034,0xaadb009f,0x3f9c1058,0x00000000}},	//   fty_, _בחור, hivu_,
  { {0x799d0035,0xdce00078,0x656d12b8,0x00000000}},	// [9e10] misw, rkmė, rjah,
  { {0x3f9c5133,0x656d004d,0x799d0229,0x00000000}},	//   jivu_, sjah, lisw,
  { {0xd2510032,0x60c9000f,0xd8b8006a,0x00000000}},	//   ثنا_, _szem, _مدیا_,
  { {0x8ad90047,0x10150021,0x27e95134,0x00000000}},	//   אַנפ, مبتد, _kuan_,
  { {0x27e95135,0x3e4700ea,0x7bc15136,0x00000000}},	//   _juan_, _sőt_, yllu,
  { {0x60c900c2,0x2d864396,0xe7fa0042,0x00000000}},	//   _vzem, _aloe_, ्ठता_,
  { {0x6fcd0024,0x27e95137,0x61e00014,0x00000000}},	//   júce, _luan_, _fiml,
  { {0xee36000d,0x6fcd06fe,0x4d6505f4,0x00000000}},	//   ёны_, dúce, скив,
  { {0xec790076,0x799d002b,0xbc620085,0x00000000}},	//   упп_, disw, звык,
  { {0x5f740021,0x68e4002b,0x7bc15138,0x00000000}},	//   _والر, _sgid, ullu,
  { {0xe9da011c,0xc3320063,0xdce900c2,0x00000000}},	//   лко_, הוי_, lječ,
  { {0xe9a60086,0x27e9002b,0xe8e00013,0x00000000}},	//   самп, _buan_, _suối_,
  { {0xf71a000d,0x3bd52636,0x44325139,0x00000000}},	//   лівы_, _люкс, xty_,
  { {0xdce90117,0xd62a0175,0x291e513a,0x00000000}},	//   iječ, логе_, şta_,
  { {0xc9f50067,0xfaa2513b,0xceb2009a,0x00000000}},	//   _استع, _нашо, ֤ין_,
  { {0x44320bcf,0x27e9001f,0x3f9c074f,0x00000000}},	//   tty_, _fuan_, zivu_,
  { {0x98b90529,0x4432513c,0x27e92075,0x00000000}},	// [9e20] resă_, uty_, _guan_,
  { {0x212d028d,0x60c00137,0x4432513d,0x00000000}},	//   _aceh_, _rymm, rty_,
  { {0x02060076,0xdb9a0047,0x44321e01,0x00000000}},	//   ёздн, נסער, sty_,
  { {0x3aba0047,0x443205fa,0x395200e5,0x00000000}},	//   אמענ, pty_, _jays_,
  { {0xc0130086,0x3a250162,0xb87b513e,0x00000000}},	//   зміщ, hulp_, ncíp,
  { {0xe8200053,0xef0e0062,0x395200e5,0x00000000}},	//   _बिना_, амa_, _lays_,
  { {0x4420160e,0x52860021,0x6f080066,0x00000000}},	//   lri_, _الأك, _vedc,
  { {0x3f9c024a,0x4420513f,0xdceb008f,0x00000000}},	//   sivu_, ori_, _pogā,
  { {0x40960021,0x44205140,0xe8e0008d,0x00000000}},	//   _الذر, nri_, _muồi_,
  { {0x799d0185,0x44205141,0x3ea60002,0x00000000}},	//   wisw, iri_, _лизг,
  { {0xed06007e,0x395200e5,0x8afc0022,0x00000000}},	//   _هواپ, _bays_, djęt,
  { {0x27e92f70,0x8afc0051,0xf96b0121,0x00000000}},	//   _puan_, ejęt, урой_,
  { {0x39520034,0x27e95142,0xd0060593,0x00000000}},	//   _days_, _quan_, بل_,
  { {0x799d06a7,0x44205143,0x0bb5005d,0x00000000}},	//   sisw, dri_, _وجوگ,
  { {0x7d250014,0x44205144,0x4b37009a,0x00000000}},	//   _útsý, eri_, _לרגל_,
  { {0x27e90397,0x7df1001c,0xe9a400e1,0x00000000}},	//   _tuan_, _jāsa, _најп,
  { {0x44201d3d,0xdb010955,0x5399066e,0x00000000}},	// [9e30] gri_, coló, авая_,
  { {0xdce9007d,0xdceb003b,0xdce0008f,0x00000000}},	//   vječ, _kogă, ekmī,
  { {0x26c70024,0x44205145,0xd25b0085,0x00000000}},	//   _áno_, ari_, ыца_,
  { {0x44205146,0xdb0100cd,0xdce9007d,0x00000000}},	//   bri_, nolò, tječ,
  { {0x44205147,0xa3d50da9,0x25a90fc4,0x00000000}},	//   cri_, _момч, mnal_,
  { {0x98b90006,0xdce9007d,0xfe70007e,0x00000000}},	//   cesą_, rječ, کده_,
  { {0xdce9017f,0xdb0108af,0x877c0047,0x00000000}},	//   sječ, rolü, ראוי,
  { {0x4c85019d,0xee360088,0x3134018e,0x00000000}},	//   жлив, іны_, _неср,
  { {0x395200e5,0xdb015148,0x25a95149,0x00000000}},	//   _rays_, dolò, inal_,
  { {0x39520034,0xdceb003b,0xeb991225,0x00000000}},	//   _says_, _bogă, рио_,
  { {0x89aa0055,0x395203b2,0x753d0051,0x00000000}},	//   иков_, _pays_, _obsz,
  { {0xdb1a00ac,0x4420514a,0x645d514b,0x00000000}},	//   notê, yri_, _orsi,
  { {0xe8e00013,0xfd100021,0x25a901c8,0x00000000}},	//   _ruồi_, _سجن_, dnal_,
  { {0x39520034,0x7d0b00ac,0xbb420002,0x00000000}},	//   _ways_, _hegs, _жешк,
  { {0xdb01514c,0x645d514d,0xb87b0460,0x00000000}},	//   soló, _arsi, scíp,
  { {0x4420514e,0xdb01514f,0x25a9081b,0x00000000}},	//   tri_, colò, gnal_,
  { {0x7d0b000f,0x842a0054,0x44205150,0x00000000}},	// [9e40] _megs, ржзв_, uri_,
  { {0x44205151,0x2bcf0053,0x25a95152,0x00000000}},	//   rri_, _सीमा, anal_,
  { {0x98b900eb,0xdce90024,0x61400026,0x00000000}},	//   resą_, dieľ, _nálæ,
  { {0x44205153,0xdb1a013d,0x41030085,0x00000000}},	//   pri_, iltá, дзцв,
  { {0x69c600c7,0x98a20078,0x6443003b,0x00000000}},	//   ilke, iekį_, ănic,
  { {0xdfcf0067,0x7d0b004b,0x637b00dd,0x00000000}},	//   نين_, _aegs, _dîns,
  { {0xa3d70042,0x00000000,0x00000000,0x00000000}},	//   ागर_,   ,   ,
  { {0x867b0041,0x5c741367,0x71660044,0x00000000}},	//   ירצו, злит, _باسك,
  { {0x8c43000a,0xfbaa0121,0xb14301dd,0x00000000}},	//   дење, итой_, _інфл,
  { {0x61fe02f0,0x25ad01a6,0xdce90066,0x00000000}},	//   oppl, čeli_, cieľ,
  { {0xdb0100cd,0x5ea60044,0x7fd5012c,0x00000000}},	//   tolò, _بمال, _хіті,
  { {0x6fc400cd,0x2d8d1b0c,0x9c660044,0x00000000}},	//   dòci, chee_, _وهاو,
  { {0xb8f3016a,0xdb0100cd,0x7dd50006,0x00000000}},	//   _वर_, rolò, _išsp,
  { {0x68f6002b,0xc7bb0121,0x35c30042,0x00000000}},	//   _efyd, рём_, _वीज़,
  { {0x69330080,0x68f6001f,0x25a00019,0x00000000}},	//   _přeč, _ffyd, fiil_,
  { {0x48150ab1,0xf56801dd,0x74a7005e,0x00000000}},	//   _емис, ошук_, ојзе,
  { {0xe8e0008b,0x25a915ae,0x99d40021,0x00000000}},	// [9e50] _buổi_, rnal_, _تتوا,
  { {0xd25b131b,0x03d40086,0xdb1a0014,0x00000000}},	//   ице_, джую, amtö,
  { {0x25a00019,0x6fc400cd,0xed590dad,0x00000000}},	//   biil_, còci, lože_,
  { {0x7dea0022,0x51840085,0x85a71313,0x00000000}},	//   _gęsi, муча, _фјод,
  { {0x644f051e,0x7d0b00e8,0xa3e4016a,0x00000000}},	//   _usci, _regs, _पंच_,
  { {0x4429014f,0x644d001f,0x752d5154,0x00000000}},	//   mua_, mwai, lgaz,
  { {0x44295155,0xdb1a017d,0x644d002b,0x00000000}},	//   lua_, potê, lwai,
  { {0x752d0009,0x3cf70161,0x4429003b,0x00000000}},	//   ngaz, ीरें_, oua_,
  { {0x644d001f,0xdb1a0014,0x752d013d,0x00000000}},	//   nwai, iltæ, igaz,
  { {0x4429003b,0xab29005e,0xcf780021,0x00000000}},	//   iua_, љона_, _وإلا_,
  { {0x644d0ac9,0xb603004c,0x44295156,0x00000000}},	//   hwai, ýšle, hua_,
  { {0x442947f0,0x69c60072,0xed580054,0x00000000}},	//   kua_, ulke, _моє_,
  { {0x44290035,0x3855005a,0x25a0004b,0x00000000}},	//   jua_, мърс, viil_,
  { {0x4429014f,0xddc10080,0x752d0a02,0x00000000}},	//   dua_, _splň, egaz,
  { {0x7c290e4e,0x6abc004d,0x25a0004e,0x00000000}},	//   luer, ürft, tiil_,
  { {0x2508007e,0x291e0006,0xed590b57,0x00000000}},	//   ترسی_, ėtas_, bože_,
  { {0x44295157,0x25a00150,0x7c290f8c,0x00000000}},	// [9e60] gua_, riil_, nuer,
  { {0x752d5158,0x24920022,0x9837009a,0x00000000}},	//   agaz, rzym_, _צריף_,
  { {0x61fe007a,0x248000f3,0x24920045,0x00000000}},	//   uppl, syim_, szym_,
  { {0x673c0026,0x3cf70053,0x44295159,0x00000000}},	//   lfrj, ीरों_, bua_,
  { {0xe8e0001b,0x93c6003b,0x44293ed4,0x00000000}},	//   _tuổi_, epăş, cua_,
  { {0xfbc7002a,0xd3b90054,0x6fe90054,0x00000000}},	//   _ست_, _дусі_, іфів_,
  { {0x7c29004d,0xdb0e004c,0x32434598,0x00000000}},	//   euer, ádím, _перг,
  { {0x7c2902dd,0x63be017f,0x798600ca,0x00000000}},	//   fuer, lopn, jkkw,
  { {0x7c292070,0xac310047,0x8e200054,0x00000000}},	//   guer, _לאָזן_, рiв_,
  { {0x53be0053,0x66150022,0xdb08006c,0x00000000}},	//   ्तिश, yszk, ondé,
  { {0x7c29004d,0x7df1008f,0x60cd008f,0x00000000}},	//   auer, _jāsl, ļame,
  { {0xed59016b,0x9f4400cd,0x63be0114,0x00000000}},	//   tože_, _humà_, hopn,
  { {0x7c2902dd,0xf1bf0066,0xe8e0008d,0x00000000}},	//   cuer, ýšia_, _muỗi_,
  { {0x4429024a,0x61ee0164,0x27e50244,0x00000000}},	//   vua_, _oubl, öln_,
  { {0x8b3b0063,0xc6680001,0x7bda0026,0x00000000}},	//   _התוצ, пште_, mmtu,
  { {0x442913b8,0x4dfb0041,0x7bc80cc0,0x00000000}},	//   tua_, מפלא, lldu,
  { {0x6fcd0024,0x3f8c005b,0x752d00ea,0x00000000}},	// [9e70] dúcn, _oldu_, rgaz,
  { {0x44290009,0x026b0121,0x644d0616,0x00000000}},	//   rua_, йшей_, rwai,
  { {0x7bda007a,0x44290963,0x798d515a,0x00000000}},	//   imtu, sua_, _klaw,
  { {0xc5f8003d,0x442935ba,0x7dc504a6,0x00000000}},	//   ģēt_, pua_, pósi,
  { {0x4429515b,0xcee9000d,0xdb1a00cd,0x00000000}},	//   qua_, одле_, potè,
  { {0x798d0185,0x394b0003,0x5f940121,0x00000000}},	//   _llaw, hecs_, ничт,
  { {0xdce9001c,0x64420003,0x61ee007d,0x00000000}},	//   pieļ, çoiv, _gubl,
  { {0x3f8c0014,0x7c29515c,0xdb1a004d,0x00000000}},	//   _eldu_, tuer, hltä,
  { {0x6d4909ee,0xed5900c2,0x394b45f2,0x00000000}},	//   reea, tožb_, decs_,
  { {0x7c293951,0x798d515d,0x6d490168,0x00000000}},	//   ruer, _alaw, seea,
  { {0xcda8007e,0xddc8013d,0x394a1340,0x00000000}},	//   _کهنه_, _erdő, озно_,
  { {0xa96a0138,0x499a019d,0x7c2902dd,0x00000000}},	//   цима_, ітня_, puer,
  { {0x7c29515e,0x798d002b,0x673c0046,0x00000000}},	//   quer, _dlaw, tfrj,
  { {0x8c422953,0x61fb0130,0xa088009a,0x00000000}},	//   _реше, _čuln, פְרִ,
  { {0xaa920032,0xe7370076,0x798d0b3c,0x00000000}},	//   _للوث, ьер_, _flaw,
  { {0x99520006,0xceb20063,0x798d2b09,0x00000000}},	//   ršų_, דיל_, _glaw,
  { {0x6fcd0024,0x64a30d62,0x63be515f,0x00000000}},	// [9e80] júco, вата, topn,
  { {0x387f00bd,0x61ee0d8d,0x6fcd0066,0x00000000}},	//   äure_, _publ, dúco,
  { {0x6d97003b,0x7dc5013d,0xc5f80023,0x00000000}},	//   nţas, lósu, ģēs_,
  { {0xdce902f4,0x2f0a0051,0xed59007d,0x00000000}},	//   ěněn, _mógł_, jdž_,
  { {0x7bc80026,0x7bc30150,0x44243bf5,0x00000000}},	//   yldu, _oknu, _ím_,
  { {0x61ee0019,0xdfd0014d,0xdb1a024b,0x00000000}},	//   _tubl, ديت_, poté,
  { {0x69c42b8f,0x6e4301ce,0x0206014b,0x00000000}},	//   _okie, вејз, _ізан,
  { {0x2dd70032,0x99860080,0x1d340062,0x00000000}},	//   وبية_, dulů_, хния,
  { {0x7e870006,0xdb180195,0x447b0041,0x00000000}},	//   _įspū, _akvá, ַנטע,
  { {0x798d135f,0x7bc80058,0x807b009a,0x00000000}},	//   _slaw, uldu, _ונמצ,
  { {0x798d0150,0x394b3170,0xe9f8013c,0x00000000}},	//   _plaw, tecs_, янні_,
  { {0x7c470137,0x1ea914d7,0x26180082,0x00000000}},	//   örrå, _عالي_, _फिजी_,
  { {0x394b0110,0x6d97003b,0xdb180195,0x00000000}},	//   recs_, rţat, _ekvá,
  { {0xbc6714d7,0x27c400de,0x00000000,0x00000000}},	//   _آمون_, َيَّ,   ,
  { {0x7dea0051,0x386d003b,0x64460078,0x00000000}},	//   _gęst, ţer_, _apki,
  { {0x58d50121,0x99990051,0x03f9007b,0x00000000}},	//   _пойт, żyła_, знај_,
  { {0xdb0126ea,0x69dd5160,0x54990085,0x00000000}},	// [9e90] rolö, mmse, чваў_,
  { {0x6d97000c,0x58d8000d,0xdb080331,0x00000000}},	//   nţar, _ідэя_, modó,
  { {0x98ac0051,0xdcee004c,0xe7e80042,0x00000000}},	//   ędą_, ýděl, _टूटा_,
  { {0x7dc51979,0x6595000d,0xe5070049,0x00000000}},	//   nóst, _чаму, _تبدي,
  { {0x50670021,0x3f691dd1,0xd00902d8,0x00000000}},	//   بطاق, зило_, челе_,
  { {0x6d420034,0x9f4501a8,0x7e550af0,0x00000000}},	//   _aboa, _xilè_, етиц,
  { {0xee39148d,0xa1950817,0xa49b00cd,0x00000000}},	//   їни_, _завч, _geòr,
  { {0x63a50150,0x50670062,0xdb010003,0x00000000}},	//   lihn, _отза, milé,
  { {0xed591fc3,0x6fc400cd,0xdb0111f5,0x00000000}},	//   rdž_, tòct, lilé,
  { {0xa3bf0053,0x9986004c,0x69c45161,0x00000000}},	//   ँकि_, tulů_, _skie,
  { {0x61e91ab4,0xdb0e004c,0x7e6104f9,0x00000000}},	//   _kiel, ádám, _urlp,
  { {0x4c950601,0xf9920049,0x99d60044,0x00000000}},	//   _пиес, ابد_, عتدا,
  { {0x7a3501f7,0xdb08006d,0x6fc400cd,0x00000000}},	//   _bütç, godó, mòcr,
  { {0x61e9003d,0x7dea00eb,0x60c900a4,0x00000000}},	//   _liel, _tęst, _myem,
  { {0xcb660076,0x6d5913dc,0xdb010003,0x00000000}},	//   _чаще_, _kawa, vilè,
  { {0x6d5b5162,0x6d592a06,0x69c414ce,0x00000000}},	//   ndua, _jawa, _ukie,
  { {0x6d5926b2,0x7c3b406a,0x60c93839,0x00000000}},	// [9ea0] _mawa, ntur, _nyem,
  { {0x6d590397,0x68ed0051,0xe45f0072,0x00000000}},	//   _lawa, _zgad, _työn_,
  { {0x2d8f004b,0x6285002b,0x61e95163,0x00000000}},	//   _olge_, gyho, _biel,
  { {0x6d595164,0x61e95165,0x7c3b0246,0x00000000}},	//   _nawa, _ciel, ktur,
  { {0x61e95166,0x63a50360,0x8fa61a5c,0x00000000}},	//   _diel, bihn, наде,
  { {0xa49b00cd,0x7c3b5167,0x2d8f5168,0x00000000}},	//   _teòr, dtur, _alge_,
  { {0x6d595169,0x61e918a0,0x657d516a,0x00000000}},	//   _bawa, _fiel, _yosh,
  { {0x6d590397,0xdd970076,0x7c3b516b,0x00000000}},	//   _cawa, ешь_, ftur,
  { {0x7c3b002c,0xacea007e,0x6d59516c,0x00000000}},	//   gtur, يرکل_, _dawa,
  { {0x09c90161,0xed5900c2,0x61e9516d,0x00000000}},	//   रत्य, roža_, _ziel,
  { {0x200d0199,0x61e90034,0xdb080051,0x00000000}},	//   _zwei_, _yiel, wodó,
  { {0x6d591362,0xdb010072,0x7c3b008f,0x00000000}},	//   _gawa, enlä, btur,
  { {0x657d2ee0,0x7bc1516e,0x7c3b516f,0x00000000}},	//   _rosh, bolu, ctur,
  { {0x7bc10529,0x6d5947ff,0xef0e000d,0x00000000}},	//   colu, _zawa, амi_,
  { {0x7dc5007a,0x3982007a,0xdb1a5170,0x00000000}},	//   póst, _póst_, notí,
  { {0xdb015171,0x68ed0139,0xdb08013d,0x00000000}},	//   vilé, _ugad, indí,
  { {0x9327007e,0x61e92546,0xf994009f,0x00000000}},	// [9eb0] فران, _riel, _תרפ_,
  { {0x61e95172,0xe9df013d,0xdb01123c,0x00000000}},	//   _siel, lmú_, tilé,
  { {0x657d5173,0x61e95174,0xe139000d,0x00000000}},	//   _tosh, _piel, дзеі_,
  { {0x63a50360,0x62850114,0x361a009f,0x00000000}},	//   sihn, ryho, _קורד,
  { {0x61e95175,0x29d90027,0x6d590397,0x00000000}},	//   _viel, méad_, _rawa,
  { {0x61e90045,0x4429000f,0xdce9017f,0x00000000}},	//   _wiel, mra_, ljeć,
  { {0x6d405176,0x6d594430,0x44295177,0x00000000}},	//   ffma, _pawa, lra_,
  { {0x7c3b5178,0x8d6503d6,0x29d90025,0x00000000}},	//   ttur, твие, néad_,
  { {0x44295179,0xdce9007d,0x7c3b517a,0x00000000}},	//   nra_, ijeć, utur,
  { {0x4429517b,0x6d59517c,0xdb23007e,0x00000000}},	//   ira_, _wawa, دودی,
  { {0x6d590645,0x6fc400cd,0x316d0734,0x00000000}},	//   _tawa, pòcr, _knez_,
  { {0x7c3b00d8,0x4429517d,0x7bc125cb,0x00000000}},	//   ptur, kra_, solu,
  { {0x291204ab,0x442900ea,0x9f9b0019,0x00000000}},	//   _veya_, jra_, pääs_,
  { {0x4429517e,0x7aa50021,0x7c290838,0x00000000}},	//   dra_, _لإعل, mrer,
  { {0x4429517f,0xd4f60121,0x395b5180,0x00000000}},	//   era_, вязы, _faqs_,
  { {0x7c295181,0xf8660f55,0x29d90139,0x00000000}},	//   orer, _авио, géad_,
  { {0xd706011c,0x44295182,0x7c290e4c,0x00000000}},	// [9ec0] _изпи, gra_, nrer,
  { {0x78ad0080,0x7c295183,0x67d30092,0x00000000}},	//   šová, irer, _коњу,
  { {0x7c290199,0x7d0900e8,0xdce9007d,0x00000000}},	//   hrer, kbes, bjeć,
  { {0x7c2916af,0x4255000d,0x44295184,0x00000000}},	//   krer, ытут, bra_,
  { {0x7d09331d,0x44295185,0xa8ad0063,0x00000000}},	//   dbes, cra_, ּבוֹ,
  { {0x7d095186,0x7dd50078,0x7c295187,0x00000000}},	//   ebes, _išsy, drer,
  { {0x7c295188,0x57250041,0x7d09087d,0x00000000}},	//   erer, אַפּ_, fbes,
  { {0x7d095189,0x7c29017d,0xed870086,0x00000000}},	//   gbes, frer, вськ_,
  { {0x7c2906f1,0xc0e32099,0xc045043e,0x00000000}},	//   grer, _вотк, _مخلو,
  { {0xf413014e,0x4a540e82,0x9b940044,0x00000000}},	//   ספת_, гкос, الدت,
  { {0xc3330a7a,0x29040058,0x7c29518a,0x00000000}},	//   בות_, ıman_, arer,
  { {0x44293a92,0x6f1800c3,0x7c29518b,0x00000000}},	//   yra_, lavc, brer,
  { {0x7c29006c,0x9c9a0044,0x6d630260,0x00000000}},	//   crer, _تنشط_, ávaž,
  { {0x4429518c,0xe9df0024,0x60180025,0x00000000}},	//   vra_, smú_, _zúmá,
  { {0xdb1a017d,0x96f802b3,0x442937b6,0x00000000}},	//   potâ, тест_, wra_,
  { {0x4429518d,0x7afd004c,0x7793005d,0x00000000}},	//   tra_, ěste, ایگا,
  { {0x2919518e,0xf8bf0164,0xb4d50076,0x00000000}},	// [9ed0] masa_, rgés_, ужащ,
  { {0x1755005a,0xdce9017f,0xf207000d,0x00000000}},	//   _своя, sjeć, вядо,
  { {0x29d90027,0x44292294,0x7d090618,0x00000000}},	//   péad_, sra_, ybes,
  { {0x7d09006f,0x4429518f,0x673b007d,0x00000000}},	//   xbes, pra_, đuju,
  { {0x656f41ee,0x7d09130e,0x6fcd5190,0x00000000}},	//   _inch, vbes, lúci,
  { {0x291908f0,0x2d820137,0x649a0047,0x00000000}},	//   hasa_, öken_, _טירה,
  { {0x29195191,0x7d091f57,0xf77400ff,0x00000000}},	//   kasa_, tbes, יקס_,
  { {0x7c295192,0x29192444,0xe8d9008d,0x00000000}},	//   trer, jasa_, _caị_,
  { {0x1be90121,0x24892eda,0x6d95013d,0x00000000}},	//   ндии_, nyam_, _ráad,
  { {0x7c291e4c,0x7d0946aa,0x6f180066,0x00000000}},	//   rrer, sbes, cavc,
  { {0x6fcd034d,0x7d095193,0xdd8e007e,0x00000000}},	//   júci, pbes, زوی_,
  { {0x6fcd0024,0x7c295194,0x2d940054,0x00000000}},	//   dúci, prer, _кріс,
  { {0x9b450032,0x31560047,0x0c240054,0x00000000}},	//   _منشو, נישן_, _вмін,
  { {0xa142003d,0x656f055b,0x2d8d00fe,0x00000000}},	//   ēķin, _anch, lkee_,
  { {0x291900bb,0x6fcd0025,0x6381004c,0x00000000}},	//   basa_, rúch, _míně,
  { {0x29195195,0xd5e6080b,0x2d8d5196,0x00000000}},	//   casa_, ужби, nkee_,
  { {0x2bf600b5,0x69c60006,0x201f008d,0x00000000}},	// [9ee0] ָמען_, moke, _nvui_,
  { {0x6fcd18a8,0x656f1677,0x61f5092a,0x00000000}},	//   búci, _ench, _buzl,
  { {0x201f0268,0xb226000d,0x673b007d,0x00000000}},	//   _avui_, умел, đujt,
  { {0x25a9095b,0xf67b0041,0x055607b3,0x00000000}},	//   cial_, _נאכמ, _стоя,
  { {0xdefa0055,0xa0670d62,0xb1130054,0x00000000}},	//   ный_, лаца_, сміш,
  { {0x7e7e0137,0xdb1a00ea,0xa8570063,0x00000000}},	//   äppo, kotá, טינה_,
  { {0x69c600fe,0x44320003,0x29195197,0x00000000}},	//   koke, luy_, yasa_,
  { {0xdb08017d,0x99420051,0x69c65198,0x00000000}},	//   cidê, _cóż_, joke,
  { {0x69c60009,0x4127005a,0xaf3601fb,0x00000000}},	//   doke, _щото_, _مرات,
  { {0x40930032,0x29191320,0x25a95199,0x00000000}},	//   _الكر, wasa_, zial_,
  { {0xdb01006d,0xc3330063,0x69c6004b,0x00000000}},	//   cilí, זות_, foke,
  { {0x29190397,0xdb01017d,0x61e2519a,0x00000000}},	//   uasa_, gilâ, nmol,
  { {0x2919058c,0x7d1d0026,0xdca31c7a,0x00000000}},	//   rasa_, ðsse, _лаци,
  { {0x29190035,0x6fcd175e,0x61e2519b,0x00000000}},	//   sasa_, túci, hmol,
  { {0x25a904bc,0x2919519c,0x69c6519d,0x00000000}},	//   tial_, pasa_, boke,
  { {0x55580304,0x569411ec,0xdd1c011b,0x00000000}},	//   лася_, щаст, tářk,
  { {0xdb08017d,0x394900ae,0xe3150d34,0x00000000}},	// [9ef0] vidê, _ibas_, имањ,
  { {0x25a9519e,0x2489519f,0x9cd70063,0x00000000}},	//   sial_, ryam_, רומה_,
  { {0xd2510021,0x325551a0,0x25a951a1,0x00000000}},	//   تنا_, рвер, pial_,
  { {0x656f51a2,0x3d0e0053,0xdb010331,0x00000000}},	//   _unch, सरों_, vilí,
  { {0xf3ff0016,0x653600b5,0xf48701d5,0x00000000}},	//   _irão_, _דארף_, _сунн,
  { {0xdb080016,0x8e85018e,0xde050002,0x00000000}},	//   sidê, игле, апки,
  { {0xed591485,0x2d95197b,0xe1070085,0x00000000}},	//   вой_, ирис, _бязп,
  { {0x3869000c,0x2d8d51a3,0x0d852474,0x00000000}},	//   _orar_, ukee_, рлин,
  { {0x69c60288,0xff25007e,0xdb0151a4,0x00000000}},	//   voke, _نبای, silí,
  { {0x8b25000a,0x2d8d119d,0xdb0100d1,0x00000000}},	//   јдне, skee_, nnlø,
  { {0x69c610ca,0x2fc7362a,0x1a290062,0x00000000}},	//   toke, mong_, ъжни_,
  { {0x2fc70465,0x88e60b3f,0xf8660505,0x00000000}},	//   long_, ижне, авмо,
  { {0x69c651a5,0xa2a70053,0x2fc700a4,0x00000000}},	//   roke, _टेस्, oong_,
  { {0x2fc700bb,0x386902f0,0xdb1a00ea,0x00000000}},	//   nong_, _drar_, potá,
  { {0x69c60009,0x9f4500cd,0x66e651a6,0x00000000}},	//   poke, _milà_, рова,
  { {0x7ceb04ab,0x2fc70275,0x6b8351a7,0x00000000}},	//   _görü, hong_, _hong,
  { {0x2fc715c4,0xd6d90051,0x6b8351a8,0x00000000}},	// [9f00] kong_, ęła_, _kong,
  { {0x4432008b,0x6b8351a9,0x7d1b51aa,0x00000000}},	//   ruy_, _jong, haus,
  { {0x2fc700bb,0xf3c9007e,0x7d1b51ab,0x00000000}},	//   dong_, ابقه_, kaus,
  { {0xf3ff017d,0x614651ac,0x7d1b51ad,0x00000000}},	//   _grão_, реда, jaus,
  { {0x61e23037,0x98a000b2,0x7d1b51ae,0x00000000}},	//   rmol, _odič_, daus,
  { {0x2fc700bb,0x79960185,0x442015b7,0x00000000}},	//   gong_, _llyw, msi_,
  { {0x91e6000a,0x257c0080,0x442051af,0x00000000}},	//   _вове, _síly_, lsi_,
  { {0x30060086,0x7d1b0006,0x6b830035,0x00000000}},	//   _взаг, gaus, _aong,
  { {0x2fc700bb,0x9f4c0080,0x4420167f,0x00000000}},	//   bong_, _lidé_, nsi_,
  { {0xdb0100cd,0xdb6a0062,0x23c60053,0x00000000}},	//   gilà, трил_, वविद,
  { {0x6b83202b,0x44200058,0xdb230014,0x00000000}},	//   _dong, hsi_, _þrýt,
  { {0x7d1b0037,0x442015c0,0x7996001f,0x00000000}},	//   caus, ksi_, _clyw,
  { {0x9f4c0003,0x6b8351b0,0x6141013d,0x00000000}},	//   _aidé_, _fong, láló,
  { {0x6b8351b1,0x395f0df9,0x442051b2,0x00000000}},	//   _gong, žus_, dsi_,
  { {0x614103e8,0x7c2223f1,0x44201bfc,0x00000000}},	//   náló, _hvor, esi_,
  { {0x44200009,0x7996001f,0xb5940121,0x00000000}},	//   fsi_, _glyw, оисш,
  { {0x2fc70273,0xe4e7019d,0x7bc80019,0x00000000}},	// [9f10] yong_, рівн, oodu,
  { {0x473533de,0xc3980054,0xdb08006c,0x00000000}},	//   _унос, акує_, fidé,
  { {0x442051b3,0x17560063,0x4422004b,0x00000000}},	//   asi_, _הסתר_, _evk_,
  { {0x2fc700e3,0xdb080268,0xdb1a095e,0x00000000}},	//   wong_, sidè, oltó,
  { {0x2fc74857,0x7d1b00fe,0x629e00c2,0x00000000}},	//   tong_, vaus, azpo,
  { {0x2fc7002c,0xdb01013d,0x8237005d,0x00000000}},	//   uong_, kilá, _پرسا,
  { {0x22950032,0x1ec90055,0xce180088,0x00000000}},	//   _الأس, ылки_, ацыі_,
  { {0x2fc751b4,0x6b831823,0xc6b80063,0x00000000}},	//   song_, _song, יהוי_,
  { {0x7d1b51b5,0x2fc751b6,0x6b8351b7,0x00000000}},	//   raus, pong_, _pong,
  { {0x7d1b045e,0x7c2204d9,0xb35f0054,0x00000000}},	//   saus, _dvor, змiщ,
  { {0xdb0600ea,0x4ea70002,0x7d1b51b8,0x00000000}},	//   émák, _траа, paus,
  { {0x645d450e,0x644f51b9,0x442051ba,0x00000000}},	//   _ossi, _opci, ysi_,
  { {0x8d5a0063,0x6b831865,0x31560041,0x00000000}},	//   _תכני, _tong, זירן_,
  { {0x6b9a28e7,0x6b830035,0xa7da0021,0x00000000}},	//   chtg, _uong, اوسط_,
  { {0x645d0e5c,0x644f008f,0x3f8500b2,0x00000000}},	//   _assi, _apci, _molu_,
  { {0xe5a31225,0x4420003a,0x9f4c006c,0x00000000}},	//   писи, tsi_, _vidé_,
  { {0x7b06000f,0x614100ea,0x03262509,0x00000000}},	// [9f20] _érté, záló, йдан,
  { {0x442051bb,0x3f850058,0x04b50054,0x00000000}},	//   rsi_, _nolu_, істя,
  { {0x442051bc,0x645d51bd,0x216a1dd0,0x00000000}},	//   ssi_, _essi, лижи_,
  { {0xf1a5019d,0x44220019,0x7d191a70,0x00000000}},	//   орін, _tvk_, _news,
  { {0x29020b13,0x629e0758,0xdb080003,0x00000000}},	//   icka_, szpo, sidé,
  { {0x6d4b00bd,0xd8d70047,0x9053000d,0x00000000}},	//   _abga, זונט_, явіц,
  { {0x3f8551be,0x644400fe,0xe29a005e,0x00000000}},	//   _dolu_, ltii, _сав_,
  { {0x7bc80051,0x656451bf,0xdd97000d,0x00000000}},	//   wodu, ndih, йшы_,
  { {0x6444003a,0x7afd004c,0x55770041,0x00000000}},	//   ntii, ěstn, מעקן_,
  { {0x64440072,0x29d90139,0xa3d80042,0x00000000}},	//   itii, géan_, ाति_,
  { {0x64d50161,0x644400fe,0x6d9c0003,0x00000000}},	//   _दर्श, htii, _réaf,
  { {0x64440449,0x7c2251c0,0x67e00137,0x00000000}},	//   ktii, _tvor, höjd,
  { {0xa3d80161,0x3f85005b,0x6564001f,0x00000000}},	//   ाता_, _yolu_, ddih,
  { {0xaa94019c,0x0a942049,0xdb0119c7,0x00000000}},	//   _милч, _малю, pilá,
  { {0xa143003d,0x569451c1,0xd6d90051,0x00000000}},	//   šķir, парт, ęło_,
  { {0x7df1008f,0x6f1a51c2,0x00000000,0x00000000}},	//   _jāsp, _letc,   ,
  { {0x644400a4,0xf3ff008d,0x5fba0042,0x00000000}},	// [9f30] gtii, _trãm_, ेवाल,
  { {0xdb1a0137,0x6f1a3272,0xed5900c2,0x00000000}},	//   botå, _netc, roži_,
  { {0xa5f90001,0x92590076,0xd6d9007e,0x00000000}},	//   _њему_, рает_, _خودش_,
  { {0x6444004b,0x3f8551c3,0x212a005d,0x00000000}},	//   btii, _solu_, ليمی_,
  { {0x6d9c0025,0x4acf0053,0x3f8514e2,0x00000000}},	//   _méad, _सुनव, _polu_,
  { {0x6d9c0139,0x7a010023,0x3f6951c4,0x00000000}},	//   _léad, _lēta, рико_,
  { {0xfebb007e,0x29021081,0x623401dd,0x00000000}},	//   داشت_, ycka_, _неру,
  { {0x7dc500ea,0x236351c5,0x7ed400de,0x00000000}},	//   lósz, _hajj_, أزها,
  { {0x6d950026,0x29d90025,0x3f850150,0x00000000}},	//   _fáan, téan_, _tolu_,
  { {0x0a490121,0x25ad0061,0x5ba92183,0x00000000}},	//   азой_, čely_, рком_,
  { {0xdcfb06bb,0x2fc00139,0xc332009f,0x00000000}},	//   ljuč, éige_, ווי_,
  { {0x6d9c0d23,0x64440072,0x5c75005e,0x00000000}},	//   _céad, ytii, _млет,
  { {0xe45f024a,0x656400a8,0x2902056c,0x00000000}},	//   _myös_, vdih, rcka_,
  { {0xe73a0856,0x6d9c0003,0x6d490206,0x00000000}},	//   јев_, _péag, lfea,
  { {0xba77006a,0x6d9c0025,0xf7430121,0x00000000}},	//   _داشت, _féad, ьеро,
  { {0x6444024a,0x799d2cbf,0x29d90139,0x00000000}},	//   ttii, chsw, néal_,
  { {0xd46706cb,0x6d490025,0x656451c6,0x00000000}},	// [9f40] оите_, ifea, rdih,
  { {0x64440ff2,0x6d490025,0x03260086,0x00000000}},	//   rtii, hfea, іден,
  { {0x27ed00ac,0x644451c7,0xc3050021,0x00000000}},	//   ïene_, stii, سبلو,
  { {0x6443003b,0x6444078c,0xdb010315,0x00000000}},	//   ănir, ptii, lilä,
  { {0xe05604f6,0x6d490025,0x29d90139,0x00000000}},	//   تخاب, dfea, déal_,
  { {0x443251c8,0x60290054,0xdb01165b,0x00000000}},	//   mry_, сіїв_, nilä,
  { {0x44320034,0xdd9a00e2,0x6d491486,0x00000000}},	//   lry_, иши_, ffea,
  { {0x44320f21,0xe45f0072,0xdb010072,0x00000000}},	//   ory_, _työt_, hilä,
  { {0xdb0100fe,0x6d9c0025,0x44322b9e,0x00000000}},	//   kilä, _réad, nry_,
  { {0x443200e3,0x0b8a0612,0x1be7005e,0x00000000}},	//   iry_, рсии_, одњи_,
  { {0x9d460432,0x8aa30156,0x443251c9,0x00000000}},	//   _межд, дряд, hry_,
  { {0x44320c60,0x6d490025,0x29d90139,0x00000000}},	//   kry_, cfea, céal_,
  { {0x9f4c0080,0xdce9007d,0xbec7008f,0x00000000}},	//   _lidí_, bjeđ, rzīš,
  { {0xdceb008f,0xdb01004b,0x44321026,0x00000000}},	//   _ungā, gilä, dry_,
  { {0x99d70032,0x44320f21,0x2b4e0089,0x00000000}},	//   _وتعا, ery_, _ibfc_,
  { {0x628300bd,0x39150121,0x44320cb6,0x00000000}},	//   änom, _эмир, fry_,
  { {0xb9c40021,0x443251ca,0x7dc5013d,0x00000000}},	// [9f50] _تقيي, gry_, tósz,
  { {0x67e000fe,0x3959077d,0xef1f0051,0x00000000}},	//   töje, less_, ążka_,
  { {0x443251cb,0x61fc51cc,0x41550081,0x00000000}},	//   ary_, _curl, звес,
  { {0x395933f5,0x7dc5000f,0xe1f8000d,0x00000000}},	//   ness_, sósz, ігі_,
  { {0xd0ab000a,0xa2cb0053,0xf9940063,0x00000000}},	//   јтед_, _तुर्, ורף_,
  { {0x38640014,0x61fc51cd,0x23fa0063,0x00000000}},	//   æmri_, _furl, _להשא,
  { {0xa3d80053,0x8db5012c,0x52244968,0x00000000}},	//   ातर_, зспі, _офта,
  { {0x2d99006d,0x20240014,0x3959008f,0x00000000}},	//   óse_, örið_, jess_,
  { {0x6d490025,0x29d951ce,0x9f890046,0x00000000}},	//   rfea, réal_, búð_,
  { {0xeb9951cf,0x0b4501ce,0x94b6009d,0x00000000}},	//   сио_, чнон, לִיד_,
  { {0xdb080331,0x8a05066e,0x395912a9,0x00000000}},	//   cidí, язне, fess_,
  { {0x499a1406,0xed59008f,0xc7a9009a,0x00000000}},	//   стоя_, tožu_, _גב_,
  { {0xdb010072,0xef18008f,0xed5900a8,0x00000000}},	//   tilä, _soļi_, mež_,
  { {0xfaa52544,0xed5900b2,0x44324b39,0x00000000}},	//   _нало, lež_, vry_,
  { {0xa596005a,0x6d950139,0xdb010527,0x00000000}},	//   пращ, _láam, rilä,
  { {0xf99f0290,0x395951d0,0x3940003b,0x00000000}},	//   chè_, cess_, _ucis_,
  { {0xed590024,0x442651d1,0x443251d2,0x00000000}},	// [9f60] iež_, éo_, ury_,
  { {0x443251d3,0x33630054,0x00000000,0x00000000}},	//   rry_, нвуг,   ,
  { {0xe7170063,0xdb08017d,0xd6fb0063,0x00000000}},	//   _מחיר_, lidã, _לפיכ,
  { {0xc69300b5,0x443208b3,0x9f4c01c2,0x00000000}},	//   _נאר_, pry_, _vidí_,
  { {0xed5908ea,0x4424008b,0x3166013d,0x00000000}},	//   dež_, _ìm_, rdoz_,
  { {0x395900bd,0xae000053,0xa2a70053,0x00000000}},	//   zess_, _लंदन_, _टेक्,
  { {0x6d9c0025,0x9f44006d,0x539b0063,0x00000000}},	//   _réab, _sumó_, _פילו,
  { {0x5c980062,0x7a01008f,0x5c740154,0x00000000}},	//   жкия_, _pētn, длит,
  { {0xdb08006d,0x8c430002,0x6566184f,0x00000000}},	//   sidí, еење, _makh,
  { {0xdb08032a,0xddd80078,0x395900e5,0x00000000}},	//   pidí, tyvų, wess_,
  { {0x39593850,0xa9350e74,0x00000000,0x00000000}},	//   tess_, менш,   ,
  { {0x3dcd01e1,0x656651d4,0x02b70063,0x00000000}},	//   coew_, _nakh, להים_,
  { {0x395951d5,0x6d42003b,0xf3ff0013,0x00000000}},	//   ress_, _icoa, _trãi_,
  { {0x6d9c0027,0x395951d6,0xdb1a00ea,0x00000000}},	//   _féac, sess_, eltö,
  { {0xf674000d,0x656637d3,0x66e7013d,0x00000000}},	//   нгрэ, _bakh, déké,
  { {0x98b9001c,0xdb010137,0x25a00025,0x00000000}},	//   nesī_, rilå, ghil_,
  { {0x7a08004c,0x69cf0260,0x58040044,0x00000000}},	// [9f70] _děte, moce, _كويك,
  { {0x25a0215e,0x69cf0de5,0x889c0063,0x00000000}},	//   ahil_, loce, _לבחי,
  { {0x2480003b,0x656611fe,0x8e20046e,0x00000000}},	//   axim_, _fakh, сiм_,
  { {0x25a00122,0x69cf0d6c,0x29d20014,0x00000000}},	//   chil_, noce, láar_,
  { {0xf2110042,0xe0ce082d,0x00000000,0x00000000}},	//   डीज़_, тв_,   ,
  { {0xc3480085,0xdbf1011b,0xa3d80082,0x00000000}},	//   _нясе_, tříh, ातः_,
  { {0x656600ac,0xed59007c,0x9e640044,0x00000000}},	//   _yakh, tež_, فاين,
  { {0x9627003d,0x6d9c0164,0x200f04aa,0x00000000}},	//   _ieņē, _réac, ppgi_,
  { {0x1c420076,0xcc89007e,0x69cf51d7,0x00000000}},	//   вным, زنده_, doce,
  { {0xdb08017d,0xcb69007e,0x7d03013d,0x00000000}},	//   vidã, آمده_, _bíró,
  { {0x7e7e0137,0x52db0053,0x9f340054,0x00000000}},	//   äppt, _भरोस, _чехі,
  { {0xdb08017d,0x3eba0066,0x69cf2b92,0x00000000}},	//   tidã, úpte_, goce,
  { {0x656651d8,0x29d20046,0xbb450131,0x00000000}},	//   _rakh, fáar_, _желк,
  { {0x6d9c0027,0x65661ed4,0xdb08017d,0x00000000}},	//   _téac, _sakh, ridã,
  { {0xd5b20021,0x7c3b004b,0xba190044,0x00000000}},	//   نفس_, luur, _بيعا_,
  { {0xdb1a0164,0x6d5b01f4,0x69cf16eb,0x00000000}},	//   entè, neua, coce,
  { {0xb9b30021,0x66e700ea,0x98a6005e,0x00000000}},	// [9f80] _جميع, téké, _ципе,
  { {0x61b80053,0x6d5b001f,0x39b6001c,0x00000000}},	//   ेक्ष, heua, rāsu_,
  { {0x7c3b006f,0x1a9a0047,0x656651d9,0x00000000}},	//   huur, ֿינע, _takh,
  { {0xe0da376d,0x64630072,0x7c3b0cb0,0x00000000}},	//   ове_, äviä, kuur,
  { {0x9fca0076,0x7c3b0ff2,0x0333004c,0x00000000}},	//   огда_, juur, _říši_,
  { {0x6d42000c,0x7c3b0180,0x09bb0053,0x00000000}},	//   _scoa, duur, _उद्य,
  { {0x7e2a000d,0xdb20011b,0x1eaa005d,0x00000000}},	//   ціла_, átím, غاتي_,
  { {0x7176006a,0x661a0066,0xdb0801c8,0x00000000}},	//   _تهرا, átky, didá,
  { {0x69cf51da,0x9bf40699,0xef18008f,0x00000000}},	//   voce, нзич, _soļu_,
  { {0xdb1a1560,0xef18008f,0x547b07e9,0x00000000}},	//   onté, _poļu_, קטיו,
  { {0xd337014e,0x3f9b0164,0x69cf258d,0x00000000}},	//   וריה_, êque_, toce,
  { {0x7c3b0104,0x387208a9,0x497404d6,0x00000000}},	//   buur, _bryr_, влюс,
  { {0xad25007e,0x69cf3849,0xd7770021,0x00000000}},	//   _سرنو, roce, واسع,
  { {0xac97006a,0xeaaf006a,0xd90f007e,0x00000000}},	//   _تنها_, اعی_, دیک_,
  { {0x6d40006f,0x5b570132,0x69cf0972,0x00000000}},	//   ogma, _חיוב_, poce,
  { {0x69360080,0x67e00137,0x6d4051db,0x00000000}},	//   _přež, röja, ngma,
  { {0xdb1a01d4,0x3f9e01a1,0x33753d47,0x00000000}},	// [9f90] enté, _oltu_, нгар,
  { {0xc7c70086,0xdce2007c,0x68e00058,0x00000000}},	//   _іспи, _naoč, ümde,
  { {0x27f80066,0x515549fb,0x7c3b00ca,0x00000000}},	//   ženú_, етлу, zuur,
  { {0x59f900b7,0x3f9e02f7,0x2519009a,0x00000000}},	//   פּעד, _altu_, _מוֹא,
  { {0xdb010137,0x3f8c01c8,0x7fd50054,0x00000000}},	//   mnlö, _bodu_, нікі,
  { {0x63b10080,0x141a0063,0x7c3b056f,0x00000000}},	//   édně, _מושב, vuur,
  { {0x53340001,0x44294397,0xbdf5005e,0x00000000}},	//   _јест, lsa_, нчић,
  { {0x217b0032,0xbc650b3f,0x7c3b11b1,0x00000000}},	//   _بحسب_, евик, tuur,
  { {0x442951dc,0x442b3347,0x7de3013d,0x00000000}},	//   nsa_, _jvc_, _kősz,
  { {0x2d8200c7,0x442951dd,0x6d40002c,0x00000000}},	//   öker_, isa_, agma,
  { {0x752f0051,0xd94605f7,0x7c3b1c0e,0x00000000}},	//   _odcz, нени, suur,
  { {0xa96a0001,0x3f87007d,0x44293b3e,0x00000000}},	//   чима_, ljnu_, ksa_,
  { {0xaacf0161,0x752400eb,0xb9080053,0x00000000}},	//   _सुरक, vaiz, _भर_,
  { {0xbb850021,0x7d0951de,0x442951df,0x00000000}},	//   _سلبي, lces, dsa_,
  { {0x442951e0,0xdce2001c,0x7c260240,0x00000000}},	//   esa_, _bloķ, škrt,
  { {0x6d9c0d23,0x7d09053f,0x442951e1,0x00000000}},	//   _léan, nces, fsa_,
  { {0x7c2951e2,0x28060051,0x442951e3,0x00000000}},	// [9fa0] nser, ówną_, gsa_,
  { {0x6d9c0164,0x7d090051,0x68e451e4,0x00000000}},	//   _néan, hces, _izid,
  { {0x442951e5,0x7d090051,0xeb960041,0x00000000}},	//   asa_, kces, עדער_,
  { {0x7c2951e6,0xc3290063,0xd13201fb,0x00000000}},	//   kser, מו_, امش_,
  { {0xfaf8001c,0x3f9e0150,0x7c2951e7,0x00000000}},	//   ldīt_, _pltu_, jser,
  { {0x6d9c0025,0x7d094f5e,0x7c2951e8,0x00000000}},	//   _céan, eces, dser,
  { {0x6d9c0027,0x7c2b1699,0x7c291744,0x00000000}},	//   _déan, _avgr, eser,
  { {0xfaf8008f,0x6d40007d,0x65bb0072,0x00000000}},	//   idīt_, ugma, mähä,
  { {0xdb030137,0x6d403921,0x7c292181,0x00000000}},	//   _omnä, rgma, gser,
  { {0x6d9c0003,0x9b94005e,0xdd000058,0x00000000}},	//   _géan, тиоц, ıtıl,
  { {0x533700b5,0x442946bb,0x7c290e6c,0x00000000}},	//   ענטן_, zsa_, aser,
  { {0x23a400c7,0xbae3000d,0x442951e9,0x00000000}},	//   _höjd_, ыцый, ysa_,
  { {0xc173014e,0x67e000c7,0x7c2948ec,0x00000000}},	//   אחר_, röjn, cser,
  { {0x5c970088,0x69c4008f,0x442951ea,0x00000000}},	//   _якія_, _ejie, vsa_,
  { {0x6be30032,0x67e00137,0x36d50d34,0x00000000}},	//   _حكوم, möjl, товр,
  { {0x442951eb,0xdce00075,0x442b51ec,0x00000000}},	//   tsa_, lkmı, _pvc_,
  { {0xf3f9000a,0x24580076,0x98b90006,0x00000000}},	// [9fb0] днаш_, нать_, mesį_,
  { {0x23a400c7,0x61c90053,0x69dd51ed,0x00000000}},	//   _nöjd_, िक्ष, llse,
  { {0x7d09006f,0x290b0290,0x442951ee,0x00000000}},	//   yces, occa_, ssa_,
  { {0x6d9c51ef,0x98b90006,0x7f9400cd,0x00000000}},	//   _séan, nesį_, _màqu,
  { {0x69dd05e5,0x23a40137,0x3f694b31,0x00000000}},	//   ilse, _böjd_, дило_,
  { {0x7c2951f0,0x2607004b,0x69dd004d,0x00000000}},	//   vser, _kõo_, hlse,
  { {0x8fa20076,0x69c70080,0x644d51f1,0x00000000}},	//   раще, čkej, ltai,
  { {0xdb010025,0x644d51f2,0xf67c0063,0x00000000}},	//   mhlé, otai, לאומ,
  { {0xdd8e0032,0x6d9c0025,0xdca50002,0x00000000}},	//   توي_, _téan, тапи,
  { {0x7d0951f3,0x69dd51f4,0x69d651f5,0x00000000}},	//   sces, else, _skye,
  { {0x644d51f6,0x61fb05b3,0x7a08004c,0x00000000}},	//   htai, _kiul, _pěta,
  { {0x69960088,0xdb0800fe,0x644d276c,0x00000000}},	//   трох, eidä, ktai,
  { {0x0db800f2,0x8c4517e6,0x61e9002b,0x00000000}},	//   _ثالث_, _реле, _mhel,
  { {0x69dd0004,0x2d8f0122,0x8c1a009a,0x00000000}},	//   alse, _hoge_, _חוסי,
  { {0xfaf8001c,0x9f450025,0xecc3001c,0x00000000}},	//   udīt_, _chlé_, šķās_,
  { {0x61fb0035,0xdb1a0051,0x644d51f7,0x00000000}},	//   _niul, botó, ftai,
  { {0x60db0009,0x2d8f1a99,0x23bf0042,0x00000000}},	// [9fc0] _nyum, _moge_, ्वंद,
  { {0x61e90019,0x656d0150,0x2d8f51f8,0x00000000}},	//   _ahel, adah, _loge_,
  { {0xe286005a,0x179b0063,0x23a40137,0x00000000}},	//   ължи, _חייב, _nöje_,
  { {0x61e951f9,0x644d0b3c,0x2d8f08ed,0x00000000}},	//   _chel, btai, _noge_,
  { {0xd007011c,0x644d2336,0x61fb017e,0x00000000}},	//   вече_, ctai, _diul,
  { {0xdefa0076,0x8cc50053,0x4fd30086,0x00000000}},	//   мый_, ापनो, ажіт,
  { {0xdeef000d,0x60c951fa,0x61fb003b,0x00000000}},	//   ры_, _exem, _fiul,
  { {0x61fb4dc4,0xc6930063,0x2d8f0331,0x00000000}},	//   _giul, שאה_, _coge_,
  { {0x9f4c00fe,0x2d8f2f80,0x98b90078,0x00000000}},	//   _pidä_, _doge_, vesį_,
  { {0xdc55005d,0x5b14014b,0x00000000,0x00000000}},	//   اريک, ымот,   ,
  { {0x2d8f017d,0xdd92005d,0x69dd013d,0x00000000}},	//   _foge_, _پوش_, tlse,
  { {0x20040035,0x61fb01a8,0x4ea5005e,0x00000000}},	//   _kumi_, _xiul, _срђа,
  { {0x1d070138,0x8c4341db,0x69dd51fb,0x00000000}},	//   _речи_, _вече, rlse,
  { {0xc7c40076,0x9f450025,0xdb1a51fc,0x00000000}},	//   асси, _phlé_, ontí,
  { {0x6d9c0027,0xdb1a0139,0x200451fd,0x00000000}},	//   _léam, nntí, _lumi_,
  { {0xa3b50053,0x644d434e,0xa2b80053,0x00000000}},	//   _जगह_, ttai, ्पन्,
  { {0x656d18a6,0x6d9c4952,0x3949017d,0x00000000}},	// [9fd0] rdah, _réal, _icas_,
  { {0x386900c7,0x61e92704,0x644d0d20,0x00000000}},	//   _isar_, _shel, rtai,
  { {0x60db0089,0x644d51fe,0x644000a5,0x00000000}},	//   _syum, stai, _åmin,
  { {0x2004003e,0x644d51ff,0x81d4000d,0x00000000}},	//   _bumi_, ptai, аціц,
  { {0xf3ff017d,0x628a069f,0x443f0013,0x00000000}},	//   _isão_, øfor, _êu_,
  { {0x289c0063,0x200430d2,0xdcfb007d,0x00000000}},	//   וידא, _dumi_, ljuć,
  { {0x6d9c0025,0x61e95200,0xc6950041,0x00000000}},	//   _téal, _thel, טאַ_,
  { {0x799d006f,0x61e95201,0xdcfb007d,0x00000000}},	//   jksw, _uhel, njuć,
  { {0x60db005b,0xb0b70042,0x2bb90044,0x00000000}},	//   _uyum, _अधिग, فادة_,
  { {0xe9df0066,0xdd1c004c,0x3b850054,0x00000000}},	//   elú_, háňk, улог,
  { {0x386900e3,0x2d8f0003,0x9f5600cf,0x00000000}},	//   _asar_, _toge_, ågår_,
  { {0x98b2005b,0xcd2b007e,0xf769009a,0x00000000}},	//   _sayı_, _آسان_, _מק_,
  { {0x7d1b4517,0x98b20058,0xc8b605ac,0x00000000}},	//   mbus, _payı_, усны,
  { {0x366a0088,0xe9df0025,0x764e04aa,0x00000000}},	//   наго_, alú_, ttby,
  { {0x46a3071f,0xfb1600de,0x00000000,0x00000000}},	//   барв, _صقيع_,   ,
  { {0x7c3b00ca,0x09e60054,0xceb2009f,0x00000000}},	//   orur, _щойн, צין_,
  { {0x5fc30053,0x29d90003,0x69db0047,0x00000000}},	// [9fe0] वचाल, réat_, _אַזו,
  { {0x6d9c0027,0x20040509,0x7c3b0023,0x00000000}},	//   _réam, _rumi_, irur,
  { {0xdb9a00b5,0x95c6007e,0x6d9c0139,0x00000000}},	//   עסער, _ميده, _séam,
  { {0x10a6047e,0x3217007e,0x644b00cd,0x00000000}},	//   лиен, ايند_, àgic,
  { {0x25d7014e,0xdfda005a,0x62830072,0x00000000}},	//   _תוכן_, нък_, änor,
  { {0x7d1b0019,0x9e140083,0xce940094,0x00000000}},	//   ebus, адкі, иалъ,
  { {0xb7db0047,0x7c3b45ca,0x7dde005f,0x00000000}},	//   עקצי, erur, lësi,
  { {0x7d1b00a4,0xdc8a0002,0x6d9c0139,0x00000000}},	//   gbus, есол_, _téam,
  { {0x5b260475,0x51930021,0x00000000,0x00000000}},	//   льна, _القذ,   ,
  { {0x7d1b00a4,0x7fd60085,0x4a54015b,0x00000000}},	//   abus, _сібі, акос,
  { {0xe9190054,0xfc2f007e,0xd35707e9,0x00000000}},	//   коні_, يحی_, ניטי_,
  { {0x7d1d0026,0x3ec20078,0x29040734,0x00000000}},	//   ðsst, įstą_, žman_,
  { {0x7c3b000c,0xe9df0025,0x6605004b,0x00000000}},	//   crur, rlú_, _suhk,
  { {0x66050004,0x2fc00025,0xa49b0013,0x00000000}},	//   _puhk, éigh_, _ngòa,
  { {0xa2d40042,0x6757005d,0x2b920043,0x00000000}},	//   _बुल्, نیکس_, _نیکس,
  { {0x386941b0,0x3949002b,0x96f80094,0x00000000}},	//   _tsar_, _ucas_, уест_,
  { {0x386933c5,0x442f00ea,0x29d90025,0x00000000}},	// [9ff0] _usar_, ég_, séas_,
  { {0x17550062,0x66050cb0,0xe3b30044,0x00000000}},	//   _твоя, _tuhk, حرر_,
  { {0x7d0200c3,0x76b80121,0x7d1b2231,0x00000000}},	//   _ogos, _блэр_, ybus,
  { {0xd5670336,0x7d02155f,0x6019030b,0x00000000}},	//   _стоп, _ngos, водя_,
  { {0x656f2389,0x5ff5005e,0x998d004c,0x00000000}},	//   _iach, азду, kudž_,
  { {0xad9c0024,0xdfd4000d,0x25a95202,0x00000000}},	//   _stĺp, бочы, lhal_,
  { {0x9f9600d7,0x244f005b,0x7c22008b,0x00000000}},	//   рвју_, lüm_, _awor,
  { {0x656f5203,0x25a95204,0xdb01004b,0x00000000}},	//   _jach, nhal_, silü,
  { {0x244f005b,0x23a40137,0x7d1b5205,0x00000000}},	//   nüm_, _höja_, rbus,
  { {0xdb1a00e8,0xeb990001,0x7c3b0003,0x00000000}},	//   litê, тио_, rrur,
  { {0xdd8e007e,0x7c224dfe,0x6fdf0003,0x00000000}},	//   سوی_, _ewor, vêch,
  { {0x645d5206,0x656f5207,0xdb010025,0x00000000}},	//   _opsi, _nach, mhlí,
  { {0x25a90150,0x29d90139,0xc796000d,0x00000000}},	//   dhal_, téar_, арвы,
  { {0x2d8d0159,0xf746005e,0x25a900a8,0x00000000}},	//   ljee_, јево, ehal_,
  { {0x645d00eb,0x656f5208,0xdb0100cd,0x00000000}},	//   _apsi, _bach, bilò,
  { {0x656f5209,0x3eaa004d,0x05660141,0x00000000}},	//   _cach, _übte_, јван,

  { {0x0446520a,0x6fdf0164,0x29d90025,0x00000000}},	// [a000] резн, pêch, péar_,
  { {0x656f0025,0xdb1a0025,0xd764007e,0x00000000}},	//   _each, ontá, _اندی,
  { {0x55e60002,0x2d9f0072,0x69c60524,0x00000000}},	//   _вонб, kkue_, onke,
  { {0x9f450025,0xa50a00d7,0x244f005b,0x00000000}},	//   _dhlí_, _шема_, büm_,
  { {0x65640072,0x69c62366,0x51550092,0x00000000}},	//   meih, inke, стху,
  { {0x6d59004d,0x08770047,0x656f23d3,0x00000000}},	//   _abwa, יענט_, _zach,
  { {0x7c220034,0x656f1f48,0xfda6005e,0x00000000}},	//   _swor, _yach, ијим,
  { {0xac540021,0xdceb005b,0x65a3004b,0x00000000}},	//   منبث, _algı, _lõhn,
  { {0x9da7005a,0x644400a4,0xdb1a32b4,0x00000000}},	//   ръща_, nuii, entá,
  { {0x29120035,0x69c6520b,0x6d9c0139,0x00000000}},	//   _afya_, enke, _méai,
  { {0xc3330132,0x237900b5,0xa4e30053,0x00000000}},	//   חות_, אָרמ, _खर्च_,
  { {0x7c220045,0x7d02007d,0xdb0101a8,0x00000000}},	//   _twor, _ugos, uilò,
  { {0x65640b73,0x9999013d,0x656f520c,0x00000000}},	//   deih, érő_, _rach,
  { {0x656f520d,0xc7bb0121,0x68ed0058,0x00000000}},	//   _sach, тём_, _ıldı,
  { {0x656f520e,0xaa430141,0x8b6501fb,0x00000000}},	//   _pach, _дејл, _دانم,
  { {0xf53f0137,0x65640050,0xdb1a005f,0x00000000}},	//   _blåa_, geih, kitë,
  { {0x25a9520f,0x19b80021,0x656f5210,0x00000000}},	// [a010] rhal_, _خطوة_, _vach,
  { {0x656f5211,0x244f005b,0x25a04a6b,0x00000000}},	//   _wach, rüm_, akil_,
  { {0xed5902f4,0x656f5212,0x25a90943,0x00000000}},	//   liže_, _tach, phal_,
  { {0x656f0025,0x998d0051,0x65640072,0x00000000}},	//   _uach, erdź_, ceih,
  { {0x20670001,0x85fa0047,0x321a00e5,0x00000000}},	//   рђев, _תּיק, appy_,
  { {0x94f6009a,0x0217005d,0xf0a8012c,0x00000000}},	//   _לצרף_, _نظرد, шкіл_,
  { {0x61e2005b,0xdb1a00cd,0xed59026c,0x00000000}},	//   blol, mitè, гой_,
  { {0xf1a7000a,0xdb1a01a8,0x0d8522cf,0x00000000}},	//   _тргн, litè, слин,
  { {0x752d01f4,0xdb010046,0x3b090094,0x00000000}},	//   iaaz, shlí, лепо_,
  { {0x2cad0051,0xed59007d,0x4a450098,0x00000000}},	//   rzed_, diže_, бнов,
  { {0x733a0047,0x7e6d0023,0x2cad013d,0x00000000}},	//   װערס, āaps, szed_,
  { {0x69c65213,0xfe70005d,0xdbd90075,0x00000000}},	//   unke, _زدم_, lçül,
  { {0xb8860066,0xdb08004b,0xfc3f0139,0x00000000}},	//   _opíš, endõ, áíd_,
  { {0x656400bd,0x999f004c,0xfb350041,0x00000000}},	//   weih, butů_, _האַש_,
  { {0x644b0268,0x6b8347da,0x656401b2,0x00000000}},	//   àgin, _inng, teih,
  { {0xa2b80053,0x6d495214,0x00000000,0x00000000}},	//   ्पस्, ngea,   ,
  { {0x7984002c,0x6d490025,0xf7460856,0x00000000}},	// [a020] _iniw, igea, _лепо,
  { {0x25a05215,0x25b9004b,0x7996002b,0x00000000}},	//   skil_, _emsl_, _hoyw,
  { {0x8675000d,0x65640072,0x9bba0041,0x00000000}},	//   _дыяц, peih, נצעפ,
  { {0x614640d8,0xd764007e,0x7a13003b,0x00000000}},	//   седа, _انگی, _găte,
  { {0xdb0300ea,0xb0330086,0x6d4900e5,0x00000000}},	//   _elné, зніш, dgea,
  { {0x33d50086,0xccf90051,0x5f93005e,0x00000000}},	//   _діст, reśl_, зишт,
  { {0x62650021,0x91e61e1b,0x44325216,0x00000000}},	//   _وافق, _гове, lsy_,
  { {0x6c145217,0xdb1a09ed,0x7d981f30,0x00000000}},	//   одиф, mité, рвис_,
  { {0xdb1a03b2,0x4432425a,0x6ab20053,0x00000000}},	//   lité, nsy_, ुप्र,
  { {0xdb0a0137,0x4432006c,0x5a341f9d,0x00000000}},	//   _omfå, isy_, онот,
  { {0xdb1a12a2,0xaa5828dd,0xa3d90042,0x00000000}},	//   nité, шину_, ावत_,
  { {0x394d0994,0x44325218,0xc27b0047,0x00000000}},	//   ües_, ksy_, ארטי,
  { {0xac94005a,0xcb340062,0x69df005f,0x00000000}},	//   _фалш, _делъ, _ūpes,
  { {0x443210e9,0x7a13003b,0xdca3005e,0x00000000}},	//   dsy_, _săte, _хаљи,
  { {0x9f5e0164,0x38605219,0xfa330593,0x00000000}},	//   _cité_, _epir_, _فريد,
  { {0xb8860080,0xdb1a0003,0x7bda521a,0x00000000}},	//   _spíš, dité, lotu,
  { {0xe4500021,0x7bc8521b,0xe4e70054,0x00000000}},	// [a030] فضل_, ondu, сівн,
  { {0xa3b30053,0x7bc8521c,0x68ed4b80,0x00000000}},	//   जों_, nndu, _izad,
  { {0xb886034d,0xdb080025,0xa2b80042,0x00000000}},	//   _vpíš, ghdé, ्पष्,
  { {0x7bda00fe,0xa159521d,0x63be008f,0x00000000}},	//   hotu, раду_, aipn,
  { {0x7bda024a,0xdb010124,0x19580041,0x00000000}},	//   kotu, ihlá, מבאל_,
  { {0x8cdc0161,0xdb1a29be,0xa2d40042,0x00000000}},	//   _पड़ो, bité, _बुक्,
  { {0x7bda2d09,0xdb1a521e,0x35f8007e,0x00000000}},	//   dotu, cité, _خرید_,
  { {0x8db50088,0xd0d5005a,0xa2b80161,0x00000000}},	//   ўскі, _добъ, ्पर्,
  { {0x7bda004b,0x6d49521f,0x7bc80014,0x00000000}},	//   fotu, rgea, fndu,
  { {0xdfdb0062,0x6d49004d,0x7bda5220,0x00000000}},	//   _съб_, sgea, gotu,
  { {0x68ed5221,0x8a05014b,0x99d60044,0x00000000}},	//   _azad, юзне, قتحا,
  { {0xdb0100fe,0xdb1a00fe,0x82760047,0x00000000}},	//   kilö, entä, קערע_,
  { {0xa3d90235,0x629e0051,0xa1560063,0x00000000}},	//   ावा_, zypo, חברה_,
  { {0x6b830031,0x97da0121,0x7bda38fd,0x00000000}},	//   _unng, рьму_, cotu,
  { {0x629e3849,0xa50a05bd,0x672e013d,0x00000000}},	//   xypo, иева_, rabj,
  { {0xdb010027,0xdb1a419d,0x79840051,0x00000000}},	//   chlá, vité, _uniw,
  { {0x29050080,0xdb0b0014,0x7cf60047,0x00000000}},	// [a040] ělat_, _óhóf, ַזעס_,
  { {0xdb1a12a2,0x44325222,0x7ae30072,0x00000000}},	//   tité, rsy_, _kynt,
  { {0x7a08004c,0x63be00c2,0x44325223,0x00000000}},	//   _pěti, ripn, ssy_,
  { {0xf3e9014e,0x7bda0035,0xdb1a5224,0x00000000}},	//   דף_, zotu, rité,
  { {0x7bda0035,0x7bc80026,0xdb1a5225,0x00000000}},	//   yotu, yndu, sité,
  { {0x2d9913ac,0x27170080,0xdb01004b,0x00000000}},	//   ösen_, mění_, lilõ,
  { {0xf8bf0003,0x59ca0053,0x6d470078,0x00000000}},	//   mbée_, ाचार, ėjan,
  { {0x1d34005a,0x2dd70021,0x98a90022,0x00000000}},	//   чния, يبية_, _udać_,
  { {0x27170080,0xc5f30a7a,0xdb1a00fe,0x00000000}},	//   nění_, ודה_, yntä,
  { {0x68ed0051,0xa3ea0053,0x7bc85226,0x00000000}},	//   _rzad, मति_, undu,
  { {0x7ae30185,0x43770047,0x6d9c0003,0x00000000}},	//   _cynt, קײטן_, _béat,
  { {0x7bda0072,0x6d46013d,0x4c8601ce,0x00000000}},	//   sotu, ókad, _млев,
  { {0x7bda5227,0xa3ea0042,0xdc55005d,0x00000000}},	//   potu, मता_, _فروک,
  { {0x27170080,0xbb57000d,0xfc3f0066,0x00000000}},	//   dění_, _маіх_, šíc_,
  { {0x7ae30185,0xe6950121,0x387e008f,0x00000000}},	//   _gynt, чивы, ātra_,
  { {0xdb015228,0xbdf40063,0xa3b30042,0x00000000}},	//   gilõ, לֶּה_, जोई_,
  { {0x6d9c0025,0xed5900c2,0x27ed5229,0x00000000}},	// [a050] _héas, niža_, ïens_,
  { {0xd3710021,0x69dd522a,0xdb080331,0x00000000}},	//   عها_, lose, midó,
  { {0xdb010659,0xf804000d,0x65a3004b,0x00000000}},	//   silö, _ўчын, _jõhk,
  { {0xe0d3006a,0x6b980205,0xc6920047,0x00000000}},	//   وزش_, _lovg, _נאכ_,
  { {0x65a30019,0x7a13003b,0x95160063,0x00000000}},	//   _lõhk, _măta, _מקרא_,
  { {0x62350caa,0x69dd522b,0xb4fa0063,0x00000000}},	//   _негу, hose, _לפרי,
  { {0x69dd1668,0x6e92005d,0xfe790085,0x00000000}},	//   kose, فلوا, сёлы_,
  { {0x32280086,0x9f470139,0xf1bf013d,0x00000000}},	//   _фірм_, nmnú_, _öá_,
  { {0x65a30004,0xcc350021,0x7ae3095f,0x00000000}},	//   _põhj, أربع, _synt,
  { {0x7ae321e7,0x5ba9522c,0x69dd522d,0x00000000}},	//   _pynt, ском_, eose,
  { {0x0dcb0086,0x7a13003b,0xe9da0251,0x00000000}},	//   _куди_, _băta, йко_,
  { {0x20050009,0x186a0499,0x64560072,0x00000000}},	//   _hili_, бами_, ytyi,
  { {0x6d5b05b3,0x7ae31542,0x65aa0046,0x00000000}},	//   mfua, _wynt, _nýha,
  { {0x18670699,0x2717004c,0x8c1a089e,0x00000000}},	//   џари_, vění_, _הוסי,
  { {0xcb12014e,0xcf9200b5,0x6d5b0035,0x00000000}},	//   _אלו_, ײטן_, ofua,
  { {0x27170080,0x645600fe,0x7bc100fe,0x00000000}},	//   tění_, ttyi, lilu,
  { {0xddc1001c,0x00000000,0x00000000,0x00000000}},	// [a060] _aplū,   ,   ,
  { {0x7bc1522e,0xdb01017d,0x287b0063,0x00000000}},	//   nilu, bilô, _פנימ,
  { {0x479b00b5,0x6d9c0025,0xa79b0063,0x00000000}},	//   _הייס, _méar, _השיח,
  { {0x6d9c0025,0xa1580086,0x6a3a0047,0x00000000}},	//   _léar, іалу_, מגעפ,
  { {0xd12f04de,0x2005522f,0x6023000d,0x00000000}},	//   امه_, _bili_, едча,
  { {0xb6020080,0x44205230,0x6d9c0139,0x00000000}},	//   žáda, mpi_, _néar,
  { {0x2005005b,0x44205231,0x66065232,0x00000000}},	//   _dili_, lpi_, _kikk,
  { {0xdceb001c,0x91e30054,0x65a3004b,0x00000000}},	//   _sagā, _зосе, _rõhk,
  { {0x6d9c0025,0x20050290,0x7bc15233,0x00000000}},	//   _béar, _fili_, filu,
  { {0x0b8a0055,0x6d9c0025,0x6d5b0035,0x00000000}},	//   ссии_, _céar, afua,
  { {0x6d9c0139,0x69dd5234,0x0ac60121,0x00000000}},	//   _déar, tose, ящим,
  { {0x6d9c02dd,0x644401a9,0x7bc15235,0x00000000}},	//   _véas, krii, ailu,
  { {0x58870088,0x387f0014,0x7bc15236,0x00000000}},	//   чына, íur_, bilu,
  { {0x6d9c0c6a,0x66062c17,0x69dd0050,0x00000000}},	//   _téas, _aikk, sose,
  { {0x6a130021,0xe5ab0001,0x69dd02a0,0x00000000}},	//   _كبير, бњак_, pose,
  { {0x660600ea,0x21e7004b,0x7524013d,0x00000000}},	//   _cikk, rõhk_, gbiz,
  { {0x442000a4,0x66065237,0xdb1a003b,0x00000000}},	// [a070] gpi_, _dikk, mitâ,
  { {0xe4e4000d,0xdb1a00be,0x3374219b,0x00000000}},	//   хісн, litâ, нгур,
  { {0xdb0100bd,0x64445238,0x44205239,0x00000000}},	//   chlä, arii, api_,
  { {0x64440019,0x75350047,0x2005523a,0x00000000}},	//   brii, _קאָד_, _sili_,
  { {0x200d051e,0x7ff5007e,0x2005523b,0x00000000}},	//   _quei_, وستا, _pili_,
  { {0x442b113c,0xdceb003b,0x6d470078,0x00000000}},	//   _iwc_, _lagă, ėjam,
  { {0x7bc10290,0xdce9007d,0xdb1a0066,0x00000000}},	//   vilu, odeć, gití,
  { {0x6d5b0035,0x7db4000d,0x200500a4,0x00000000}},	//   ufua, есьц, _wili_,
  { {0x2005024a,0xd6d90051,0x752f0051,0x00000000}},	//   _tili_, ęły_, _mecz,
  { {0x752f0051,0x2bb90021,0x1bb90021,0x00000000}},	//   _lecz, تابة_, تابع_,
  { {0xd9464b41,0xc3320063,0x442b002b,0x00000000}},	//   мени, כוי_, _lwc_,
  { {0x5dd80086,0x1eea007e,0xc7a90063,0x00000000}},	//   _ефір_, _بومی_, _דב_,
  { {0x6d9c0027,0x6606047f,0x7bc1523c,0x00000000}},	//   _téar, _rikk, pilu,
  { {0x66060307,0xeab10021,0x87b93652,0x00000000}},	//   _sikk, _لعب_, пуст_,
  { {0x7a080080,0x6606065c,0xe57a0054,0x00000000}},	//   _děts, _pikk, озв_,
  { {0x7aee004d,0x85ea0054,0xdb1a3ecf,0x00000000}},	//   übte, ідав_, citâ,
  { {0x3cfa0047,0x4439523d,0xdb1a523e,0x00000000}},	// [a080] ַלענ, _cvs_, zití,
  { {0x44390469,0x6606006f,0x3ddf00ca,0x00000000}},	//   _dvs_, _wikk, houw_,
  { {0x64440004,0x4420514b,0x7d0b04aa,0x00000000}},	//   srii, spi_, _oggs,
  { {0x4420523f,0x64445240,0x00000000,0x00000000}},	//   ppi_, prii,   ,
  { {0x2f184fa2,0xd43614d7,0x00000000,0x00000000}},	//   поль_, _تعجب,   ,
  { {0xdb1a38c3,0x5e860363,0x43753d6d,0x00000000}},	//   zitâ, дуиз, _пуст,
  { {0x7c2b0185,0x63a35241,0xfc3f0139,0x00000000}},	//   _awgr, önne, áín_,
  { {0x65a30004,0x5c741d7c,0xbdf700f2,0x00000000}},	//   _põhi, елит, وريا_,
  { {0xe10b0063,0xfc3f0445,0x9b6a2530,0x00000000}},	//   _וּבָ, šín_, ошна_,
  { {0x65a3004b,0x409b009a,0x7ac634d0,0x00000000}},	//   _võhi, _ובמס, дсме,
  { {0x3ddf0122,0xdc55005d,0xed5a012c,0x00000000}},	//   bouw_, وریک, _мож_,
  { {0xdcff0023,0xc237009a,0x00000000,0x00000000}},	//   švār, ורטו_,   ,
  { {0xdb1a017d,0x8dfb009a,0x3dfb009a,0x00000000}},	//   ritâ, _והאת, _ולאד,
  { {0x2cb0005b,0xead41791,0x65a3004b,0x00000000}},	//   ıldı_, _поль, _jõhv,
  { {0xbd050164,0xf8ae007e,0x26070085,0x00000000}},	//   _théâ, لکی_, дчаг,
  { {0xdb1a078d,0xfaa7007e,0x6aa701e1,0x00000000}},	//   lità, _تجهی, øjfe,
  { {0x94ab0304,0x24580076,0xd37b0086,0x00000000}},	// [a090] цтва_, мать_, жче_,
  { {0xdb1a078d,0x44f40330,0x08f800f2,0x00000000}},	//   nità, тпус, _غريب_,
  { {0x69cf1523,0xe535089d,0x752f056c,0x00000000}},	//   once, _пень, _tecz,
  { {0x77b000c7,0x32640062,0x44395242,0x00000000}},	//   _växe, ътув, _tvs_,
  { {0xb06b0021,0xe0ce0086,0x6d9c0003,0x00000000}},	//   تصال_, ув_, _réap,
  { {0xf41f00fe,0x644d006c,0x9f47004c,0x00000000}},	//   _itä_, muai, olné_,
  { {0x644d5243,0x5214000d,0x25a95244,0x00000000}},	//   luai, _адст, okal_,
  { {0x69cf006d,0xf41f0137,0x7c950002,0x00000000}},	//   ébel, _träd_, ероц,
  { {0x3ddf006f,0x65600137,0x644d5245,0x00000000}},	//   rouw_, _ömhe, nuai,
  { {0x69cf5246,0x61eb124f,0xeb910044,0x00000000}},	//   ence, llgl, اظة_,
  { {0x25a9000f,0x644d0025,0xf41f0072,0x00000000}},	//   kkal_, huai, _ltä_,
  { {0x65a3004b,0x5d840021,0x9f5e00be,0x00000000}},	//   _kõhu, _للمل, _titã_,
  { {0x29040a26,0x7bf9005e,0x7bcc0014,0x00000000}},	//   äma_, _ендр_, ðluð,
  { {0xdb1a19c9,0x644d5247,0x25a90089,0x00000000}},	//   cità, duai, ekal_,
  { {0x7a09004c,0x65a3004b,0xa6a900f2,0x00000000}},	//   _větr, _lõhu, وافق_,
  { {0xdb1a5248,0x644d0025,0x65aa0240,0x00000000}},	//   pitã, fuai, _výho,
  { {0xd4672f16,0x644d5249,0x04432338,0x00000000}},	// [a0a0] ните_, guai, летн,
  { {0x32d622ce,0x213f0360,0x25a90360,0x00000000}},	//   нцес, _aduh_, akal_,
  { {0xdb1a524a,0x69c600fe,0xcb120047,0x00000000}},	//   nitá, oike, אלב_,
  { {0x2d9d0045,0x69c6524b,0x644d0003,0x00000000}},	//   _nowe_, nike, buai,
  { {0x69c600fe,0x644d0089,0xf5370063,0x00000000}},	//   iike, cuai, _אנכי_,
  { {0x69c60019,0x7bcf11f5,0x61eb004d,0x00000000}},	//   hike, écul, algl,
  { {0x61460001,0xda0b0053,0x69c6524c,0x00000000}},	//   _пева, _संगत_, kike,
  { {0x2247034d,0xc693014e,0x2c260086,0x00000000}},	//   ánke_, ראה_, ньог,
  { {0x2d9d00ac,0x69c60f4b,0x0caa0e82,0x00000000}},	//   _dowe_, dike, ятки_,
  { {0x61e20019,0x765c0051,0xceea000d,0x00000000}},	//   lool, ktry, _едзе_,
  { {0xdb1a524d,0x69c6524e,0xeb970002,0x00000000}},	//   rità, fike, хиќ_,
  { {0x765c18a4,0x248022aa,0x61e2004b,0x00000000}},	//   dtry, kvim_, nool,
  { {0x644d017d,0xfbcf007e,0x3f9e00c2,0x00000000}},	//   xuai, شتی_, _kotu_,
  { {0x8c1b00b5,0x765c00b9,0x61e2524f,0x00000000}},	//   _צווי, ftry, hool,
  { {0x61e20004,0x765c5250,0xc9870086,0x00000000}},	//   kool, gtry, _зупи,
  { {0x644d18b3,0x69c64988,0xf0a60013,0x00000000}},	//   tuai, cike, _đành_,
  { {0x798d0009,0x5964005a,0x26110053,0x00000000}},	// [a0b0] _inaw, _съща, _दूरी_,
  { {0x65a30019,0x644d0025,0x25a95251,0x00000000}},	//   _rõhu, ruai, skal_,
  { {0x32550928,0x644d180a,0x25a900a8,0x00000000}},	//   твер, suai, pkal_,
  { {0x65a3004b,0x11f60043,0xaadb009d,0x00000000}},	//   _põhu, نتنگ, החבר,
  { {0x644d04bc,0x7aea0b68,0x75360047,0x00000000}},	//   quai, _lyft, _בארד_,
  { {0xdb1a2e7f,0x10a20856,0x69c6011b,0x00000000}},	//   litæ, ришн, zike,
  { {0x6115000d,0xb1aa0014,0x3f9e008f,0x00000000}},	//   _адбу, þýðu, _dotu_,
  { {0x65a30019,0xfc3f108f,0x68fb0078,0x00000000}},	//   _tõhu, ším_, žudy,
  { {0x69c65252,0x0c3600de,0x00000000,0x00000000}},	//   vike, نكية_,   ,
  { {0x798d080d,0x765c5253,0x21e7004b,0x00000000}},	//   _anaw, ytry, rõhu_,
  { {0x3869000c,0x2fc70465,0x69c65254,0x00000000}},	//   _apar_, ming_, tike,
  { {0x2fc75255,0x765c073a,0x798d002b,0x00000000}},	//   ling_, vtry, _cnaw,
  { {0x2fc700e5,0x3ea7002b,0x98ab003b,0x00000000}},	//   oing_, lynt_, vacă_,
  { {0x69c65256,0xdb1a5257,0x61e25258,0x00000000}},	//   sike, pitá, zool,
  { {0x3ea7001f,0x49ba007e,0x2fc70104,0x00000000}},	//   nynt_, _يابد_, iing_,
  { {0x7d1b2aa9,0xceb2014e,0x765c1c38,0x00000000}},	//   ncus, ביל_, rtry,
  { {0xe8fa005a,0x69c40051,0x2fc75259,0x00000000}},	// [a0c0] _юли_, _imie, king_,
  { {0xf8370063,0x7c3b525a,0x2fc7525b,0x00000000}},	//   _שנית_, isur, jing_,
  { {0x2480017f,0x2fc7525c,0x3f9e0072,0x00000000}},	//   svim_, ding_, _rotu_,
  { {0x2fc70034,0x3ea7001f,0x248d007d,0x00000000}},	//   eing_, dynt_, _šeme_,
  { {0x61e20019,0xdfda005a,0x6e93007e,0x00000000}},	//   rool, мък_, یلها,
  { {0x66f60053,0x2fc706ef,0x6e8a005e,0x00000000}},	//   _इराक_, ging_, дљив_,
  { {0x61e20004,0x3ea70031,0x8fa30001,0x00000000}},	//   pool, gynt_, раје,
  { {0x2fc700a4,0x71590085,0xfe450043,0x00000000}},	//   aing_, _прус_, اکلی,
  { {0x7aea00c7,0x7c3b002c,0x2fc7525d,0x00000000}},	//   _syft, gsur, bing_,
  { {0xef83018e,0x69c4525e,0x2fc71157,0x00000000}},	//   _клуп, _amie, cing_,
  { {0x7c3b0034,0x3869132f,0x798d002b,0x00000000}},	//   asur, _spar_, _pnaw,
  { {0x200c00a4,0x7aea00f5,0xceb30047,0x00000000}},	//   _hidi_, _vyft, _דיע_,
  { {0xc1730063,0xdd05003b,0x987402fe,0x00000000}},	//   בחר_, ăpăt, аляц,
  { {0x798d002b,0x5c3700ff,0x6566525f,0x00000000}},	//   _wnaw, _ירדן_, _abkh,
  { {0xf8bf03d9,0xda7a005a,0x200c47e5,0x00000000}},	//   mbém_, _цял_, _midi_,
  { {0x798d0009,0x7c220024,0x200c0080,0x00000000}},	//   _unaw, _ktor, _lidi_,
  { {0x2fc75260,0xdb030137,0xd4070121,0x00000000}},	// [a0d0] ying_, _elnä, вяжи,
  { {0x02a7019d,0x98be000c,0x2fc70c69,0x00000000}},	//   крем, ştă_, xing_,
  { {0x9f5e024a,0x2fc75261,0xd25b0be6,0x00000000}},	//   _mitä_, ving_, ьца_,
  { {0xc69200b7,0x7bc808f0,0xdb1a1c3f,0x00000000}},	//   _האט_, hidu, litä,
  { {0x3ea7001f,0x2fc728b2,0x7bc85262,0x00000000}},	//   wynt_, ting_, kidu,
  { {0x657d5263,0xdb1a0bfc,0x2fc70474,0x00000000}},	//   _hash, nitä, uing_,
  { {0x9294000d,0x7c221e44,0x200c5264,0x00000000}},	//   _карц, _ator, _didi_,
  { {0x7c3b5265,0xf2d20063,0x7bc8167e,0x00000000}},	//   tsur, _העל_, eidu,
  { {0x657d0009,0x200c0290,0x7c3b5266,0x00000000}},	//   _mash, _fidi_, usur,
  { {0x7c220027,0x6d425267,0x7c3b2653,0x00000000}},	//   _dtor, _edoa, rsur,
  { {0xdb1a5268,0x61fb0509,0xdb0a00be,0x00000000}},	//   entó, _khul, _alfâ,
  { {0x657d5269,0x19960141,0x7c3b00dd,0x00000000}},	//   _nash, ујор, psur,
  { {0x7bc82c5d,0x2d8f526a,0xdb080072,0x00000000}},	//   bidu, _inge_, ehdä,
  { {0x7bc8526b,0xdb01011b,0x6287009c,0x00000000}},	//   cidu, aklá, _orjo,
  { {0x657d526c,0x442201f2,0xdb1a2bbf,0x00000000}},	//   _bash, _stk_, antó,
  { {0x69c4526d,0xceb20063,0x61e900ca,0x00000000}},	//   _umie, זיל_, _nkel,
  { {0x657d526e,0x00000000,0x00000000,0x00000000}},	// [a0e0] _dash,   ,   ,
  { {0x5503526f,0x61e95270,0xf53f00a5,0x00000000}},	//   спуб, _akel, _blås_,
  { {0xdb1a005b,0x657d5271,0xf53f00a5,0x00000000}},	//   sitç, _fash, _plåt_,
  { {0x22460024,0x22470240,0x657d06f7,0x00000000}},	//   čok_, ánka_, _gash,
  { {0x61fb0035,0x200c0019,0x4fc605fb,0x00000000}},	//   _dhul, _pidi_, лска,
  { {0x2d8f01e3,0x7bc8120d,0xdb01004c,0x00000000}},	//   _ange_, xidu, zklá,
  { {0x200c055e,0x7c225272,0x9f5e0072,0x00000000}},	//   _vidi_, _stor, _ritä_,
  { {0x9f5e024a,0xdb1a00bd,0x7bc80051,0x00000000}},	//   _sitä_, zitä, widu,
  { {0x7bc85273,0xdb01004c,0x16160082,0x00000000}},	//   tidu, vklá, _दूसर_,
  { {0x99860006,0xdb1a004d,0x7bc8004b,0x00000000}},	//   kslų_, xitä, uidu,
  { {0x7bc80004,0xdb1a0461,0x7c220022,0x00000000}},	//   ridu, vitä, _wtor,
  { {0x2eb00161,0x7bc84466,0x6aa800a3,0x00000000}},	//   जनीत, sidu, rydf,
  { {0x657d0d94,0x7c225274,0xab940054,0x00000000}},	//   _rash, _utor, _вилі,
  { {0x657d5275,0xcc57009a,0x00000000,0x00000000}},	//   _sash, _עסוק_,   ,
  { {0x9f8b0019,0x16350062,0x8b65007e,0x00000000}},	//   _töös_, ребя, _خانم,
  { {0xca470021,0xa968005e,0xb5a402fe,0x00000000}},	//   _إليه_, _бића_, бруй,
  { {0xdb1a5276,0x33870062,0xf53f0f8c,0x00000000}},	// [a0f0] pitä, лужв, _slås_,
  { {0x61e90498,0x61fb5277,0x657d2558,0x00000000}},	//   _skel, _shul, _wash,
  { {0x92590076,0x20f4008b,0x7a13003b,0x00000000}},	//   тает_, _ài_, _păti,
  { {0x8ab500b5,0x2a570047,0x62080044,0x00000000}},	//   סלײג_, רבאן_, هْلِ_,
  { {0x752d282c,0x31580044,0x3d0e0042,0x00000000}},	//   mbaz, اجمة_, ाखों_,
  { {0x44293d7f,0x644d0139,0x660f5278,0x00000000}},	//   mpa_, mrai, _hick,
  { {0x44294eba,0xfd110021,0xa77c0149,0x00000000}},	//   lpa_, يجة_, גרופ,
  { {0xada50076,0x20160066,0x61e90078,0x00000000}},	//   раил, údií_, _ukel,
  { {0x4429014f,0xdb1800c7,0x644d2389,0x00000000}},	//   npa_, _omvä, nrai,
  { {0x7ff70032,0x660f3e60,0x44295279,0x00000000}},	//   _إسرا, _lick, ipa_,
  { {0x644d527a,0xaa49005a,0x2d990244,0x00000000}},	//   hrai, ъпна_, öses_,
  { {0x2d8f1c38,0x7dc50078,0x660f2df4,0x00000000}},	//   _unge_, iųsk, _nick,
  { {0x644d013d,0x00000000,0x00000000,0x00000000}},	//   jrai,   ,   ,
  { {0x644d527b,0xdcfb007d,0x7c291121,0x00000000}},	//   drai, nduč, mper,
  { {0x644d527c,0x62850061,0x660f3996,0x00000000}},	//   erai, jvho, _bick,
  { {0xceb20063,0xf53f06a3,0x644d527d,0x00000000}},	//   קין_, _slår_, frai,
  { {0xb4250032,0x6fd6024c,0x44293ce3,0x00000000}},	// [a100] معلو, _बदलू, gpa_,
  { {0x7c29322e,0xdb0106a5,0xcb120041,0x00000000}},	//   iper, rklæ, ַלד_,
  { {0xdb0100b9,0x4429527e,0x644d1d43,0x00000000}},	//   sklæ, apa_, arai,
  { {0x673c00c3,0x629a00cd,0x644b0460,0x00000000}},	//   larj, _àtom, ágic,
  { {0x644d0027,0xdcee003d,0x6604065c,0x00000000}},	//   crai, ādīj, mmik,
  { {0x673c00c3,0x7c29527f,0x6604003a,0x00000000}},	//   narj, dper, lmik,
  { {0x7c2920a1,0x660400a8,0x2eb00042,0x00000000}},	//   eper, omik, जनेत,
  { {0x261c006d,0xef18001c,0x91e30c8d,0x00000000}},	//   _mío_, _daļa_, _досе,
  { {0x9f450139,0x7a13003b,0x673c5280,0x00000000}},	//   _chló_, _mătu, karj,
  { {0x6be30032,0x2d99051c,0xed59007d,0x00000000}},	//   يكيم, öser_, dižu_,
  { {0x673c00c3,0xdb0100bd,0x77b000c7,0x00000000}},	//   darj, chlü, _växl,
  { {0x644d5281,0x7c290917,0x6e2a189d,0x00000000}},	//   yrai, bper, mpfb,
  { {0x764e001f,0x6604004b,0x57a71a78,0x00000000}},	//   erby, dmik, ашва,
  { {0x644d0164,0xdb0100bd,0x66044fbc,0x00000000}},	//   vrai, fklä, emik,
  { {0x6595000a,0x660f0238,0x644d001f,0x00000000}},	//   баву, _pick, wrai,
  { {0x644d5282,0x7a13003b,0x628301e1,0x00000000}},	//   trai, _cătu, ænom,
  { {0xdb010025,0x644d0003,0x752d5283,0x00000000}},	// [a110] bhló, urai, rbaz,
  { {0x644d4952,0x660f0359,0xe4e4000d,0x00000000}},	//   rrai, _wick, цісн,
  { {0x660f5284,0x7a13003b,0xdb010e77,0x00000000}},	//   _tick, _fătu, cklä,
  { {0xf5950021,0x7c295285,0x44295286,0x00000000}},	//   _الحج, yper, ppa_,
  { {0x7c295287,0xe0d001fb,0xa158167b,0x00000000}},	//   xper, وزه_, рачу_,
  { {0x32180926,0x10480062,0x33a80062,0x00000000}},	//   _fury_, ряци_, _късо_,
  { {0x98ab0051,0x87b807e9,0x00000000,0x00000000}},	//   racę_, שלוס_,   ,
  { {0x673c00c2,0x7c295288,0x261a0082,0x00000000}},	//   zarj, tper, _मंसी_,
  { {0xb4f50053,0x7c295289,0x60d503c3,0x00000000}},	//   _आरोप_, uper, _הוּא_,
  { {0x7c29223f,0xbed50002,0x5f440021,0x00000000}},	//   rper, _лозј, _ونقل,
  { {0x673c528a,0x7c29528b,0xdb1e004c,0x00000000}},	//   varj, sper, ýván,
  { {0x261c02dd,0xc7a900ff,0x7c291110,0x00000000}},	//   _río_, _אב_, pper,
  { {0x3e6100ea,0x673c528c,0x7d7a009a,0x00000000}},	//   lót_, tarj, _תרנג,
  { {0x261c006d,0x7a13003b,0xdca20320,0x00000000}},	//   _pío_, _sătu, _хаши,
  { {0x7a13003b,0x4df90041,0x6604528d,0x00000000}},	//   _pătu, ָפּא, tmik,
  { {0xdb010c38,0x660419fb,0x09e30062,0x00000000}},	//   rklä, umik, _нощн,
  { {0x673c3a62,0x6604528e,0x35e5000d,0x00000000}},	// [a120] parj, rmik, ццёв,
  { {0x261c006d,0x660408a4,0x7ccb008f,0x00000000}},	//   _tío_, smik, mērī,
  { {0x9f4c001b,0xdb1a0066,0x5b3a0041,0x00000000}},	//   _đoàn_, titú, רגעק,
  { {0x31c50054,0x3e612717,0xdcff011b,0x00000000}},	//   осів, dót_, ávěr,
  { {0x0f140054,0x11d70044,0x00000000,0x00000000}},	//   омлю, حونة_,   ,
  { {0xc059019d,0xdefa0076,0xa0730088,0x00000000}},	//   рії_, лый_, ягіч,
  { {0xf8bf00ea,0xee860121,0x877b0047,0x00000000}},	//   zzé_, сыло, ראצי,
  { {0x25a0017e,0x3dcd0022,0x5d542530,0x00000000}},	//   njil_, giew_, цкит,
  { {0xe0da0001,0x5bb803d6,0x25a00089,0x00000000}},	//   _сва_, илия_, ijil_,
  { {0xf8bf419d,0x547b0063,0x5ce30121,0x00000000}},	//   ncée_, נטיו, яюща,
  { {0xc3330063,0x6dbb0051,0x65760072,0x00000000}},	//   הות_, właś, keyh,
  { {0x6456002c,0x6da30062,0xada316e0,0x00000000}},	//   kuyi, _ниха, _нахл,
  { {0x98a20022,0xacf601f3,0x5c060e74,0x00000000}},	//   ybką_, _اسات, _ляка,
  { {0x7bcf0164,0xf8bf01e0,0x9b940a55,0x00000000}},	//   écut, rzé_, _фикц,
  { {0xdb1a01e1,0xcbc5005d,0x16340085,0x00000000}},	//   ditø, _بزني, зеся,
  { {0x58d50062,0xe4e7071f,0xf9930593,0x00000000}},	//   _мойт, бізн, _ربع_,
  { {0x64a4000a,0x3e6100ea,0x69cf528f,0x00000000}},	// [a130] паѓа, zót_, mice,
  { {0x69cf5290,0x3cfb0063,0x261a0042,0x00000000}},	//   lice, רלמנ, _मूवी_,
  { {0xdb030268,0xd0190022,0x02d90021,0x00000000}},	//   _conè, _suń_, جواب_,
  { {0x9f4c008b,0x69cf5291,0x92b40021,0x00000000}},	//   _đoán_, nice, أحكا,
  { {0x8fa50ac5,0x3dcd5292,0x897c0041,0x00000000}},	//   жале, view_, טראצ,
  { {0xdb0300cd,0x3e6100ea,0xd0090002,0x00000000}},	//   _fonè, tót_, шеле_,
  { {0x99890051,0x39490e7c,0x6e92005e,0x00000000}},	//   _miał_, _odas_, дију,
  { {0x0c25101a,0x3e61101d,0xec491326,0x00000000}},	//   омин, rót_, азил_,
  { {0x61eb3a0c,0x69cf5293,0x2d9f00a8,0x00000000}},	//   mogl, dice, rjue_,
  { {0xfbc50086,0x39495294,0x2d84004b,0x00000000}},	//   ібно, _adas_, adme_,
  { {0xdb1a00fe,0xe9da3dc4,0x69cf2a26,0x00000000}},	//   yntö, ико_, fice,
  { {0x7a13000c,0x3e45001c,0x61eb5295,0x00000000}},	//   _bătr, mēt_, nogl,
  { {0x7a130529,0x3e45003d,0x30790047,0x00000000}},	//   _cătr, lēt_, באָנ,
  { {0xd5b1001b,0xe8f70363,0x99890022,0x00000000}},	//   ến_, юля_, _ciał_,
  { {0x644b04a6,0x3e45001c,0xe9a60002,0x00000000}},	//   ágin, nēt_, _макп,
  { {0x28c50053,0x6b834bf0,0x6d5b343f,0x00000000}},	//   _लेकि, _hang, ngua,
  { {0x61eb3ec2,0x6d5b0290,0x63a702e2,0x00000000}},	// [a140] dogl, igua, _bojn,
  { {0x6b83014f,0x7984058c,0x7c240025,0x00000000}},	//   _jang, _haiw, _éire,
  { {0xf8bf0003,0x6b835296,0x61eb3b28,0x00000000}},	//   rcée_, _mang, fogl,
  { {0x3e45003d,0x61eb44ca,0xdb031f22,0x00000000}},	//   dēt_, gogl, _coné,
  { {0x7984002c,0x798600ac,0x6b8300a4,0x00000000}},	//   _maiw, idkw, _oang,
  { {0x6b8343bb,0x5f930095,0x69cf5297,0x00000000}},	//   _nang, дишт, zice,
  { {0x7056007e,0xdb035298,0x62630121,0x00000000}},	//   _ژنرا, _foné, _овра,
  { {0x6b830102,0x61eb0290,0x79842f40,0x00000000}},	//   _aang, cogl, _naiw,
  { {0x2d820024,0x6b835299,0x69cf529a,0x00000000}},	//   ľke_, _bang, vice,
  { {0x79960034,0x644400fe,0x2d820dec,0x00000000}},	//   _anyw, isii, žke_,
  { {0x3e45001c,0x0ac60076,0x6b8304bf,0x00000000}},	//   cēt_, ющим, _dang,
  { {0x6444024a,0x7bcf0003,0x6b832389,0x00000000}},	//   ksii, écur, _eang,
  { {0x6d40282e,0x6b8304b1,0x7a14000c,0x00000000}},	//   mama, _fang, _pătr,
  { {0xcb670001,0x6d40529b,0x69cf529c,0x00000000}},	//   _даље_, lama, sice,
  { {0x69cf529d,0x64440050,0x85a702d8,0x00000000}},	//   pice, esii, ојад,
  { {0x248900c3,0x6d40529e,0x6b83529f,0x00000000}},	//   tvam_, nama, _zang,
  { {0x5455005a,0x6b834f52,0xb4b50161,0x00000000}},	// [a150] яват, _yang, जने_,
  { {0x6d401d1a,0x2489017d,0x7bda0026,0x00000000}},	//   hama, rvam_, nntu,
  { {0x6d4015c4,0x65aa0114,0x63a752a0,0x00000000}},	//   kama, _výhr, _vojn,
  { {0x63a70045,0xf67a00b5,0x1a9b0047,0x00000000}},	//   _wojn, _פארמ, ייבע,
  { {0x7dc50006,0x6d4052a1,0xf8bf0003,0x00000000}},	//   iųst, dama, mbés_,
  { {0x6d400509,0x3e45001c,0x8e490021,0x00000000}},	//   eama, tēt_, ملتك_,
  { {0x69cd112c,0x31350b0e,0x442b0222,0x00000000}},	//   _omae, _невр, _htc_,
  { {0x753d0045,0x3e45003d,0x6b835299,0x00000000}},	//   _jesz, rēt_, _sang,
  { {0x6b8318ab,0x7bda001f,0x3e45001c,0x00000000}},	//   _pang, fntu, sēt_,
  { {0x69dd03b2,0x3e45001c,0x69cd001f,0x00000000}},	//   éren, pēt_, _amae,
  { {0x6d401aec,0x9ee90021,0x6b8352a2,0x00000000}},	//   bama, _افضل_, _vang,
  { {0x6d40265d,0x6b834993,0x7bda52a3,0x00000000}},	//   cama, _wang, antu,
  { {0x6b83204d,0x3f851848,0x644b0331,0x00000000}},	//   _tang, _kalu_, ágil,
  { {0x78a90019,0x3f872f88,0x6b833efd,0x00000000}},	//   äeva, ndnu_, _uang,
  { {0x753d000f,0x443952a4,0x3f851f06,0x00000000}},	//   _besz, _aws_, _malu_,
  { {0x64440004,0x3f85014f,0x4439001f,0x00000000}},	//   tsii, _lalu_, _bws_,
  { {0x39420004,0x43760055,0x752452a5,0x00000000}},	// [a160] maks_, зует, rciz,
  { {0xb9030055,0x394227fe,0x644452a6,0x00000000}},	//   _язык, laks_, rsii,
  { {0x68120080,0xae0e0053,0x6444065c,0x00000000}},	//   _vědě, ागमन_, ssii,
  { {0x39420019,0xf1a901fb,0x4439002b,0x00000000}},	//   naks_, يانه_, _fws_,
  { {0x6d4052a7,0x10470062,0xdb01004d,0x00000000}},	//   vama, пящи_, chlö,
  { {0x6d4b010a,0x39420019,0x68f600fe,0x00000000}},	//   _adga, haks_, _myyd,
  { {0x7c2b003d,0x39420019,0x3f85001f,0x00000000}},	//   _atgr, kaks_, _dalu_,
  { {0xdef90088,0x39420004,0x41550002,0x00000000}},	//   цыі_, jaks_, _отуѓ,
  { {0x6d400351,0x39420019,0x3f8552a8,0x00000000}},	//   rama, daks_, _falu_,
  { {0x6d4052a9,0x3942344f,0x7bda37ef,0x00000000}},	//   sama, eaks_, untu,
  { {0x21fc02f4,0x6d4052aa,0x8af70085,0x00000000}},	//   ního_, pama, знэс_,
  { {0x6d400089,0x3942004b,0x4efb0041,0x00000000}},	//   qama, gaks_, _פלאג,
  { {0xd5b1001b,0xed570086,0x2ac20003,0x00000000}},	//   ếm_, _хоч_, _bébé_,
  { {0xd7f10013,0x3942004b,0xba760044,0x00000000}},	//   ỗ_, aaks_, _فاعت,
  { {0x21fc0080,0xf1bf0066,0x3942065e,0x00000000}},	//   jího_, úška_, baks_,
  { {0x3ea101cf,0xfaf70063,0xe4e70054,0x00000000}},	//   ähti_, _מצוי_, пізн,
  { {0x69dd0147,0x753d00ea,0xf8bf109c,0x00000000}},	// [a170] mnse, _vesz, rbés_,
  { {0x753d0051,0x442b008d,0xdb1a0022,0x00000000}},	//   _wesz, _vtc_, mitó,
  { {0x753d000f,0x224700ea,0x22950021,0x00000000}},	//   _tesz, énk_, بلاس,
  { {0x69dd52ab,0x3f8552ac,0xdb1a01d1,0x00000000}},	//   nnse, _salu_, vitý,
  { {0xdce0001c,0xdb1800ea,0xc5fb0053,0x00000000}},	//   iemē, _elvé, ्षीय_,
  { {0x76550051,0x1e951c9b,0xdfd10044,0x00000000}},	//   orzy, дрир, ضيع_,
  { {0x21fc02f4,0x63a30026,0xdb09005b,0x00000000}},	//   cího_, önnu, ünün,
  { {0x69dd4685,0x656d004d,0xa4c0005b,0x00000000}},	//   jnse, nfah, nüşü_,
  { {0x39420004,0x656d1d03,0xf09f0003,0x00000000}},	//   vaks_, ifah, _çà_,
  { {0x76550051,0x3942431b,0xdb1a29c7,0x00000000}},	//   krzy, waks_, ditó,
  { {0x39420019,0x76550051,0x8eb5007e,0x00000000}},	//   taks_, jrzy, _تماش,
  { {0x6d4b0146,0x68f6024a,0x69dd47da,0x00000000}},	//   _udga, _pyyd, gnse,
  { {0xe87c01f7,0x39423f0b,0x21fc0080,0x00000000}},	//   _düşü, raks_, zího_,
  { {0x39420004,0x69dd52ad,0xa84d004c,0x00000000}},	//   saks_, anse, énář_,
  { {0xe9d20032,0x7bc10139,0x7a42004c,0x00000000}},	//   _لغة_, mhlu, _vítá,
  { {0x7bc10014,0x68f60072,0x656d004d,0x00000000}},	//   lhlu, _tyyd, gfah,
  { {0x60040268,0xd4674540,0xd4d50085,0x00000000}},	// [a180] lòme, мите_, ніфэ,
  { {0x21fc0080,0x76550051,0x29d2007d,0x00000000}},	//   tího_, brzy, ošao_,
  { {0x38cb006a,0x600400cd,0x39400078,0x00000000}},	//   _هایی_, nòme, _keis_,
  { {0x20050974,0x63a500c2,0x02de0042,0x00000000}},	//   _ahli_, ajhn, _मशीन,
  { {0x7bc1003e,0x765c00fe,0x98b9003b,0x00000000}},	//   khlu, lury, masă_,
  { {0x3940018d,0x7bdd0164,0x63a3004d,0x00000000}},	//   _leis_, ésul, önnt,
  { {0x2e4a005a,0x98b9003b,0x394000a8,0x00000000}},	//   цяло_, oasă_, _oeis_,
  { {0xdb0a0146,0xdb0319f1,0xee070002,0x00000000}},	//   _ilfø, _coní, мејл_,
  { {0x9be60086,0x69dd0153,0xdbc6004b,0x00000000}},	//   дінк, érem, _möön,
  { {0x5a340d64,0x7bc10025,0x4bda0021,0x00000000}},	//   ннот, ghlu, تبعد_,
  { {0x8aa30086,0x59f9000d,0x2480002b,0x00000000}},	//   вряд, зеня_, hwim_,
  { {0x69dd2a9d,0x8d930021,0x7d930044,0x00000000}},	//   unse, _للمش, _للمؤ,
  { {0x39400025,0x69dd52ae,0x3e68006c,0x00000000}},	//   _deis_, rnse, lût_,
  { {0x76550045,0x7d020c61,0x7bc12cbf,0x00000000}},	//   trzy, _izos, chlu,
  { {0xdb1a00be,0x656d004d,0x99d70021,0x00000000}},	//   sitó, tfah, _يتعا,
  { {0x69d600ea,0x8a04005e,0x29d20130,0x00000000}},	//   ézet, _изје, nšal_,
  { {0xe9df034d,0x656d0199,0xa4c00058,0x00000000}},	// [a190] mnú_, rfah, rüşü_,
  { {0xe9df0024,0x66060019,0x76550051,0x00000000}},	//   lnú_, _ehkk, przy,
  { {0x77b000c7,0x33f40137,0x656d004d,0x00000000}},	//   _växt, växt_, pfah,
  { {0x29d200c2,0xe9df52af,0xd258007f,0x00000000}},	//   jšal_, nnú_, ьцу_,
  { {0xe4e70086,0x53470076,0x660d0213,0x00000000}},	//   _цінн, _охва, mmak,
  { {0xe9df164b,0x660d2ae1,0x3e68006c,0x00000000}},	//   hnú_, lmak, fût_,
  { {0xe9df0024,0xf314000d,0x7bdd0003,0x00000000}},	//   knú_, _адрэ, ésum,
  { {0x22470114,0x660d52b0,0xe9df0066,0x00000000}},	//   ánku_, nmak, jnú_,
  { {0xe9df0024,0xcc880013,0x7bc10014,0x00000000}},	//   dnú_, _cớ_, thlu,
  { {0x394052b1,0xdd1d003b,0xe9df52b2,0x00000000}},	//   _seis_, _fâşi, enú_,
  { {0x7bc10014,0x29d200a8,0xdd950085,0x00000000}},	//   rhlu, bšal_, _пажы,
  { {0x3ce0074f,0x600401a8,0x660d00ca,0x00000000}},	//   _žive_, ròme, jmak,
  { {0x660d52b3,0x7cc404a0,0xdd1c011b,0x00000000}},	//   dmak, _لزوم, ušťk,
  { {0x660d0520,0x387f00be,0xdbc6004b,0x00000000}},	//   emak, çura_, _söön,
  { {0xe9df0024,0x3940004b,0xf6d50054,0x00000000}},	//   bnú_, _teis_, вітя,
  { {0x660d3520,0xe6170062,0xe9df0066,0x00000000}},	//   gmak, едс_, cnú_,
  { {0xe3ba0062,0x672100a8,0x999f0078,0x00000000}},	// [a1a0] пба_, žlja, artų_,
  { {0x64560034,0x26cc0016,0x43860021,0x00000000}},	//   rryi, údos_, علاق,
  { {0xdbc6004b,0x44320324,0xdb010195,0x00000000}},	//   _töön, spy_, yklý,
  { {0x4432015e,0xdb0300cd,0x41aa0062,0x00000000}},	//   ppy_, _monà, явен_,
  { {0x351b0063,0x44241317,0xf1a901f3,0x00000000}},	//   _מוכנ, _îm_, باله_,
  { {0xf41f0072,0xe9df0066,0xcff40062,0x00000000}},	//   _eräs_, znú_, ъплъ,
  { {0xf67a0047,0x6e21066d,0x539b0063,0x00000000}},	//   לאַמ, _culb, _צילו,
  { {0xf41f0137,0x3e68006c,0x5c740896,0x00000000}},	//   _gräs_, rût_, влит,
  { {0xe9df0024,0x442233f9,0xfc2f007e,0x00000000}},	//   vnú_, _juk_, یحی_,
  { {0x660d52b4,0x6e2152b5,0xda7a0062,0x00000000}},	//   zmak, _fulb, пям_,
  { {0xe9df0024,0x442252b6,0x43570047,0x00000000}},	//   tnú_, _luk_, עסטל_,
  { {0xcc880013,0x3e4c004c,0x2d8a0023,0x00000000}},	//   _tớ_, mět_, ēbes_,
  { {0x98b8005a,0xe9df0024,0xdb180046,0x00000000}},	//   елят_, rnú_, _ilví,
  { {0xe9df10c3,0xc5fb0053,0x660d00e5,0x00000000}},	//   snú_, ्ष्य_, wmak,
  { {0x7c220035,0x44221c8f,0xd5bb52b7,0x00000000}},	//   _huor, _auk_, пса_,
  { {0xc5f8000a,0x660d002c,0xdcfb007d,0x00000000}},	//   еѓу_, umak, uduć,
  { {0x660d52b8,0x63ae00c2,0xf3f10013,0x00000000}},	// [a1b0] rmak, _bobn, _ự_,
  { {0x7c220290,0xa2950086,0x660d52b9,0x00000000}},	//   _muor, казі, smak,
  { {0x660d1b68,0xdb0101a8,0xd1310593,0x00000000}},	//   pmak, lklò, لما_,
  { {0x3e4c0080,0x30350121,0x3a370047,0x00000000}},	//   dět_, ведё, גראם_,
  { {0x7c2213d0,0xdb030460,0xf8b30053,0x00000000}},	//   _nuor, _moná, ुनिय,
  { {0x25a92ffa,0x6e2149f4,0x7dde0023,0x00000000}},	//   ljal_, _pulb, bīsk,
  { {0xbea5130d,0xdfce043e,0x9e090044,0x00000000}},	//   тайк, تيو_, ويتك_,
  { {0x44220150,0x25a952ba,0x63ae00c2,0x00000000}},	//   _yuk_, njal_, _zobn,
  { {0x6d420529,0x7c22051e,0x1c42000d,0x00000000}},	//   _deoa, _cuor, аным,
  { {0x25a90019,0x6e2152bb,0x3e4c004c,0x00000000}},	//   hjal_, _tulb, bět_,
  { {0x2b580022,0x25a94677,0x63aa0046,0x00000000}},	//   órca_, kjal_, öfni,
  { {0x7c22051e,0x3eba00d1,0x6d4252bc,0x00000000}},	//   _fuor, øpte_, _geoa,
  { {0xef18001c,0x9b950021,0x25a9004b,0x00000000}},	//   _daļu_, _للإت, djal_,
  { {0x442252bd,0x25a900c2,0x6b8a002b,0x00000000}},	//   _ruk_, ejal_, _gafg,
  { {0x7c2200bd,0x63ae0b59,0x442252be,0x00000000}},	//   _zuor, _robn, _suk_,
  { {0x442252bf,0x2d8d52c0,0x63ae48c9,0x00000000}},	//   _puk_, ndee_, _sobn,
  { {0x6295006d,0x2d8d004b,0xf484005d,0x00000000}},	// [a1c0] _arzo, idee_, دازی,
  { {0x44224e54,0x25a9004b,0x629552c1,0x00000000}},	//   _vuk_, ajal_, _brzo,
  { {0xdb0300ea,0x69c60019,0x20020006,0x00000000}},	//   _elnö, ohke, _ūkio_,
  { {0x3e4c0080,0x442252c2,0xf41f0072,0x00000000}},	//   vět_, _tuk_, _isän_,
  { {0x6443007d,0x41530454,0xf99300ff,0x00000000}},	//   ćnic, рвіс, ירא_,
  { {0x3e4c0080,0xdb1a004b,0x9f8a004b,0x00000000}},	//   tět_, mitö, _lööb_,
  { {0x7c22024a,0x2216000d,0x5ea4007e,0x00000000}},	//   _suor, _афар, امعل,
  { {0x656452c3,0xd6570063,0x6d0d0042,0x00000000}},	//   ngih, דיקת_, ाइंग_,
  { {0x7dde001c,0x61e252c4,0x6d42004b,0x00000000}},	//   nīsi, mnol, _veoa,
  { {0x7c2200fe,0x3e4c0080,0xdb0319c7,0x00000000}},	//   _vuor, pět_, _soná,
  { {0xdea3007e,0xdb1a004b,0xdee3019c,0x00000000}},	//   _نیوی, hitö, _кофи,
  { {0x7c2200fe,0x3ed90047,0x61e252c5,0x00000000}},	//   _tuor, _אַנא, nnol,
  { {0x6c54000a,0x7c2d005b,0x61e252c6,0x00000000}},	//   _склу, _çarp, inol,
  { {0x7dde003d,0x6b8a00b9,0xe7300021,0x00000000}},	//   dīsi, _uafg, قصف_,
  { {0xf1b900c2,0x25a90019,0x3f9e00ac,0x00000000}},	//   _hiše_, tjal_, _mntu_,
  { {0x69c60199,0x6564002c,0xdb1a164b,0x00000000}},	//   chke, ggih, chtá,
  { {0x33750017,0xa5f852c7,0x61e252c8,0x00000000}},	// [a1d0] лгар, тету_, dnol,
  { {0x389a0063,0xd4980062,0x62950051,0x00000000}},	//   _ניתנ, ърс_, _przo,
  { {0x387e000c,0x798d00a4,0x3f8e002b,0x00000000}},	//   ătre_, _kaaw, ddfu_,
  { {0x61e252c9,0xfb150047,0x3ab90047,0x00000000}},	//   gnol, אַנט_, עמײנ,
  { {0xd5b1001b,0x80cd0053,0x798d00a4,0x00000000}},	//   ếu_, _देखे, _maaw,
  { {0x61e2001f,0x6287006f,0x600401a8,0x00000000}},	//   anol, _tsjo, tòma,
  { {0x2f540086,0x661d52ca,0x644d52cb,0x00000000}},	//   ртіс, _kisk, lsai,
  { {0x2c6b02ab,0x61e22c1c,0xf1b9007d,0x00000000}},	//   tød_, cnol, _biše_,
  { {0x442900ac,0x661d52cc,0x40590049,0x00000000}},	//   nqa_, _misk, _سلاح_,
  { {0x3f8c001c,0x2d8b01c2,0x2c6b05b9,0x00000000}},	//   _gadu_, žce_, rød_,
  { {0xd9460f34,0xdb0300be,0x7dde008f,0x00000000}},	//   лени, _monç, zīsi,
  { {0x82760047,0x644d52cd,0x69c6078c,0x00000000}},	//   נערע_, ksai, uhke,
  { {0xdb1a004b,0x256d013d,0x644d008f,0x00000000}},	//   ditõ, zóló_, jsai,
  { {0x6c520138,0x8b94005a,0x661d52ce,0x00000000}},	//   _укљу, _връч, _aisk,
  { {0x661d52cf,0xe9da02b6,0xed590114,0x00000000}},	//   _bisk, _пкк_, akže_,
  { {0x7dde003d,0x88862050,0xdb1a004b,0x00000000}},	//   tīsi, _ближ, titö,
  { {0xb0d20053,0x69c452d0,0x6b8152d1,0x00000000}},	// [a1e0] _देंग, _ilie, oelg,
  { {0xdd0300eb,0xdb030164,0x798d0051,0x00000000}},	//   ūrėk, _conç, _zaaw,
  { {0x50d6006a,0x69c452d2,0x661d52d3,0x00000000}},	//   گزار, _klie, _fisk,
  { {0xd5b1001b,0xc3290063,0x249f007d,0x00000000}},	//   ết_, לו_, _šume_,
  { {0x7bc30004,0x3f8c52d4,0x935a0001,0x00000000}},	//   _olnu, _padu_, _прву_,
  { {0xdb030555,0x661d0240,0x78a9004b,0x00000000}},	//   _gonç, _zisk, äevi,
  { {0x63aa0026,0x69c42943,0x3f8c39ca,0x00000000}},	//   öfnu, _olie, _vadu_,
  { {0xf1b901b3,0xbdb40095,0x6b81085b,0x00000000}},	//   _piše_, рбиј, eelg,
  { {0x9b6a0062,0x6b81087d,0x7bc60a10,0x00000000}},	//   ншна_, felg, ūkum,
  { {0xf1b90117,0xe0d7005e,0x6b8152d5,0x00000000}},	//   _više_, _сву_, gelg,
  { {0x69c400bd,0xdd8f0002,0x3eb800b9,0x00000000}},	//   _blie, _лш_, _ært_,
  { {0x69c43e77,0xd9150121,0x201e00a8,0x00000000}},	//   _clie, идны, _hiti_,
  { {0x201e52d6,0x98740085,0x6fb80042,0x00000000}},	//   _kiti_, бляц, _अवां,
  { {0xdb1800ea,0xc7c70062,0x661d52d7,0x00000000}},	//   _elvá, усми, _sisk,
  { {0x7bda3b4a,0x201e52d8,0x8f9b0063,0x00000000}},	//   mitu, _miti_, עילי,
  { {0x69c42eb3,0x7bda07d2,0x201e52d9,0x00000000}},	//   _glie, litu, _liti_,
  { {0x24580076,0x752d1059,0x2455007e,0x00000000}},	// [a1f0] лать_, rcaz, شناس,
  { {0x661d0162,0x201e01b3,0x36d51314,0x00000000}},	//   _wisk, _niti_, _воор,
  { {0x644d52da,0x7bda0019,0x7afd0080,0x00000000}},	//   ssai, iitu, řstv,
  { {0x7bda0551,0x50b541af,0x6b8146bb,0x00000000}},	//   hitu, ислу, zelg,
  { {0x201e065f,0x7bda52db,0x10a50bd8,0x00000000}},	//   _biti_, kitu, рилн,
  { {0x9028000d,0x201e52dc,0x200c00a3,0x00000000}},	//   уцца_, _citi_, _chdi_,
  { {0x7de1001c,0x74d90053,0x6b8152dd,0x00000000}},	//   lēsi, _नेतृ, velg,
  { {0xf2d20063,0x201e0006,0x7bda125e,0x00000000}},	//   _ועל_, _eiti_, eitu,
  { {0x7bda52de,0x201e003b,0x6d4900f1,0x00000000}},	//   fitu, _fiti_, raea,
  { {0x61e91609,0xdab9000d,0x764e001f,0x00000000}},	//   _hjel, вымі_, ysby,
  { {0x7e9c003b,0x61e9130e,0x69c452df,0x00000000}},	//   _căpă, _kjel, _plie,
  { {0x7cd90002,0x6b8152e0,0x6e3a009d,0x00000000}},	//   _имер_, selg, _יתעד,
  { {0x69c40179,0xdb1a0072,0x7bda10c5,0x00000000}},	//   _vlie, ehtä, bitu,
  { {0x7bda0b07,0xd5eb008b,0x7d06005b,0x00000000}},	//   citu, _đíc, ükse,
  { {0x61fb29cf,0x7e630332,0x8f880063,0x00000000}},	//   _okul, nunp, נְשֵ,
  { {0xceb20063,0x9663005a,0x3936000d,0x00000000}},	//   חיל_, юксе, _тэкс,
  { {0x9f5e00fe,0xdb1a0003,0x93464345,0x00000000}},	// [a200] _yhtä_, sitô, инае,
  { {0x2d8f52e1,0x764e01f2,0xa7fb0331,0x00000000}},	//   _lage_, psby, puña,
  { {0x201e52e2,0x61e952e3,0x27ed04aa,0x00000000}},	//   _riti_, _bjel, éene_,
  { {0x61e9017f,0xea7600b5,0x201e52e4,0x00000000}},	//   _cjel, יגער_, _siti_,
  { {0x61e90117,0x25a21a9d,0x201e52e5,0x00000000}},	//   _djel, _inkl_, _piti_,
  { {0x7c240027,0x3ce02583,0xdb0a52e6,0x00000000}},	//   _éiri, _živo_, _sofí,
  { {0x61e907e6,0x201e52e7,0x7bda52e8,0x00000000}},	//   _fjel, _viti_, vitu,
  { {0x61e9076c,0x6e970062,0x201e0089,0x00000000}},	//   _gjel, рвър_, _witi_,
  { {0x2d8f010a,0xbc670754,0x201e52e9,0x00000000}},	//   _dage_, لمين_, _titi_,
  { {0x90e5007e,0xdb1a0050,0xc5e30042,0x00000000}},	//   _اسفن, yhtä, _गद्य_,
  { {0xbeaa04de,0x7de1001c,0xf1b900c2,0x00000000}},	//   _جهان_, zēsi, _hiša_,
  { {0xf1b9007d,0x7bda52ea,0x2d8f52eb,0x00000000}},	//   _kiša_, situ, _gage_,
  { {0x6c34007e,0x6e280114,0xedf5007e,0x00000000}},	//   _افتا, _hudb, _اينگ,
  { {0xc7c40076,0xdcfb01f7,0x2d842831,0x00000000}},	//   осси, lduğ, leme_,
  { {0x394b0089,0x66b40002,0x69dd4366,0x00000000}},	//   pacs_, обру, éres,
  { {0xf99f0268,0xdcfb01f7,0x59d40021,0x00000000}},	//   rmès_, nduğ, _وغير,
  { {0x600d006d,0x69dd07d2,0x64a40002,0x00000000}},	// [a210] lúme, mise, оаѓа,
  { {0x61e91609,0x7de1003d,0xb8eb016a,0x00000000}},	//   _sjel, rēsi, लन_,
  { {0xe6950032,0x600d007a,0xdb030137,0x00000000}},	//   _الجد, núme, _tonå,
  { {0xa5bb006d,0x2d843dbf,0x69dd52ec,0x00000000}},	//   _dióc, jeme_, nise,
  { {0x39490025,0x628a00b9,0x60f80054,0x00000000}},	//   _meas_, æfor, анця_,
  { {0x69dd326f,0x39490025,0x7dde001c,0x00000000}},	//   hise, _leas_, zīst,
  { {0x320d03e9,0x3dc60034,0xee390001,0x00000000}},	//   _they_, _blow_, ћни_,
  { {0x63b500ea,0x2d8451f5,0x3dc652ed,0x00000000}},	//   _hozn, geme_, _clow_,
  { {0x69dd0004,0x61f90022,0xab2919b6,0x00000000}},	//   dise, mowl, лопа_,
  { {0x78bd024a,0x6e28017f,0x2d8f12a9,0x00000000}},	//   dysv, _fudb, _wage_,
  { {0x69dd52ee,0x2d8f52ef,0x3dc60969,0x00000000}},	//   fise, _tage_, _flow_,
  { {0x3949000c,0x2d840240,0x2489006f,0x00000000}},	//   _ceas_, ceme_, kwam_,
  { {0x27f84647,0x39490139,0xec350041,0x00000000}},	//   torn_, _deas_, _פאַר_,
  { {0x30da0047,0x600d03ea,0x40da0047,0x00000000}},	//   אַלע, lúmb, אַלײ,
  { {0x69dd52f0,0x7afd0022,0x7c3b52f1,0x00000000}},	//   bise, ęsts, lpur,
  { {0xd5b1001b,0x249f007d,0x90dd00cd,0x00000000}},	//   ếp_, _šuma_, _peŀl,
  { {0x79860035,0x7bc1001c,0x64a3000d,0x00000000}},	// [a220] mekw, oklu, пата,
  { {0x79863900,0x7c3b003b,0xd8d70047,0x00000000}},	//   lekw, ipur, _לופט_,
  { {0x79860122,0xdceb001c,0xce95001c,0x00000000}},	//   oekw, _angļ, šējā_,
  { {0x629a00f8,0x6e2852f2,0x987a0047,0x00000000}},	//   _átom, _rudb, ָאַט,
  { {0xdfda005a,0x90530088,0x6e2852f3,0x00000000}},	//   лък_, звіц, _sudb,
  { {0x087700b5,0x3dc60034,0xdfd001a7,0x00000000}},	//   מענט_, _slow_, بيت_,
  { {0x6f01001f,0x69dd00fe,0x29d21bba,0x00000000}},	//   _cylc, yise, nšas_,
  { {0x63b50024,0x629c52f4,0x660452f5,0x00000000}},	//   _zozn, _irro, nlik,
  { {0xdcfb005b,0x660452f6,0x69dd52f7,0x00000000}},	//   rduğ, ilik, vise,
  { {0xdee60459,0x672102e2,0x2d840019,0x00000000}},	//   _лози, žlji, seme_,
  { {0x6f01001f,0x7c3b001f,0x2904005b,0x00000000}},	//   _gylc, apur, üman_,
  { {0x7bc100e3,0x59f90076,0x78bd00fe,0x00000000}},	//   aklu, ремя_, tysv,
  { {0x600d006d,0x660452f8,0x69dd52f9,0x00000000}},	//   súme, dlik, rise,
  { {0x7bc10199,0x629c52fa,0x69dd52fb,0x00000000}},	//   cklu, _orro, sise,
  { {0x98a501f7,0x3774000d,0x660452fc,0x00000000}},	//   ğlı_, чыўс, flik,
  { {0x98a5005b,0x660452fd,0xe3bf006d,0x00000000}},	//   şlı_, glik, _puño_,
  { {0x5455019d,0xe9df0025,0xf92a0047,0x00000000}},	// [a230] юват, miú_, _דופּ,
  { {0xe4d40032,0xe9df0025,0x6e220139,0x00000000}},	//   ستقب, liú_, _liob,
  { {0xe2350002,0x63b5376b,0x69c0013d,0x00000000}},	//   цнењ, _vozn, ömeg,
  { {0xdb030024,0xe9df0027,0x225c0114,0x00000000}},	//   _ponú, niú_, ávka_,
  { {0x628e52fe,0x629c1b69,0x5ff54a59,0x00000000}},	//   _esbo, _erro, озду,
  { {0x443903e9,0x4fe80086,0x6d4052ff,0x00000000}},	//   _its_, бмін_, ebma,
  { {0xdfcf006a,0x6e222ae4,0x1e850054,0x00000000}},	//   ويچ_, _biob, ілим,
  { {0x442302b0,0xf8bf5300,0x6e22003b,0x00000000}},	//   _hij_, ncés_, _ciob,
  { {0xe9df0027,0xdb1a0025,0x6e221643,0x00000000}},	//   diú_, chtú, _diob,
  { {0x69dd0164,0x44231a84,0x79860035,0x00000000}},	//   èren, _jij_, wekw,
  { {0x44230122,0x656f051e,0xdd8e006a,0x00000000}},	//   _mij_, _occh, روی_,
  { {0x7c3b5301,0x7bc15302,0x6443007d,0x00000000}},	//   ppur, sklu, ćnij,
  { {0x26d101f4,0xa17a0047,0x6d4b008f,0x00000000}},	//   ezzo_, סטשט, _iega,
  { {0x657d00f3,0x61b60161,0x656f01f4,0x00000000}},	//   _absh, _अक्ष, _acch,
  { {0x6d4b053b,0x66045303,0x442b42b1,0x00000000}},	//   _kega, tlik, _auc_,
  { {0xa3d70161,0x7c231d30,0xe5a3086c,0x00000000}},	//   ़ोस_, _hinr, миси,
  { {0x44230b7d,0x26d101f4,0x66045304,0x00000000}},	// [a240] _bij_, azzo_, rlik,
  { {0x3f87017f,0x66044f40,0xe73a0001,0x00000000}},	//   jenu_, slik, _њен_,
  { {0x44395305,0x7c2b37aa,0x42560062,0x00000000}},	//   _ets_, _lugr, ютат,
  { {0xf8bf00cd,0xf6530063,0xda7a0047,0x00000000}},	//   ccés_, _קצר_, ינער,
  { {0x1047005a,0x7c2b0822,0xbfaa0074,0x00000000}},	//   оящи_, _nugr, итке_,
  { {0xc059019d,0x44230122,0x6d4b0019,0x00000000}},	//   сії_, _gij_, _aega,
  { {0x60040268,0x6d4b0359,0xb8870014,0x00000000}},	//   nòmi, _bega, _kvíð,
  { {0x442302b0,0x5d5415d3,0x6d4b3fca,0x00000000}},	//   _zij_, чкит, _cega,
  { {0xab5c001c,0x4f5a0021,0xe0da16e0,0x00000000}},	//   ekļa, _نجاد_, _тва_,
  { {0x3f8704ea,0x6d595306,0x32065307,0x00000000}},	//   cenu_, _edwa, lloy_,
  { {0xba0b005a,0xe9df0025,0x6d4b0290,0x00000000}},	//   ихме_, tiú_, _fega,
  { {0x7c2300bd,0x6d4b5308,0x9e65005d,0x00000000}},	//   _einr, _gega, _رامن,
  { {0xe9df0027,0xec77000a,0x6443007d,0x00000000}},	//   riú_, _мпц_, ćnik,
  { {0x2905003d,0xe9df0025,0x6d4b0051,0x00000000}},	//   āla_, siú_, _zega,
  { {0x7c2b00bd,0x163b0032,0x44230122,0x00000000}},	//   _zugr, ؤسسة_, _rij_,
  { {0x442b0994,0xa4d50086,0xca830021,0x00000000}},	//   _puc_, побі, _آليً,
  { {0x69c00019,0xf8bf0153,0x6b880983,0x00000000}},	// [a250] ömee, rcés_, oedg,
  { {0xb8e1016a,0x29150051,0x7df3003b,0x00000000}},	//   ून_, ądać_, măse,
  { {0x3f875309,0xaaca0042,0xe535012c,0x00000000}},	//   venu_, ानिक, _нень,
  { {0x44230122,0xd1b80593,0x442b530a,0x00000000}},	//   _wij_, يانا_, _tuc_,
  { {0x3f870164,0x8fa50304,0xc0c80001,0x00000000}},	//   tenu_, зале, жује_,
  { {0x94ba014e,0x9f47530b,0x6d4b340d,0x00000000}},	//   _המשת, onné_, _sega,
  { {0x7c2b0006,0xed5908a6,0x6d4b530c,0x00000000}},	//   _sugr, бой_, _pega,
  { {0x656d530d,0x8d750021,0x3f87530e,0x00000000}},	//   ngah, سابا, senu_,
  { {0xdb030027,0x20540076,0x6d4b29e3,0x00000000}},	//   _inné, _октя, _vega,
  { {0xcb690001,0x7c2d0139,0x26de0195,0x00000000}},	//   љане_, _éarm, útok_,
  { {0x76550051,0x6d4b48bb,0x3dcd00e5,0x00000000}},	//   jszy, _tega, phew_,
  { {0xf1b90117,0x2247027d,0x61eb004d,0x00000000}},	//   _još_, ánky_, nngl,
  { {0xbc19000d,0x29040026,0x7df3003b,0x00000000}},	//   _лікі_, æma_, găse,
  { {0xf1b9007d,0x600401a8,0x4c9a089e,0x00000000}},	//   _loš_, tòmi, _לבנו,
  { {0xbb3a0041,0x20070023,0x4bd8005d,0x00000000}},	//   _פעקי, ilni_, _ببند_,
  { {0x25a60876,0x3ce0027c,0x09fa0021,0x00000000}},	//   ñol_, _živi_, _دفعة_,
  { {0x2ea80053,0x76550051,0xe5060044,0x00000000}},	// [a260] _कप्त, aszy, سبري,
  { {0xdb0303b2,0x656d00a4,0x317f000c,0x00000000}},	//   _anné, agah, _abuz_,
  { {0xf1b900c3,0x67bb0063,0x91e60259,0x00000000}},	//   _boš_, _המיק, поже,
  { {0x69c63928,0x216a0aad,0x2007530f,0x00000000}},	//   nkke, сиди_, elni_,
  { {0xd00a1321,0x69c65310,0xb0330054,0x00000000}},	//   беде_, ikke, еніш,
  { {0xdb0300ea,0x987b0041,0x61eb5311,0x00000000}},	//   _enné, מאנט, angl,
  { {0x32060034,0x6b8801f2,0x20020078,0x00000000}},	//   ploy_, vedg, _ūkis_,
  { {0x20071228,0x00000000,0x00000000,0x00000000}},	//   alni_,   ,   ,
  { {0x69dd0164,0x5c06000d,0xc3340063,0x00000000}},	//   èrem, зяна, ֽוֹ_,
  { {0x6f66000a,0xfbaa0156,0x69c61430,0x00000000}},	//   _ѕвез, стий_, ekke,
  { {0x7f3b009a,0x765a0006,0xeb970002,0x00000000}},	//   _העבו, štyj, чиќ_,
  { {0x394d006d,0x61e25312,0x64560050,0x00000000}},	//   úes_, niol, ksyi,
  { {0x3d2b006a,0x76550051,0xdca30336,0x00000000}},	//   _اتمی_, wszy, _паци,
  { {0x645600e8,0x61e2001f,0x7df3003b,0x00000000}},	//   dsyi, hiol, răse,
  { {0xdb7b014e,0x61e21229,0x61eb002b,0x00000000}},	//   _הנוכ, kiol, yngl,
  { {0x69c600bd,0x76550051,0x9f470066,0x00000000}},	//   ckke, rszy, rnné_,
  { {0x57f5464a,0x99f80063,0x39780021,0x00000000}},	// [a270] _опит, _מזהה_, _رصيد_,
  { {0xa3d70161,0x76550051,0x656d00a4,0x00000000}},	//   ़ों_, pszy, sgah,
  { {0x69cd00f5,0x64560089,0xd6280002,0x00000000}},	//   _klae, asyi, _ноќе_,
  { {0x27e30122,0x68e20006,0x9f5c00cd,0x00000000}},	//   lijn_, _žodi, lovè_,
  { {0x69cd001f,0x9475005d,0x61eb0244,0x00000000}},	//   _mlae, _تگزا, rngl,
  { {0x8b070080,0x69cd001f,0x27e300ca,0x00000000}},	//   _jiří, _llae, nijn_,
  { {0x69c60234,0x629a007d,0xc33212cd,0x00000000}},	//   ykke, _štov, _יום_,
  { {0xf1940619,0x27e3006f,0x61e25313,0x00000000}},	//   _пись, hijn_, ciol,
  { {0xcf2701f3,0xd0e9005d,0x00000000,0x00000000}},	//   _فراي, _بکام_,   ,
  { {0x0ae90076,0x69cd0019,0x3e57000c,0x00000000}},	//   ждой_, _alae, păt_,
  { {0xa3ae0235,0x69cd0185,0xa5bb0139,0x00000000}},	//   कात_, _blae, _piól,
  { {0x69c63e91,0x69cd0934,0x88e620fb,0x00000000}},	//   ukke, _clae, джме,
  { {0x69c6024a,0x31560047,0x999f0078,0x00000000}},	//   rkke, וירן_, estų_,
  { {0x8b03004c,0x61e2288d,0x38330085,0x00000000}},	//   ářsk, ziol, тнёр,
  { {0x69cd001f,0x2bda007e,0xf772007e,0x00000000}},	//   _flae, _بانک_, _یاد_,
  { {0xc9f60021,0x1c380013,0x64a65314,0x00000000}},	//   _تستع, _hỗịc_, маба,
  { {0x1426015a,0x43760121,0x61e25315,0x00000000}},	// [a280] ддам, дует, viol,
  { {0x64560089,0x61e21780,0x27e300ca,0x00000000}},	//   rsyi, wiol, cijn_,
  { {0x754900ea,0x64560072,0x61e25316,0x00000000}},	//   észü, ssyi, tiol,
  { {0x9f5c0114,0x55e601ce,0x9ae8009a,0x00000000}},	//   mové_, _цомб, הַנִ,
  { {0x9f5c108f,0x61e241b0,0x20560a55,0x00000000}},	//   lové_, riol, фтер,
  { {0x2f14000d,0x61e25317,0x4ea63852,0x00000000}},	//   ндлё, siol, дриа,
  { {0x6e930086,0x9f5c0114,0xdb030460,0x00000000}},	//   вищу, nové_, _monó,
  { {0x27e3006f,0x68f60805,0x9186005d,0x00000000}},	//   zijn_, _oxyd, _تجسم,
  { {0x9f5c004a,0xf41f0137,0x63bc5318,0x00000000}},	//   hové_, _isär_, _korn,
  { {0xdfa60067,0x63bc5319,0x9f5c0114,0x00000000}},	//   _تحري, _jorn, kové_,
  { {0x9f5c004a,0x63bc0640,0x2fd70049,0x00000000}},	//   jové_, _morn, _تولد_,
  { {0x27e3006f,0x7afd004d,0x9f5c0114,0x00000000}},	//   wijn_, ßsta, dové_,
  { {0x27e30122,0x63bc00ac,0xeb9a0121,0x00000000}},	//   tijn_, _oorn, _мид_,
  { {0x9f5c004c,0xe7840256,0x4cb71cdf,0x00000000}},	//   fové_, кусо, _юлію_,
  { {0x27e3006f,0x9f5c004a,0xd5bb4ad2,0x00000000}},	//   rijn_, gové_, оса_,
  { {0xca2900b5,0xdb180114,0x999f0078,0x00000000}},	//   _צופֿ, _nové, rstų_,
  { {0x8415005a,0x27e3006f,0x63bc0269,0x00000000}},	// [a290] емах, pijn_, _born,
  { {0x9f5c108f,0x6b9a00b9,0xcc770063,0x00000000}},	//   bové_, ndtg, וגמת_,
  { {0x2a6c00c3,0xddc3000c,0xf1b900c2,0x00000000}},	//   nudb_, nunţ, _hiši_,
  { {0x28c60161,0xf1b9011b,0x471a009a,0x00000000}},	//   रैकि, _kiši_, _מותג,
  { {0x63bc531a,0x25ab531b,0x6b980137,0x00000000}},	//   _forn, _incl_, _oavg,
  { {0x63bc531c,0xdb0300cd,0x1e951a5c,0x00000000}},	//   _gorn, _monò, ерир,
  { {0xed59093e,0xa2820043,0x823400de,0x00000000}},	//   пой_, _میلو, _لرقا,
  { {0xe1ff0014,0x7bc800ca,0x66ee013d,0x00000000}},	//   _ðó_, ekdu, lőké,
  { {0x9f5c0114,0x9c25286c,0x0cc90042,0x00000000}},	//   zové_, ндид, िनेम,
  { {0x7e2b0054,0x9f470331,0x9f5c004c,0x00000000}},	//   _діда_, ronó_, yové_,
  { {0x200500a4,0x63b80137,0x8b94000d,0x00000000}},	//   _ikli_, övni, трыч,
  { {0x7e9a014e,0x9f470025,0x82da0041,0x00000000}},	//   _מסעו, inní_, פֿיק,
  { {0xdb030051,0xa3c40042,0x1c4415ce,0x00000000}},	//   _ponó, ौसम_, _анім,
  { {0xa5bb000f,0x4cba014e,0x9f5c004a,0x00000000}},	//   _fiók, _מזנו, tové_,
  { {0xb9070161,0xa3ae0053,0x66ee013d,0x00000000}},	//   _ये_, कास_, dőké,
  { {0xceb20063,0x212d0150,0x9f5c004a,0x00000000}},	//   נין_, _ngeh_, rové_,
  { {0x9169001b,0x7de80080,0x6287003d,0x00000000}},	// [a2a0] _gửi_, měst, _apjo,
  { {0xdb1a0025,0xdcea007d,0xdb180014,0x00000000}},	//   chtó, šiće, _sové,
  { {0x39520034,0x63bc531d,0x599a01f9,0x00000000}},	//   _keys_, _vorn, ּשְׁ,
  { {0xfb1600b5,0x78a407b4,0x463b0047,0x00000000}},	//   ײַבט_, _kriv, _מעטע,
  { {0x63bc531e,0x6731004c,0xd0370054,0x00000000}},	//   _torn, řejň, езії_,
  { {0x6444531f,0x741604a0,0x80a314d7,0x00000000}},	//   mpii, _سوزا, امون,
  { {0x8e260612,0x628b0022,0x7dd5013d,0x00000000}},	//   нфид, łgor, _másf,
  { {0x249f007d,0x24920051,0xa3ae0053,0x00000000}},	//   _šumi_, owym_, काव_,
  { {0x64440072,0xd1750085,0x442a5320,0x00000000}},	//   npii, _шыры, _kib_,
  { {0x3a29003e,0x9d13000d,0x54770041,0x00000000}},	//   _siap_, ыдыч, עגיע_,
  { {0x442a5321,0xf44d01ce,0xdd8f005d,0x00000000}},	//   _mib_, циjу_, _گون_,
  { {0x7df3003b,0x3f8e0014,0xddc3003b,0x00000000}},	//   păsa, lefu_, runţ,
  { {0xdd8f0032,0x78a45322,0x8c43005e,0x00000000}},	//   _دون_, _criv, _бече,
  { {0x7aeb00ea,0x78a45323,0xf1b9007d,0x00000000}},	//   áltá, _driv, _viši_,
  { {0x3a29014f,0xeb97000a,0x78a40ff2,0x00000000}},	//   _tiap_, _чиј_, _eriv,
  { {0x4a530062,0x49740062,0x442a39b0,0x00000000}},	//   _скъс, _блъс, _aib_,
  { {0x7c2a0035,0x24f8026c,0x7dde008f,0x00000000}},	// [a2b0] _kifr, енты_, gūsi,
  { {0x799d3a19,0x6672005d,0x00000000,0x00000000}},	//   ldsw, دگیر,   ,
  { {0x442a5324,0xe3300013,0xa1950054,0x00000000}},	//   _dib_, _đuổ, кажч,
  { {0x7dde13ed,0x66ee013d,0x799d5325,0x00000000}},	//   būsi, sőké, ndsw,
  { {0x660d5326,0x799d006f,0xa3ae0042,0x00000000}},	//   mlak, idsw, काश_,
  { {0xdee5257e,0x660d5327,0x442a0206,0x00000000}},	//   коли, llak, _gib_,
  { {0xa3ae0161,0x1798009a,0x660d056c,0x00000000}},	//   कार_, גדול_, olak,
  { {0x4c850076,0xce18000d,0x660d0332,0x00000000}},	//   влив, нцыі_, nlak,
  { {0x660d003e,0x7c2a0014,0x7de8004c,0x00000000}},	//   ilak, _bifr, věst,
  { {0x7c2a5328,0x660d10a5,0x98b9005f,0x00000000}},	//   _cifr, hlak, lasė_,
  { {0xa96a1a5c,0x7c2a5329,0x7de8004c,0x00000000}},	//   мина_, _difr, těst,
  { {0x60160016,0x660d007d,0x7c2a004d,0x00000000}},	//   râme, jlak, _eifr,
  { {0x6d49532a,0x1a65005d,0x660d532b,0x00000000}},	//   mbea, ریکی_, dlak,
  { {0x290c001c,0x660d532c,0x6d4940c9,0x00000000}},	//   āda_, elak, lbea,
  { {0x07a3018e,0x645d532d,0x442a532e,0x00000000}},	//   јасн, _avsi, _rib_,
  { {0x660d002c,0x78a4244c,0x644f002b,0x00000000}},	//   glak, _triv, _bwci,
  { {0x644f001f,0xa3ae0053,0x442a4d19,0x00000000}},	// [a2c0] _cwci, काल_, _pib_,
  { {0xa3dc0161,0x7c2a0268,0x6e2b00ac,0x00000000}},	//   तों_, _xifr, _ligb,
  { {0x6444021e,0x660d00ea,0xd54a005e,0x00000000}},	//   spii, blak, _опне_,
  { {0x442a532f,0x3aba00b5,0x50460635,0x00000000}},	//   _wib_, ומענ, ведб,
  { {0x644f002b,0xf1b90130,0x7afd0022,0x00000000}},	//   _gwci, _nišu_, ęsty,
  { {0x14d70063,0xe123005e,0x66040072,0x00000000}},	//   _יוכל_, јмљи, loik,
  { {0x3f8e2cdb,0x7c2a01f4,0x539b0063,0x00000000}},	//   refu_, _rifr, _קילו,
  { {0x660400fe,0x7c2a5330,0x3f8e0035,0x00000000}},	//   noik, _sifr, sefu_,
  { {0xdb0a0164,0x6e2b08a5,0x8c430002,0x00000000}},	//   _infé, _digb, аење,
  { {0xc332009a,0x660d0022,0x5ba65331,0x00000000}},	//   יו֙_, zlak, триз,
  { {0x9e65006a,0x6d49033c,0x9f5c01d1,0x00000000}},	//   _مانن, bbea, noví_,
  { {0x799d006f,0x765c0137,0x7a3e008f,0x00000000}},	//   udsw, dsry, _rītd,
  { {0x09e4000d,0xc8670062,0x660d5332,0x00000000}},	//   роўн, ътни, vlak,
  { {0x5ba3011c,0x9f5c004c,0x95c5005d,0x00000000}},	//   _връз, koví_, گيره,
  { {0x27ed0117,0x660d000f,0x45d50448,0x00000000}},	//   đen_, tlak, говс,
  { {0x5967005a,0x27ed00ea,0x34950142,0x00000000}},	//   _ръка, ően_, лабр,
  { {0x660d0397,0x24580076,0x08fb0021,0x00000000}},	// [a2d0] rlak, кать_, _ترغب_,
  { {0x9327007e,0x395913b2,0x9cd70063,0x00000000}},	//   نران, lass_, דומה_,
  { {0x6d4900e5,0x660d5333,0x2d865334,0x00000000}},	//   ybea, plak, _oboe_,
  { {0xdb180066,0x200e0a27,0x78a25335,0x00000000}},	//   _noví, elfi_, _šovi,
  { {0x07f8007e,0xe0d0014d,0x30850044,0x00000000}},	//   _سریع_, يزه_, التف,
  { {0x6e2b00e8,0x9f5c0195,0xe8160042,0x00000000}},	//   _sigb, boví_, णतया_,
  { {0x2eb4005a,0x7dd5006d,0xc293007e,0x00000000}},	//   исъс, _láse, _خیاب,
  { {0x2ca65336,0xf1a40095,0xf1b9007d,0x00000000}},	//   _brod_, _крун, _pišu_,
  { {0xcc89007e,0x39594520,0x44210025,0x00000000}},	//   رنده_, dass_, omh_,
  { {0xd9cc0053,0x60c400fe,0xf1b9007d,0x00000000}},	//   ास्ट, äime, _višu_,
  { {0x44210025,0x39ea05f9,0x3a260142,0x00000000}},	//   imh_, едно_, лмог,
  { {0x64400003,0x186a0928,0x39595337,0x00000000}},	//   _émig, нами_, gass_,
  { {0x765c002b,0xcb69066e,0xdb1800dd,0x00000000}},	//   wsry, _зале_, _covâ,
  { {0x2d9d0917,0xed59007d,0xaae4005d,0x00000000}},	//   _hawe_, laž_, اسیو,
  { {0xf743005a,0xcb560063,0x39591d24,0x00000000}},	//   сесо, _עסקה_, bass_,
  { {0x2d9f5338,0x2956005a,0x69dd006c,0x00000000}},	//   ndue_, _съкр, èret,
  { {0x2d9d0035,0xd46725d9,0xe5a3072d,0x00000000}},	// [a2e0] _mawe_, лите_, щити,
  { {0x660400fe,0x600d0014,0x9f5c0195,0x00000000}},	//   soik, búmi, toví_,
  { {0x8b5600b5,0x66040072,0x55e6080b,0x00000000}},	//   ריעס_, poik, _бонб,
  { {0xc69300b7,0x72290086,0x44210025,0x00000000}},	//   _פאר_, вців_, amh_,
  { {0xe1370085,0x11d70044,0x6098005d,0x00000000}},	//   узіі_, دونة_, ئنتس_,
  { {0x25a00019,0xc0590086,0x9f5c004c,0x00000000}},	//   ldil_, тії_, poví_,
  { {0x24803449,0x25a029b1,0xdb180080,0x00000000}},	//   ltim_, odil_, _poví,
  { {0x25a00019,0x1d34005a,0xdcba07da,0x00000000}},	//   ndil_, шния, ещо_,
  { {0x24805339,0xdce9017c,0x7f461fc6,0x00000000}},	//   ntim_, adeľ, _безж,
  { {0x3940003b,0xe47b0063,0x747b0041,0x00000000}},	//   _afis_, עריכ, עניג,
  { {0xdb1a00d1,0x7ac60f55,0x83b70041,0x00000000}},	//   nktø, успе, אפיע_,
  { {0x7dde001c,0x2e160021,0x2d9d0150,0x00000000}},	//   gūst, _صباح, _gawe_,
  { {0x25a000f1,0x3f9e533a,0x395925cb,0x00000000}},	//   ddil_, _katu_, rass_,
  { {0x7d060019,0x25a000a8,0x395904a7,0x00000000}},	//   üksu, edil_, sass_,
  { {0x39592be3,0x56950002,0xa3ae0042,0x00000000}},	//   pass_, шавт, काई_,
  { {0x9f5c00cd,0x4a7b0063,0x3ce90078,0x00000000}},	//   hovà_, _נרחב, _žavi_,
  { {0xdce90066,0xc35502d8,0xb3550896,0x00000000}},	// [a2f0] zdeľ, икај, икаш,
  { {0x25a0533b,0x6576009c,0x4498014b,0x00000000}},	//   adil_, agyh, ывую_,
  { {0x82a70076,0x9295000d,0x2480007d,0x00000000}},	//   ышае, раец, atim_,
  { {0x9f470164,0xe45f0026,0x7dd500f8,0x00000000}},	//   miné_, _tvö_, _másc,
  { {0x3f9e0974,0xe4c70088,0x24800034,0x00000000}},	//   _batu_, _сённ, ctim_,
  { {0x3f9e0150,0xa858009f,0x8fa503e5,0x00000000}},	//   _catu_, ריגה_, раке,
  { {0x3f9e533c,0x9e64007e,0x2f540054,0x00000000}},	//   _datu_, ماين, стіс,
  { {0x2d940121,0x601600dd,0x3d190042,0x00000000}},	//   брьс, râma, _परदे_,
  { {0x61eb02f6,0xed59007c,0x2d9f533d,0x00000000}},	//   migl, raž_, rdue_,
  { {0xa5bb0025,0x61eb0f07,0xab291b06,0x00000000}},	//   _fhóg, ligl, копа_,
  { {0xb6040006,0x2007533e,0x2d9d002b,0x00000000}},	//   ūšiu, moni_, _tawe_,
  { {0x61eb2eb3,0x2007533f,0x82760047,0x00000000}},	//   nigl, loni_, סערע_,
  { {0x20070004,0x9f5c0a63,0x6d5b0150,0x00000000}},	//   ooni_, lová_, maua,
  { {0x61eb0290,0x20075340,0x6d5b0520,0x00000000}},	//   higl, noni_, laua,
  { {0x65c60062,0x9f5c004a,0x9f470153,0x00000000}},	//   абва, nová_, giné_,
  { {0x7bc3007a,0x75d60021,0x37030054,0x00000000}},	//   _honu, جيرا, цпсг,
  { {0xd5b7001b,0x7bc35341,0xe8fa0121,0x00000000}},	// [a300] ớng_, _konu, _шли_,
  { {0xf7460001,0x9f5c0114,0x27ed0003,0x00000000}},	//   _њено, ková_, éent_,
  { {0x24805342,0x3f9e43e8,0x20075343,0x00000000}},	//   stim_, _ratu_, doni_,
  { {0xdb1a04b1,0x3f9e014f,0x69c40803,0x00000000}},	//   rktø, _satu_, _joie,
  { {0x20075344,0x60265345,0xa0970044,0x00000000}},	//   foni_, адда, لضوء_,
  { {0x33d50088,0x261700f4,0x20075346,0x00000000}},	//   _ліст, nçon_, goni_,
  { {0xd1760076,0x61eb5347,0x9f5c5348,0x00000000}},	//   _вызы, bigl, rovà_,
  { {0x3f9e0009,0x20070035,0x69c45349,0x00000000}},	//   _watu_, aoni_, _noie,
  { {0x3f9e0035,0xdb0a004d,0x7bc3534a,0x00000000}},	//   _tatu_, _wofü, _bonu,
  { {0xa5bb0025,0x20070c8f,0x7dd5534b,0x00000000}},	//   _thóg, coni_, _pásc,
  { {0x1fb50245,0x69c4000c,0x6d5b534c,0x00000000}},	//   _устр, _boie, baua,
  { {0x6d5b534d,0x09f90021,0x9f470003,0x00000000}},	//   caua, افحة_, viné_,
  { {0xdb03004d,0x286b0062,0xa3e70053,0x00000000}},	//   _annä, ърно_, _बगल_,
  { {0x628e1031,0x629c01a8,0x9f470003,0x00000000}},	//   _opbo, _osro, tiné_,
  { {0x35e70088,0x799f0089,0x69d6534e,0x00000000}},	//   ацав, _taqw, _flye,
  { {0x69d600ac,0x26170003,0x20071c65,0x00000000}},	//   _glye, açon_, zoni_,
  { {0xf94a00b5,0x61eb051e,0x7bda021e,0x00000000}},	// [a310] _געפֿ, vigl, ohtu,
  { {0xd7950032,0xdb0a0c77,0x92a7005e,0x00000000}},	//   _الدخ, _infâ, ијел,
  { {0x644601f7,0x20070035,0x61eb534f,0x00000000}},	//   _etki, voni_, tigl,
  { {0xd1670062,0x201e0bda,0x9f5c01d1,0x00000000}},	//   ръжи, _ahti_, vová_,
  { {0xf99f0813,0x61eb5350,0x9f4700fe,0x00000000}},	//   llès_, rigl, ynnä_,
  { {0x6aaa001f,0x9f5c027d,0x61eb5351,0x00000000}},	//   _orff, tová_, sigl,
  { {0x61eb3834,0xe61f0013,0x20075352,0x00000000}},	//   pigl, _khô_, roni_,
  { {0x7bc301f7,0x44390004,0xa3b50053,0x00000000}},	//   _sonu, _kus_, झाव_,
  { {0x44390d93,0x7bc352a0,0x61e95353,0x00000000}},	//   _jus_, _ponu, _imel,
  { {0x69c40164,0x69dd006f,0x44395354,0x00000000}},	//   _soie, ëren, _mus_,
  { {0x15f90161,0x7bc328ba,0x6d42002b,0x00000000}},	//   ्कार_, _vonu, _ffoa,
  { {0x443902a7,0xe61f008d,0x44312839,0x00000000}},	//   _ous_, _nhô_, _liz_,
  { {0x69c43ab8,0x7bda0139,0x44395355,0x00000000}},	//   _voie, bhtu, _nus_,
  { {0x6d5900f3,0x7bda0199,0x44315356,0x00000000}},	//   _hewa, chtu, _niz_,
  { {0x44390cd4,0xdb18000f,0xf99f0268,0x00000000}},	//   _aus_, _tová, glès_,
  { {0x44395357,0xf5b50086,0x4431001c,0x00000000}},	//   _bus_, осую, _aiz_,
  { {0x44315358,0x6d59053b,0x7416007e,0x00000000}},	// [a320] _biz_, _mewa, مورا,
  { {0x6d59014f,0xf1a9007e,0x44395359,0x00000000}},	//   _lewa, یانه_, _dus_,
  { {0x443103d9,0xf99f0003,0x857c0121,0x00000000}},	//   _diz_, clès_, _а́ет_,
  { {0x1219000d,0x4439535a,0xda7a0041,0x00000000}},	//   аючы_, _fus_, טנער,
  { {0x4431017d,0x44392910,0x644608a9,0x00000000}},	//   _fiz_, _gus_, _utki,
  { {0x161c0053,0x7dd5535b,0xd3ba0086,0x00000000}},	//   _भीतर_, _rása, _сумі_,
  { {0x2fc500c3,0x443904a1,0xb87b0e08,0x00000000}},	//   _dolg_, _zus_, ozíc,
  { {0x82f7009a,0x5e430044,0x2dda0044,0x00000000}},	//   _הצלב_, أَيْ, طبعة_,
  { {0x6d590397,0x6d40245c,0x7bda00e5,0x00000000}},	//   _dewa, rcma, thtu,
  { {0x9b580079,0x7bda004b,0xcf890044,0x00000000}},	//   шиот_, uhtu, _نضمن_,
  { {0x5e4a0002,0xfba70121,0x5d6a0062,0x00000000}},	//   _спем_, стый_, _бием_,
  { {0xf2d30047,0x6d591152,0x600d0014,0x00000000}},	//   פער_, _gewa, búms,
  { {0xae1b0063,0xb87b0066,0x48e40085,0x00000000}},	//   _עודכ, dzíc, зоўв,
  { {0xa3a80053,0x4439535c,0x6e3a4f94,0x00000000}},	//   _खोल_, _rus_, _kutb,
  { {0x4439535d,0x8a460021,0xe61f0013,0x00000000}},	//   _sus_, _ائتم, _phô_,
  { {0x443101f7,0x06150086,0xdb0a00cd,0x00000000}},	//   _siz_, ідаю, _infà,
  { {0x9f470290,0x68200137,0xadd7009a,0x00000000}},	// [a330] finì_, född, צומח_,
  { {0x6e3a0034,0x61e90b9c,0x7df3000c,0x00000000}},	//   _outb, _smel, răsi,
  { {0xe535026c,0x6e3a00ac,0xe61f0013,0x00000000}},	//   _мень, _nutb, _thô_,
  { {0x443902dd,0x32640086,0x78ad0f8c,0x00000000}},	//   _tus_, ятув, _krav,
  { {0x44390004,0x6d59535e,0x7dd50114,0x00000000}},	//   _uus_, _rewa, _básn,
  { {0x6d590ff0,0x644d535f,0x185c0047,0x00000000}},	//   _sewa, mpai, רכגע,
  { {0x2fc51a20,0x644d00fe,0x6d59014f,0x00000000}},	//   _volg_, lpai, _pewa,
  { {0x2d8a00ea,0x61e9148a,0x1c4538b3,0x00000000}},	//   őben_, _umel, оним,
  { {0x644d1e3d,0x68200137,0x62855360,0x00000000}},	//   npai, löde, ltho,
  { {0x3a200034,0x7ff70242,0x6d590150,0x00000000}},	//   _ship_, _اسرا, _wewa,
  { {0x6d59053b,0xf8a90063,0x8ae40085,0x00000000}},	//   _tewa, _שש_, зіўл,
  { {0xee2e013c,0x62852eb4,0x78ad1e3e,0x00000000}},	//   _ін_, itho, _brav,
  { {0x62855361,0xf7461213,0x7bf90154,0x00000000}},	//   htho, жего, _кндр_,
  { {0x3a2000e5,0x69dd0075,0xab295362,0x00000000}},	//   _whip_, ahse, _кола_,
  { {0x78ad5363,0x69dd0139,0x644d12b1,0x00000000}},	//   _erav, bhse, epai,
  { {0x69dd0199,0x7dd5000f,0x78ad0d02,0x00000000}},	//   chse, _máso, _frav,
  { {0x62850185,0x644d00a4,0x68200137,0x00000000}},	// [a340] etho, gpai, tödd,
  { {0xa5bb0025,0x9f4701a8,0x798d0022,0x00000000}},	//   _phóc, finí_, _zbaw,
  { {0x78ad00c3,0x7dd50114,0x644d0072,0x00000000}},	//   _zrav, _náso, apai,
  { {0x7ddc013d,0xe733009d,0x00000000,0x00000000}},	//   _kése, _קֵץ_,   ,
  { {0x224d00c2,0x62855364,0x3217005d,0x00000000}},	//   _čeke_, atho, آيند_,
  { {0x66165365,0x6820004d,0x1fb638ba,0x00000000}},	//   llyk, böde, юсер,
  { {0xce470002,0x6e4301fb,0xcdda0092,0x00000000}},	//   озје_, ونوم, ињи_,
  { {0x85480006,0x9daa0062,0x8c665366,0x00000000}},	//   brėž, ръка_, отод,
  { {0x9c37014b,0x60970044,0x00000000,0x00000000}},	//   опыт_, _ونفس_,   ,
  { {0xc3340063,0x3a74005e,0x8bd80a2f,0x00000000}},	//   ּוֹ_, плор, смос_,
  { {0x29050058,0x8ae30054,0x2da30072,0x00000000}},	//   ğlam_, діял, öreä_,
  { {0x78ad0a97,0x8b66005d,0x00000000,0x00000000}},	//   _prav, حاکم,   ,
  { {0x7dd501d9,0x3ad5008d,0x3eb20022,0x00000000}},	//   _záso, áp_, łatę_,
  { {0x7ddc0164,0x661600ac,0xdb0a0516,0x00000000}},	//   _dése, elyk, _enfá,
  { {0x661608a9,0xe81f0082,0x00000000,0x00000000}},	//   flyk, _मीणा_,   ,
  { {0x7dd52f42,0x78ad2308,0xd5b82050,0x00000000}},	//   _násl, _trav, осу_,
  { {0x04590021,0x78ad00b2,0x6e22002b,0x00000000}},	// [a350] صلاة_, _urav, _mhob,
  { {0x57f40076,0x62854ee6,0x68200137,0x00000000}},	//   _опыт, ttho, töde,
  { {0xe2980086,0x64400003,0x62855367,0x00000000}},	//   жає_, _émin, utho,
  { {0x7df3000c,0x62855368,0x7ddc00ed,0x00000000}},	//   năst, rtho, _lésb,
  { {0x55ba014e,0xadc30013,0x62855369,0x00000000}},	//   _המרו, hoản, stho,
  { {0x9405006a,0x26170058,0xd3780121,0x00000000}},	//   _روزه, kçok_, _мчс_,
  { {0xf412009a,0x1758009a,0xd3460043,0x00000000}},	//   _נפל_, חסור_, _رینه_,
  { {0xb2220026,0xbca50021,0x317f0058,0x00000000}},	//   áætl, كمبي, _ucuz_,
  { {0x9627001c,0x2bb90021,0xcd35005d,0x00000000}},	//   _izņē, مادة_, يرکب,
  { {0x7ddc03b2,0x9c22000d,0x7dd501d1,0x00000000}},	//   _rése, ндыд, _zásl,
  { {0xe8e1001b,0x2fe40021,0x3b090f0a,0x00000000}},	//   _đều_, _تكلف, сено_,
  { {0xf2d20041,0x6ec80082,0x8f1a009a,0x00000000}},	//   געט_, ़हरु, _הועת,
  { {0x2d8f017d,0x5d3a0063,0x6e2906a5,0x00000000}},	//   _ibge_, _התנא, mmeb,
  { {0x2bbb0032,0xddc3005f,0xdca204ed,0x00000000}},	//   _خاصة_, ksnū, _чаши,
  { {0xe9df0139,0x6abc004d,0xa3b50053,0x00000000}},	//   bhú_, ärft, झाई_,
  { {0xe9df0066,0x4df90041,0xa446309f,0x00000000}},	//   chú_, צפּא, знад,
  { {0x99920006,0x75d30021,0x6616536a,0x00000000}},	// [a360] ūzų_, ريكا, rlyk,
  { {0x66160831,0x764e536b,0x6e29004d,0x00000000}},	//   slyk, ppby, hmeb,
  { {0x8c1a0063,0xe2972127,0x021a0054,0x00000000}},	//   צועי, зах_, бідь_,
  { {0x68e20006,0xf41f004d,0x2247004c,0x00000000}},	//   _žody, _spät_, ínka_,
  { {0x60160016,0xf537014e,0x6e290019,0x00000000}},	//   lâmi, _מרכז_, dmeb,
  { {0x9f5c0024,0xd0100021,0x9f4701a8,0x00000000}},	//   lovú_, خلت_, ginà_,
  { {0x60160016,0xcf260021,0x6e22536c,0x00000000}},	//   nâmi, أرشي, _phob,
  { {0xade3019d,0x9f5c0066,0x21a31375,0x00000000}},	//   ецьк, novú_, _писм,
  { {0xaf36014d,0x4cb80054,0xe0da536d,0x00000000}},	//   _فرات, ілою_, _ува_,
  { {0x9f5c0024,0xa3b50042,0x09d50042,0x00000000}},	//   hovú_, झाए_, दस्य,
  { {0xe9df0027,0x9f5c0066,0xbeaa005d,0x00000000}},	//   thú_, kovú_, _دهان_,
  { {0x2617005b,0x3ddf006f,0x9f47017d,0x00000000}},	//   rçok_, chuw_, miná_,
  { {0x9f5c0066,0x7df300dd,0x7de50044,0x00000000}},	//   dovú_, răst, _تسلم,
  { {0x4c9b0063,0xdc370047,0x7d1d1555,0x00000000}},	//   _לבדו, _זאגט_, üsse,
  { {0x87040076,0x660d1ae0,0xd61b0044,0x00000000}},	//   еяте, toak, مترا_,
  { {0xa634071f,0xa5bb013d,0xda7b009a,0x00000000}},	//   енсі, _ehón, _הנהר,
  { {0x6440536e,0x349401e2,0x64a40002,0x00000000}},	// [a370] _émil, натр, наѓа,
  { {0xd3710032,0xc6a70ace,0xdd9901c8,0x00000000}},	//   ئها_, _ерми, zeň_,
  { {0x9f5c0024,0x38690026,0x754800ea,0x00000000}},	//   bovú_, _hvar_, észí,
  { {0x386902eb,0x41e40088,0xdb0300cd,0x00000000}},	//   _kvar_, ніча, _danè,
  { {0xc0c80001,0xdd99004a,0x6d5d0014,0x00000000}},	//   зује_, veň_, ðsam,
  { {0x25a900ea,0xf78a0041,0x94ba0063,0x00000000}},	//   ldal_, ַנפֿ, _ומשת,
  { {0x25a9536f,0xe3b20041,0x92940ae8,0x00000000}},	//   odal_, _בױם_, _парц,
  { {0x9627003d,0x56b80063,0x25a95370,0x00000000}},	//   _uzņē, לפון_, ndal_,
  { {0xdd990024,0xea00008b,0x24895371,0x00000000}},	//   reň_, _ngại_, ntam_,
  { {0x320f34da,0x7bca0857,0x9f5c0066,0x00000000}},	//   logy_, _cofu, zovú_,
  { {0x3ed50032,0xfe700021,0xdd99027d,0x00000000}},	//   _تقار, _مدن_, peň_,
  { {0x7dd500ea,0x63a75372,0x24895373,0x00000000}},	//   _másk, _lajn, ktam_,
  { {0xa5bb001b,0xb87b00ea,0xdb0a00bd,0x00000000}},	//   _phón, szín, _anfä,
  { {0x0c24019d,0x6295006f,0xac27000d,0x00000000}},	//   _змін, _opzo, _эфек,
  { {0x2cad0037,0x16a70431,0x9f5c0066,0x00000000}},	//   lved_, мври_, tovú_,
  { {0xcb12014e,0x7b03000c,0x60162b1f,0x00000000}},	//   _שלה_, ăută, râmi,
  { {0x9f5c0066,0x63a7013d,0xb3ca005e,0x00000000}},	// [a380] rovú_, _bajn, олаз_,
  { {0x2cad0034,0x66090755,0x9f5c0066,0x00000000}},	//   ived_, čeka, sovú_,
  { {0xea010013,0x67bb0063,0x9f5c017c,0x00000000}},	//   _quầy_, _ומיק, povú_,
  { {0xe61a0054,0x320f5374,0x6b9a2033,0x00000000}},	//   _фдм_, gogy_, zetg,
  { {0x69c6006f,0xdb035375,0x24895376,0x00000000}},	//   ijke, _dané, ctam_,
  { {0xb033019d,0x2cad4ae4,0x6564013d,0x00000000}},	//   вніш, dved_, laih,
  { {0x2cad2882,0x5275005e,0x2d8d5377,0x00000000}},	//   eved_, _путу, ffee_,
  { {0x6b9a006f,0x656400fe,0xdb080003,0x00000000}},	//   wetg, naih, _élép,
  { {0x23830026,0x2cad01e1,0x7ddc4de2,0x00000000}},	//   _þrjá_, gved_, _césa,
  { {0x7ddc0164,0x6f0d005b,0x4e960021,0x00000000}},	//   _désa, şaca, _يشار,
  { {0x33770f6d,0xdb030026,0x6b9a00cd,0x00000000}},	//   ועים_, _ennþ, retg,
  { {0x61e207e6,0x2b5101f7,0xc33312cd,0x00000000}},	//   nhol, ızca_, כות_,
  { {0xdd8f007e,0xa09b0047,0x44385378,0x00000000}},	//   _خون_, ֿילט, _oir_,
  { {0xc7bb000d,0x3f9c00a8,0x61e21e50,0x00000000}},	//   цём_, nevu_, hhol,
  { {0xb5950da6,0xe6130032,0x63a75379,0x00000000}},	//   нивш, نشر_, _rajn,
  { {0x63a7000f,0x248900ea,0x4438537a,0x00000000}},	//   _sajn, ttam_, _air_,
  { {0x443804ab,0x61e2010a,0xd7e70086,0x00000000}},	// [a390] _bir_, dhol, _жіно,
  { {0x6fd40268,0x3f9c1b9d,0x25a900b8,0x00000000}},	//   _fàci, jevu_, sdal_,
  { {0x2489537b,0xdb0a004d,0x656400a4,0x00000000}},	//   stam_, _unfä, baih,
  { {0xc6920047,0x7c38537c,0x61e21c59,0x00000000}},	//   _גאט_, _livr, ghol,
  { {0x24442502,0x4438142e,0x63a72b4e,0x00000000}},	//   _göm_, _fir_, _tajn,
  { {0x44380031,0x187c0063,0x80a80054,0x00000000}},	//   _gir_, קטוב, ьвів_,
  { {0x682000ea,0x9d450782,0x799d0168,0x00000000}},	//   ködn, нейд, kesw,
  { {0x6fdd0268,0xd7380063,0x92940085,0x00000000}},	//   _dèca, וטות_, _шасц,
  { {0x61140085,0x98ab0058,0x7dd501c8,0x00000000}},	//   _адту, kacı_, _jási,
  { {0x7dd500ea,0x2cad537d,0xddc8008f,0x00000000}},	//   _mási, rved_, ļoša,
  { {0x68200137,0xf4120063,0x656f0e88,0x00000000}},	//   födn, רפי_, _odch,
  { {0x6fd400cd,0xc3320063,0x799d002b,0x00000000}},	//   _ràci, טוי_, gesw,
  { {0x26170016,0x6c840021,0x656401b2,0x00000000}},	//   nçou_, _للنم, vaih,
  { {0xa7da0032,0x60c40659,0xd0f60063,0x00000000}},	//   أوسط_, äimi, תמשת_,
  { {0x4438537e,0x66060062,0x61e23974,0x00000000}},	//   _rir_, епва, yhol,
  { {0x7dd506b2,0xa3a80053,0x78a40019,0x00000000}},	//   _bási, _खोज_, _tsiv,
  { {0x6d490025,0x67e20066,0xea010013,0x00000000}},	// [a3a0] icea, _pôjd, _quấy_,
  { {0x0857014e,0x645d002b,0x6fd401a8,0x00000000}},	//   _רבים_, _dwsi, _tàci,
  { {0x443810e9,0x61e2537f,0x9f470072,0x00000000}},	//   _vir_, thol, iinä_,
  { {0x2a6a000f,0x443809f8,0x3f9c0035,0x00000000}},	//   ábbi_, _wir_, wevu_,
  { {0x61e231d4,0x3f9c0066,0x44385380,0x00000000}},	//   rhol, tevu_, _tir_,
  { {0x443825be,0x4ea603d6,0x61e25381,0x00000000}},	//   _uir_, ериа, shol,
  { {0x2617017d,0x61e25382,0x7dd50061,0x00000000}},	//   açou_, phol, _zási,
  { {0x291e0051,0xbef70021,0x7c385183,0x00000000}},	//   ętaj_, عروض_, _sivr,
  { {0xdb181560,0x98ab005b,0xe58b0063,0x00000000}},	//   _invé, yacı_, הָיָ,
  { {0x3ea90051,0xdb57326a,0x6d495383,0x00000000}},	//   łata_, нюю_, acea,
  { {0x7c383de3,0xa3e50042,0x2a6a013d,0x00000000}},	//   _vivr, बोट_, ébb_,
  { {0x225c004a,0x61360058,0xd9440699,0x00000000}},	//   ávky_, _gülü, леџи,
  { {0x6aa124bf,0x799d0550,0xf1b3009a,0x00000000}},	//   awlf, resw, אסר_,
  { {0x2ca6001f,0xb8c90053,0x7dd50026,0x00000000}},	//   _isod_, _गई_, _rási,
  { {0xab270001,0x7a3e0006,0x98ab0058,0x00000000}},	//   _поља_, _būte, racı_,
  { {0x3495026c,0x7ddc2abf,0x7dd50066,0x00000000}},	//   кабр, _méso, _pási,
  { {0x7bda0058,0xe4e70054,0xf51b005d,0x00000000}},	// [a3b0] oktu, хівн, سترش_,
  { {0xdce008ed,0x93070002,0x7bda5384,0x00000000}},	//   jamč, нџел, nktu,
  { {0xc87f004d,0x7bda0078,0x62354222,0x00000000}},	//   luß_, iktu, вежу,
  { {0x7ae50019,0x2ca6001f,0xcb130047,0x00000000}},	//   _ühte, _osod_, אלע_,
  { {0xf9940063,0x7bda0026,0x645d006f,0x00000000}},	//   טרף_, kktu, _uwsi,
  { {0x2617017d,0x7d19002b,0x7e6d0023,0x00000000}},	//   rçou_, _ryws, ņapm,
  { {0x5f05005a,0x9f470072,0x628b003b,0x00000000}},	//   ъзка, vinä_, ăgos,
  { {0x7ddc0164,0x9f5c0061,0x7bda0058,0x00000000}},	//   _déso, mový_, ektu,
  { {0xf2040088,0x9f5c004a,0xa5bb0460,0x00000000}},	//   _сяро, lový_, _dióx,
  { {0x1a65007e,0x6d490d23,0x66dc0072,0x00000000}},	//   نیتی_, scea, näkö,
  { {0x6d46005b,0x7ddc00ea,0x26171997,0x00000000}},	//   ıkar, _késl, nços_,
  { {0x9f4700fe,0xc87f004d,0x3a295385,0x00000000}},	//   sinä_, fuß_, _chap_,
  { {0x88c70054,0x75fa004c,0x9f470050,0x00000000}},	//   вляв_, hůzc, pinä_,
  { {0x9f5c0114,0xbc070121,0x2d9f006c,0x00000000}},	//   kový_, _ячей, leue_,
  { {0x9f5c027d,0xfaa51533,0xcf920041,0x00000000}},	//   jový_, _райо, ױטן_,
  { {0x98be005b,0xceb20063,0xdb030066,0x00000000}},	//   ştı_, סין_, _janí,
  { {0xd46706cb,0xdb031983,0x044302b3,0x00000000}},	// [a3c0] ките_, _maní, иетн,
  { {0x2d9f0917,0xd78a005d,0x32d60141,0x00000000}},	//   heue_, _کنگو_, кцес,
  { {0x2905005b,0x27770063,0x66e60448,0x00000000}},	//   şlat_, _בגין_, _рона,
  { {0x7ddc0164,0xdb18004a,0x6fd400cd,0x00000000}},	//   _réso, _nový, _làct,
  { {0x4094009b,0x50ba00de,0x11d700de,0x00000000}},	//   التر, بداد_, خونة_,
  { {0x25a00164,0xdfcf0067,0xb4de0053,0x00000000}},	//   leil_, يين_, तनी_,
  { {0x6fdd0268,0x9316007e,0x79960051,0x00000000}},	//   _tècn, _شورش, _obyw,
  { {0x27f8004d,0x25a00168,0x23272c16,0x00000000}},	//   hirn_, neil_, _роси_,
  { {0xdb010146,0xc5f3014e,0xdb03004c,0x00000000}},	//   ndlæ, ידה_, _daní,
  { {0x6e960021,0x25a0030c,0xdd0c0022,0x00000000}},	//   _للطا, heil_, _półk,
  { {0xe9f90726,0x7bda5386,0x2480006f,0x00000000}},	//   енні_, rktu, huim_,
  { {0xadb70021,0xdef7009a,0x0e690044,0x00000000}},	//   _لهما_, _במבט_, _أصلي_,
  { {0x386d03b2,0xc8640fd0,0x5c730054,0x00000000}},	//   éer_, итри, _вліт,
  { {0xd7c9007e,0x24802eba,0xc87f0244,0x00000000}},	//   روزه_, duim_, ruß_,
  { {0x25a05387,0x9f5c0124,0x6b9b009a,0x00000000}},	//   feil_, xový_, _חשוד,
  { {0xf99f00cd,0x644b017d,0xa907005d,0x00000000}},	//   roès_, ígio, _لبخن,
  { {0x80be0161,0xdb0a05dd,0x3860001f,0x00000000}},	// [a3d0] ्हों, _anfø, _gwir_,
  { {0xc3540001,0x7dd50026,0x6fdd00cd,0x00000000}},	//   икуј, _hást, _rèco,
  { {0x7dd50080,0x93880062,0x6820013d,0x00000000}},	//   _zásu, ъста_, ködj,
  { {0x261713a3,0x9f5c0240,0x66dc0072,0x00000000}},	//   rços_, rový_, säkö,
  { {0x7dd5006d,0xdfd5026c,0x999f0078,0x00000000}},	//   _mást, лоды, lptų_,
  { {0x9f5c01d9,0x7dd505d5,0x442a5388,0x00000000}},	//   pový_, _lást, _ghb_,
  { {0x4e950021,0x69dd27e8,0xdb1801c2,0x00000000}},	//   اشتر, kkse, _pový,
  { {0x7db40088,0x7dd50512,0x76450089,0x00000000}},	//   асьц, _nást, _muhy,
  { {0xa5bb0027,0x7c2a0027,0xbfab0086,0x00000000}},	//   _chói, _bhfr, _отже_,
  { {0xa5bb0139,0x7dd50014,0x69dd5389,0x00000000}},	//   _dhói, _rásu, ekse,
  { {0x16030053,0xdb0300ea,0x3ed50043,0x00000000}},	//   रचार_, _taní, _حقار,
  { {0x6016017d,0xdb1800cd,0xc7a9009a,0x00000000}},	//   lâmp, _envï, _מב_,
  { {0xfd440088,0x6d5b014f,0x6fd400cd,0x00000000}},	//   _тэхн, mbua, _tàct,
  { {0x69dd024a,0x291e001c,0xaae5002a,0x00000000}},	//   akse, āta_, _مسعو,
  { {0x65ba0001,0x25a000bd,0x7dd50025,0x00000000}},	//   нуар_, teil_, _fást,
  { {0x290501f7,0x69dd0359,0xdce0001c,0x00000000}},	//   ğlar_, ckse, lamā,
  { {0x25a00164,0x290501f7,0xb4de0053,0x00000000}},	// [a3e0] reil_, şlar_, तने_,
  { {0x7dd50114,0x07a6005e,0x248000ac,0x00000000}},	//   _zást, _саон, ruim_,
  { {0xdb0a00cd,0x1bf60047,0x232a0121,0x00000000}},	//   _cafè, נצער_, хожи_,
  { {0x00e605bd,0x067b07e9,0x7a3e008f,0x00000000}},	//   лжен, _אנטל, _jūta,
  { {0x24800367,0x660418e7,0x463b0047,0x00000000}},	//   quim_, mnik, _רעכע,
  { {0x66041361,0x644600a4,0xdce0001c,0x00000000}},	//   lnik, _iuki, jamā,
  { {0x656600f3,0x69dd024a,0xdb010d88,0x00000000}},	//   _kekh, ykse, ndlä,
  { {0xa5bb0025,0x63ae00a4,0x6446538a,0x00000000}},	//   _phói, _habn, _kuki,
  { {0x71d70063,0xa3e80053,0x1d07005e,0x00000000}},	//   _עומד_, _बता_, лећи_,
  { {0xda7a15d4,0x7dd50025,0x64460089,0x00000000}},	//   ням_, _sást, _muki,
  { {0xdb0300cd,0x6d5b00a4,0x6604538b,0x00000000}},	//   _canà, bbua, knik,
  { {0x69dd024a,0xa5bb0025,0x8e0a0062,0x00000000}},	//   ukse, _thói, _янев_,
  { {0x6446538c,0x98b80062,0x69dd536b,0x00000000}},	//   _nuki, глят_, rkse,
  { {0xdce0001c,0x69dd004b,0x6604538d,0x00000000}},	//   camā, skse, enik,
  { {0x7dd50025,0x64464ded,0x629c14b3,0x00000000}},	//   _tást, _auki, _npro,
  { {0x6446538e,0x63ae01e1,0x7ae5004b,0x00000000}},	//   _buki, _aabn, _ühta,
  { {0x5507066c,0xd37b0794,0x629c538f,0x00000000}},	// [a3f0] учва, ече_, _apro,
  { {0x430b0002,0x66045390,0x629c0139,0x00000000}},	//   нхем_, anik, _bpro,
  { {0x66040198,0xdb030512,0x23740021,0x00000000}},	//   bnik, _kaná, صالح,
  { {0x6d42008b,0x8afb0047,0xdce0008f,0x00000000}},	//   _ngoa, עלאז, zamā,
  { {0x60160529,0x601f0016,0x90c50363,0x00000000}},	//   tâmp, lêmi, рбле,
  { {0xd47a0047,0x3d180053,0xe0d80085,0x00000000}},	//   _באשל, _पड़े_, ыві_,
  { {0xcee60086,0x9758009a,0xd00e04a0,0x00000000}},	//   идше_, ניהו_, بلو_,
  { {0x8db5000d,0xbca50021,0x7c950085,0x00000000}},	//   рскі, لمبي, ароц,
  { {0x6d5b0397,0xcd29005a,0xdb01017d,0x00000000}},	//   rbua, ъжие_, celê,
  { {0xdb18048e,0xabd5018e,0x7dd5017d,0x00000000}},	//   _enví, рциј, _páss,
  { {0x66040051,0x1a0600a0,0x2cb8001c,0x00000000}},	//   ynik, ипом, ārda_,
  { {0x601f0016,0x6820004d,0xdb03017d,0x00000000}},	//   dêmi, mödi, _caná,
  { {0x6604065f,0x68200137,0x00000000,0x00000000}},	//   vnik, lödi,   ,
  { {0x66040045,0xdb030025,0x3f8704ec,0x00000000}},	//   wnik, _eaná, ngnu_,
  { {0xdb030e7c,0x09e6352d,0x66045391,0x00000000}},	//   _faná, _войн, tnik,
  { {0xe9df0024,0x395f0014,0xdb030331,0x00000000}},	//   ckú_, ðust_, _ganá,

  { {0xa3560021,0x7ddc0003,0x629c5392,0x00000000}},	// [a400] لخاص, _désh, _spro,
  { {0x6604055e,0x682000ea,0xd8db0063,0x00000000}},	//   snik, ködi, _סקיר,
  { {0x66043dd5,0x7c210137,0x463a0021,0x00000000}},	//   pnik, illr, _لأحد_,
  { {0xe0da290b,0xfc48008b,0x91e60002,0x00000000}},	//   кве_, _lửa_, јоде,
  { {0x629c0045,0x20870062,0x4fc62254,0x00000000}},	//   _wpro, ийци_, иска,
  { {0xfc48008b,0x24920022,0x5ff30e74,0x00000000}},	//   _nửa_, mtym_, озіу,
  { {0x7ddc0164,0x539b0063,0x6820004d,0x00000000}},	//   _hési, _שילו, gödi,
  { {0x9fa3007a,0x7dd50331,0xf657009a,0x00000000}},	//   síðu_, _básq, בסקי_,
  { {0x64400164,0x224d5393,0xb04a0131,0x00000000}},	//   _émis, _čeki_, _рззз_,
  { {0xfc48001b,0x6609017f,0x60e8005b,0x00000000}},	//   _cửa_, čeki, ırmı,
  { {0xb4db008b,0x7ddc0003,0xdd8a0085,0x00000000}},	//   _ngàn, _lési, _абед_,
  { {0x996724fe,0xbae30085,0xed5a5394,0x00000000}},	//   штол, юцый, _род_,
  { {0xfbcf006a,0x7ae5004b,0x9bea005e,0x00000000}},	//   ستی_, _ühtn, _имдб_,
  { {0xd7fb0095,0xe9df0066,0x9b940044,0x00000000}},	//   тум_, skú_, _طلبت,
  { {0xdb0300ea,0x3952002b,0x75fa011b,0x00000000}},	//   _taná, _ffys_, různ,
  { {0xdb180268,0x8b3b0063,0xc9f4043e,0x00000000}},	//   _invà, _בתוצ, _وسيع,
  { {0xb87b00ea,0x22a80058,0x0614071f,0x00000000}},	// [a410] gzít, _aşk_, ідую,
  { {0x7ddc03b2,0x6b880137,0xdce20d6d,0x00000000}},	//   _dési, ngdg, _neoč,
  { {0x7a3f008f,0xdb0a5395,0x8547014b,0x00000000}},	//   _jūto, _infó, _вэге,
  { {0x6d470080,0xc2440500,0x31580044,0x00000000}},	//   ějak, інік, لجهة_,
  { {0xc1040021,0xdb0a00bd,0x7f75000d,0x00000000}},	//   يومي, _anfü, буйц,
  { {0x656d0150,0xdce0003b,0x8fa50085,0x00000000}},	//   laah, zamă, саке,
  { {0x2127007e,0xa49b00cd,0x21290066,0x00000000}},	//   _چيزی_, _exòt, ťah_,
  { {0xfc48001b,0x69dd00e8,0x63a55396,0x00000000}},	//   _sửa_, êrel, lehn,
  { {0xdb0100ea,0x1fa70086,0x7a38005f,0x00000000}},	//   melé, _врег, _uţti,
  { {0x63a500c2,0x7dd50331,0xdb01013d,0x00000000}},	//   nehn, _vásq, lelé,
  { {0xae78019d,0xdb23005d,0xf8a9089e,0x00000000}},	//   _всіх_, تودی, _רש_,
  { {0xdb03419e,0x6fdd0003,0x7c95007e,0x00000000}},	//   _lanç, _sèch, _هشتا,
  { {0xeb990581,0x9916000d,0x91ba0063,0x00000000}},	//   _бил_, сьні, אמרי,
  { {0x7ddc0164,0x6285004b,0xdb01013d,0x00000000}},	//   _rési, kuho, helé,
  { {0x67290080,0xdb0100ea,0x20071c8f,0x00000000}},	//   řejn, kelé, inni_,
  { {0xbb3a0047,0x7ddc0331,0x628544cc,0x00000000}},	//   _געצי, _pési, duho,
  { {0xdb185397,0x69c43f8b,0xd6270121,0x00000000}},	// [a420] _invá, _inie, соте_,
  { {0xdb030bc8,0x661d5398,0x77860001,0x00000000}},	//   _canç, _eksk, _улоз,
  { {0xb87b000f,0xdb030016,0x9bfa0047,0x00000000}},	//   szít, _danç, נהעט,
  { {0x69d60b6c,0x20090139,0x67e20066,0x00000000}},	//   _joye, éain_, _môjm,
  { {0x69d603b2,0x69c40045,0x765c00ac,0x00000000}},	//   _moye, _mnie, lpry,
  { {0xdce00078,0xdb03004d,0x69d60003,0x00000000}},	//   namą, _kanä, _loye,
  { {0xf1c3004c,0x69c40022,0x00000000,0x00000000}},	//   áší_, _onie,   ,
  { {0x7bc35399,0x20070290,0x69d61276,0x00000000}},	//   _annu, anni_, _noye,
  { {0x81bd0003,0xf1c30114,0x8afc0051,0x00000000}},	//   _chœu, šší_, zbęd,
  { {0x24800025,0x8bc60121,0xdce00078,0x00000000}},	//   irim_, ссид, jamą,
  { {0x7ae50019,0x539b0047,0x441b0047,0x00000000}},	//   _ühtl, נסטא, רויס,
  { {0x63a500bd,0xa3b10053,0x14c80053,0x00000000}},	//   zehn, _फ़ोन_, रमाण,
  { {0x69d6066d,0x61e2539a,0xdca305ef,0x00000000}},	//   _doye, ikol, _наци,
  { {0xdb01000f,0x2ac6005e,0xd7f800fb,0x00000000}},	//   zelé, _гљив, бус_,
  { {0x69d61ca8,0xdb0311f5,0x5b7b0041,0x00000000}},	//   _foye, _ranç, _ערהא,
  { {0x91ad001b,0xdb030555,0x69c40051,0x00000000}},	//   _thẻ_, _sanç, _gnie,
  { {0xdb01000f,0x200c00c2,0xf94a0047,0x00000000}},	// [a430] velé, _ojdi_, _דעפֿ,
  { {0x7d1d00bd,0x290c005b,0xa5bb539b,0x00000000}},	//   üssi, ğdat_, _chór,
  { {0xdb0100ea,0x3255000d,0xa6ab0049,0x00000000}},	//   telé, цвер, _صادق_,
  { {0x200c00c2,0xd059000d,0x61e24d97,0x00000000}},	//   _ajdi_, аркі_, gkol,
  { {0x7ddc0164,0xfe09008b,0xa5bb0139,0x00000000}},	//   _jésu, hắc_, _fhór,
  { {0x6f87013c,0x6609007d,0xd009005e,0x00000000}},	//   судж, čeku, јеке_,
  { {0xdcfb017f,0xb7dc00b5,0xdb013525,0x00000000}},	//   oguć, רקוי, pelé,
  { {0xa1940076,0xec7905a1,0xec99005e,0x00000000}},	//   _насч, апи_, атој_,
  { {0x61fb00a4,0x7a12001c,0x1d090854,0x00000000}},	//   _imul, nāte, репи_,
  { {0x69c4003d,0x69d60164,0x9f350054,0x00000000}},	//   _snie, _soye, _дезі,
  { {0xdb0105b9,0xa9a605f4,0x4431539c,0x00000000}},	//   ndlø, оинд, _mhz_,
  { {0x27fa0150,0x7ae5004b,0x99f60085,0x00000000}},	//   _smpn_, _ühtm, іяні,
  { {0x69d60164,0xfba90053,0x9f450003,0x00000000}},	//   _voye, क़दम, _allé_,
  { {0x248001f7,0x9f4705d5,0x7ddc0003,0x00000000}},	//   vrim_, minó_, _désu,
  { {0x61fb000c,0x61e2539d,0x4ded0053,0x00000000}},	//   _omul, ykol, _जताई_,
  { {0x69c4539e,0xa5bb0139,0xceb2009f,0x00000000}},	//   _unie, _shór, ויל_,
  { {0x7d1600d1,0xe61701dd,0xb87b013d,0x00000000}},	// [a440] _øyst, іду_, szír,
  { {0x53c70002,0x20090025,0xf35a005e,0x00000000}},	//   огум_, éail_, ршај_,
  { {0x75ea0061,0x61e2539f,0x316a1313,0x00000000}},	//   _výzb, tkol, ашло_,
  { {0xea8c0047,0x248000dd,0x61e2004c,0x00000000}},	//   רנאָ, prim_, ukol,
  { {0x61e253a0,0x75fa0080,0xdb0a004c,0x00000000}},	//   rkol, hůzk, _rafí,
  { {0x61e22e4f,0x61fb1b3f,0xdb0a004c,0x00000000}},	//   skol, _emul, _safí,
  { {0x6536007e,0x61e253a1,0xfe6f00f2,0x00000000}},	//   _درگذ, pkol, ندي_,
  { {0x9343019d,0x7ddc0460,0x2cbd002b,0x00000000}},	//   _інте, _nést, _brwd_,
  { {0x9f47006d,0xdca3005e,0xa1c3014b,0x00000000}},	//   ginó_, дањи, _ўбуд,
  { {0x7ddc03b2,0x201e0078,0x3a200058,0x00000000}},	//   _résu, _ukti_, _akip_,
  { {0x3eb800ea,0x201c39d0,0x61e90072,0x00000000}},	//   _ért_, movi_, _ylel,
  { {0xfcaa006a,0x201c0869,0x2cbd002b,0x00000000}},	//   _ناتو_, lovi_, _frwd_,
  { {0xc173014e,0x9f470290,0x7ddc0003,0x00000000}},	//   וחר_, minò_, _dést,
  { {0xbebc001c,0x201c389e,0x6729004c,0x00000000}},	//   _dzīv, novi_, řejm,
  { {0x3dc60037,0xc5fb000a,0x67e20024,0x00000000}},	//   _know_, аѓа_, _môjh,
  { {0x7a12003d,0xdb090014,0x201c3692,0x00000000}},	//   tāte, _ónák, hovi_,
  { {0x94ab257e,0x34940daf,0x39490019,0x00000000}},	// [a450] штва_, матр, _igas_,
  { {0x61fb53a2,0x9f5c0195,0x61e9005f,0x00000000}},	//   _smul, bivé_, _slel,
  { {0x7afc0025,0x201c1b9d,0x224d008f,0x00000000}},	//   úrth, dovi_, _čeks_,
  { {0xdb180137,0x41e40054,0x50b505ac,0x00000000}},	//   _invä, міча, зску,
  { {0x9f470290,0xf7f4007e,0xa6e20026,0x00000000}},	//   dinò_, _رسید, öðva,
  { {0x201c01b3,0xa2a60042,0x7bd853a3,0x00000000}},	//   govi_, _टैक्, _novu,
  { {0x2ba90053,0x1ea8005d,0x00000000,0x00000000}},	//   क़सा, قايي_,   ,
  { {0xee390001,0x61fb42c3,0x25a90bb6,0x00000000}},	//   љни_, _umul, neal_,
  { {0x24890016,0x683200b9,0x321d0051,0x00000000}},	//   nuam_, læde, mowy_,
  { {0x321d0045,0x3a2053a4,0x80a40021,0x00000000}},	//   lowy_, _skip_, _تمكن,
  { {0x7bd802f6,0x63b50089,0x9f470331,0x00000000}},	//   _dovu, _mazn, sinó_,
  { {0x9f470290,0x321d0051,0x75fa004c,0x00000000}},	//   cinò_, nowy_, růzk,
  { {0xdb182ddc,0x25a90027,0xdb030026,0x00000000}},	//   _anvä, deal_, _janú,
  { {0x9f5c419d,0x9cd60063,0x63b5081a,0x00000000}},	//   tivé_, _מונה_, _nazn,
  { {0xfaa2011c,0x321d0051,0xb7b9000d,0x00000000}},	//   _защо, kowy_, цыях_,
  { {0x2d8d0035,0x9f5c53a5,0x201c074f,0x00000000}},	//   ngee_, rivé_, zovi_,
  { {0x248900e3,0x321d0051,0x64a353a6,0x00000000}},	// [a460] guam_, dowy_, ната,
  { {0x6135013d,0x142353a7,0xd764005d,0x00000000}},	//   zülé, едум, _تندی,
  { {0x386900bd,0xe7db014e,0xb7db0063,0x00000000}},	//   _zwar_, _הקיש, _הקיי,
  { {0x0446093e,0x321d0022,0xa50a0131,0x00000000}},	//   _немн, gowy_, _гема_,
  { {0x25d700b7,0xdb1800c7,0x55bb0063,0x00000000}},	//   _זוכן_, _invå, _המכו,
  { {0xdb0a00c7,0x201c0290,0x656400a4,0x00000000}},	//   _infö, uovi_, lbih,
  { {0x2cad00e5,0x9f47004c,0x321d0022,0x00000000}},	//   ewed_, chní_, bowy_,
  { {0xdb030066,0x9daa0062,0x321d0022,0x00000000}},	//   _fanú, съка_, cowy_,
  { {0x7bd8017f,0x613500ea,0xdb08017d,0x00000000}},	//   _povu, rülé, cedê,
  { {0x7ae100d1,0x7ddc017d,0x50b5000d,0x00000000}},	//   fylt, _péss, _ўсту,
  { {0x613500ea,0x443a000c,0xe45f0014,0x00000000}},	//   pülé, imp_, _gröf_,
  { {0x80b30053,0xa8990002,0xee3a005e,0x00000000}},	//   _इनमे, окму_, _уне_,
  { {0x7bd80009,0x25a90034,0x7a3f008f,0x00000000}},	//   _tovu, veal_, _jūti,
  { {0x65640089,0xca47007e,0x321d0051,0x00000000}},	//   ebih, _کليه_, zowy_,
  { {0x752f0045,0x63b501b3,0xdb0a0137,0x00000000}},	//   _szcz, _razn, _anfö,
  { {0x63b50117,0x443a292c,0x2489017d,0x00000000}},	//   _sazn, emp_, tuam_,
  { {0xb97c0063,0x7c2800cd,0x25a953a8,0x00000000}},	// [a470] _הנחי, oldr, real_,
  { {0x672500fe,0x656400a4,0x68ef005b,0x00000000}},	//   _tyhj, abih, ındı,
  { {0x98b901f7,0x321d0051,0x63b5007d,0x00000000}},	//   ması_, towy_, _vazn,
  { {0x68320146,0x229531c8,0x2cad001f,0x00000000}},	//   ræde, råk_, ywed_,
  { {0x656f0185,0x7a12001c,0x321d0051,0x00000000}},	//   _iech, nāta, rowy_,
  { {0x656f53a9,0x321d0051,0x6e220066,0x00000000}},	//   _hech, sowy_, _akob,
  { {0xb2840121,0xd5e10053,0xdb01004c,0x00000000}},	//   _пытк, _नवाज, telí,
  { {0x7c28056f,0x660d53aa,0x799d006f,0x00000000}},	//   eldr, nnak, jfsw,
  { {0x660d24ca,0x2d8d00e8,0x64470035,0x00000000}},	//   inak, rgee_, _kiji,
  { {0x7a12001c,0x64470089,0x656f53ab,0x00000000}},	//   dāta, _jiji, _lech,
  { {0xeeb924dc,0xdb0800cd,0xdb010331,0x00000000}},	//   _флеш_, nedè, pelí,
  { {0x645d0aba,0xf2d20047,0x656f0114,0x00000000}},	//   _otsi, דעט_, _nech,
  { {0x6d590035,0x660d53ac,0x98b9005b,0x00000000}},	//   _ifwa, dnak, fası_,
  { {0x660d00fe,0x6e2928f9,0xa3ac0053,0x00000000}},	//   enak, lleb, कड़ा_,
  { {0x645d0812,0x6e3b008f,0x656f53ad,0x00000000}},	//   _atsi, omub, _bech,
  { {0x7a12001c,0x6e29004d,0x656f13e4,0x00000000}},	//   bāta, nleb, _cech,
  { {0x656f0185,0x644753ae,0x644f53af,0x00000000}},	// [a480] _dech, _biji, _cuci,
  { {0x9f451c50,0x7a3f001c,0x660d1332,0x00000000}},	//   _allí_, _rūti, anak,
  { {0x645d024a,0x656f53b0,0x2cb8001c,0x00000000}},	//   _etsi, _fech, ārdi_,
  { {0x6d4b00f3,0xf1a300e1,0x644f53b1,0x00000000}},	//   _ngga, вршн, _fuci,
  { {0x66040072,0x7c282c38,0x6d5d0058,0x00000000}},	//   miik, yldr, ısal,
  { {0x6d590179,0x6d4b0b03,0x6604065c,0x00000000}},	//   _afwa, _agga, liik,
  { {0xdb0800cd,0xbea30699,0x6e290244,0x00000000}},	//   cedè, вајк, fleb,
  { {0x660410f0,0x7ddc0118,0x98b9005b,0x00000000}},	//   niik, _césp, zası_,
  { {0x98b90058,0x6da3005e,0x9f5c004c,0x00000000}},	//   yası_, тиња, liví_,
  { {0x7a12001c,0x660d371c,0x8af80893,0x00000000}},	//   vāta, znak, знос_,
  { {0x660d005b,0xddcb0755,0x98b9005b,0x00000000}},	//   ynak, žišt, vası_,
  { {0x7a12008f,0xdb08013d,0x3e7a008f,0x00000000}},	//   tāta, nedé, mīt_,
  { {0x660d0024,0x98b901f7,0x3e7a001c,0x00000000}},	//   vnak, tası_, līt_,
  { {0x656f00bd,0x6e2053b2,0xdce0004c,0x00000000}},	//   _sech, lomb, zamě,
  { {0x3e7a003d,0x98b901f7,0xdb0800ea,0x00000000}},	//   nīt_, rası_, kedé,
  { {0x644700e3,0x62850240,0x98b9005b,0x00000000}},	//   _siji, vrho, sası_,
  { {0x656f53b3,0x25a20089,0x660d204e,0x00000000}},	// [a490] _vech, _dbkl_, rnak,
  { {0x656f00bd,0x7a12001c,0x68e00137,0x00000000}},	//   _wech, nātn, ämde,
  { {0x64470035,0xe0d0007e,0x660d147f,0x00000000}},	//   _viji, یزه_, pnak,
  { {0x3e7a003d,0xd1310032,0xdb0800ea,0x00000000}},	//   dīt_, هما_, gedé,
  { {0x645d02fb,0xf8bf00cd,0xe001000d,0x00000000}},	//   _utsi, nvé_, лькi_,
  { {0x7a36004c,0x7bdc0014,0x2eb54c19,0x00000000}},	//   máte, örul, есис,
  { {0xfc48001b,0x6e20006d,0x2ca601da,0x00000000}},	//   _gửi_, fomb, _apod_,
  { {0x24860812,0x6e3b00a4,0x442153b4,0x00000000}},	//   šome_, umub, loh_,
  { {0x30150088,0xdb010024,0x91ad008b,0x00000000}},	//   _здар, delá, _ghé_,
  { {0xeb990001,0x2e4b005a,0x44213914,0x00000000}},	//   чио_, _дядо_, noh_,
  { {0xf99f0290,0xdd00001c,0x6e2053b5,0x00000000}},	//   ffè_, ātāj, bomb,
  { {0x61f901f7,0x9d750047,0x6e2053b6,0x00000000}},	//   _çalı, _װײַס_, comb,
  { {0x0d76006a,0x4421014f,0x39440137,0x00000000}},	//   _سخنگ, koh_, äms_,
  { {0x7a36004c,0xcc760aeb,0xdb08013d,0x00000000}},	//   dáte, _טענה_, zedé,
  { {0xe794006a,0x660400fe,0xf7530021,0x00000000}},	//   _یادک, tiik, انفج,
  { {0xf1b906bb,0x7a3f0006,0x75ea0066,0x00000000}},	//   _naš_, _būtu, _výzo,
  { {0x6604112c,0x3e7a001c,0x480a0062,0x00000000}},	// [a4a0] riik, zīt_, _неин_,
  { {0x660400fe,0x4421216c,0xf5070121,0x00000000}},	//   siik, goh_, хнул_,
  { {0xf1b9017f,0x7a12001c,0x74130021,0x00000000}},	//   _baš_, nāto, دولا,
  { {0xf8a40042,0x00000000,0x00000000,0x00000000}},	//   _ओहाय,   ,   ,
  { {0x44210397,0x9f4500cd,0x7c2100b9,0x00000000}},	//   boh_, _allà_, kolr,
  { {0x3e7a003d,0x44210228,0xc0590086,0x00000000}},	//   tīt_, coh_, фії_,
  { {0x44380199,0x6e2053b7,0x7bdc0014,0x00000000}},	//   _ihr_, tomb, örum,
  { {0x3e7a003d,0xe2a60026,0x68e600ac,0x00000000}},	//   rīt_, öðum_, kykd,
  { {0x3e7a003d,0x6e2053b8,0x6d570043,0x00000000}},	//   sīt_, romb, رجيح_,
  { {0x4438087d,0x6e2053b9,0x3e7a008f,0x00000000}},	//   _jhr_, somb, pīt_,
  { {0x6e2000c3,0xda77014c,0x657601a1,0x00000000}},	//   pomb, няя_, kayh,
  { {0xf1c6016a,0xddea0049,0x65760050,0x00000000}},	//   _रोमन, _عرضه_, jayh,
  { {0xf8bf0164,0x291e005b,0x4438004d,0x00000000}},	//   uvé_, ştan_, _ohr_,
  { {0xf8bf4dc9,0x7a12008f,0xecb70063,0x00000000}},	//   rvé_, bāto, _נפוץ_,
  { {0x2cb8003d,0x25a0001f,0x5b570063,0x00000000}},	//   ārdu_, ffil_, _איוב_,
  { {0x25a018a4,0x38600014,0x7a363995,0x00000000}},	//   gfil_, _ftir_, táte,
  { {0x69cd0035,0x442153ba,0x28f90121,0x00000000}},	// [a4b0] _inae, toh_, _цепь_,
  { {0x67e20066,0x443853bb,0x7a3653bc,0x00000000}},	//   _dôjs, _chr_, ráte,
  { {0x8c1b0063,0x442107c9,0x92951fa0,0x00000000}},	//   לומי, roh_, таец,
  { {0x442100e3,0x225c004c,0x443800e7,0x00000000}},	//   soh_, ívka_, _ehr_,
  { {0xf1b9065f,0x7c380019,0x44210089,0x00000000}},	//   _vaš_, _ohvr, poh_,
  { {0x9f4502dd,0xc0e253bd,0x8fa553be,0x00000000}},	//   _allá_, рошк, таке,
  { {0xa75c0063,0x91ad0013,0x53340dcb,0x00000000}},	//   הדור, _chẽ_, _берт,
  { {0x248953bf,0x7a12008f,0x4d620094,0x00000000}},	//   oram_, vāto, акъв,
  { {0x4438004d,0xdb0301d1,0x00db0cac,0x00000000}},	//   _yhr_, _daný, _عبرت_,
  { {0xa5bb0026,0x68e60078,0x248953c0,0x00000000}},	//   _skól, vykd, iram_,
  { {0xa3d2024c,0x05e10053,0x0dcb00e1,0x00000000}},	//   वात_, _नवंब, _нуди_,
  { {0xdd1d000c,0x248953c1,0x7a12008f,0x00000000}},	//   _câţi, kram_, rāto,
  { {0x7c2100f3,0x48fc0053,0xdb010058,0x00000000}},	//   polr, _लेखो_, kelç,
  { {0x8b940062,0xfc48008d,0x200753c2,0x00000000}},	//   _бръч, _bửu_, nini_,
  { {0x68e600d1,0xfc480013,0xd62a46c1,0x00000000}},	//   sykd, _cửu_, дове_,
  { {0x24890026,0x6d5b00ae,0x200753c3,0x00000000}},	//   fram_, ncua, hini_,
  { {0x200703d7,0x25a053c4,0xe643007b,0x00000000}},	// [a4c0] kini_, rfil_, ретп,
  { {0x7ae50019,0xdb0105b9,0x9359005e,0x00000000}},	//   _ühts, relæ, ерцу_,
  { {0x248953c5,0x877b0047,0x200753c6,0x00000000}},	//   aram_, _קאטי, dini_,
  { {0x2489091f,0xe297005e,0x463a0054,0x00000000}},	//   bram_, ђач_, _ічня_,
  { {0x40960055,0xa3d20053,0x44380509,0x00000000}},	//   трет, वाद_, _thr_,
  { {0x443800bd,0xbea60076,0x200753c7,0x00000000}},	//   _uhr_, вший, gini_,
  { {0x59b20053,0x63bc45d2,0xdb010072,0x00000000}},	//   ज़ार, _iarn, nelä,
  { {0x6e39002b,0xbdb40141,0xadb40131,0x00000000}},	//   _chwb, убиј, убиш,
  { {0x61e00027,0x63bc14ee,0x200753c8,0x00000000}},	//   _ioml, _karn, bini_,
  { {0xdb1a013d,0x61e0013d,0xa0670601,0x00000000}},	//   ldté, _homl, _рафа_,
  { {0x291e000c,0x7ec80164,0x229c0114,0x00000000}},	//   ştal_, _dépô, ník_,
  { {0xc27b014e,0x2d9200d1,0xecea0002,0x00000000}},	//   ורטי, _øye_, _одел_,
  { {0x2cb8001c,0xcdf70063,0x6ba70137,0x00000000}},	//   ārds_, _במאי_, ärgå,
  { {0x69cd0185,0x629e02fb,0xdb030e7c,0x00000000}},	//   _wnae, ktpo, _canó,
  { {0xdceb001c,0x5c3700ff,0xdb01092e,0x00000000}},	//   _iegā, _שטוב_, gelä,
  { {0x200753c9,0x248953ca,0x229c0061,0x00000000}},	//   zini_, tram_, dík_,
  { {0xdb030022,0x20070058,0x63bc53cb,0x00000000}},	// [a4d0] _fanó, yini_, _barn,
  { {0x7a360026,0x44270c08,0x229c0124,0x00000000}},	//   máta, ôn_, fík_,
  { {0x63bc2659,0x200753cc,0x61e0013d,0x00000000}},	//   _darn, vini_, _boml,
  { {0x63bc1ff2,0x24860006,0xa5f90184,0x00000000}},	//   _earn, šoma_, _чему_,
  { {0x3c390164,0x63bc53cd,0x200753ce,0x00000000}},	//   lève_, _farn, tini_,
  { {0x27e153cf,0x9f5c3b75,0xf99f01a8,0x00000000}},	//   _john_, tivá_, onès_,
  { {0x200704ab,0xed5953d0,0x27e153d1,0x00000000}},	//   rini_, ной_, _mohn_,
  { {0xf99f00cd,0x200753d2,0x27e1004d,0x00000000}},	//   inès_, sini_, _lohn_,
  { {0x200753d3,0xdd11005b,0x3c390003,0x00000000}},	//   pini_, _düşm, hève_,
  { {0x6d5b1c5d,0xdb18004c,0x6140004c,0x00000000}},	//   scua, _zavé, _dílč,
  { {0x224d00eb,0xba75007e,0xdb0100d1,0x00000000}},	//   _kiek_, داخت, kelå,
  { {0x75ea0080,0xdb080871,0xc332009a,0x00000000}},	//   _výzk, cedí, מוי_,
  { {0x224702f4,0xdb0353d4,0xdb010137,0x00000000}},	//   ínky_, _canò, delå,
  { {0x224d00e8,0xdb010072,0xdb1a013d,0x00000000}},	//   _liek_, telä, zdté,
  { {0x98a5003d,0xd757007e,0xa3d20053,0x00000000}},	//   ālā_, الفت_, वास_,
  { {0x63bc0019,0xdb010137,0x229c53d5,0x00000000}},	//   _sarn, relä, vík_,
  { {0x20ce0026,0x61e0262d,0xdb08003b,0x00000000}},	// [a4e0] iðið_, _roml, cedâ,
  { {0x61e00137,0x5664007e,0xdb03006c,0x00000000}},	//   _soml, _نگرف, _abné,
  { {0x63bc53d6,0x179b0047,0x3872001f,0x00000000}},	//   _varn, _אייב, _hwyr_,
  { {0x629e53d7,0x63bc374b,0xa3d20053,0x00000000}},	//   rtpo, _warn, वाह_,
  { {0xd0d40062,0x63bc53d8,0xdb1a013d,0x00000000}},	//   ролъ, _tarn, rdté,
  { {0xceba0001,0x7a0b0051,0xb4c20053,0x00000000}},	//   ељи_, nętr, ्मी_,
  { {0x7a12008f,0x3872002b,0x290c0058,0x00000000}},	//   gātk, _lwyr_, ğday_,
  { {0x5d54026b,0xdb01004b,0x20ce0014,0x00000000}},	//   шкит, ndlõ, gðið_,
  { {0x644e0009,0x7ddc000f,0x25d70047,0x00000000}},	//   _kibi, _kész, רופן_,
  { {0x644e0035,0x224d1c40,0x7ae800ac,0x00000000}},	//   _jibi, _ziek_, tydt,
  { {0x3872001f,0xdb0853d9,0xfba70121,0x00000000}},	//   _awyr_, pedí, утый_,
  { {0x27e100bd,0xf2d300b5,0x75f8004c,0x00000000}},	//   _sohn_, צער_, _jízd,
  { {0x79840185,0x7d7b0047,0xdb0101e1,0x00000000}},	//   _ddiw, _טראג, velå,
  { {0xf41f0137,0x7a3653da,0x4ae60044,0x00000000}},	//   _iväg_, ráta, _مثبّ,
  { {0x85a70002,0xd90f007e,0xe7f60053,0x00000000}},	//   лјад, تیک_, ीफ़ा_,
  { {0xf99f0813,0xb4c20053,0x35b50699,0x00000000}},	//   rnès_, ्मू_, јбар,
  { {0x7b040006,0x644e240d,0x224d0066,0x00000000}},	// [a4f0] žutė, _bibi, _riek_,
  { {0xdce0003d,0x9f4500fe,0x644e3d38,0x00000000}},	//   lamē, _yllä_, _cibi,
  { {0x644e53db,0xe45f0137,0x212d0150,0x00000000}},	//   _dibi, _grön_, _syeh_,
  { {0xd6d80054,0x25b20058,0xb15c0054,0x00000000}},	//   _сть_, ceyl_, енцi,
  { {0x656d014f,0x7a360114,0xbec7008f,0x00000000}},	//   mbah, kátn, itīš,
  { {0xdceb0529,0x224d53dc,0x656d53dd,0x00000000}},	//   _legă, _wiek_, lbah,
  { {0xa3d20161,0x224d20ae,0x141a0063,0x00000000}},	//   वार_, _tiek_, _יושב,
  { {0x656d0baa,0xdceb003b,0x78ad004c,0x00000000}},	//   nbah, _negă, _opav,
  { {0x20ce007a,0x656d0150,0x3e550023,0x00000000}},	//   rðið_, ibah, _māti_,
  { {0x7a12003d,0x644e017d,0x60c953de,0x00000000}},	//   māti, _xibi, _irem,
  { {0x78ad53df,0x6380004c,0x9999013d,0x00000000}},	//   _apav, lání, első_,
  { {0xdb2400ea,0xd9460256,0xdb01006c,0x00000000}},	//   ásáv, иени, nflé,
  { {0x7a12003d,0x656d004d,0xf93605ac,0x00000000}},	//   nāti, dbah, рхню,
  { {0x656d0089,0x18670b0e,0x7a36011b,0x00000000}},	//   ebah, рари_, cátn,
  { {0x7ddc000f,0xf74653e0,0x656d004d,0x00000000}},	//   _rész, рево, fbah,
  { {0x9655005a,0x442a0150,0x0566037b,0x00000000}},	//   сърч, _skb_, рван,
  { {0x9f470027,0x7a12001c,0x442a0c02,0x00000000}},	// [a500] ghnú_, jāti, _pkb_,
  { {0xdb0802f4,0x187b00b5,0x63800080,0x00000000}},	//   ledá, _שטיב, dání,
  { {0x9f5c0c4a,0xe29a01e8,0x7bc10019,0x00000000}},	//   nivå_, тае_, idlu,
  { {0x60c953e1,0x71a60088,0x506653e2,0x00000000}},	//   _brem, радз, атка,
  { {0x9f472803,0x60c94028,0x644e53e3,0x00000000}},	//   chnú_, _crem, _tibi,
  { {0x7a3d00ea,0x2480001c,0x60c9131a,0x00000000}},	//   méte, msim_, _drem,
  { {0xd3350088,0x7a3d236b,0x444453e4,0x00000000}},	//   _гэты, léte, mm_,
  { {0x8066019d,0x60c953e5,0x7644005b,0x00000000}},	//   _вваж, _frem, nmiy,
  { {0xdceb000c,0x2bd20053,0x44441aaf,0x00000000}},	//   _regă, ताला, om_,
  { {0x44440025,0x8c430002,0xed59007d,0x00000000}},	//   nm_, оење, rdža_,
  { {0x444453e6,0xeb970002,0xfeba0021,0x00000000}},	//   im_, шиќ_, _جاءت_,
  { {0x44440221,0x248053e7,0x7d08001c,0x00000000}},	//   hm_, ksim_, tīrī,
  { {0x444453e8,0x98b80330,0xfd12005d,0x00000000}},	//   km_, алят_, _بجا_,
  { {0xdb1853e9,0x7a3d0003,0xbec7008f,0x00000000}},	//   _haví, déte, stīš,
  { {0x0cb60161,0x89d9007e,0x2480005b,0x00000000}},	//   _अनुम, _موثر_, esim_,
  { {0xb9990001,0x9f470025,0xe5550856,0x00000000}},	//   _свих_, thnú_, скањ,
  { {0x656d53ea,0x290f0137,0x2480008f,0x00000000}},	// [a510] rbah, _äga_, gsim_,
  { {0x63800080,0x7a12001c,0x656d051c,0x00000000}},	//   vání, vāti, sbah,
  { {0x752f0051,0x60c912bf,0x7d1d013d,0x00000000}},	//   _wycz, _srem, üssz,
  { {0xdb1853eb,0x7bc10089,0x44440479,0x00000000}},	//   _naví, zdlu, am_,
  { {0x7a36027d,0x7c281994,0x7a3d006d,0x00000000}},	//   záto, kodr, céte,
  { {0x289a00b5,0xafe20076,0x60c953ec,0x00000000}},	//   ריװא, зошл, _vrem,
  { {0x75ea0240,0x7a12008f,0xe7ff0053,0x00000000}},	//   _výzv, sāti, _उतना_,
  { {0xd0870121,0x60c915ae,0x7bc1002b,0x00000000}},	//   _выжи, _trem, wdlu,
  { {0x2d86001f,0xd0e9007e,0x7c280137,0x00000000}},	//   _ddoe_, _حکام_, fodr,
  { {0x64450139,0x7a3621e2,0x9982004c,0x00000000}},	//   nmhi, táto, toků_,
  { {0x7bc10019,0x660d1846,0x64450139,0x00000000}},	//   rdlu, kiak, imhi,
  { {0x69d80053,0x9982004c,0x7a364c1e,0x00000000}},	//   याधी, roků_, ráto,
  { {0xfd56014e,0x660d4acc,0x44440051,0x00000000}},	//   _השני_, diak, ym_,
  { {0x7a3d000f,0xe9df0066,0x7bdc07fb,0x00000000}},	//   véte, ajú_, örut,
  { {0xaa950021,0xe45f0137,0x76440058,0x00000000}},	//   _العث, _dröm_, tmiy,
  { {0x7a3d00ea,0x6a640021,0x777c00cd,0x00000000}},	//   téte, _بطول, sarx,
  { {0x7644005b,0x24800150,0x444453ed,0x00000000}},	// [a520] rmiy, usim_, tm_,
  { {0x3ea90051,0x32d6000d,0x7a3d2f17,0x00000000}},	//   łaty_, йцес, réte,
  { {0x44442ff6,0x660d1f81,0x248053ee,0x00000000}},	//   rm_, biak, ssim_,
  { {0x44442ef9,0x7a3d4ed9,0x6355004c,0x00000000}},	//   sm_, péte, třní,
  { {0x44441c60,0x399b0047,0xdf7816f2,0x00000000}},	//   pm_, רינד, аблі_,
  { {0xdb0102ab,0x9326007e,0xf3e60086,0x00000000}},	//   belø, _هرزن, _ужго,
  { {0x7a120023,0xadd8195f,0xf2d8009a,0x00000000}},	//   lātu, имку_, _דַּל,
  { {0x21a30001,0x7c28001f,0x867b0047,0x00000000}},	//   _нисм, wodr, ארקו,
  { {0xb87b00ea,0x9bc60121,0x7a12008f,0x00000000}},	//   nyít, бёнк, nātu,
  { {0x7c280078,0x8fe50044,0xe0f7009a,0x00000000}},	//   uodr, _وألم, _הצמח_,
  { {0x7c2853ef,0x9a67005d,0xfe720044,0x00000000}},	//   rodr, یمیل_, _ردا_,
  { {0x7f3b00b5,0x1e570063,0x7a12008f,0x00000000}},	//   _געבו, _השאר_, kātu,
  { {0x6a53003b,0x7bdc0014,0x7c2853f0,0x00000000}},	//   _săft, örus, podr,
  { {0x660d0022,0x8cb70042,0xf77014d7,0x00000000}},	//   wiak, ्टरो, فاف_,
  { {0xa3cc0235,0x660d2488,0xa3d20053,0x00000000}},	//   _शोध_, tiak, वाई_,
  { {0x78ac0137,0x96350e74,0x9a6714d7,0x00000000}},	//   ålvä, інац, _اميل_,
  { {0x045b007e,0x660d53f1,0x94770044,0x00000000}},	// [a530] اجرت_, riak, إدرا,
  { {0x660d187b,0x44331276,0x386953f2,0x00000000}},	//   siak, ulx_, _itar_,
  { {0x38690089,0x660d4e6d,0xe1f0005d,0x00000000}},	//   _htar_, piak, کسل_,
  { {0xdb0102ab,0xa4d5013c,0xd6e8089e,0x00000000}},	//   relø, _домі, _הַשָ,
  { {0xdb010205,0x661d006f,0x659a009a,0x00000000}},	//   selø, _ijsk, _דירק,
  { {0xa87c0047,0x7a04013d,0x3e47009c,0x00000000}},	//   ראגר, lőtt, _lőtt_,
  { {0x25a9002b,0xa2940054,0x479c0041,0x00000000}},	//   ofal_, _нарі, טיגס,
  { {0xdb0a00bd,0xee3900e1,0x387e0051,0x00000000}},	//   _dafü, јни_, ątrz_,
  { {0x38690150,0xada80021,0x1fa700e2,0x00000000}},	//   _ntar_, صديق_, _грег,
  { {0x7a360066,0x4aa91002,0x2d82013d,0x00000000}},	//   rátm, акон_, óker_,
  { {0xbf150032,0xa3ab0042,0x628b0022,0x00000000}},	//   _بواب, क्य_, ągow,
  { {0x7a360080,0x394a04f2,0xdce0005f,0x00000000}},	//   mátk, изно_, jamė,
  { {0x91bf001b,0xb903000d,0x8936013a,0x00000000}},	//   _chủ_, дзяк, تعدا,
  { {0xcb690086,0x7a12001c,0xfcfa0047,0x00000000}},	//   _таке_, vātu, _כּול,
  { {0x26cc30b6,0x7bc3000c,0x65c6005a,0x00000000}},	//   ído_, _ianu, обва,
  { {0x7bc353f3,0xbb3a0041,0x7a120023,0x00000000}},	//   _hanu, _דעצי, tātu,
  { {0x69d6006d,0x7bc353f4,0xe9df0331,0x00000000}},	// [a540] _inye, _kanu, omún_,
  { {0x245f001f,0x69c43318,0x7a3d246c,0x00000000}},	//   _dîm_, _haie, méta,
  { {0x69c60146,0x057601a7,0xa5bb0026,0x00000000}},	//   odke, _واحد, _bjód,
  { {0xdb1a00ea,0x7a360260,0xcb120063,0x00000000}},	//   ndtá, dátk, ולב_,
  { {0x7a3d17a6,0x38a42502,0x69c453f5,0x00000000}},	//   néta, nör_, _maie,
  { {0xbe8a042c,0x69c41255,0x7bc353f6,0x00000000}},	//   асие_, _laie, _nanu,
  { {0x69d60009,0x38a40502,0x7a3600ea,0x00000000}},	//   _onye, hör_, rátj,
  { {0x85f700b5,0x7bc300a4,0xdb1801c2,0x00000000}},	//   ַציע_, _aanu, _navá,
  { {0x6283004a,0x6fb60021,0x7bc300dd,0x00000000}},	//   ánov, _ومرا, _banu,
  { {0x7a360405,0x69c600f5,0xbd8a007e,0x00000000}},	//   láth, edke, _چنان_,
  { {0x80c20053,0xda35000d,0x7bc3363d,0x00000000}},	//   लिके, зены, _danu,
  { {0x38a400c7,0x91bf008b,0x7a360025,0x00000000}},	//   för_, _phủ_, náth,
  { {0x38a400c7,0x7a3d0164,0x99a500ea,0x00000000}},	//   gör_, géta, ítők_,
  { {0x7bc30da5,0x61e20072,0xd7f82046,0x00000000}},	//   _ganu, hjol, оус_,
  { {0x98ac001c,0x45d524dc,0x61e201f2,0x00000000}},	//   ādā_, повс, kjol,
  { {0x91bf008b,0x7a3d0003,0x69c41276,0x00000000}},	//   _thủ_, béta, _gaie,
  { {0x8ccd0161,0xe5340086,0x29020051,0x00000000}},	// [a550] तियो, деть, czka_,
  { {0x69a70161,0xdb180114,0x61e20150,0x00000000}},	//   ट्री, _zavá, ejol,
  { {0x77ba0063,0x67ba0063,0xb882004c,0x00000000}},	//   _המתח, _המתק, říte,
  { {0x5bb70235,0x245f0185,0x2bb70053,0x00000000}},	//   _अस्व, _tîm_, _अस्थ,
  { {0x403549fb,0x3f690733,0x3cf40042,0x00000000}},	//   педс, било_, इनों_,
  { {0x6008000d,0xa2ad0042,0x7205005d,0x00000000}},	//   онім_, ीबद्, _کورم,
  { {0x645d5106,0xfd4c001b,0x38a400ea,0x00000000}},	//   _husi, _triể, zör_,
  { {0x645d0009,0x657d0035,0x9f470066,0x00000000}},	//   _kusi, _jesh, chný_,
  { {0x628553f7,0xdb1a00b9,0x7bc353f8,0x00000000}},	//   lsho, ndtæ, _panu,
  { {0x7a3653f9,0x1c42093e,0x799d004d,0x00000000}},	//   máti, нным, egsw,
  { {0x69c453fa,0xda650086,0x645553fb,0x00000000}},	//   _paie, явни, _mizi,
  { {0xa3ab0394,0x38a453fc,0x7bc30035,0x00000000}},	//   क्त_, tör_, _wanu,
  { {0x645d00eb,0xc9550088,0x8d5a0063,0x00000000}},	//   _nusi, дтры, _הכני,
  { {0xa3ab0053,0x7a3d53fd,0x61fb01a8,0x00000000}},	//   _कॉल_, réta, _llul,
  { {0x61fb0004,0x645d2b28,0x38a4005b,0x00000000}},	//   _olul, _ausi, sör_,
  { {0xd90d006a,0x645d11a0,0x7a3d3ac2,0x00000000}},	//   ایی_, _busi, péta,
  { {0xdb0a007a,0x6564005b,0x6455005b,0x00000000}},	// [a560] _hafð, rcih, _bizi,
  { {0x64550080,0xdb1806a5,0x7a36039f,0x00000000}},	//   _cizi, _davæ, dáti,
  { {0x645553fe,0x6b9c00cd,0x657d0058,0x00000000}},	//   _dizi, òrgi, _fesh,
  { {0x6d59001f,0x7a3f0078,0x61e953ff,0x00000000}},	//   _ngwa, _būty, _coel,
  { {0x61e903a8,0x645516ca,0x61ed004b,0x00000000}},	//   _doel, _fizi, öala,
  { {0x6d59002c,0x61fb0019,0xdcff004c,0x00000000}},	//   _agwa, _elul, ůvěr,
  { {0x62850025,0x27e500ea,0xe2971850,0x00000000}},	//   csho, ölni_, _нар_,
  { {0x225c004c,0x61e95400,0x531b009a,0x00000000}},	//   ívku_, _goel, _הולצ,
  { {0xc0590086,0x6283008f,0x6b815401,0x00000000}},	//   _діє_, šnot, falg,
  { {0xcfaa007e,0x3a200150,0x61e95402,0x00000000}},	//   _دارم_, _ajip_, _zoel,
  { {0xdb010066,0xdfa5002a,0xb4e80082,0x00000000}},	//   pelý, _تحقي, बहु_,
  { {0xcefe0058,0x6b8100ca,0xbef7009a,0x00000000}},	//   ışın_, aalg, _מצבו_,
  { {0x6b8130d1,0x657d5403,0xc8670c46,0x00000000}},	//   balg, _resh, ятни,
  { {0x62855404,0x645d5405,0x9cd7069a,0x00000000}},	//   ysho, _rusi, _מודה_,
  { {0x645d1d56,0x7bd80162,0xa3e00053,0x00000000}},	//   _susi, _invu, थान_,
  { {0x645501f7,0xa4d50086,0x645d5406,0x00000000}},	//   _sizi, мобі, _pusi,
  { {0x9f450003,0x61e900ca,0x54550062,0x00000000}},	// [a570] _volé_, _roel, дват,
  { {0x78fc0063,0x657d00bd,0xa87c0063,0x00000000}},	//   _לפחו, _wesh, _האזר,
  { {0x64555407,0x61e95408,0x7a3d017c,0x00000000}},	//   _vizi, _poel, néto,
  { {0x2fc50205,0x645d5409,0x7a3600f8,0x00000000}},	//   _salg_, _tusi, táti,
  { {0x645d024a,0xf485006a,0x61e90122,0x00000000}},	//   _uusi, _تاجی, _voel,
  { {0x61e9006f,0x6d59002b,0x7a36540a,0x00000000}},	//   _woel, _sgwa, ráti,
  { {0x2fc502ab,0x3e7a003d,0x61e90250,0x00000000}},	//   _valg_, gūt_, _toel,
  { {0x201c00cd,0x7bc8001f,0x7a36391b,0x00000000}},	//   anvi_, eddu, páti,
  { {0xdb080066,0x1c450054,0x9f5c01d1,0x00000000}},	//   cedú, мним, livý_,
  { {0x9f63024a,0x3e7a003d,0xa3c20161,0x00000000}},	//   ävät_, būt_, ्यय_,
  { {0xfc460080,0x7a3d108f,0x321d002b,0x00000000}},	//   _říct_, rétn, onwy_,
  { {0x7bd8006d,0x7a12001c,0x6b81115c,0x00000000}},	//   _envu, gātp, salg,
  { {0xa3c20235,0xb4bc0053,0x6b810019,0x00000000}},	//   ्यम_, _आने_, palg,
  { {0x1c440086,0x2d9f36f4,0xdce0008f,0x00000000}},	//   _знім, lgue_, zamī,
  { {0x46a30062,0xa3d10042,0xceb2009a,0x00000000}},	//   карв, वयन_, ֣ין_,
  { {0xa3ab0053,0xceb20063,0x2d9f07b9,0x00000000}},	//   क्स_, כיל_, ngue_,
  { {0x2d9f0331,0x7a0b0022,0x69c0006c,0x00000000}},	// [a580] igue_, jęty, ômeu,
  { {0x798d0051,0x833a0121,0xe3b70888,0x00000000}},	//   _zdaw, очет_, мбу_,
  { {0x3860006d,0x91e62877,0xdce0008f,0x00000000}},	//   _huir_, може, tamī,
  { {0xf2340043,0x5679009d,0x00000000,0x00000000}},	//   رباک, _מְשׂ,   ,
  { {0x987a0047,0x50d6007e,0x7bc80ea7,0x00000000}},	//   קאַט, بزار, yddu,
  { {0x7a36540b,0x2d9f0516,0x38602cec,0x00000000}},	//   mátu, egue_, _muir_,
  { {0x4ea60002,0x7a363dd4,0x03a30201,0x00000000}},	//   фрла, látu, _широ,
  { {0x25a0540c,0x386d003b,0xef18008f,0x00000000}},	//   ngil_, ţeri_, _ceļa_,
  { {0x80a6006a,0x7a12001c,0x7a36013d,0x00000000}},	//   _زمان, vātp, nátu,
  { {0x2d9f487f,0x7bc8002b,0x00000000,0x00000000}},	//   ague_, uddu,   ,
  { {0x7bc830bd,0x78b60078,0xca150062,0x00000000}},	//   rddu, _apyv, еднъ,
  { {0xdde3000c,0x7a36013d,0xdb010046,0x00000000}},	//   ărţi, kátu, kflæ,
  { {0x3860018d,0xd90f007e,0x386d006f,0x00000000}},	//   _cuir_, شید_, ëer_,
  { {0x2d84540d,0xdc8b2177,0x7a36013d,0x00000000}},	//   lame_, _וְהָ, dátu,
  { {0xdcc80013,0x0bb7009f,0x7ae701e1,0x00000000}},	//   _hỉ_, _חלום_, øjtt,
  { {0x25a000a4,0x7c3a1b80,0x4d7b0047,0x00000000}},	//   ggil_, lltr, ַרבע,
  { {0x2d840006,0xb9550086,0xd8470086,0x00000000}},	// [a590] iame_, _явищ, _охоп,
  { {0xdcc80013,0x43940141,0x2d84540e,0x00000000}},	//   _mỉ_, каус, hame_,
  { {0x92590055,0x87070088,0xe2980086,0x00000000}},	//   чает_, _цяпе, дає_,
  { {0x2d8400eb,0x0b150047,0xe45f0137,0x00000000}},	//   jame_, ײַער_, _bröt_,
  { {0xb0680021,0x2d84357b,0x7a360046,0x00000000}},	//   وصول_, dame_, mátt,
  { {0x764d005b,0x7a3610ba,0x248919fb,0x00000000}},	//   lmay, látt, msam_,
  { {0x9f450268,0x24580076,0x2d84540f,0x00000000}},	//   _allò_, _царь_, fame_,
  { {0x764d3a8e,0x2d845410,0xdcc80013,0x00000000}},	//   nmay, game_, _bỉ_,
  { {0xe134000d,0x2d9f5411,0x24895412,0x00000000}},	//   _анты, rgue_, nsam_,
  { {0x3ec4024a,0x5ba9018b,0x7a360026,0x00000000}},	//   ästä_, чком_, hátt,
  { {0x764d005b,0xe7e30053,0x2489004d,0x00000000}},	//   kmay, खाना_, hsam_,
  { {0x2d840037,0xc7a901f9,0x24895413,0x00000000}},	//   came_, _לב_, ksam_,
  { {0x7e6103a8,0x9f4500cd,0x39350085,0x00000000}},	//   _hulp, _molí_, вэрс,
  { {0x291e000c,0x6e3b0014,0x2489004b,0x00000000}},	//   ăta_, llub, dsam_,
  { {0x24460003,0x45d602b6,0xf6261f30,0x00000000}},	//   nôme_, нцат, едво,
  { {0xa2c30053,0x6e3b00a4,0x7a365414,0x00000000}},	//   रबन्, nlub, tátu,
  { {0x79865415,0xdcc80013,0xf50a019c,0x00000000}},	// [a5a0] makw, _xỉ_, чнал_,
  { {0x443a0162,0x36c60635,0x764d00a4,0x00000000}},	//   ulp_, _због, amay,
  { {0x2bf600b5,0x248900a4,0x1bf60047,0x00000000}},	//   עמען_, asam_, עצער_,
  { {0xeac9008b,0x2d84017d,0x0206000d,0x00000000}},	//   _mẹ_, xame_, эзен,
  { {0x2d840024,0x2489001f,0xdb01051c,0x00000000}},	//   vame_, csam_, lflä,
  { {0x6e94000a,0xe7e30053,0xdcc80013,0x00000000}},	//   вику, खाया_, _rỉ_,
  { {0x75f80240,0x7e612b2e,0xdcc80013,0x00000000}},	//   _nízk, _culp, _sỉ_,
  { {0x433b00b5,0x63be0def,0x9f5c006d,0x00000000}},	//   _זעלב, lepn, tivó_,
  { {0x79860228,0x60c4005b,0xf53f04c7,0x00000000}},	//   dakw, çimd, _ubåt_,
  { {0xdb1a3384,0x2d8f0c2e,0x764d0058,0x00000000}},	//   leté, _edge_, zmay,
  { {0x7a3600ea,0xed59082a,0x764d005b,0x00000000}},	//   játs, veže_, ymay,
  { {0xdb1a00ea,0xdcc8008b,0xe9190086,0x00000000}},	//   neté, _tỉ_, домі_,
  { {0xa3c20161,0x984b005a,0xdb01017d,0x00000000}},	//   ्या_, зява_, nglê,
  { {0xdb1a0003,0x2bd70042,0x629e46bc,0x00000000}},	//   heté, _भोपा, kupo,
  { {0x764d01f7,0xdb01004d,0x7a3d0066,0x00000000}},	//   tmay, gflä, nétk,
  { {0xed591253,0xdb1a0003,0x764d5416,0x00000000}},	//   seže_, jeté, umay,
  { {0xdbf90045,0xdb1a000f,0xe7870001,0x00000000}},	// [a5b0] _głów, deté, _пуно,
  { {0x24180086,0x1368005e,0x27e7004b,0x00000000}},	//   нією_, ешци_, _õnn_,
  { {0x7bca0035,0x24895417,0x764d005b,0x00000000}},	//   _mafu, ssam_, pmay,
  { {0xdb1a000f,0x7bca001f,0x1515000d,0x00000000}},	//   geté, _lafu, _адмя,
  { {0x91bf008b,0x7a3d013d,0x9f4501c8,0x00000000}},	//   _chú_, tétj, _volí_,
  { {0x7e610886,0x24460003,0xe8d9008d,0x00000000}},	//   _pulp, tôme_, _ngọ_,
  { {0xdb1a00ea,0x91bf008d,0x91b4004c,0x00000000}},	//   beté, _thù_, ířím,
  { {0xed59026c,0x24465418,0x97580063,0x00000000}},	//   мой_, rôme_, עיהו_,
  { {0x5dd40076,0x9f5c0290,0x61f6005b,0x00000000}},	//   ующу, rivò_, öyle,
  { {0x6e3b4aca,0x7e615419,0x44333996,0x00000000}},	//   slub, _tulp, nox_,
  { {0xda780088,0x3f87074f,0x4421008b,0x00000000}},	//   няў_, manu_, inh_,
  { {0xa5bb0026,0xa91b0014,0xc332089e,0x00000000}},	//   _sjón, maþj, שוט_,
  { {0xdb0100ea,0x63b5007d,0x6d5c004c,0x00000000}},	//   jelö, _obzn, ěrat,
  { {0xdb1a03e8,0xdb010244,0x9d1a009a,0x00000000}},	//   zeté, tflä, _קוסט,
  { {0x2cad3ef9,0x443341bd,0x96b9541a,0x00000000}},	//   lted_, dox_, нуту_,
  { {0xdb0100bd,0x6b83541b,0x3f87001f,0x00000000}},	//   rflä, _heng, hanu_,
  { {0x2cad541c,0xdb1a000f,0x7bca0035,0x00000000}},	// [a5c0] nted_, veté, _yafu,
  { {0x66040009,0x389b0047,0x2cad541d,0x00000000}},	//   shik, _קיינ, ited_,
  { {0xf6260088,0x6b832741,0x2cad0019,0x00000000}},	//   _адно, _meng, hted_,
  { {0x4421008b,0x91bf0013,0x7d09004d,0x00000000}},	//   anh_, _phú_, kzes,
  { {0xdb1a000f,0x629e541e,0xe04a007e,0x00000000}},	//   reté, supo, وشته_,
  { {0x3f871761,0x91030001,0x5f930002,0x00000000}},	//   ganu_, рпље, аишт,
  { {0x5299005a,0xe7e30053,0x9f4501f4,0x00000000}},	//   _пътя_, खाता_, _colà_,
  { {0x2cad0034,0x7bca0089,0x91bf0013,0x00000000}},	//   fted_, _safu, _thú_,
  { {0xf063000a,0x645c0dbb,0x2367027c,0x00000000}},	//   _вкуп, _kiri, žnje_,
  { {0x44380089,0x6b83192e,0x7a3d541f,0x00000000}},	//   _jkr_, _ceng, méti,
  { {0x2cad0037,0x6b83014f,0x645c2fc3,0x00000000}},	//   ated_, _deng, _miri,
  { {0xc33301d8,0x7bca0035,0x645c42f7,0x00000000}},	//   יות_, _wafu, _liri,
  { {0x7bca10ca,0x2cad0037,0x6b832973,0x00000000}},	//   _tafu, cted_, _feng,
  { {0xf7700021,0x645c00a4,0x443800ac,0x00000000}},	//   قاف_, _niri, _nkr_,
  { {0x7a3d0003,0x25b2001f,0x6b8801e1,0x00000000}},	//   héti, ffyl_, madg,
  { {0x645c5420,0x3f87159a,0x6b835421,0x00000000}},	//   _airi, zanu_, _zeng,
  { {0x645c01f7,0xe4a70062,0x7a3d3d50,0x00000000}},	// [a5d0] _biri, ърво, jéti,
  { {0x645c5422,0x337408b0,0x93940021,0x00000000}},	//   _ciri, игур, لجما,
  { {0x7d090290,0x41e7000d,0x645c2126,0x00000000}},	//   zzes, кіда, _diri,
  { {0xa29415d4,0x69cf00c7,0x320600a4,0x00000000}},	//   раці, ndce, ghoy_,
  { {0xe1340088,0x69cd0019,0x30a70940,0x00000000}},	//   анцы, _maae, трев,
  { {0x645c01f7,0x13a7007e,0x765d0150,0x00000000}},	//   _giri, _جنسی_, _hisy,
  { {0xed59085a,0x6b8801e1,0x3f870c19,0x00000000}},	//   deža_, dadg, ranu_,
  { {0xce180088,0x2cad010e,0x656d0397,0x00000000}},	//   кцыі_, tted_, ncah,
  { {0x6b835423,0x63a50025,0x3f87170d,0x00000000}},	//   _peng, oghn, panu_,
  { {0x2cad0037,0x63a50025,0x645c00cd,0x00000000}},	//   rted_, nghn, _xiri,
  { {0x6b835424,0x7d095425,0x69cf006f,0x00000000}},	//   _veng, szes, fdce,
  { {0x2cad0037,0x6b830009,0x60c905dd,0x00000000}},	//   pted_, _weng, _ksem,
  { {0x6ba40026,0x6b835426,0x6b8801e1,0x00000000}},	//   útgá, _teng, badg,
  { {0x9d1a00b5,0x60c90009,0x7c920032,0x00000000}},	//   _אונט, _msem, _الوص,
  { {0x69cd00b9,0x3f850019,0x765d5427,0x00000000}},	//   _faae, _melu_, _bisy,
  { {0x69cd05b9,0x7afc000e,0x7bc11e00,0x00000000}},	//   _gaae, ørte, lelu,
  { {0x443800e3,0x645c5428,0x044a0002,0x00000000}},	// [a5e0] _pkr_, _piri, епак_,
  { {0x200700c2,0x7bc15429,0x69c9008f,0x00000000}},	//   jhni_, nelu, īmeņ,
  { {0x60c9542a,0x645c542b,0xabfa0047,0x00000000}},	//   _asem, _viri, עהער,
  { {0xd2590086,0x645c035a,0x7bc1542c,0x00000000}},	//   вці_, _wiri, helu,
  { {0x7bc127cc,0x3493000d,0x3f85007d,0x00000000}},	//   kelu, _лаўр, _belu_,
  { {0x7a3d0164,0x3f85542d,0x3eca0001,0x00000000}},	//   réti, _celu_, ећим_,
  { {0x69a5016a,0x60c9542e,0x3f8502e2,0x00000000}},	//   _काली, _esem, _delu_,
  { {0x7a3d0164,0x52b20053,0x7c38004c,0x00000000}},	//   péti, ीबीस, _skvr,
  { {0xa0c90021,0x2dd70021,0xed59007d,0x00000000}},	//   _لذلك_, طبية_, teža_,
  { {0x200703a4,0x7bc130de,0x9b94005e,0x00000000}},	//   chni_, gelu, јинц,
  { {0x6b8800b9,0xd4370047,0xed5902f7,0x00000000}},	//   radg, רטיי_, reža_,
  { {0x6b8800b9,0xccf90051,0xda350121,0x00000000}},	//   sadg, byś_, ремы,
  { {0x7bc1542f,0xdb1a006d,0xed592029,0x00000000}},	//   belu, metí, peža_,
  { {0xb8ed0053,0xdb1a24ba,0x753d0022,0x00000000}},	//   _रन_, letí, _rysz,
  { {0xf3f9000c,0x7a28005b,0x1bfb0063,0x00000000}},	//   _îţi_, sıta, _אלגב,
  { {0xe66443bd,0xe4e70454,0xd4e70065,0x00000000}},	//   стро, лізн, люзи,
  { {0xdb0800cd,0x656d0089,0xd7f1008b,0x00000000}},	// [a5f0] cedò, rcah, ữ_,
  { {0x33950121,0x59dd0042,0x4615005d,0x00000000}},	//   ражё, याकर, _چودر,
  { {0x753d0045,0x7afa02ab,0x765d00a4,0x00000000}},	//   _wysz, nytt, _tisy,
  { {0x9564005a,0x3f85007d,0x3f9a0014,0x00000000}},	//   _гърд, _selu_, ópun_,
  { {0x7bc10089,0xc0e50699,0x2007002b,0x00000000}},	//   yelu, ролк, thni_,
  { {0x60c900c3,0x23e7000d,0x7afa02c0,0x00000000}},	//   _vsem, _сімв, kytt,
  { {0x2c690024,0x7bc15430,0xf7f80047,0x00000000}},	//   _súd_, velu, רזוך_,
  { {0xfe450002,0x9db9000d,0x7afa0072,0x00000000}},	//   јнио, тыку_, dytt,
  { {0xb8820080,0x3f85007d,0x7bc15431,0x00000000}},	//   říze, _telu_, telu,
  { {0x5e870088,0xd13802d8,0x3b850121,0x00000000}},	//   _будз, _схс_, шлог,
  { {0x16050161,0x225f0150,0x7bc1000c,0x00000000}},	//   रसार_, _kiuk_, relu,
  { {0x186a1b79,0x7bc1157b,0xe9a601e2,0x00000000}},	//   ками_, selu, шамп,
  { {0x39490045,0xdb0a004d,0x6aa11b25,0x00000000}},	//   _czas_, _abfä, sulf,
  { {0x7afa05dd,0x9836000d,0xbd440021,0x00000000}},	//   bytt, рэмі, _انهي,
  { {0x9f4500cd,0xe73a5432,0x7a3d013d,0x00000000}},	//   _dolç_, тев_, vétv,
  { {0x673e011b,0x2aba009a,0x00000000,0x00000000}},	//   _vypj, _ימצא,   ,
  { {0xd46706cb,0xa3d10053,0x63860002,0x00000000}},	// [a600] иите_, वयं_, игаа,
  { {0xa68607ed,0x00000000,0x00000000,0x00000000}},	//   _клод,   ,   ,
  { {0x213f0089,0x75f8013d,0xa79b009a,0x00000000}},	//   _ayuh_, _bízt, _בשיח,
  { {0xdb1801da,0x2fd7007e,0x20053482,0x00000000}},	//   _navý, یوند_, _alli_,
  { {0xdb1a2d7a,0xab5c008f,0x236708ed,0x00000000}},	//   vetí, ieļa, žnja_,
  { {0x7afa00fe,0x6037000d,0xd0370054,0x00000000}},	//   yytt, апіў_, азії_,
  { {0x9e06150a,0x42d50e74,0xcf89005d,0x00000000}},	//   ичил, _літу, ائهٔ_,
  { {0x97570063,0x7afa0072,0x66f7009f,0x00000000}},	//   סיקו_, vytt, ימצא_,
  { {0xafe62724,0x442a0150,0x4fa60086,0x00000000}},	//   _коал, _kjb_, _визв,
  { {0x34b7014e,0x629e5433,0x7afa190c,0x00000000}},	//   ספים_, orpo, tytt,
  { {0x5a35005a,0x1b18000d,0x8aa30928,0x00000000}},	//   йнот, ужны_, оряд,
  { {0xf2d300b5,0x201c00c2,0x7afa01e1,0x00000000}},	//   קער_, livi_, rytt,
  { {0x1bd4011c,0x7afa00fe,0x7996001f,0x00000000}},	//   _голя, sytt, _ddyw,
  { {0xd9180121,0x9f4c01c8,0xdb0c0046,0x00000000}},	//   рью_, _lodí_, ókód,
  { {0xc66800e1,0x66f40239,0xa3e00042,0x00000000}},	//   иште_, опру, थाई_,
  { {0x7a28005b,0x201c5434,0x8c3d3039,0x00000000}},	//   nıtl, hivi_, puşc,
  { {0xf3670581,0x24f80895,0x8c3d18ad,0x00000000}},	// [a610] атен, анты_, luşa,
  { {0x201c01b3,0x224d5435,0x04c80044,0x00000000}},	//   jivi_, _shek_, ؤولي_,
  { {0x93190021,0xdb1a00cd,0x8c3d005b,0x00000000}},	//   دقاء_, netà, nuşa,
  { {0x7a3d11f5,0xdb010093,0x442a5436,0x00000000}},	//   pétu, rflø, _ejb_,
  { {0x8387122b,0x4615005d,0x75f8013d,0x00000000}},	//   _выбе, _نوگر, _vízt,
  { {0x386900e3,0x7e6805b9,0x25a951b2,0x00000000}},	//   _muar_, _budp, lgal_,
  { {0x38690397,0xa2940086,0x92945437,0x00000000}},	//   _luar_, _марі, _марц,
  { {0x7db4000d,0xf2d20047,0x25a95438,0x00000000}},	//   осьц, _צען_, ngal_,
  { {0xed5900c2,0x61ed0072,0x201c0130,0x00000000}},	//   režo_, öalu, bivi_,
  { {0x321d0051,0x5fae0042,0x5ac901ce,0x00000000}},	//   liwy_, _घायल, глом_,
  { {0x3946001c,0x00000000,0x00000000,0x00000000}},	//   _šos_,   ,   ,
  { {0x8a390062,0x4dd40044,0x60db5439,0x00000000}},	//   ияят_, _وتنس, _krum,
  { {0x2a600019,0xa9230062,0x39360085,0x00000000}},	//   _viib_, здял, сэнс,
  { {0x186741b8,0x6d4b543a,0x25a94331,0x00000000}},	//   сари_, _izga, egal_,
  { {0x2bb80021,0xe45f0137,0x1a650043,0x00000000}},	//   _خانة_, _esök_, _دیجی_,
  { {0x0566005a,0x201c074f,0x38690139,0x00000000}},	//   сван, zivi_, _fuar_,
  { {0x7a3d0026,0x8b030080,0xe3ba0ab1,0x00000000}},	// [a620] rétt, ěřuj, лба_,
  { {0x69c6543b,0x25a90b66,0x7a280075,0x00000000}},	//   leke, agal_, zıtl,
  { {0x69c6016d,0x7a28005b,0x7a3d543c,0x00000000}},	//   oeke, yıtl, métr,
  { {0xdb1a543d,0x7a3d543e,0x60db543f,0x00000000}},	//   netá, létr, _brum,
  { {0x201c150d,0x465700b5,0x74fa000d,0x00000000}},	//   tivi_, _לױטן_, _сэнс_,
  { {0x7a3d236b,0x201c0003,0x7644005b,0x00000000}},	//   nétr, uivi_, lliy,
  { {0x3246000a,0x69c65440,0x6f1e0066,0x00000000}},	//   _гевг, keke, ĺpco,
  { {0x201c3834,0x69c600fe,0x26d8017d,0x00000000}},	//   sivi_, jeke, ivro_,
  { {0x44441d8d,0x443a10da,0xdceb0078,0x00000000}},	//   ol_, oop_, _megė,
  { {0x7a28005b,0x443a5441,0xda7a2a35,0x00000000}},	//   sıtl, nop_, лям_,
  { {0x7644132d,0xe3b30047,0x9fbd0051,0x00000000}},	//   kliy, לױז_, ałów_,
  { {0x44440199,0x3f8e0009,0x3861007d,0x00000000}},	//   hl_, lafu_, _sihr_,
  { {0x443a5442,0x63bc0606,0x244f0058,0x00000000}},	//   kop_, _obrn, lüme_,
  { {0x4444285b,0x3f8e001f,0x25a9002b,0x00000000}},	//   jl_, nafu_, wgal_,
  { {0x8c1b0063,0x629800ea,0x69c65443,0x00000000}},	//   _תווי, ávol, beke,
  { {0x3f8e4c9d,0x44443cd8,0xdd080066,0x00000000}},	//   hafu_, el_, _môžm,
  { {0x60c401f7,0xf3ff017d,0xd37b0121,0x00000000}},	// [a630] çiml, _quão_, гче_,
  { {0x76445444,0x7c3a5445,0x7c285446,0x00000000}},	//   aliy, notr, nndr,
  { {0x236700c2,0x76440058,0x7c285447,0x00000000}},	//   žnjo_, bliy, indr,
  { {0xddc10529,0x44445448,0x7c3a5449,0x00000000}},	//   _mulţ, al_, hotr,
  { {0x4444001f,0x7c3a544a,0x20550899,0x00000000}},	//   bl_, kotr, откр,
  { {0xd006026b,0x7c3a007d,0x5fd40062,0x00000000}},	//   жеше_, jotr, зцъф,
  { {0x69c600ea,0x7e62544b,0x57fc009a,0x00000000}},	//   yeke, _biop, רלוו,
  { {0x60db0498,0x7c28544c,0x660d0072,0x00000000}},	//   _trum, endr, nhak,
  { {0x3f8e0035,0x69c600ea,0xdb1a05b9,0x00000000}},	//   bafu_, veke, netæ,
  { {0x0c360021,0x69c6006f,0x6d4b00c2,0x00000000}},	//   يكية_, weke, _vzga,
  { {0x2fc7544d,0x69c6544e,0xdcfb0006,0x00000000}},	//   meng_, teke, mbuč,
  { {0x3ea70268,0xe0c7006a,0x6f0b005b,0x00000000}},	//   munt_, وز_, ımcı,
  { {0x44440080,0x443a002c,0x26c100ac,0x00000000}},	//   yl_, yop_, _apho_,
  { {0x69c6000f,0x2fc70370,0x290c0051,0x00000000}},	//   seke, neng_, ąda_,
  { {0xdb1a017d,0xdb0100bd,0x44443f9b,0x00000000}},	//   petá, nflü, vl_,
  { {0x2fc700bb,0xf506000a,0x76440035,0x00000000}},	//   heng_, озбо, uliy,
  { {0x2fc700a4,0x9f880026,0x4444544f,0x00000000}},	// [a640] keng_, kóði_, tl_,
  { {0xa3e70235,0x76560072,0x44445450,0x00000000}},	//   भाष_, smyy, ul_,
  { {0x2fc700bb,0x3ea70268,0x443a1d74,0x00000000}},	//   deng_, junt_, rop_,
  { {0x660d0122,0xc6930047,0x64450455,0x00000000}},	//   chak, _קאר_, alhi,
  { {0x7c285451,0x6e3b04bc,0x6e295452,0x00000000}},	//   yndr, doub, dneb,
  { {0x2bae0394,0x2fc70bad,0x7e620123,0x00000000}},	//   ज्ञा, geng_, _siop,
  { {0x2327011c,0x3f8e0035,0x7e621cd4,0x00000000}},	//   _дори_, rafu_, _piop,
  { {0xdcba005a,0x6e295453,0x66040ab6,0x00000000}},	//   ащо_, gneb, nkik,
  { {0xf653014e,0x7c3a5454,0xddc9008f,0x00000000}},	//   וצה_, totr, kmeņ,
  { {0x60cd13ff,0x7c3a0006,0xdc390058,0x00000000}},	//   çame, uotr, fçıl,
  { {0x66040072,0x6e3b00ac,0x8c3d0058,0x00000000}},	//   kkik, boub, muşl,
  { {0x7c3a116c,0x5ce60021,0x8c3d005b,0x00000000}},	//   sotr, _وكال, luşl,
  { {0xfbcf007e,0x7c3a5455,0x394d01e1,0x00000000}},	//   رتی_, potr, åes_,
  { {0x3945003d,0x6e20053a,0x7d0c0058,0x00000000}},	//   āls_, limb, ılsı,
  { {0x2246006f,0x7d000137,0x4b7b0047,0x00000000}},	//   klok_, lyms, _דאוו,
  { {0x6e20003e,0x660400a4,0x6aa800b9,0x00000000}},	//   nimb, gkik, mudf,
  { {0x19aa0047,0x660d5456,0x7d00069f,0x00000000}},	// [a650] _הױפּ, rhak, nyms,
  { {0x6e200529,0x6604002c,0x660d175d,0x00000000}},	//   himb, akik, shak,
  { {0x6e29001f,0xdb08017d,0x6e205457,0x00000000}},	//   yneb, cedô, kimb,
  { {0xdce9017f,0x7bc8010e,0x6e200035,0x00000000}},	//   zbeđ, hedu, jimb,
  { {0x2fc723a5,0x7bc82d28,0xd1410051,0x00000000}},	//   teng_, kedu, knął_,
  { {0x224600a4,0x6e200089,0xdb01004d,0x00000000}},	//   alok_, eimb, tflü,
  { {0x224628b6,0x60cd0555,0x442116ed,0x00000000}},	//   blok_, çamb, mih_,
  { {0x2fc7002c,0xdb01004d,0x44212e96,0x00000000}},	//   seng_, rflü, lih_,
  { {0xdb1a00fe,0xec760076,0x6e295458,0x00000000}},	//   hetä, ппы_, rneb,
  { {0x442116ea,0x3ea75459,0x7bc8545a,0x00000000}},	//   nih_, punt_, gedu,
  { {0x6e203534,0x661d545b,0xed59008f,0x00000000}},	//   bimb, _omsk, ieži_,
  { {0xdb1a00fe,0xdeba0063,0x44211506,0x00000000}},	//   detä, _למעל, hih_,
  { {0x257c0080,0x44215342,0xa5bb0026,0x00000000}},	//   nálů_, kih_, _ljós,
  { {0x44215342,0x913a0047,0xd7f20021,0x00000000}},	//   jih_, מערק, ركز_,
  { {0x8c3d005b,0x4421545c,0xa3c10053,0x00000000}},	//   nuşm, dih_, ्जन_,
  { {0x8afa014e,0x3e71545d,0x96630160,0x00000000}},	//   _להצי, _mát_, ексе,
  { {0x6604024a,0x98ac008f,0x66d5004c,0x00000000}},	// [a660] rkik, ādē_, týká,
  { {0x6604021f,0x4421545e,0x38b60205,0x00000000}},	//   skik, gih_, mær_,
  { {0xa1c60fe2,0xdb1a01f7,0x3f8c01b3,0x00000000}},	//   збед, retç, _redu_,
  { {0x2372003d,0xdb1a0058,0x7bc80a67,0x00000000}},	//   _šajā_, setç, zedu,
  { {0x200e00f3,0x38b6007a,0x4421014f,0x00000000}},	//   thfi_, nær_, bih_,
  { {0x4421545f,0x6e2005b3,0x3e715460,0x00000000}},	//   cih_, wimb, _bát_,
  { {0xc059148d,0x6e201320,0x3e71008b,0x00000000}},	//   ції_, timb, _cát_,
  { {0x6aa80838,0x6467013d,0x3e71004a,0x00000000}},	//   vudf, _óriá, _dát_,
  { {0x38b600d1,0x6e201aae,0x7c210246,0x00000000}},	//   jær_, rimb, filr,
  { {0x798d2528,0xac180086,0x6e205461,0x00000000}},	//   _seaw, іону_, simb,
  { {0x9f7b0063,0x7c2f0003,0x201e0078,0x00000000}},	//   _הנבח, écra, _imti_,
  { {0x4421082a,0x320600a4,0x69d60d7e,0x00000000}},	//   zih_, nkoy_, _caye,
  { {0x5c06005a,0x386d00e8,0xb5fb06b2,0x00000000}},	//   _няка, êer_, _diál,
  { {0xdb1a024a,0x96050042,0x9d2b009a,0x00000000}},	//   tetä, रस्ट_, _לֵוִ,
  { {0x3bbb0f6d,0x442106bb,0x98be003d,0x00000000}},	//   _המוד, vih_, ātā_,
  { {0x4421017e,0x38b65462,0x69d6107b,0x00000000}},	//   wih_, bær_, _gaye,
  { {0x44215463,0xdb1a004b,0xa5f80a91,0x00000000}},	// [a670] tih_, setä, чету_,
  { {0xb8830080,0x7d1d5464,0x8c3d0058,0x00000000}},	//   říst, ússi, yuşm,
  { {0x8c4100bd,0x44215465,0xed59082a,0x00000000}},	//   äßig, rih_, reži_,
  { {0x44211e2e,0x661d0026,0x200c00ca,0x00000000}},	//   sih_, _umsk, _aldi_,
  { {0x3e71001b,0xa5bb0026,0x442102f7,0x00000000}},	//   _sát_, _fjór, pih_,
  { {0xc4d20063,0x257c004c,0x50640896,0x00000000}},	//   _שגם_, rálů_, нтја,
  { {0x66ff0053,0x6208013d,0x7c215466,0x00000000}},	//   ैनिक_, árló, vilr,
  { {0xf2d20ee1,0x8c3d0058,0x200c0046,0x00000000}},	//   _בעל_, ruşm, _eldi_,
  { {0x4c35000d,0x62340092,0x69d65467,0x00000000}},	//   дэнт, _чету, _raye,
  { {0x69d6005b,0x3e710013,0x61fb5468,0x00000000}},	//   _saye, _tát_, _houl,
  { {0x69d61cac,0x61fb2f55,0xff530021,0x00000000}},	//   _paye, _koul, _أخذ_,
  { {0x61fb00fe,0x29020051,0x38b602ab,0x00000000}},	//   _joul, tyka_, tær_,
  { {0x9f5800ea,0x61fb04bc,0x6d4f0058,0x00000000}},	//   özök_, _moul, ücad,
  { {0xb5fb006d,0x60c4005b,0x38b60093,0x00000000}},	//   _diám, çimi, rær_,
  { {0xa3e70053,0x6fbf0042,0xf743202f,0x00000000}},	//   भाई_, ल्यू, веро,
  { {0x2378074f,0xdbcc0026,0x61fb5469,0x00000000}},	//   _sfrj_, lóðu, _noul,
  { {0x75d30021,0x89eb0063,0x98560121,0x00000000}},	// [a680] ضيلا, _וַיֵ, _отош,
  { {0x61e919f2,0x2d8f546a,0xdb010014,0x00000000}},	//   _anel, _lege_, rglæ,
  { {0x6b9c017d,0x61fb546b,0x316a546c,0x00000000}},	//   órgi, _boul, ошло_,
  { {0x61fb04bc,0x2d8f546d,0x6f030051,0x00000000}},	//   _coul, _nege_, dync,
  { {0x61fb0164,0xa5bb0014,0xdbcc0014,0x00000000}},	//   _doul, _tjór, kóðu,
  { {0xd12f007e,0xdbcc0014,0x60cd0075,0x00000000}},	//   جمه_, jóðu, çama,
  { {0x61fb1db7,0xe7c00042,0xdb01181a,0x00000000}},	//   _foul, श्यप, nglä,
  { {0x3ea00be1,0x20070052,0x61fb546e,0x00000000}},	//   čit_, akni_, _goul,
  { {0xdca30001,0xab5c008f,0x5e4300de,0x00000000}},	//   вањи, meļi, خَيْ,
  { {0xb87b006d,0x2007099e,0x61fb006c,0x00000000}},	//   nvíe, ckni_, _zoul,
  { {0x78a6546f,0xfff5007e,0xed5900a8,0x00000000}},	//   erkv, _سکوت_, dežu_,
  { {0x7de50054,0x1ea90044,0x00000000,0x00000000}},	//   _піід, _رامي_,   ,
  { {0x6ba701e1,0x9cb30044,0x00000000,0x00000000}},	//   ærgå, _لمنت,   ,
  { {0x2d8f006f,0x236702f7,0x68e00046,0x00000000}},	//   _zege_, žnji_, æmda,
  { {0x683f0080,0xc5fb000a,0x78a6004b,0x00000000}},	//   vádě, оѓа_, arkv,
  { {0x7bda5470,0xf487173e,0x7bd85471,0x00000000}},	//   ldtu, дужн, _havu,
  { {0x61fb5472,0x7bd822c7,0xdb110014,0x00000000}},	// [a690] _roul, _kavu, úgöl,
  { {0x61e90179,0x7bda5473,0x61fb5474,0x00000000}},	//   _snel, ndtu, _soul,
  { {0x7bd80035,0x61fb5475,0x08f8005d,0x00000000}},	//   _mavu, _poul, _فریب_,
  { {0x50b50076,0x6aba0137,0xe4a701ce,0x00000000}},	//   еску, ittf, _орго,
  { {0x61fb03b2,0x68290066,0x2d8f21cc,0x00000000}},	//   _voul, ažde, _rege_,
  { {0x61fb0037,0xd0110021,0x2d8f00be,0x00000000}},	//   _woul, طلع_, _sege_,
  { {0x20070026,0x2d8f00b9,0x61fb0510,0x00000000}},	//   rkni_, _pege_, _toul,
  { {0x61e95476,0x63ad000c,0xd0d50062,0x00000000}},	//   _unel, şină, _побъ,
  { {0x6f033f61,0xc03502d8,0x2b475477,0x00000000}},	//   sync, _знај, _sync_,
  { {0xaf070fe2,0x2d8f00bd,0xee870085,0x00000000}},	//   _очек, _wege_, _жыдо,
  { {0x8c3d003b,0x0c220085,0x5f9404c3,0x00000000}},	//   nuşi, умэн, _рихт,
  { {0x7afc00c7,0xb5fb013d,0xc33203c3,0x00000000}},	//   ärta, _diák, רוט_,
  { {0xa3c10053,0xed59007d,0x487a0062,0x00000000}},	//   ्जा_, težu_, ясня_,
  { {0x7bd80006,0x660f5478,0x3d180053,0x00000000}},	//   _gavu, _alck, _बेटे_,
  { {0x96560001,0x2cad00e5,0xed59007d,0x00000000}},	//   еђај, lued_, režu_,
  { {0xd604005e,0xdb01181a,0x5ee00082,0x00000000}},	//   jедн, rglä, कित्_,
  { {0x2cad0037,0x8c3d003b,0x7bd80058,0x00000000}},	// [a6a0] nued_, euşi, _yavu,
  { {0xa3e70235,0x68e413f4,0x69cb0046,0x00000000}},	//   भाग_, _irid, _ðger,
  { {0xd3b50062,0xa3c10053,0x826a0121,0x00000000}},	//   ъсть, ्ज़_, чаев_,
  { {0x7afc000e,0x68e401e1,0xda100042,0x00000000}},	//   ørti, _krid, ासित_,
  { {0x63ab0080,0xab630022,0xd132005d,0x00000000}},	//   álné, ążym, دمش_,
  { {0xe8d9008b,0x6aba0137,0x889b0063,0x00000000}},	//   _ngờ_, yttf, לבני,
  { {0xa2e307da,0x69c45479,0x8f340121,0x00000000}},	//   _йорд, _obie, ъекц,
  { {0x387f000c,0x7bd8547a,0x68e400a4,0x00000000}},	//   ţuri_, _savu, _orid,
  { {0x2cad0034,0xed57005e,0x5d540062,0x00000000}},	//   gued_, ноћ_, ъкит,
  { {0x69c4547b,0x7bda00ea,0xe0d715ce,0x00000000}},	//   _abie, udtu, _яву_,
  { {0x62580027,0xf4130063,0x645e133c,0x00000000}},	//   ríof, רפת_, impi,
  { {0xdc1201f7,0xb87b0080,0xc33301f9,0x00000000}},	//   rşıl, jvíc, טות_,
  { {0x68e40268,0x7ae3004d,0x6dc60066,0x00000000}},	//   _crid, _ernt, _vďač,
  { {0xdb1a00d1,0x68e400f1,0x9cd70aeb,0x00000000}},	//   ketø, _drid, _נווה_,
  { {0x05870001,0x35e7000d,0x69da008f,0x00000000}},	//   еузм, нцав, ēter,
  { {0x62580025,0x9f450058,0xaa580121,0x00000000}},	//   níod, _rolü_, _пищу_,
  { {0x68e4547c,0x69cf25a1,0xdb01004d,0x00000000}},	// [a6b0] _grid, mece, uflö,
  { {0x69c406ce,0x69cf547d,0xdb0101bb,0x00000000}},	//   _zbie, lece, rflö,
  { {0x78bd00bd,0xdb1a00b9,0x69c40022,0x00000000}},	//   ltsv, getø, _ybie,
  { {0x69dd547e,0x60cd017d,0x78bd0137,0x00000000}},	//   ndse, çamo, otsv,
  { {0xd3a7000a,0x764d005b,0x69dd547f,0x00000000}},	//   _првп, mlay, idse,
  { {0x60080086,0x69cf017d,0x78bd004d,0x00000000}},	//   ннім_, hece, itsv,
  { {0x764d005b,0x69cf5480,0x10140021,0x00000000}},	//   olay, kece, دبند,
  { {0x69dd006f,0x764d1b89,0x7ceb0014,0x00000000}},	//   jdse, nlay, jörð,
  { {0x764d0397,0x69cf5481,0xe7b20042,0x00000000}},	//   ilay, dece, _जालप,
  { {0x2367017f,0x69dd0933,0x7a2b0072,0x00000000}},	//   žnju_, edse, yötä,
  { {0x764d01f7,0x2cad0034,0x9f45006d,0x00000000}},	//   klay, sued_, _voló_,
  { {0xf2d200b5,0x69cf0150,0x78bd0611,0x00000000}},	//   בעט_, gece, ftsv,
  { {0x764d5482,0xc19a0063,0x6aa8006f,0x00000000}},	//   dlay, ושרי, ardf,
  { {0x394c001c,0x764d20a1,0x68e408a9,0x00000000}},	//   āds_, elay, _vrid,
  { {0x69cf0942,0x78bd10ce,0xf746047e,0x00000000}},	//   bece, atsv, тево,
  { {0x764d330d,0x69c44c36,0x7b07008f,0x00000000}},	//   glay, _ubie, īstī,
  { {0x05660818,0xc5660002,0x04460131,0x00000000}},	// [a6c0] тван, ткак, веан,
  { {0x764d3ba0,0x7bc12bb5,0x645e5483,0x00000000}},	//   alay, nflu, umpi,
  { {0xe73a0076,0x645e00ac,0x6d4b002b,0x00000000}},	//   _цен_, rmpi, _lyga,
  { {0xd7b20053,0xdb1a000e,0xb87b006d,0x00000000}},	//   _जाँच, retø, lvía,
  { {0x8c3d005b,0x216706b4,0x600f01e1,0x00000000}},	//   luşu, вици_, _søma,
  { {0x9f650024,0x6383026b,0xb87b006d,0x00000000}},	//   _štát_, _вгра, nvía,
  { {0x69cf01f7,0x69dd00b9,0xf7730063,0x00000000}},	//   yece, ydse, סקה_,
  { {0x444408c9,0xade301dd,0x3eae004d,0x00000000}},	//   lo_, ацьк, ruft_,
  { {0x7ceb0026,0x69cf5484,0x62581c30,0x00000000}},	//   vörð, vece, ríod,
  { {0x62580025,0x44445485,0x7afc0137,0x00000000}},	//   síod, no_, ärto,
  { {0x60140268,0x764d005b,0x6d4f0080,0x00000000}},	//   _càme, ylay, ýcar,
  { {0x78bd0303,0xa5bb0066,0x44445486,0x00000000}},	//   ttsv, _amón, ho_,
  { {0x984b0062,0x44443297,0x69dd49dc,0x00000000}},	//   дява_, ko_, rdse,
  { {0x3e78000f,0x69cf5487,0x44445488,0x00000000}},	//   _két_, sece, jo_,
  { {0x3e7800ea,0x44441c43,0x764d2d12,0x00000000}},	//   _jét_, do_, tlay,
  { {0x44440027,0x3e78008b,0x3ce6007c,0x00000000}},	//   eo_, _mét_, _krov_,
  { {0x44445489,0x764d27da,0x68290078,0x00000000}},	// [a6d0] fo_, rlay, ažda,
  { {0xf8bf548a,0x764d548b,0x4444548c,0x00000000}},	//   mté_, slay, go_,
  { {0xf8bf0164,0x8c3d005b,0x60c92866,0x00000000}},	//   lté_, muşt, _spem,
  { {0x8c3d005b,0x68e2001c,0xe9df548d,0x00000000}},	//   luşt, _šodi, ndú_,
  { {0x4444548e,0xe3b0006a,0xf8bf548f,0x00000000}},	//   bo_, _ژرف_, nté_,
  { {0xf8bf0164,0x628547c9,0x44230150,0x00000000}},	//   ité_, ppho, _umj_,
  { {0xa294000d,0x660d149f,0x7afc00a5,0x00000000}},	//   _васі, okak, ärtl,
  { {0x64455490,0x8db5000d,0xe9df0066,0x00000000}},	//   lohi, ускі, jdú_,
  { {0x626c000c,0xb5fb017d,0x660d23f4,0x00000000}},	//   _uşoa, _fiáv, ikak,
  { {0x99820080,0xabd50d34,0x64455491,0x00000000}},	//   tiků_, уциј, nohi,
  { {0x6d4b0051,0xdd91007e,0xf8bf0003,0x00000000}},	//   _wyga, _هوا_, eté_,
  { {0x44445492,0x62580139,0x7bc104a7,0x00000000}},	//   zo_, míoc, sflu,
  { {0x62580025,0x44445493,0xc985005e,0x00000000}},	//   líoc, yo_, јуџи,
  { {0x315600b5,0x3e710024,0x6e2900bd,0x00000000}},	//   טירן_, _ešte_, lieb,
  { {0x3e78001b,0x1b490086,0x644500a4,0x00000000}},	//   _xét_, _язки_, dohi,
  { {0x660d00bb,0x44445494,0x8c3d18ad,0x00000000}},	//   gkak, wo_, ruşu,
  { {0x7d0916cb,0xf8bf0164,0x7d1b5495,0x00000000}},	// [a6e0] nyes, cté_, nzus,
  { {0x660d002c,0x6e29004d,0x64452133,0x00000000}},	//   akak, hieb, gohi,
  { {0x7996359a,0x2cbf0004,0x41aa0189,0x00000000}},	//   _keyw, htud_, евен_,
  { {0x44442c21,0x660d0137,0x3e785496,0x00000000}},	//   so_, ckak, _rét_,
  { {0x6736001c,0x3e780013,0x44445497,0x00000000}},	//   šajā, _sét_, po_,
  { {0x444400ac,0x799600a4,0xddcb2401,0x00000000}},	//   qo_, _leyw, _figū,
  { {0x62580027,0x6d5d0026,0xf8b10053,0x00000000}},	//   ríob, ýsan, _जम्प,
  { {0x3ce65498,0x6e295499,0x7c28004d,0x00000000}},	//   _prov_, gieb, widr,
  { {0xb8820080,0x629e48b4,0xc19b0063,0x00000000}},	//   říje, lspo, _רשמי,
  { {0x610a003d,0xc4d30063,0xd12f08aa,0x00000000}},	//   _vēlā, צגת_, _عمل_,
  { {0x5a35036a,0x645c001f,0x799600ac,0x00000000}},	//   инот, _mhri, _beyw,
  { {0xe9df0024,0x629e15dd,0x9d9a0021,0x00000000}},	//   udú_, ispo, _أنشئ_,
  { {0xf8bf0164,0x64450035,0xad8b0063,0x00000000}},	//   uté_, yohi, _נְאֻ,
  { {0xf8bf0164,0x1cb70063,0x62810003,0x00000000}},	//   rté_, _עלול_, _élog,
  { {0x6b9a549a,0xdce001f7,0x8c3d005b,0x00000000}},	//   matg, mamı, ruşt,
  { {0xdce001f7,0xf8bf0164,0x6b9a00cd,0x00000000}},	//   lamı, pté_, latg,
  { {0x645c0025,0x9f5e0003,0x6445549b,0x00000000}},	// [a6f0] _bhri, _doté_, tohi,
  { {0x6b9a0268,0xdce0005b,0x660d549c,0x00000000}},	//   natg, namı, skak,
  { {0x6b9a00cd,0x7c2f0003,0x644523ff,0x00000000}},	//   iatg, écri, rohi,
  { {0xa2940086,0xdb1a0022,0x92940085,0x00000000}},	//   саці, letó, сацц,
  { {0x6b9a00b9,0x759a0063,0xdce0005b,0x00000000}},	//   katg, _בסרג, kamı,
  { {0x287c00b5,0x62580025,0x645c0025,0x00000000}},	//   ענומ, tíoc, _ghri,
  { {0x6e295193,0xf2e40086,0x224619b5,0x00000000}},	//   tieb, _люто, book_,
  { {0x62580027,0x82370032,0x7d1b0a67,0x00000000}},	//   ríoc, _إرسا, tzus,
  { {0xc2120063,0x7e7d003b,0x6e29549d,0x00000000}},	//   _והן_, _ăspu, rieb,
  { {0xb5fb0025,0x7d1b00bd,0x60db00a4,0x00000000}},	//   _fhág, rzus, _isum,
  { {0x7d1b3c11,0x2cbf0019,0xdd99027d,0x00000000}},	//   szus, stud_, paň_,
  { {0x26da0089,0xb87b240a,0xaa460200,0x00000000}},	//   _rspo_, rvín, ремл,
  { {0xc956026c,0xdce00058,0x7c84005e,0x00000000}},	//   ртны, bamı, _лује,
  { {0x7d0600fe,0xb8ee0053,0x60db05b3,0x00000000}},	//   äkse, _रह_, _msum,
  { {0xa596005a,0x9f5e549e,0x601f0078,0x00000000}},	//   иращ, _poté_, _išmė,
  { {0x78a90fbf,0x645c549f,0x600f00d1,0x00000000}},	//   ševa, _shri, _søml,
  { {0x3ce80053,0x645c46b8,0x9f5e0003,0x00000000}},	// [a700] जिये_, _phri, _voté_,
  { {0x2cad423a,0x629e54a0,0x389b0149,0x00000000}},	//   ired_, tspo, _שיינ,
  { {0x032600d7,0x60db54a1,0x2cad001f,0x00000000}},	//   јден, _asum, hred_,
  { {0x629e0102,0xea8c0047,0x600f06a5,0x00000000}},	//   rspo, גנאָ, _dømm,
  { {0xdce0005b,0x629e1110,0x645c2854,0x00000000}},	//   yamı, sspo, _thri,
  { {0xa2e60055,0x4ea6047e,0x629e1860,0x00000000}},	//   _когд, ариа, pspo,
  { {0x6d5900e3,0x99990024,0x2cad0034,0x00000000}},	//   _azwa, losť_, ered_,
  { {0xadf4000a,0x4cb80121,0x2cad0136,0x00000000}},	//   спиш, глию_, fred_,
  { {0x99990024,0x6b9a0268,0x6d590051,0x00000000}},	//   nosť_, tatg, _czwa,
  { {0x61e2000f,0xbea6013c,0x6142004c,0x00000000}},	//   ldol, _важк, _cílů,
  { {0x6b9a0268,0x2cad0034,0x3377009a,0x00000000}},	//   ratg, ared_, יעים_,
  { {0x6b9a0268,0x99990066,0x2cad54a2,0x00000000}},	//   satg, kosť_, bred_,
  { {0x2cad1930,0x61e0075a,0x6b9a54a3,0x00000000}},	//   cred_, _maml, patg,
  { {0x61e2024a,0x99990024,0x60c20006,0x00000000}},	//   hdol, dosť_, itom,
  { {0xdb1a0016,0x96270002,0x60c20072,0x00000000}},	//   retó, аќал, htom,
  { {0x600f05e7,0x60c254a4,0xbafb03c3,0x00000000}},	//   _rømm, ktom, _יהוש,
  { {0x61e2001f,0x04950593,0x3f9c54a5,0x00000000}},	// [a710] ddol, صلاح, kavu_,
  { {0x799d00a4,0x3f9c04c9,0x4427008b,0x00000000}},	//   lasw, javu_, òn_,
  { {0xb5fb54a6,0x2cad54a7,0x636b005e,0x00000000}},	//   _diár, zred_, траг_,
  { {0x600f04aa,0x61e20c5f,0xaaa90042,0x00000000}},	//   _vømm, gdol, _किसक,
  { {0x8467011c,0xddc20051,0x95380121,0x00000000}},	//   _въве, _okoł, _взят_,
  { {0x6b9800c2,0x600f01f2,0xdfd10021,0x00000000}},	//   _nevg, _tømm, سيع_,
  { {0x6d590051,0x60c2232c,0xbec7008f,0x00000000}},	//   _szwa, atom, ksīš,
  { {0x61e031c8,0x62580025,0xed59026c,0x00000000}},	//   _gaml, líon, лой_,
  { {0xa3ab0053,0x60db09c9,0x4c82026c,0x00000000}},	//   _गया_, _usum, плыв,
  { {0x2cad0034,0x62580025,0xbad5000d,0x00000000}},	//   rred_, níon, бімы,
  { {0x4a460d82,0x1f140044,0xbb451dc6,0x00000000}},	//   йнов, _وبمج, сенк,
  { {0x2005001f,0x2cad410b,0x62580025,0x00000000}},	//   _holi_, pred_, híon,
  { {0x200500c3,0x6c850021,0x27e14fb8,0x00000000}},	//   _koli_, _التم, _bahn_,
  { {0x99990024,0x4b790047,0xeb990062,0x00000000}},	//   vosť_, _גאַו, _сик_,
  { {0x61e2339c,0xdb01004d,0x200554a8,0x00000000}},	//   ydol, nglü, _moli_,
  { {0x99990024,0x3f9c1964,0x6aa32f6d,0x00000000}},	//   tosť_, zavu_, _ivnf,
  { {0x61e000e3,0x05560062,0x4d7a0041,0x00000000}},	// [a720] _raml, ствя, אָבא,
  { {0x60c200c3,0x61e01bbc,0x68fb0063,0x00000000}},	//   vtom, _saml, _עליה,
  { {0xe80d0053,0xe9df00cd,0x60c2395e,0x00000000}},	//   _सकता_, clús_, wtom,
  { {0x60c254a9,0x7afc00bd,0xe2970001,0x00000000}},	//   ttom, ärti, сац_,
  { {0x20050024,0x61e235b1,0x987a0041,0x00000000}},	//   _boli_, rdol, נאַט,
  { {0x660654aa,0x8fa3005e,0x20054655,0x00000000}},	//   _hokk, паље, _coli_,
  { {0x66060004,0x6ab60161,0x8fa354ab,0x00000000}},	//   _kokk, _अमेर, чаје,
  { {0xdb01007a,0x53370047,0x6b980058,0x00000000}},	//   uglý, _האלב_, _sevg,
  { {0x91030002,0x200500a3,0x8fa654ac,0x00000000}},	//   _епте, _foli_, _газе,
  { {0xb5fb001b,0xdbf00080,0x60110026,0x00000000}},	//   _khác, _tříd, rðmæ,
  { {0x0dca019d,0x39400034,0xe9f90097,0x00000000}},	//   _були_, _axis_, анні_,
  { {0x6606007a,0x78600137,0xb5fb0139,0x00000000}},	//   _nokk, hövd, _mhác,
  { {0xa3b80053,0x8c461810,0x799d54ad,0x00000000}},	//   छला_, _леде, rasw,
  { {0xd9180076,0x7af70014,0x7bc7004b,0x00000000}},	//   сью_, óatí, õjut,
  { {0x799d0035,0xdb1e00fe,0x66061ecb,0x00000000}},	//   pasw, ävän, _bokk,
  { {0x442a0c3f,0x95d9000a,0xb5fb0025,0x00000000}},	//   _amb_, јдат_, _sháb,
  { {0x26c300c3,0x53990076,0xc3990086,0x00000000}},	// [a730] stjo_, ивая_, икає_,
  { {0xb3670076,0x7e7a54ae,0x68ed54af,0x00000000}},	//   бъек, _outp, _irad,
  { {0x62580027,0x68ed0114,0xb5fb039f,0x00000000}},	//   ríon, _hrad, _chác,
  { {0x3abb0047,0x62580025,0x6606006f,0x00000000}},	//   רמאנ, síon, _gokk,
  { {0xb5fb0025,0x200554b0,0xb87b004c,0x00000000}},	//   _tháb, _poli_, dvík,
  { {0x68ed0035,0xa295126b,0x442a29d6,0x00000000}},	//   _mrad, _магі, _gmb_,
  { {0x8db50054,0x200554b1,0xc7b40041,0x00000000}},	//   оспі, _voli_, לבס_,
  { {0xf2d200b5,0x62580027,0x786000c7,0x00000000}},	//   _קען_, níol, möve,
  { {0xee360088,0x78600137,0x23c60053,0x00000000}},	//   ўны_, löve, र्वद,
  { {0xeb990001,0x5ac90133,0x00000000,0x00000000}},	//   шио_, алом_,   ,
  { {0x68ed005b,0x78a9007d,0xdddb0051,0x00000000}},	//   _arad, ševl, rmuł,
  { {0xdd1e0080,0x68ed4473,0xd910005d,0x00000000}},	//   _síťo, _brad, فیع_,
  { {0x786001e3,0x7e7a26ad,0x68ed54b2,0x00000000}},	//   höve, _zutp, _crad,
  { {0xcb690095,0x68ed54b3,0x78600ed5,0x00000000}},	//   _кале_, _drad, köve,
  { {0xba3d0006,0x66e31657,0x7860013d,0x00000000}},	//   grįs, мора, jöve,
  { {0x2d9f00bd,0x78a40f1b,0x68ed54b4,0x00000000}},	//   naue_, _tviv, _frad,
  { {0x644300c3,0x68ed54b5,0xe4060c46,0x00000000}},	// [a740] čnin, _grad, озап,
  { {0xb5fb008d,0xa5bb0022,0x3e710130,0x00000000}},	//   _phác, _omów, _ošto_,
  { {0x442a004d,0xf428004d,0x86460988,0x00000000}},	//   _vmb_, emäß_, _множ,
  { {0x660600fe,0x4b4c0047,0x3f85003b,0x00000000}},	//   _uokk, נגאַ, _aflu_,
  { {0x3e711fc3,0x95880006,0x10a3278e,0x00000000}},	//   _ašto_, grąž, дичн,
  { {0xf503000d,0xb5fb008b,0xeeaa0bf5,0x00000000}},	//   _ўзро, _thác, атик_,
  { {0xb87b0014,0xddc90022,0xdb1a1ac3,0x00000000}},	//   tvík, kleń, letö,
  { {0x2dd3005a,0x6ca60376,0x614606b4,0x00000000}},	//   джър, орож, _деба,
  { {0x62580025,0xbc77007f,0x1d3401a4,0x00000000}},	//   níom, обых_, яния,
  { {0x8c430138,0x69cd001f,0x9b6a0ae8,0x00000000}},	//   мење, _sbae, ишна_,
  { {0xa5bb017d,0x3b540062,0x8ae60085,0x00000000}},	//   _imóv, якор, ціпл,
  { {0x68ed00eb,0xba2b0086,0x25a054b6,0x00000000}},	//   _prad, ріод_, jail_,
  { {0xcd36006a,0x7860000f,0xed572aeb,0x00000000}},	//   _براب, zöve, _доц_,
  { {0xf1150047,0x7c2a1c7d,0xb8670044,0x00000000}},	//   פֿרי_, _umfr, تاجو,
  { {0xdb4f0086,0x25a0160b,0x6595183e,0x00000000}},	//   _цю_, fail_, забу,
  { {0x7afc0004,0xddc20051,0x25a054b7,0x00000000}},	//   ärtu, _ukoń, gail_,
  { {0xd37b2f57,0xb5fb0139,0x68ed4d11,0x00000000}},	// [a750] аче_, _cháa, _urad,
  { {0x7c3a0c29,0x78600b6e,0xa3d41406,0x00000000}},	//   nntr, töve, моуч,
  { {0x25a00027,0x7c3a54b8,0x321d002b,0x00000000}},	//   bail_, intr, thwy_,
  { {0x25a00027,0x92590076,0x2bca0053,0x00000000}},	//   cail_, щает_, ़्ता,
  { {0xc5fa014e,0x786040a3,0x443a0150,0x00000000}},	//   _הפרט, söve, bnp_,
  { {0xc0780086,0xdb1a004b,0xd00606da,0x00000000}},	//   ісії_, letõ, зеше_,
  { {0xa195019d,0x82a400e1,0x160f0042,0x00000000}},	//   _навч, _оште, _सवार_,
  { {0x7c3a0568,0x7a3600b2,0x7e6254b9,0x00000000}},	//   entr, ošte, _chop,
  { {0x2d9f004d,0x811918ea,0x7a3654ba,0x00000000}},	//   raue_, _ужас_, nšte,
  { {0x4b252049,0xdb1a004e,0xbfbb0044,0x00000000}},	//   змов, hetõ, _خطرا_,
  { {0xb17d0024,0xc9490063,0xac380085,0x00000000}},	//   _zaťa, _עמ_, ўчых_,
  { {0x7a360006,0x7c3a54bb,0xd9460094,0x00000000}},	//   kšte, antr, земи,
  { {0x25a01db7,0x7e6954bc,0x18a30085,0x00000000}},	//   vail_, mmep, наям,
  { {0x7c94007e,0xdb1a004b,0x7e69078c,0x00000000}},	//   _آشنا, eetõ, lmep,
  { {0x7d0600d1,0x6443027d,0x25a054bd,0x00000000}},	//   øksv, čnil, tail_,
  { {0x6e3b0026,0xdb1a004b,0x25a00139,0x00000000}},	//   nnub, tetö, uail_,
  { {0x7e690035,0x62580025,0x25a054be,0x00000000}},	// [a760] imep, uíom, rail_,
  { {0x2d9d00e8,0x62580025,0xdb1a0bda,0x00000000}},	//   _lewe_, ríom, retö,
  { {0xb77b0063,0x7a3600c2,0x518609da,0x00000000}},	//   _לאיש, ašte, пула,
  { {0xdb1a0019,0x2d9d338a,0x9f5e0139,0x00000000}},	//   petö, _newe_, _notá_,
  { {0xb5fb008b,0x78a654bf,0x2ba6004c,0x00000000}},	//   _khán, nskv, nící_,
  { {0x9326007e,0x6e3b0089,0xaf060121,0x00000000}},	//   _فرزن, enub, зчик,
  { {0x877b0047,0x66160006,0x7e62002b,0x00000000}},	//   זאצי, okyk, _phop,
  { {0x661600eb,0x51b50001,0x66042892,0x00000000}},	//   nkyk, _осуђ, njik,
  { {0x2ba60080,0xd026005a,0x66160078,0x00000000}},	//   jící_, _емай, ikyk,
  { {0xb5fb008b,0x78a6069f,0x2ba6004c,0x00000000}},	//   _nhán, dskv, dící_,
  { {0xddc80078,0xb87b00be,0x1a780085,0x00000000}},	//   _iudž, nvív, юбны_,
  { {0xd337009a,0x1eea0043,0x4efb009d,0x00000000}},	//   לריה_, _پوچی_, _להבו,
  { {0xa2070063,0x09e4000d,0x2ca6027c,0x00000000}},	//   לֶךְ_, хоўн, _uvod_,
  { {0x36d50138,0x7a36034d,0xb5fb008b,0x00000000}},	//   могр, všte, _chán,
  { {0x3f9e00eb,0x7bda54c0,0xddc810f5,0x00000000}},	//   _metu_, metu, _mudž,
  { {0x64430198,0x7bda54c1,0x3f9e54c2,0x00000000}},	//   čnim, letu, _letu_,
  { {0x7bda0019,0xd8bb007e,0xd944005e,0x00000000}},	// [a770] oetu, _ادعا_, _пећи,
  { {0x7a36007d,0xdb1a3a7c,0xa4e4000d,0x00000000}},	//   ršte, setõ, эўск,
  { {0x7bda54c3,0x53340121,0xc2c40044,0x00000000}},	//   ietu, нефт, فيلي,
  { {0x7bda54c4,0x7a36017f,0xe8d9008d,0x00000000}},	//   hetu, pšte, _ngừ_,
  { {0xd009000a,0xddc854c5,0x7bda13b8,0x00000000}},	//   желе_, _budž, ketu,
  { {0x2d9d00ac,0xe0d80054,0x7bda54c6,0x00000000}},	//   _sewe_, яві_, jetu,
  { {0x7bda0004,0x6e3b002c,0x7e69004b,0x00000000}},	//   detu, tnub, tmep,
  { {0x443354c7,0x31c42303,0xcc8904a9,0x00000000}},	//   lix_, _псув, обие_,
  { {0x7bda12a1,0x443300f4,0x78600137,0x00000000}},	//   fetu, oix_, höva,
  { {0x7bda0529,0x2d9d0009,0x3f9e0014,0x00000000}},	//   getu, _wewe_, _getu_,
  { {0x64a2000c,0xa3cf0053,0x600f05e7,0x00000000}},	//   mţiţ, व्य_, _dømt,
  { {0x3f9e0035,0xc7a90ee1,0x44211848,0x00000000}},	//   _zetu_, _כב_, hhh_,
  { {0x3f9e0009,0x6443017f,0x3ea0017f,0x00000000}},	//   _yetu_, čnij, ćite_,
  { {0xdb1a017d,0x7bda478f,0x78a654c8,0x00000000}},	//   tetô, cetu, rskv,
  { {0x661600ac,0x44332335,0xeafb005d,0x00000000}},	//   tkyk, dix_, _درشت_,
  { {0x44330268,0x96550001,0x2ba6004c,0x00000000}},	//   eix_, еђуј, pící_,
  { {0xb5fb001b,0x66160006,0x98be0023,0x00000000}},	// [a780] _thán, rkyk, ātē_,
  { {0x75240089,0x661600fe,0x68e414dd,0x00000000}},	//   rziz, skyk, _isid,
  { {0x68290078,0x1666005e,0xf7461527,0x00000000}},	//   gždu, _овом, _цено,
  { {0x22400019,0x44330803,0xc6930063,0x00000000}},	//   õik_, aix_, _שאר_,
  { {0x7bda0035,0x00da009b,0x00000000,0x00000000}},	//   yetu, تبات_,   ,
  { {0xd0100021,0xd0070001,0xdb01005f,0x00000000}},	//   طلب_, деље_, galë,
  { {0xc3340047,0xa2e30121,0x3f9e0066,0x00000000}},	//   _װוּ_, _иорд, _vetu_,
  { {0xdb0154c9,0x3f9e0035,0x78a91ba3,0x00000000}},	//   palê, _wetu_, ševi,
  { {0xed570138,0x7bda51c7,0xd6570063,0x00000000}},	//   моћ_, tetu, ויקת_,
  { {0x6aba00c7,0xf063000d,0x69c40b6c,0x00000000}},	//   tutf, _акуп, _acie,
  { {0x83b7014e,0x68e4077d,0xaa592d21,0x00000000}},	//   ופיע_, _asid, зину_,
  { {0x7bda0d68,0x7d0600d1,0x7c21004d,0x00000000}},	//   setu, økss, ahlr,
  { {0x200c54ca,0x273c0066,0x7bda54cb,0x00000000}},	//   _kodi_, yšné_, petu,
  { {0x6aba00b9,0x644302e2,0x7bc30025,0x00000000}},	//   putf, čnik, _gcnu,
  { {0x200c54cc,0x45d5050f,0x68e40290,0x00000000}},	//   _modi_, новс, _esid,
  { {0x78600137,0x3e45008f,0x59c60053,0x00000000}},	//   röva, pēte_, _वायर,
  { {0x69dd54cd,0xe53401d5,0x189b0044,0x00000000}},	// [a790] mese, веть, _بضعة_,
  { {0x7a360006,0x200c19d2,0xc86700f2,0x00000000}},	//   mšta, _nodi_, _تطبي,
  { {0xddc80045,0x9295000d,0x68e400ea,0x00000000}},	//   _budż, хаец, _zsid,
  { {0xa294019d,0x69dd54ce,0x201e49ee,0x00000000}},	//   таці, nese, _alti_,
  { {0x629c001f,0x7a3654cf,0x69dd1a6c,0x00000000}},	//   _ewro, nšta, iese,
  { {0x200c54d0,0xb87b007a,0x85740651,0x00000000}},	//   _codi_, lvís, _шлях,
  { {0x63a507c9,0x69dd032e,0x64a2003b,0x00000000}},	//   mahn, kese, rţiţ,
  { {0x261c0027,0x63a5003e,0x7a360006,0x00000000}},	//   _líon_, lahn, kšta,
  { {0x629c0051,0x50f50086,0x69dd54d1,0x00000000}},	//   _zwro, _язат, dese,
  { {0x200c001f,0x78bd0019,0x69c407b9,0x00000000}},	//   _godi_, dusv, _scie,
  { {0x7afc0019,0xb87b0080,0x7a365005,0x00000000}},	//   ärtp, zvít, ešta,
  { {0x200701a6,0x8ed80021,0x69dd54d2,0x00000000}},	//   ljni_, _تذكر_, gese,
  { {0x61e90009,0x78bd0019,0x63a50150,0x00000000}},	//   _mael, gusv, kahn,
  { {0x63a554d3,0x69c40022,0x9f47011b,0x00000000}},	//   jahn, _wcie, edné_,
  { {0x261c0025,0x8c1a0063,0x7a360078,0x00000000}},	//   _díon_, _מוסי, ašta,
  { {0x85b50138,0xb4db00cd,0x69c40051,0x00000000}},	//   кључ, _exàm, _ucie,
  { {0xb4661fa5,0x261c0139,0x63a54d7f,0x00000000}},	// [a7a0] екал, _fíon_, fahn,
  { {0x6fd301f7,0x61fb54d4,0x601400cd,0x00000000}},	//   nıcı, _anul, _tàmi,
  { {0x443154d5,0x3a2054d6,0x23c60053,0x00000000}},	//   _dmz_, _klip_, र्गद,
  { {0x1a9a0047,0x200c54d7,0x2bcf0053,0x00000000}},	//   פינע, _sodi_, त्ता,
  { {0x63a55396,0x083a009d,0x00000000,0x00000000}},	//   bahn, ֔עְל,   ,
  { {0xdb0100cd,0x69dd14e0,0x3e6154d8,0x00000000}},	//   palè, zese, vóta_,
  { {0x200c027c,0x628e04aa,0x11d6071f,0x00000000}},	//   _vodi_, _utbo, _піар,
  { {0xadf40dd5,0x7a360066,0x61e954d9,0x00000000}},	//   тпиш, yšta, _gael,
  { {0x59a70161,0x6d59002b,0x25a2008f,0x00000000}},	//   _ख़बर, _cywa, _mekl_,
  { {0x69dd54da,0x78bd0019,0xf1bf013d,0x00000000}},	//   wese, vusv, _öár_,
  { {0x7a260014,0xe3b30041,0x786000a5,0x00000000}},	//   _mótf, װױר_, tövn,
  { {0xf2d300b5,0x7bc100a4,0xda670021,0x00000000}},	//   נער_, aglu, عادي,
  { {0x63a50150,0x69a20053,0x49740121,0x00000000}},	//   yahn, _ख़री, ллюс,
  { {0x69dd0763,0x3e45001c,0x9f45006c,0x00000000}},	//   sese, mēta_, _salé_,
  { {0x3e45001c,0xc2210053,0x69dd54db,0x00000000}},	//   lēta_, _मतलब_, pese,
  { {0xcf570063,0x63a50052,0x07080021,0x00000000}},	//   גבלת_, wahn, ريقي_,
  { {0x9f470024,0x7a3600c2,0x3e45001c,0x00000000}},	// [a7b0] rdné_, oštn, nēta_,
  { {0x8707000d,0x93880085,0x8d4b009d,0x00000000}},	//   _зяме, есца_, הֲבֵ,
  { {0x63a5014f,0xf8bf0003,0xa8580063,0x00000000}},	//   rahn, lué_, _איזה_,
  { {0x50b50121,0x63a517e5,0x6fd30058,0x00000000}},	//   вску, sahn, zıcı,
  { {0x6fd301f7,0xf8bf0003,0xc0e50098,0x00000000}},	//   yıcı, nué_, толк,
  { {0x61e9001f,0x3e45001c,0x660f0399,0x00000000}},	//   _wael, dēta_, _hock,
  { {0x3ce600c2,0x660f54dc,0xddc20022,0x00000000}},	//   _asov_, _kock, _ukoś,
  { {0xe8d9001b,0x8f140085,0xfe710044,0x00000000}},	//   _ngữ_, ыфіч, جدت_,
  { {0x6fd3005b,0x660f54dd,0x2bb90044,0x00000000}},	//   tıcı, _mock, وادة_,
  { {0x3a202f73,0xea890095,0xb3ca0053,0x00000000}},	//   _slip_, мбол_, _सॉफ़्,
  { {0x6d590022,0x6fd30058,0x78ad004b,0x00000000}},	//   _wywa, rıcı, _avav,
  { {0x8d87005a,0xdd950088,0x7bc1002b,0x00000000}},	//   _чужд, _рады, sglu,
  { {0xf8bf54de,0x3e45001c,0x25a254df,0x00000000}},	//   gué_, cēta_, _rekl_,
  { {0x5fe10042,0x4d64014b,0x00000000,0x00000000}},	//   फ़िल, _сків,   ,
  { {0xc7a30dd5,0x798d002b,0xa3e50042,0x00000000}},	//   риск, _ffaw, भजन_,
  { {0xceb211b4,0xf8bf1a2d,0x660f2901,0x00000000}},	//   ייל_, bué_, _cock,
  { {0x3ddf0122,0x59a70053,0x660f44bb,0x00000000}},	// [a7c0] ieuw_, _ख़तर, _dock,
  { {0x998902f7,0x7d060bda,0x7a360d84,0x00000000}},	//   _imaš_, äksi, ošto,
  { {0x3e45001c,0xc20f0086,0x41c60085,0x00000000}},	//   zēta_, ає_, вёла,
  { {0x68f6072f,0x7a3600a8,0xe297167b,0x00000000}},	//   _kryd, išto, тац_,
  { {0xdb0300b9,0x2cbf004b,0x45d30085,0x00000000}},	//   _udnæ, juud_, _тоўс,
  { {0x90530088,0x7a360006,0x91bf008b,0x00000000}},	//   авіц, kšto, _phụ_,
  { {0x69d600f3,0x9e340062,0xde580085,0x00000000}},	//   _obye, лекч, накі_,
  { {0x0367042c,0x2bcf0053,0x6ced0053,0x00000000}},	//   _риск_, त्सा, जिंग_,
  { {0x24860027,0xc0e31a78,0xa2da0042,0x00000000}},	//   íomh_, _котк, नबक्,
  { {0x3e45003d,0x261c0025,0x4fea0054,0x00000000}},	//   rēta_, _síol_, _імен_,
  { {0x6d440024,0x0c730032,0x3eb800ea,0x00000000}},	//   _žiad, جديد, _írt_,
  { {0xf8bf0164,0x68f654e0,0x3e45008f,0x00000000}},	//   tué_, _bryd, pēta_,
  { {0xac0a0001,0x660f54e1,0xd90f007e,0x00000000}},	//   _онда_, _rock, زید_,
  { {0xd9180055,0x68f6035a,0x261c0139,0x00000000}},	//   тью_, _dryd, _díom_,
  { {0x660f1823,0xf8ae007e,0x0768000d,0x00000000}},	//   _pock, يکی_, ваёй_,
  { {0x62810164,0x69c000cd,0xd5b847b9,0x00000000}},	//   _éloi, òmet, ксу_,
  { {0xf8bf0164,0xa3a7005e,0x2bcf0042,0x00000000}},	// [a7d0] qué_, вјек, त्वा,
  { {0x6e22032a,0xb5fb0139,0x6aba54e2,0x00000000}},	//   _llob, _mhái, ortf,
  { {0xe2980086,0xe7ec0053,0x29190137,0x00000000}},	//   ває_, _छोटा_, lysa_,
  { {0x645e54e3,0x41b40200,0x355500de,0x00000000}},	//   alpi, асшт, _منجز,
  { {0x25a954e4,0x6d4e00bd,0x80e40021,0x00000000}},	//   maal_, ßbal, لأول,
  { {0x8e39007e,0xe8d90013,0x1ec917db,0x00000000}},	//   کستر_, _ngử_, елки_,
  { {0x7a260014,0x44230130,0x7e552530,0x00000000}},	//   _hóte, _ilj_, лтиц,
  { {0xdb030164,0x25a9308d,0xb5fb0025,0x00000000}},	//   _fenê, naal_, _bhái,
  { {0xb5fb0027,0xacf504a0,0x00000000,0x00000000}},	//   _chái, اسبت,   ,
  { {0xdab90088,0x25a90162,0xb5fb0139,0x00000000}},	//   нымі_, haal_, _dhái,
  { {0x7cfd0026,0xc4d00053,0x25a9017a,0x00000000}},	//   færð, _सङ्ख, kaal_,
  { {0xb5fb0027,0x68f654e5,0xf2da0047,0x00000000}},	//   _fhái, _pryd, ײַטל,
  { {0x3e45001c,0x25a9056f,0x9f45240a,0x00000000}},	//   lēto_, daal_, _malí_,
  { {0x395e003d,0x60db00ac,0x68f600ac,0x00000000}},	//   āts_, _mpum, _vryd,
  { {0x1867071a,0x2cad0b34,0x291900a4,0x00000000}},	//   уари_, lsed_, aysa_,
  { {0x68f6001f,0x25a9006f,0x2bcf0053,0x00000000}},	//   _tryd, gaal_, त्रा,
  { {0x9f450290,0x2cad0898,0x056654e6,0x00000000}},	// [a7e0] _salì_, nsed_, уван,
  { {0x69c60122,0x2cad4d4b,0x389b00ff,0x00000000}},	//   lgke, ised_, _ריינ,
  { {0x3ce50053,0xdb0154e7,0x25a9056f,0x00000000}},	//   _जैसे_, kalí, baal_,
  { {0x2cad0019,0x25a9006f,0xa50a06da,0x00000000}},	//   ksed_, caal_, _зема_,
  { {0x3e4c02f4,0xc05a0088,0x9f450857,0x00000000}},	//   něte_, нік_, _dalí_,
  { {0x6e2204c9,0xd007065b,0x2cad25e8,0x00000000}},	//   _slob, лече_, dsed_,
  { {0x2cad0198,0x444454e8,0xdb01039f,0x00000000}},	//   esed_, mn_, falí,
  { {0xb5fb0025,0x62580025,0x444454e9,0x00000000}},	//   _phái, ríos, ln_,
  { {0xdb08017d,0x25370047,0x44440287,0x00000000}},	//   cadê, ָניש_, on_,
  { {0xcbe605fb,0x25a9006f,0x444454ea,0x00000000}},	//   уции, zaal_, nn_,
  { {0x2cad0034,0x60c207a0,0x444451fe,0x00000000}},	//   ased_, luom, in_,
  { {0xb5fb0027,0xc3330132,0x61e20025,0x00000000}},	//   _thái, מות_, neol,
  { {0xddc901f7,0xdddb005b,0x443a32a4,0x00000000}},	//   lleş, lmuş, kip_,
  { {0x444454eb,0x8c4306e6,0x9f47004c,0x00000000}},	//   jn_, _лече, zdní_,
  { {0xddc901f7,0x25a90162,0x44441269,0x00000000}},	//   nleş, taal_, dn_,
  { {0x60c254ec,0xa5070062,0x7c3a1602,0x00000000}},	//   kuom, лязл, litr,
  { {0x25a954ed,0x3e45001c,0x44440bfe,0x00000000}},	// [a7f0] raal_, zēto_, fn_,
  { {0xddc901f7,0xdb0300cd,0x9f45006d,0x00000000}},	//   kleş, _benè, _salí_,
  { {0x25a90438,0x60db54ee,0x7e910023,0x00000000}},	//   paal_, _spum, _kāpe,
  { {0x443a00eb,0x7c3a24bd,0x78bd06a5,0x00000000}},	//   aip_, hitr, orsv,
  { {0x9f470080,0x444454ef,0xc0c8005e,0x00000000}},	//   rdní_, bn_, гује_,
  { {0xb5fb06b2,0x2cad0019,0x660d22cb,0x00000000}},	//   _cháv, vsed_, ljak,
  { {0x9294000d,0xdb0354f0,0x660d54f1,0x00000000}},	//   _гасц, _genè, ojak,
  { {0x2cad0019,0x660d54f2,0x3e45001c,0x00000000}},	//   tsed_, njak, rēto_,
  { {0xac850079,0x3e45001c,0x4c850d34,0x00000000}},	//   јгол, sēto_, јлов,
  { {0x2cad54f3,0x799d004d,0xdb010331,0x00000000}},	//   rsed_, ebsw, salí,
  { {0x7f840032,0x2cad0034,0x63a7085a,0x00000000}},	//   _المن, ssed_, _mejn,
  { {0x26c302dd,0x3e4c0080,0x2cad010e,0x00000000}},	//   dujo_, těte_, psed_,
  { {0x443a005b,0x6287006d,0x444454f4,0x00000000}},	//   yip_, _lujo, yn_,
  { {0x63a70080,0x6e29006f,0x7c282e28,0x00000000}},	//   _nejn, lheb, chdr,
  { {0x444402ab,0xcc3a0047,0x96b9005e,0x00000000}},	//   vn_, _בעסט, луту_,
  { {0xe8fa257e,0x444404bf,0x6abc0026,0x00000000}},	//   _али_, wn_, árfe,

  { {0x62870164,0x444454f5,0x7d1b003e,0x00000000}},	// [a800] _aujo, tn_, nyus,
  { {0x444454f6,0x26c3006d,0xdb01017d,0x00000000}},	//   un_, bujo_, calã,
  { {0x6287017d,0x67bb0063,0xd186000d,0x00000000}},	//   _cujo, _במיק, алей,
  { {0xdb0300cd,0x443a299d,0x62870078,0x00000000}},	//   _venè, sip_, _dujo,
  { {0x645754f7,0x85470156,0x63a701e1,0x00000000}},	//   boxi, _взяв_, _fejn,
  { {0x60c200eb,0xe296000a,0x61e20025,0x00000000}},	//   ruom, _враќ, seol,
  { {0x212006bb,0x60c20006,0xdb0800cd,0x00000000}},	//   ših_, suom, cadè,
  { {0x2d820031,0xddc901f7,0xe3630086,0x00000000}},	//   øke_, rleş, _єкти,
  { {0x394d0045,0x7c2854f8,0x7c3a54f9,0x00000000}},	//   żesz_, thdr, titr,
  { {0x7ed60086,0xdb03013d,0xe8d90013,0x00000000}},	//   _відч, _zené, _ngỡ_,
  { {0x752d02f6,0x62803941,0xab3825a6,0x00000000}},	//   zzaz, _kimo, упну_,
  { {0x7f3b0063,0xdb230014,0x6e29050b,0x00000000}},	//   _בעבו, _þrýs, cheb,
  { {0x7c940032,0x3ea9017f,0x7c3a4de0,0x00000000}},	//   _التص, ćate_, pitr,
  { {0xe8240121,0x5ba30062,0x628054fa,0x00000000}},	//   офсо, _дръз, _limo,
  { {0xb5a7005a,0x27f1008f,0x85a7007b,0x00000000}},	//   ирай, rdzn_, ијад,
  { {0x6d5c01f7,0x4b7b0e2a,0x443824d7,0x00000000}},	//   ğraf, _באוו, _amr_,
  { {0x7bc800ac,0x660d0c6f,0x9f450114,0x00000000}},	// [a810] ogdu, rjak, _malá_,
  { {0x22460024,0x44380089,0x7bc854fb,0x00000000}},	//   enok_, _cmr_, ngdu,
  { {0x2d820024,0x63a726c6,0x645754fc,0x00000000}},	//   ľkej_, _vejn, roxi,
  { {0x22460093,0xdb0100ea,0xf8bf109c,0x00000000}},	//   gnok_, nalá, oré_,
  { {0x628054fd,0x14f4000d,0x84e40085,0x00000000}},	//   _dimo, _дзяў, _доўж,
  { {0x290b00cd,0xb97c0047,0x78600072,0x00000000}},	//   ixca_, דנדי, tövi,
  { {0xdb03006d,0xdb01027d,0x31690066,0x00000000}},	//   _tené, kalá, ťaz_,
  { {0xf2d20063,0xdb0854fe,0x5fc90042,0x00000000}},	//   _מעל_, cadé, _रावल,
  { {0xdb01000f,0x6e2954ff,0x7a260025,0x00000000}},	//   dalá, rheb, _nóta,
  { {0x69cd0331,0xf8bf5500,0x7984002b,0x00000000}},	//   _acae, dré_, _sgiw,
  { {0x44210ff0,0xdce7005b,0x7a3601c2,0x00000000}},	//   ikh_, ımız, lšti,
  { {0xdb0100ea,0xa5bb0014,0x68220066,0x00000000}},	//   galá, _blóm, _pôdo,
  { {0xc9560055,0xf8bf0164,0x7a360114,0x00000000}},	//   стны, gré_, nšti,
  { {0x765d5501,0xd264008f,0xeb960054,0x00000000}},	//   _aksy, miņš_, _лиш_,
  { {0x68ed0290,0xdb0a00b9,0xd839000d,0x00000000}},	//   _esad, _adfæ, рэў_,
  { {0x7a360006,0xdb080003,0x7afc05a5,0x00000000}},	//   kšti, xadé, ærte,
  { {0xcc88001b,0x62805502,0xf8bf0164,0x00000000}},	// [a820] _lớn_, _rimo, cré_,
  { {0x43760121,0xf3f1008d,0x7a36004c,0x00000000}},	//   бует, _ựa_, dšti,
  { {0x644b4ed9,0x224604aa,0x38170063,0x00000000}},	//   égia, tnok_, _הקים_,
  { {0xd25915d4,0x6b5a0041,0xc1b40082,0x00000000}},	//   аці_, אדעפ, ुलेग,
  { {0x25a00e53,0xdb0800ea,0x628000f8,0x00000000}},	//   mbil_, radé, _vimo,
  { {0x20b90088,0x645c1a55,0x98a20022,0x00000000}},	//   рыць_, _ukri, czką_,
  { {0x7a36017f,0xe297018e,0xaf03000d,0x00000000}},	//   ašti, _гас_, зчык,
  { {0x6280000e,0x4cb80121,0x7a36004c,0x00000000}},	//   _uimo, алию_, bšti,
  { {0xc5f30063,0x9f470066,0x25a0003b,0x00000000}},	//   לדה_, rdná_, ibil_,
  { {0xf8bf0003,0x20d2003b,0x7c930021,0x00000000}},	//   vré_, mâi_, أشيا,
  { {0xdb015503,0x5f760021,0x7a261230,0x00000000}},	//   talá, _طائر, _sóta,
  { {0x5d860032,0x2cbf00b9,0xe37b0047,0x00000000}},	//   _الإل, brud_, טריר,
  { {0xf8bf00f4,0xfdf70063,0xc7bb0121,0x00000000}},	//   uré_, _לצאת_, лёв_,
  { {0xf8bf5504,0x7a260025,0xdb0100ea,0x00000000}},	//   rré_, _vóta, salá,
  { {0x6fda0053,0xdc3b0047,0x501b0063,0x00000000}},	//   प्यू, _געגר, נולו,
  { {0x7e91001c,0xe8d9008b,0x682b0378,0x00000000}},	//   _jāpa, _ngủ_, _südd,
  { {0x68ed5319,0xb5fb0139,0x98b9008f,0x00000000}},	// [a830] _usad, _shás, āzēs_,
  { {0x7a365505,0x44272ac0,0xb5fb5506,0x00000000}},	//   všti, ón_, _phás,
  { {0xfa89008b,0x44210089,0x929524fe,0x00000000}},	//   _lẫn_, rkh_, цаец,
  { {0x92590076,0x7a36004c,0x60f901a4,0x00000000}},	//   шает_, tšti, инея_,
  { {0xdb0a00b9,0x7a3610f5,0x1fa912b9,0x00000000}},	//   _udfæ, ušti, акли_,
  { {0xd5bf001c,0x3e45001c,0x7a365507,0x00000000}},	//   žādu_, mēti_, ršti,
  { {0x3e45008f,0x6a44013d,0x0309009a,0x00000000}},	//   lēti_, lőfe, _דִּֽ,
  { {0x7a36017f,0x9d550021,0x237e013d,0x00000000}},	//   pšti, ينغت, _útja_,
  { {0x9f5e0994,0x62810003,0x3e45001c,0x00000000}},	//   _botó_, _éloq, nēti_,
  { {0xfa89001b,0x8fa40001,0x3a2900ea,0x00000000}},	//   _dẫn_, _нађе, _alap_,
  { {0xcb695508,0x7e83013d,0xbfb40044,0x00000000}},	//   ране_, _főpa, _رحلت,
  { {0x2483006f,0x6b9c0058,0x3a290168,0x00000000}},	//   _lijm_, ırga, _clap_,
  { {0x9f5e00ea,0x998c013d,0xe81b0042,0x00000000}},	//   _fotó_, élők_, _नकशा_,
  { {0xf092014e,0x30790047,0xa5bb0026,0x00000000}},	//   ונך_, יאָנ, _flók,
  { {0x224d0150,0x98ab008f,0x3a290783,0x00000000}},	//   _ojek_, ājās_, _flap_,
  { {0xdb030331,0x66e30062,0xf5ea0131,0x00000000}},	//   _jení, ьоса, јмал_,
  { {0x3ea0017f,0x682b00bd,0xb5fb0025,0x00000000}},	// [a840] ćiti_, _süde, _phár,
  { {0x7d040139,0x9c820066,0xdb0301a8,0x00000000}},	//   _áise, _účta, _lení,
  { {0x366a012c,0xd6b60044,0x74130cac,0x00000000}},	//   _вано_, _بإخب, بولا,
  { {0x20d2000c,0x7a260014,0xdb010db3,0x00000000}},	//   tâi_, _móto, malä,
  { {0xe6110063,0x261c0025,0xb5fb0139,0x00000000}},	//   _אִם_, _díot_, _thár,
  { {0x2fc000bd,0x443e00ea,0xceba005e,0x00000000}},	//   ßig_, _öt_, аљи_,
  { {0x9f4c0290,0xdb035509,0x73f90041,0x00000000}},	//   _andò_, _bení, _פּשו,
  { {0x2005550a,0x7a3621e4,0x2a7200a3,0x00000000}},	//   _enli_, oštu, _nhyb_,
  { {0x629e00fe,0xdb030080,0xf8bf013d,0x00000000}},	//   lppo, _dení, nzét_,
  { {0xfa89001b,0xbfc300e1,0x60c2550b,0x00000000}},	//   _vẫn_, _обук, mrom,
  { {0x7e91001c,0x9f5e006d,0x3e45001c,0x00000000}},	//   _tāpa, _votó_, zēti_,
  { {0xed5a15d3,0x2d92005b,0x7a360006,0x00000000}},	//   _кое_, _üye_, kštu,
  { {0x60c2550c,0xf1b30063,0x9f5e00be,0x00000000}},	//   nrom, וסר_, _totó_,
  { {0x66060072,0xe8d90013,0x9999004c,0x00000000}},	//   _ankk, _ngụ_, pisů_,
  { {0x261c018d,0x60c23c02,0xe5ab005e,0x00000000}},	//   _níos_, hrom, ињак_,
  { {0x95cb000a,0x3a2900a4,0x442a550d,0x00000000}},	//   јува_, _ulap_, _alb_,
  { {0x98be003b,0x644b0003,0x84970044,0x00000000}},	// [a850] ătă_, égio, تجزئ,
  { {0xf367550e,0x3e45001c,0x442a0013,0x00000000}},	//   отен, rēti_, _clb_,
  { {0x261c0139,0x3e45008f,0x7a360078,0x00000000}},	//   _cíos_, sēti_, aštu,
  { {0x52150121,0x3e45008f,0x64890023,0x00000000}},	//   ядет, pēti_, _ažie,
  { {0x629e0246,0x26080053,0xae090042,0x00000000}},	//   appo, हारी_, वासन_,
  { {0xf8bf00ea,0xd3e3007e,0x389c0063,0x00000000}},	//   lzés_, _تقسی, סיונ,
  { {0x224d0146,0xd00e0021,0xdb03550f,0x00000000}},	//   _tjek_, الى_, _pení,
  { {0x3e610026,0x92580121,0xdb0800ed,0x00000000}},	//   jótt_, _даст_, gadí,
  { {0xdb03006d,0x60c24a32,0x7bda002b,0x00000000}},	//   _vení, crom, fftu,
  { {0x2a6000b9,0x98a20051,0xcc880013,0x00000000}},	//   _skib_, czkę_, _gớm_,
  { {0xdb030521,0x98b0007d,0xa3dd0053,0x00000000}},	//   _tení, đača_, थ्य_,
  { {0x9f5e0290,0x38c20026,0x7bda0046,0x00000000}},	//   _totò_, _nærð_, aftu,
  { {0x787200b9,0x9aa5007e,0xdb0a006c,0x00000000}},	//   hæve, _کمبو, _lefè,
  { {0x261c0027,0x3ce00053,0xdb03017d,0x00000000}},	//   _níor_, _कहते_, _venâ,
  { {0x44ed016b,0xb5fb0025,0xdbc6004b,0x00000000}},	//   _až_, _pháp, töök,
  { {0x261c02dd,0x69db0019,0xf8bf013d,0x00000000}},	//   _ríos_, õuet, gzés_,
  { {0x261c0027,0xa3ff004c,0x9f4c0445,0x00000000}},	// [a860] _síos_, _řeší_, _radí_,
  { {0x29000016,0x77ca0001,0x3e45001c,0x00000000}},	//   _iria_, _улог_, mētu_,
  { {0x38c2007a,0xf8bf00ea,0x3e45008f,0x00000000}},	//   _færð_, szét_, lētu_,
  { {0x7aba014e,0xcc88008b,0xb6030080,0x00000000}},	//   מצעו, _sớm_, ášte,
  { {0x26d80fbe,0x261c0025,0x3e45001c,0x00000000}},	//   ltro_, _fíor_, nētu_,
  { {0x60c243c2,0xe2a30013,0x261c0331,0x00000000}},	//   rrom, _khứ_, _tíos_,
  { {0xdb083306,0xd7f1008b,0xa5bb0025,0x00000000}},	//   tadí, ỗi_, _slói,
  { {0x26c5007d,0x682b005b,0x26d8085a,0x00000000}},	//   šlog_, _müda, itro_,
  { {0x645e004b,0xfa890013,0x63a3013d,0x00000000}},	//   oopi, _dẫm_, űnne,
  { {0x628e0009,0x8cbd016a,0x3e45001c,0x00000000}},	//   _kubo, _शिरो, dētu_,
  { {0xdb080016,0xa5bb0051,0x29004d7c,0x00000000}},	//   dadã, _glów, _aria_,
  { {0xdb030016,0x68300137,0xdee50021,0x00000000}},	//   _senã, _lädd, _تأكي,
  { {0x29005510,0x26d85511,0x629a0003,0x00000000}},	//   _cria_, etro_, _étof,
  { {0xb8f50394,0x645e017f,0xaa87007e,0x00000000}},	//   _हम_, jopi, _کنيم_,
  { {0x45d5050f,0x628e006d,0xe2a3008b,0x00000000}},	//   мовс, _nubo, _chứ_,
  { {0x3e45008f,0xee490013,0x29005512,0x00000000}},	//   bētu_, hẽn_, _fria_,
  { {0x629c20ae,0xf8bf00ea,0xd5540062,0x00000000}},	// [a870] _atro, rzés_, ектъ,
  { {0x69dd1c41,0x628e5513,0xf8bf013d,0x00000000}},	//   lfse, _bubo, szés_,
  { {0x26ca01f4,0xf8bf00ea,0x26d8193b,0x00000000}},	//   cubo_, pzés_, ctro_,
  { {0x78720146,0x628e5514,0x63bc00a8,0x00000000}},	//   ræve, _dubo, _edrn,
  { {0xe0ce005a,0x629c0e1a,0x44ed5515,0x00000000}},	//   ъв_, _etro, _už_,
  { {0x44250c70,0x23c303b2,0x7a360024,0x00000000}},	//   _ôl_, _déjà_, nštr,
  { {0x3e45003d,0xfe79004c,0x00000000,0x00000000}},	//   zētu_, tmů_,   ,
  { {0x9f47034d,0x69dd006f,0xdb030240,0x00000000}},	//   nené_, jfse, _nená,
  { {0xdb011676,0x764d2e10,0x61eb5516,0x00000000}},	//   mblé, inay, megl,
  { {0x60cb002c,0x683000fe,0x4b25013c,0x00000000}},	//   mugm, _käde, дмов,
  { {0x68e42a9b,0xbb850021,0x39ea1e1b,0x00000000}},	//   _spid, بلدي, одно_,
  { {0x29000551,0x645e0035,0x9f470240,0x00000000}},	//   _pria_, zopi, jené_,
  { {0x645e0009,0x9f47027d,0x682b181d,0x00000000}},	//   yopi, dené_, _süda,
  { {0x3e45003d,0x26d8051e,0x7e620080,0x00000000}},	//   rētu_, ttro_, _zkop,
  { {0x26d85517,0x683000c7,0xcc560063,0x00000000}},	//   utro_, _rädd, _קבצי_,
  { {0x764d00bb,0x290000cd,0x3e45183d,0x00000000}},	//   gnay, _tria_, mēts_,
  { {0x26d82f83,0xdb0a1908,0x3e45001c,0x00000000}},	// [a880] stro_, _refé, lēts_,
  { {0xd7ca006a,0xe2a3008b,0x61eb004b,0x00000000}},	//   _بوده_, _thứ_, eegl,
  { {0x26ca00ac,0x9f470240,0x3e45001c,0x00000000}},	//   qubo_, bené_, nēts_,
  { {0x9f4701c2,0xa5bb0264,0x61eb4a33,0x00000000}},	//   cené_, _slóv, gegl,
  { {0x645e5518,0xdb08013d,0xf5060085,0x00000000}},	//   popi, iadá, _ўзго,
  { {0x7e7b006f,0x628e5519,0x6830092e,0x00000000}},	//   emup, _tubo, _fäde,
  { {0xe7e00161,0xdee30001,0x61eb551a,0x00000000}},	//   ख्या_, воји, begl,
  { {0x61eb0290,0x4e770021,0x4444551b,0x00000000}},	//   cegl, وحيد_, li_,
  { {0x4444551c,0x7e6200ca,0x40930021,0x00000000}},	//   oi_, _vkop, _للقر,
  { {0x9f470a63,0xdb0301c2,0x4444551d,0x00000000}},	//   zené_, _sená, ni_,
  { {0xcc88001b,0x59f9000d,0x4444551e,0x00000000}},	//   _mới_, пеня_, ii_,
  { {0xdb08000f,0xcc880013,0x7e62007d,0x00000000}},	//   gadá, _lới_, _ukop,
  { {0x9f47027d,0x69dd0026,0x5938000d,0x00000000}},	//   vené_, rfse, дзяў_,
  { {0x61eb0045,0x7e600397,0x4444551f,0x00000000}},	//   zegl, lomp, ji_,
  { {0x290d000c,0x9f4718a8,0x3e45001c,0x00000000}},	//   ţea_, tené_, cēts_,
  { {0xdb0300b9,0x5499000d,0xf1b9004c,0x00000000}},	//   _benæ, зваў_, _koše_,
  { {0x9f470024,0x44445520,0x61eb01f4,0x00000000}},	// [a890] rené_, fi_, vegl,
  { {0x68300019,0x61eb004d,0x9f470061,0x00000000}},	//   _päde, wegl, rdnú_,
  { {0xf1b9017f,0x64890006,0x7a260025,0x00000000}},	//   _loše_, _džia, _bóth,
  { {0x60cb002c,0x683000c7,0x7d0200ea,0x00000000}},	//   tugm, _väde, _oros,
  { {0x3e45001c,0x75360051,0x7a260139,0x00000000}},	//   zēts_, czyz, _dóth,
  { {0x61eb08ea,0x44445521,0xcf250044,0x00000000}},	//   segl, ci_, فرعي,
  { {0x661d024a,0x6445002c,0x7d02473c,0x00000000}},	//   _kosk, mihi, _aros,
  { {0x6445002c,0x661d00fe,0x7d025522,0x00000000}},	//   lihi, _josk, _bros,
  { {0xdfdb005a,0x7d025523,0x644500fe,0x00000000}},	//   _мъж_, _cros, oihi,
  { {0x7e690019,0x64451bb8,0x683000bd,0x00000000}},	//   slep, nihi, _mädc,
  { {0xdb03017d,0x64450072,0x7e6900a8,0x00000000}},	//   _menç, iihi, plep,
  { {0xc869014e,0x661d003d,0x6445114c,0x00000000}},	//   _הן_, _nosk, hihi,
  { {0x444401f7,0x644500bb,0xfce50086,0x00000000}},	//   yi_, kihi, _чоло,
  { {0xdb0300b9,0x64450035,0x44445524,0x00000000}},	//   _renæ, jihi, xi_,
  { {0xcf92009f,0xcb66005e,0x661d5525,0x00000000}},	//   רטל_, _паше_, _bosk,
  { {0x62890051,0x4444383e,0x64450072,0x00000000}},	//   _nieo, wi_, eihi,
  { {0x661d5526,0x6a44013d,0x2bb60053,0x00000000}},	// [a8a0] _dosk, lőfo, _आजमा,
  { {0xdb030014,0x44445527,0x75360022,0x00000000}},	//   _venæ, ui_, rzyz,
  { {0xa5bb0025,0xdb0c00ea,0x78ad006f,0x00000000}},	//   _clós, űköd, _zwav,
  { {0xcc8800aa,0xa49b01a8,0xdb06004c,0x00000000}},	//   _với_, _iròn, áméh,
  { {0x644503d5,0x44445528,0x56370047,0x00000000}},	//   bihi, pi_, _טאטע_,
  { {0xcc88001b,0x3e4c0080,0x44440034,0x00000000}},	//   _tới_, měti_, qi_,
  { {0xdb0a010a,0xb5fb0066,0x7e605529,0x00000000}},	//   _udfø, _okál, tomp,
  { {0xb87b0331,0xdb240014,0x7d02378f,0x00000000}},	//   ctíf, ðsíu, _pros,
  { {0x7e60552a,0x7a262d2f,0xfd12013a,0x00000000}},	//   romp, _góti, اجع_,
  { {0x8c430002,0xe0860021,0x7e60552b,0x00000000}},	//   лење, _أجري, somp,
  { {0x200c31af,0x682b004d,0x7e60552c,0x00000000}},	//   _indi_, _südo, pomp,
  { {0x7d021446,0x64450035,0xfe72007e,0x00000000}},	//   _tros, zihi, _صدا_,
  { {0x644500fe,0x661d552d,0xdca30c0b,0x00000000}},	//   yihi, _rosk, _бачи,
  { {0xdb0300c7,0x3e4c004c,0xd7c90043,0x00000000}},	//   _benä, děti_, بوسه_,
  { {0xa49b00cd,0xadf40053,0x201e552e,0x00000000}},	//   _cròn, _आसान_, _moti_,
  { {0xdb080014,0x6aba02fd,0x5eeb009a,0x00000000}},	//   tadæ, mstf, הַמְ,
  { {0x64451621,0xa5bb0026,0xb17d0066,0x00000000}},	// [a8b0] tihi, _slós, _obťa,
  { {0x201e552f,0x7d0600fe,0xd37b1001,0x00000000}},	//   _noti_, äksy, пче_,
  { {0x64453a8e,0xdb035530,0x661d5531,0x00000000}},	//   rihi, _venç, _tosk,
  { {0xd370006a,0x78720146,0x200c5532,0x00000000}},	//   حهٔ_, nævn, _andi_,
  { {0x683010c8,0xa5bb5533,0xdb03017d,0x00000000}},	//   _häda, _flór, _tenç,
  { {0x6aba45ba,0xa5bb017d,0x28980063,0x00000000}},	//   kstf, _glór, עדון_,
  { {0x5454000a,0x6455006f,0x201e0290,0x00000000}},	//   _сврт, _ijzi, _doti_,
  { {0x60c400eb,0x682b00bd,0x7e91001c,0x00000000}},	//   šima, _südl, _jāpi,
  { {0x6e295398,0x9f47430a,0x6cd20021,0x00000000}},	//   rkeb, mení_, لقيا,
  { {0x9f4701c2,0x61fb5534,0xd1640062,0x00000000}},	//   lení_, _haul, _съси,
  { {0x68300004,0x61fb5535,0xa9a60074,0x00000000}},	//   _näda, _kaul, кинд,
  { {0x9f470024,0xdb030137,0x61fb5536,0x00000000}},	//   není_, _renä, _jaul,
  { {0x2904007a,0x61fb5537,0x91ba0063,0x00000000}},	//   íma_, _maul, ומרי,
  { {0x61fb5538,0x69a20042,0xdb18017c,0x00000000}},	//   _laul, _क्री, _zdví,
  { {0x23bc004c,0xdb0314a7,0xf1b30042,0x00000000}},	//   hájí_, _benå, ुणान,
  { {0xdb0300fe,0x9f470114,0xe9df0139,0x00000000}},	//   _venä, jení_, liún_,
  { {0x4431006f,0x9f47004a,0x39360085,0x00000000}},	// [a8c0] _blz_, dení_, _шэкс,
  { {0x64890078,0x232a01ce,0xb8f60042,0x00000000}},	//   _džio, мози_, ां_,
  { {0x201e463c,0x61fb275a,0x25a9009c,0x00000000}},	//   _roti_, _baul, bbal_,
  { {0x64890006,0x72290086,0xdb0300b9,0x00000000}},	//   _užin, нців_, _genå,
  { {0x201e5539,0x61fb2b32,0x260f0042,0x00000000}},	//   _poti_, _daul, डारी_,
  { {0x03a3019d,0x6aba32e9,0x493b009a,0x00000000}},	//   _виро, ystf, וגנו,
  { {0x201e0290,0xb87b10e1,0x04430156,0x00000000}},	//   _voti_, stíg, _терн,
  { {0x9f4702f4,0x3df40002,0x61fb1825,0x00000000}},	//   cení_, узис, _gaul,
  { {0x201e2eba,0x9cb4007e,0xe9df0066,0x00000000}},	//   _toti_, دمخت, inút_,
  { {0x200c058c,0x61e2553a,0xfa8a001b,0x00000000}},	//   _undi_, lfol, _mẫu_,
  { {0x5b13000d,0x61fb0035,0x25a900ca,0x00000000}},	//   амэт, _yaul, ybal_,
  { {0xf2d300b5,0xda35093e,0x61e2553b,0x00000000}},	//   סער_, уемы, nfol,
  { {0x2e370063,0xcc88008b,0x9f45004a,0x00000000}},	//   _בראש_, _bớt_, _malý_,
  { {0xc7c40076,0x9f470114,0x6830004d,0x00000000}},	//   исси, zení_, _päda,
  { {0x6c790047,0xf1b9007d,0xf5390066,0x00000000}},	//   _אָקס, _loša_, _ťť_,
  { {0xb5a40076,0xe6540086,0x36d40002,0x00000000}},	//   ируй, авсь, јотр,
  { {0x25a6258a,0x3ea9017f,0x49b8007e,0x00000000}},	// [a8d0] ñola_, ćati_, _شايد_,
  { {0x84340086,0x25a9032a,0xfa8a0013,0x00000000}},	//   анує, sbal_, _dẫu_,
  { {0xdb0300d1,0x9f4701d9,0x61fb553c,0x00000000}},	//   _tenå, tení_, _paul,
  { {0x2c790003,0x7a260014,0xd378553d,0x00000000}},	//   mède_, _fótu, тчу_,
  { {0x9f470024,0x7afd001c,0x61fb1098,0x00000000}},	//   rení_, āsti, _vaul,
  { {0x9f4701c2,0x4fc70a3a,0x102500de,0x00000000}},	//   sení_, тсда, طّبّ,
  { {0x61fb553e,0x9f470114,0x83840121,0x00000000}},	//   _taul, pení_, _выте,
  { {0x7d1d0137,0xc6940041,0x7a260046,0x00000000}},	//   ässo, סאפ_, _jótt,
  { {0x4bd90088,0x7a26007a,0x31550088,0x00000000}},	//   ньня_, _mótt, _сваё,
  { {0x6e950062,0x63b500a8,0x00000000,0x00000000}},	//   _бижу, _jezn,   ,
  { {0xcc880013,0x78bd04aa,0x63b5004c,0x00000000}},	//   _rớt_, essv, _mezn,
  { {0xe9df0025,0x9f4700cd,0xa49b01a8,0x00000000}},	//   siún_, menà_, _pròl,
  { {0x4a430062,0x26c500ea,0x6a760014,0x00000000}},	//   сняв, álon_, gáfa,
  { {0x7a26039f,0xdb030857,0x63b5106b,0x00000000}},	//   _rótu, _menú, _nezn,
  { {0xdb010019,0xae170053,0xcc880013,0x00000000}},	//   nalü, थापन_, _vớt_,
  { {0x672103b0,0x6489007d,0xe6431fa4,0x00000000}},	//   älja, _džim, бесп,
  { {0x26d10035,0x7a260014,0x63b5553f,0x00000000}},	// [a8e0] auzo_, _dótt, _bezn,
  { {0x26d100ac,0xb376005d,0x9999017c,0x00000000}},	//   buzo_, هداش, risť_,
  { {0x2c790003,0x316d0003,0x61e2230d,0x00000000}},	//   cède_, _ayez_, tfol,
  { {0x9f4700cd,0x78a40196,0x32650054,0x00000000}},	//   denà_, _ktiv, атів,
  { {0x9f470024,0x61e22067,0x7d1d004d,0x00000000}},	//   rdný_, rfol, ässl,
  { {0xa87a0047,0xdb0304a5,0x644b006c,0x00000000}},	//   עאַר, _denú, égit,
  { {0x69c45540,0xb7db0063,0x9e140086,0x00000000}},	//   _odie, תקצי, идкі,
  { {0xb87b1908,0x69c45541,0x9ed70062,0x00000000}},	//   otíc, _ndie, умът_,
  { {0xd83f00c3,0x2fd60021,0xb87b00ed,0x00000000}},	//   ščih_, _متاح, ntíc,
  { {0x3e57003b,0x69c45542,0x2a6901e1,0x00000000}},	//   răta_, _adie, _skab_,
  { {0x78a403d9,0x6f930021,0x5f930021,0x00000000}},	//   _ativ, _المض, _المئ,
  { {0xa2cc0053,0xd3570063,0x3e57003b,0x00000000}},	//   _हिन्, ריטי_, păta_,
  { {0x9f47108f,0x69c4001f,0xd90f007e,0x00000000}},	//   mená_, _ddie, سید_,
  { {0x3ebd00fe,0x9f470240,0x7a260026,0x00000000}},	//   _äytä_, lená_, _sótt,
  { {0x682b00bd,0xe9df0139,0xdb9b0063,0x00000000}},	//   _jüdi, unús_, _אסור,
  { {0x9f470024,0x63b508c4,0x69c0006d,0x00000000}},	//   nená_, _sezn, ómet,
  { {0x2c79006c,0xd3a70699,0xa4d515ce,0x00000000}},	// [a8f0] sède_, греп, розі,
  { {0x68ed00bb,0x69c40024,0x6e220019,0x00000000}},	//   _ipad, _zdie, _loob,
  { {0xe2980086,0x64890006,0xf8bf0003,0x00000000}},	//   гає_, _užim, lsé_,
  { {0xa4d5019d,0xf8bf3b2f,0x9f47027d,0x00000000}},	//   _комі, osé_, jená_,
  { {0x629a0164,0xf8bf2500,0x9f47027d,0x00000000}},	//   _éton, nsé_, dená_,
  { {0x41260076,0xf8bf0003,0x889c0047,0x00000000}},	//   рошо_, isé_, עבוי,
  { {0x9028000d,0xe9df0025,0x656f001f,0x00000000}},	//   ыцца_, tiúl_, _hych,
  { {0x9f4500cd,0x68ed52c8,0x9f4a0046,0x00000000}},	//   _saló_, _opad, úmál_,
  { {0x6d440066,0x7e91008f,0x6e2600a5,0x00000000}},	//   _žiar, _rāpu, ökba,
  { {0x4423074f,0x3ce50053,0xe8d90013,0x00000000}},	//   _joj_, _कहीं_, _ngự_,
  { {0x9f45000f,0xdb0100ea,0x9f470240,0x00000000}},	//   _való_, való, bená_,
  { {0xa2d60161,0x9f470080,0xdb0100cd,0x00000000}},	//   मंत्, cená_, falò,
  { {0x61e90009,0x672100c7,0xdb015543,0x00000000}},	//   _mbel, äljn, taló,
  { {0xc05200b5,0x5d3a0063,0x80cd0053,0x00000000}},	//   ַזן_, _בתנא, _सिने,
  { {0xddc90024,0x61e92512,0x7c230025,0x00000000}},	//   tieň, _obel, _ionr,
  { {0x78a40290,0x69c40290,0x7c232269,0x00000000}},	//   _ttiv, _udie, _honr,
  { {0x656f001f,0x7c235544,0x44235545,0x00000000}},	// [a900] _cych, _konr, _boj_,
  { {0x656f0185,0x04460001,0xb87b0283,0x00000000}},	//   _dych, шезн, rtíc,
  { {0xb87b5546,0xe73a1c7a,0x628221ef,0x00000000}},	//   stíc, _рен_, tmoo,
  { {0x27ed0117,0xcc88008b,0x2cbf0214,0x00000000}},	//   đene_, _lớp_, ksud_,
  { {0x6fb60032,0x656f001f,0x9f47027d,0x00000000}},	//   لمشا, _gych, vená_,
  { {0x2d980080,0x3ec60b3f,0x7d040025,0x00000000}},	//   ěrem_, асиб, _áisi,
  { {0x6e2200c3,0xb87b006d,0x9f470024,0x00000000}},	//   _poob, ntía, tená_,
  { {0x25a05547,0xade30083,0x00000000,0x00000000}},	//   ncil_, оцьк,   ,
  { {0x9f470024,0x25a20089,0x10a30cdf,0x00000000}},	//   rená_, _mfkl_, _митн,
  { {0x7c231de4,0xddc0004c,0x682b004b,0x00000000}},	//   _conr, pomů, _tüdi,
  { {0x2905001c,0x6e225548,0x63970041,0x00000000}},	//   ālam_, _toob, ידיא_,
  { {0x6c34007e,0x26c53887,0xe9190054,0x00000000}},	//   _گفتا, álom_, гомі_,
  { {0x984b005a,0xf99f078d,0xf8bf0003,0x00000000}},	//   вява_, rcè_, usé_,
  { {0xf8bf3380,0x656f01c2,0xad25007e,0x00000000}},	//   rsé_, _rych, _درمو,
  { {0xf8bf5549,0xfa56007e,0xdb1a00ea,0x00000000}},	//   ssé_, _گروگ, egtö,
  { {0x7a360006,0xaa44007b,0xa6340054,0x00000000}},	//   kšty, _мејл, онсі,
  { {0xd7e70086,0x394f0137,0xadf90053,0x00000000}},	// [a910] _кіно, _ägs_, ्यतन_,
  { {0x656f0114,0xa3a702d8,0x473512a5,0x00000000}},	//   _vych, рјак, _гнос,
  { {0xd7dc0161,0x656f0051,0x682b00bd,0x00000000}},	//   _बातच, _wych, _südw,
  { {0xed59017f,0x67280137,0x44230051,0x00000000}},	//   laže_, ädje, _woj_,
  { {0x4423017f,0xdb1800b9,0x81c80086,0x00000000}},	//   _toj_, _udvæ, ргів_,
  { {0x73c50021,0x764d0150,0x6a52008f,0x00000000}},	//   _ديسم, liay, rāfi,
  { {0xf8380063,0x752d013d,0x57fa0041,0x00000000}},	//   שנות_, lyaz, טלװו,
  { {0x7c23554a,0x764d0397,0x61e9554b,0x00000000}},	//   _sonr, niay, _ubel,
  { {0xed59082a,0x752d0379,0x1c450054,0x00000000}},	//   kaže_, nyaz, йним,
  { {0x2d9f0034,0x4ee70086,0x1c110053,0x00000000}},	//   scue_, _відз, ़ाइल_,
  { {0x764d00a4,0xdddb003b,0x1b490141,0x00000000}},	//   kiay, cluş, узни_,
  { {0x8d950021,0x25b9004c,0x7c3a004e,0x00000000}},	//   _الإش, _nesl_, ahtr,
  { {0x6abc0026,0xbca501fb,0x48e30062,0x00000000}},	//   árfr, _امتي, появ,
  { {0x7c3a554c,0xdb0a092e,0x07a30eae,0x00000000}},	//   chtr, _befä, зарн,
  { {0xfb87000d,0xf1d80053,0xfbb60063,0x00000000}},	//   _тыдн, _डालन, _הפצת_,
  { {0xb87b006d,0x9f470072,0xe9da0ae8,0x00000000}},	//   rtía, menä_, _ски_,
  { {0xb87b006d,0x14c8007e,0x25a02dd1,0x00000000}},	// [a920] stía, شهای_, rcil_,
  { {0x8ccf0053,0x9f4700cd,0x6a7d0003,0x00000000}},	//   _दिनो, cenç_, réfe,
  { {0xdb0a00bd,0x764d0052,0x9f470072,0x00000000}},	//   _gefä, biay, nenä_,
  { {0xd5b90076,0xb87b554d,0x91ba0044,0x00000000}},	//   _всё_, ntín, اطار_,
  { {0x6604005b,0x6e3b0b54,0x9c8200c2,0x00000000}},	//   mdik, dhub, ščil,
  { {0x33d5019d,0x66042ae1,0x7fd60054,0x00000000}},	//   _міст, ldik, сіді,
  { {0xe8190161,0x6604554e,0xdb01004d,0x00000000}},	//   दाता_, odik, nblä,
  { {0x6604058c,0x6e3b0089,0x1d340062,0x00000000}},	//   ndik, ghub, жния,
  { {0xed870086,0x6da30095,0x68300137,0x00000000}},	//   йськ_, чиња, _vädj,
  { {0x26c500ea,0xdb1a554f,0x66040072,0x00000000}},	//   álok_, laté, hdik,
  { {0x6e960021,0x60c202c0,0x7d0b0104,0x00000000}},	//   _الصا, lsom, _ergs,
  { {0xcce6007e,0x98ad1035,0x7c3a5550,0x00000000}},	//   _هستي, šeč_, shtr,
  { {0x9e650032,0x63be5551,0x395f0003,0x00000000}},	//   _بالن, kapn, çus_,
  { {0x7afc00b9,0x60c25552,0x66045553,0x00000000}},	//   ærts, isom, edik,
  { {0x63be0228,0x9f475554,0xed590b59,0x00000000}},	//   dapn, renç_, raže_,
  { {0x60c20b4b,0x78d51213,0x5b5703c3,0x00000000}},	//   ksom, _джих, _לשון_,
  { {0x5fc80161,0xe5730021,0x9f5e0003,0x00000000}},	// [a930] रणाल, سطر_, _daté_,
  { {0x7bda1d56,0xdb180003,0x60c212f5,0x00000000}},	//   ngtu, _revê, dsom,
  { {0x66040150,0xf1b900a8,0x64895555,0x00000000}},	//   bdik, _peš_, _oživ,
  { {0xddc9008f,0xdb1a4b27,0xdce90023,0x00000000}},	//   kleš, ratè, tceļ,
  { {0xd14b007e,0x2169005e,0x60e70086,0x00000000}},	//   دشان_, јили_, сцез,
  { {0xb97c0041,0xd0090074,0x9ea90c46,0x00000000}},	//   ארדז, реке_, авка_,
  { {0x6e3b00ac,0x62350076,0x629800ea,0x00000000}},	//   thub, _деву, ívot,
  { {0x7bda5556,0x82370242,0x4e290ace,0x00000000}},	//   egtu, _ارسا, роин_,
  { {0xddc900c3,0x7e6903a8,0x6e3b053b,0x00000000}},	//   gleš, roep, rhub,
  { {0x9f470072,0x40e8089e,0x0ae905ac,0x00000000}},	//   tenä_, _לַעֲ, адой_,
  { {0x6d4008ee,0xddc9004c,0xcef9005d,0x00000000}},	//   azma, aleš, _خفاش_,
  { {0xa2cc0161,0xc7a90ee1,0x7bda00a4,0x00000000}},	//   _हिस्, _יב_, agtu,
  { {0x39350088,0xdb0301f7,0x9f4700fe,0x00000000}},	//   пэрс, _henü, senä_,
  { {0xdb1a000f,0x2cad0034,0x60c40025,0x00000000}},	//   zaté, mped_, áimi,
  { {0x2cad0034,0x63be0137,0x7d095557,0x00000000}},	//   lped_, vapn, lves,
  { {0x27ed0117,0x85050053,0x682b004d,0x00000000}},	//   đena_, रिंट_, _südt,
  { {0x14262b15,0x7d093daf,0x74160021,0x00000000}},	// [a940] одам, nves, يورا,
  { {0x2aed0053,0xb87b017d,0xf772007e,0x00000000}},	//   _जहाँ_, ntíl, _ياد_,
  { {0x660436a1,0xdb1a2abf,0x27f85558,0x00000000}},	//   pdik, taté, mern_,
  { {0x27f85559,0xe4da007e,0x60c2555a,0x00000000}},	//   lern_, _پوست_, tsom,
  { {0x60c20006,0x7bda0006,0xa1830121,0x00000000}},	//   usom, ygtu, мышл,
  { {0x27f80bfc,0x4ea60612,0x682b004b,0x00000000}},	//   nern_, ориа, _hüdr,
  { {0x26d8555b,0xaf03000d,0x63bc003b,0x00000000}},	//   nuro_, дчык, _iern,
  { {0x27f8555c,0x63bc555d,0x290000fe,0x00000000}},	//   hern_, _hern, _osia_,
  { {0x7d54005a,0x63bc2e38,0xdcfb0066,0x00000000}},	//   явих, _kern, abuľ,
  { {0x63bc04b1,0xe61f0024,0xbc670021,0x00000000}},	//   _jern, _zhôd_, يمين_,
  { {0xda7b0076,0xdb0300bd,0xdb1800ea,0x00000000}},	//   иям_, _genü, _kevé,
  { {0x7d0900c3,0x3c3b0164,0x63bc103b,0x00000000}},	//   bves, _rêve_, _lern,
  { {0x32040051,0x27f8555e,0x8b07004c,0x00000000}},	//   _mamy_, fern_, _poří,
  { {0x27f80832,0xeb4a007e,0xb87b0025,0x00000000}},	//   gern_, _پشتو_, rtío,
  { {0x629c00eb,0x26d8555f,0xb87b0025,0x00000000}},	//   _nuro, guro_, stío,
  { {0x26cd017f,0xdb18000f,0x8b3b0063,0x00000000}},	//   čeo_, _nevé, _כתוצ,
  { {0xdb030942,0x63bc0ff0,0x27f800bd,0x00000000}},	// [a950] _fenó, _bern, bern_,
  { {0xf1d80053,0x629c2d16,0x69dd5560,0x00000000}},	//   _डाउन, _buro, lgse,
  { {0x63bc03b2,0xdb18000f,0x26d81095,0x00000000}},	//   _dern, _bevé, curo_,
  { {0x7d09508e,0x629c312f,0x290b007d,0x00000000}},	//   yves, _duro, ovca_,
  { {0xddc80051,0x645800c2,0x361a0063,0x00000000}},	//   łośc, čvir, _הורד,
  { {0x629c051e,0x63bc5561,0xa0690001,0x00000000}},	//   _furo, _gern, љака_,
  { {0x9f470024,0xa49b00cd,0x3e5700dd,0x00000000}},	//   lenú_, _eròt, lăti_,
  { {0xf1bf007a,0x27f8087d,0x6e92005e,0x00000000}},	//   _þá_, zern_, нију,
  { {0x7d090006,0x2cad00e5,0x9f470066,0x00000000}},	//   uves, uped_, nenú_,
  { {0x7d095562,0x63a503a7,0x69dd5563,0x00000000}},	//   rves, nchn, egse,
  { {0x63a50199,0x7d095564,0x27f85565,0x00000000}},	//   ichn, sves, vern_,
  { {0x2cad4d59,0x200510c2,0xdb01004c,0x00000000}},	//   pped_, _hali_, nclé,
  { {0x20051d1a,0xdb0301a8,0x225f0137,0x00000000}},	//   _kali_, _penó, _mjuk_,
  { {0x27f800bd,0x9f470024,0xfbd3007e,0x00000000}},	//   uern_, denú_, _آتش_,
  { {0x7bc15566,0x27f8004d,0xec360063,0x00000000}},	//   malu, rern_, _מאסר_,
  { {0x629a0164,0x7bc1014f,0xdb0300cd,0x00000000}},	//   _étoi, lalu, _fenò,
  { {0x63bc5567,0x2900003e,0xdb1100b9,0x00000000}},	// [a960] _pern, _usia_, ågæl,
  { {0xdb080025,0x32045568,0xdb0a017d,0x00000000}},	//   cadó, _samy_, _refú,
  { {0x682b0019,0x7dd6005b,0xe7b70063,0x00000000}},	//   _tüdr, nüsü, _מהיר_,
  { {0x11d70021,0x9f470066,0x7bc10859,0x00000000}},	//   كومة_, benú_, halu,
  { {0x63bc0397,0x20050eba,0x26c50024,0x00000000}},	//   _tern, _bali_, álov_,
  { {0x66065569,0x7532001c,0x224d0058,0x00000000}},	//   _hakk, īdzī, _emek_,
  { {0x644e00bb,0x5f9302a9,0x660600fe,0x00000000}},	//   _imbi, ништ, _kakk,
  { {0x225a0021,0x442a1c3a,0x20070f74,0x00000000}},	//   _الرد_, _hob_, adni_,
  { {0xe62a008b,0x361b0063,0x6606556a,0x00000000}},	//   _độ_, מוקד, _makk,
  { {0x200500eb,0x442a4c80,0x64890114,0x00000000}},	//   _gali_, _job_, _užit,
  { {0xed59082a,0xe9f90086,0x9f470066,0x00000000}},	//   raža_, онні_, zenú_,
  { {0xb87b0026,0x1e861485,0x60c40006,0x00000000}},	//   rtím, _элем, šimu,
  { {0x588708a6,0x9f5e00cd,0x69dd4cba,0x00000000}},	//   зыва, _matí_, rgse,
  { {0x27ed017f,0x9f470024,0x660600fe,0x00000000}},	//   đeno_, venú_, _aakk,
  { {0x660623f1,0xdb08556b,0x7dd60058,0x00000000}},	//   _bakk, radó, cüsü,
  { {0x644e0dd1,0x20070c22,0xdb080139,0x00000000}},	//   _ambi, zdni_, sadó,
  { {0x6a7d02dd,0x63a5556c,0x442a04bf,0x00000000}},	// [a970] léfo, tchn, _bob_,
  { {0xe9df00cd,0xdb0a00b9,0x9f4d0066,0x00000000}},	//   lgú_, _befø, čnúc_,
  { {0xd5ed008b,0x63a5556d,0xd6d50121,0x00000000}},	//   hoả, rchn, _южны,
  { {0x63a50199,0x66060026,0x7c2a001f,0x00000000}},	//   schn, _gakk, _lofr,
  { {0x3cf80053,0x680f0078,0x63a50022,0x00000000}},	//   ्टों_, pėdė, pchn,
  { {0x6a76556e,0x6606556f,0x60cd1bba,0x00000000}},	//   ráfi, _zakk, šamo,
  { {0x7d023303,0x20073692,0x20055570,0x00000000}},	//   _asos, rdni_, _vali_,
  { {0x2d990831,0x787200b9,0xdb1a18a8,0x00000000}},	//   øse_, nævr, gatí,
  { {0xd0d4005a,0x4c8505fb,0x20053873,0x00000000}},	//   _потъ, млив, _tali_,
  { {0x69cd001f,0x20050290,0xcac90121,0x00000000}},	//   _adae, _uali_, огое_,
  { {0x60c40006,0x290c008f,0x78ad0516,0x00000000}},	//   šimt, ādam_, _atav,
  { {0x7bc15571,0xdb1a017d,0x7dd60058,0x00000000}},	//   salu, catí, rüsü,
  { {0x69cd001f,0xee36000d,0xbd450021,0x00000000}},	//   _ddae, _інш_, _تنشي,
  { {0x7c2a001f,0x7bc70014,0x66065572,0x00000000}},	//   _gofr, ðjud, _sakk,
  { {0xe73a101a,0x66065573,0x28d30053,0x00000000}},	//   цев_, _pakk, _तिथि,
  { {0x442a0016,0x60c900c2,0xdb0801a8,0x00000000}},	//   _sob_, _ovem, padò,
  { {0x442a0185,0x15fd0161,0xfe790080,0x00000000}},	// [a980] _pob_, उज़र_, ilů_,
  { {0x6e2b02b0,0xdb1a0080,0x66061215,0x00000000}},	//   _logb, zatí, _wakk,
  { {0x442a5574,0x660617d3,0x98a20006,0x00000000}},	//   _vob_, _takk, vykę_,
  { {0x7df90053,0xda210042,0xb5da0044,0x00000000}},	//   ्योग_, यायत_, _ببدء_,
  { {0x98a20051,0x10a306b4,0xd0d40094,0x00000000}},	//   tykę_, вичн, холъ,
  { {0x60c91253,0x442a0150,0x644e2a39,0x00000000}},	//   _dvem, _uob_, _umbi,
  { {0xe80f0161,0xd3720242,0xdb1a5575,0x00000000}},	//   ायता_, _شهر_, tatí,
  { {0x7c2a1908,0x2498004b,0xa63b0041,0x00000000}},	//   _sofr, _hirm_, ַגיר,
  { {0xab5c003d,0xdb1a108e,0x00000000,0x00000000}},	//   daļa, ratí,   ,
  { {0x6fb30021,0xddc90022,0xb87b011b,0x00000000}},	//   _لمكا, gieł, rtík,
  { {0x20250024,0x03d70063,0xa08b0063,0x00000000}},	//   úpiť_, ווים_, _וְאִ,
  { {0x629a0003,0x7d02002b,0x290f013d,0x00000000}},	//   _étou, _tsos, _ágak_,
  { {0xf8ae007e,0x7c2a04aa,0x6da331ab,0x00000000}},	//   یکی_, _tofr, _рича,
  { {0x7d7b009d,0x00000000,0x00000000,0x00000000}},	//   _ונדו,   ,   ,
  { {0x764100eb,0xfa8a008d,0x7793005d,0x00000000}},	//   ūlym, _lẫy_, ضیحا,
  { {0x6a84000a,0x24980025,0x9f5e01a8,0x00000000}},	//   _илја, _airm_, _matà_,
  { {0x6a760026,0xe80f0053,0x2905001c,0x00000000}},	// [a990] gáfu, ायदा_, ālas_,
  { {0xd37b3d39,0xcc78009a,0xd3db0044,0x00000000}},	//   оче_, פְּר, تبرا_,
  { {0x60c9017f,0xfe79004c,0x64891273,0x00000000}},	//   _svem, ylů_, _džip,
  { {0xdb1801c2,0xfa8a0013,0xdb0105e7,0x00000000}},	//   _neví, _bẫy_, rblø,
  { {0x24980886,0xe4a406da,0xf1940054,0x00000000}},	//   _firm_, _арсо, виць,
  { {0x751600b5,0x3e4c004c,0xd006019c,0x00000000}},	//   _אַלע_, měty_, ееше_,
  { {0x20d5007a,0x25a90f65,0x6fe00042,0x00000000}},	//   _búið_, ocal_, _नारं,
  { {0xb87b0016,0xfde6005a,0x9f5e017d,0x00000000}},	//   luíd, едък_, _satã_,
  { {0xfa8a008d,0x6a7d006c,0xdb1801c8,0x00000000}},	//   _gẫy_, réfl, _deví,
  { {0xb87b017d,0xbc62000d,0x26cc5576,0x00000000}},	//   nuíd, лвык, ádok_,
  { {0xab5c001c,0x68f65577,0x38710066,0x00000000}},	//   taļa, _spyd, dozr_,
  { {0xa96a0001,0xd9460002,0xade9007e,0x00000000}},	//   зима_, ееми, _رفتم_,
  { {0x64490078,0x497a0085,0x9d44005d,0x00000000}},	//   _įein, ясоў_, _لئون,
  { {0x68300137,0x7e7b5578,0xed56009a,0x00000000}},	//   _räds, llup, _אבנר_,
  { {0xb5fb0026,0xfbd20063,0xcc3a0041,0x00000000}},	//   _sjáa, _עתה_, _מעסט,
  { {0xa49b0268,0xdb0300bd,0xd6270001,0x00000000}},	//   _pròp, _benö, носе_,
  { {0x05660878,0x9f5e017d,0x24980078,0x00000000}},	// [a9a0] хван, _matá_, _pirm_,
  { {0xdb1a000f,0x25a90139,0xfa8a008d,0x00000000}},	//   latá, acal_, _rẫy_,
  { {0xe29a01e8,0x67350051,0x6aab000c,0x00000000}},	//   чае_, cyzj, _înfă,
  { {0xe6460376,0xdb1a5579,0x71a6000d,0x00000000}},	//   _чемп, natá, хадз,
  { {0xb87b0016,0xe61f008b,0x765624e8,0x00000000}},	//   buíd, _khôn_, miyy,
  { {0x69c6557a,0x38a6001f,0xdb1a00ea,0x00000000}},	//   hake, _môr_, hatá,
  { {0x4444018d,0x69c6021f,0xdb1a013d,0x00000000}},	//   mh_, kake, katá,
  { {0x76560222,0x44442175,0x644b008f,0x00000000}},	//   niyy, lh_, īgie,
  { {0x2d820031,0x9f5e0139,0x806601dd,0x00000000}},	//   åke_, _datá_, _зваж,
  { {0x444400aa,0x9f470a63,0xdb0a0026,0x00000000}},	//   nh_, lený_, _vefþ,
  { {0x3fc9007e,0x4444557b,0x2902056c,0x00000000}},	//   _آگهی_, ih_, ewka_,
  { {0x9f470024,0xb5fb000f,0xdb1a000f,0x00000000}},	//   nený_, _aján, gatá,
  { {0x38a626be,0xc2130047,0x76410078,0x00000000}},	//   _côr_, אהר_, ūlyk,
  { {0x2c160161,0x7644002c,0x79840051,0x00000000}},	//   ताओं_, ehiy, _dziw,
  { {0x4444018d,0xb87b557c,0x29040026,0x00000000}},	//   dh_, ktív, æmar_,
  { {0x4b7b0149,0x387f0164,0x9f470240,0x00000000}},	//   _מאוו, œur_, jený_,
  { {0xb87b0016,0x9f470240,0x7c3a0dde,0x00000000}},	// [a9b0] tuíd, dený_, oktr,
  { {0x4444057a,0x25a9264a,0xf36750bd,0x00000000}},	//   gh_, scal_, нтен,
  { {0xb87b444c,0x93190021,0x7c2800ca,0x00000000}},	//   ruíd, بقاء_, ijdr,
  { {0xd6d80086,0x4444557d,0x61e22033,0x00000000}},	//   _ять_, ah_, ggol,
  { {0x4444018d,0x661d557e,0x660d005b,0x00000000}},	//   bh_, _insk, mdak,
  { {0xdb0a00bd,0xdb1a00ea,0xb87b38c2,0x00000000}},	//   _befü, zatá, atív,
  { {0xe8220053,0x9f47004a,0x4032007b,0x00000000}},	//   माता_, bený_, рејс,
  { {0x660d23c1,0x9f47557f,0x29020051,0x00000000}},	//   ndak, cený_, ywka_,
  { {0x69c60213,0x7e7b0360,0xbc6514b4,0x00000000}},	//   vake, rlup, квик,
  { {0x7e7b0026,0xe0c7007e,0xddc90051,0x00000000}},	//   slup, یز_, wień,
  { {0xdb1a000f,0x2fc718ab,0xdb0a00bd,0x00000000}},	//   tatá, mang_, _gefü,
  { {0x2fc75580,0x3eaa0a63,0x38a6017d,0x00000000}},	//   lang_, žité_, _pôr_,
  { {0xdb1a3d3b,0x2fc7008d,0x1d0912ab,0x00000000}},	//   ratá, oang_, _цели_,
  { {0x69c65581,0x2fc73534,0x3ff90047,0x00000000}},	//   sake, nang_, ופֿע,
  { {0x6e3b00ac,0xdb1a00ea,0x2fc7055f,0x00000000}},	//   okub, patá, iang_,
  { {0x2fc715c4,0x0936000d,0x645700cd,0x00000000}},	//   hang_, _ахоў, eixi,
  { {0x69c4001c,0x2fc7437c,0x6e3b0035,0x00000000}},	// [a9c0] _ieie, kang_, ikub,
  { {0xb5fb007a,0x2fc70397,0xdb03017d,0x00000000}},	//   _hjál, jang_, _fenô,
  { {0x2fc70e53,0x7bc35582,0x9f470024,0x00000000}},	//   dang_, _menu, tený_,
  { {0x6aa30150,0x78a4065c,0x62895583,0x00000000}},	//   _munf, _kuiv, _cheo,
  { {0x9f470024,0x78a40003,0x61e25584,0x00000000}},	//   rený_, _juiv, rgol,
  { {0xb87b0016,0x69c45585,0xa07324ad,0x00000000}},	//   stív, _leie, агіч,
  { {0xb87b22da,0x9f471ca9,0x2d8020b4,0x00000000}},	//   quíe, denó_, _šie_,
  { {0x27ed0117,0x69c4003d,0x2fc700a4,0x00000000}},	//   đeni_, _neie, aang_,
  { {0xf653014e,0x2fc718a5,0x7bc35586,0x00000000}},	//   יצה_, bang_, _benu,
  { {0x2fc7014f,0x660d5587,0x21750001,0x00000000}},	//   cang_, zdak, _суср,
  { {0xdb1800ea,0x69c40d13,0x201e4d09,0x00000000}},	//   _bevá, _beie, _inti_,
  { {0x200c10ca,0xdb1a0058,0x6aa30168,0x00000000}},	//   _hadi_, hatç, _dunf,
  { {0x9f5c00cd,0x6a7d09ed,0x200c09c9,0x00000000}},	//   devé_, néfi, _kadi_,
  { {0x200c014f,0x78a4006f,0x7bc3404f,0x00000000}},	//   _jadi_, _duiv, _genu,
  { {0xf1bf027d,0x69c40ded,0x7bc85588,0x00000000}},	//   áška_, _feie, madu,
  { {0xb0d20235,0x27ed0080,0x7bc3006f,0x00000000}},	//   _सिंग, řen_, _zenu,
  { {0x62890185,0x2fc718b1,0x201e5589,0x00000000}},	// [a9d0] _rheo, yang_, _onti_,
  { {0x62890027,0x6a7d0003,0x2e380003,0x00000000}},	//   _sheo, défi, _défi_,
  { {0x2fc70250,0x78a4006f,0xd3a40121,0x00000000}},	//   vang_, _zuiv, рруп,
  { {0x2fc731e6,0x7bc8558a,0x661d2375,0x00000000}},	//   wang_, hadu, _unsk,
  { {0x2fc72fbe,0x7bc81846,0x40351c9d,0x00000000}},	//   tang_, kadu, ледс,
  { {0x7bc80004,0x2fc70bbf,0xab5c008f,0x00000000}},	//   jadu, uang_, taļl,
  { {0x2fc72ff8,0x64540001,0x7bc81167,0x00000000}},	//   rang_, _тврђ, dadu,
  { {0xc33200b7,0x7bc80004,0x60d600eb,0x00000000}},	//   _פון_, eadu, šyma,
  { {0x7bc30e53,0x2fc718a5,0xb87b16eb,0x00000000}},	//   _penu, pang_, ntís,
  { {0xb5fb007a,0x78a4017d,0x69c4558b,0x00000000}},	//   _sjál, _ruiv, _seie,
  { {0x78a403b2,0x2c55004c,0x3f85004c,0x00000000}},	//   _suiv, vědě_, _uzlu_,
  { {0x7bc801a9,0x7bc30022,0xb87b013d,0x00000000}},	//   aadu, _wenu, ztít,
  { {0x69c4328b,0xed5906bb,0x7bc3558c,0x00000000}},	//   _veie, kaži_, _tenu,
  { {0x69c400e8,0x7aec00ea,0x7bc82264,0x00000000}},	//   _weie, öltö, cadu,
  { {0x461a000d,0x69c4004b,0x61e9558d,0x00000000}},	//   нцаў_, _teie, _ocel,
  { {0x3ea50529,0xdb180d02,0xd5ed0013,0x00000000}},	//   _mult_, _bevæ, goà,
  { {0xdb0a0026,0xddc9001c,0x448a1225,0x00000000}},	// [a9e0] _hefð, pieņ, ебан_,
  { {0x61e9558e,0x480601dd,0xe5771636,0x00000000}},	//   _acel, _спов, узу_,
  { {0xddc9027c,0x3a2000f5,0x200c558f,0x00000000}},	//   dlež, _knip_, _radi_,
  { {0xb87b004a,0xddc900a8,0x26cc01c8,0x00000000}},	//   stít, elež, ádou_,
  { {0x200c003e,0x4431039f,0x7ae15590,0x00000000}},	//   _padi_, _foz_, hult,
  { {0xddc900c2,0x648b017d,0x7ae10543,0x00000000}},	//   glež, güid, kult,
  { {0xab610019,0x7ae106a5,0x3ea55591,0x00000000}},	//   öüle, jult, _cult_,
  { {0x7bc80089,0x5375005e,0x9f4701f4,0x00000000}},	//   wadu, _ђурђ, tenò_,
  { {0x21670138,0x51660088,0x7bc80016,0x00000000}},	//   _бити_, _сваб, tadu,
  { {0x62980080,0x61e90080,0x201e30ec,0x00000000}},	//   ůvod, _zcel, _unti_,
  { {0x7bc85592,0x3ea50246,0xd5ed0013,0x00000000}},	//   radu, _gult_, hoá,
  { {0x7bc85593,0x7b630121,0xdb030014,0x00000000}},	//   sadu, стье, _ofnæ,
  { {0x3ea50122,0x7bc85594,0xd7fb0065,0x00000000}},	//   _zult_, padu, нув_,
  { {0xb5fb0114,0x7ae135db,0xddc0004c,0x00000000}},	//   _ukáz, bult, nomž,
  { {0xdb0a0026,0xf1bf0024,0xb87b05d5,0x00000000}},	//   _gefð, ššia_, guía,
  { {0x35b55595,0x00000000,0x00000000,0x00000000}},	//   рбар,   ,   ,
  { {0xa3e90053,0x2a690150,0xf5990062,0x00000000}},	// [a9f0] _याद_, _ijab_, тващ_,
  { {0x61e9175f,0xb87b5596,0xa3d50086,0x00000000}},	//   _scel, dríg, рожч,
  { {0x443104a6,0x657d00ac,0xed59242d,0x00000000}},	//   _voz_, _wysh, raži_,
  { {0x27ed017f,0xd5bb0054,0xb6ba0063,0x00000000}},	//   đenu_, _ясо_, _שצרי,
  { {0x3ea50025,0x44315597,0x7ae15598,0x00000000}},	//   _sult_, _toz_, zult,
  { {0xc4f600b5,0xdb1800fe,0x50b8007e,0x00000000}},	//   _דזשי_, _kevä, ادند_,
  { {0x2fc5076c,0x44ef0058,0xf838009a,0x00000000}},	//   _velg_, lü_, רנות_,
  { {0x2ca6002c,0x7ae100fe,0x3ea5006f,0x00000000}},	//   _buod_, vult, _vult_,
  { {0x1c455599,0x660f559a,0xdb180072,0x00000000}},	//   иним, _mack, _levä,
  { {0x660f0780,0x1c1f0053,0xdb950086,0x00000000}},	//   _lack, बाइल_, ишнь,
  { {0x9f4b0072,0xff530049,0xcb6905ef,0x00000000}},	//   älän_, _اخذ_, тане_,
  { {0x660f0ae2,0xb5fb0014,0x7ae1559b,0x00000000}},	//   _nack, _dják, rult,
  { {0xfe700067,0x8d870121,0x7ae1559c,0x00000000}},	//   _عدم_, _сужд, sult,
  { {0xdb180137,0xb87b0516,0x5d840021,0x00000000}},	//   _bevä, tuía, _الهل,
  { {0x66d9435a,0x9656005e,0x660f559d,0x00000000}},	//   льтр_, ађај, _back,
  { {0x2956005a,0x7aee0240,0xdb180066,0x00000000}},	//   _въор, žití, _devä,
  { {0x290c001c,0xb87b559e,0xda65005d,0x00000000}},	// [aa00] ādas_, rtír, _داوي,
  { {0x29370047,0x7d19002b,0x291e008f,0x00000000}},	//   _כאפן_, _mrws, ātad_,
  { {0x660f0d88,0xb87b02fc,0xed59559f,0x00000000}},	//   _fack, quía, mažu_,
  { {0xed59007d,0x24440137,0xb87b3c09,0x00000000}},	//   lažu_, _döma_, nuín,
  { {0x0594006a,0x03a60086,0x3eb9003b,0x00000000}},	//   _دادگ, _виго, _ăsta_,
  { {0x6604007a,0xc0760138,0x764100eb,0x00000000}},	//   leik, шћењ, ūlyt,
  { {0xe7ee0053,0x8f34000d,0x1c1f0042,0x00000000}},	//   _जाना_, сейц, बाईल_,
  { {0xddc90051,0x03670086,0x7d19002b,0x00000000}},	//   mieś, _тиск_, _brws,
  { {0xafe60076,0xed59007d,0x62824c4d,0x00000000}},	//   _возл, kažu_, mloo,
  { {0x660455a0,0x7d19002b,0xdb1a0066,0x00000000}},	//   heik, _drws, matú,
  { {0x9d54007e,0xddc90051,0x62820180,0x00000000}},	//   شنگت, nieś, oloo,
  { {0x6251027d,0x62824d5b,0x7d19002b,0x00000000}},	//   sťov, nloo, _frws,
  { {0xdb180137,0x660f55a1,0x7afd003b,0x00000000}},	//   _sevä, _rack, ăsta,
  { {0xdd3b0063,0x660f55a2,0xd7c901f3,0x00000000}},	//   _בעדכ, _sack, طوره_,
  { {0x628255a3,0x660f2ff6,0xf773014d,0x00000000}},	//   kloo, _pack, زاس_,
  { {0x9f5c0080,0xb87b0268,0xe61f008b,0x00000000}},	//   jeví_, dríe, _khôi_,
  { {0x660f00c7,0x5887000d,0x628200ca,0x00000000}},	// [aa10] _vack, _вына, dloo,
  { {0x62820104,0xe7ee0053,0x3cee0042,0x00000000}},	//   eloo, _जाया_, _आमने_,
  { {0x660f0924,0xa2f50895,0x62820c5f,0x00000000}},	//   _tack, спеч, floo,
  { {0x80db0053,0x628200ca,0xdcee004c,0x00000000}},	//   _निदे, gloo, áděl,
  { {0xe3e9007e,0xdb0a004d,0xd14b007e,0x00000000}},	//   _مکان_, _gefö, خشان_,
  { {0x6e2255a4,0xddc0005f,0x628255a5,0x00000000}},	//   _anob, komų, aloo,
  { {0x62820122,0x7bc70026,0xb87b0139,0x00000000}},	//   bloo, ðjum, huío,
  { {0xf99f0268,0x628209fe,0x11d40021,0x00000000}},	//   ndès_, cloo, _وتقد,
  { {0xec7912b9,0xadf80042,0x00000000,0x00000000}},	//   лпи_, ्ज़न_,   ,
  { {0x1c4502a1,0x30850021,0x6e2255a6,0x00000000}},	//   сном, _الطف, _enob,
  { {0x78b60137,0xcb690131,0x00000000,0x00000000}},	//   _styv, ѓаме_,   ,
  { {0x7d19002b,0xdef60063,0xd356009a,0x00000000}},	//   _trws, _למעט_, מיתי_,
  { {0x66041b74,0x8e740021,0xb87b013d,0x00000000}},	//   veik, _بالض, ttíp,
  { {0x97be0085,0x7d7a009d,0x00000000,0x00000000}},	//   эрмi, _גננו,   ,
  { {0x66044d13,0x7c2355a7,0xa2d30042,0x00000000}},	//   teik, _innr, _डिग्,
  { {0x442300a8,0xb87b013d,0x66040078,0x00000000}},	//   _anj_, stíp, ueik,
  { {0xddc90051,0xab5c008f,0x628200ca,0x00000000}},	// [aa20] wieś, vaļi, vloo,
  { {0x61fb0331,0x7d1d0072,0x232a0f55,0x00000000}},	//   _abul, ässy, лози_,
  { {0x5c5a00b5,0xa5bb006d,0x656f55a8,0x00000000}},	//   נדעק, _inón, _exch,
  { {0xb87b55a9,0x64900019,0x7d091913,0x00000000}},	//   críb, käig, kwes,
  { {0x3af1008b,0xc05a0454,0x21670893,0x00000000}},	//   háp_, лік_, бици_,
  { {0xdb1a0024,0x628255aa,0x6447007d,0x00000000}},	//   ratú, sloo, _glji,
  { {0x645e2400,0xb5fb0026,0x7d09087d,0x00000000}},	//   mipi, _sjái, ewes,
  { {0xbe8a0121,0x0cd8005e,0xbcb40062,0x00000000}},	//   ысле_, адић_, обищ,
  { {0xa49b0268,0x2176000a,0x68e60137,0x00000000}},	//   _pròx, _ѓубр, jukd,
  { {0x645e55ab,0x6c540085,0x6a680058,0x00000000}},	//   nipi, ікну, sıfl,
  { {0x7f860032,0x547b014e,0xa49b00cd,0x00000000}},	//   _الان, רטיו, _isòt,
  { {0xc3332d31,0xfce60076,0xe61f008b,0x00000000}},	//   לות_, _годо, _thôi_,
  { {0x6da303eb,0x645e1846,0x7d960021,0x00000000}},	//   _عموم, kipi, _الشؤ,
  { {0x64900019,0x5c730086,0xeaaf007e,0x00000000}},	//   näid, _еліт, بعی_,
  { {0xab2702d8,0x2bf70aeb,0x466b21e9,0x00000000}},	//   _гоја_, _המון_, грам_,
  { {0x7bca0ac6,0x645e001f,0xdb01004d,0x00000000}},	//   _hefu, eipi, tblö,
  { {0x69cf55ac,0xb87b017d,0xdb03109c,0x00000000}},	// [aa30] mace, luím, _agnè,
  { {0x734b0189,0x645e442e,0x69cf55ad,0x00000000}},	//   лчев_, gipi, lace,
  { {0xe9f9001b,0xe7ee0053,0x16350062,0x00000000}},	//   _giả_, _जाता_, _деня,
  { {0xa294000d,0x7bca013d,0x69cf55ae,0x00000000}},	//   пахі, _lefu, nace,
  { {0x69cf55af,0x7bd8007d,0x6aaa55b0,0x00000000}},	//   iace, _odvu, _luff,
  { {0x44230150,0xdff5013c,0x645e0bb6,0x00000000}},	//   _unj_, іяль, cipi,
  { {0xd1bb0032,0x80db0053,0x985d0022,0x00000000}},	//   _ماذا_, _निवे, _głąb_,
  { {0x69cf30a8,0xee3925d9,0xd25b007b,0x00000000}},	//   jace, рни_, _сцг_,
  { {0x6aaa00bd,0x7bca55b1,0x9f470003,0x00000000}},	//   _auff, _befu, igné_,
  { {0xdfd1007e,0xac390086,0x6aaa1014,0x00000000}},	//   _آيا_, рчих_, _buff,
  { {0x7d094149,0x29000290,0x69cf55b2,0x00000000}},	//   swes, _spia_, face,
  { {0xf2d20047,0x01f90047,0x6aaa55b3,0x00000000}},	//   ועט_, ױפֿל, _duff,
  { {0xfe420086,0x7e7b02e2,0x7e69004e,0x00000000}},	//   _іншо, moup, mnep,
  { {0xbb450076,0x7bca07cf,0xb87b00be,0x00000000}},	//   _мелк, _gefu, buím,
  { {0x2bbf0053,0x07a355b4,0x386d006c,0x00000000}},	//   _श्या, дарн, éera_,
  { {0x38af0cd4,0x0686013c,0xdb030139,0x00000000}},	//   _für_, іган, _ngné,
  { {0x645e55b5,0x29000035,0x75d30021,0x00000000}},	// [aa40] tipi, _upia_, بيقا,
  { {0xe45f0026,0x200755b6,0x764d00a4,0x00000000}},	//   _svör_, jeni_, ahay,
  { {0x41aa026b,0x7e7b0080,0x27e50051,0x00000000}},	//   авен_, koup, ólne_,
  { {0xdb1a07e6,0xb5fb0014,0x764d55b7,0x00000000}},	//   ratø, _sjáv, chay,
  { {0x645e002c,0x6b832e58,0x6490004e,0x00000000}},	//   pipi, _lyng, täid,
  { {0x7e6900a4,0x6616091b,0xd91b0063,0x00000000}},	//   enep, ldyk, יונל,
  { {0x44f4024a,0x444455b8,0x69cf1cbe,0x00000000}},	//   lä_, mk_, yace,
  { {0x66160c47,0xe2a60026,0x3ea201be,0x00000000}},	//   ndyk, óðum_, ökt_,
  { {0x44385016,0x44f4024a,0x69cf01d9,0x00000000}},	//   _kor_, nä_, vace,
  { {0x661600fe,0xb4fb07e9,0x6aaa1b0c,0x00000000}},	//   hdyk, ספיי, _puff,
  { {0x6b830185,0x444455b9,0xef17000a,0x00000000}},	//   _cyng, ik_, _ммф_,
  { {0xb5fb02dd,0xb87b02dd,0x44381e6a,0x00000000}},	//   _imág, dría, _lor_,
  { {0x443810e9,0x44f4024a,0x444455ba,0x00000000}},	//   _oor_, jä_, kk_,
  { {0x444402b0,0x44f400fe,0x44381269,0x00000000}},	//   jk_, dä_, _nor_,
  { {0x6b83001f,0x6490004b,0xb87b0e1f,0x00000000}},	//   _gyng, käib, quím,
  { {0x764d00a4,0x44442f7b,0xa5bb0025,0x00000000}},	//   uhay, ek_, _gnól,
  { {0x7ae800a4,0x764d55bb,0xb87b0331,0x00000000}},	// [aa50] ludt, rhay, aría,
  { {0x7d02175f,0xb87b006d,0x44382771,0x00000000}},	//   _mpos, bría, _cor_,
  { {0xf7700021,0x443855bc,0x7c3800c2,0x00000000}},	//   _لاَ_, _dor_, _movr,
  { {0x6d4000eb,0x7d020b16,0x20070474,0x00000000}},	//   kyma, _opos, weni_,
  { {0x2007000f,0xd49b000a,0x44380cc8,0x00000000}},	//   teni_, _врв_, _for_,
  { {0x7c3800f3,0x6d4000eb,0xf8bf0003,0x00000000}},	//   _novr, dyma, ipé_,
  { {0x7e7b0080,0x200755bd,0x2fd60021,0x00000000}},	//   toup, reni_, سويد_,
  { {0x28dc0161,0x7bce007a,0x8d55005a,0x00000000}},	//   _बिलि, ðbun, зточ,
  { {0x6b8335cd,0xc2120047,0xb5fb00ea,0x00000000}},	//   _syng, _אהן_, _imád,
  { {0xbebc003d,0x2ca30137,0x7e7b0003,0x00000000}},	//   _brīd, öjd_, soup,
  { {0x7c3855be,0x765d1262,0x7d0255bf,0x00000000}},	//   _dovr, _omsy, _epos,
  { {0x6d40001f,0x60c900ac,0x7e600360,0x00000000}},	//   byma, _kwem, cimp,
  { {0x444400e8,0x7ae8004b,0x2bbd0042,0x00000000}},	//   yk_, audt, ोरदा,
  { {0x44f400fe,0x60c90035,0x29dc008b,0x00000000}},	//   vä_, _mwem, ửa_,
  { {0x60c900ac,0x44440ad5,0xdb0a000e,0x00000000}},	//   _lwem, vk_, _affæ,
  { {0x44f409ff,0x443800ea,0xb87b006d,0x00000000}},	//   tä_, _sor_, rría,
  { {0x443842e1,0x764401f7,0x444455c0,0x00000000}},	// [aa60] _por_, rkiy, tk_,
  { {0x7d1b024a,0xd91b0047,0x44440329,0x00000000}},	//   ivus, _פויל, uk_,
  { {0x7d1b0004,0x6d400045,0x443855c1,0x00000000}},	//   hvus, zyma, _vor_,
  { {0x44440f4b,0xd2590636,0x64a60f2e,0x00000000}},	//   sk_, оці_, _нама,
  { {0xf772006a,0xf1a9007e,0x444455c2,0x00000000}},	//   _زاگ_, زانه_, pk_,
  { {0x7d1b0019,0x62990524,0x6d400195,0x00000000}},	//   dvus, amwo, vyma,
  { {0x7d0255c3,0x7e6055c4,0xd6560063,0x00000000}},	//   _spos, timp, ּיִת_,
  { {0x7c3855c5,0x7ae80137,0x6d4055c6,0x00000000}},	//   _sovr, vudt, tyma,
  { {0x644300bd,0xc0e3018e,0x7c38064f,0x00000000}},	//   önig, _потк, _povr,
  { {0x7e600c6f,0x6d4055c7,0x0ab40092,0x00000000}},	//   simp, ryma, мбоџ,
  { {0x69be016a,0x7e60053b,0x60c9006f,0x00000000}},	//   _व्ही, pimp, _zwem,
  { {0x224600ea,0xdb03002b,0x6e39002b,0x00000000}},	//   nkok_, _egnï, _gowb,
  { {0xdcf7007e,0x2e370063,0x7c3800c2,0x00000000}},	//   _فروش_, _מראש_, _tovr,
  { {0xa8a40962,0xf8bf4b27,0x7ea70075,0x00000000}},	//   ерск, rpé_, _tıpt,
  { {0xabfb3997,0xdb1a02d2,0xf1cc0042,0x00000000}},	//   _ההור, natü, ारान,
  { {0xf8bf0164,0x7bc70046,0x9f5e009c,0x00000000}},	//   ppé_, ðjuv, _ható_,
  { {0xb5fb0026,0x9f5c0072,0xdb1a004e,0x00000000}},	// [aa70] _sjás, levä_, hatü,
  { {0xdb1a0058,0xe61f002b,0x6f0d0022,0x00000000}},	//   katü, _chôr_, łaci,
  { {0x64451761,0x3a290146,0x9f5e006d,0x00000000}},	//   rkhi, _knap_, _mató_,
  { {0xdb1a55c8,0x228e0066,0xd370005d,0x00000000}},	//   lató, týka_, دهٔ_,
  { {0xb5fb007a,0xdb1a004b,0xe1f00242,0x00000000}},	//   _fjár, eatü, اسم_,
  { {0x3ea60072,0xc9180063,0xb97c0047,0x00000000}},	//   _aiot_, פחות_, זנדי,
  { {0x23650137,0xb87b0139,0x3ea6006c,0x00000000}},	//   _älj_, hrío, _biot_,
  { {0x7d1b0019,0xdb1a0758,0x3ea6003b,0x00000000}},	//   tvus, ható, _ciot_,
  { {0xe7bf0053,0x7bc5004b,0xdb1a0022,0x00000000}},	//   ्राप, _õhuk, kató,
  { {0x39420006,0x7d1b004b,0xc10401fb,0x00000000}},	//   vyks_, rvus, _سومي,
  { {0x7d1b0ff2,0xb87b3eb1,0x1df90085,0x00000000}},	//   svus, erío, _межы_,
  { {0xb87b0139,0x6e890044,0xff7a009a,0x00000000}},	//   frío, _بنصف_, _וטעמ,
  { {0xdb0a0d88,0xb87b0025,0x8e56009f,0x00000000}},	//   _affä, grío, _קינג_,
  { {0xdb1a55c9,0x6b652274,0x6d9a009d,0x00000000}},	//   gató, _окла, _ובנפ,
  { {0x224d004b,0x27e50022,0xd7f90085,0x00000000}},	//   _olek_, ólna_, чуў_,
  { {0xb87b0027,0x2ca70b34,0x3eb800ea,0x00000000}},	//   brío, _hind_, _érte_,
  { {0xb87b0025,0x2ca755ca,0x33f601d5,0x00000000}},	// [aa80] crío, _kind_, дчес,
  { {0xdb1a55cb,0x22a80058,0xdb18011b,0x00000000}},	//   matò, _aşka_, _levý,
  { {0x38b42ddc,0x65c60e34,0xeb930063,0x00000000}},	//   _här_, _обна, תָּ_,
  { {0x38b40137,0xdb030139,0xddc0008f,0x00000000}},	//   _kär_, _ngní, rimū,
  { {0x3ea63992,0xc05a0054,0x3cf90042,0x00000000}},	//   _riot_, жій_, ्बों_,
  { {0xceba0001,0x46d20053,0x22462b4e,0x00000000}},	//   ољи_, _तबाह, skok_,
  { {0x38b400c7,0x7ed3007e,0xaa86017c,0x00000000}},	//   _lär_, نزيا, _zmýš,
  { {0x9d1408b9,0xdb1a0075,0xbe9700de,0x00000000}},	//   едич, ratü, وضيا_,
  { {0x38b42ddc,0x21670086,0xb87b0195,0x00000000}},	//   _när_, _жити_, rtíz,
  { {0x3a2917e4,0x2ca7003b,0x9f5c0072,0x00000000}},	//   _snap_, _cind_, tevä_,
  { {0x9f5e00cd,0x60c200fe,0x9e3c0114,0x00000000}},	//   _obté_, lpom, _buďt,
  { {0x2ca7016d,0xb87b0025,0x38b40d88,0x00000000}},	//   _eind_, trío, _bär_,
  { {0xdb1a55cc,0x2ca708dc,0xfe9b0063,0x00000000}},	//   tató, _find_, _ויאמ,
  { {0x38b401e3,0x9c570021,0x3c440044,0x00000000}},	//   _där_, _يجوز_, _سَعِ,
  { {0x442d008b,0xdb1a55cd,0x7c2a3040,0x00000000}},	//   _đe_, rató, _infr,
  { {0xb5fb0014,0xe4c70121,0xcb07007e,0x00000000}},	//   _smáb, дёжн, _آيين_,
  { {0xc7c70001,0x60c200c3,0xdb1a00cd,0x00000000}},	// [aa90] _осни, jpom, catò,
  { {0x69db0026,0x60c200c2,0xe8d80063,0x00000000}},	//   ðuef, dpom, _חוזר_,
  { {0x224d1a20,0x7c250014,0xdb18013d,0x00000000}},	//   _plek_, _óhre, _nevü,
  { {0xeb910047,0xd6d80054,0x644e55ce,0x00000000}},	//   אָד_, _ють_, _elbi,
  { {0x7c2a24b9,0x3af8008b,0xc0e50086,0x00000000}},	//   _onfr, hép_, холк,
  { {0x64900659,0x3af800ea,0x41740021,0x00000000}},	//   läin, kép_, خامس,
  { {0x9f50007a,0x60c21058,0x2ca755cf,0x00000000}},	//   ðaðu_, apom, _rind_,
  { {0x2ca755d0,0x7c2a0199,0x439408a6,0x00000000}},	//   _sind_, _anfr, _расс,
  { {0x2ca755d1,0x99820022,0x660d0022,0x00000000}},	//   _pind_, zekł_, ieak,
  { {0xfc310032,0x628b08de,0x64900072,0x00000000}},	//   احة_, llgo, häin,
  { {0x2ca7021f,0x3af800ea,0x660d55d2,0x00000000}},	//   _vind_, gép_, keak,
  { {0xee2e0088,0xdb1a00cd,0x7c2a100f,0x00000000}},	//   _ён_, tatò, _enfr,
  { {0xed4e55d3,0x660d55d4,0x2ca700dd,0x00000000}},	//   _со_, deak, _tind_,
  { {0x26de017f,0xdb1a00cd,0xccf2009a,0x00000000}},	//   štom_, ratò, _עכו_,
  { {0x8696000a,0x96960d3e,0x38b4004d,0x00000000}},	//   ејач, ераш, _wär_,
  { {0x660d01e1,0x60c20022,0xcd03004c,0x00000000}},	//   geak, ypom, aměť_,
  { {0x442a55d5,0x999e0006,0xa5072254,0x00000000}},	// [aaa0] _pnb_, ėtų_, нета_,
  { {0x78fb014e,0x628b006f,0x3957089e,0x00000000}},	//   _צפיו, elgo, _נשים_,
  { {0xb8f30235,0x47f7009a,0x237600de,0x00000000}},	//   ही_, _אציל_, رائح,
  { {0x78690006,0x2377007e,0xdb010e7c,0x00000000}},	//   ržve, رمند_, lcló,
  { {0x7d1c001c,0x442a0089,0x3af800ea,0x00000000}},	//   ārsk, _tnb_, zép_,
  { {0x60c2051e,0xf99300ff,0x10a308b0,0x00000000}},	//   rpom, ארד_, гичн,
  { {0x91e60794,0x62540022,0x777755d6,0x00000000}},	//   _пове, eżoś, _xxxx,
  { {0x9df70062,0xb87b05ab,0x7f4714d7,0x00000000}},	//   енът_, quív, عليق_,
  { {0x5c741fc6,0x6ecc0042,0x28dc55d7,0x00000000}},	//   клит, _सबकु, _बिगि,
  { {0xf4f700b5,0x8fa60cbb,0x46e10053,0x00000000}},	//   עזיש_, _зазе, _फिलह,
  { {0x628255d8,0xdb181358,0x26de0130,0x00000000}},	//   oooo, _revó, štoj_,
  { {0x3af8013d,0x200e0058,0x00000000,0x00000000}},	//   rép_, lefi_,   ,
  { {0x64900072,0x8c4605ce,0xa30d0082,0x00000000}},	//   väin, _педе, _सन्ज_,
  { {0xb87b006d,0x7c2a55d9,0xdd8f01f3,0x00000000}},	//   prím, _unfr, _اوه_,
  { {0x45d54ba4,0x3ea90066,0x333355d6,0x00000000}},	//   ковс, ňate_, xxxx_,
  { {0xbb77009a,0x65950085,0xc6900044,0x00000000}},	//   _רעהו_, вабу, مِّ_,
  { {0x649000fe,0xdb200026,0xb87b0014,0x00000000}},	// [aab0] räin, ðtæk, nrík,
  { {0x649000fe,0xd131007e,0x7ae855da,0x00000000}},	//   säin, یما_, ordt,
  { {0xf6990fe2,0x28b70053,0x200e005b,0x00000000}},	//   _овој_, _इंडि, defi_,
  { {0x7bc5004b,0x7ae8013d,0x1fbb0042,0x00000000}},	//   _õhuv, irdt, ॉर्ड,
  { {0x68fd55db,0x25d6009a,0xd4b80085,0x00000000}},	//   ntsd, _שושן_, _пляц_,
  { {0xb144000d,0x68fd0206,0x2f110023,0x00000000}},	//   ыніл, itsd, _pšg_,
  { {0x647405ac,0x43940320,0x13940121,0x00000000}},	//   _сгру, _барс, _бирю,
  { {0xa295000d,0xdb030139,0x68fd446b,0x00000000}},	//   _рабі, _ngná, ktsd,
  { {0x60db0035,0xb87b006d,0xc0150062,0x00000000}},	//   _uvum, rríj, _имащ,
  { {0x26de00ea,0x7e620150,0x1c450065,0x00000000}},	//   átok_, _emop, тном,
  { {0xb87b0066,0x9f040049,0x3df50002,0x00000000}},	//   príj, _مولو, _азес,
  { {0x3f64005e,0x68fd55dc,0xa96a031e,0x00000000}},	//   _стуб, ftsd, дима_,
  { {0x68fd00b9,0x2d8200ea,0x7ae80983,0x00000000}},	//   gtsd, üket_, ardt,
  { {0xed560138,0x66e60079,0x1d060ab1,0x00000000}},	//   _још_, кога, _реши_,
  { {0x1779015a,0xb5fb0014,0x68fd24f5,0x00000000}},	//   есть_, _smáa, atsd,
  { {0xe5f3000c,0x6028001c,0xdb010139,0x00000000}},	//   văţă, _zīmē, scló,
  { {0x628200ac,0x46a3000d,0x2a79013d,0x00000000}},	// [aac0] vooo, ратв, érbe_,
  { {0xd7ca007e,0xba3b002b,0xa494005d,0x00000000}},	//   _توده_, rmïe, ایست,
  { {0x3e7a008f,0x00000000,0x00000000,0x00000000}},	//   līte_,   ,   ,
  { {0xb87b00ed,0xe5f3003b,0xbebc008f,0x00000000}},	//   suít, răţă, _brīn,
  { {0x24440026,0x64900072,0xf8bf013d,0x00000000}},	//   _sömu_, läim, rvég_,
  { {0x321d001f,0xdcf50080,0xb87b017d,0x00000000}},	//   adwy_, ůběh, luír,
  { {0xe8e0001b,0x200e0762,0x43750054,0x00000000}},	//   _ước_, refi_, _бутт,
  { {0xb87b09dd,0xf7730063,0x877b069a,0x00000000}},	//   nuír, יקו_, ואצי,
  { {0xdb1a55dd,0xbebc0023,0x5ea30044,0x00000000}},	//   natö, _grīn, جميل,
  { {0xb87b0026,0x6490004b,0xcf260044,0x00000000}},	//   rrík, käim, _لرصي,
  { {0x3d170042,0xdb1a004b,0xb87b0014,0x00000000}},	//   _बैठे_, hatö, srík,
  { {0xb87b0024,0x4d4a0141,0x28b70042,0x00000000}},	//   prík, _опен_, _इंदि,
  { {0xdb1a004b,0x1e57009a,0x8e6b009a,0x00000000}},	//   jatö, _בשאר_, _קֳבֵ,
  { {0xdddb0058,0x68fd169f,0x98a0011b,0x00000000}},	//   onuş, rtsd, _frič_,
  { {0x386d0117,0x44d00045,0x64900072,0x00000000}},	//   đer_, eń_, räil,
  { {0xa5bb0139,0xdb1a0014,0x649001cf,0x00000000}},	//   _nnót, fatö, säil,
  { {0x64900072,0xdb0a01e1,0x35b4295d,0x00000000}},	// [aad0] päil, _affø, рбур,
  { {0x7bc50019,0xf1b900a8,0x54540500,0x00000000}},	//   _õhut, _maše_, авут,
  { {0x6aad0035,0x12b40021,0x320f55de,0x00000000}},	//   _kiaf, لإنج, tegy_,
  { {0xe45f00c7,0xddc9003b,0x415512b9,0x00000000}},	//   _stöd_, ineţ, лвес,
  { {0x9105014c,0xc7b8007d,0xb87b0516,0x00000000}},	//   упле, žđe_, quís,
  { {0x244400a5,0x661d1b0c,0xc0c80085,0x00000000}},	//   _döms_, _hask, туце_,
  { {0x661d39ff,0x6490004b,0xaed202f8,0x00000000}},	//   _kask, käij, бојш,
  { {0x765800eb,0xa5bb0025,0x661d27f1,0x00000000}},	//   _įvyk, _gnót, _jask,
  { {0x798d0397,0x661d06a3,0x44fd0290,0x00000000}},	//   _nyaw, _mask, nì_,
  { {0x661d0b3d,0xec7605ac,0x98a2005f,0x00000000}},	//   _lask, лпы_, vykį_,
  { {0x44fd008b,0x56940121,0x76560050,0x00000000}},	//   hì_, ва́т, yhyy,
  { {0xceb2014e,0x63bb005b,0x661d43c5,0x00000000}},	//   _היא_, _şunl, _nask,
  { {0x82760047,0x1d090062,0xfce538ff,0x00000000}},	//   רערע_, _чели_, _соло,
  { {0x6e3b1312,0x7e690006,0x44fd0290,0x00000000}},	//   ljub, liep, dì_,
  { {0x26de01c2,0x2875000d,0x661d209e,0x00000000}},	//   éto_, рыяр, _bask,
  { {0xdb1a55df,0x9655005e,0x78690078,0x00000000}},	//   tatö, ађуј, ržva,
  { {0x7bc50019,0xb87b017d,0x661d007d,0x00000000}},	// [aae0] _õhus, ruír, _dask,
  { {0xdb1a55e0,0xf8bf0164,0x764d00a4,0x00000000}},	//   ratö, uvée_, akay,
  { {0x37750076,0xf8bf0164,0x6e3b0360,0x00000000}},	//   _выяс, rvée_, kjub,
  { {0x44fd01f4,0x661d27f4,0xdb1a2071,0x00000000}},	//   bì_, _gask, patö,
  { {0xf772007e,0x91e355e1,0x7e6901af,0x00000000}},	//   _خاک_, соче, diep,
  { {0x69d602dd,0x22950147,0x61430001,0x00000000}},	//   _leye, råka_, сеља,
  { {0xe296000a,0x752400ea,0xe51c0053,0x00000000}},	//   _браќ, lviz, निकि_,
  { {0x6490004b,0xf1b90734,0xe8040042,0x00000000}},	//   käik, _paše_, श्ता_,
  { {0xacb40001,0x6aad01f4,0x6604004b,0x00000000}},	//   јбољ, _riaf, ifik,
  { {0xf1b955e2,0x752455e3,0xb5fb55e4,0x00000000}},	//   _vaše_, iviz, _amál,
  { {0x798d0089,0x04370047,0x69d655e5,0x00000000}},	//   _syaw, אטיש_, _beye,
  { {0xc333014e,0x201e55e6,0xed5a0062,0x00000000}},	//   צור_, _hati_, _пое_,
  { {0x201e0009,0x661d55e7,0xa5bb0139,0x00000000}},	//   _kati_, _rask, _onór,
  { {0x661d003d,0x201e0397,0x7afd003b,0x00000000}},	//   _sask, _jati_, ăstr,
  { {0x661d55e8,0x66040232,0x7bda55e9,0x00000000}},	//   _pask, ffik, matu,
  { {0xdb1800bd,0x201e55ea,0x7bc5004b,0x00000000}},	//   _bevö, _lati_, _õhur,
  { {0xdddb0080,0x752400ea,0xf5340002,0x00000000}},	// [aaf0] nouš, gviz, бетќ,
  { {0x7d1d0146,0x44fd3ddd,0x201e55eb,0x00000000}},	//   æssi, rì_, _nati_,
  { {0x44fd0290,0x56950086,0x629b055f,0x00000000}},	//   sì_, _вант, _phuo,
  { {0x7bda1212,0xdddb0080,0x1af70047,0x00000000}},	//   hatu, kouš, רמאל_,
  { {0x26de0024,0x7bda55ec,0xb6040024,0x00000000}},	//   átov_, katu, íšet,
  { {0xd0091321,0x648b0813,0x6d5b0058,0x00000000}},	//   теке_, güit, vzua,
  { {0x7e690122,0x201e55ed,0x7bda55ee,0x00000000}},	//   tiep, _dati_, datu,
  { {0xa267011c,0xa0c5006a,0xfe45000a,0x00000000}},	//   _съгл, _نيرو, рнио,
  { {0x69d655ef,0x6e3b0360,0x6f1a04d3,0x00000000}},	//   _reye, rjub, _estc,
  { {0x40870076,0x7e690229,0xeb100053,0x00000000}},	//   _субб, siep, ़बूत_,
  { {0x4421018d,0x66040045,0xceeb007e,0x00000000}},	//   idh_, yfik, _سران_,
  { {0x8f440121,0x6926007f,0x7bda0656,0x00000000}},	//   _ухуд, амма, aatu,
  { {0x7bda0004,0x8e84009e,0x0dc80062,0x00000000}},	//   batu, _النه, _сухи_,
  { {0x6c790047,0x7d1c001c,0x7bda28af,0x00000000}},	//   _שאַפ, ārst, catu,
  { {0x45d6086c,0x61fb0b16,0x3e7a008f,0x00000000}},	//   ицат, _ocul, līta_,
  { {0x66040035,0x645555f0,0xc87f004d,0x00000000}},	//   ufik, _alzi, wußt_,
  { {0x66040397,0x3e7a001c,0x44664b61,0x00000000}},	// [ab00] rfik, nīta_, авав,
  { {0x752402f6,0x3eaf10ce,0x61fb55f1,0x00000000}},	//   rviz, _ligt_, _acul,
  { {0x3a200812,0x201e55f2,0xa6ca0021,0x00000000}},	//   _kaip_, _rati_, _جوجل_,
  { {0x44210027,0x201e017f,0x290200fe,0x00000000}},	//   adh_, _sati_, otka_,
  { {0xb87b0016,0x7bda0052,0x201e55f3,0x00000000}},	//   rrív, yatu, _pati_,
  { {0x3e7a003d,0x7ee60076,0x26de004a,0x00000000}},	//   dīta_, ацие, štou_,
  { {0x7bda55f4,0xd4671213,0xa2e3085e,0x00000000}},	//   vatu, _тире_, _морд,
  { {0x7bda25e5,0xf53f0838,0x61fb0139,0x00000000}},	//   watu, _igår_, _gcul,
  { {0xdd970076,0x7bda55f5,0x3eaf01e1,0x00000000}},	//   ишь_, tatu, _digt_,
  { {0xe5710063,0x9c380002,0xddc908cf,0x00000000}},	//   לַי_, упот_, rneš,
  { {0xb5fb0026,0xee3a0062,0xfee90021,0x00000000}},	//   _smám, _инж_, _معنى_,
  { {0xdddb0080,0x3ced0611,0xaa67019c,0x00000000}},	//   pouš, brev_, рток,
  { {0x7bda55f6,0x3e7a0023,0xe9443f17,0x00000000}},	//   patu, cīta_, охро,
  { {0x27ed0199,0x58870088,0xac93000d,0x00000000}},	//   ßen_, рыма, _даіш,
  { {0x3ea4004d,0x290255f7,0x64430072,0x00000000}},	//   ommt_, atka_, önim,
  { {0xe654019d,0x27ed005b,0x9f5c006d,0x00000000}},	//   овсь, şen_, levó_,
  { {0x26c50006,0xf1b90d76,0xc7b8007d,0x00000000}},	// [ab10] ūlo_, _naša_, žđa_,
  { {0x69dd55f8,0x84340086,0x57f50c45,0x00000000}},	//   lase, онує, _упот,
  { {0x94a81001,0xbebc001c,0x26de00ea,0x00000000}},	//   ртта_, _drīk, átot_,
  { {0x69dd3a29,0x7bd8006c,0xe1d90054,0x00000000}},	//   nase, _levu, удді_,
  { {0xe4a7000a,0x3eaf00b9,0xe4e40603,0x00000000}},	//   _врво, _rigt_, _мірн,
  { {0x69dd55f9,0x3eaf00b9,0x32d9007e,0x00000000}},	//   hase, _sigt_, _مدرک_,
  { {0x2a690019,0x2d8f01e1,0x69dd55fa,0x00000000}},	//   _omab_, _syge_, kase,
  { {0x3e7a001c,0xdddb3692,0x69dd55fb,0x00000000}},	//   tīta_, služ, jase,
  { {0x4155000d,0x7bd801f4,0x2d9904aa,0x00000000}},	//   _увас, _bevu, åse_,
  { {0x2d91001c,0x3e7a008f,0x69dd55fc,0x00000000}},	//   āze_, rīta_, ease,
  { {0x3b090001,0x7bd84901,0x5f950021,0x00000000}},	//   ћемо_, _devu, _الائ,
  { {0x69dd55fd,0x61f9001f,0x7bce0014,0x00000000}},	//   gase, ngwl, ðbur,
  { {0xa3d70235,0x7e7e00ea,0x31790047,0x00000000}},	//   सरा_, éppe, ראָד,
  { {0x7bd80983,0x29025127,0x69dd0b49,0x00000000}},	//   _gevu, rtka_, aase,
  { {0x3a2000eb,0x69dd0f98,0x2902365c,0x00000000}},	//   _taip_, base, stka_,
  { {0x7bc10717,0x69c10080,0x69dd55fe,0x00000000}},	//   lclu, ělec, case,
  { {0x291e001c,0x3ae3005b,0xb87b55ff,0x00000000}},	// [ab20] ātas_, lıp_, trít,
  { {0x7bc10bea,0x2eee002b,0xdceb0078,0x00000000}},	//   nclu, yrff_, _lygį,
  { {0x68e40146,0xa49b00cd,0x3ae3005b,0x00000000}},	//   _hvid, _apòs, nıp_,
  { {0x20070026,0x21a60002,0x52750002,0x00000000}},	//   efni_, бием, оучу,
  { {0x7bc3002b,0xb87b017c,0xa225005d,0x00000000}},	//   _ofnu, prít, ترله,
  { {0xf1b95600,0x3ae30058,0x69dd1a96,0x00000000}},	//   _vaša_, kıp_, zase,
  { {0x764600eb,0x69dd005b,0x7bd85601,0x00000000}},	//   _koky, yase, _revu,
  { {0x5d540062,0x20070014,0x7bc1213a,0x00000000}},	//   жкит, afni_, eclu,
  { {0x764600eb,0xb5fb0026,0x69dd5602,0x00000000}},	//   _moky, _smák, vase,
  { {0x40960032,0x69c4162d,0xa157009a,0x00000000}},	//   _الطر, _afie, _הבמה_,
  { {0xfbaa0121,0x6a15111b,0x68e45603,0x00000000}},	//   ытий_, омну, _avid,
  { {0x7bc30046,0x5f37009a,0x00000000,0x00000000}},	//   _efnu, _לטבע_,   ,
  { {0xd90f006a,0x644301bb,0x3e7a008f,0x00000000}},	//   رید_, önik, līto_,
  { {0x69dd0d9e,0x9f450139,0x68e45604,0x00000000}},	//   sase, _gcló_, _dvid,
  { {0x7ac632b9,0x69dd5605,0x68e4169b,0x00000000}},	//   _усле, pase, _evid,
  { {0x8afc0045,0xda7b0062,0x6f4b009a,0x00000000}},	//   rzęd, _щял_, אֲמַ,
  { {0x6e2200d1,0x95c8439c,0x286b01ce,0x00000000}},	// [ab30] _maob, суса_, _брно_,
  { {0xa3a7018e,0xa394004c,0xe4150085,0x00000000}},	//   бјек, _důžé_, юдзь,
  { {0x69c4002b,0xb867005d,0x68e401d1,0x00000000}},	//   _yfie, _ناگو, _zvid,
  { {0x3e7a001c,0xb87b0024,0xe1f00021,0x00000000}},	//   dīto_, prís, فسه_,
  { {0x7bc1006f,0x3ae30058,0x83d50044,0x00000000}},	//   yclu, zıp_, _ويحص,
  { {0x3ae3005b,0x7bc15606,0x7ff501fb,0x00000000}},	//   yıp_, xclu, زستا,
  { {0x8fa206b4,0xb87b0331,0x4fa2005e,0x00000000}},	//   маше, nríq, мишв,
  { {0x24890078,0x2f015607,0x5e490330,0x00000000}},	//   žimą_, róg_, рпим_,
  { {0x44230198,0x64470117,0x628b146f,0x00000000}},	//   _kaj_, _koji, mogo,
  { {0x3ae3005b,0x3d090053,0x6d460072,0x00000000}},	//   tıp_, _वहीं_, äkaa,
  { {0x649000fe,0x68e40ef0,0x229c5608,0x00000000}},	//   päiv, _svid, líka_,
  { {0x7bc1203d,0x64475609,0xc9aa27b5,0x00000000}},	//   sclu, _loji, ивне_,
  { {0xec6e005a,0x66160072,0x229c560a,0x00000000}},	//   _жп_, veyk, níka_,
  { {0x44230198,0x64900019,0x6ca7005a,0x00000000}},	//   _naj_, näit, _уреж,
  { {0xf1b900c3,0x661600fe,0x3b060086,0x00000000}},	//   _našo_, teyk, _дещо_,
  { {0x68e400d1,0x61e94cb5,0xc7a30141,0x00000000}},	//   _tvid, _ndel, фиск,
  { {0x64900019,0x68e4027d,0x628b1246,0x00000000}},	// [ab40] käit, _uvid, dogo,
  { {0x442300e3,0x61e9560b,0x0496000d,0x00000000}},	//   _caj_, _adel, іраў,
  { {0x26050235,0xb724007e,0x7c2302c3,0x00000000}},	//   _हॉकी_, _عکسه, _manr,
  { {0x7afd0045,0xd62a0001,0x6b7a00b5,0x00000000}},	//   ństw, _томе_, ברענ,
  { {0x61e9001f,0xfe790080,0xb87b0025,0x00000000}},	//   _ddel, dnů_, isín,
  { {0x291210ca,0x399b00b5,0x6e22017f,0x00000000}},	//   _mpya_, בינד, _saob,
  { {0x6e2200a4,0xf8bf013d,0xcf260021,0x00000000}},	//   _paob, evél_, ترشي,
  { {0x00ca0062,0x7c230983,0xc7b30063,0x00000000}},	//   _влак_, _aanr, ובו_,
  { {0x99800080,0x3e7a001c,0x212d0605,0x00000000}},	//   _aniž_, sīto_, _greh_,
  { {0x7c23001f,0x61e90384,0x64900b75,0x00000000}},	//   _canr, _zdel, mäis,
  { {0x6e220025,0x649000fe,0x61e900b9,0x00000000}},	//   _taob, läis, _ydel,
  { {0xbebc001c,0xf1b10053,0xfe72009b,0x00000000}},	//   _brīv, ुँचन, _غدا_,
  { {0x649000fe,0xddc2003b,0x7eb50078,0x00000000}},	//   näis, _emoţ, _išpa,
  { {0x7c23001f,0x8afc0022,0xd918014b,0x00000000}},	//   _ganr, rzęb, цью_,
  { {0x6447006d,0xf6470636,0xe9f90013,0x00000000}},	//   _roji, охан, _chả_,
  { {0x44230198,0x64900072,0xf1b90078,0x00000000}},	//   _saj_, käis, _rašo_,
  { {0x64470080,0x14f5000d,0xf8bf004c,0x00000000}},	// [ab50] _poji, язаў, ovém_,
  { {0xb87b0027,0x8afc0051,0xf8bf017d,0x00000000}},	//   msío, częc, nvém_,
  { {0x60c90844,0x8c1b0063,0xb87b0025,0x00000000}},	//   _stem, שובי, lsío,
  { {0xf1b90198,0xd370006a,0xb87b017d,0x00000000}},	//   _vašo_, خهٔ_, juíz,
  { {0x44230117,0x64900019,0x61e900c2,0x00000000}},	//   _taj_, täit, _vdel,
  { {0x44b4005a,0x94ba0063,0x1beb0053,0x00000000}},	//   _обяс, _למשת, _फ़ाइल_,
  { {0x628b560c,0x0018000d,0x13590044,0x00000000}},	//   pogo, іўшы_, _الأخ_,
  { {0x212d00c3,0xa77c0063,0x7c232dba,0x00000000}},	//   _treh_, ירופ, _sanr,
  { {0x5fcf0053,0x60c9560d,0x61e40014,0x00000000}},	//   _स्थल, _utem, ðile,
  { {0x71880063,0xf8bf0026,0xab65560e,0x00000000}},	//   _וְעַ, rvél_, звол,
  { {0xf98900b7,0x69c10080,0x7c23007d,0x00000000}},	//   _ער_, ělen, _vanr,
  { {0xdce7005b,0x69c10051,0x8f9a0063,0x00000000}},	//   şlık, ślen, _היעי,
  { {0x7c23005b,0x39360085,0x5e440044,0x00000000}},	//   _tanr, чэнс, _تَنْ,
  { {0x64900213,0xe9f90013,0xb87b00be,0x00000000}},	//   häir, _phả_, ssín,
  { {0x2bd1016a,0x07a300e1,0x186700e1,0x00000000}},	//   _द्या, еарн, чари_,
  { {0x6b9c00bd,0x7e7b1045,0x00000000,0x00000000}},	//   ürge, nnup,   ,
  { {0x05662d9b,0x14c8006a,0xcaa503eb,0x00000000}},	// [ab60] чван, زهای_, _تصوي,
  { {0xe9f9008b,0x07a60002,0xb87b017d,0x00000000}},	//   _thả_, _напн, nsíl,
  { {0xdc9a00b5,0x67bb0063,0x130a0a7d,0x00000000}},	//   ציעל, _למיק, сней_,
  { {0x649000fe,0xf1260086,0xb5fb0014,0x00000000}},	//   täis, зько, _smáv,
  { {0xc5f30ca4,0x1fb80121,0x69c6560f,0x00000000}},	//   _אדר_, оллы_, icke,
  { {0x649000fe,0x5f9401f6,0x859b009a,0x00000000}},	//   räis, милт, _לשכו,
  { {0x649000fe,0xff230002,0x63835610,0x00000000}},	//   säis, емјо, _згра,
  { {0x44445611,0xbe8a0001,0x64905612,0x00000000}},	//   lj_, љске_, päis,
  { {0x4444331a,0x7f86005d,0x9d130085,0x00000000}},	//   oj_, _کلان, едыч,
  { {0x44445613,0x69c631b5,0x61e20072,0x00000000}},	//   nj_, ecke, laol,
  { {0x444402b0,0x44380acd,0x76560072,0x00000000}},	//   ij_, _mnr_, kkyy,
  { {0x6aa40164,0x7f3b0063,0xee290021,0x00000000}},	//   _chif, _לעבו, _وأنه_,
  { {0x5a340062,0x3ebe5614,0xbd54005d,0x00000000}},	//   хнят, _hutt_, _تراژ,
  { {0x7b0500fe,0x8c430fc7,0x65640066,0x00000000}},	//   öttö, _пече, dzih,
  { {0x3ebe0019,0xab930054,0x7c384819,0x00000000}},	//   _jutt_, _пиші, _invr,
  { {0x44440045,0x61e20019,0x7c28087d,0x00000000}},	//   ej_, jaol, lddr,
  { {0x61e20019,0x38a40137,0x7afa5615,0x00000000}},	// [ab70] daol, förd_, lutt,
  { {0xf1b9017f,0x7c2806ac,0x444404aa,0x00000000}},	//   _sgš_, nddr, gj_,
  { {0x7afa0234,0x7c280014,0x93190593,0x00000000}},	//   nutt, iddr, تقاء_,
  { {0x44441228,0x7afa0290,0x62883543,0x00000000}},	//   aj_, iutt, _ídol,
  { {0x7c380229,0x3ebe0014,0x44445616,0x00000000}},	//   _onvr, _autt_, bj_,
  { {0x7afa024a,0x3ebe133f,0xb5fb01d1,0x00000000}},	//   kutt, _butt_, _emát,
  { {0x69c600c7,0xef190086,0x10080021,0x00000000}},	//   ycke, іми_, ستوى_,
  { {0xa294019d,0x7afa3b7e,0x7c3800ac,0x00000000}},	//   _засі, dutt, _anvr,
  { {0x3e6a006a,0xc2120063,0x6aa4001f,0x00000000}},	//   تجوی_, _בהן_, _rhif,
  { {0x8b070080,0x0ae90121,0x6aa45617,0x00000000}},	//   _naří, одой_, _shif,
  { {0x3ebe0c29,0x8d87007e,0x1ee7005d,0x00000000}},	//   _gutt_, _کشان, _روشی_,
  { {0x7eb50078,0x69d8013d,0x69c65618,0x00000000}},	//   _išpo, _őveb, ucke,
  { {0x7afa00fe,0xb5fb0114,0x660d0137,0x00000000}},	//   autt, _mlád, dfak,
  { {0x7afa0b9f,0x6e295619,0x7d090a48,0x00000000}},	//   butt, ldeb, mtes,
  { {0x66e60086,0x7d094b29,0x7afa18c8,0x00000000}},	//   ьова, ltes, cutt,
  { {0x6e29561a,0xa695005e,0x4438561b,0x00000000}},	//   ndeb, еруј, _snr_,
  { {0xc9860032,0x6e29561c,0x7d09561d,0x00000000}},	// [ab80] _تشغي, ideb, ntes,
  { {0x660d00e3,0x765d35c5,0x44440b5b,0x00000000}},	//   afak, _elsy, uj_,
  { {0x02060088,0x7d090004,0x9f980014,0x00000000}},	//   дзен, htes, _náði_,
  { {0x8b070080,0xdb2400ea,0x27a90047,0x00000000}},	//   _zaří, ésév, _מסתּ,
  { {0x51830138,0x6e29561e,0x61e2561f,0x00000000}},	//   куша, ddeb, raol,
  { {0x20560376,0xf1a9014d,0x7afa0058,0x00000000}},	//   ьтер, سانه_, yutt,
  { {0x7d09010e,0x3e7a001c,0x2d99004d,0x00000000}},	//   etes, līti_, üsen_,
  { {0x7afa00fe,0xddc9003b,0x27e33bdc,0x00000000}},	//   vutt, vieţ, zajn_,
  { {0x7eb500eb,0xc006100b,0x3e7a001c,0x00000000}},	//   _išpl, _опак, nīti_,
  { {0x3ebe0290,0x61e03850,0x60260086,0x00000000}},	//   _tutt_, _heml, _ідеа,
  { {0x7afa00fe,0x7d095620,0x69c10051,0x00000000}},	//   uutt, ates, ślem,
  { {0x7afa5621,0xb87b007a,0xddc9000c,0x00000000}},	//   rutt, rsím, rieţ,
  { {0x8b070080,0x27e35622,0xbebc008f,0x00000000}},	//   _paří, tajn_, _trīs,
  { {0xa8a4000a,0x3e7a001c,0xd6db06da,0x00000000}},	//   врск, dīti_, жта_,
  { {0xf7940088,0xabfb0063,0xddc95623,0x00000000}},	//   варэ, _והור, lieš,
  { {0x61e05624,0xd91b0062,0xb5fb5625,0x00000000}},	//   _neml, _дьо_, _amár,
  { {0xddc9001c,0xb5fb0026,0x60c00a43,0x00000000}},	// [ab90] nieš, _smás, _numm,
  { {0x752d051e,0x201c074f,0xfdbb0042,0x00000000}},	//   rvaz, jevi_, _उल्फ,
  { {0x3a2900e8,0xa3a90053,0xc7d60063,0x00000000}},	//   _kaap_, खें_, _אותי_,
  { {0xa4d50086,0xd3a406be,0x7d091d8c,0x00000000}},	//   _помі, труп, ytes,
  { {0xb5fb108f,0x61e40026,0x7bca1ddc,0x00000000}},	//   _vlád, ðila, _offu,
  { {0x8fa52724,0xf1b900c2,0xd0110593,0x00000000}},	//   нале, _maši_, الغ_,
  { {0x2eb5000a,0x69c1004c,0x26c15626,0x00000000}},	//   нсис, ělej, _juho_,
  { {0x6d250174,0x7bca4f1f,0x6e92005e,0x00000000}},	//   едиз, _affu, лију,
  { {0x6fca0053,0x6e294491,0xab640022,0x00000000}},	//   _स्कू, rdeb, óżny,
  { {0x61e00add,0x201c0290,0xc014042c,0x00000000}},	//   _zeml, cevi_, _имущ,
  { {0xddc900eb,0xdbdc0026,0x7d094776,0x00000000}},	//   aieš, ráði, stes,
  { {0xdddb004c,0x7bca2a5a,0x7d095627,0x00000000}},	//   louž, _effu, ptes,
  { {0xddc9003d,0x3ead1781,0x27e14cce,0x00000000}},	//   cieš, mmet_, _behn_,
  { {0x9d760047,0x3ead5628,0xfd48014b,0x00000000}},	//   _אײנס_, lmet_, _юзік_,
  { {0x5a96000a,0x6a960086,0x6013005b,0x00000000}},	//   _приф, _приє, mımı,
  { {0xb5fb5629,0xe61f0024,0x3e7a001c,0x00000000}},	//   _aláb, _skôr_, tīti_,
  { {0xd5b20021,0x33f6137a,0x3ead3928,0x00000000}},	// [aba0] افذ_, ечес, imet_,
  { {0x6013005b,0x60c0562a,0x3ead562b,0x00000000}},	//   nımı, _rumm, hmet_,
  { {0x224d0173,0x52760002,0x60c03d3c,0x00000000}},	//   _boek_, нуду, _summ,
  { {0x78620024,0x27e100bd,0x321d00ac,0x00000000}},	//   _dôve, _zehn_, gewy_,
  { {0x645b000f,0x201c038b,0x6013005b,0x00000000}},	//   áció, tevi_, kımı,
  { {0x3ea60034,0x557700b5,0xddc9001c,0x00000000}},	//   _shot_, _װעלן_, vieš,
  { {0x5f930a90,0x03a35217,0x201c079c,0x00000000}},	//   лишт, _биро, revi_,
  { {0xddc9001c,0x442a562c,0x2a60004b,0x00000000}},	//   tieš, _hab_, _nlib_,
  { {0x442a00f3,0x644e562d,0x201c01f4,0x00000000}},	//   _kab_, _kobi, pevi_,
  { {0x224d0122,0x2cb800c7,0x9b580002,0x00000000}},	//   _zoek_, örd_, диот_,
  { {0x442a001f,0x8afc0051,0x644e2cd3,0x00000000}},	//   _mab_, częl, _mobi,
  { {0x2456007a,0x68fd09db,0x69c0562e,0x00000000}},	//   _dæmi_, tusd, žmen,
  { {0x2bd10161,0xf1b9001c,0x60130058,0x00000000}},	//   _द्वा, _paši_, bımı,
  { {0x644e562f,0x6013005b,0x68fd00ac,0x00000000}},	//   _nobi, cımı, rusd,
  { {0xadf4016a,0xf1b95630,0x6b660003,0x00000000}},	//   _इयान_, _vaši_, _dégé,
  { {0x7c2a5631,0xdb9b089e,0x26041dd6,0x00000000}},	//   _hafr, _מסור, лчуг,
  { {0xc7cb0076,0x442a5551,0x59d40021,0x00000000}},	// [abb0] _ныне_, _bab_, _صغير,
  { {0x224d10e9,0x3ead01f7,0x225f00b9,0x00000000}},	//   _soek_, zmet_, _sluk_,
  { {0x644e065f,0x7c2a5632,0x3e7a008f,0x00000000}},	//   _dobi, _mafr, lītu_,
  { {0xe0d5005e,0xd0d50062,0x68ed5633,0x00000000}},	//   водњ, водъ, _kvad,
  { {0x3e7a001c,0x442a5634,0x644e5635,0x00000000}},	//   nītu_, _fab_, _fobi,
  { {0x644e048e,0x442a00bd,0xe3b3007e,0x00000000}},	//   _gobi, _gab_, _مرز_,
  { {0x3ead2667,0xf8380063,0x26c501c8,0x00000000}},	//   tmet_, תנות_, íloh_,
  { {0x7c2a004b,0xa2be0042,0x3eb95636,0x00000000}},	//   _aafr, षदर्, öst_,
  { {0x2d990146,0x6013005b,0xdddb0240,0x00000000}},	//   æse_, tımı, použ,
  { {0x3e7a001c,0x69cd001f,0xdca5005e,0x00000000}},	//   dītu_, _afae, ђани,
  { {0x601301f7,0x68ed5637,0x5ba90505,0x00000000}},	//   rımı, _avad, ьком_,
  { {0x16110053,0x63ba0014,0x60130058,0x00000000}},	//   _डॉलर_, _útne, sımı,
  { {0xb7e60053,0x60130058,0xed4e49a0,0x00000000}},	//   _क़दम_, pımı, _то_,
  { {0x38a400c7,0x68ed410b,0x31560047,0x00000000}},	//   föra_, _dvad, דישן_,
  { {0x38a400c7,0xf0920063,0x644e2da9,0x00000000}},	//   göra_, ינך_, _robi,
  { {0xdbe20003,0x442a5638,0x644e5639,0x00000000}},	//   _rééd, _sab_, _sobi,
  { {0x6e2b00bb,0x764f002b,0x442a002b,0x00000000}},	// [abc0] _magb, _docy, _pab_,
  { {0x44630079,0x42d60454,0xb5fb563a,0x00000000}},	//   авув, віду, _plác,
  { {0xf206000d,0x420a005e,0xe31600de,0x00000000}},	//   вяло, днео_, ضباب,
  { {0x6e2b00bb,0xd2590086,0x90e6007e,0x00000000}},	//   _nagb, нці_, نستن,
  { {0x660404aa,0x442a563b,0x644e563c,0x00000000}},	//   mgik, _tab_, _tobi,
  { {0x644e017f,0xf1b9222e,0x399d00ea,0x00000000}},	//   _uobi, _našu_, lású_,
  { {0x3e7a001c,0x6e2b322c,0x7c2a563d,0x00000000}},	//   zītu_, _bagb, _rafr,
  { {0x66040397,0x7c2a563e,0xdceb0075,0x00000000}},	//   ngik, _safr, _azgı,
  { {0x6e2b3460,0xd026005a,0xdbdc0014,0x00000000}},	//   _dagb, _имай, _báðu,
  { {0x3fcb005d,0x8c430131,0xf1a904a0,0x00000000}},	//   _قدمی_, иење, _ساقه_,
  { {0x6fd80235,0x7c2a007a,0x61ed0026,0x00000000}},	//   _न्यू, _vafr, ðalg,
  { {0xfee90032,0x3e7a003d,0x6f7900b5,0x00000000}},	//   _أعلى_, tītu_, _אָנג,
  { {0x6e20330c,0x7c2a0035,0xb87b017d,0x00000000}},	//   memb, _tafr, isív,
  { {0x7d001920,0x3e7a001c,0x6e20563f,0x00000000}},	//   mums, rītu_, lemb,
  { {0x3e7a001c,0x8c1b0063,0x7e625640,0x00000000}},	//   sītu_, _חווי, _klop,
  { {0xb5950076,0x61e40026,0x6e204d6f,0x00000000}},	//   гибш, ðill, nemb,
  { {0xa50722c1,0x5507005a,0x394400c7,0x00000000}},	// [abd0] ъявл, ъчва, ämst_,
  { {0x648b001c,0xd37b0189,0x63f40021,0x00000000}},	//   kļie, мче_, لأمر,
  { {0x3e7a003d,0x7ea5007a,0x623532f0,0x00000000}},	//   nīts_, hópa, лежу,
  { {0x62820019,0x62531452,0xcb130047,0x00000000}},	//   gnoo, _açor, ילע_,
  { {0xe4e40086,0x7d004263,0xd1b800f2,0x00000000}},	//   _вісн, jums, ناها_,
  { {0x628200a4,0x7eb50078,0x6e2b0c29,0x00000000}},	//   anoo, _išpi, _sagb,
  { {0x6e2b0273,0x44210228,0xdbdc0014,0x00000000}},	//   _pagb, meh_, _ráðu,
  { {0x44210397,0x3e7a003d,0x6e205551,0x00000000}},	//   leh_, dīts_, gemb,
  { {0xf1b9001c,0x0c79000d,0x7d00008f,0x00000000}},	//   _pašu_, есны_, gums,
  { {0x44210198,0xe9f9001b,0xbc62000d,0x00000000}},	//   neh_, _thẻ_, йвык,
  { {0xf1b95641,0x6e2b5642,0xf8bf013d,0x00000000}},	//   _vašu_, _tagb, kvés_,
  { {0xcd350242,0x4421352a,0x7d000196,0x00000000}},	//   _مرتب, heh_, bums,
  { {0x44210360,0x7afa06f8,0x7d0032ef,0x00000000}},	//   keh_, artt, cums,
  { {0x4421017f,0x7e62007d,0x8c420062,0x00000000}},	//   jeh_, _zlop, _геше,
  { {0x3e7a001c,0x44215643,0x399d013d,0x00000000}},	//   lūta_, deh_, tású_,
  { {0xd6270121,0x4b7a009d,0x00000000,0x00000000}},	//   лосе_, _ראקו,   ,
  { {0xe9f9008b,0x34aa005e,0xc224007e,0x00000000}},	// [abe0] _nhẹ_, евао_, یکرو,
  { {0x2902053b,0x6e205644,0x442112ca,0x00000000}},	//   muka_, zemb, geh_,
  { {0x6e2000bb,0x628200e8,0xb17d0024,0x00000000}},	//   yemb, tnoo, _reťa,
  { {0x6e205645,0x0d820121,0x3ced004b,0x00000000}},	//   xemb, ́льн, ksev_,
  { {0xb87b017d,0x29025646,0x7a3b0072,0x00000000}},	//   rsív, nuka_, _hätä,
  { {0xb87b03d9,0x3cf90161,0xed590080,0x00000000}},	//   ssív, ोंने_, dyž_,
  { {0xb87b0025,0x6e205647,0x27e7004b,0x00000000}},	//   msít, temb, _õnne_,
  { {0xe3c10058,0x7d005648,0x8cf40141,0x00000000}},	//   ğış_, tums, азиц,
  { {0x127b00b5,0x9be6000d,0x38a40026,0x00000000}},	//   _נאמע, лінк, vörn_,
  { {0x3e7a003d,0x7ea500ea,0x7b14100b,0x00000000}},	//   tīts_, rópa, адох,
  { {0x6e2014d1,0x7d005649,0x8fa6173e,0x00000000}},	//   pemb, sums, _саже,
  { {0xdd8f007e,0xfaf8001c,0x3e7a183d,0x00000000}},	//   _کوه_, dzīt_, rīts_,
  { {0x6e930032,0x5e930021,0xd5ed008b,0x00000000}},	//   _النا, _النط, hoạ,
  { {0x6d4600fe,0x36d53121,0x3e7a0023,0x00000000}},	//   äkau, иогр, pīts_,
  { {0x395f031c,0xab270d34,0x4421564a,0x00000000}},	//   šus_, _боја_, veh_,
  { {0x7ea50026,0x29022c8d,0xf8bf0003,0x00000000}},	//   hópn, buka_, uvés_,
  { {0x62830164,0xf8bf0164,0x229c0080,0x00000000}},	// [abf0] énom, rvés_, níku_,
  { {0xb5fb006d,0xe3b30021,0xf36701e2,0x00000000}},	//   _glán, مرض_, лтен,
  { {0x69dd0ad5,0x4421564b,0xd5ed008d,0x00000000}},	//   obse, reh_, goạ,
  { {0xeb970047,0x4421564c,0x60cd0e7c,0x00000000}},	//   נדאר_, seh_, íamo,
  { {0x9f4500ac,0x4421082a,0x2d800066,0x00000000}},	//   _gelê_, peh_, _žien_,
  { {0x00840086,0x656d004d,0x9f470061,0x00000000}},	//   бліо, mzah, lané_,
  { {0x656d00bd,0x290218e1,0x7c21564d,0x00000000}},	//   lzah, zuka_, velr,
  { {0x764d00e3,0x43840021,0x9f47027d,0x00000000}},	//   njay, _الفق, nané_,
  { {0x656d3a98,0x7db4000d,0xfd460062,0x00000000}},	//   nzah, йсьц, изък_,
  { {0x9f6b011c,0x764d00e3,0x201300cd,0x00000000}},	//   _през_, hjay, òxid_,
  { {0x3e7a001c,0x656d004d,0x3b09005e,0x00000000}},	//   sūta_, hzah, њемо_,
  { {0x6f03053b,0xb5fb0025,0x6dc70021,0x00000000}},	//   munc, _slán, _إزال,
  { {0x9f470a63,0x6f03366f,0x8c451137,0x00000000}},	//   dané_, lunc, _веле,
  { {0x29020117,0x764d0089,0x6f0300e5,0x00000000}},	//   ruka_, ejay, ounc,
  { {0x6f03564e,0x68fd0186,0xfaa6259f,0x00000000}},	//   nunc, arsd, _како,
  { {0x21290024,0x29020035,0xdeef000d,0x00000000}},	//   ťahy_, puka_, цыi_,

  { {0x61eb564f,0xd8f4007e,0x6d5b0397,0x00000000}},	// [ac00] dagl, _ازبک, nyua,
  { {0x6f0300e3,0xa4430095,0xb87b0240,0x00000000}},	//   kunc, онуд, usít,
  { {0x6f035650,0xb87b013d,0xdcc80013,0x00000000}},	//   junc, rsít, _mỉa_,
  { {0xb87b000f,0x61eb0290,0x6f035651,0x00000000}},	//   ssít, gagl, dunc,
  { {0x7bc3051e,0xb17d017c,0x69c4056c,0x00000000}},	//   _ognu, _deťo, _mgie,
  { {0xa073019d,0x6f035652,0xb9370063,0x00000000}},	//   огіч, func, יננו_,
  { {0x61eb0290,0x2d80003b,0x6f035653,0x00000000}},	//   bagl, _ţie_, gunc,
  { {0x61eb01f4,0xa2cb0053,0x62890023,0x00000000}},	//   cagl, _तंत्, _gjeo,
  { {0x9046007e,0x5c980062,0x5c740062,0x00000000}},	//   _پناه, лкия_, йлит,
  { {0x9f470240,0x6aad1157,0x229c0014,0x00000000}},	//   zané_, _shaf, ríku_,
  { {0xe9f9001b,0x9b94005e,0xab860062,0x00000000}},	//   _chế_, синц, рупк,
  { {0xc33301f9,0x7e695654,0x69cf5655,0x00000000}},	//   קור_, chep, ucce,
  { {0x9f470512,0x68fd006f,0x2727001f,0x00000000}},	//   vané_, ursd, _sŵn_,
  { {0x78620024,0xdc08003d,0x611a001c,0x00000000}},	//   _dôvo, _rēķi, mālā,
  { {0x9f4701d9,0xe9f9008b,0x17540086,0x00000000}},	//   tané_, _ghế_, овря,
  { {0x3bbb0063,0x8f1b0063,0x656d004d,0x00000000}},	//   _במוד, כולת, tzah,
  { {0x764d00e3,0x9f4701d9,0xe4e70086,0x00000000}},	// [ac10] rjay, rané_, рібн,
  { {0x6f03005b,0x9f4701d9,0x656d5656,0x00000000}},	//   yunc, sané_, rzah,
  { {0x75360006,0xbebc001c,0x656d1cef,0x00000000}},	//   avyz, _drīz, szah,
  { {0xb5fb0014,0x611a008f,0x67d3011b,0x00000000}},	//   _klám, kālā, bějí,
  { {0x61eb5657,0x98da0053,0xbebc008f,0x00000000}},	//   ragl, _बढ़ाए, _frīz,
  { {0x6f03003b,0x61eb5658,0x7fd80094,0x00000000}},	//   tunc, sagl, афът_,
  { {0x61eb002c,0xf7f80047,0xb5fb0331,0x00000000}},	//   pagl, בזוך_, _llám,
  { {0x443102dd,0xfe45000a,0x52850021,0x00000000}},	//   _haz_, снио, _الرك,
  { {0x69c400e8,0xee3602dc,0x6f0347c3,0x00000000}},	//   _rgie, сны_, sunc,
  { {0x3c650daf,0x443100c3,0xac180086,0x00000000}},	//   ског, _jaz_, ацює_,
  { {0x61e90004,0x6d5b00e3,0x4431001c,0x00000000}},	//   _keel, syua, _maz_,
  { {0x78620024,0x6455017f,0xddc200c3,0x00000000}},	//   _pôvo, _lozi, _zmož,
  { {0x61e90004,0xdcc80013,0x60c15659,0x00000000}},	//   _meel, _tỉa_, _kilm,
  { {0xe9f900aa,0x6455565a,0x29f80013,0x00000000}},	//   _thế_, _nozi, ọa_,
  { {0x2d9200d1,0xec12007e,0x62990022,0x00000000}},	//   _øyer_, _رويد, kowo,
  { {0x9f450114,0xfd640013,0xcf920149,0x00000000}},	//   _celé_, _nguờ, פטן_,
  { {0xceb20063,0x05aa005a,0x62990051,0x00000000}},	// [ac20] ליל_, увай_, dowo,
  { {0x4431000c,0x645549bd,0x48060156,0x00000000}},	//   _caz_, _cozi, _упов,
  { {0x61e904c6,0xddcb0051,0x9f4500ea,0x00000000}},	//   _beel, _mogł, _felé_,
  { {0xdb9a0047,0xfaf60063,0x60c100e5,0x00000000}},	//   אסער, מצעי_, _ailm,
  { {0x61e903a8,0x4431263f,0x60c1565b,0x00000000}},	//   _deel, _faz_, _bilm,
  { {0xd259001c,0x8459018e,0x60c901f4,0x00000000}},	//   _viņa_, _крст_, _duem,
  { {0x447b00b5,0x61e903ae,0x62990022,0x00000000}},	//   _ענלע, _feel, bowo,
  { {0x62990051,0x60c10c29,0x61e936ad,0x00000000}},	//   cowo, _eilm, _geel,
  { {0x64690006,0x4431005b,0xe9f9008b,0x00000000}},	//   šsių, _yaz_, _chẽ_,
  { {0xddc2027d,0x26c246da,0x61e9565c,0x00000000}},	//   _umož, _liko_, _zeel,
  { {0xb4db0268,0xfd0f007e,0xb5fb011b,0x00000000}},	//   _gràf, وجی_, _slám,
  { {0x26c2565d,0x6443004d,0xfe720044,0x00000000}},	//   _niko_, öniz, _عدا_,
  { {0x127b0047,0x1dac0053,0x2c690066,0x00000000}},	//   ראכע, _चरित, _súde_,
  { {0x7b070139,0x67d429c2,0x26c2005f,0x00000000}},	//   ósté, зору, _aiko_,
  { {0x27ff005b,0x443106ce,0xeac90013,0x00000000}},	//   ğun_, _raz_, _hẹn_,
  { {0x95d9000a,0x6455565e,0xea00008b,0x00000000}},	//   рдат_, _sozi, _trại_,
  { {0x4431565f,0x54554ad2,0x64555660,0x00000000}},	// [ac30] _paz_, оват, _pozi,
  { {0x628a05d5,0xe787013c,0x61e95661,0x00000000}},	//   éfon, _гумо, _seel,
  { {0x94a8011c,0x8afc0051,0x3834000d,0x00000000}},	//   стта_, częt, _энэр,
  { {0x4431004d,0x60c15662,0x64550022,0x00000000}},	//   _waz_, _silm, _wozi,
  { {0x60c9006d,0x62995663,0x60c10150,0x00000000}},	//   _quem, rowo, _pilm,
  { {0x212d0198,0x26c200ac,0x61e900ca,0x00000000}},	//   _vseh_, _ziko_, _weel,
  { {0x786b01f7,0x62990051,0x61e92a3f,0x00000000}},	//   _güve, powo, _teel,
  { {0x1287007e,0xef16000d,0xa77c009f,0x00000000}},	//   _امری_, імы_, טרופ,
  { {0x60c1010a,0x60c90019,0xddcb0022,0x00000000}},	//   _tilm, _uuem, _pogł,
  { {0xb4db0268,0x9f471994,0x2a6900a4,0x00000000}},	//   _tràf, laní_, _alab_,
  { {0x2dd50d82,0x661d08ce,0xb4db01a8,0x00000000}},	//   _джер, _obsk, _fràg,
  { {0x753d000f,0x7afc0405,0x6ffb008f,0x00000000}},	//   _orsz, árta, sācē,
  { {0x38a4004b,0x26c25664,0x27fe056c,0x00000000}},	//   löri_, _riko_, ótno_,
  { {0x2a690019,0x9f470066,0xb7da005d,0x00000000}},	//   _elab_, haní_, شورا_,
  { {0x18a30088,0x9f470124,0xf6560121,0x00000000}},	//   фарм, kaní_, отаю,
  { {0x8afc0051,0xcb12089e,0x9f47017c,0x00000000}},	//   rzęt, _חלה_, janí_,
  { {0x9f4701d9,0x786b332a,0xeac90013,0x00000000}},	// [ac40] daní_, _süve, _kẹo_,
  { {0x8afc0022,0x61ed0046,0x58060044,0x00000000}},	//   częs, ðaln, _بودك,
  { {0xeac9008b,0xd1ca007f,0x82f60085,0x00000000}},	//   _mẹo_, алее_, ючац,
  { {0xe29a000d,0xe8160053,0x7b0c0041,0x00000000}},	//   шае_, द्रा_, רפאַ,
  { {0xdfd40121,0xbba60042,0x76465665,0x00000000}},	//   полы, _ऑर्क, _inky,
  { {0xb5fb013d,0x29025666,0x786b004e,0x00000000}},	//   _aláh, irka_, _tüve,
  { {0xb5fb004c,0x787b0063,0x3e6a14b4,0x00000000}},	//   _bláh, יָהו, ишин_,
  { {0xbe8a0001,0x2000000c,0x5d540062,0x00000000}},	//   јске_, şii_, зкит,
  { {0xd00a0138,0xddc20045,0x61e40026,0x00000000}},	//   _везе_, _umoż, ðilu,
  { {0x0bf30055,0xeac90013,0xaff70021,0x00000000}},	//   мпью, _vẹn_, _وفقا_,
  { {0x61e2017f,0x20d0008b,0x4e2a0002,0x00000000}},	//   obol, _hài_, _воен_,
  { {0xb5fb01c2,0x5ce60062,0x539b009f,0x00000000}},	//   _vlák, _дюка, שיטו,
  { {0x6c77007e,0xfc2f005d,0x4974014b,0x00000000}},	//   صحیح_, رحی_, дляс,
  { {0x20d00013,0x9f470061,0x76465667,0x00000000}},	//   _mài_, zaní_, _anky,
  { {0x7c28001f,0x61e25668,0xdcc8008d,0x00000000}},	//   medr, kbol, _mỉm_,
  { {0x61e206bb,0xfb87007e,0x7c285669,0x00000000}},	//   jbol, _بدهی, ledr,
  { {0x9f4714c0,0x61e21686,0x6eca0022,0x00000000}},	// [ac50] vaní_, dbol, _dębi,
  { {0xa3a70138,0x93a70076,0x61e24068,0x00000000}},	//   ојек, ошед, ebol,
  { {0x9f470024,0xd49801dd,0x69c0008f,0x00000000}},	//   taní_, іру_, žmet,
  { {0x20d0001b,0x5274005d,0x7c28566a,0x00000000}},	//   _bài_, وانز, hedr,
  { {0xdd86043b,0x20d0001b,0x2ca50137,0x00000000}},	//   _أو_, _cài_, ylld_,
  { {0x55ba0063,0x20d0001b,0x660d004b,0x00000000}},	//   _למרו, _dài_, lgak,
  { {0x752d00ac,0xdb030114,0x6447566b,0x00000000}},	//   lwaz, _ozná, _inji,
  { {0x290200c7,0x69db006d,0x660d1f93,0x00000000}},	//   yrka_, ñuel, ngak,
  { {0x644706bb,0xb5fb0025,0xa9240006,0x00000000}},	//   _knji, _clái, įžki,
  { {0x60db0035,0x7c281b26,0x4c690899,0x00000000}},	//   _itum, gedr, сион_,
  { {0x7ea50026,0x628b566c,0xbb450d82,0x00000000}},	//   hópi, ongo, ченк,
  { {0x752d02ae,0x9f4700cd,0xce380021,0x00000000}},	//   kwaz, manà_, _وأنا_,
  { {0x7c28566d,0x628b01f4,0x20d00013,0x00000000}},	//   bedr, ingo, _xài_,
  { {0x60db0035,0x7d09140a,0x5d3a0063,0x00000000}},	//   _mtum, mues, _לתנא,
  { {0x7d0900fe,0x61fb566e,0x61e204b3,0x00000000}},	//   lues, _odul, ybol,
  { {0x6447091c,0x61ed0014,0xc7a30002,0x00000000}},	//   _anji, ðall, хиск,
  { {0xb4db00cd,0xa5bb017d,0x61e20137,0x00000000}},	// [ac60] _aràb, _abób, vbol,
  { {0xd7f1008b,0x628b566f,0x39405670,0x00000000}},	//   ữa_, engo, _iris_,
  { {0xf8b3014e,0x20d0008b,0x2486007d,0x00000000}},	//   _רשת_, _sài_, đom_,
  { {0xf53f1262,0x2ab200ea,0x64475671,0x00000000}},	//   _frå_, lább_, _enji,
  { {0x463b0047,0xc243000d,0x30340076,0x00000000}},	//   _העכע, энцк, делё,
  { {0x20d0001b,0x7e880080,0x321a007e,0x00000000}},	//   _vài_, měpi, _گيرد_,
  { {0xba3b00ac,0x91e61f4d,0x61e40026,0x00000000}},	//   loïe, _нове, ðils,
  { {0x20d000aa,0x787000c7,0xdceb005b,0x00000000}},	//   _tài_, _hävd, _aygı,
  { {0x7d095672,0x62820213,0x2ab200ea,0x00000000}},	//   gues, mioo, kább_,
  { {0xf3f10013,0xf044007e,0xba3b0003,0x00000000}},	//   _ột_, _تعری, zoïd,
  { {0x2fd7006a,0x7c283385,0x39405673,0x00000000}},	//   _روند_, redr, _aris_,
  { {0xaf490032,0xcf250021,0x39401d26,0x00000000}},	//   _بشكل_, _تركي, _bris_,
  { {0x7d0902dd,0xb5fb0240,0x984b0062,0x00000000}},	//   cues, _kláv, бява_,
  { {0xd9180121,0x9f47092d,0xddc90022,0x00000000}},	//   чью_, laná_, zież,
  { {0x628b001f,0x8c53007e,0x8c1b0165,0x00000000}},	//   yngo, _سئوا, _הווי,
  { {0x443f01f7,0xdb030114,0x394001a8,0x00000000}},	//   _şu_, _uzná, _fris_,
  { {0x660d37d4,0x3e7a008f,0x61ed0014,0x00000000}},	// [ac70] rgak, gūti_, ðalm,
  { {0x628b0185,0x734b0062,0x68f8004c,0x00000000}},	//   wngo, йчев_, řadí,
  { {0x752d0089,0x290b5674,0x27f80066,0x00000000}},	//   swaz, luca_, šenú_,
  { {0xe3b00032,0x62820ff2,0x628b5675,0x00000000}},	//   ارك_, gioo, ungo,
  { {0x9179001b,0x9f47027d,0xdddb0051,0x00000000}},	//   _bấm_, daná_, ykuł,
  { {0xf99400b5,0x29380047,0x9179008b,0x00000000}},	//   ערס_, פאון_, _cấm_,
  { {0x9028000d,0x662600ea,0xddc90051,0x00000000}},	//   яцца_, _ütkö, pież,
  { {0xb4db0994,0x7d090072,0x91790013,0x00000000}},	//   _gràc, tues, _tầm_,
  { {0x60db0009,0xb5fb017d,0x290b231d,0x00000000}},	//   _utum, _fláv, juca_,
  { {0x290b1ce0,0x78700072,0xab650083,0x00000000}},	//   duca_, _käve, двол,
  { {0x6ee701a7,0x2ab200ea,0x291919fb,0x00000000}},	//   _رسال, vább_, etsa_,
  { {0x7d09048e,0x38a40bfc,0x4a430086,0x00000000}},	//   pues, hört_, внюв,
  { {0x7d09233a,0x9f640072,0x7870004b,0x00000000}},	//   ques, ätön_, _läve,
  { {0xcb6950be,0x00000000,0x00000000,0x00000000}},	//   _мале_,   ,   ,
  { {0xe7370811,0xc7950766,0x07a32267,0x00000000}},	//   мер_, ерты, варн,
  { {0x39400006,0xaaba007e,0x38a40014,0x00000000}},	//   _tris_, _بدتر_, vöru_,
  { {0x14c8007e,0x38a40137,0x62820072,0x00000000}},	// [ac80] سهای_, fört_, vioo,
  { {0x26cc1088,0xa2e60076,0x9f47027d,0x00000000}},	//   ídos_, дожд, zaná_,
  { {0xb4db0268,0xb87b350c,0x62820656,0x00000000}},	//   _pràc, spíc, tioo,
  { {0x41aa0189,0xb5fb5676,0x2a8800ea,0x00000000}},	//   овен_, _sláv, lőbb_,
  { {0x62820004,0x9f470512,0xb5fb5677,0x00000000}},	//   rioo, vaná_, _cláu,
  { {0x62822c84,0x289b0041,0xa0675678,0x00000000}},	//   sioo, ֿיקא, мача_,
  { {0x7ea5007a,0x44382856,0xb4db00cd,0x00000000}},	//   hópu, _iar_, _tràc,
  { {0x443831c8,0x9f450164,0x1d340432,0x00000000}},	//   _har_, _delà_, ения,
  { {0x645c5679,0x443848dc,0x9f47567a,0x00000000}},	//   _kori, _kar_, raná_,
  { {0xac260121,0x645c1c4f,0x9f470195,0x00000000}},	//   ффик, _jori, saná_,
  { {0x4438567b,0x2a8810fd,0x645c2070,0x00000000}},	//   _mar_, zőbe_, _mori,
  { {0x6ab60185,0x4438567c,0xaacf0053,0x00000000}},	//   _chyf, _lar_, _संरक,
  { {0x394d017d,0xc19b0041,0x60c8567d,0x00000000}},	//   ães_, ַשלי, _kidm,
  { {0x645c0812,0x4438567e,0x2919567f,0x00000000}},	//   _nori, _nar_, rtsa_,
  { {0x61ed0026,0x67d40086,0xdca3005e,0x00000000}},	//   ðalk, тосу, _шаљи,
  { {0x38a400c7,0xe4e70086,0x60c85680,0x00000000}},	//   förs_, діжн, _lidm,
  { {0x443804bf,0x38a45681,0x38b600b9,0x00000000}},	// [ac90] _bar_, görs_, færd_,
  { {0x4438031d,0x62805682,0xe616085a,0x00000000}},	//   _car_, _ammo, čišč,
  { {0x645c0529,0x201300cd,0x3e7a001c,0x00000000}},	//   _dori, òxim_, lūtu_,
  { {0x23df0394,0x53df0161,0x44380034,0x00000000}},	//   _प्रद, _प्रश, _ear_,
  { {0x6d440006,0x44385683,0x645c5684,0x00000000}},	//   _šian, _far_, _fori,
  { {0x3e710512,0x645c5685,0x44385686,0x00000000}},	//   _máte_, _gori, _gar_,
  { {0x60c80006,0x8fa22c9e,0xb4ab0042,0x00000000}},	//   _didm, лаше, खती_,
  { {0x38b602ab,0x6d425687,0x69cd0025,0x00000000}},	//   mære_, _broa, _ngae,
  { {0x2ab2000f,0x38b60205,0x6ab6001f,0x00000000}},	//   jába_, lære_, _rhyf,
  { {0x6aa402ab,0x3134005e,0xec760121,0x00000000}},	//   _skif, _јефр, епь_,
  { {0x6d425688,0x7c38005b,0x6a86065b,0x00000000}},	//   _eroa, _davr, елна,
  { {0xdb1e0080,0xaf040085,0x61ed0014,0x00000000}},	//   áván, _шчук, ðalh,
  { {0x3e7a003d,0x7e690026,0x64480e7c,0x00000000}},	//   gūtu_, mkep, _ódig,
  { {0x7ea50026,0x7e6906a5,0x30790047,0x00000000}},	//   rópu, lkep, לאָנ,
  { {0xd5b7001b,0x38b600d1,0x44385689,0x00000000}},	//   ếng_, jære_, _rar_,
  { {0x2a88000f,0x6aa40035,0x26de001c,0x00000000}},	//   sőbb_, _ukif, īto_,
  { {0x765d01f7,0x4438568a,0xeb1f0053,0x00000000}},	// [aca0] _dosy, _par_, _बहुत_,
  { {0x7d1b024a,0x38b6000e,0x7e69004b,0x00000000}},	//   itus, fære_, hkep,
  { {0x645c568b,0xb5fb568c,0x7d1b0019,0x00000000}},	//   _vori, _clás, htus,
  { {0x44380359,0xd2590086,0x645c004d,0x00000000}},	//   _war_, мці_, _wori,
  { {0x7ea50026,0xd0d70086,0x645c568d,0x00000000}},	//   hóps, едії_, _tori,
  { {0x442c0025,0x68fb017d,0x645c0072,0x00000000}},	//   _úd_, áudi, _uori,
  { {0x7d1b0019,0x2ab2013d,0x60c8568e,0x00000000}},	//   etus, zába_, _vidm,
  { {0x7c38017f,0x9f47005b,0xb65b0047,0x00000000}},	//   _savr, zanç_, ִדיש,
  { {0x2dd70021,0xb5fb0026,0x7d1b00a4,0x00000000}},	//   ربية_, _klár, gtus,
  { {0x7c3a00b9,0x60fb0063,0x0f31005d,0x00000000}},	//   udtr, _מהמק, _چکيد,
  { {0x141b0047,0x7d1b04b4,0xdfcf007e,0x00000000}},	//   הויב, atus, _ايم_,
  { {0x58d50054,0x2ab2013d,0x6d42568f,0x00000000}},	//   комт, tába_, _troa,
  { {0x61ed0026,0x984b0062,0x765d5690,0x00000000}},	//   ðali, пява_, _rosy,
  { {0xd259001c,0xb4db00cd,0x765d21bd,0x00000000}},	//   _viņi_, _bràn, _sosy,
  { {0x36d50175,0x2f1a002b,0xf794000d,0x00000000}},	//   тобр, nëg_, гарэ,
  { {0x7afa28ac,0x16340062,0x69da004c,0x00000000}},	//   mstt, леся, ětec,
  { {0x68ed0051,0x243902d8,0xa3d505ac,0x00000000}},	// [acb0] _uwad, мпањ_, возч,
  { {0xb5fb5691,0xb4ab0053,0x38b602ab,0x00000000}},	//   _clár, खते_, tære_,
  { {0x72190071,0x430b000d,0xd37b046e,0x00000000}},	//   джер_, яхам_, чча_,
  { {0x38b601f2,0x61cb0053,0xd9f10042,0x00000000}},	//   rære_, िशेष, चरित_,
  { {0xe0d80086,0x229c01da,0x7d1b1942,0x00000000}},	//   еві_, níky_, xtus,
  { {0x99920051,0xc0c8005e,0x7afa188f,0x00000000}},	//   _abyś_, нује_, kstt,
  { {0x201a0268,0xd00e0021,0x7afa09fe,0x00000000}},	//   òpia_, زلي_, jstt,
  { {0xfe45000a,0x7bda000c,0x63a3004d,0x00000000}},	//   тнио, ectu, ünnu,
  { {0x7d1b17e3,0x7a4200ea,0x26d3017d,0x00000000}},	//   utus, nítő, _luxo_,
  { {0x7e695692,0x44ef0051,0xbc620121,0x00000000}},	//   skep, iż_, ивык,
  { {0x7d1b5693,0x3e7a008f,0x9c64005d,0x00000000}},	//   stus, gūts_, اهپو,
  { {0x7ea50865,0x7de70021,0x2c72003b,0x00000000}},	//   róps, _أسام, _râde_,
  { {0x3ead3e8d,0x6fd80053,0x97da0121,0x00000000}},	//   mlet_, नुकू, дьбу_,
  { {0x3ead28d7,0x3ea00648,0xcd760149,0x00000000}},	//   llet_, čite_, _בענק_,
  { {0x44ef0045,0x26cb017d,0x7d09027f,0x00000000}},	//   eż_, _bico_, lres,
  { {0x7aed0051,0x7d095694,0x224d013d,0x00000000}},	//   _łatw, ores, _nnek_,
  { {0x26cb24b9,0x7d095695,0x3ead5696,0x00000000}},	// [acc0] _dico_, nres, ilet_,
  { {0xb4db5697,0x386d006f,0x7d09005f,0x00000000}},	//   _tràn, ëert_, ires,
  { {0x7d0900bd,0x3ead5698,0x26cb5699,0x00000000}},	//   hres, klet_, _fico_,
  { {0x6d4400eb,0x3ead00b9,0x7d09569a,0x00000000}},	//   _šiam, jlet_, kres,
  { {0xc05a0086,0x3ead569b,0x01330021,0x00000000}},	//   дій_, dlet_, لعود,
  { {0xdc08003d,0xc0130086,0xd12f007e,0x00000000}},	//   _mēģi, иміщ, تمه_,
  { {0x7d09000f,0xceba0001,0x644e569c,0x00000000}},	//   eres, мљи_, _inbi,
  { {0x3ead38a7,0x8c3c005b,0x539b00ff,0x00000000}},	//   glet_, doğa, _חילו,
  { {0x8cf3000d,0x27f800c2,0x7d092996,0x00000000}},	//   азыц, karn_, gres,
  { {0x3ead569d,0x3ebf00a4,0xa3b90042,0x00000000}},	//   alet_, amut_, _चरम_,
  { {0x3ead3e8d,0x7ea5017d,0x27f8001f,0x00000000}},	//   blet_, rópr, darn_,
  { {0x0e660002,0x7d090955,0x3ead01a8,0x00000000}},	//   _шкен, bres, clet_,
  { {0x58870be6,0x27f8001f,0x7d09569e,0x00000000}},	//   выва, farn_, cres,
  { {0x5c730086,0x7afa004d,0x58870085,0x00000000}},	//   _кліт, pstt, тыма,
  { {0x59a50394,0xd259001c,0x26cb569f,0x00000000}},	//   _ऐडवर, _ziņu_, _pico_,
  { {0x644e00bd,0x7a42013d,0x4993005d,0x00000000}},	//   _anbi, títő, _نیجر,
  { {0x44ef0051,0x26cb01f4,0xf99f00c6,0x00000000}},	// [acd0] uż_, _vico_, rgès_,
  { {0x291e000c,0x3e710026,0xd6db0062,0x00000000}},	//   ătat_, _máta_, _отм_,
  { {0x3e71007a,0x3ea4006f,0x7a4200ea,0x00000000}},	//   _láta_, komt_, sítő,
  { {0x69dd000f,0x7d090119,0xf5e40054,0x00000000}},	//   ncse, yres, _вірм,
  { {0x3ead005b,0x69dd002b,0x764f0022,0x00000000}},	//   vlet_, icse, _incy,
  { {0x290b1ca2,0x3ead069f,0x7d0956a0,0x00000000}},	//   irca_, wlet_, vres,
  { {0x7e77006f,0xeaca0013,0x28da0053,0x00000000}},	//   ëxpo, _kẹt_, _यूनि,
  { {0x7d0956a1,0x3ead1962,0x7219009a,0x00000000}},	//   tres, ulet_, _רוּח,
  { {0x3ead4823,0x3ebf56a2,0x61ed0014,0x00000000}},	//   rlet_, rmut_, ðalu,
  { {0xd259001c,0xbed500e1,0x3e7110c3,0x00000000}},	//   _viņu_, _божј, _dáta_,
  { {0x290b56a3,0x7c2e004b,0x26c0002b,0x00000000}},	//   erca_, õbra, ymio_,
  { {0x3f7a00b5,0x7d092347,0x69dd013d,0x00000000}},	//   _אָדע, pres, gcse,
  { {0x323600b5,0x386156a4,0xf9920021,0x00000000}},	//   נטשן_, _bohr_, صبح_,
  { {0x38b60026,0xd9430001,0x8c67018e,0x00000000}},	//   færa_, љери, _штед,
  { {0xdbd1004b,0x290b2070,0xdc9a089e,0x00000000}},	//   _müük, arca_, _איסל,
  { {0x2ab9013d,0x69dd013d,0x27f856a5,0x00000000}},	//   tébe_, ccse, sarn_,
  { {0x26c019d2,0x1a9b016e,0xa96a0094,0x00000000}},	// [ace0] rmio_, _ריפע, _чипа_,
  { {0x2ab9013d,0x9f4c01c8,0x764f56a6,0x00000000}},	//   rébe_, _sedí_, _ency,
  { {0xa3b90053,0x1bf60047,0x2ab9013d,0x00000000}},	//   _चरण_, רצער_, sébe_,
  { {0x2ca556a7,0x7e7700ca,0x11d700de,0x00000000}},	//   hold_, ëxpl, هومة_,
  { {0x64430016,0x6a660014,0x6458004e,0x00000000}},	//   ônic, _hófs, övis,
  { {0xd8d70047,0x20d90290,0x2ca55462,0x00000000}},	//   אוסט_, _dèi_, jold_,
  { {0xa2e30121,0xaacf0042,0xcf26009b,0x00000000}},	//   _госд, _संगक, ارتي,
  { {0x61ed0026,0x68e456a8,0x33930044,0x00000000}},	//   ðalt, _otid, _الفز,
  { {0xa2a10053,0x29004f78,0x1016002a,0x00000000}},	//   गकर्, _nvia_, _مباد,
  { {0x3ea406a5,0x1dc00053,0x54770041,0x00000000}},	//   somt_, शेषत, ָגטע_,
  { {0x68e400eb,0x38612c80,0x68fd56a9,0x00000000}},	//   _atid, _rohr_, wssd,
  { {0xdd00005b,0x8f9b009a,0x6f79009a,0x00000000}},	//   ştık, _איבי, _בְנו,
  { {0x6c540079,0x786b0004,0x8aa4000d,0x00000000}},	//   _вклу, _hüvi, срэд,
  { {0x6d3b014e,0x9f470024,0x7e62010e,0x00000000}},	//   _נתונ, vanú_, _hoop,
  { {0x9999000f,0x7e6256aa,0x7bdb009a,0x00000000}},	//   reső_, _koop, _אקוו,
  { {0x58d5011c,0x9f470066,0xc6a70081,0x00000000}},	//   _коит, tanú_, урги,
  { {0xb4db00cd,0xd7fb005e,0x93f50699,0x00000000}},	// [acf0] _tràm, _пун_, ипац,
  { {0x44270014,0x7e621865,0x9f4756ab,0x00000000}},	//   ýn_, _loop, ranú_,
  { {0x998d0051,0x7e6256ac,0x9f470066,0x00000000}},	//   żeń_, _ooop, sanú_,
  { {0x394904fd,0xeb91089e,0x2701005f,0x00000000}},	//   _kras_, חָד_, mėn_,
  { {0x61f956ad,0x2127007e,0xc5fa0063,0x00000000}},	//   rawl, ايتی_, _בפרט,
  { {0xd00605fb,0x21660856,0xe9df017c,0x00000000}},	//   аеше_, риши_, hcú_,
  { {0x61ed0026,0x2ca50d1a,0xcee80021,0x00000000}},	//   ðals, vold_, هرين_,
  { {0x394900bb,0xfde60062,0x44332e91,0x00000000}},	//   _oras_, адък_, lex_,
  { {0x7ae40750,0x7e62117b,0x628b095b,0x00000000}},	//   _čita, _doop, migo,
  { {0x3ea0074f,0x4c6902d8,0x443356ae,0x00000000}},	//   čita_, тион_, nex_,
  { {0x394956af,0x68e4007d,0x2ca556b0,0x00000000}},	//   _aras_, _stid, rold_,
  { {0xa96a0138,0x394956b1,0x628b39eb,0x00000000}},	//   вима_, _bras_, nigo,
  { {0x9975005e,0xec6e44b0,0x999e004c,0x00000000}},	//   бурш, _дп_, ětů_,
  { {0x29000290,0x78700e04,0x39490c0f,0x00000000}},	//   _vvia_, _gävl, _dras_,
  { {0x44330136,0xe8170042,0xe7e50042,0x00000000}},	//   dex_, _तारा_, कड़ा_,
  { {0xc7a30940,0x6d440006,0x3949081c,0x00000000}},	//   циск, _šiai, _fras_,
  { {0x394956b2,0x9f450024,0x628b56b3,0x00000000}},	// [ad00] _gras_, _celú_, digo,
  { {0x628b0006,0x44331005,0x2701005f,0x00000000}},	//   eigo, gex_, bėn_,
  { {0x2bab0053,0xe1fa012c,0x00000000,0x00000000}},	//   _घुमा, вге_,   ,
  { {0x9f4c027d,0xd36f0021,0xb14619b6,0x00000000}},	//   _nedá_, بهم_, инел,
  { {0x90c605c5,0x7e620656,0x786b004e,0x00000000}},	//   абде, _roop, _süvi,
  { {0x201a0019,0xe018000d,0xf1a9002a,0x00000000}},	//   üpi_, ужкі_, دامه_,
  { {0x628b20ea,0xa06702f8,0xc7d7009a,0x00000000}},	//   bigo, раја_, בוצי_,
  { {0x290c0051,0xf2a30811,0x0dca04f2,0x00000000}},	//   ądaj_, _дисп, купи_,
  { {0x61ed02dd,0xdcba0086,0xf8bf0003,0x00000000}},	//   ñale, кщо_, ltée_,
  { {0xceea0086,0x27230066,0x8c6616fc,0x00000000}},	//   _адже_, nčná_, ртид,
  { {0xf8bf0164,0x26de00cd,0x39490331,0x00000000}},	//   ntée_, ítol_, _sras_,
  { {0xfe790080,0xbd87007e,0x1bf20053,0x00000000}},	//   chů_, انین_, _आजकल_,
  { {0x787000c7,0xdb03027d,0xcd36007e,0x00000000}},	//   _tävl, _vyná, _خراب,
  { {0xe9df0871,0x5d7b0063,0x4d7b0063,0x00000000}},	//   scú_, _שָׁנ, _שָׁא,
  { {0x1cbb00b5,0x44335404,0x4cbb009a,0x00000000}},	//   _שמוע, vex_, _שמוג,
  { {0x3949048e,0xaa2d00fe,0x442a56b4,0x00000000}},	//   _tras_, ämää_, _abb_,
  { {0x6ac40021,0x442a56b5,0x628b56b6,0x00000000}},	// [ad10] _بقيم, _bbb_, vigo,
  { {0xc3cb0021,0xeaca008b,0x25bd0058,0x00000000}},	//   نظام_, _hẹp_, _ızlı_,
  { {0x628b03d9,0x443356b7,0x389c0149,0x00000000}},	//   tigo, rex_, _ביזנ,
  { {0x07360047,0x443356b8,0x926b0062,0x00000000}},	//   _פארם_, sex_, ърза_,
  { {0xc2440088,0x95cb0001,0x628b56b9,0x00000000}},	//   ўнік, _јуна_, rigo,
  { {0x753d00ea,0x628b56ba,0xd7f10013,0x00000000}},	//   _issz, sigo, ữu_,
  { {0xf8bf0003,0x8c3c0058,0x6d460046,0x00000000}},	//   ctée_, roğl, ækan,
  { {0x7c2a00bd,0xddd30066,0x17980063,0x00000000}},	//   _abfr, ťaže, ידול_,
  { {0x62890490,0xc2120063,0x656d56bb,0x00000000}},	//   _imeo, _מהן_, nyah,
  { {0x3e710024,0x7d02074f,0xac392df7,0x00000000}},	//   _táto_, _dvos, учих_,
  { {0xdce7005b,0xcaca0121,0xeaca008d,0x00000000}},	//   ılım, лгое_, _bẹp_,
  { {0xc86911b4,0x753d013d,0x2d7f0022,0x00000000}},	//   _אן_, _ossz, _płeć_,
  { {0xeaca0013,0x2c690066,0x8c45259e,0x00000000}},	//   _dẹp_, _súdu_, _геле,
  { {0x9f430014,0xec780054,0x6ca40021,0x00000000}},	//   _þjó_, _кпі_, _وصول,
  { {0x628901f4,0x66e620fb,0x753d013d,0x00000000}},	//   _omeo, соба, _assz,
  { {0xaad00042,0x442a004d,0xf6550054,0x00000000}},	//   _सूचक, _sbb_, отую,
  { {0x442a003e,0xba17009a,0xe3d600de,0x00000000}},	// [ad20] _pbb_, _החפץ_, متاع,
  { {0x98a90006,0x290256bc,0xf8bf0003,0x00000000}},	//   _ypač_, mska_, ttée_,
  { {0xf8bf0003,0x7e7b00ac,0x1bfa0047,0x00000000}},	//   utée_, khup, רלעב,
  { {0xfad6014e,0xf8bf0164,0x290200fe,0x00000000}},	//   צונך_, rtée_, oska_,
  { {0xf8bf0164,0x290256bd,0x76440058,0x00000000}},	//   stée_, nska_, mdiy,
  { {0xf8bf0164,0x290256be,0x76440058,0x00000000}},	//   ptée_, iska_, ldiy,
  { {0x444456bf,0x5f430032,0x68f6001f,0x00000000}},	//   md_, كنول, _lwyd,
  { {0x22960032,0x3ea0017f,0x32960021,0x00000000}},	//   _الرس, čito_, _الرأ,
  { {0x752456c0,0x444456c1,0x68f6001f,0x00000000}},	//   ntiz, od_, _nwyd,
  { {0x61e20965,0x6aad06a3,0x447b0047,0x00000000}},	//   lcol, _skaf, ָנטע,
  { {0x68f6001f,0x6d4b56c2,0xdb0300a5,0x00000000}},	//   _awyd, _erga, _nynä,
  { {0x6d440006,0x2902027c,0x68f6001f,0x00000000}},	//   _šiau, fska_, _bwyd,
  { {0x0c73006a,0xd5a70053,0x76440058,0x00000000}},	//   زدید, _कुंज, ddiy,
  { {0x444402b0,0x69d600ea,0x8c430fd0,0x00000000}},	//   jd_, _egye, _нече,
  { {0x44440c70,0x68f6002b,0x4bfb07e9,0x00000000}},	//   dd_, _ewyd, _גלוס,
  { {0x68f6002b,0x29020ae9,0x444456c3,0x00000000}},	//   _fwyd, bska_, ed_,
  { {0x44440122,0x68f6001f,0x9f470240,0x00000000}},	// [ad30] fd_, _gwyd, daný_,
  { {0x444456c4,0x80dc0053,0xd37b019c,0x00000000}},	//   gd_, _पढ़े, лче_,
  { {0x656d56c5,0xd1d9049f,0x45d50861,0x00000000}},	//   syah, адец_, _монс,
  { {0x656d002c,0x444456c6,0x73c40021,0x00000000}},	//   pyah, ad_, سينم,
  { {0x444456c7,0x1a9c0041,0x128a005d,0x00000000}},	//   bd_, נידע, جمنی_,
  { {0x61e20290,0xcee90121,0x2904013d,0x00000000}},	//   acol, адке_, ámai_,
  { {0x645556c8,0x6d47001c,0x61e2003b,0x00000000}},	//   _inzi, ājam, bcol,
  { {0x62890035,0x61e2055b,0x7c280717,0x00000000}},	//   _umeo, ccol, efdr,
  { {0xec790448,0xb5fb56c9,0xec9901ce,0x00000000}},	//   ипи_, _bláz, итој_,
  { {0x29022061,0x68f6002b,0x3fa40014,0x00000000}},	//   vska_, _rwyd, áruð_,
  { {0x68f60185,0xf4120063,0x29020051,0x00000000}},	//   _swyd, ופי_, wska_,
  { {0x5cf50086,0x29021ba3,0x26da56ca,0x00000000}},	//   _дяку, tska_, _rupo_,
  { {0xddc21c0d,0x26da006d,0xb23a0047,0x00000000}},	//   _zlož, _supo_, בערז,
  { {0x38b6010a,0x7870024a,0x9f47027d,0x00000000}},	//   mærk_, _kävi, zaný_,
  { {0x444456cb,0x6d4956cc,0x66e30cb7,0x00000000}},	//   vd_, lvea, доса,
  { {0x61fb56cd,0x75240290,0x645556ce,0x00000000}},	//   _neul, ttiz, _anzi,
  { {0x9f470512,0x44660ac5,0x764427da,0x00000000}},	// [ad40] vaný_, овав, rdiy,
  { {0x629925ca,0x444404bf,0x752456cf,0x00000000}},	//   enwo, ud_, rtiz,
  { {0x673e0117,0xd2aa0076,0x201e0150,0x00000000}},	//   _uspj, акже_, _rcti_,
  { {0xdb9a0047,0x6455332d,0x72290054,0x00000000}},	//   בסער, _enzi, йців_,
  { {0x61ed02dd,0xa50a0001,0x61fb001f,0x00000000}},	//   ñala, _њега_, _deul,
  { {0x1df20053,0xb87b0080,0x61e21264,0x00000000}},	//   घर्ष_, spív, scol,
  { {0x6e2916af,0xdfcf013a,0x6d490168,0x00000000}},	//   ffeb, نيه_, evea,
  { {0xddc236c5,0x61fb1667,0x3e7800ea,0x00000000}},	//   _vlož, _geul, _béta_,
  { {0x3eb8001c,0x467b0047,0x067b0047,0x00000000}},	//   ērt_, יװקײ, ינקל,
  { {0xdca30001,0x224656d0,0x61fb003b,0x00000000}},	//   мањи, ldok_, _zeul,
  { {0xee3a0076,0xddc23af5,0x9f5c0195,0x00000000}},	//   _вне_, _ulož, kavé_,
  { {0x9f4c00fe,0x224656d1,0x7f3b0063,0x00000000}},	//   _vedä_, ndok_, _כעבו,
  { {0x212606a7,0x394d258a,0x22460051,0x00000000}},	//   ntoh_, íes_, idok_,
  { {0x3ea905c9,0x8c430001,0xfbcf007e,0x00000000}},	//   čate_, _жеље, عتی_,
  { {0x64430016,0x9f4500ac,0x5a47000d,0x00000000}},	//   ônim, _aflê_, _дэпа,
  { {0xcb130132,0x6609001c,0x2cac001f,0x00000000}},	//   _חלק_, _ķeks, lodd_,
  { {0x95cb026b,0x3e710025,0x2a6900dd,0x00000000}},	// [ad50] рува_, _dáth_, _ioab_,
  { {0x61fb03b2,0x2cac001f,0x18680001,0x00000000}},	//   _seul, nodd_, _мањи_,
  { {0x3e710027,0x291956d2,0x61fb4819,0x00000000}},	//   _fáth_, lusa_, _peul,
  { {0x05870138,0x2cac0185,0x9f450240,0x00000000}},	//   _дугм, hodd_, _celý_,
  { {0x61fb0003,0xb4db00cd,0xd13b56d3,0x00000000}},	//   _veul, _cràt, рхе_,
  { {0x38b600b9,0xe0420086,0xcef50002,0x00000000}},	//   værk_, енши, пчињ,
  { {0x2cac0185,0x90280088,0x29190009,0x00000000}},	//   dodd_, юцца_, husa_,
  { {0xe1ff007a,0x8d651001,0x22640066,0x00000000}},	//   _þó_, звие, ľská_,
  { {0x2cac0185,0xfd110021,0x291956d4,0x00000000}},	//   fodd_, رجة_, jusa_,
  { {0x3b850001,0x2cac001f,0xe8200053,0x00000000}},	//   злог, godd_, _बाधा_,
  { {0xf4120047,0x3b09005e,0x7e93003b,0x00000000}},	//   עפט_, љемо_, făpt,
  { {0x291956d5,0x5fba009a,0xaf340044,0x00000000}},	//   fusa_, _הצענ, _تركت,
  { {0x3ead006f,0x8c64007e,0x291956d6,0x00000000}},	//   moet_, سطین, gusa_,
  { {0xb87b0024,0x7e93003b,0x3c450044,0x00000000}},	//   dpís, răpu, _رَبِ,
  { {0x9f5c0195,0x29193753,0xc654005d,0x00000000}},	//   tavé_, ausa_, وفسک,
  { {0xb906005a,0xe9a62049,0x291956d7,0x00000000}},	//   _език, _найп, busa_,
  { {0x3ae10026,0x291956d8,0xceb20063,0x00000000}},	// [ad60] _hóp_, cusa_, תין_,
  { {0xf5070121,0xdbe3006c,0x53a60085,0x00000000}},	//   янул_, _déçu, пазб,
  { {0xb87b0066,0xb7db0063,0xe7db0063,0x00000000}},	//   apís, _לקיי, _לקיש,
  { {0xf8bf00ea,0x82890086,0x91e34fc2,0x00000000}},	//   ntén_, осіб_, еоце,
  { {0x25d70063,0x3ead006f,0x224600ea,0x00000000}},	//   _מוכן_, doet_, rdok_,
  { {0x38b60026,0xa505000d,0xe20a0022,0x00000000}},	//   færi_, _ўяўл, dróż_,
  { {0x27470080,0xcfd3005e,0x07360047,0x00000000}},	//   míná_, ношћ, לאַם_,
  { {0x3ead0146,0x2cac001f,0x5d540062,0x00000000}},	//   goet_, wodd_, дкит,
  { {0x443a00ac,0x2cac002b,0x76460058,0x00000000}},	//   oep_, todd_, _maky,
  { {0x95880051,0x443a56d9,0x3ae10013,0x00000000}},	//   ciąż, nep_, _bóp_,
  { {0x2cac0185,0x200c001f,0x59a50053,0x00000000}},	//   rodd_, _iddi_, _गुजर,
  { {0x2cac001f,0x443a56da,0x29194506,0x00000000}},	//   sodd_, hep_, tusa_,
  { {0x443a56db,0x3d130053,0x6480004b,0x00000000}},	//   kep_, _दिये_, _köid,
  { {0xdd3b0063,0x2919063d,0x443a007d,0x00000000}},	//   _לעדכ, rusa_, jep_,
  { {0x3ae1001b,0x57a40095,0x7c3a56dc,0x00000000}},	//   _góp_, ешта, metr,
  { {0x291900ea,0x8aa4000d,0xba5502d8,0x00000000}},	//   pusa_, _прыд, _цвиј,
  { {0x764600e3,0x200c0185,0xe5340054,0x00000000}},	// [ad70] _daky, _oddi_, неть,
  { {0x7c3a56dd,0xb87b011b,0x19b80044,0x00000000}},	//   netr, apír, _عطية_,
  { {0x7c3a56de,0x99820078,0x04c80044,0x00000000}},	//   ietr, bekų_, أولي_,
  { {0x200c0089,0xa507000d,0x63b5004a,0x00000000}},	//   _addi_, _нягл, _vyzn,
  { {0x5045000a,0x7c3a00d1,0x63b50051,0x00000000}},	//   делб, ketr, _wyzn,
  { {0x443a25eb,0x764601a8,0xdb030066,0x00000000}},	//   cep_, _zaky, _vynú,
  { {0x22950062,0x4423113c,0x3ead1171,0x00000000}},	//   _живя, _icj_, toet_,
  { {0x200c3230,0x64470b54,0x95880051,0x00000000}},	//   _eddi_, _haji, siąż,
  { {0x6447053b,0x3ead2a76,0xccc50591,0x00000000}},	//   _kaji, roet_, мбий,
  { {0xeb990001,0x7c3a05e1,0xb6040078,0x00000000}},	//   жио_, getr, įšit,
  { {0x290900fe,0x442300cd,0x644756df,0x00000000}},	//   _avaa_, _mcj_, _maji,
  { {0x644700fe,0xdd8e007e,0x6ee70058,0x00000000}},	//   _laji, اوی_, _tıbb,
  { {0x76460397,0xda1f0053,0x62980003,0x00000000}},	//   _raky, _भारत_, évoi,
  { {0x644756e0,0x7d1b021e,0xf8bf56e1,0x00000000}},	//   _naji, muus, stén_,
  { {0x8b940062,0x7c3c004b,0x68ed56e2,0x00000000}},	//   _пръч, õrre, _etad,
  { {0x6ba3003b,0xfbd20063,0x8afa0063,0x00000000}},	//   ăugă, _בתו_, _והקי,
  { {0x644756e3,0x7d1b01cf,0x97da0044,0x00000000}},	// [ad80] _baji, nuus, _وبدأ_,
  { {0xe73a0138,0x61e9051e,0x3ea0065f,0x00000000}},	//   _део_, _afel, čiti_,
  { {0x7e6b0229,0x443a56e4,0xb87b0014,0x00000000}},	//   _oogp, rep_, ppír,
  { {0x7d1b0659,0x443a56e5,0xd250014d,0x00000000}},	//   kuus, sep_, طنت_,
  { {0xd13003eb,0x60f7000d,0x660452cc,0x00000000}},	//   امت_, днія_, maik,
  { {0x660456e6,0x644756e7,0xa0670092,0x00000000}},	//   laik, _gaji, даља_,
  { {0xdfd00032,0x57fb0063,0x7e6b01e1,0x00000000}},	//   ديث_, קלקו, _bogp,
  { {0x644702f4,0x667b56e8,0x941e0053,0x00000000}},	//   _zaji, ַװיג, _पाँच_,
  { {0x7d1b00a4,0x628209fe,0x2d84007d,0x00000000}},	//   guus, mhoo, uzme_,
  { {0x3e780080,0x6282150e,0x44e456e9,0x00000000}},	//   _této_, lhoo, _mö_,
  { {0xeb97000a,0x6e4700c7,0x660456ea,0x00000000}},	//   диќ_, örbä, kaik,
  { {0x3952001f,0x628228b0,0x7d1b085b,0x00000000}},	//   _brys_, nhoo, buus,
  { {0x984b005a,0x44e4004b,0x6604017e,0x00000000}},	//   оява_, _nö_, daik,
  { {0x58d40e82,0xa3c00042,0xeb8f0043,0x00000000}},	//   коят, ुधा_, اظی_,
  { {0x6282006f,0x6447227c,0xc7b80121,0x00000000}},	//   khoo, _raji, дёт_,
  { {0x9f5c0024,0x644756eb,0x66042617,0x00000000}},	//   javí_, _saji, gaik,
  { {0x39521a5f,0x628256ec,0x3e710014,0x00000000}},	// [ad90] _grys_, dhoo, _gátu_,
  { {0x3e71007a,0x44e401bb,0x62820229,0x00000000}},	//   _hátt_, _dö_, ehoo,
  { {0xf8bf0016,0xa5bb0027,0x660407f4,0x00000000}},	//   ntém_, _gcón, baik,
  { {0x44e400c7,0xfd5e008b,0x6447091c,0x00000000}},	//   _fö_, _quyể, _waji,
  { {0xc616014e,0x3e710026,0x644756ed,0x00000000}},	//   _אחרי_, _mátt_, _taji,
  { {0x7d1b00fe,0xc0c8005e,0x615201f3,0x00000000}},	//   vuus, мује_, انوئ,
  { {0x38b605dd,0xfd5e008b,0x9f5c0566,0x00000000}},	//   mært_, _tuyể, baví_,
  { {0x38b60205,0x7d1b00fe,0x628228b0,0x00000000}},	//   lært_, tuus, choo,
  { {0x8c950454,0xf8bf013d,0x21550085,0x00000000}},	//   ерні, ttél_, _якаў,
  { {0x0d820088,0x66042c1d,0x7d1b0659,0x00000000}},	//   ульн, zaik, ruus,
  { {0x4421018d,0x7d1b00fe,0x61e400c2,0x00000000}},	//   igh_, suus, žile,
  { {0x26d90198,0x39521cbf,0x6d40002b,0x00000000}},	//   _niso_, _prys_, bwma,
  { {0x660456ee,0xfe79004c,0x61190063,0x00000000}},	//   vaik, mků_, הוָה,
  { {0x2d940051,0xfe79004c,0x44e401bb,0x00000000}},	//   ódeł_, lků_, _rö_,
  { {0x66042a51,0x7d0956ef,0x44e42502,0x00000000}},	//   taik, lses, _sö_,
  { {0x39520006,0x9f9b004b,0x7bc3007d,0x00000000}},	//   _trys_, määr_, _iznu,
  { {0x7d0956f0,0x66043fbb,0x38b60026,0x00000000}},	// [ada0] nses, raik, fært_,
  { {0xe72a005a,0x7d090d9e,0x69c4001c,0x00000000}},	//   _еоод_, ises, _izie,
  { {0x7aeb000c,0x62820706,0xbfa30013,0x00000000}},	//   _întă, thoo, uyế,
  { {0x7d0956f1,0x2366017f,0xdcb10013,0x00000000}},	//   kses, ćoj_, hỏ_,
  { {0xfe7902f4,0x9f5c0114,0x38b60014,0x00000000}},	//   dků_, raví_, bært_,
  { {0x628256f2,0x8f460062,0x7d0956f3,0x00000000}},	//   shoo, ехид, dses,
  { {0x645c56f4,0x64a3157c,0x37db0047,0x00000000}},	//   _inri, _сара, פֿגע,
  { {0x1d34005a,0x9f5e0003,0x5d660cf7,0x00000000}},	//   вния, _jeté_, етоз,
  { {0x6280024a,0xdd90007e,0x6298006c,0x00000000}},	//   _ilmo, شود_, évou,
  { {0x3e710014,0xe61f017c,0x9f5e011b,0x00000000}},	//   _sátt_, _hmôt_, _leté_,
  { {0x69c4051e,0x8a190002,0xfe79004c,0x00000000}},	//   _azie, монс_, bků_,
  { {0x7d090150,0xc3330063,0xe9d1005e,0x00000000}},	//   bses, נור_, игнy_,
  { {0xf8bf0114,0x26d956f5,0x9f5e01a8,0x00000000}},	//   stém_, _riso_, _setè_,
  { {0x69c40045,0xba3b0003,0x3ea0007d,0x00000000}},	//   _dzie, roïq, čitu_,
  { {0x60da3e1f,0xf8bf00ea,0x7793007e,0x00000000}},	//   _mitm, lték_, ایجا,
  { {0x60da2891,0xba770049,0x98c10058,0x00000000}},	//   _litm, _ساعت, ısır_,
  { {0x386d00ac,0x26d956f6,0x38b60093,0x00000000}},	// [adb0] êers_, _viso_, tært_,
  { {0x44210037,0x7d1d0268,0xfe790080,0x00000000}},	//   ugh_, àssi, zků_,
  { {0x44215284,0x26d90066,0xad9d0022,0x00000000}},	//   rgh_, _tiso_, jaźn,
  { {0xa3cd0235,0xe2980086,0x290b0025,0x00000000}},	//   शेष_, нає_, osca_,
  { {0xfe790080,0x765d56f7,0xdced008f,0x00000000}},	//   vků_, _insy, ējīg,
  { {0x2249017f,0x7d0909db,0xf8bf013d,0x00000000}},	//   žak_, vses, dték_,
  { {0xfe790080,0x60da006f,0x752d3096,0x00000000}},	//   tků_, _ditm, ltaz,
  { {0x7d090004,0x764d56f8,0x752d56f9,0x00000000}},	//   tses, nday, otaz,
  { {0x752d02f6,0x290b0051,0x61e400c2,0x00000000}},	//   ntaz, jsca_, žilc,
  { {0x6ab600e8,0x60da005b,0x752d0290,0x00000000}},	//   _skyf, _gitm, itaz,
  { {0x5f79006a,0x8c3c01f7,0x200756fa,0x00000000}},	//   _تماس_, toğr, mani_,
  { {0x20070e29,0x8a060062,0x60da00ca,0x00000000}},	//   lani_, ъзме, _zitm,
  { {0xf2d20047,0x9f5e01a8,0x6d47008f,0x00000000}},	//   יעט_, _reté_, ājas,
  { {0x62880078,0x7e691529,0x38b601e1,0x00000000}},	//   _įdom, ljep, værs_,
  { {0x20070290,0x66e6180e,0x291956fb,0x00000000}},	//   iani_, тоба, arsa_,
  { {0x200716cb,0x6aa40035,0x7e6956fc,0x00000000}},	//   hani_, _ujif, njep,
  { {0x2007047d,0x7ae356fd,0xe4e50054,0x00000000}},	// [adc0] kani_, _hunt, гієн,
  { {0xba3b001f,0x200756fe,0xa5bb0139,0x00000000}},	//   mnïa, jani_, _gcóm,
  { {0x68e40102,0x7ae32025,0xf8bf00ea,0x00000000}},	//   _huid, _junt, zték_,
  { {0x68e40004,0x7ae356ff,0xf5061fc6,0x00000000}},	//   _kuid, _munt, _измо,
  { {0x20075700,0x7e691c2d,0x7ae330fc,0x00000000}},	//   fani_, djep, _lunt,
  { {0x443e007a,0x3e4e0013,0xf1a901fb,0x00000000}},	//   _út_, _ột_, رانه_,
  { {0x68e40983,0x389b0047,0x7ae35701,0x00000000}},	//   _luid, ויסנ, _nunt,
  { {0xf8bf000f,0xad9d0051,0x2007004e,0x00000000}},	//   tték_, raźn, aani_,
  { {0xc693014e,0xe2970001,0xc0e60086,0x00000000}},	//   יאה_, _рат_, _розк,
  { {0x60da0179,0xa0c90021,0x20075702,0x00000000}},	//   _uitm, _كذلك_, cani_,
  { {0x7ae30027,0x441b0047,0x09bd0053,0x00000000}},	//   _cunt, וויס, ोध्य,
  { {0x68e45703,0xbb930121,0x7e690130,0x00000000}},	//   _buid, рающ, cjep,
  { {0x61ed006d,0x68e45704,0x290b00ed,0x00000000}},	//   ñali, _cuid, usca_,
  { {0x68e40173,0xa8a40980,0xcb540049,0x00000000}},	//   _duid, арск, _منتظ,
  { {0x7ae34da4,0xc1080013,0xd6db5705,0x00000000}},	//   _gunt, hỗ_, дта_,
  { {0x752d051e,0x200701a6,0x0bb7014e,0x00000000}},	//   ttaz, zani_, _שלהם_,
  { {0x200703f7,0x764d070e,0x752d0035,0x00000000}},	// [add0] yani_, rday, utaz,
  { {0x752d5706,0x7ae300ae,0x4427005b,0x00000000}},	//   rtaz, _yunt, ün_,
  { {0x752d02f6,0x68e40122,0x20075707,0x00000000}},	//   staz, _zuid, vani_,
  { {0x2007046c,0x3d13016a,0xf6790047,0x00000000}},	//   wani_, _दिले_, _נאָמ,
  { {0x9564005a,0x361a0149,0x20075708,0x00000000}},	//   _кърд, _אורד, tani_,
  { {0x34950abb,0xb97c3997,0x90c50085,0x00000000}},	//   _сагр, ונדי, ыбле,
  { {0x20075709,0x61e4007d,0x201a19b8,0x00000000}},	//   rani_, žila, ópia_,
  { {0x39490004,0xdb2500ea,0x78b500ea,0x00000000}},	//   _osas_, épít, hozv,
  { {0x7ae30492,0x7e6927fe,0x2007570a,0x00000000}},	//   _sunt, rjep, pani_,
  { {0x7ae3570b,0x62990051,0x68e40e7c,0x00000000}},	//   _punt, liwo, _ruid,
  { {0x68e400e8,0x3949035e,0xb0b60047,0x00000000}},	//   _suid, _asas_, _עפעס_,
  { {0x68e4112c,0xdb030022,0x8f880063,0x00000000}},	//   _puid, _synó, _בְנֵ,
  { {0x20050218,0x127a0047,0x68e4466a,0x00000000}},	//   _keli_, גארע, _quid,
  { {0x7ae3570c,0xad1a0063,0x3ebf0f3b,0x00000000}},	//   _tunt, _נוצר, llut_,
  { {0x3949570d,0x20050035,0x7c34013d,0x00000000}},	//   _esas_, _meli_, égrő,
  { {0xcf920047,0x7d1b570e,0x2005009c,0x00000000}},	//   צטן_, orus, _leli_,
  { {0xee5c0026,0x32040d66,0x3ebf0072,0x00000000}},	// [ade0] æðið_, _remy_, ilut_,
  { {0x20050019,0x7d1b26cc,0xf484005d,0x00000000}},	//   _neli_, irus, جاری,
  { {0x7d1b3175,0x6e2e013d,0x9bc9009a,0x00000000}},	//   hrus, őbbi, תֶּ֖,
  { {0x979b0047,0x0bb60041,0xd67a0044,0x00000000}},	//   _טשיק, אלעם_, _أحدا_,
  { {0x200527ca,0x99890022,0x6e940043,0x00000000}},	//   _beli_, _zdał_, یلتا,
  { {0x6f01001f,0x6606570f,0x2ef40062,0x00000000}},	//   _bwlc, _hekk, азкр,
  { {0xd8d70047,0x66065710,0x20055711,0x00000000}},	//   נוצט_, _kekk, _deli_,
  { {0xb5fb039f,0x26c001f4,0x644e18b4,0x00000000}},	//   _inác, nlio_, _habi,
  { {0x644e5712,0xd24f0021,0xf8bf0003,0x00000000}},	//   _kabi, _عنك_, luée_,
  { {0x9b580079,0x20050089,0x644e5713,0x00000000}},	//   виот_, _geli_, _jabi,
  { {0x644e03d5,0x2ee50034,0x26c00006,0x00000000}},	//   _mabi, _gulf_, klio_,
  { {0x3ebf0003,0x644e5714,0x7d1b5715,0x00000000}},	//   clut_, _labi, brus,
  { {0xa3d60053,0x7d1b5716,0x44381ad3,0x00000000}},	//   ाइड_, crus, _obr_,
  { {0xac1852c7,0x644e5717,0x62990022,0x00000000}},	//   _року_, _nabi, ziwo,
  { {0x66065718,0x66190022,0x67d51ece,0x00000000}},	//   _bekk, ówko, рову,
  { {0x26c002f6,0x644e19fb,0x3a29017e,0x00000000}},	//   glio_, _aabi, _ucap_,
  { {0x66062d27,0x39495719,0x65150021,0x00000000}},	// [adf0] _dekk, _usas_, شوائ,
  { {0x45b8014c,0x8883005d,0x644e295c,0x00000000}},	//   угую_, _ایسن, _cabi,
  { {0x20051964,0xf8bf0003,0x26c01eee,0x00000000}},	//   _reli_, guée_, blio_,
  { {0x4438001f,0xd6fa0047,0x41550071,0x00000000}},	//   _ebr_, _שפרכ, ивес,
  { {0x644e571a,0x9f5e0066,0x98a20022,0x00000000}},	//   _fabi, _detí_, stką_,
  { {0xf8bf0003,0xdc1e0053,0x442506a5,0x00000000}},	//   buée_, पलोड_, _øl_,
  { {0xb5fb0139,0x3e780014,0x2005571b,0x00000000}},	//   _gnác, _létu_, _veli_,
  { {0x3ebf0072,0x7d1b2e2d,0x225f0130,0x00000000}},	//   ulut_, trus, _unuk_,
  { {0x645a017d,0x1e8201dd,0x7d1b388f,0x00000000}},	//   _ótic, ільм, urus,
  { {0x3ebf1374,0xec760121,0x7d1b571c,0x00000000}},	//   slut_, ипы_, rrus,
  { {0x26c0001f,0x3ebf1653,0x5aca3f17,0x00000000}},	//   ylio_, plut_, клом_,
  { {0xeb960076,0x7d1b571d,0x93b6009a,0x00000000}},	//   рию_, prus, ילתו_,
  { {0x66060031,0xcd290002,0x8288009a,0x00000000}},	//   _rekk, _ржле_, רְתֶ,
  { {0x26c0001f,0x6d59017e,0xa5bb0139,0x00000000}},	//   wlio_, _irwa, _gcói,
  { {0x644e571e,0xa6960259,0x660601cf,0x00000000}},	//   _rabi, арај, _pekk,
  { {0x443800ac,0x442a0137,0x644e571f,0x00000000}},	//   _sbr_, _scb_, _sabi,
  { {0x660600d1,0x644e5720,0x2d8d1215,0x00000000}},	// [ae00] _vekk, _pabi, nzee_,
  { {0x4463019d,0xf8bf0164,0x26c0017f,0x00000000}},	//   овув, tuée_, slio_,
  { {0x644e00c3,0x66060004,0x26c0006d,0x00000000}},	//   _vabi, _tekk, plio_,
  { {0xc2170086,0xd259071f,0x3f9a0046,0x00000000}},	//   аєш_, лці_, úpum_,
  { {0x644e1e71,0xa06a0259,0x201a017d,0x00000000}},	//   _tabi, када_, ópio_,
  { {0x7524006f,0x3e780014,0x10a30456,0x00000000}},	//   muiz, _létt_, оичн,
  { {0xf8bf0164,0xa2d6007e,0x6d595721,0x00000000}},	//   quée_, _نيست, _arwa,
  { {0x9df70062,0x44445722,0x68f600a5,0x00000000}},	//   анът_, le_, _otyd,
  { {0x68f600b9,0x44444129,0x22590014,0x00000000}},	//   _ntyd, oe_, _óska_,
  { {0x44445723,0x6d590022,0x1fb65724,0x00000000}},	//   ne_, _drwa, _ксер,
  { {0xe45700b5,0x7524006f,0x6d590c84,0x00000000}},	//   בייט_, huiz, _erwa,
  { {0x44445725,0xff7b0047,0xbf9b009a,0x00000000}},	//   he_, _שטאמ, _ביבש,
  { {0x8cf40021,0x7e624247,0x44445726,0x00000000}},	//   _اكتش, _inop, ke_,
  { {0x44442225,0x75245727,0x8c432c5c,0x00000000}},	//   je_, duiz, _мече,
  { {0x7e621a20,0x44445728,0x68f6102d,0x00000000}},	//   _knop, de_, _etyd,
  { {0x9f5e051e,0x6d4b001f,0x4444448f,0x00000000}},	//   _metà_, _ysga, ee_,
  { {0x44441b85,0x7524053c,0x998000dd,0x00000000}},	// [ae10] fe_, guiz, _idiş_,
  { {0x3ea905c9,0x7c2819a5,0x44445729,0x00000000}},	//   čati_, ngdr, ge_,
  { {0xf367257e,0x7e620983,0x11f7005d,0x00000000}},	//   штан, _onop, لواک_,
  { {0x44440185,0x4b370132,0xd370005d,0x00000000}},	//   ae_, שראל_, بهٔ_,
  { {0x660d0a53,0x27ec0024,0x463a0047,0x00000000}},	//   maak, ždne_, _גערע,
  { {0x6754007e,0x660d0072,0xf8bf2abf,0x00000000}},	//   _اخیر, laak, mtés_,
  { {0x64450035,0xf8bf572a,0x5fd40062,0x00000000}},	//   mehi, ltés_, оцъф,
  { {0xc3320063,0x6445572b,0x660d572c,0x00000000}},	//   _מול_, lehi, naak,
  { {0x3e78007a,0xf8bf572d,0xe1f000de,0x00000000}},	//   _rétt_, ntés_, _آسف_,
  { {0xcc89006a,0xf8bf0164,0x660d006f,0x00000000}},	//   انده_, ités_, haak,
  { {0x75240035,0xbb450156,0x09e617f2,0x00000000}},	//   zuiz, щенк, йонн,
  { {0x6d590051,0xa5c20014,0x660d01cf,0x00000000}},	//   _trwa, þókn, jaak,
  { {0x444425c5,0x64453af6,0x6d4b004d,0x00000000}},	//   ye_, kehi, _usga,
  { {0x3ff900b5,0x6e29572e,0x44442d08,0x00000000}},	//   טפֿע, lgeb, xe_,
  { {0x17790928,0x9a6a0021,0xe6c601fb,0x00000000}},	//   асть_, _ممثل_, متري,
  { {0x7524572f,0x3f7a0047,0x07a317b2,0x00000000}},	//   tuiz, אָמע, часн,
  { {0xc486000d,0x68f600d1,0x6e29004d,0x00000000}},	// [ae20] блак, _utyd, igeb,
  { {0x64450396,0x44440955,0x6e29004d,0x00000000}},	//   gehi, ue_, hgeb,
  { {0x1877014e,0x44445655,0x6e293c1c,0x00000000}},	//   _העיר_, re_, kgeb,
  { {0x6e29006f,0x366a12d5,0xf8bf013d,0x00000000}},	//   jgeb, _само_, stét_,
  { {0xf8bf00f4,0x752407a8,0x6e295730,0x00000000}},	//   ctés_, quiz, dgeb,
  { {0x6e295731,0x7416005d,0x7e625732,0x00000000}},	//   egeb, _دوسا, _snop,
  { {0x43860032,0xf8bf0026,0x6e295733,0x00000000}},	//   _الأق, bréf_, fgeb,
  { {0x39401b2a,0xf8bf5734,0x3d130042,0x00000000}},	//   _opis_, ntér_, _दिखे_,
  { {0xd59b00b5,0xdb180114,0x98a20022,0x00000000}},	//   ָביל, _vyví, stkę_,
  { {0x20c90139,0xf8bf013d,0x5b141225,0x00000000}},	//   lúin_, mrég_, омот,
  { {0x2d825735,0x6fb6007e,0x3940455c,0x00000000}},	//   ške_, _امضا, _apis_,
  { {0x628238e7,0x8c18007e,0x5eeb0063,0x00000000}},	//   nkoo, ديگر_, _עַבְ,
  { {0xc9840896,0x6282004e,0x1e57009a,0x00000000}},	//   пури, ikoo, _לשאר_,
  { {0xd9180055,0x660d0250,0x200e1d4c,0x00000000}},	//   щью_, waak, nafi_,
  { {0x6282119d,0x660d458c,0x64455736,0x00000000}},	//   kkoo, taak, vehi,
  { {0xf96b011c,0xe6940076,0xfaa4018e,0x00000000}},	//   _брой_, писы, _најо,
  { {0x54990088,0xf8bf0164,0x62822a3f,0x00000000}},	// [ae30] аваў_, utés_, dkoo,
  { {0xf8070259,0xf8bf5737,0x62825738,0x00000000}},	//   _учин, rtés_, ekoo,
  { {0x64450012,0xf8bf5739,0x200e4f11,0x00000000}},	//   rehi, stés_, dafi_,
  { {0x7aea0228,0x64450019,0x62820019,0x00000000}},	//   _muft, sehi, gkoo,
  { {0x47d5006a,0xd0090002,0x7aea573a,0x00000000}},	//   _ديگر, аеле_, _luft,
  { {0x7bc60051,0x20540062,0x65600139,0x00000000}},	//   ękuj, зтър, _ámha,
  { {0x6e291517,0x20c90014,0x987c0047,0x00000000}},	//   tgeb, búin_, ררוק,
  { {0xdee20062,0x6d4900e5,0x628251c9,0x00000000}},	//   мощи, twea, ckoo,
  { {0x7aea00bd,0x629b0290,0x6e29287d,0x00000000}},	//   _auft, _imuo, rgeb,
  { {0x9f6300ea,0x6e29573b,0x6d4900e5,0x00000000}},	//   ívót_, sgeb, rwea,
  { {0x3b090001,0x39400051,0x3df5000d,0x00000000}},	//   јемо_, _spis_, _дзес,
  { {0xc8690a7a,0x3a9a0054,0x4a9a0085,0x00000000}},	//   _בן_, ртою_, ртоў_,
  { {0x6dc70021,0x3eb800ea,0x7aed008f,0x00000000}},	//   _ازال, _írta_, _čatu,
  { {0x62890185,0x394000c3,0x7bc70014,0x00000000}},	//   _lleo, _vpis_, ýjus,
  { {0x869a000a,0xf8bf00ea,0x62891454,0x00000000}},	//   атат_, ttér_, _oleo,
  { {0x6aad0014,0x95860121,0x4df90041,0x00000000}},	//   _gjaf, олбе, שפּא,
  { {0x3940007d,0xe6c50044,0xf8bf011b,0x00000000}},	// [ae40] _upis_, ستفي, rtér_,
  { {0xa3d60053,0x03a60612,0xb5fb006d,0x00000000}},	//   ाइल_, оизо, _unán,
  { {0x7ae4573c,0xc1ea0bd8,0xb716005d,0x00000000}},	//   _kiit, адеж_, _ببخش,
  { {0x26c4006d,0xe2460021,0xa1c60cd6,0x00000000}},	//   _ómo_, تخطي, обед,
  { {0x78bc006f,0x200e0026,0x628211c8,0x00000000}},	//   oorv, tafi_, rkoo,
  { {0x7ae4037e,0x672101a6,0x6289573d,0x00000000}},	//   _liit, šlje, _eleo,
  { {0xdfd30085,0x200e573e,0x4e8a0054,0x00000000}},	//   мошы, rafi_, ищим_,
  { {0x7ae4024a,0x877b0063,0x8e200086,0x00000000}},	//   _niit, יאצי, _вiн_,
  { {0x78bc0ff2,0x0dca0054,0x75360022,0x00000000}},	//   korv, шуки_, ntyz,
  { {0x7d1d00ea,0xb5fb573f,0x6aad0150,0x00000000}},	//   ássa, _anál, _sjaf,
  { {0x7bc30185,0x54570047,0x99990066,0x00000000}},	//   _cynu, קסטן_, iesť_,
  { {0xe8d9001b,0x200c0150,0xfce65740,0x00000000}},	//   _trị_, _hedi_, _додо,
  { {0x78bc06a5,0x6aae0058,0x200c0058,0x00000000}},	//   forv, _şofö, _kedi_,
  { {0xa5bb00cd,0xdfc60021,0x7aea5741,0x00000000}},	//   _ocór, في_, _tuft,
  { {0x7bc3001f,0x200c27eb,0x20c90139,0x00000000}},	//   _gynu, _medi_, dúil_,
  { {0xf8bf1eff,0x68fd1310,0x95cb0bd8,0x00000000}},	//   drée_, ppsd, ауза_,
  { {0x7c3a00ac,0x200c001f,0x6abd5742,0x00000000}},	// [ae50] oftr, _oedi_, mosf,
  { {0x26cc0268,0x2cfb0047,0x645a0014,0x00000000}},	//   ïdor_, ילמא, _ótil,
  { {0xf8bf0003,0x8c3c0058,0x62895743,0x00000000}},	//   grée_, ciğe, _pleo,
  { {0x7ae40016,0x29090035,0x6abd5744,0x00000000}},	//   _xiit, _kwaa_, nosf,
  { {0x68ed00e3,0x4104000d,0x1a9c0047,0x00000000}},	//   _juad, дзів, סידע,
  { {0xf8bf0003,0x6abd002b,0xc57a009d,0x00000000}},	//   brée_, hosf, _הרשת,
  { {0xa5bb0025,0xf8bf0164,0x69cb00b9,0x00000000}},	//   _gcór, crée_, _øgef,
  { {0x64553a57,0xe29f0014,0x2d953461,0x00000000}},	//   _hazi, _öð_, зрос,
  { {0x7ae400fe,0xa0c50593,0xdca55745,0x00000000}},	//   _riit, _فيرو, запи,
  { {0x7ae4024a,0x64555746,0x50950043,0x00000000}},	//   _siit, _jazi, _علاء,
  { {0x64555747,0x6abd5748,0x7ae401a9,0x00000000}},	//   _mazi, fosf, _piit,
  { {0x64555749,0x68e50072,0x7bc3574a,0x00000000}},	//   _lazi, _aihd, _vynu,
  { {0x68ed02dd,0x200c005b,0x7ae4574b,0x00000000}},	//   _cuad, _yedi_, _viit,
  { {0x6455574c,0xacfa0063,0x68ed002b,0x00000000}},	//   _nazi, _ההסכ, _duad,
  { {0x366a06be,0x7ae4004b,0x2aa400ea,0x00000000}},	//   баво_, _tiit, rűbb_,
  { {0x78bc2ec9,0xf8bf0153,0x61e4007d,0x00000000}},	//   sorv, vrée_, žili,
  { {0x20c90025,0x68ed2264,0xb4d70053,0x00000000}},	// [ae60] túil_, _guad, ागू_,
  { {0xf8bf0164,0xa84a0021,0x3636007e,0x00000000}},	//   trée_, _الدم_, _کردس,
  { {0xa87b0063,0x20c90025,0x645a017d,0x00000000}},	//   _האיר, rúil_, _ótim,
  { {0x20c90027,0x25ad017f,0x3d1c0053,0x00000000}},	//   súil_, _žele_, _मिले_,
  { {0x6455574d,0x200c2408,0x66045553,0x00000000}},	//   _fazi, _pedi_, mbik,
  { {0x442c01e1,0x6604004b,0x61e9574e,0x00000000}},	//   _ød_, lbik, _egel,
  { {0x200c051e,0x43430b0f,0xddcb0051,0x00000000}},	//   _vedi_, _перв, _nagł,
  { {0x200c0c70,0x2e4a0062,0x64551ba9,0x00000000}},	//   _wedi_, сяко_, _zazi,
  { {0x4e170049,0x9f5e0072,0xe6110063,0x00000000}},	//   ستيد_, _setä_, כִי_,
  { {0x7c3a00bd,0xdc980054,0x752400be,0x00000000}},	//   uftr, івні_, iriz,
  { {0x75240089,0x6abd574f,0x7bf7014b,0x00000000}},	//   hriz, tosf, янэр_,
  { {0xfa8b0121,0xe9810085,0x602f009c,0x00000000}},	//   ссой_, вамi_, rőmű,
  { {0xc4be0161,0x62980003,0xac181910,0x00000000}},	//   ्ताओ, évoy, _долу_,
  { {0x387a002b,0x7524039d,0xe8d90013,0x00000000}},	//   _copr_, driz, _trọ_,
  { {0xddc9017f,0x6af30021,0x64551b2a,0x00000000}},	//   mješ, _كثير, _razi,
  { {0xddc9017f,0x64555750,0x6ee7005b,0x00000000}},	//   lješ, _sazi, _kıbr,
  { {0xdddb017f,0x95cb05fb,0xc8672c47,0x00000000}},	// [ae70] okuš, сува_, _етни,
  { {0x26c25751,0x6604004b,0x387a00a3,0x00000000}},	//   _ekko_, abik, _gopr_,
  { {0x92590076,0x64555752,0xddc9007d,0x00000000}},	//   жает_, _vazi, iješ,
  { {0x64550009,0x75240afd,0xc708009a,0x00000000}},	//   _wazi, briz, _מִשֹ,
  { {0xdb18024a,0x7524051e,0x69cb00b9,0x00000000}},	//   _hyvä, criz, _øged,
  { {0xe0d3007e,0x26c904d0,0x660f5753,0x00000000}},	//   رزش_, llao_, _heck,
  { {0xdb180072,0xddc90130,0x4f320043,0x00000000}},	//   _jyvä, dješ, نفوذ,
  { {0x69ce0042,0xc332009a,0x00000000,0x00000000}},	//   _सरली, _שון_,   ,
  { {0x9fe70021,0x6e3b0014,0x660f5754,0x00000000}},	//   _فساه, rfub, _meck,
  { {0x660f5755,0xfce50054,0x3b85079b,0x00000000}},	//   _leck, ьопо, длог,
  { {0xf8bf0016,0x661d553f,0x6d5b165b,0x00000000}},	//   guém_, _odsk, svua,
  { {0x2f18000d,0xedd50021,0x2fc0004d,0x00000000}},	//   _хоць_, _قياد, ßige_,
  { {0x3ead02eb,0x387a00c2,0x6480004b,0x00000000}},	//   mnet_, _popr_, _köit,
  { {0x661d0d02,0x48e30062,0x66f50078,0x00000000}},	//   _adsk, кояв, _sąka,
  { {0x661d00ac,0x660f5756,0x9f5c0195,0x00000000}},	//   _bdsk, _beck, kavý_,
  { {0x3ebf02f4,0x3ead3e2a,0x75245757,0x00000000}},	//   nout_, nnet_, triz,
  { {0x66045758,0xe5a35759,0x98a2008f,0x00000000}},	// [ae80] rbik, вити, aukā_,
  { {0x3ead00bd,0x6721027c,0x7524575a,0x00000000}},	//   hnet_, šlja, rriz,
  { {0x93c3000c,0xa5bb00ea,0x3ead00df,0x00000000}},	//   _ţări, _adód, knet_,
  { {0xd1ca0be6,0xdddb0ae1,0x3ebf006c,0x00000000}},	//   олее_, zkuš, jout_,
  { {0x8f000054,0x3ead575b,0x3ebf37b6,0x00000000}},	//   цiю_, dnet_, dout_,
  { {0x74e70086,0x660f0206,0x916d008d,0x00000000}},	//   _одяг_, _zeck, uốt_,
  { {0xddc90117,0x20b90088,0x3ead00bd,0x00000000}},	//   vješ, чыць_, fnet_,
  { {0x3ead0c23,0x3ebf575c,0x31690066,0x00000000}},	//   gnet_, gout_, ťaza_,
  { {0x32060a9f,0xbc4a575d,0xbda60044,0x00000000}},	//   mboy_, очне_, بحثو,
  { {0x320600e5,0xd197009a,0x00000000,0x00000000}},	//   lboy_, _חכמי_,   ,
  { {0x3ebf04bc,0xddc9007d,0x3ead575e,0x00000000}},	//   bout_, rješ, bnet_,
  { {0xdddb00c3,0xbd460021,0x0d860156,0x00000000}},	//   skuš, _يناي, _олен,
  { {0xddc9017f,0x26c00290,0xdb180072,0x00000000}},	//   pješ, doio_, _syvä,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xbc67007e,0xdb1804aa,0x2d84008d,0x00000000}},	//   _زمين_, _byvå, lyme_,
  { {0xe8d90013,0x98a2008f,0x85050021,0x00000000}},	//   _trỏ_, rukā_, فورن,
  { {0x660f01e3,0xf8ae006a,0xb4d5047e,0x00000000}},	// [ae90] _veck, شکی_, ежащ,
  { {0xdb1800c7,0x26c9575f,0xf4840062,0x00000000}},	//   _tyvä, slao_, кухн,
  { {0x660f01e3,0x3ead5760,0x3ebf5761,0x00000000}},	//   _teck, ynet_, yout_,
  { {0x661d0146,0xe298019d,0x29194712,0x00000000}},	//   _udsk, має_, ossa_,
  { {0x2919024a,0x3ead02ab,0xe1670021,0x00000000}},	//   nssa_, vnet_, بداي,
  { {0x7ff5006a,0x29192c9c,0xf5360063,0x00000000}},	//   رستا, issa_, _אנשי_,
  { {0x3ead0f6e,0xdbd6003a,0x2d82000e,0x00000000}},	//   tnet_, _jääk, øken_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xc0cb52c7,0xdbd600fe,0x752d0290,0x00000000}},	//   _дуже_, _lääk, nuaz,
  { {0xeb990001,0x3ebf0003,0x3ead5762,0x00000000}},	//   зио_, sout_, snet_,
  { {0x200700c3,0x29195763,0x3ead00cf,0x00000000}},	//   mbni_, essa_, pnet_,
  { {0x3d950bd8,0x2f5a009a,0x00000000,0x00000000}},	//   _пиер, _מדענ,   ,
  { {0xf2d20047,0x61fb0035,0x8d870044,0x00000000}},	//   טעט_, _mful, _تشان,
  { {0x752d0290,0x6c350021,0xeb9904f2,0x00000000}},	//   duaz, _أفغا, _нил_,
  { {0x26c00290,0x2ca50026,0x61fb0137,0x00000000}},	//   toio_, mild_, _oful,
  { {0xc6a5005e,0x22b800b2,0x69c00058,0x00000000}},	//   врђи, očke_, ümes,
  { {0x22b800c2,0x26c000be,0x2803004c,0x00000000}},	// [aea0] nčke_, roio_, írné_,
  { {0x6aa600b9,0x68390139,0x320607ab,0x00000000}},	//   likf, rúdó, wboy_,
  { {0x389b00b5,0x26c0017d,0xf8c70003,0x00000000}},	//   _זיינ, poio_, éées_,
  { {0x2ca54b57,0x00000000,0x00000000,0x00000000}},	//   hild_,   ,   ,
  { {0xc1e70076,0x2ca500c7,0x752d01f4,0x00000000}},	//   ньше_, kild_, cuaz,
  { {0x7e6b00a4,0x673c00c2,0x18360041,0x00000000}},	//   _angp, otrj, גאַל_,
  { {0xce94005a,0xb5fb0027,0x3ea414a7,0x00000000}},	//   какъ, _snái, timt_,
  { {0x2d840078,0x29195764,0x64800656,0x00000000}},	//   tyme_, yssa_, _töis,
  { {0x2ca50130,0x3d94341e,0xc693009a,0x00000000}},	//   fild_, типр, טאה_,
  { {0x4f963734,0x859b0063,0x61e400c2,0x00000000}},	//   _преу, פשיו, žils,
  { {0x3d100235,0xa3d60161,0xab27000a,0x00000000}},	//   _दौरे_, ाइट_, ноќа_,
  { {0xdbd60019,0xaf490021,0x62810003,0x00000000}},	//   _rääk, _تشكل_, _îlot,
  { {0x291900fe,0x2ca55765,0x66160058,0x00000000}},	//   ussa_, bild_, dayk,
  { {0x672100ea,0xdbd600fe,0x3a20005b,0x00000000}},	//   áljo, _pääk, _edip_,
  { {0x69c00378,0x2bf7009a,0x92100042,0x00000000}},	//   ümer, _אמון_, ाराज_,
  { {0x752d051e,0x7af70331,0x44f60014,0x00000000}},	//   tuaz, _éxta, _bæ_,
  { {0xf4870591,0x659424f7,0x00000000,0x00000000}},	// [aeb0] нужн, гату,   ,
  { {0xa6f5005e,0x3949005f,0x44f60046,0x00000000}},	//   _изош, _ipas_, _dæ_,
  { {0xe787000a,0x00000000,0x00000000,0x00000000}},	//   _чупо,   ,   ,
  { {0x78a7006f,0x44f60026,0x471a009d,0x00000000}},	//   lijv, _fæ_, _קורג,
  { {0x44f62ad6,0x69da0051,0x752d01f4,0x00000000}},	//   _gæ_, ęteg, quaz,
  { {0x20d200dd,0x27ab009a,0x8fa55766,0x00000000}},	//   tâia_, ּסֵּ, кале,
  { {0xb8820080,0xa3d433e3,0x2eb51567,0x00000000}},	//   _říka, _борч, ксис,
  { {0x61fb02ab,0x78a7006f,0x39490072,0x00000000}},	//   _uful, hijv, _opas_,
  { {0x2d8b0114,0x6d3200de,0x00000000,0x00000000}},	//   áce_, لفيض,   ,
  { {0x4c850086,0x2ca5133f,0x22b80605,0x00000000}},	//   тлов, uild_, rčke_,
  { {0x29000290,0x3a200150,0x7bca001f,0x00000000}},	//   _stia_, _pdip_, _cyfu,
  { {0xfeb80032,0xfaa6050f,0x780a0053,0x00000000}},	//   _كانت_, тамо, वर्क_,
  { {0x827600b5,0x6aa60137,0x3f875767,0x00000000}},	//   דערע_, rikf, lynu_,
  { {0x7d1b0019,0x6aa65768,0x2d820072,0x00000000}},	//   msus, sikf, äkee_,
  { {0x7d1b0019,0x7bca001f,0xe7371259,0x00000000}},	//   lsus, _gyfu, кер_,
  { {0x98a20078,0x61ed0130,0xcf92009a,0x00000000}},	//   duką_, žalj, בטל_,
  { {0xa806005a,0x7d1b5769,0x60c30066,0x00000000}},	// [aec0] _изпл, nsus, konm,
  { {0x14c8006a,0x69cb00b9,0x44f6000e,0x00000000}},	//   رهای_, _øgea, _væ_,
  { {0x7d1b0009,0xe2a3008b,0xddc2007d,0x00000000}},	//   hsus, _trừ_, _mnoš,
  { {0x6b7a00b5,0xd36f0754,0x5275018e,0x00000000}},	//   ורענ, تهم_, лучу,
  { {0x60c3102b,0xc434005d,0x98a20078,0x00000000}},	//   fonm, _مکات, auką_,
  { {0x7d1b0ba5,0xa3df0053,0x93460a29,0x00000000}},	//   dsus, देह_, _инге,
  { {0xa067005e,0x2240004b,0x7d1b576a,0x00000000}},	//   таја_, õiks_, esus,
  { {0x645c53f4,0x7d780021,0xc7b30063,0x00000000}},	//   _hari, فمبر_, יבו_,
  { {0x7d1b1eb1,0x645c576b,0x645e0ae9,0x00000000}},	//   gsus, _kari, odpi,
  { {0x645c576c,0x01370063,0x9f98004a,0x00000000}},	//   _jari, _ברמת_, lším_,
  { {0x5fb6016a,0x7d1b1102,0x6280576d,0x00000000}},	//   _अखिल, asus, _komo,
  { {0x2fd7006a,0x6d260088,0x645c26c5,0x00000000}},	//   _شوند_, _аддз, _lari,
  { {0x9d9a0021,0x7c470137,0x6280576e,0x00000000}},	//   _تنشئ_, ärrå, _momo,
  { {0x645c576f,0xcb340062,0xdca32c16,0x00000000}},	//   _nari, _бекъ, _качи,
  { {0x78a70122,0x8e200086,0x9cd70063,0x00000000}},	//   rijv, _вiд_, _שווה_,
  { {0x628000f3,0x645c002c,0x9f98004a,0x00000000}},	//   _nomo, _aari, jším_,
  { {0x645c5770,0x645e006f,0x60c300a4,0x00000000}},	// [aed0] _bari, fdpi, yonm,
  { {0xa8550138,0x645c5771,0x147701a7,0x00000000}},	//   _скоч, _cari, خارج,
  { {0x645c1b18,0x6e225772,0x8bd8009a,0x00000000}},	//   _dari, _odob, תַּח,
  { {0x6e220150,0x62800419,0x7d020072,0x00000000}},	//   _ndob, _como, _otos,
  { {0x7aed000f,0x62340472,0x645c5773,0x00000000}},	//   _miat, речу, _fari,
  { {0x765d00f3,0xc108000d,0x98a20078,0x00000000}},	//   _hasy, тэце_, puką_,
  { {0xa3df0235,0x60c30034,0x628003cc,0x00000000}},	//   देश_, ronm, _fomo,
  { {0x7d1b0004,0xb5fb0025,0x645c5774,0x00000000}},	//   tsus, _gnát, _zari,
  { {0x765d5299,0x5c15014c,0x7bce004d,0x00000000}},	//   _masy, льну, übun,
  { {0xb5fb0080,0x7d1b1f11,0x27ec0066,0x00000000}},	//   _znát, rsus, ždni_,
  { {0x7d1b5775,0x7aed0586,0xf989009a,0x00000000}},	//   ssus, _biat, _צר_,
  { {0x7d1b0019,0x765d340b,0x69c10058,0x00000000}},	//   psus, _nasy, ğlen,
  { {0x7aed227c,0x22b800c2,0x69c10058,0x00000000}},	//   _diat, nčka_, şlen,
  { {0xddc2007d,0x6e2213e4,0x5c070e82,0x00000000}},	//   _unoš, _zdob, _ряда,
  { {0x765d00f3,0x20c90025,0x7aed5776,0x00000000}},	//   _basy, lúis_, _fiat,
  { {0x645c00bb,0xa695005e,0x7aed427c,0x00000000}},	//   _sari, аруј, _giat,
  { {0x9f980080,0x0566014c,0x645c1c45,0x00000000}},	// [aee0] vším_, ыван, _pari,
  { {0x62800942,0x399b0063,0x59aa0042,0x00000000}},	//   _somo, _נייד, _चेयर,
  { {0x883b0063,0x9f980260,0x628045f3,0x00000000}},	//   _אתיו, tším_, _pomo,
  { {0x6d4b50a8,0x645c5777,0x99990078,0x00000000}},	//   _opga, _wari, cesų_,
  { {0x645c23c1,0xa1582469,0xd575007f,0x00000000}},	//   _tari, талу_, _курь,
  { {0x2912001f,0x7e7b001c,0xe8d9008b,0x00000000}},	//   _mwya_, ejup, _trễ_,
  { {0x7d020045,0x6d4b20ae,0x6d590306,0x00000000}},	//   _stos, _apga, _aswa,
  { {0x1ef70021,0x44442f7b,0x62800078,0x00000000}},	//   دعوة_, lf_, _uomo,
  { {0x7aed051e,0x20c90025,0xe297107a,0x00000000}},	//   _riat, gúis_, _сат_,
  { {0x44445778,0x6b9a004d,0x7aed5779,0x00000000}},	//   nf_, tztg, _siat,
  { {0x4444577a,0x656400fe,0x54770047,0x00000000}},	//   if_, hvih, אגיע_,
  { {0xbb930121,0x20c90139,0x6e222b92,0x00000000}},	//   сающ, búis_, _udob,
  { {0x3ea60031,0x984b005a,0xa80201f7,0x00000000}},	//   _imot_, нява_, ğınd,
  { {0x444402b0,0xa80201f7,0x68f6005b,0x00000000}},	//   jf_, şınd, _duyd,
  { {0x765d577b,0x6d404f13,0xc435007e,0x00000000}},	//   _pasy, ltma, یکست,
  { {0x69cb00b9,0x4444577c,0x7bd8007d,0x00000000}},	//   _øgeo, ef_, _izvu,
  { {0x99990006,0xf1a40053,0x4444577d,0x00000000}},	// [aef0] resų_, _खेलन, ff_,
  { {0x78a50026,0xdce2085a,0x6d40158f,0x00000000}},	//   _umhv, _oroč, itma,
  { {0xf3670088,0x36d5000a,0x1cbb0047,0x00000000}},	//   ытан, _вонр, עמבע,
  { {0x6d40577e,0x9f5e00cd,0xf6790047,0x00000000}},	//   ktma, _letó_, _סאָמ,
  { {0xe1f8000d,0x660d3d20,0x6d401329,0x00000000}},	//   угі_, mbak, jtma,
  { {0x660d02fb,0x6d40004d,0xc0c8005e,0x00000000}},	//   lbak, dtma, лује_,
  { {0x6d40577f,0x8fa20121,0x1e950ace,0x00000000}},	//   etma, жаще, ирир,
  { {0x6d4b00d1,0x6d405780,0x752d1a55,0x00000000}},	//   _ppga, ftma, oraz,
  { {0x212b008b,0x6d4000b9,0x7e7b0e78,0x00000000}},	//   _ích_, gtma, rjup,
  { {0x3ea601e3,0x1035007e,0x20c90139,0x00000000}},	//   _emot_, _خبرگ, rúis_,
  { {0xbb4524f8,0x752d0080,0xde95005e,0x00000000}},	//   шенк, hraz, _кажњ,
  { {0xfc3f0080,0x09e60432,0xf2d20047,0x00000000}},	//   ří_, ионн, ַעם_,
  { {0x660d0146,0xa96a0001,0x69cb00b9,0x00000000}},	//   dbak, њига_, _øgel,
  { {0x752d5781,0x7d091d88,0x225f5782,0x00000000}},	//   draz, mpes, _lauk_,
  { {0xe616000a,0x7d095783,0xa7a70062,0x00000000}},	//   ифаќ, lpes, акра_,
  { {0xfb24006a,0x4444001f,0x752d5784,0x00000000}},	//   _اروپ, wf_, fraz,
  { {0x752d051e,0xa3e80053,0x33f6042c,0x00000000}},	// [af00] graz, मेन_, ачес,
  { {0x44440199,0x629900a4,0x76440058,0x00000000}},	//   uf_, ehwo, sfiy,
  { {0x44445785,0x752d5786,0xd4d5000d,0x00000000}},	//   rf_, araz, сітэ,
  { {0xd7bb014e,0x752d027d,0xe2460021,0x00000000}},	//   _יציר, braz, شخصي,
  { {0x28db0161,0x752d0290,0xc05a0086,0x00000000}},	//   _मीडि, craz, вій_,
  { {0xdce20743,0x0115000d,0x394d0058,0x00000000}},	//   _proč, сьцю, çesi_,
  { {0x20c90025,0x4fc6007b,0xd372013a,0x00000000}},	//   túir_, јсла, _ظهر_,
  { {0x2a6000e3,0xdce200c2,0xe8d90013,0x00000000}},	//   _naib_, _vroč, _trệ_,
  { {0x8c3c01f7,0xddc9005b,0xf3f9003b,0x00000000}},	//   liği, rdeş, _şţi_,
  { {0x67210198,0x6d405787,0xf3f10063,0x00000000}},	//   šlji, rtma, ּ֣י_,
  { {0x752d3715,0x6d405788,0xcaa70044,0x00000000}},	//   zraz, stma, لصحي,
  { {0x66fc0080,0x69c1005b,0xa802005b,0x00000000}},	//   _ačko, şlem, şıld,
  { {0xf8bf00ea,0xf3ff008f,0x0e9b089e,0x00000000}},	//   nség_, žģis_, _בשאל,
  { {0x8c43005e,0x8d85007e,0x201c1adc,0x00000000}},	//   _деље, _دشمن, navi_,
  { {0x6298001c,0x23a50053,0x67d5183e,0x00000000}},	//   īvoj, _गेंद, сову,
  { {0x8c3c01f7,0x752d4468,0xf8bf236b,0x00000000}},	//   diği, traz, tués_,
  { {0x95cb1001,0x752d0290,0x95d90002,0x00000000}},	// [af10] тува_, uraz, удат_,
  { {0x201c01b3,0x752d3271,0x8c3c005b,0x00000000}},	//   javi_, rraz, fiği,
  { {0x290b00c3,0x660a00ea,0xa8560063,0x00000000}},	//   lpca_, ímké, _היתה_,
  { {0xf8bf02dd,0x623506b6,0x7d09000e,0x00000000}},	//   pués_, седу, ypes,
  { {0xf8bf5789,0x67350022,0x0165578a,0x00000000}},	//   qués_, luzj, скло,
  { {0x38610199,0xb97c0047,0x84670062,0x00000000}},	//   _jahr_, כנדי, _тъме,
  { {0x33950021,0x6626013d,0x8c3c0075,0x00000000}},	//   _الأز, _átkö, ciği,
  { {0x57b80063,0xdc010053,0xc5f20041,0x00000000}},	//   ילוב_, ोर्ड_, ּדי_,
  { {0x201c0c61,0x2a600150,0xdb180061,0x00000000}},	//   bavi_, _raib_, _vyvý,
  { {0x0dc80138,0x201c0290,0x7d0944b4,0x00000000}},	//   јући_, cavi_, rpes,
  { {0x7d095289,0x1fa7261d,0xa0c40044,0x00000000}},	//   spes, _траг, _بيلو,
  { {0x2cac001f,0xdb1e19bc,0x7d090b40,0x00000000}},	//   aidd_, íván, ppes,
  { {0xddc9017f,0xa49b00cd,0x290d003b,0x00000000}},	//   ljež, _atòm, ţean_,
  { {0xdd8e0021,0xc8b60121,0x3ead578b,0x00000000}},	//   _سوى_, ссмы, liet_,
  { {0x2a6000e3,0xf8bf00ea,0xd62a578c,0x00000000}},	//   _taib_, zség_, лове_,
  { {0x3ead578d,0x201c00c3,0x26d200a4,0x00000000}},	//   niet_, zavi_, ulyo_,
  { {0x98a601d5,0x3cfa0047,0x9426000d,0x00000000}},	// [af20] _гипе, ָלענ, ймае,
  { {0xb97b014e,0x8c3c01f7,0x3ead0717,0x00000000}},	//   _עניי, tiği, hiet_,
  { {0x8c1a0063,0xa2c40053,0x3ead578e,0x00000000}},	//   רועי, िकल्, kiet_,
  { {0x3ead0418,0xf8bf000f,0x8c3c01f7,0x00000000}},	//   jiet_, tség_, riği,
  { {0x3ead578f,0x64430268,0x7243007e,0x00000000}},	//   diet_, ònic, سپول,
  { {0x04960021,0x3ead001c,0xf8bf00ea,0x00000000}},	//   _السح, eiet_, rség_,
  { {0xf8bf000f,0x3ead0f4e,0x2cac0137,0x00000000}},	//   sség_, fiet_, vidd_,
  { {0x25ad027c,0x93b70063,0x877b0047,0x00000000}},	//   _želi_, _הללו_, טאצי,
  { {0x1ee9007e,0xe049007e,0x25a03048,0x00000000}},	//   جويی_, _چشمه_, nzil_,
  { {0x3ead2f91,0x7f1a012c,0x00000000,0x00000000}},	//   aiet_, _біду_,   ,
  { {0xf8bf0164,0x3ead5790,0x2e4a0062,0x00000000}},	//   nsée_, biet_, _бяло_,
  { {0x3ead5791,0x7a04000d,0xf8bf0003,0x00000000}},	//   ciet_, зярж, isée_,
  { {0x6ce60054,0xa3e80042,0xe10b009a,0x00000000}},	//   _ліке, मेत_, ְּךָ,
  { {0x98ab000c,0x321d0051,0x25a05792,0x00000000}},	//   ducă_, zawy_, dzil_,
  { {0x48a80071,0x8c1b009a,0xc6d700de,0x00000000}},	//   стям_, _גווי, مترت,
  { {0x386100bd,0x9f4d0003,0x15150330,0x00000000}},	//   _wahr_, înée_, ждая,
  { {0x941905fb,0x44f4254f,0x84e90044,0x00000000}},	// [af30] ижат_, зпус, لفرق_,
  { {0x3ead003d,0x7c3a5793,0x7e62004b,0x00000000}},	//   ziet_, ngtr, _laop,
  { {0x321d0051,0xd3710593,0x798f002b,0x00000000}},	//   tawy_, بها_, lycw,
  { {0xddc9017f,0x672100ea,0x7e62027d,0x00000000}},	//   vjež, álju, _naop,
  { {0x3ead480e,0x321d0051,0x2bcf24fa,0x00000000}},	//   viet_, rawy_, _सुना,
  { {0xa0695794,0xd006019c,0xb938009a,0x00000000}},	//   рака_, оеше_, מנדו_,
  { {0x3ead003d,0x03090063,0x7a44013d,0x00000000}},	//   tiet_, _כִּֽ, nító,
  { {0xd109014d,0x2f540054,0x6457093c,0x00000000}},	//   _نقره_, ятіс, lexi,
  { {0x8d550086,0x3ead5795,0x361c0063,0x00000000}},	//   ітич, riet_, אוחד,
  { {0x3ead003d,0x64575796,0x4b25046a,0x00000000}},	//   siet_, nexi, омов,
  { {0xfbd10021,0x29090072,0x3f67007d,0x00000000}},	//   بتة_, _ataa_, _uđu_,
  { {0xe8d9008d,0x39ea0fc7,0x28d20042,0x00000000}},	//   _trớ_, идно_, _दीजि,
  { {0x2d820031,0x6abd006d,0x672500a5,0x00000000}},	//   øket_, érfa, _avhj,
  { {0xfc460080,0xf8bf5797,0xd70a05f4,0x00000000}},	//   čích_, ysée_, инге_,
  { {0x37871137,0x64575798,0x37750121,0x00000000}},	//   обро_, dexi, пытс,
  { {0x6e3b053b,0x64570061,0x6f7a016e,0x00000000}},	//   ngub, eexi, בְמו,
  { {0x34aa0001,0xb4aa231c,0x3486014b,0x00000000}},	// [af40] авао_, аказ_, огаг,
  { {0x14260086,0xe3b20593,0x443a005f,0x00000000}},	//   ідем, ورا_, ugp_,
  { {0xe1fa1321,0xf8bf0003,0xc20a04a0,0x00000000}},	//   аге_, usée_, لقان_,
  { {0x316d0198,0x366a0001,0xf8bf0164,0x00000000}},	//   _brez_, _тамо_, rsée_,
  { {0xf8bf0164,0x60ca0104,0x51830121,0x00000000}},	//   ssée_, tofm, дуща,
  { {0x2bcf0235,0x7e62017f,0xa87a0047,0x00000000}},	//   _सुभा, _saop, שאַר,
  { {0x66040066,0x9f03005d,0xaaca0082,0x00000000}},	//   ocik, وووو, रवाक,
  { {0x752409f5,0x66045799,0x01da00de,0x00000000}},	//   osiz, ncik, _نوزع_,
  { {0x7524579a,0x60260062,0xdcba0062,0x00000000}},	//   nsiz, _мдаа, ищо_,
  { {0x628200fe,0x75240290,0x69cb01e1,0x00000000}},	//   ljoo, isiz, _øgei,
  { {0x0eba000d,0x29092bcc,0x93fb089e,0x00000000}},	//   _куды_, _staa_, יליי,
  { {0x2d8200d1,0x442a579b,0x7524579c,0x00000000}},	//   økes_, _ldb_, ksiz,
  { {0x6ef50006,0x644e0290,0xfee90021,0x00000000}},	//   _išba, _obbi, _اعلى_,
  { {0x6e20579d,0xd7f801d5,0x7a44013d,0x00000000}},	//   lamb, жут_, tító,
  { {0xddd9056c,0x58d43a82,0x5c37009a,0x00000000}},	//   _gawł, форт, _וטוב_,
  { {0x6e2006a7,0x644e3b6f,0xa5f802a1,0x00000000}},	//   namb, _abbi, жету_,
  { {0x5507005a,0x7a4400ea,0x6e200035,0x00000000}},	// [af50] ючва, sító, iamb,
  { {0xd5b801dd,0x6e3b02f7,0x6e20579e,0x00000000}},	//   іст_, zgub, hamb,
  { {0xd37b000d,0x32550b3f,0xd4980095,0x00000000}},	//   шча_, звер, црт_,
  { {0x442a01e1,0x6e20579f,0x52740002,0x00000000}},	//   _edb_, jamb, душу,
  { {0x661d001c,0xc6170053,0x6e200d28,0x00000000}},	//   _iesk, तरीय_, damb,
  { {0x80a80086,0xa5bb0025,0x6282004b,0x00000000}},	//   овів_, _ndói, ajoo,
  { {0x44210c96,0x661d037e,0x6aad004b,0x00000000}},	//   mah_, _kesk, _omaf,
  { {0x442109e8,0x6e2057a0,0xa5bb013d,0x00000000}},	//   lah_, gamb, _adói,
  { {0x2d8b03b2,0x661d014f,0x7d09005e,0x00000000}},	//   âce_, _mesk, љног_,
  { {0xd0110021,0x44213414,0x1c450156,0x00000000}},	//   _ألا_, nah_, чном,
  { {0x2d820031,0x6e2057a1,0x0bb50062,0x00000000}},	//   øker_, bamb, ящия,
  { {0x6e2057a2,0x44213bcc,0x661d57a3,0x00000000}},	//   camb, hah_, _nesk,
  { {0x44210397,0xed580086,0x0dcb0699,0x00000000}},	//   kah_, _мої_, _тужи_,
  { {0x20cb0161,0xf8bf1e06,0x629b001f,0x00000000}},	//   िविध, drés_, _lluo,
  { {0x442157a4,0x661d0386,0x66e61379,0x00000000}},	//   dah_, _besk, зова,
  { {0xe7370459,0x7524005b,0x661d0130,0x00000000}},	//   џет_, tsiz, _cesk,
  { {0x442a541c,0xf8bf0bbd,0x44214628,0x00000000}},	// [af60] _pdb_, grés_, fah_,
  { {0x661d0019,0x442157a5,0x752457a6,0x00000000}},	//   _eesk, gah_, rsiz,
  { {0x7ae41770,0x7794007e,0x6e201d4c,0x00000000}},	//   _khit, _غیرا, yamb,
  { {0x661d021f,0xdcb1008b,0x254e008f,0x00000000}},	//   _gesk, hỉ_, tēlā_,
  { {0x44210397,0xf8bf0003,0x22b8085a,0x00000000}},	//   bah_, crés_, nčki_,
  { {0x6e200035,0x644e0290,0x442157a7,0x00000000}},	//   wamb, _ubbi, cah_,
  { {0x7c21000f,0x7ae400fe,0x6e2003d7,0x00000000}},	//   dalr, _ohit, tamb,
  { {0x3da6019d,0x2bcf0053,0xb3bb0063,0x00000000}},	//   зроб, _सुधा, _המלכ,
  { {0x6e2057a8,0xa3e80042,0x2904004c,0x00000000}},	//   ramb, मेर_, ímal_,
  { {0xc19b0063,0x6e201f05,0x7ae400a5,0x00000000}},	//   _השמי, samb, _ahit,
  { {0x6e200035,0xda3506c9,0xba190044,0x00000000}},	//   pamb, мены, ييدا_,
  { {0x442157a9,0x7ae415e5,0x201e3928,0x00000000}},	//   zah_, _chit, _heti_,
  { {0x44210e53,0x661d5653,0x9b43005d,0x00000000}},	//   yah_, _resk, ونیو,
  { {0x7ae40004,0x661d0080,0xf8bf0003,0x00000000}},	//   _ehit, _sesk, vrés_,
  { {0x442157aa,0x201e007d,0x36d50141,0x00000000}},	//   vah_, _meti_, довр,
  { {0x44210397,0x3bbb0063,0x201e08ea,0x00000000}},	//   wah_, _למוד, _leti_,
  { {0x442157a5,0xcebf004c,0xf8bf006c,0x00000000}},	// [af70] tah_, ířil_, urés_,
  { {0xd37b005a,0xf8bf2986,0x661d3d7e,0x00000000}},	//   йче_, rrés_, _wesk,
  { {0x44211d09,0xd6d10032,0xa3e80161,0x00000000}},	//   rah_, _لقد_, मेल_,
  { {0x6abd0031,0xf8bf0268,0xb184027d,0x00000000}},	//   nnsf, prés_, _šťas,
  { {0xf1940086,0x44213414,0x656f2494,0x00000000}},	//   ниць, pah_, _urch,
  { {0x44210089,0x201e2030,0x69cb01e1,0x00000000}},	//   qah_, _ceti_, _øgeu,
  { {0x201e0024,0x7c210034,0xcee90121,0x00000000}},	//   _deti_, valr, одке_,
  { {0xee390699,0x629b004e,0x2d950481,0x00000000}},	//   цни_, _uluo, дрос,
  { {0x4c350088,0x6298001c,0x7c2157ab,0x00000000}},	//   мэнт, īvot, talr,
  { {0x201e0026,0x7ae43183,0x51f40044,0x00000000}},	//   _geti_, _shit, _أسفر,
  { {0x7fb9007e,0x656d004b,0x60c40139,0x00000000}},	//   _بهار_, hvah, éime,
  { {0x201e0089,0xf8c60082,0x00000000,0x00000000}},	//   _zeti_, लक्प,   ,
  { {0x7c2903ec,0x8c4524a6,0xa3b40042,0x00000000}},	//   _долг_, _желе, _जेन_,
  { {0x7ae4212e,0x9c840066,0x17fa0021,0x00000000}},	//   _whit, točň, ترحة_,
  { {0x6d4957ac,0x7ae400e5,0x7e69004c,0x00000000}},	//   ltea, _thit, odep,
  { {0xe8d9001b,0x7e6957ad,0x6d4938ec,0x00000000}},	//   _trở_, ndep, otea,
  { {0x75d30032,0x7d7a0047,0x448a005e,0x00000000}},	// [af80] نيفا, ֿרעג, обан_,
  { {0xb4d80161,0x6d490025,0xb9370047,0x00000000}},	//   ाते_, itea, _קריג_,
  { {0xa3e80053,0x69c1005b,0x201e57ae,0x00000000}},	//   में_, şlet, _reti_,
  { {0x7e690261,0x201e57af,0x673c0605,0x00000000}},	//   jdep, _seti_, murj,
  { {0xba4800eb,0x66290080,0x201e46a6,0x00000000}},	//   _grįž, řský, _peti_,
  { {0x6d490025,0xcf9a007b,0x61fb57b0,0x00000000}},	//   dtea, жји_, _egul,
  { {0x9f980071,0xe29a0156,0x201e57b1,0x00000000}},	//   явку_, _дав_, _veti_,
  { {0x60c100b9,0x6298008f,0xb5fb004c,0x00000000}},	//   _ejlm, īvos, _snáz,
  { {0x8146007e,0x63ae0078,0x6d493d5a,0x00000000}},	//   _زنان, žinė, gtea,
  { {0xe57100b5,0x2bcf0042,0xecba00de,0x00000000}},	//   אַט_, _सुहा, تطعت_,
  { {0x764d01f7,0xaab5000d,0xd4370047,0x00000000}},	//   yfay, ейні, וריק_,
  { {0xbb930076,0x6d4936f5,0x2aab0054,0x00000000}},	//   тающ, btea, ітно_,
  { {0x6d4957b2,0xdd9201f3,0x0217009a,0x00000000}},	//   ctea, _جوش_, וחכם_,
  { {0x290000cd,0xddc20022,0x48e4000d,0x00000000}},	//   _duia_, _mnoż, коўв,
  { {0x644300cd,0xd68b0062,0xf1b9007d,0x00000000}},	//   ònim, ощад_, _meša_,
  { {0xfaa800de,0x00000000,0x00000000,0x00000000}},	//   _يهوي_,   ,   ,
  { {0x29000bc8,0x95390062,0x9c7c0a80,0x00000000}},	// [af90] _guia_, язат_, emči,
  { {0xf1b916fe,0x2a6957b3,0x656d57b4,0x00000000}},	//   _neša_, _haab_, rvah,
  { {0x656d0004,0x29000035,0x7e6900d1,0x00000000}},	//   svah, _zuia_, ydep,
  { {0x6d4919bd,0x72050043,0x3619009d,0x00000000}},	//   ytea, روتم, _מוֹד,
  { {0x7e690024,0x78b500c3,0xd00909c8,0x00000000}},	//   vdep, oizv, пеле_,
  { {0x78b5008f,0xfc4e008d,0x3f69076a,0x00000000}},	//   nizv, _sửng_, зико_,
  { {0xff51007e,0xcef50002,0xa3f4012c,0x00000000}},	//   اخت_, нчињ, _апрі,
  { {0x4d650001,0x6d4957b5,0xc7f80063,0x00000000}},	//   екив, ttea, וזות_,
  { {0x7e6957b6,0x6d4957b7,0x2d9923e7,0x00000000}},	//   rdep, utea, áse_,
  { {0x6d4957b8,0x7e690e6d,0xe044005e,0x00000000}},	//   rtea, sdep, _инђи,
  { {0x6d49121f,0xde35000d,0x7a6a0320,0x00000000}},	//   stea, _зэль, пинг_,
  { {0x6d490f9d,0xfd4c008d,0x78b50249,0x00000000}},	//   ptea, nmiề, eizv,
  { {0xac950183,0x2bcf0042,0xbd450044,0x00000000}},	//   _падш, _सुरा, _أنتي,
  { {0x6f0103e8,0xdce900c2,0x3ebf12a9,0x00000000}},	//   _kulc, oveč, lnut_,
  { {0xac74007e,0x7bd80078,0x75ea013d,0x00000000}},	//   _جانش, _gyvu, közé,
  { {0x3ebf57b9,0xdce2007d,0xf65f01e1,0x00000000}},	//   nnut_, _proć, _skær_,
  { {0x69c101f7,0x75d60021,0x3ebf57ba,0x00000000}},	// [afa0] şler, ريطا, inut_,
  { {0x62990122,0x03a60175,0x05770021,0x00000000}},	//   ekwo, низо, عملة_,
  { {0xdce90198,0x69cb00b9,0x083b0047,0x00000000}},	//   jveč, _øger, _צעטל,
  { {0x41e6000d,0xe29a0141,0x599a0063,0x00000000}},	//   ніла, џад_, ּשַׁ,
  { {0x26d22d99,0x3ebf10f5,0x6f01006c,0x00000000}},	//   moyo_, dnut_, _aulc,
  { {0x3ebf00ac,0x26c00078,0x232a0200,0x00000000}},	//   enut_, lnio_, _ноги_,
  { {0x82a60086,0x6f01003b,0x645e57bb,0x00000000}},	//   _завж, _culc, mepi,
  { {0x26c00290,0x3ebf007d,0x6f0157bc,0x00000000}},	//   nnio_, gnut_, _dulc,
  { {0x8ffa014d,0x26c057bd,0xfd0f005d,0x00000000}},	//   _فرار_, inio_, یجی_,
  { {0x2a690004,0xc5f300b5,0x645e57be,0x00000000}},	//   _saab_, נדז_, nepi,
  { {0x645e16cd,0xdb1c0058,0x34b7089e,0x00000000}},	//   iepi, _özür, תפים_,
  { {0x6ee557bf,0x3af40085,0x645e33d6,0x00000000}},	//   tóbe, ляўс, hepi,
  { {0x26c00045,0x645e57c0,0x78b5008f,0x00000000}},	//   dnio_, kepi, tizv,
  { {0x645e3692,0x26c057c1,0x3b540121,0x00000000}},	//   jepi, enio_, _аккр,
  { {0x78b5013d,0x67d54dae,0x645e57c2,0x00000000}},	//   rizv, тову, depi,
  { {0x7bdb01f9,0x57f4195a,0x645e57c3,0x00000000}},	//   _מקוו, упст, eepi,
  { {0x7d0200eb,0xa8020058,0x35f503e5,0x00000000}},	// [afb0] _juos, ğırd, тпар,
  { {0x64a40138,0xe7870086,0xb5d4005e,0x00000000}},	//   гађа, _зумо, ужуј,
  { {0x7d1d013d,0x7d020527,0x75ea013d,0x00000000}},	//   ássz, _luos, tözé,
  { {0x46a50053,0x21f50021,0x6e22378f,0x00000000}},	//   _ऐतिह, نكاس, _neob,
  { {0x7d0200eb,0x50450002,0x629957c4,0x00000000}},	//   _nuos, велб, rkwo,
  { {0x6f0157c5,0x645e57c6,0xdceb008f,0x00000000}},	//   _pulc, cepi, _orgā,
  { {0x6e2200bd,0xb2ab005a,0xdd260078,0x00000000}},	//   _beob, _етаж_, _rūšy,
  { {0x442357c7,0x443157c8,0x6f013ee1,0x00000000}},	//   _hej_, _hdz_, _vulc,
  { {0xc05b0086,0xdce900c3,0x6ee500ea,0x00000000}},	//   _ніж_, sveč, tóbb,
  { {0x44230c04,0xeb990c45,0x1fa73e30,0x00000000}},	//   _jej_, дио_, _прег,
  { {0x26c04467,0xfaa63f36,0x3ebf01d1,0x00000000}},	//   ynio_, вано, pnut_,
  { {0xeb960076,0x645e0051,0xe6bd0053,0x00000000}},	//   тию_, zepi, ्कोज,
  { {0x6455074f,0xc9630062,0xbd280044,0x00000000}},	//   _obzi, авяй, _كأول_,
  { {0x442357c9,0x26c0002b,0x25a90066,0x00000000}},	//   _nej_, wnio_, dzal_,
  { {0x26c00051,0x26d20150,0x7c3c00cd,0x00000000}},	//   tnio_, toyo_, órre,
  { {0x64550a67,0x7c2357ca,0xf74301ce,0x00000000}},	//   _abzi, _henr, јето,
  { {0x7e6b00bb,0xa4460001,0xf503005a,0x00000000}},	// [afc0] _magp, кнад, изто,
  { {0x7e6b4d97,0x26c000fc,0x97da0021,0x00000000}},	//   _lagp, snio_, _يبدأ_,
  { {0xc7a6019d,0xb8f6016a,0x7c230150,0x00000000}},	//   _ринк, िक_, _menr,
  { {0x7e6b00bb,0x6d590983,0x9982004c,0x00000000}},	//   _nagp, _opwa, naků_,
  { {0x6e2201a8,0x4423013d,0x40340320,0x00000000}},	//   _reob, _fej_, гелс,
  { {0x212d00c3,0x7644005b,0x6e22007d,0x00000000}},	//   _dveh_, lgiy, _seob,
  { {0x7d02024a,0xb17d0024,0x444400a4,0x00000000}},	//   _suos, _vzťa, mg_,
  { {0x444457cb,0x76440949,0x7d02146c,0x00000000}},	//   lg_, ngiy, _puos,
  { {0xade3019d,0x444457cc,0x7e6b188f,0x00000000}},	//   ицьк, og_, _dagp,
  { {0x7d0200fe,0x444457cd,0x5c731dc6,0x00000000}},	//   _vuos, ng_, альт,
  { {0xeb97000a,0xdeef57ce,0x444457cf,0x00000000}},	//   виќ_, _вы_, ig_,
  { {0x7d0248fe,0x00000000,0x00000000,0x00000000}},	//   _tuos,   ,   ,
  { {0xf2d300b5,0x7c2357d0,0x984b0094,0x00000000}},	//   שער_, _fenr, мява_,
  { {0x444457d1,0x8bb60021,0x7c233ebe,0x00000000}},	//   jg_, _لإعا, _genr,
  { {0x7c28051e,0x87041087,0x48a80086,0x00000000}},	//   madr, ияте, ттям_,
  { {0x7c282876,0x7e6057d2,0x442349e0,0x00000000}},	//   ladr, nemp, _sej_,
  { {0x7e6057d3,0x6d403aaa,0x545512b9,0x00000000}},	// [afd0] iemp, numa, лват,
  { {0x4444334a,0x7c2857d4,0x7e6057d5,0x00000000}},	//   gg_, nadr, hemp,
  { {0x442357d6,0xd7950062,0xdce90066,0x00000000}},	//   _vej_, _синъ, zveď,
  { {0x444457d7,0x7e6057d8,0x32d4000d,0x00000000}},	//   ag_, jemp, аціс,
  { {0x6d40003d,0xdd8604f6,0x442357d9,0x00000000}},	//   juma, _او_, _tej_,
  { {0x7c280024,0xc0c80001,0x6d400e39,0x00000000}},	//   jadr, кује_, duma,
  { {0x7e6b0273,0xa3e70053,0x7c2857da,0x00000000}},	//   _pagp, _परि_, dadr,
  { {0x6d4057db,0x9294000d,0x660d2e25,0x00000000}},	//   fuma, _касц, ncak,
  { {0x752d051e,0x6d4057dc,0x7c2357dd,0x00000000}},	//   nsaz, guma, _penr,
  { {0x64450397,0x4c850cbb,0x98a0007d,0x00000000}},	//   nghi, улов, _ivić_,
  { {0x6d40002c,0x2d820d88,0x64450025,0x00000000}},	//   auma, äker_, ighi,
  { {0xc86901f9,0x38a600ac,0xc9aa0002,0x00000000}},	//   _מן_, _môre_, евме_,
  { {0x7c282923,0x6d5900e5,0x6d4057de,0x00000000}},	//   badr, _upwa, cuma,
  { {0x91ba014e,0x7c2857df,0xf7461567,0x00000000}},	//   תמשי, cadr, лего,
  { {0xc795000d,0x60c300d1,0xb8dc0053,0x00000000}},	//   арты, innm, _आग_,
  { {0x6b9c0d02,0x07a30054,0x6445013d,0x00000000}},	//   ørge, щасн, eghi,
  { {0x6aa40035,0x343a0021,0x7644107b,0x00000000}},	// [afe0] _ilif, فساد_, rgiy,
  { {0x74160021,0x444457e0,0x644501f4,0x00000000}},	//   اوضا, ug_, gghi,
  { {0xd62a005a,0x6d40000c,0x6aa457e1,0x00000000}},	//   _поне_, zuma, _klif,
  { {0x4444001f,0x7e6057e2,0x644557e3,0x00000000}},	//   sg_, xemp, aghi,
  { {0x39420019,0x444457e4,0x7e601e3d,0x00000000}},	//   nuks_, pg_, vemp,
  { {0x6aa4001f,0xc9530063,0x6d4057e5,0x00000000}},	//   _llif, צמו_, vuma,
  { {0x6aa40104,0x3942004b,0x7c2857e6,0x00000000}},	//   _olif, huks_, vadr,
  { {0x39420004,0x1d342ab5,0xed8a0472,0x00000000}},	//   kuks_, ания, есок_,
  { {0x6280141a,0x7e6057e7,0x91e30086,0x00000000}},	//   _inmo, remp, _готе,
  { {0x7e6057e8,0x6d4053f4,0xfc460080,0x00000000}},	//   semp, ruma, _číst_,
  { {0x6aa40838,0x7c2828f9,0xf8bf013d,0x00000000}},	//   _blif, radr, ssék_,
  { {0x22462fb3,0x6aa402c9,0x7c2857e9,0x00000000}},	//   ngok_, _clif, sadr,
  { {0x7c2857ea,0x3942004b,0x7e7b0041,0x00000000}},	//   padr, guks_, _ראדז,
  { {0x2a6d0080,0x6aa444d6,0xd71b0044,0x00000000}},	//   žeb_, _elif, فترض_,
  { {0xa3b40053,0x628057eb,0xe78417f2,0x00000000}},	//   _जेल_, _onmo, буто,
  { {0x7d0d0025,0x6aa41ff0,0xddc2007d,0x00000000}},	//   _éasc, _glif, _zaoš,
  { {0x660d0397,0x7aed00a4,0xa5bb1358,0x00000000}},	// [aff0] rcak, _ihat, _geól,
  { {0x6280010a,0x752d051e,0x95d80076,0x00000000}},	//   _anmo, rsaz, удут_,
  { {0x752d0290,0x04c80021,0x7aed0b21,0x00000000}},	//   ssaz, دولي_, _khat,
  { {0x27fc004c,0xe2980054,0x979a009d,0x00000000}},	//   ůzné_, лає_, _ישתק,
  { {0x7aed002b,0x1af80041,0x21692b31,0x00000000}},	//   _mhat, אמאל_, тили_,
  { {0x10a2005e,0xf4872049,0x291900dd,0x00000000}},	//   жишн, _сумн, ipsa_,
  { {0xafe50054,0x2898009a,0x4394578a,0x00000000}},	//   шокл, רדון_, _ларс,
  { {0x8d550b3f,0xed590cbb,0x98a20022,0x00000000}},	//   аточ, вои_, mską_,
  { {0x31580021,0xc0470021,0x98a20051,0x00000000}},	//   _مجلة_, _مخاو, lską_,
  { {0x8b07004c,0x929d0022,0xbebc008f,0x00000000}},	//   _neří, _biłg, _svīt,
  { {0x6a86071a,0x9bd4000d,0x4c820054,0x00000000}},	//   ална, йцюш, ілюв,
  { {0x39420004,0x7f43051e,0x7aed57ec,0x00000000}},	//   tuks_, munq, _chat,
  { {0x7f43051e,0x7aed0139,0x00000000,0x00000000}},	//   lunq, _dhat,   ,
  { {0x8f000086,0x8c420065,0x98b9008f,0x00000000}},	//   цiї_, _деше, tusā_,
  { {0x39420019,0x4cba0063,0x1cba0063,0x00000000}},	//   suks_, _במסג, _במסע,
  { {0x39420019,0xa5bb0e7c,0xa695005e,0x00000000}},	//   puks_, _teól, бруј,

  { {0x94260076,0xe9df006d,0xa5070062,0x00000000}},	// [b000] имае, lgún_, иета_,
  { {0xd70a0121,0x6ef50078,0xc4831501,0x00000000}},	//   _иное_, _išbu, олук,
  { {0xe9df02dd,0xa3d30053,0x122a0121,0x00000000}},	//   ngún_, _हुआ_, воей_,
  { {0x5b560047,0x00000000,0x00000000,0x00000000}},	//   ישען_,   ,   ,
  { {0x7cef00b9,0x61e90051,0xe2970141,0x00000000}},	//   mørf, _czel, јач_,
  { {0x61e9001c,0xd0d70054,0x64a657ed,0x00000000}},	//   _dzel, адії_, _тага,
  { {0x8fa30001,0x61e957ee,0x1ee9005d,0x00000000}},	//   жаје, _ezel, گويی_,
  { {0x73f90041,0x628057ef,0x78bc0050,0x00000000}},	//   _תּשו, _unmo, hirv,
  { {0xe9df02dd,0x7aed002b,0xe2970caa,0x00000000}},	//   egún_, _rhat, _тат_,
  { {0x7aed57f0,0xd00f00de,0x00000000,0x00000000}},	//   _shat, _يلق_,   ,
  { {0xb47900b5,0x9e660619,0xe47900b5,0x00000000}},	//   אָרי, _введ, אָרש,
  { {0xd90f007e,0x7d7a0044,0x0efa043e,0x00000000}},	//   ویب_, _لمصر_, _شعاع_,
  { {0xa3d30053,0x3f9c0066,0x1e57009a,0x00000000}},	//   _हुई_, lyvu_, _כשאר_,
  { {0x7aed0034,0x98b9000c,0xdb0100ea,0x00000000}},	//   _what, dusă_, szlá,
  { {0x787c00c7,0xd8c8000d,0x29040014,0x00000000}},	//   _såvä, рыяд_, ímar_,
  { {0xdddb003b,0x6370013d,0x386301e1,0x00000000}},	//   nduş, zóná, sejr_,
  { {0x98a20051,0x38c9005d,0x04c900f2,0x00000000}},	// [b010] wską_, _مادی_, هوري_,
  { {0x6abd007a,0x442757f1,0xe5c40454,0x00000000}},	//   lisf, ún_, істо,
  { {0x61e914e0,0x3ea60059,0xd371009e,0x00000000}},	//   _szel, _olot_, ثها_,
  { {0xddc9000c,0x7f430290,0xd378000d,0x00000000}},	//   ndeţ, vunq, шчу_,
  { {0xe1670001,0x61e0002b,0x2725002b,0x00000000}},	//   рђен, _cyml, lŷn_,
  { {0x41744d95,0xe0d80086,0x61e900c3,0x00000000}},	//   غانس, аві_, _vzel,
  { {0x3ea60146,0xf83800ff,0x290100a8,0x00000000}},	//   _blot_, בנות_, _miha_,
  { {0xa3d30053,0x29010019,0x6ee50051,0x00000000}},	//   _हुए_, _liha_, róbo,
  { {0xf2d200b5,0x6abd0290,0x61e94245,0x00000000}},	//   _זען_, disf, _uzel,
  { {0xddc9003b,0x8d54000d,0x29011fba,0x00000000}},	//   edeţ, ітыч, _niha_,
  { {0x1a2a0002,0x60da0047,0x3ea657f2,0x00000000}},	//   лжни_, _עקענ, _flot_,
  { {0xe8b20042,0x6abd0046,0xdb06013d,0x00000000}},	//   ुच्च, gisf, émáh,
  { {0x78bc0046,0xceb2009a,0xee78005d,0x00000000}},	//   tirv, _ציד_, _خصلت_,
  { {0x6abd0026,0x3ea657f3,0xdc350041,0x00000000}},	//   érfr, _zlot_, _האַט_,
  { {0x31ae00ea,0xc7a306da,0x290100a8,0x00000000}},	//   _közé_, пирк, _diha_,
  { {0x59860086,0xf743018e,0x316d006c,0x00000000}},	//   _глиб, џето, _osez_,
  { {0xf5ea0121,0xe45a0094,0xe57a014b,0x00000000}},	// [b020] умал_, лжа_, ыза_,
  { {0x98b9003b,0xc5d5000d,0x38a600be,0x00000000}},	//   rusă_, цісь, _fôra_,
  { {0x28970063,0x3775000d,0x61e0002b,0x00000000}},	//   _הדין_, _дыяс, _syml,
  { {0x200502f6,0x98b9000c,0x63ae007d,0x00000000}},	//   _agli_, pusă_, _đinđ,
  { {0xfc450066,0xc05a01dd,0xb1130021,0x00000000}},	//   _číne_, гій_, كونغ,
  { {0x987a0047,0x3ea657f4,0x94074fb2,0x00000000}},	//   ראַט, _slot_, _герб_,
  { {0x645c123a,0x3ea657f5,0x443802f7,0x00000000}},	//   _ibri, _plot_, _idr_,
  { {0x2005051e,0x442a57f6,0x6abd0717,0x00000000}},	//   _egli_, _heb_, xisf,
  { {0x7c3c006d,0x3ea600ca,0x3a2900e5,0x00000000}},	//   órro, _vlot_, _reap_,
  { {0x442a001c,0xdce2007d,0xd12f0044,0x00000000}},	//   _jeb_, _prođ, _أمل_,
  { {0x645c0025,0xef1a0afc,0x799d002b,0x00000000}},	//   _mbri, _сме_, wysw,
  { {0xe8d9008b,0xe9f90086,0xddc9003b,0x00000000}},	//   _trừ_, инні_, udeţ,
  { {0x645c57f7,0xddc9003b,0x5887066e,0x00000000}},	//   _obri, rdeţ, быва,
  { {0xac182956,0x6da30001,0x60c40025,0x00000000}},	//   _току_, _хиља, éimh,
  { {0xe784005e,0x4993007e,0x6ef50078,0x00000000}},	//   путо, زیگر, _išbr,
  { {0x645c57f8,0x59da0053,0x6d4043a2,0x00000000}},	//   _abri, _युवर, orma,
  { {0xe6940076,0xd4b90856,0x6f021459,0x00000000}},	// [b030] читы, алац_, _mioc,
  { {0x7c2a1c1e,0x69da003b,0x6d4057f9,0x00000000}},	//   _jefr, ştec, irma,
  { {0x442a57fa,0x644300cd,0x6d404ae6,0x00000000}},	//   _deb_, òniq, hrma,
  { {0x7cef0146,0x645c001f,0x7d1b0cb6,0x00000000}},	//   pørg, _ebri, ypus,
  { {0xd13b0121,0x7cef05a5,0x442a0b02,0x00000000}},	//   ухе_, løre, _feb_,
  { {0xb6080a63,0x656f1daa,0xf8bf57fb,0x00000000}},	//   _vyšš, _isch, msés_,
  { {0x6f0257fc,0x6d4003a9,0x7cef05e7,0x00000000}},	//   _bioc, erma, nøre,
  { {0x645c05c9,0xf99f0268,0x44210025,0x00000000}},	//   _zbri, ncès_, lbh_,
  { {0x44210027,0xa5bb00ea,0x7d090001,0x00000000}},	//   obh_, _adóz, јног_,
  { {0x3c650076,0xf8bf0003,0x44210139,0x00000000}},	//   цког, isés_, nbh_,
  { {0x7cef0031,0xda6657fd,0x44210025,0x00000000}},	//   jøre, овни, ibh_,
  { {0xc332014e,0x6f0202f6,0x4fd600b5,0x00000000}},	//   ווט_, _gioc, _וועב_,
  { {0xdce90117,0x3ead0a2e,0x38c8007e,0x00000000}},	//   jveć, mhet_, ماسی_,
  { {0x7cef02ab,0x7c2a050c,0x25dd0042,0x00000000}},	//   føre, _gefr, _खड़ी_,
  { {0x7cef0146,0x7d0b0026,0xfcf80047,0x00000000}},	//   gøre, _hugs, _פּױל,
  { {0x44380150,0x3ead57fe,0x442a0526,0x00000000}},	//   _sdr_, nhet_, _seb_,
  { {0x6e2b00ea,0x442a00a4,0x7d040139,0x00000000}},	// [b040] _megb, _peb_, _éist,
  { {0x7d030009,0x27ed0080,0x98b90006,0x00000000}},	//   _jins, řena_, tusą_,
  { {0x3ead02f0,0x7d0b00ac,0x656f144b,0x00000000}},	//   khet_, _lugs, _esch,
  { {0x442a57ff,0xf99f0164,0x4b4c00b5,0x00000000}},	//   _web_, ccès_, רגאַ,
  { {0x64430297,0x6f020139,0x442a057c,0x00000000}},	//   ónic, _rioc, _teb_,
  { {0x3ead00ea,0x645c5800,0x6f025801,0x00000000}},	//   ehet_, _ubri, _sioc,
  { {0x7d0b003d,0x6f02177f,0x7c2a3b3b,0x00000000}},	//   _augs, _pioc, _refr,
  { {0x7d0303b2,0x3ead2330,0x63a302ab,0x00000000}},	//   _ains, ghet_, ønne,
  { {0x6fda0235,0x9df7005a,0x6e39001f,0x00000000}},	//   _पुरू, онът_, _ddwb,
  { {0x26c9017f,0x7d03513a,0xdc3c0066,0x00000000}},	//   znao_, _cins, páči,
  { {0xf4130063,0x5c31007e,0xe0430086,0x00000000}},	//   ופת_, رکوز, _інци,
  { {0x7d034954,0x6d400da5,0xddc90078,0x00000000}},	//   _eins, prma, sdeš,
  { {0xed570085,0x7d035802,0x59c50044,0x00000000}},	//   _моц_, _fins, سيسك,
  { {0x7cef02ab,0x7d035803,0xf77301fb,0x00000000}},	//   tøre, _gins, واز_,
  { {0xeabf0290,0x262b005e,0xe7a80121,0x00000000}},	//   più_, ицао_, овёл_,
  { {0x7d03102c,0x7cef05dd,0x69da003b,0x00000000}},	//   _zins, røre, ştea,
  { {0xf99f01a8,0x261a0042,0x20bc0082,0x00000000}},	// [b050] rcès_, बड़ी_, ्चाध,
  { {0x3ead00ea,0xde8f008b,0xd37b293a,0x00000000}},	//   zhet_, _kịch_, иче_,
  { {0x44210027,0xf8bf0164,0x656f0051,0x00000000}},	//   rbh_, ssés_, _wsch,
  { {0x656f5804,0x6ee50022,0x1308071f,0x00000000}},	//   _tsch, róbk, іній_,
  { {0x442100e3,0xde8f001b,0xe4a70635,0x00000000}},	//   pbh_, _lịch_, _дрво,
  { {0xccf80080,0xc5fa0063,0x24982bdf,0x00000000}},	//   jmě_, _לפרט, _gorm_,
  { {0x3ead5805,0xbea50062,0x44240054,0x00000000}},	//   thet_, зайк, _ієра,
  { {0x764d1362,0xccf80080,0x7d035806,0x00000000}},	//   ngay, emě_, _sins,
  { {0x4177007e,0x656d004d,0x7d035807,0x00000000}},	//   _بازس, nwah, _pins,
  { {0x2ca90b0e,0x998011f0,0xde8f0013,0x00000000}},	//   скоп_, _afiş_, _bịch_,
  { {0x7d030ac6,0xcb69005a,0xa2f5009f,0x00000000}},	//   _vins, щане_, ּמָה_,
  { {0xde8f001b,0xa96a05c5,0x25a00150,0x00000000}},	//   _dịch_, бима_, yyil_,
  { {0x49990076,0x290f0164,0x6ed3000c,0x00000000}},	//   отря_, _égal_, răbd,
  { {0x23bd0161,0xad1a0063,0xa3ab0042,0x00000000}},	//   ्पाद, _הוסר, गना_,
  { {0x17790055,0xfaa65808,0x6d49003b,0x00000000}},	//   ость_, _нако, luea,
  { {0x8b3a014e,0x6b9c00c7,0x784e00ea,0x00000000}},	//   _התקצ, ärge, _bőví,
  { {0x2f110026,0x656d2f1b,0x6d4900dd,0x00000000}},	// [b060] _lág_, gwah, nuea,
  { {0x7e690122,0x33f60002,0x6aac0042,0x00000000}},	//   heep, пчес, _चतुर,
  { {0x389b11b4,0x24985809,0x35fa007e,0x00000000}},	//   _היינ, _vorm_, _گردد_,
  { {0x87170063,0x644b005f,0x2498580a,0x00000000}},	//   _מקטע_, ėgia, _worm_,
  { {0xc2190086,0x317f0402,0x3a370063,0x00000000}},	//   ієї_, _cruz_, פרסם_,
  { {0xd3780130,0x71090054,0x00000000,0x00000000}},	//   _šću_, іхів_,   ,
  { {0xa8570063,0xb17d0124,0xc6b6009a,0x00000000}},	//   פיקה_, _vyťa, ּהִי_,
  { {0x877b00b5,0x66164878,0x333b009a,0x00000000}},	//   מאצי, ncyk, _לתלמ,
  { {0x50460088,0x6d491358,0x614309da,0x00000000}},	//   _неаб, guea, _пета,
  { {0x2f110025,0xd00f0021,0x718b0063,0x00000000}},	//   _fág_, _ملك_, _לְבַ,
  { {0xccf80080,0xe4570047,0xa0670854,0x00000000}},	//   rmě_, הייט_, _хаха_,
  { {0xdcfc0058,0xbd6a005e,0xdc02011b,0x00000000}},	//   ıyıc, _грке_, _učím,
  { {0x69da000c,0xc987005e,0x5eeb009a,0x00000000}},	//   şten, чуни, _הַגְ,
  { {0xddeb00b5,0xde8f001b,0x7dc50021,0x00000000}},	//   _פֿאָ, _tịch_, _تتمك,
  { {0x7b060080,0x6c5b0063,0xc6a70131,0x00000000}},	//   ístě, _הדוח, праи,
  { {0x27ed0080,0xe8d9008b,0x1ae40856,0x00000000}},	//   řeno_, _trữ_, _појм,
  { {0x764d0397,0xba74007e,0x5499000d,0x00000000}},	// [b070] rgay, _سايت, оваў_,
  { {0x8707000d,0x656d004d,0xe8270121,0x00000000}},	//   _няме, rwah, _эфио,
  { {0x98ab000c,0x98b9000c,0x656d14e7,0x00000000}},	//   ască_, arsă_, swah,
  { {0x05190021,0xddd4004c,0x38af0244,0x00000000}},	//   _ويجب_, žařs, _würd_,
  { {0xd0090002,0x7e69004b,0xaa380041,0x00000000}},	//   оеле_, veep, לטאק_,
  { {0x6aad001f,0x2f110e7c,0x20540062,0x00000000}},	//   _llaf, _pág_, етър,
  { {0xb4d90235,0xcef50002,0x4433580b,0x00000000}},	//   ावी_, мчињ, max_,
  { {0x0d850076,0x6d49003b,0x271800a8,0x00000000}},	//   длин, tuea, _učne_,
  { {0xdb08027d,0x7e6957c4,0x8db50603,0x00000000}},	//   vzdá, reep, ьскі,
  { {0x6aad23d4,0x4433580c,0x0b590766,0x00000000}},	//   _alaf, nax_, ормы_,
  { {0xeb991657,0xaa462a21,0xae190094,0x00000000}},	//   цин_, менл, _джеф_,
  { {0x1fc90161,0x929d0051,0x60c3580d,0x00000000}},	//   िपीड, _miło, linm,
  { {0x3ea200c7,0x6d4904a6,0x690b0022,0x00000000}},	//   ökte_, quea, _ażeb,
  { {0xb69b017d,0x4c840054,0xfbc52dc1,0x00000000}},	//   _diâm, _плів, _обло,
  { {0x869a0002,0x66e64ee9,0x480702fa,0x00000000}},	//   отат_, дова, дерн_,
  { {0xfe79004c,0x64430014,0xddc0008f,0x00000000}},	//   ndů_, ónin, lemš,
  { {0x38af01f7,0x60c3005b,0xe5720021,0x00000000}},	// [b080] _süre_, kinm, خطأ_,
  { {0x03a60001,0x66160f1b,0xddc000c2,0x00000000}},	//   мизо, scyk, nemš,
  { {0xf6264990,0x833a0330,0x60c3580e,0x00000000}},	//   _одно, ючат_, dinm,
  { {0x9c7c00c3,0x2d80001c,0x41e6000d,0x00000000}},	//   moče, _šiem_, міла,
  { {0x9c7c22f1,0x5fc30042,0x60181dc6,0x00000000}},	//   loče, _वेबल, поля_,
  { {0x1de10053,0x60c3580f,0x62895810,0x00000000}},	//   _पड़त, ginm, _eneo,
  { {0xb4ea0053,0xd007005e,0x7ae45811,0x00000000}},	//   मती_, меље_, _okit,
  { {0xf8bf0003,0x3da605f7,0x1ef70021,0x00000000}},	//   mpée_, дроб, وعية_,
  { {0x60c40025,0x9c7c004c,0x7d6a0054,0x00000000}},	//   éims, hoče, ішив_,
  { {0xe0860021,0x9c7c429d,0x6aad00a3,0x00000000}},	//   _تجري, koče, _slaf,
  { {0x9c7c00c3,0x69da003b,0x6aad3688,0x00000000}},	//   joče, ştel, _plaf,
  { {0xf8bf0003,0xa2a10053,0x53370041,0x00000000}},	//   ipée_, कॉप्, ונטן_,
  { {0xb9e40086,0x7e62017d,0x9c7c01ff,0x00000000}},	//   віри, _ibop, eoče,
  { {0x7d1d017d,0xe8d9008d,0x7ae40078,0x00000000}},	//   ísse, _trử_, _ekit,
  { {0x9c7c0198,0x248d008b,0x2ca30137,0x00000000}},	//   goče, _đem_, öjde_,
  { {0x60c3005b,0xbebc008f,0x8f9b0063,0x00000000}},	//   zinm, _avīz, חילי,
  { {0x7afd1c7d,0x60c35812,0x929d0022,0x00000000}},	// [b090] mmst, yinm, _siło,
  { {0xb4d9016a,0x9c7c5813,0xa7750193,0x00000000}},	//   ावे_, ločb, _злоч,
  { {0xca48007e,0x44335814,0x02190054,0x00000000}},	//   _علیه_, rax_, піль_,
  { {0xd6270032,0x7cef01f2,0xddc05815,0x00000000}},	//   _تعدي, jørn, zemš,
  { {0x35b4000d,0x69080058,0xde8f0013,0x00000000}},	//   _абяр, _ürdü, _bịnh_,
  { {0xe1f00021,0xe4c7000d,0x7afd0244,0x00000000}},	//   جسم_, _цёмн, hmst,
  { {0xa5bb017d,0xd00602b6,0xde8f008d,0x00000000}},	//   _geór, неше_, _dịnh_,
  { {0x6289000c,0xa1591bdd,0x443100ea,0x00000000}},	//   _uneo, _набу_, _hez_,
  { {0x4431005b,0xc05b15d4,0x98ef0053,0x00000000}},	//   _kez_, _між_, छताछ_,
  { {0xd0110032,0x7afd3492,0x16010053,0x00000000}},	//   _إلا_, emst, लेयर_,
  { {0x27180077,0x7af65385,0x4431011b,0x00000000}},	//   _očna_, _phyt, _mez_,
  { {0x6b9c0504,0xa96a005e,0xd946157f,0x00000000}},	//   ärga, пима_, неми,
  { {0x3eaf001c,0xbda70021,0x38b4004e,0x00000000}},	//   _ilgt_, _تحاو, _järg_,
  { {0x6ee50051,0x61e4155e,0x7e7b343c,0x00000000}},	//   róbu, üili, ldup,
  { {0x290c0066,0x46f612ab,0x6d5b5816,0x00000000}},	//   _žiaľ_, ечат, ltua,
  { {0x7ae40009,0x7e7b00f3,0xcf9200b5,0x00000000}},	//   _ukit, ndup, נטן_,
  { {0x61e90150,0x39460025,0x9c7c00c2,0x00000000}},	// [b0a0] _nyel, _íos_, soče,
  { {0x44310024,0x2d800006,0x6d5b5817,0x00000000}},	//   _cez_, _šiek_, itua,
  { {0x44315818,0x7b09005b,0x6d5b0019,0x00000000}},	//   _dez_, _üstü, htua,
  { {0xe8d9001b,0xdbc60019,0xa50a5819,0x00000000}},	//   _trợ_, _tööo, _нема_,
  { {0x44310016,0x7e7b0014,0xa6830085,0x00000000}},	//   _fez_, ddup, _сляд,
  { {0xf8bf0164,0xa5bb1c43,0xd00f0593,0x00000000}},	//   ppée_, _teór, مله_,
  { {0xde8f008b,0x7cef04aa,0x61e9581a,0x00000000}},	//   _vịnh_, tørn, _eyel,
  { {0x38b400c7,0x9c7c0066,0x38af004b,0x00000000}},	//   _färg_, mlči, _müra_,
  { {0xde8f0013,0xa3bc0042,0xe611009d,0x00000000}},	//   _tịnh_, इज़र_, יִי_,
  { {0x387a0024,0x6ed3003b,0x4cb70121,0x00000000}},	//   _napr_, răba, елью_,
  { {0xa4b70063,0xe7e00053,0xcf890021,0x00000000}},	//   גליה_, _खुला_, _يضمن_,
  { {0x67ce00ea,0x2912017e,0xd3370063,0x00000000}},	//   zőjé, _buya_, ערכה_,
  { {0x291202dd,0xf2d300b5,0x5a34000d,0x00000000}},	//   _cuya_, רער_, ынят,
  { {0x916d001b,0x9b940021,0xac9402d8,0x00000000}},	//   _hộp_, _للتت, _јакш,
  { {0xe7db0161,0x64430297,0x4431581b,0x00000000}},	//   _मुखप, ónim, _rez_,
  { {0x1477007e,0x3cfe01f4,0x63a50061,0x00000000}},	//   کارج, lmtv_, vyhn,
  { {0x99840021,0x5455026b,0x44314bb3,0x00000000}},	// [b0b0] _مليو, кват, _pez_,
  { {0xdce2004c,0x47d500de,0x00000000,0x00000000}},	//   _opoč, _ليخر,   ,
  { {0x44310fca,0x92590076,0x9fb5004c,0x00000000}},	//   _vez_, дает_, třím_,
  { {0x916d008b,0x2807004c,0x67ce013d,0x00000000}},	//   _nộp_, ětně_, sőjé,
  { {0x7cef06a5,0x38b40137,0x6d5b581c,0x00000000}},	//   førl, _färd_, xtua,
  { {0xe04204d8,0x3f690a30,0x9f64011b,0x00000000}},	//   анши, дико_, _štáb_,
  { {0x6d470078,0x61e90022,0x63a300a5,0x00000000}},	//   ąjam, _wyel, ännd,
  { {0x6d5b581d,0xee090062,0xf0bb005d,0x00000000}},	//   ttua, мейл_, _کارش_,
  { {0x3ea200c7,0x6b9c0019,0x6d5b0072,0x00000000}},	//   ökta_, ärgn, utua,
  { {0x38b40137,0x69da0058,0xfc310021,0x00000000}},	//   _käre_, ştek, جحة_,
  { {0x29124111,0x79841c07,0xf4120063,0x00000000}},	//   _suya_, _sriw, יפי_,
  { {0x2d9906a5,0x752f0022,0x6d5b0b7f,0x00000000}},	//   øses_, _owcz, ptua,
  { {0x6e29003e,0xdce2004c,0x89d50054,0x00000000}},	//   mbeb, _zpoč, гірш,
  { {0x6b650055,0x661d581e,0x60cd0025,0x00000000}},	//   _акка, _afsk, éamh,
  { {0xe73a0076,0x63a304aa,0x2aa20022,0x00000000}},	//   ьев_, ønnl, _dóbr_,
  { {0x79841cb6,0x2912006d,0xdc450023,0x00000000}},	//   _triw, _tuya_, _pūķi,
  { {0x9c7c00c3,0x6d49581f,0xf50a0cb2,0x00000000}},	// [b0c0] loča, nrea, днал_,
  { {0x6d490027,0x29370063,0x7ebe0006,0x00000000}},	//   irea, _שאין_, rūpi,
  { {0x6d490025,0x38b400c7,0x8c42005b,0x00000000}},	//   hrea, _värd_, _öğen,
  { {0x23271001,0x6d490d36,0xdcfb0130,0x00000000}},	//   тоци_, krea, dvuč,
  { {0xaa7b027d,0xdce24c1d,0x6e29004d,0x00000000}},	//   plýv, _spoč, dbeb,
  { {0x6d495820,0x94230002,0x6e295821,0x00000000}},	//   drea, _вмре, ebeb,
  { {0x6d495822,0x690b0022,0x3af9004c,0x00000000}},	//   erea, _ożen, lépe_,
  { {0x6d490025,0xb7db00b5,0x6e2900a4,0x00000000}},	//   frea, וקצי, gbeb,
  { {0x26d200bb,0x6ee50024,0xa26a0022,0x00000000}},	//   inyo_, tóbr, zęść_,
  { {0x212600e3,0x8ffa03eb,0xcb980086,0x00000000}},	//   mpoh_, _قرار_, евої_,
  { {0xdce200c3,0x9c7c00c3,0xb5fb0025,0x00000000}},	//   _upoč, goča, _abál,
  { {0x4ea300d7,0x3af9013d,0x6d495823,0x00000000}},	//   _врша, képe_, brea,
  { {0x6d491729,0xe9470062,0x3ed90047,0x00000000}},	//   crea, ъхно, _אַסא,
  { {0x929d0051,0xa9c4000d,0xdce6008f,0x00000000}},	//   _piłk, рсюк, īmēj,
  { {0x2f18009c,0x57a432e6,0x00000000,0x00000000}},	//   _jég_, ашта,   ,
  { {0x2f18000f,0x5a470088,0xba550001,0x00000000}},	//   _még_, _рэка, _свиј,
  { {0xd684007b,0x15180021,0xa3c0004c,0x00000000}},	// [b0d0] јусп, نزلة_, výší_,
  { {0x8d5b0041,0xd3a70098,0xa8750085,0x00000000}},	//   וכמי, креп, _слоі,
  { {0x53e40088,0x7eb50066,0x128a005d,0x00000000}},	//   ацца, _hápe, کمنی_,
  { {0xe2980086,0xfb150047,0x25de0053,0x00000000}},	//   кає_, אַסט_, _कुकी_,
  { {0x38b400bd,0x7abc014e,0xc244000d,0x00000000}},	//   _wäre_, וצאו, рнік,
  { {0x69da00bd,0x4f790062,0x6d495824,0x00000000}},	//   ßtei, ещия_, vrea,
  { {0x53340c8d,0xd25b0001,0xfe710021,0x00000000}},	//   _вест, _оца_, مدة_,
  { {0x9c7c1035,0x25a9096c,0x6d495825,0x00000000}},	//   voča, oyal_, trea,
  { {0x64680026,0x25a95826,0x2d94000d,0x00000000}},	//   _þrið, nyal_, арэс,
  { {0x9c7c02f7,0xddca003b,0x6d492308,0x00000000}},	//   toča, ţişe, rrea,
  { {0x2d860290,0x7e5500f2,0x6d495827,0x00000000}},	//   _eroe_, _مناص, srea,
  { {0x9c7c0198,0x6d5c000c,0x38af049c,0x00000000}},	//   roča, ărar, _büro_,
  { {0x38c8006a,0x2d8200df,0x9c7c4dcb,0x00000000}},	//   ناسی_, åket_, močn,
  { {0x9c7c160f,0x3ead06a3,0x290c10c8,0x00000000}},	//   ločn, lket_, öda_,
  { {0xaa7b0ac6,0x9cda0063,0x1be90062,0x00000000}},	//   glýs, _אקספ, _ядки_,
  { {0xa3d70161,0x3ead38cb,0xeab20044,0x00000000}},	//   ापन_, nket_, _دعت_,
  { {0x5983000d,0x7ae65828,0xdb02013d,0x00000000}},	// [b0e0] _глыб, mokt, szló,
  { {0xa856005e,0x3ead004e,0xa9bb009a,0x00000000}},	//   _стиј, hket_, _נזיר,
  { {0x394002ab,0x3ead02ab,0x9c7c007d,0x00000000}},	//   _hvis_, kket_, kočn,
  { {0x5b560047,0xd25001f3,0x2f18013d,0x00000000}},	//   טשען_, زنت_, _rég_,
  { {0xc1e70b62,0x10a608b0,0xddc900a8,0x00000000}},	//   льше_, лидн, edež,
  { {0xe9f90013,0x3ead013d,0xc0e30e82,0x00000000}},	//   _hoả_, eket_, бочк,
  { {0x443a5829,0x33780063,0x80a50042,0x00000000}},	//   map_, _בְּב, _कवरे,
  { {0x443a430d,0x6b9c0019,0x9c7c00c2,0x00000000}},	//   lap_, ärgm, gočn,
  { {0x7ae64d6f,0xfd140002,0xadd4005e,0x00000000}},	//   dokt, јмоќ, ропљ,
  { {0x443a582a,0x3ead582b,0x5b26582c,0x00000000}},	//   nap_, aket_, льма,
  { {0x3b630055,0xdd92007e,0x3940582d,0x00000000}},	//   бъяв, _گوش_, _avis_,
  { {0x3ead0924,0x7eb50024,0x2d8200d1,0x00000000}},	//   cket_, _pápe, åkes_,
  { {0x443a582e,0xc8f50062,0x4c940141,0x00000000}},	//   kap_, измъ, _вилс,
  { {0x6b9c010a,0xed57014e,0x443a0228,0x00000000}},	//   ørgs, _עבור_, jap_,
  { {0x443a0397,0x8c1b0063,0x7c3a582f,0x00000000}},	//   dap_, _אווי, matr,
  { {0xaa7b0026,0x7c3a5830,0x394001e1,0x00000000}},	//   rlýs, latr, _fvis_,
  { {0xf4870259,0x84350054,0x344b1fc6,0x00000000}},	// [b0f0] лужн, инає, ечен_,
  { {0xaa7b0ac6,0x25a904d2,0x443a3534,0x00000000}},	//   plýs, ryal_, gap_,
  { {0xd3710067,0xe787000d,0x521505bd,0x00000000}},	//   تها_, _супо, адет,
  { {0xf53f01e3,0x7c3a0b34,0x179a009a,0x00000000}},	//   _två_, hatr, _סירב,
  { {0x210f0053,0x9c7c00c2,0x1167007e,0x00000000}},	//   ादेश_, vočn, التی_,
  { {0xa0690138,0x8fa5005a,0x29380047,0x00000000}},	//   така_, иале, ראגן_,
  { {0xc4d20063,0x9c7c339e,0x3ead0072,0x00000000}},	//   _וגם_, točn, tket_,
  { {0x7c3a5831,0xa3b20042,0x00000000,0x00000000}},	//   eatr, टनर_,   ,
  { {0x38b400c7,0x6d465005,0x9c7c15df,0x00000000}},	//   _lära_, škan, ročn,
  { {0xa2a10161,0x3ead5832,0x64575833,0x00000000}},	//   कॉर्, sket_, ngxi,
  { {0x2d820031,0x38b400c7,0x9c7c017f,0x00000000}},	//   åker_, _nära_, počn,
  { {0x9c7c00c2,0x7c3a2af9,0x3ce50109,0x00000000}},	//   ločl, aatr, solv_,
  { {0xfeb8007e,0xb2760047,0x443a0360,0x00000000}},	//   _حالت_, בערג_, yap_,
  { {0x6e3b00bd,0x38b40137,0x7c3a4057,0x00000000}},	//   laub, _bära_, catr,
  { {0xac74006a,0x7cef0031,0xe73705fb,0x00000000}},	//   _دانش, jøri, иер_,
  { {0x7a0c001c,0x75d604a0,0xd6260044,0x00000000}},	//   _pētī, ليزا, شعري,
  { {0x80d60053,0x443a5834,0xe61708a2,0x00000000}},	// [b100] _बदले, tap_, рду_,
  { {0x7cef0e5a,0x25fc0053,0x6aa40139,0x00000000}},	//   føri, लेगी_, _hoif,
  { {0x6e3b30fa,0x38cb007e,0x443a5835,0x00000000}},	//   kaub, _جايی_, rap_,
  { {0x63a300c7,0x443a32a4,0x7c3a48ec,0x00000000}},	//   änna, sap_, zatr,
  { {0x7c3a107b,0x715a05ce,0xa1ba0044,0x00000000}},	//   yatr, трес_, خطاء_,
  { {0x6ab60185,0x25af00b9,0xe8d9008b,0x00000000}},	//   _llyf, øgle_, _trụ_,
  { {0x44382c12,0xdfcf002a,0x03a60699,0x00000000}},	//   _ier_, ويه_, _тиво,
  { {0x4438210c,0x7c3a5836,0x1d340062,0x00000000}},	//   _her_, watr, бния,
  { {0x44380198,0xdddb000c,0xac18005e,0x00000000}},	//   _ker_, reuş, лопу_,
  { {0x44380117,0x62820173,0x7c3a24e4,0x00000000}},	//   _jer_, ldoo, uatr,
  { {0x443802f0,0x62805837,0x501b0041,0x00000000}},	//   _mer_, _kamo, _סואו,
  { {0xdfcf006a,0x6aa40a2c,0x63a305b9,0x00000000}},	//   _تيم_, _coif, ønni,
  { {0xdd8f0032,0x094b005a,0x79a40121,0x00000000}},	//   _يوم_, ъчни_, орре,
  { {0x443801e3,0x8cf30088,0x644a5838,0x00000000}},	//   _ner_, _дзіц, ófil,
  { {0xe9f90013,0x1b770021,0x6d400582,0x00000000}},	//   _doạ_, _نصية_, lsma,
  { {0x62805839,0x4438583a,0x3acf0022,0x00000000}},	//   _namo, _aer_, tępu_,
  { {0x4438583b,0x7aed204d,0x6d40583c,0x00000000}},	// [b110] _ber_, _ikat, nsma,
  { {0x7c38017f,0x4438583d,0x7cef04aa,0x00000000}},	//   _jevr, _cer_, tøri,
  { {0x443808f9,0x7c38006f,0x6b9c0137,0x00000000}},	//   _der_, _mevr, ärgh,
  { {0x443804c6,0xe6950032,0x98b9001c,0x00000000}},	//   _eer_, _الحد, pusē_,
  { {0x4438583e,0x7cfd0164,0x78a50019,0x00000000}},	//   _fer_, lère, _kohv,
  { {0x4438583f,0x6d4002e0,0x3e710013,0x00000000}},	//   _ger_, dsma, _ạt_,
  { {0xc0580086,0x7cfd0003,0x9c7c00c2,0x00000000}},	//   річ_, nère, ročl,
  { {0x44210d9d,0x62803aaf,0x9c7c00c2,0x00000000}},	//   lch_, _gamo, sočl,
  { {0x9c7c0198,0x443801f7,0x7c380162,0x00000000}},	//   močj, _yer_, _bevr,
  { {0x44211a74,0x62805840,0xbb750062,0x00000000}},	//   nch_, _zamo, бумъ,
  { {0x6e3b00a4,0x0c22000d,0x7c385841,0x00000000}},	//   paub, ямэн, _devr,
  { {0xcff60063,0x7cfd0003,0x9c7c00c2,0x00000000}},	//   _הצעה_, dère, nočj,
  { {0x6b8a006f,0x82760047,0x44210066,0x00000000}},	//   _erfg, זערע_, kch_,
  { {0x7c380162,0x7cfd0003,0x7aed5842,0x00000000}},	//   _gevr, fère, _ekat,
  { {0x7cfd0164,0x7eb5004a,0x78a5007d,0x00000000}},	//   gère, _zápa, _dohv,
  { {0x44385843,0x96950086,0x7aed00a4,0x00000000}},	//   _ser_, оруш, _gkat,
  { {0x44385844,0x46a30062,0x628042f8,0x00000000}},	// [b120] _per_, чатв, _ramo,
  { {0x99920080,0x62805845,0x7cfd0003,0x00000000}},	//   _když_, _samo, bère,
  { {0x62800009,0x44385846,0x7c3a0047,0x00000000}},	//   _pamo, _ver_, רגעז,
  { {0xd259019d,0x6b9c0004,0x44381a6c,0x00000000}},	//   иці_, ärgi, _wer_,
  { {0x628202b0,0x628004a6,0x673b017f,0x00000000}},	//   rdoo, _vamo, ćuje,
  { {0xdb1a03e8,0x6d4000c7,0xc0e30b3f,0x00000000}},	//   szté, vsma, почк,
  { {0xd095000d,0x9c7c00c2,0x20b9000d,0x00000000}},	//   ўшчы, bočj, шыць_,
  { {0x6d462e6a,0x7eb5013d,0x6d404f73,0x00000000}},	//   škam, _pápa, tsma,
  { {0x7aed005f,0x65645847,0x6d405848,0x00000000}},	//   _rkat, ntih, usma,
  { {0x9c7c0198,0x6564080d,0x7cfd0003,0x00000000}},	//   močk, itih, yère,
  { {0x6d401468,0x38b4004b,0xc5f50042,0x00000000}},	//   ssma, _pärn_, _आर्य_,
  { {0x38af005b,0x7cfd0164,0xbe850021,0x00000000}},	//   _türk_, vère, _وجنو,
  { {0x984b005a,0x2d9900fe,0x7c385849,0x00000000}},	//   лява_, äset_, _tevr,
  { {0x7cfd02a7,0xd90f007e,0x6f1a584a,0x00000000}},	//   tère, ژیک_, _kutc,
  { {0x38af550a,0x38b4004b,0x49190042,0x00000000}},	//   _jüri_, _tärn_, _यूरो_,
  { {0x44210c70,0x7f3b00b5,0x7cfd0164,0x00000000}},	//   wch_, טעלו, rère,
  { {0x69da584b,0x6594000a,0x7cfd0003,0x00000000}},	// [b130] şter, пату, sère,
  { {0x9d1b014e,0x6f1a0034,0x4421584c,0x00000000}},	//   טומט, _outc, uch_,
  { {0x44211dc0,0x65640089,0x27ed004d,0x00000000}},	//   rch_, atih, ßend_,
  { {0x442127a0,0x3ea62af9,0x798d161f,0x00000000}},	//   sch_, _noot_, _kraw,
  { {0x9c7c00c2,0x61450dc8,0x6d4609b6,0x00000000}},	//   ročj, цела, škaj,
  { {0x3f8c007d,0x6f1a3183,0x6447007d,0x00000000}},	//   _brdu_, _butc, _udji,
  { {0x10480076,0x3ea602ce,0xf3f30593,0x00000000}},	//   сячи_, _boot_, _رأس_,
  { {0x92b7007e,0x6f1a2a0d,0xfd490002,0x00000000}},	//   _احسا, _dutc, азик_,
  { {0x2d8b0080,0x52b50042,0x31342282,0x00000000}},	//   íce_, ंसीस, _нетр,
  { {0x985d001c,0x6cc5000d,0xa0c40044,0x00000000}},	//   gāļu_, ійна, _فيقو,
  { {0x3ea60cfc,0x798d584d,0x4ee7000d,0x00000000}},	//   _foot_, _araw, _лідз,
  { {0x6ee70021,0x271800c2,0x798d035a,0x00000000}},	//   _اسئل, _učni_, _braw,
  { {0x7cef0831,0x31790047,0x798d0115,0x00000000}},	//   ført, באָד, _craw,
  { {0x798d04bf,0xd9430002,0x7eb5013d,0x00000000}},	//   _draw, ќери, _kápo,
  { {0x752d001c,0xf0920063,0xfaa61567,0x00000000}},	//   epaz, ונם_, _мако,
  { {0x2ca70b05,0x6abd004d,0x798d0333,0x00000000}},	//   _hond_, chsf, _fraw,
  { {0x2913584e,0x284a0054,0x38b4004b,0x00000000}},	// [b140] _fixa_, _кзпп_, _härm_,
  { {0x3e4c0078,0x9f450072,0x33f6137a,0x00000000}},	//   mėtų_, _kylä_, очес,
  { {0x3e4c0006,0x7eb50114,0x33d60054,0x00000000}},	//   lėtų_, _nápo, ціат,
  { {0x7ebc000f,0x6d460014,0x65642198,0x00000000}},	//   _képe, ákak, ptih,
  { {0x3ea6201a,0x3e4c0078,0x38b402d2,0x00000000}},	//   _root_, nėtų_, _lärm_,
  { {0x50660054,0x113902dc,0x2ca7002b,0x00000000}},	//   ітла, сяцы_, _nond_,
  { {0x7e6900d1,0x7cef00b9,0x3ea61207,0x00000000}},	//   ffep, hørs, _poot_,
  { {0x7cef0146,0xbe8a0001,0x33930032,0x00000000}},	//   kørs, рске_, _تلفز,
  { {0x9c7c0198,0xeeb70086,0x7ebc00ea,0x00000000}},	//   loči, ільш_, _népe,
  { {0x3e4c0006,0x38af004b,0x0caa17e1,0x00000000}},	//   dėtų_, _türi_, ртии_,
  { {0x7cf40268,0x3f8c4d1f,0x9c7c00c2,0x00000000}},	//   nàri, _urdu_, noči,
  { {0x798d584f,0x7cef0831,0x7cf400cd,0x00000000}},	//   _praw, førs, iàri,
  { {0x2bb5001b,0x99920051,0x7cf400cd,0x00000000}},	//   ác_, _gdyż_, hàri,
  { {0x6da30138,0x7ebc0164,0x2ca7013d,0x00000000}},	//   _циља, _dépe, _gond_,
  { {0xa814000a,0x9c7c00c3,0x8bc3005a,0x00000000}},	//   ддрш, joči, _осъд,
  { {0x7cf400cd,0x798d0241,0xc6f9000d,0x00000000}},	//   dàri, _traw, ёнах_,
  { {0x7ebc10fd,0x7cef01e1,0x6f02002b,0x00000000}},	// [b150] _gépe, mørr, _mhoc,
  { {0x7d1d1997,0x752d01f4,0x04670085,0x00000000}},	//   íssi, rpaz, ўтам,
  { {0x9c7c0198,0x78a10026,0x39590b64,0x00000000}},	//   goči, ölvu, luss_,
  { {0xb77a00b5,0x877a009f,0x64430046,0x00000000}},	//   _פארש, _פארי, ðnib,
  { {0xc69200b5,0x39595850,0x24830130,0x00000000}},	//   _נאך_, nuss_, _tajm_,
  { {0x63a300d1,0xb97c5851,0x9c7c5852,0x00000000}},	//   ønns, ינדי, boči,
  { {0x7cf40268,0x2ca71184,0x3959004d,0x00000000}},	//   càri, _rond_, huss_,
  { {0xfe45000a,0x3eb90026,0x6f025853,0x00000000}},	//   чнио, óst_, _choc,
  { {0xee360088,0x3861001f,0xaf240047,0x00000000}},	//   чны_, _ochr_, _פּאַסי,
  { {0x7ebc0164,0xdc990caa,0x7eb501d1,0x00000000}},	//   _répe, стиш_, _zápl,
  { {0x2ca70122,0x6f020025,0x2bb50013,0x00000000}},	//   _vond_, _fhoc, úc_,
  { {0x7cef01f2,0x539a0063,0x09e6005e,0x00000000}},	//   tørs, צירו, зомн,
  { {0x427a0041,0x9c7c0130,0x39590244,0x00000000}},	//   זארג, zoči, guss_,
  { {0x3e4c0006,0xed59004c,0x7cef01e1,0x00000000}},	//   rėtų_, muž_, rørs,
  { {0xc7a6005a,0x3b0a0f92,0x4c9a0063,0x00000000}},	//   чивк, _леко_, _לבסו,
  { {0x7cef00d1,0x3ebf0370,0x6f1e04a5,0x00000000}},	//   pørs, nhut_, ípci,
  { {0xcb13014e,0x38b4004b,0x1818005d,0x00000000}},	// [b160] _אלה_, _järk_, _وردک_,
  { {0x7cf40268,0x9c7c3f1e,0x6f09004d,0x00000000}},	//   tàri, toči, hmec,
  { {0x6f0900c3,0xb80a007e,0x9c7c0078,0x00000000}},	//   kmec, _ديدم_, uoči,
  { {0x7cf40268,0x9c7c14d5,0x6d460078,0x00000000}},	//   ràri, roči, škai,
  { {0x290a0775,0xea8d0041,0x7ebc013d,0x00000000}},	//   omba_, ינאָ, _lépc,
  { {0x26d20035,0x6f02057a,0x6f090066,0x00000000}},	//   liyo_, _shoc, emec,
  { {0xdfd00021,0xdddb00c2,0x7eb500ea,0x00000000}},	//   ضية_, vduš, _tápl,
  { {0x6d550045,0x5255005e,0xaf030085,0x00000000}},	//   ązan, _отуђ, нчык,
  { {0x5d98000d,0x38af0058,0x4d980054,0x00000000}},	//   ікоў_, _kürt_, ікою_,
  { {0x31bb014e,0xc1bb014e,0x26d200a4,0x00000000}},	//   _הזמנ, _הממש, hiyo_,
  { {0x7cef0205,0x2d8f2795,0x6f020139,0x00000000}},	//   tørr, _erge_, _thoc,
  { {0x3959003d,0xada609c8,0x8f9b016e,0x00000000}},	//   tuss_, _наел, _ליבי,
  { {0x26d20c55,0x6ec50021,0xcee90043,0x00000000}},	//   diyo_, _تتلق, _برلن_,
  { {0x5887000d,0x6b9c065e,0x39595854,0x00000000}},	//   чыма, ärgs, russ_,
  { {0x7cef00d1,0x6c830593,0xf7940085,0x00000000}},	//   pørr, _سليم, нарэ,
  { {0xc6f90500,0xab830062,0x9967005e,0x00000000}},	//   інах_, _чушк, _етол,
  { {0x27ed0022,0xf6c8014b,0x00000000,0x00000000}},	// [b170] łen_, чырк_,   ,
  { {0x53350002,0x44f4218c,0xddc0013d,0x00000000}},	//   дежт, епус, nemű,
  { {0x23790049,0xc828009a,0x339500de,0x00000000}},	//   تماد_, _מֵרֹ, بلاز,
  { {0x645e002c,0x26c05855,0x7e625856,0x00000000}},	//   agpi, chio_, _ncop,
  { {0x98b9008f,0x95c8005e,0xe1340085,0x00000000}},	//   jusī_, _еура_, енчы,
  { {0xf484005a,0x7e623016,0xc05b0054,0x00000000}},	//   _пусн, _acop, сід_,
  { {0xd347007e,0xbea50062,0x38b4004b,0x00000000}},	//   _ریشه_, дайк, _särk_,
  { {0xcd290456,0xd7bc016e,0x67bc009a,0x00000000}},	//   ожие_, מצור, ממוק,
  { {0x2eed0104,0x6f0954fc,0x7aef2131,0x00000000}},	//   roef_, rmec, doct,
  { {0x38b4004b,0x6f095857,0x3ebf27d5,0x00000000}},	//   _värk_, smec, shut_,
  { {0x3ebf0150,0x394949f4,0x3b0a0201,0x00000000}},	//   phut_, _avas_, жено_,
  { {0x2d8f00c2,0x9f040021,0xeb960121,0x00000000}},	//   _trge_, _كولو, фию_,
  { {0x2d8f5858,0xdd940085,0x6208009d,0x00000000}},	//   _urge_, _пацы, ּ֔רֶ,
  { {0x315600b5,0xdc3c0066,0x290a5859,0x00000000}},	//   וישן_, _záľu, umba_,
  { {0x26c00185,0x7ebc0003,0x6d46011b,0x00000000}},	//   thio_, _hépa, ákav,
  { {0xf484007e,0x7ebc013d,0xb4b60042,0x00000000}},	//   کاری, _képa, जस्_,
  { {0x34aa0001,0xddc20051,0xb4aa1743,0x00000000}},	// [b180] овао_, _zdoł, оказ_,
  { {0x224d00e3,0x26d2114c,0xa50a0092,0x00000000}},	//   _adek_, siyo_, цеза_,
  { {0x26d200a4,0xaa57007e,0x69c600a8,0x00000000}},	//   piyo_, _علیا_, lzke,
  { {0xe1fa0184,0x38af35c2,0x6807013d,0x00000000}},	//   оге_, _fürs_, séjé,
  { {0x7ebc0003,0x7cfd01a8,0xbebc008f,0x00000000}},	//   _népa, vèrn, _ktīv,
  { {0x7e624350,0x1543005e,0x6d550022,0x00000000}},	//   _scop, _јерм, ązal,
  { {0x44442b22,0x6d4f0066,0x63830336,0x00000000}},	//   ma_, ácan, _игра,
  { {0xf8bb0161,0x2f170076,0x4444585a,0x00000000}},	//   _उत्प, мощь_, la_,
  { {0x7ebc0003,0x4444585b,0x9d140002,0x00000000}},	//   _cépa, oa_, ндич,
  { {0x7ebc585c,0x4444585d,0x9b580002,0x00000000}},	//   _dépa, na_, пиот_,
  { {0x4033019d,0x3ea20137,0x7aef0d2e,0x00000000}},	//   _реєс, ökts_, toct,
  { {0x6d5b00bb,0x63a303be,0xb69b0003,0x00000000}},	//   buua, änni, _châl,
  { {0x76440150,0x44440e94,0x644e585e,0x00000000}},	//   daiy, ka_, _odbi,
  { {0xfbcf006a,0x2f010025,0x4444585f,0x00000000}},	//   اتی_, móga_, ja_,
  { {0xd7f80055,0x2f0155ff,0x76440058,0x00000000}},	//   дут_, lóga_, faiy,
  { {0x442a2aee,0x44445860,0x6d460078,0x00000000}},	//   _afb_, ea_, škau,
  { {0x44445861,0x39490516,0x06a40044,0x00000000}},	// [b190] fa_, _uvas_, خصَّ,
  { {0x9c7c0066,0x59960063,0x44445862,0x00000000}},	//   poču, _נכתב_, ga_,
  { {0x7e7b0035,0x442a04ee,0x70db0042,0x00000000}},	//   yeup, _dfb_, _बदौल,
  { {0x95cb0074,0x44445863,0x7d183588,0x00000000}},	//   _дуга_, aa_, _livs,
  { {0x7c2a5864,0x44445865,0xda010053,0x00000000}},	//   _offr, ba_, ोधित_,
  { {0x7ebc0164,0x44440955,0xf8bf0003,0x00000000}},	//   _répa, ca_, mpés_,
  { {0x7ebc0164,0x64455866,0x32670cdb,0x00000000}},	//   _sépa, mahi, _отав,
  { {0x2d8d2af2,0x38b400fe,0x7c2a5867,0x00000000}},	//   tvee_, _väri_, _affr,
  { {0x61da0053,0x7e7b3114,0x9f4c0260,0x00000000}},	//   बपृष, reup, _vydá_,
  { {0xb16e02f4,0x644503d5,0xf8bf0003,0x00000000}},	//   ížeč, nahi, ipés_,
  { {0xde950001,0x7eb50460,0x6b9c0137,0x00000000}},	//   _пажњ, _lápi, ärgp,
  { {0x44445868,0x7c2a260c,0x1a66007e,0x00000000}},	//   za_, _effr, ریخی_,
  { {0xed4e148d,0x644500bb,0x7cf400cd,0x00000000}},	//   _що_, kahi, tàrt,
  { {0xdb1a000f,0x4444302e,0x6d491632,0x00000000}},	//   sztá, xa_, msea,
  { {0x69c600ea,0x64455869,0x4444586a,0x00000000}},	//   szke, dahi, va_,
  { {0x64430026,0x7ebc00ea,0x4444586b,0x00000000}},	//   ðnin, _lépn, wa_,
  { {0x4444586c,0x7eb5006d,0x9c7c004a,0x00000000}},	// [b1a0] ta_, _cápi, počt,
  { {0x6445002c,0x6d49586d,0x661d00ac,0x00000000}},	//   gahi, isea, _egsk,
  { {0x7c2401f7,0x929d0051,0xd62a0002,0x00000000}},	//   _şirk, _chło, _ноне_,
  { {0xaa7b14c0,0xd252007e,0x6f19001f,0x00000000}},	//   mnýc, انش_, _niwc,
  { {0x291a01f0,0x64454bbc,0xaa7b004a,0x00000000}},	//   _kipa_, bahi, lnýc,
  { {0x6e29017d,0xfaf9008f,0x64450075,0x00000000}},	//   eceb, ltīt_, cahi,
  { {0xaa7b0240,0x7eb5004a,0x6d49586e,0x00000000}},	//   nnýc, _zápi, esea,
  { {0xaa7b004c,0x6289002b,0x3da63f5d,0x00000000}},	//   inýc, _gaeo, ероб,
  { {0x91e3005a,0xfaf9001c,0x63a30137,0x00000000}},	//   _боте, itīt_, ännv,
  { {0x8fa601fc,0xa113014d,0x7ae4586f,0x00000000}},	//   _пазе, _موقت, _ajit,
  { {0xaa7b0114,0x54570047,0x6d495870,0x00000000}},	//   jnýc, עסטן_, asea,
  { {0xaa7b0a63,0x64450089,0x34dd0042,0x00000000}},	//   dnýc, zahi, _मद्द,
  { {0x6445002c,0x6d490025,0xddea007e,0x00000000}},	//   yahi, csea, _عرصه_,
  { {0x7eb506b2,0x26f90053,0x6d460078,0x00000000}},	//   _rápi, ंत्र_, škas,
  { {0x291a0150,0x64455871,0x37070c4d,0x00000000}},	//   _dipa_, vahi, ечав,
  { {0x7cf400cd,0x64451332,0x7b210003,0x00000000}},	//   càrr, wahi, _bœuf,
  { {0x6445053a,0xaa540121,0xf8bf0003,0x00000000}},	// [b1b0] tahi, _свыш, upés_,
  { {0xa8a40905,0xaa7b027d,0x7afd5872,0x00000000}},	//   _брюк, bnýc, llst,
  { {0x64455873,0xf09f008b,0xf8bf0813,0x00000000}},	//   rahi, _đà_, spés_,
  { {0x64455874,0xf8bf0003,0xe3b00021,0x00000000}},	//   sahi, ppés_, حرك_,
  { {0x644500bb,0xb2240086,0x42240086,0x00000000}},	//   pahi, уміл, удів,
  { {0x7afd5875,0x628b002b,0x00000000,0x00000000}},	//   hlst, sdgo,   ,
  { {0x656d0332,0x23e4000d,0xa3ce004c,0x00000000}},	//   ltah, _бітв, píší_,
  { {0x7ebc0164,0x6d490019,0x98b90078,0x00000000}},	//   _dépo, tsea, kusį_,
  { {0x6e290367,0x656d5876,0xaa7b0114,0x00000000}},	//   rceb, ntah, znýc,
  { {0x27ed0080,0x656d0089,0x7af603d4,0x00000000}},	//   řeny_, itah, _skyt,
  { {0xb5fb0139,0x38b4004b,0x6d495877,0x00000000}},	//   _scál, _märt_, ssea,
  { {0x656d1362,0xaa7b027d,0x38b40137,0x00000000}},	//   ktah, vnýc, _lärt_,
  { {0x3ed800b5,0x98d60086,0x6d462f23,0x00000000}},	//   _אַװא, вівщ, škar,
  { {0xaa7b0a63,0xec7927b5,0x7afd2b27,0x00000000}},	//   tnýc, _цпк_, alst,
  { {0xf743000a,0x656d26c5,0x46f60065,0x00000000}},	//   иеро, etah, вчат,
  { {0xcf920e2a,0x321f008b,0x7ae40035,0x00000000}},	//   סטן_, _nguy_, _ujit,
  { {0x60c10025,0x656d00a4,0xaa7b0240,0x00000000}},	// [b1c0] _ollm, gtah, snýc,
  { {0xfaf9001c,0xaa7b0240,0x66db0072,0x00000000}},	//   stīt_, pnýc, täkä,
  { {0x61e91233,0x44160002,0x1459000d,0x00000000}},	//   _axel, тфат, эшты_,
  { {0x7ebc03b2,0x60c15878,0xb23700de,0x00000000}},	//   _répo, _allm, نكما_,
  { {0x7ebc0164,0x66db0072,0x80b30042,0x00000000}},	//   _dépl, säkä, _अवशे,
  { {0x50f30085,0xed590061,0x3cfd0042,0x00000000}},	//   азіт, drž_, ॉगों_,
  { {0x7ee60121,0xd467173e,0x54674073,0x00000000}},	//   кцие, _шире_, _шарм_,
  { {0x99990024,0x8fa30001,0x66c30019,0x00000000}},	//   lasť_, раће, _tõke,
  { {0x7c2d0058,0x7afd01e1,0x516617e2,0x00000000}},	//   _şara, vlst, _шваб,
  { {0x7afd0122,0x98b90078,0x00000000,0x00000000}},	//   wlst, vusį_,   ,
  { {0x34b70063,0xead90086,0x7b210003,0x00000000}},	//   דפים_, емні_, _nœud,
  { {0x4fd900b5,0x7afd00b9,0x7cf401a8,0x00000000}},	//   _אַנד, ulst, ràrq,
  { {0x394d0c6e,0xdd92007e,0x3940001f,0x00000000}},	//   ées_, _خوش_, _cwis_,
  { {0x799600f1,0x6bd60021,0x98b90078,0x00000000}},	//   _dryw, _لتعر, rusį_,
  { {0xe9180054,0x67d401ce,0x7ac7354e,0x00000000}},	//   торі_, аору, _аспе,
  { {0xe6540054,0x9c170063,0x38b400a5,0x00000000}},	//   ивсь, _בחוק_, _bärs_,
  { {0xfaf9001c,0x7ebc5879,0x60d808a9,0x00000000}},	// [b1d0] stīs_, _répl, kivm,
  { {0x656d517c,0xdb090072,0x6abd587a,0x00000000}},	//   rtah, sydä, lksf,
  { {0xa2b40161,0x656d4b16,0x38b40137,0x00000000}},	//   _आवश्, stah, _värt_,
  { {0x656d0716,0x12280054,0x33980044,0x00000000}},	//   ptah, воїй_, ضخمة_,
  { {0x865a0063,0x20050022,0xe290005d,0x00000000}},	//   _אדרי, _szli_, تذل_,
  { {0x6725004b,0xd009007b,0xe057005d,0x00000000}},	//   _kuhj, неле_, ئیات_,
  { {0x3d060053,0xa4d40054,0xcef50131,0x00000000}},	//   _सीधे_, _торі, лчињ,
  { {0x7cfd0268,0x6d5c0078,0x2481004e,0x00000000}},	//   mèri, ąran, lehm_,
  { {0x40351705,0x7cfd01a8,0x61fb0058,0x00000000}},	//   _безс, lèri, _uyul,
  { {0x60c10d17,0x2481004d,0x6f64007e,0x00000000}},	//   _ullm, nehm_, _چهلم,
  { {0x7c95006a,0x7cfd00cd,0x7a6a06b4,0x00000000}},	//   نشگا, nèri, нинг_,
  { {0x7ebc000f,0x79960051,0x66e50078,0x00000000}},	//   _lépj, _pryw, dėko,
  { {0x6e3b014f,0x99d60021,0x00000000,0x00000000}},	//   mbub, اتجا,   ,
  { {0x799600ac,0x68f500c2,0x99d50054,0x00000000}},	//   _vryw, gozd, рююч,
  { {0x2cb8587b,0x79961cc2,0xc5f8008f,0x00000000}},	//   örde_, _wryw, _ņē_,
  { {0x29250027,0x7996001f,0x6d5b0139,0x00000000}},	//   úpaí_, _tryw, orua,
  { {0xe5a32aeb,0x68f500c2,0xf50a04c3,0x00000000}},	// [b1e0] бити, bozd, енал_,
  { {0x7cfd00cd,0x9c7c00c2,0x8886422b,0x00000000}},	//   fèri, onča, _слож,
  { {0xfaf9003d,0x9cd60063,0x7cfd00cd,0x00000000}},	//   brīd_, נועה_, gèri,
  { {0x2bf60047,0x316a41b8,0x41e60085,0x00000000}},	//   אמען_, ешко_, ліла,
  { {0xc5b60088,0x60d8587c,0x35fa005d,0x00000000}},	//   _сёнь, tivm, _سرحد_,
  { {0x7cfd00cd,0x2b590022,0x8f340085,0x00000000}},	//   bèri, ńscy_, аекц,
  { {0x6d5b0331,0x6abd01e1,0xa0a31313,0x00000000}},	//   erua, yksf, сајд,
  { {0x7d54005a,0x6e3b1f9a,0x72791259,0x00000000}},	//   авих, gbub, _исус_,
  { {0xcd36005d,0xad26009b,0x00000000,0x00000000}},	//   درعب, دربو,   ,
  { {0x6e3b00a4,0x7ebc00ea,0xddcb003b,0x00000000}},	//   abub, _képk, ţişt,
  { {0x6d5b04b4,0x7eb50460,0x76460072,0x00000000}},	//   arua, _cáps, _oeky,
  { {0x59670062,0x68f50022,0x6d5b587d,0x00000000}},	//   лъга, wozd, brua,
  { {0xddc9003b,0x7c24003b,0x6abd0310,0x00000000}},	//   rfeţ, _şiru, rksf,
  { {0x6458006d,0x67250050,0xe7873461,0x00000000}},	//   óvil, _puhj, лубо,
  { {0x76462f5c,0x3cfb0165,0xd6b50062,0x00000000}},	//   _beky, _רפוב, айвъ,
  { {0x79a7019c,0x6d5d0046,0x9635587e,0x00000000}},	//   _брое, ásag, рнац,
  { {0xf8ae007e,0x6282587f,0x95cb0854,0x00000000}},	// [b1f0] سکی_, deoo, хува_,
  { {0x7cfd0268,0xdce90080,0x64a4005e,0x00000000}},	//   tèri, yteč, бађа,
  { {0xc7ab0021,0xd37b0085,0xd2510044,0x00000000}},	//   _أدخل_, эча_, قنا_,
  { {0x764600ac,0x6282006f,0x6e225880,0x00000000}},	//   _geky, geoo, _ngob,
  { {0xc24402fe,0x7cfd01a8,0xe0452046,0x00000000}},	//   снік, sèri, анли,
  { {0x6e2214fa,0x2f550e81,0x7eb501d1,0x00000000}},	//   _agob, атис, _nápr,
  { {0x256f3a4d,0x6282006f,0xd4980062,0x00000000}},	//   lül_, beoo, _сря_,
  { {0xdce93187,0x6d5b5881,0xdf280044,0x00000000}},	//   rteč, trua, دأون_,
  { {0x256f00ea,0xdce901c2,0x64470e83,0x00000000}},	//   nül_, steč, _keji,
  { {0x64470080,0xeb990001,0x1d090001,0x00000000}},	//   _jeji, вио_, ђени_,
  { {0x6447006d,0xdb220014,0x109a009a,0x00000000}},	//   _meji, ærðf, _שבעב,
  { {0x256f5882,0x7ebc5883,0x5e270044,0x00000000}},	//   kül_, _néph, _إعاق,
  { {0xddc20080,0x64553a1b,0xdca508b0,0x00000000}},	//   _zbož, _odzi, _вали,
  { {0xe8f70071,0x21ba0047,0x291e10b9,0x00000000}},	//   иля_, דזשא, öta_,
  { {0x2904003d,0x9c7c00c2,0x7526004d,0x00000000}},	//   ēma_, ončn, _sukz,
  { {0xd5e606f0,0x7ebc0003,0x7eb50445,0x00000000}},	//   ажби, _céph, _zápr,
  { {0xbafb0063,0x256f0b35,0xa4463e42,0x00000000}},	// [b200] _בהקש, gül_, инад,
  { {0xc396005e,0x49bb009d,0x00000000,0x00000000}},	//   ијењ, _סמיס,   ,
  { {0x64470024,0x7d015884,0x7b33003b,0x00000000}},	//   _deji, ills, _dăug,
  { {0x6447008f,0x7c2d00dd,0x256f092a,0x00000000}},	//   _eeji, _şarl, bül_,
  { {0x6900024a,0x3ead017f,0xf1940499,0x00000000}},	//   töeh, djet_, силь,
  { {0x64550045,0x89970063,0x628212be,0x00000000}},	//   _gdzi, יכנס_, seoo,
  { {0x656400fe,0x26c00078,0x201a0072,0x00000000}},	//   luih, okio_, äpi_,
  { {0xb5fb0025,0x3ebf0150,0x26c00078,0x00000000}},	//   _scái, gkut_, nkio_,
  { {0x7b33003b,0x5d830021,0x27ed0058,0x00000000}},	//   _lăud, قليل, ğeni_,
  { {0x3ead0089,0x9c7c1035,0x6e3d0026,0x00000000}},	//   ajet_, ančn, ðsbr,
  { {0x256f000f,0x9e66007e,0xa5bb0013,0x00000000}},	//   zül_, _ناشن, _ngón,
  { {0x65640072,0x7d01181a,0xe981014b,0x00000000}},	//   kuih, alls, памi_,
  { {0xfce629c2,0x7ebc013d,0xe8b40042,0x00000000}},	//   _кодо, _népi, ुसूच,
  { {0x256f00ea,0xaa7b0195,0x4bd7005d,0x00000000}},	//   vül_, mným, ابید_,
  { {0xab270540,0x64472f70,0x66e50078,0x00000000}},	//   _која_, _reji, sėkm,
  { {0x256f000f,0x8c1b0063,0x56a40002,0x00000000}},	//   tül_, _בווי, ојуз,
  { {0xaa7b01d1,0xd94401ce,0x38c80043,0x00000000}},	// [b210] nným, _дењи, _چاپی_,
  { {0x35e40088,0x256f000f,0x7ebc0003,0x00000000}},	//   іцтв, rül_, _dépi,
  { {0x644700c3,0xb367005a,0x290301b3,0x00000000}},	//   _veji, ръзк, mlja_,
  { {0xb69b0164,0x64550051,0x43680054,0x00000000}},	//   _chât, _wdzi, раїн_,
  { {0x6447006d,0x7d010026,0x816b0a36,0x00000000}},	//   _teji, ylls, треб_,
  { {0x64550045,0x3ead0917,0xaa7b0240,0x00000000}},	//   _udzi, wjet_, dným,
  { {0xa267005a,0xf78a00b5,0x3ebf00fe,0x00000000}},	//   _възл, ָנפֿ, tkut_,
  { {0x764d002c,0x212b0003,0x3ead0003,0x00000000}},	//   naay, _écho_, ujet_,
  { {0x29035885,0x61440002,0x313410ae,0x00000000}},	//   klja_, _меѓа, _метр,
  { {0xddc2003b,0x3ead4ed0,0x7d0100cf,0x00000000}},	//   _scoţ, sjet_, ulls,
  { {0x798d002c,0x2cb800c7,0x764d00a4,0x00000000}},	//   _asaw, örda_, kaay,
  { {0xaa7b027d,0xcaca005e,0x7ae65886,0x00000000}},	//   bným, угме_, unkt,
  { {0xfe700049,0xed590320,0xaa7b01c8,0x00000000}},	//   _آدم_, _сол_, cným,
  { {0x6c3504de,0x656400fe,0x7ebc006c,0x00000000}},	//   _افغا, vuih, _répi,
  { {0x5b3503eb,0xdc360047,0x2795005e,0x00000000}},	//   _اعتر, _פאקט_, оштр,
  { {0x75d60032,0x7e690f5e,0x6b9c00b9,0x00000000}},	//   ميزا, ngep, ærge,
  { {0x2903082a,0x26c00078,0x6aa400a5,0x00000000}},	// [b220] blja_, rkio_, _inif,
  { {0x764d00a4,0x088a0121,0xdb0f0072,0x00000000}},	//   aaay, _сбой_, ädök,
  { {0x6aa40034,0xa2e60ac5,0xb69b0003,0x00000000}},	//   _knif, божд, _châs,
  { {0x6ab600e5,0xc1ea0085,0x7413009b,0x00000000}},	//   _joyf, льле_, سونا,
  { {0xf1d20053,0x7ebc00ea,0x65550062,0x00000000}},	//   _देखन, _képv, _мърф,
  { {0xaa7b027d,0xf9930063,0x3f98013d,0x00000000}},	//   vným, פרו_, _áruk_,
  { {0x4f570021,0xef18008f,0x3f9a0066,0x00000000}},	//   مجيد_, _apļa_, ípu_,
  { {0x1dd90161,0xa5bb0051,0xaa7b027d,0x00000000}},	//   _बेहत, _ogól, tným,
  { {0x6143019b,0xc6930063,0x3eb90137,0x00000000}},	//   _нета, לאה_, östa_,
  { {0x6aa4001f,0xb5b70063,0x3b541567,0x00000000}},	//   _anif, צליח_, окор,
  { {0x2903065f,0xb4fb0149,0x6ab600e5,0x00000000}},	//   vlja_, רליר, _boyf,
  { {0x635c000c,0x7ac70121,0xaa7b0061,0x00000000}},	//   mănă, ссое, pným,
  { {0xc9870062,0x49741a5d,0x00000000,0x00000000}},	//   щуни, пляс,   ,
  { {0x66e500eb,0xd90f005d,0xac1853bd,0x00000000}},	//   mėki, عید_, _колу_,
  { {0x66e500eb,0x9cdb0132,0x78ba0014,0x00000000}},	//   lėki, _תקופ, ötva,
  { {0xbb3b00b5,0x7cfd01a8,0x36d45887,0x00000000}},	//   _געהי, sèrt, поср,
  { {0x2903074f,0xe4e70086,0x58d50189,0x00000000}},	// [b230] plja_, біжн, _моит,
  { {0x764d002c,0x7aed0072,0x00000000,0x00000000}},	//   saay, _hjat,   ,
  { {0x764d00a4,0x7c2d005b,0xdce0007d,0x00000000}},	//   paay, _şark, jumč,
  { {0x26d9004d,0x66e50078,0x60da5888,0x00000000}},	//   _umso_, kėki, _amtm,
  { {0x60250699,0x212a005d,0xeab2009a,0x00000000}},	//   одла, لينی_, וֹג_,
  { {0x66e50006,0x10a2295e,0x90c50065,0x00000000}},	//   dėki, дишн, юбле,
  { {0xaa7b0026,0x7e6913de,0xc0c8005e,0x00000000}},	//   rnýj, tgep, ључе_,
  { {0xc2c50044,0x8d550edb,0x41e7046e,0x00000000}},	//   _بيري, оточ, _ліза,
  { {0x2d94000d,0x7e695889,0x3cc91849,0x00000000}},	//   прэс, rgep, илио_,
  { {0xcd280754,0x7e6900bd,0xcce50021,0x00000000}},	//   حسين_, sgep, تسعي,
  { {0x6a8606be,0x0aea0121,0x8afd0022,0x00000000}},	//   олна, идой_, dręb,
  { {0x66e50006,0x2ebe0121,0x644a013d,0x00000000}},	//   bėki, _а́юс, ófiz,
  { {0x527a0047,0x272e0026,0x0f1801fb,0x00000000}},	//   סנשא, _sýn_, _اغلب_,
  { {0x8afd1112,0x186a0dd5,0x7ebc0164,0x00000000}},	//   stęp, јави_, _dépu,
  { {0xd7f20021,0x76b6005e,0x00000000,0x00000000}},	//   ذكر_, ољац,   ,
  { {0x78a502ab,0x672f004c,0xcf920063,0x00000000}},	//   _enhv, _žijí, וטל_,
  { {0x673c00ac,0x2bc10053,0x0b170021,0x00000000}},	// [b240] sprj, शनका, _بقية_,
  { {0x63be1ac2,0x4aa80042,0x00000000,0x00000000}},	//   typn, गावव,   ,
  { {0x987b0047,0x6d460240,0x7ebc00ea,0x00000000}},	//   _דריק, ákaz, _képt,
  { {0x68fc588a,0x42560086,0x020602b6,0x00000000}},	//   lord, ітет, озен,
  { {0x68fc02bc,0x9c7c45f0,0x00000000,0x00000000}},	//   oord, liče,   ,
  { {0x68fc1b58,0x27ff004d,0xdce9004c,0x00000000}},	//   nord, ßung_, čněn,
  { {0x9c7c588b,0x2d9900b9,0x8fa3005e,0x00000000}},	//   niče, æsen_, даје,
  { {0xbdb40856,0x1ef70021,0xb5fb0139,0x00000000}},	//   збиј, يعية_, _gcás,
  { {0x68fc588c,0x30760076,0xb05a0593,0x00000000}},	//   kord, _мужс, _نشاط_,
  { {0x7ebc0164,0x66e50006,0x2b47001f,0x00000000}},	//   _répu, rėki, _bwnc_,
  { {0x7ebc0003,0x9c7c007d,0x6d4f017d,0x00000000}},	//   _sépu, jiče, ácar,
  { {0x8afd0051,0xb8820066,0x25740137,0x00000000}},	//   dręc, _šípo, käl_,
  { {0x25740137,0xacea0086,0x68fc588d,0x00000000}},	//   jäl_, _кмда_, ford,
  { {0x9c7c00c2,0x68fc0abc,0xc7c70062,0x00000000}},	//   fiče, gord, осби,
  { {0xcb670001,0xd6db588e,0x3ea6588f,0x00000000}},	//   _даје_, ата_, _knot_,
  { {0x25740137,0x75e70085,0xa535379e,0x00000000}},	//   fäl_, оўзе, знач,
  { {0x68fc132f,0x7afd5890,0x38c9007e,0x00000000}},	// [b250] bord, most, _هادی_,
  { {0x9c7c085a,0x394900a4,0x7afd5891,0x00000000}},	//   biče, _iwas_, lost,
  { {0x7afd0ff2,0x9c7c011b,0xc2d9005d,0x00000000}},	//   oost, ciče, رباﻳ,
  { {0x39490022,0x7afd5892,0x63b800a5,0x00000000}},	//   _kwas_, nost, ävna,
  { {0x7afd25e0,0x66c3004b,0x26c50078,0x00000000}},	//   iost, _lõkk, ūlos_,
  { {0xe0d8019d,0x55ba0063,0x7afd5893,0x00000000}},	//   ові_, _המשו, host,
  { {0x387c00c7,0x7ebc00ea,0x12e70086,0x00000000}},	//   _övre_, _néps, _діаг,
  { {0x0ea90055,0xee39005a,0x7afd0393,0x00000000}},	//   ский_, щни_, jost,
  { {0x3f9e007a,0x9c7c00c3,0x68fc01f7,0x00000000}},	//   _ertu_, ziče, yord,
  { {0x2b470185,0x7ebc006d,0x3ea64e81,0x00000000}},	//   _pwnc_, _sépt, _enot_,
  { {0x68fc5894,0x3949017e,0xfaaa0021,0x00000000}},	//   vord, _awas_, مهدي_,
  { {0x7afd5895,0xef0e0086,0x9c7c04e9,0x00000000}},	//   gost, _їм_, viče,
  { {0x2d91001c,0x9916000d,0x6da505ce,0x00000000}},	//   āzes_, зьві, _хила,
  { {0x257400c7,0x224d224f,0xa3bd0053,0x00000000}},	//   väl_, _leek_, ेना_,
  { {0x7afd5896,0x68fc5897,0x07a3129d,0x00000000}},	//   bost, rord, нарн,
  { {0xcf9200b5,0x7afd32f8,0x9c7c0734,0x00000000}},	//   עטן_, cost, riče,
  { {0x05665898,0xc566005a,0x38b400bd,0x00000000}},	// [b260] яван, якак, _märz_,
  { {0x9c7c1035,0x77ca0a74,0x5503012d,0x00000000}},	//   piče, _глог_, епуб,
  { {0x7ebc0164,0x224d09fe,0x38cb005d,0x00000000}},	//   _mépr, _beek_, _دايی_,
  { {0xc7b3009f,0x7ebc006c,0x00000000,0x00000000}},	//   _טבת_, _lépr,   ,
  { {0xd24f00b3,0x7bc15899,0x76440058,0x00000000}},	//   انه_, hylu, mbiy,
  { {0x7afd1e13,0x200503a4,0x442d005e,0x00000000}},	//   zost, _byli_, _јe_,
  { {0x645c589a,0x4444233a,0x6d5d266a,0x00000000}},	//   _idri, mb_, ásan,
  { {0x44440199,0x3f9e08ed,0xbd6a0121,0x00000000}},	//   lb_, _vrtu_, брое_,
  { {0x644e06a7,0x7cfd00cd,0x4444589b,0x00000000}},	//   _kebi, tèrp, ob_,
  { {0xdb1b000f,0x44440089,0x7afd0051,0x00000000}},	//   sztü, nb_, wost,
  { {0x66061e60,0x7ebc0003,0x28b00053,0x00000000}},	//   _lykk, _dépr, ञानि,
  { {0x644e014f,0x7afd0b4f,0x672600c2,0x00000000}},	//   _lebi, uost, _nikj,
  { {0x645c589c,0x0e9b0063,0x3c460021,0x00000000}},	//   _odri, _לשאל, _فَإِ,
  { {0x645c589d,0x644e23eb,0x66c3004b,0x00000000}},	//   _ndri, _nebi, _tõkk,
  { {0x62800198,0x6c7b0165,0x7afd589e,0x00000000}},	//   _obmo, _האופ, post,
  { {0xb6030024,0x443800ac,0x6d4000ac,0x00000000}},	//   úšob, _afr_, opma,
  { {0xc42b0021,0x442a004d,0x644e589f,0x00000000}},	// [b270] مثال_, _bgb_, _bebi,
  { {0x224d0034,0x444458a0,0xfaff00ac,0x00000000}},	//   _seek_, gb_, loë_,
  { {0x6564005b,0x644e58a1,0x645c002b,0x00000000}},	//   arih, _debi, _ddri,
  { {0x66ca0240,0x44440f40,0x645c1343,0x00000000}},	//   _týka, ab_, _edri,
  { {0x444408d5,0x9c7c0006,0xda7c0047,0x00000000}},	//   bb_, anči, מנאר,
  { {0x644e3c41,0x224d1865,0x63a1013d,0x00000000}},	//   _gebi, _week_, _álno,
  { {0xb6060024,0x7ebc0003,0x73c5014d,0x00000000}},	//   _vráť, _répr, _غيرم,
  { {0x3eb90026,0xa2b5000d,0x7c38006f,0x00000000}},	//   ðst_, _ўбач, _afvr,
  { {0x8027007e,0x628b58a2,0x7bc100a3,0x00000000}},	//   _فرام, mego, wylu,
  { {0xf65f00b9,0x602300ea,0x7b33003b,0x00000000}},	//   _blæk_, _címü, _dăun,
  { {0x2ca700bd,0x6d40005b,0x752700ca,0x00000000}},	//   _vnnd_, apma, _mijz,
  { {0x628b0309,0x63a30072,0x6299577c,0x00000000}},	//   nego, änny, ndwo,
  { {0xed4e58a3,0x6e440044,0x5e440044,0x00000000}},	//   _шо_, _أنهم, _أَهْ,
  { {0x660602ab,0x628b25a1,0x6f091e3e,0x00000000}},	//   _rykk, hego, llec,
  { {0xd7060086,0x66062579,0xa3dd0053,0x00000000}},	//   дзви, _sykk, _तेल_,
  { {0x628b01b3,0x644e58a4,0x4444002b,0x00000000}},	//   jego, _sebi, wb_,
  { {0x75270122,0x764f0051,0x9c7c027c,0x00000000}},	// [b280] _bijz, _decy, liča,
  { {0x6f0900bd,0x444458a5,0x6f1b30e6,0x00000000}},	//   hlec, ub_, hmuc,
  { {0xe29a000d,0xd4d5000d,0x9c7c58a6,0x00000000}},	//   жае_, хітэ, unči,
  { {0x660658a7,0x444406f7,0xfbd20063,0x00000000}},	//   _tykk, sb_, כתב_,
  { {0xdce0000c,0x6f090b37,0x644e58a8,0x00000000}},	//   numă, dlec, _tebi,
  { {0x7527006f,0x6f020051,0x6f0958a9,0x00000000}},	//   _gijz, _skoc, elec,
  { {0xdfd00032,0x6f092b63,0x9c7c0130,0x00000000}},	//   طية_, flec, jiča,
  { {0x6f0908dc,0x249858aa,0x2377004c,0x00000000}},	//   glec, _harm_, žejí_,
  { {0x8c8a005e,0x2498004b,0x6d400014,0x00000000}},	//   ољна_, _karm_, upma,
  { {0xa2da0161,0x9c7c007d,0x7d08322c,0x00000000}},	//   पोर्, fiča, ulds,
  { {0x6f09048e,0x7d0800c7,0x6d4000a4,0x00000000}},	//   blec, rlds, spma,
  { {0x7c2d01f7,0xddc60121,0x6f0912e2,0x00000000}},	//   _şart, _обеи, clec,
  { {0xfaff00ac,0x7c93007e,0x764f58ab,0x00000000}},	//   roë_, رشیا, _recy,
  { {0x9c7c027c,0x3166017d,0x7b76014d,0x00000000}},	//   biča, iroz_, _قطعا,
  { {0x67d50086,0x764f001f,0xd7e40086,0x00000000}},	//   хову, _pecy, віто,
  { {0x290a0218,0x929d0022,0xc6f90054,0x00000000}},	//   alba_, _okła, їнах_,
  { {0x224600df,0x99480021,0x082b0044,0x00000000}},	// [b290] dbok_, _قليل_, _وأدى_,
  { {0x2cbc00ca,0x6f0958ac,0x63e700de,0x00000000}},	//   _jovd_, zlec, وساك,
  { {0xdce9017f,0x7aef0164,0x64450025,0x00000000}},	//   steć, onct, rbhi,
  { {0x752702b0,0xd25b000d,0x21750086,0x00000000}},	//   _wijz, іце_, еукр,
  { {0x24980780,0x9c7c017f,0xc244000d,0x00000000}},	//   _farm_, ziča, тнік,
  { {0x4f95000a,0x628b58ad,0xaf950002,0x00000000}},	//   ериу, sego, ешиј,
  { {0x656d00e3,0xfe710021,0x628b2375,0x00000000}},	//   luah, هدة_, pego,
  { {0x273500c7,0x9c7c0008,0xf53f011d,0x00000000}},	//   _mån_, viča, _tråd_,
  { {0x99800051,0xada5000d,0x2268004c,0x00000000}},	//   _dziś_, хапл, ítků_,
  { {0x91e40138,0x9c7c017f,0x7aef001f,0x00000000}},	//   _рође, tiča, enct,
  { {0x656d58ae,0x27350137,0x3cf00042,0x00000000}},	//   huah, _nån_, ीक़े_,
  { {0x9c7c2dc2,0xeb96030b,0x5f740044,0x00000000}},	//   riča, хию_, _جاكر,
  { {0x9c7c08ea,0xf2170053,0xe9df0014,0x00000000}},	//   mičn, _तरफ़_, tbúa_,
  { {0x6c7900b5,0x26c9007d,0x9c7c58af,0x00000000}},	//   _זאַפ, ekao_, ličn,
  { {0x9cd60063,0xac160001,0xe9df0014,0x00000000}},	//   _רוצה_, _пољу_, rbúa_,
  { {0x66ca027d,0x7bda0063,0x9c7c3667,0x00000000}},	//   _výko, _מקצו, ničn,
  { {0x27ff005b,0xaa7b0014,0x7d0158b0,0x00000000}},	// [b2a0] ğuna_, rnýt, ools,
  { {0xca4a007e,0x27ff005b,0x33f60fec,0x00000000}},	//   _بلکه_, şuna_, нчес,
  { {0x22460031,0x929d0045,0x213f0150,0x00000000}},	//   tbok_, _skła, _atuh_,
  { {0x7ae658b1,0x9c7c00c2,0x7b3300dd,0x00000000}},	//   nikt, jičn, _răul,
  { {0x27f2001c,0x32650086,0x7656113c,0x00000000}},	//   šanā_, ттєв, mayy,
  { {0x7ae60122,0x22460829,0x66d104aa,0x00000000}},	//   hikt, sbok_, _våke,
  { {0x9c7c01b3,0x929d0022,0x7d0158b2,0x00000000}},	//   fičn, _wkła, dols,
  { {0x69c600ac,0xc7b30063,0x877b0047,0x00000000}},	//   kyke, רבה_, לאצי,
  { {0x929d0051,0x00860002,0xadd4005e,0x00000000}},	//   _ukła, _плао, топљ,
  { {0x23670add,0x2a600150,0x7ae60df9,0x00000000}},	//   šnje_, _adib_, eikt,
  { {0xdeef08a6,0x9c7c303c,0x5ba30121,0x00000000}},	//   _бы_, bičn, гряз,
  { {0x273500c7,0x7ec60003,0x7ae60089,0x00000000}},	//   _rån_, _dépê, gikt,
  { {0x7e7d01a8,0x58870121,0x66ca01d1,0x00000000}},	//   òspe, ныва, _výkl,
  { {0x29050013,0x7d0158b3,0x52bd0042,0x00000000}},	//   ôla_, cols, _ऍक्स,
  { {0xf53f04b1,0x39400150,0x9c7c0124,0x00000000}},	//   _stå_, _etis_, ličo,
  { {0xf1c6001b,0x7ae62cc5,0x7c250114,0x00000000}},	//   _đánh_, cikt, _úhra,
  { {0x6aad0035,0xdce9000c,0xe475005e,0x00000000}},	// [b2b0] _inaf, _înăl, клањ,
  { {0x47352c9e,0x656d0089,0x9c7c4120,0x00000000}},	//   _инос, ruah, zičn,
  { {0x29030009,0x76560150,0x7c3a0139,0x00000000}},	//   moja_, bayy, ictr,
  { {0xddc9000c,0x290300fe,0x68e7006f,0x00000000}},	//   ngeţ, loja_, lijd,
  { {0x9c7c389e,0xd656009a,0xcb14069a,0x00000000}},	//   vičn, _בירת_, אלף_,
  { {0x2903024a,0x68e71a99,0x9c7c027d,0x00000000}},	//   noja_, nijd, dičo,
  { {0x9c7c01a6,0x6aad0162,0x645735bd,0x00000000}},	//   tičn, _onaf, maxi,
  { {0x29030072,0x3dd20022,0x645758b4,0x00000000}},	//   hoja_, _żywa_, laxi,
  { {0x213f014f,0x9c7c3730,0x7d0158b5,0x00000000}},	//   _utuh_, ričn, tols,
  { {0x6aad58b6,0x2d9f0003,0x9c7c4dd2,0x00000000}},	//   _anaf, rvue_, sičn,
  { {0x7d0158b7,0x9c7c027c,0x25a000c2,0x00000000}},	//   rols, pičn, zvil_,
  { {0xdd8e005d,0x7d0158b8,0x9ee90044,0x00000000}},	//   حوی_, sols, _تفصل_,
  { {0x7ae658b9,0x78be00c2,0x7d0158ba,0x00000000}},	//   rikt, _popv, pols,
  { {0x7ae658bb,0x394000c2,0x80b90042,0x00000000}},	//   sikt, _vtis_, ्सटे,
  { {0x66e658bc,0x2fc700a4,0x6d5b0150,0x00000000}},	//   вова, nyng_, lsua,
  { {0x2464003d,0x6e3b58bd,0xe3b2007e,0x00000000}},	//   zīmē_, ncub, یرا_,
  { {0x6d5b58be,0x78be0618,0xe8fa02b6,0x00000000}},	// [b2c0] nsua, _topv, _оли_,
  { {0x6d5b58bf,0xdce0008f,0x04460098,0x00000000}},	//   isua, ormā, тежн,
  { {0x6d5b0089,0xf7460092,0x7ae458c0,0x00000000}},	//   hsua, _шено, _kmit,
  { {0x61460088,0x25ad00c3,0xdce0008f,0x00000000}},	//   веда, _šele_, irmā,
  { {0x28a70042,0xa9ed009a,0x6fb3005d,0x00000000}},	//   खाचि, ּחוֹ, یمها,
  { {0xe04a007e,0x044358c1,0x2fc7002b,0x00000000}},	//   ذشته_, _верн, fyng_,
  { {0x6d5b053b,0x66d10137,0x7ae403e1,0x00000000}},	//   esua, _håka, _omit,
  { {0x68e7006f,0x3da60054,0x7c2d003b,0x00000000}},	//   zijd, вроб, _şarp,
  { {0x127b0047,0x52d70041,0x6282004e,0x00000000}},	//   _קאמע, _סומע_, mfoo,
  { {0x4c940138,0x628200e8,0x7ae458c2,0x00000000}},	//   ћинс, lfoo, _amit,
  { {0x29031efb,0x6d5b58c3,0x9d13000d,0x00000000}},	//   voja_, asua, рдэч,
  { {0x68e70122,0xdb14007a,0x29030051,0x00000000}},	//   wijd, ðaða, woja_,
  { {0x2903024a,0xddc90529,0x68e70122,0x00000000}},	//   toja_, rgeţ, tijd,
  { {0x29034949,0x3cc706da,0x7ae405d1,0x00000000}},	//   uoja_, _илчо_, _emit,
  { {0x68e70122,0x290358c4,0x37070505,0x00000000}},	//   rijd, roja_, вчав,
  { {0x9bb7014e,0x6aad075a,0x8f9b0149,0x00000000}},	//   _יהוה_, _unaf, וילי,
  { {0x2bca0053,0x9634000d,0x6282004b,0x00000000}},	// [b2d0] ानका, рнуц, dfoo,
  { {0x6d5d1079,0xca2a0041,0xe5700021,0x00000000}},	//   ásai, _אופֿ, تطف_,
  { {0xed46007e,0x44271ea9,0x7e620124,0x00000000}},	//   _گپ_, än_, _odop,
  { {0x6d5d003d,0x62821269,0xe8e1008b,0x00000000}},	//   šsai, gfoo, _đột_,
  { {0x20890330,0x6d42003b,0x6f19002b,0x00000000}},	//   ейли_, _ntoa, _rhwc,
  { {0xaf9905c5,0x41040086,0x7e623dcf,0x00000000}},	//   етих_, азів, _adop,
  { {0x2f54000d,0xd00602b6,0x629b0072,0x00000000}},	//   атыс, леше_, _tauo,
  { {0x200c001f,0xdd91013a,0x02a458c5,0x00000000}},	//   _dydi_, موع_, _крум,
  { {0x6e3b58c6,0xa1940002,0xdca50ace,0x00000000}},	//   rcub, _катч, гапи,
  { {0x6e3b0942,0x64551bc3,0x9c7c0734,0x00000000}},	//   scub, _jezi, ličj,
  { {0x7e6e0025,0x6d5b28dc,0xd0110021,0x00000000}},	//   áipé, ssua, _الا_,
  { {0xcf27006a,0xa96a56d3,0xd94658c7,0x00000000}},	//   _شراي, нима_, леми,
  { {0x60c10aba,0xdbc90019,0x527a0047,0x00000000}},	//   _kolm, _rõõm, ענשא,
  { {0x66d10137,0x8d5a0063,0x645558c8,0x00000000}},	//   _råka, _טכני, _nezi,
  { {0x66d10205,0x7bc80051,0xb736005d,0x00000000}},	//   _såka, cydu, افرب,
  { {0x66d10093,0xdb040003,0x00000000,0x00000000}},	//   _påka, _orné,   ,
  { {0x645505df,0x25a60139,0x4e360041,0x00000000}},	// [b2e0] _bezi, íol_, אָבן_,
  { {0x394d003b,0x7794007e,0x645558c9,0x00000000}},	//   ţesc_, _پیرا, _cezi,
  { {0x645558ca,0x78ba0014,0x287b00ff,0x00000000}},	//   _dezi, ötvu, _אנימ,
  { {0x236700ea,0xe1fa38a5,0x4431056c,0x00000000}},	//   ánja_, нге_, _egz_,
  { {0xa0540086,0x21760002,0x20540085,0x00000000}},	//   авлі, ѓудр, акля,
  { {0xa50a0001,0xcf9a0001,0x645558cb,0x00000000}},	//   _чега_, еји_, _gezi,
  { {0x26c2024a,0x60c158cc,0x61fb58cd,0x00000000}},	//   _koko_, _dolm, _exul,
  { {0x26c2187b,0x8fa3005e,0xbec40023,0x00000000}},	//   _joko_, саће, _ņūbr,
  { {0x3d260086,0xb23b0047,0xf65f00d1,0x00000000}},	//   льов, _װעבז, _klær_,
  { {0x859700b5,0x200c001f,0x55970047,0x00000000}},	//   נדיג_, _tydi_, נדיע_,
  { {0xfaf9001c,0xdb1b0072,0x9c7c041f,0x00000000}},	//   krīt_, yytä, ličk,
  { {0x26c258ce,0xdc3c0057,0xbda60067,0x00000000}},	//   _noko_, mšči, _محتو,
  { {0xdc3c00c3,0x6d420035,0x9c7c0743,0x00000000}},	//   lšči, _utoa, ničk,
  { {0x3952002b,0xd0060593,0x4ddb0063,0x00000000}},	//   _dwys_, قل_, _אחדו,
  { {0xdc3c0198,0xbb430635,0x9c7c007d,0x00000000}},	//   nšči, _лејк, hičk,
  { {0x645502f6,0xdc3c00c2,0x501b0063,0x00000000}},	//   _sezi, išči, תולו,
  { {0x5455157c,0xa3dd0042,0x645558cf,0x00000000}},	// [b2f0] иват, _तेज_, _pezi,
  { {0xf53f2ddc,0xdc3c00eb,0xfaf9008f,0x00000000}},	//   _från_, kšči, arīt_,
  { {0x92590055,0xdc3c00c3,0x5c370047,0x00000000}},	//   вает_, jšči, ארבן_,
  { {0x9c7c017f,0xdc3c00c2,0x60c158d0,0x00000000}},	//   fičk, dšči, _solm,
  { {0x66d100d1,0xb465007e,0x764d28bb,0x00000000}},	//   _håko, _نگاه, mbay,
  { {0xf9580063,0x2366008f,0xe057005d,0x00000000}},	//   נסות_, ņoja_, ایات_,
  { {0x7b220003,0x9c7c00c2,0x656d58d1,0x00000000}},	//   _mœur, pičj, lrah,
  { {0x9c7c2024,0x8d654550,0x660f00a5,0x00000000}},	//   bičk, авие, _kyck,
  { {0xdc3c00c2,0x764d0150,0x60c158d2,0x00000000}},	//   ašči, ibay, _tolm,
  { {0x660f01e3,0xdc3c00c3,0x656d0089,0x00000000}},	//   _myck, bšči, irah,
  { {0x660f00c7,0x764d00a4,0x00000000,0x00000000}},	//   _lyck, kbay,   ,
  { {0x2d990146,0xef0e0054,0x3952002b,0x00000000}},	//   æses_, _єм_, _pwys_,
  { {0x660f00c7,0x656d0089,0x19fa000d,0x00000000}},	//   _nyck, jrah, тэнь_,
  { {0x6d490027,0x7c94005a,0x99060001,0x00000000}},	//   mpea, _гръц, ртмa,
  { {0xf6560b3f,0x9c7c027c,0x6d4958d3,0x00000000}},	//   итаю, zičk, lpea,
  { {0x764d00bb,0x6d5d0006,0x6d490072,0x00000000}},	//   gbay, šsau, opea,
  { {0x656d0004,0x7afd00ea,0xceb20063,0x00000000}},	// [b300] grah, érte, חין_,
  { {0x764d58d4,0x6d490025,0x9c7c2904,0x00000000}},	//   abay, ipea, vičk,
  { {0x26c200f3,0xb4db0268,0x656d58d5,0x00000000}},	//   _toko_, _itàl, arah,
  { {0x9c7c0117,0xdc3c00c3,0x93430054,0x00000000}},	//   tičk, všči, інче,
  { {0x67243a7c,0x70560044,0xd1961313,0x00000000}},	//   mmij, لنشا, ршењ,
  { {0x9c7c0117,0xdc3c00c2,0x3f660259,0x00000000}},	//   ričk, tšči, атиб,
  { {0x2f010066,0xdc3c33ae,0x2b060042,0x00000000}},	//   lógy_, ušči, रवाँ_,
  { {0x273c007a,0xbe8a0001,0xdc3c3ff9,0x00000000}},	//   _mín_, тске_, ršči,
  { {0x9c7c4fd8,0x273c0025,0xdc3c00a8,0x00000000}},	//   liči, _lín_, sšči,
  { {0xdc3c00c3,0xccb80086,0xba3b002b,0x00000000}},	//   pšči, угої_, ddïa,
  { {0x764d00bb,0x2d990146,0xdce9005b,0x00000000}},	//   ybay, æser_, steğ,
  { {0x7b220003,0x66d101f2,0xeef50085,0x00000000}},	//   _sœur, _råko, _лячэ,
  { {0x29870085,0x8ca10042,0xdd9000de,0x00000000}},	//   шынг, _कोको, _روث_,
  { {0xa3d60235,0x386d00bd,0x660f58d6,0x00000000}},	//   िना_, ßer_, _ryck,
  { {0x386d01f7,0x66ca0026,0xdce00080,0x00000000}},	//   ğer_, _lýku, zumě,
  { {0x764d00a4,0x96f80001,0xba55005e,0x00000000}},	//   ubay, аест_, _увиј,
  { {0x7d08021f,0xef110047,0x656d0380,0x00000000}},	// [b310] oods, פּל_, urah,
  { {0xb8950032,0x93a70121,0x69ce003b,0x00000000}},	//   _الدع, ишед, âneţ,
  { {0x656d0ff2,0xb5fb004c,0xd2510021,0x00000000}},	//   srah, _zdál, كنا_,
  { {0x236700c3,0x660f00c7,0x569402a1,0x00000000}},	//   šnjo_, _tyck, _дают,
  { {0x471a0063,0x21780121,0x95640062,0x00000000}},	//   _תורג, ийцы_, _мърд,
  { {0x66d801d1,0x6f650044,0x6536009a,0x00000000}},	//   _víke, مهتم, _לאשף_,
  { {0x7d08011b,0xc0c801ce,0x225b0044,0x00000000}},	//   dods, јуче_, _لجذب_,
  { {0x29f80013,0x77f80063,0x62d90085,0x00000000}},	//   ọai_, ימוד_, _ёмаў_,
  { {0x50670021,0x6d490003,0x7b33003b,0x00000000}},	//   _نطاق, upea, _lăut,
  { {0x2ba5003d,0x6724007d,0x7d0858d7,0x00000000}},	//   _pēc_, zmij, gods,
  { {0x6d493e0a,0x66d105a5,0xeb060054,0x00000000}},	//   spea, _påkl, йпоп,
  { {0x6d49171d,0xeec4005d,0xb2b9009d,0x00000000}},	//   ppea, _ويلپ, אמֹר,
  { {0xfe70007e,0x273c0026,0xd1410022,0x00000000}},	//   _زدن_, _sín_, _ująć_,
  { {0x2eed0238,0x7b33003b,0xbbe8007e,0x00000000}},	//   lief_, _băut, اریم_,
  { {0x7b330529,0xb8f00053,0x366a58d8,0x00000000}},	//   _căut, _शव_, лаво_,
  { {0x3ebf003e,0x9c7c58d9,0xa6b50121,0x00000000}},	//   njut_, viči, осущ,
  { {0xb5fb0080,0x672458da,0xf772007e,0x00000000}},	// [b320] _udál, rmij, _کاخ_,
  { {0x273c001b,0x672458db,0xdce916fe,0x00000000}},	//   _tín_, smij, kreč,
  { {0xb3860ace,0x1d160041,0x889b009a,0x00000000}},	//   слел, צקער_, _גביי,
  { {0x9c7c58dc,0x68ee58dd,0x2bf60041,0x00000000}},	//   riči, libd, זמען_,
  { {0xa0a60085,0x52830044,0x00000000,0x00000000}},	//   йадд, سلوك,   ,
  { {0x26c0007d,0x9c7c00a8,0x1543242b,0x00000000}},	//   ljio_, piči, _херм,
  { {0x645e58de,0x65760072,0x7d081058,0x00000000}},	//   mapi, luyh, vods,
  { {0x2eed021f,0x645e58df,0xe29a0062,0x00000000}},	//   gief_, lapi, _щаб_,
  { {0x290a0c61,0x7cd8182e,0xe1fa0085,0x00000000}},	//   koba_, имир_, _сга_,
  { {0x645e15c4,0xf36a009a,0x459b009a,0x00000000}},	//   napi, ְדָּ, נסיע,
  { {0x8afd0022,0x6d5d0014,0x9f63006c,0x00000000}},	//   kręt, ásar, évôt_,
  { {0x3f9e399c,0x645e58e0,0xed5a0141,0x00000000}},	//   _istu_, hapi, _бод_,
  { {0x645e58e1,0x09e40085,0x7d080195,0x00000000}},	//   kapi, зоўн, pods,
  { {0x645e0bda,0xdca31f1d,0x7d7b016e,0x00000000}},	//   japi, _начи, _ענוו,
  { {0xccf80080,0x2d84005b,0x645e0d52,0x00000000}},	//   mně_, ltme_, dapi,
  { {0xccf80080,0x645e005f,0x1bf7009a,0x00000000}},	//   lně_, eapi, _לצור_,
  { {0x634500eb,0x09e4005e,0x67280003,0x00000000}},	// [b330] _mėne, _ноћн, ïdja,
  { {0x645e00bb,0xccf80080,0x3f9e0019,0x00000000}},	//   gapi, nně_, _ostu_,
  { {0x16350076,0xe4c40121,0x2d84004b,0x00000000}},	//   _меня, чётн, htme_,
  { {0xdce93319,0x7aef58e2,0xdb7b0041,0x00000000}},	//   vreč, nict, רנאכ,
  { {0x3f9e58e3,0x416b005e,0xccf8004c,0x00000000}},	//   _astu_, ујем_, kně_,
  { {0x661d003d,0xccf80080,0x9fc90184,0x00000000}},	//   _izsk, jně_, игла_,
  { {0xccf80080,0x2eed0ac8,0xff2501d5,0x00000000}},	//   dně_, tief_, омко,
  { {0xee390c8d,0xef190141,0x63b401c8,0x00000000}},	//   шни_, јми_, šený,
  { {0x66d10031,0x25a90162,0xdce900c3,0x00000000}},	//   _påkj, nval_, sreč,
  { {0x2eed016d,0xdce9082a,0x2a690089,0x00000000}},	//   sief_, preč, _adab_,
  { {0x3949014f,0x66d80026,0x7aef09fe,0x00000000}},	//   _atas_, _líka, fict,
  { {0xeb960055,0xc9aa000a,0x3b0a0086,0x00000000}},	//   цию_, авме_, ремо_,
  { {0xdd940088,0xccf80080,0x4426008b,0x00000000}},	//   _нацы, bně_, ̀o_,
  { {0x26d90359,0xccf80080,0x6efe001c,0x00000000}},	//   _also_, cně_, mība,
  { {0x6efe001c,0x25a907f3,0x645e58e4,0x00000000}},	//   lība, eval_, vapi,
  { {0x7e7b4ce6,0x25a900ca,0xa6860085,0x00000000}},	//   ngup, fval_, ўлад,
  { {0x0566019d,0x6efe001c,0x959a005e,0x00000000}},	// [b340] юван, nība, штву_,
  { {0xdb2100fe,0x6aa458e5,0xd46a0121,0x00000000}},	//   ätök, _haif, риже_,
  { {0x39840ede,0x645e3631,0x25a958e6,0x00000000}},	//   lös_, rapi, aval_,
  { {0xccf80080,0x673a00ea,0x645e3029,0x00000000}},	//   zně_, ítju, sapi,
  { {0xccf80080,0x398458e7,0x76430022,0x00000000}},	//   yně_, nös_, śnyc,
  { {0x6efe001c,0x3d030053,0x3cf50053,0x00000000}},	//   dība, रकों_, ीकों_,
  { {0xccf80080,0xc0590088,0x444458e8,0x00000000}},	//   vně_, сіі_, mc_,
  { {0x645c58e9,0x5d540601,0xeeb8080b,0x00000000}},	//   _heri, пкит, слиш_,
  { {0xccf80080,0x645c4628,0x7aef106e,0x00000000}},	//   tně_, _keri, vict,
  { {0x8cf30088,0x645c0ff0,0xa5b70063,0x00000000}},	//   дзьц, _jeri, קליק_,
  { {0xccf80080,0x444458ea,0xd00a005e,0x00000000}},	//   rně_, ic_, _теже_,
  { {0xccf80080,0x9c7c00c3,0x6efe001c,0x00000000}},	//   sně_, viču, bība,
  { {0xccf80080,0x6efe001c,0x7e6058eb,0x00000000}},	//   pně_, cība, mamp,
  { {0x7e60204d,0x645c58ec,0x9c7c007c,0x00000000}},	//   lamp, _neri, tiču,
  { {0x7aef0034,0x65640089,0x444458ed,0x00000000}},	//   pict, esih, dc_,
  { {0xf7700021,0x6aa4001f,0x7e6016b0,0x00000000}},	//   ضاف_, _gaif, namp,
  { {0x645c58ee,0x7aed58ef,0x61e2013d,0x00000000}},	// [b350] _beri, _imat, jzol,
  { {0x645c2657,0x0d150047,0x25a958f0,0x00000000}},	//   _ceri, ִקײט_, rval_,
  { {0x6efe001c,0x25a90504,0x7e600f8c,0x00000000}},	//   zība, sval_, kamp,
  { {0x44443ae2,0xf77207e9,0x7e600078,0x00000000}},	//   ac_, _אקט_, jamp,
  { {0x661d003d,0x27ff01f7,0x7e6058f1,0x00000000}},	//   _uzsk, ğunu_, damp,
  { {0x8505006a,0xcf59005a,0x27ff005b,0x00000000}},	//   _روزن, брич_, şunu_,
  { {0xd343007e,0x765d1c1e,0x398400ea,0x00000000}},	//   _آفری, _kesy, zös_,
  { {0x398400fe,0x6efe001c,0x92b70021,0x00000000}},	//   yös_, tība, _بحسا,
  { {0x765d00e3,0x645c01f7,0x6299201a,0x00000000}},	//   _mesy, _yeri, mewo,
  { {0x6aa40397,0x6efe001c,0x753d58f2,0x00000000}},	//   _saif, rība, _musz,
  { {0x6efe003d,0x64450791,0xeb990154,0x00000000}},	//   sība, ichi, щин_,
  { {0x6efe003d,0x7e6058f3,0x398458f4,0x00000000}},	//   lībn, camp, tös_,
  { {0x9c7c004c,0xdb0f013d,0xec6e1bd9,0x00000000}},	//   tičt, ójáv, _пп_,
  { {0x17fa0021,0x753558f5,0x7aed58f6,0x00000000}},	//   مرأة_, _nizz, _emat,
  { {0x61e24fe4,0x753d13ac,0x645c0917,0x00000000}},	//   zzol, _ausz, _reri,
  { {0x3b07011c,0x6445531d,0x62990051,0x00000000}},	//   _нещо_, echi, jewo,
  { {0x645c4339,0xdcfb003b,0x66d80014,0x00000000}},	// [b360] _peri, ctuă, _fíkn,
  { {0x6564053b,0x753d0051,0x3f87007d,0x00000000}},	//   rsih, _dusz, ktnu_,
  { {0x765d00e3,0x7aed0185,0x444458f7,0x00000000}},	//   _fesy, _ymat, rc_,
  { {0x444436e6,0x644558f8,0xd7bb0063,0x00000000}},	//   sc_, achi, _הצטר,
  { {0xa9280006,0x60c82f56,0x444401f4,0x00000000}},	//   pažį, _podm, pc_,
  { {0x644502f6,0x7e600a9f,0xe4da007e,0x00000000}},	//   cchi, wamp, _اوست_,
  { {0x61e2000f,0x6d4b58f9,0x083b0047,0x00000000}},	//   szol, _atga, זעצל,
  { {0xbdb4005e,0x6f04007d,0x62990168,0x00000000}},	//   дбиј, čico, cewo,
  { {0x7e601324,0xa06a3c48,0xa11614d7,0x00000000}},	//   ramp, _газа_, _فورت,
  { {0x7aed0117,0x7e60014f,0xa0c90032,0x00000000}},	//   _smat, samp, _وذلك_,
  { {0x78a50004,0x692100dd,0xeb970131,0x00000000}},	//   _rahv, nţeş, пиќ_,
  { {0x3a2001a8,0x2f3b0063,0xdee308b9,0x00000000}},	//   _bzip_, _הגאד, _похи,
  { {0xf2d300b5,0x765d001f,0x2d960086,0x00000000}},	//   גער_, _resy, _хрес,
  { {0x3d140053,0x62990051,0x2367027c,0x00000000}},	//   _नीचे_, zewo, šnji_,
  { {0x78a5024a,0x753558fa,0xc66b000d,0x00000000}},	//   _vahv, _rizz, йшае_,
  { {0xabfb0063,0x753d1504,0x7aed0859,0x00000000}},	//   _להור, _pusz, _umat,
  { {0x644558fb,0x7afd0137,0x3a2014b0,0x00000000}},	// [b370] tchi, mnst, _gzip_,
  { {0xda07007e,0x3ea600a4,0x3f87004c,0x00000000}},	//   _ويژه_, _laot_, ytnu_,
  { {0xaa7b027d,0x629912a9,0x7afe1a77,0x00000000}},	//   chýc, tewo, čstv,
  { {0x7afd58fc,0xdb0406a5,0x64452e91,0x00000000}},	//   nnst, _ernæ, schi,
  { {0x628b006f,0x64450d17,0x35a4000d,0x00000000}},	//   rfgo, pchi, _заўг,
  { {0x66d80026,0x7afd58fd,0x6e39002b,0x00000000}},	//   _líkl, hnst, _sgwb,
  { {0xdb2400ea,0x43940785,0xb4fb0042,0x00000000}},	//   őség, _парс, ्वीप_,
  { {0xe7dc0063,0xdce200c2,0x7afd1df9,0x00000000}},	//   מקוש, _dvoč, jnst,
  { {0xc3320047,0x3f871536,0x6d250131,0x00000000}},	//   _יול_, stnu_, мдиз,
  { {0xd13104de,0x7afd1466,0xa91b0026,0x00000000}},	//   _شما_, enst, stþj,
  { {0xe452009d,0x00000000,0x00000000,0x00000000}},	//   כֶר_,   ,   ,
  { {0xc869014e,0x7afd54bf,0xdb1b0022,0x00000000}},	//   _כן_, gnst, dytó,
  { {0x6d4b02fb,0xdce200c3,0xc956014b,0x00000000}},	//   _utga, _zvoč, ьтны,
  { {0x225f006f,0x7afd58fe,0xe73a02b6,0x00000000}},	//   _leuk_, anst, жев_,
  { {0xaa7b004c,0x9736014b,0x00000000,0x00000000}},	//   uhýc, дэач,   ,
  { {0xdb08004b,0x26cb124c,0x2ca702ce,0x00000000}},	//   öläh, _coco_, _hand_,
  { {0x09060086,0x612401a8,0x2ca71778,0x00000000}},	// [b380] _опин, lòle, _kand_,
  { {0xa5bb000f,0x00000000,0x00000000,0x00000000}},	//   _szóc,   ,   ,
  { {0x33d50088,0x2ca710c4,0x39400162,0x00000000}},	//   ніцт, _mand_, _huis_,
  { {0x39401848,0xab620058,0x2ca758ff,0x00000000}},	//   _kuis_, _şükr, _land_,
  { {0xddc20024,0x394000ac,0xa158007f,0x00000000}},	//   _odoš, _juis_, чалу_,
  { {0x39400250,0x2ca75900,0x2a6002d2,0x00000000}},	//   _muis_, _nand_, _leib_,
  { {0x39401a2b,0x25a00150,0xdce0008f,0x00000000}},	//   _luis_, lwil_, zumē,
  { {0x2ca700e8,0xbd6a0076,0x932601f3,0x00000000}},	//   _aand_, орое_, _آرسن,
  { {0x1d340062,0x66d80066,0xf1aa005d,0x00000000}},	//   нния, _ríkl, _بازه_,
  { {0x2ca75901,0x7afd0c4c,0x3b545902,0x00000000}},	//   _cand_, wnst, нкор,
  { {0xc4770063,0xdfa60021,0x25a0002b,0x00000000}},	//   ותיו_, _تحذي, hwil_,
  { {0x2bac0080,0x394000a1,0x25a000a4,0x00000000}},	//   _věc_, _buis_, kwil_,
  { {0x2ca7330b,0xb5fb0139,0x588705ac,0x00000000}},	//   _fand_, _meác, мыва,
  { {0x6e2208ea,0xa803005b,0xdfc60021,0x00000000}},	//   _izob, _çıkm, هي_,
  { {0x26cb5903,0x612400cd,0x56950769,0x00000000}},	//   _poco_, còle, навт,
  { {0x2ca709fe,0x7d1a0137,0xfa900013,0x00000000}},	//   _zand_, llts, _hẫng_,
  { {0x66d80014,0x44b5183e,0xd83b05ac,0x00000000}},	// [b390] _kíkj, нбас, _мэн_,
  { {0xdb0400bd,0xd1380051,0x98550054,0x00000000}},	//   _ernä, _nią_, _якої,
  { {0x68f5005b,0x691200b9,0x29115904,0x00000000}},	//   mizd, pæer, moza_,
  { {0x22580121,0x9327005d,0x66d80046,0x00000000}},	//   дицы_, ذران, _líkj,
  { {0x21670121,0x6d46004c,0x8234005d,0x00000000}},	//   фтег, íkal, نرها,
  { {0x68f501f7,0x64580014,0x29115905,0x00000000}},	//   nizd, ðvit, noza_,
  { {0x38610199,0x2ca72d75,0xbf640044,0x00000000}},	//   _mehr_, _rand_, نديو,
  { {0xf83801f9,0x7b160460,0x7fe80021,0x00000000}},	//   ונות_, náut, ظروف_,
  { {0x2ca7338b,0xf53f02fd,0x29115906,0x00000000}},	//   _pand_, _gråt_, koza_,
  { {0x2367017f,0x612400cd,0x81c2008f,0x00000000}},	//   šnju_, tòle, ķēta,
  { {0x39400164,0x2ca710c4,0x02f30042,0x00000000}},	//   _suis_, _vand_, _आगाह_,
  { {0x394003b2,0xdd8e007e,0x612400cd,0x00000000}},	//   _puis_, جوی_, ròle,
  { {0x39400016,0xe9df01a8,0x2ca75907,0x00000000}},	//   _quis_, scún_, _tand_,
  { {0x2a60004d,0x29115908,0x672d5909,0x00000000}},	//   _weib_, goza_, emaj,
  { {0x25a00150,0x6f1b590a,0xd7060cf7,0x00000000}},	//   wwil_, oluc, езви,
  { {0x394000e8,0x63a20045,0xab27005a,0x00000000}},	//   _tuis_, łonk, _поща_,
  { {0xb5fb0025,0xb9c60021,0xe6e00053,0x00000000}},	// [b3a0] _reác, _ستظه, _नतीज,
  { {0x6f1b004d,0xb5fb013d,0x672d590b,0x00000000}},	//   hluc, _adás, amaj,
  { {0x6576024a,0x6f1b0045,0xa34a0054,0x00000000}},	//   sryh, kluc, їзда_,
  { {0xc7b30063,0x01663a82,0x66e60094,0x00000000}},	//   _עבר_, екдо, _чома,
  { {0xc69300b5,0x7b1605d5,0xe635014b,0x00000000}},	//   _גאר_, láus, _ахрэ,
  { {0x60180062,0x24560021,0xd0d70054,0x00000000}},	//   моля_, _سنرس, ндії_,
  { {0xe296000a,0x66d80026,0x6e2200ea,0x00000000}},	//   _праќ, _ríkj, _szob,
  { {0x23890080,0x8fa30002,0x9326005d,0x00000000}},	//   žují_, ѓање, _سرزن,
  { {0xfe6f0021,0x5275007b,0xb5fb0066,0x00000000}},	//   حدى_, _јусу, _udát,
  { {0x4c94005e,0xa5bb0124,0x2dd70044,0x00000000}},	//   њинс, _ozón, عبية_,
  { {0x2911074f,0x6f020137,0x3e7a005b,0x00000000}},	//   voza_, _tjoc, gütü_,
  { {0x38610199,0x6282590c,0x93fb009a,0x00000000}},	//   _sehr_, ngoo, לליי,
  { {0xba3b0268,0x4dd3013a,0x38611fdb,0x00000000}},	//   veïd, _متوس, _pehr_,
  { {0x7c2b0014,0xddc90260,0xc211009a,0x00000000}},	//   ámrö, dceň, ׁ֔ם_,
  { {0xed35000d,0x69c00072,0xab61004b,0x00000000}},	//   _рэцэ, ämer, üüte,
  { {0xf5e70454,0x7e62581a,0x38610206,0x00000000}},	//   нізм, _jeop, _wehr_,
  { {0x95cb00d7,0x9635000d,0x6f04004c,0x00000000}},	// [b3b0] чува_, тнац, čich,
  { {0x9964005a,0x672d590d,0x7e624c8e,0x00000000}},	//   _стъл, smaj, _leop,
  { {0xd2510021,0xdcfb007d,0x28b00042,0x00000000}},	//   لنا_, stuć, फ़ारि,
  { {0x628200e8,0x7e62081a,0x64580014,0x00000000}},	//   ggoo, _neop, ðvir,
  { {0x6f1b590e,0x6d5d008f,0xe0ce3cf5,0x00000000}},	//   vluc, šsaz, ав_,
  { {0x26c90130,0xf994009d,0x00000000,0x00000000}},	//   ljao_, ררס_,   ,
  { {0xbea5005a,0xc4d20063,0x6f1b0130,0x00000000}},	//   вайк, _דגם_, tluc,
  { {0x26c9007d,0xa9a60047,0x6f1b0075,0x00000000}},	//   njao_, ופּעס_, uluc,
  { {0x7e62003b,0x6f1b0f89,0x8e090054,0x00000000}},	//   _deop, rluc, ьнив_,
  { {0x7ce400cd,0x63b50734,0x3eb8008f,0x00000000}},	//   _nòrd, _krzn, ērta_,
  { {0x2d980529,0x3b0a0f0a,0x7c940085,0x00000000}},	//   ărea_, дено_, урыц,
  { {0xdce9017f,0xf4120063,0xa96a0001,0x00000000}},	//   kreć, שפט_, мима_,
  { {0x4e780021,0xdbde590f,0xa5bb013d,0x00000000}},	//   _أحمد_, síða, _szón,
  { {0x3ead10eb,0x7ce400cd,0x7e620089,0x00000000}},	//   ldet_, _còrd, _zeop,
  { {0xb90a0053,0xdce90130,0x3ead5910,0x00000000}},	//   _मत_, ereć, odet_,
  { {0x3ead5911,0x66d80046,0x00000000,0x00000000}},	//   ndet_, _kíki,   ,
  { {0xba3b00e8,0x04460001,0x66d105dd,0x00000000}},	// [b3c0] teïe, везн, _påkr,
  { {0x3ead00fe,0xe8f709b3,0xb97b2177,0x00000000}},	//   hdet_, _аль_, _קניי,
  { {0x316d03b2,0x18770063,0x9479000d,0x00000000}},	//   _avez_, _בעיר_, эсту_,
  { {0x3ead0146,0x63b5085a,0x2bc20042,0x00000000}},	//   jdet_, _drzn, षमता,
  { {0x64430006,0x3ead0a57,0x7e6200e5,0x00000000}},	//   žnia, ddet_, _reop,
  { {0x224d00f3,0x2d8d0019,0x7e620150,0x00000000}},	//   _efek_, dtee_, _seop,
  { {0x7e620037,0x7416006a,0x673b027d,0x00000000}},	//   _peop, _شورا, ňuje,
  { {0xb5fb0025,0x200000dd,0x00000000,0x00000000}},	//   _meán, ăii_,   ,
  { {0x6ce6000d,0x7e62004b,0xfe79004c,0x00000000}},	//   віне, _veop, chům_,
  { {0x9b580079,0x8f760086,0x3ead004e,0x00000000}},	//   ниот_, _ауді, adet_,
  { {0x316d00c3,0xd10f0042,0xfb350121,0x00000000}},	//   _zvez_, िवरण_, лноэ,
  { {0xf4130063,0x8c3c0058,0xaa7b0061,0x00000000}},	//   יפת_, değe, chýl,
  { {0x7e7d0460,0x644e0014,0xac94005e,0x00000000}},	//   óspe, _ofbi, _балш,
  { {0x0d970063,0xfd0f007e,0xdce6001c,0x00000000}},	//   _סכום_, _وجو_, ēmēj,
  { {0xd7f80076,0xd7f4082d,0xb717005d,0x00000000}},	//   вут_, азры, نظرت,
  { {0xdce000eb,0x644e314d,0xdce9007d,0x00000000}},	//   tumė, _afbi, treć,
  { {0x35b5000d,0xa5f83d47,0xe66400d9,0x00000000}},	// [b3d0] ыбар, вету_, ртсо,
  { {0xfaf9008f,0x0519005d,0x54540054,0x00000000}},	//   asīt_, رياب_, ивут,
  { {0xdce9017f,0x3ae20026,0x67d50002,0x00000000}},	//   sreć, _hópa_, _сону,
  { {0x6aad5912,0xa6db0014,0x02f00058,0x00000000}},	//   _jaaf, _siðf, _üçlü_,
  { {0x3ead5913,0x6aad5914,0x26de008f,0x00000000}},	//   vdet_, _maaf, ītot_,
  { {0x89dc014e,0x66d80026,0x20540062,0x00000000}},	//   וחדי, _ríki, атър,
  { {0x9388018e,0xa6db0014,0xd347005d,0x00000000}},	//   _иста_, _viðf, _شیشه_,
  { {0x2d8d0034,0x3ead0bb7,0x63b800b9,0x00000000}},	//   ttee_, udet_, ævne,
  { {0x656d0273,0x673d00c0,0x6234000a,0x00000000}},	//   nsah, _misj, _вету,
  { {0x2903007d,0xdca5005e,0x3e730013,0x00000000}},	//   jnja_, ћани, ợt_,
  { {0xa5bb00ea,0x2903065f,0x9f5502b1,0x00000000}},	//   _szól, dnja_, _свеч,
  { {0x673d00d1,0xf8a9009a,0xe1e714d7,0x00000000}},	//   _nisj, _מש_, مس_,
  { {0xbebd001c,0xb5fb0139,0xaa7b0195,0x00000000}},	//   elūg, _seán, chým,
  { {0xd9431a5c,0x6bd500de,0xcdb6009d,0x00000000}},	//   сери, _متبر, _תפסה_,
  { {0x37e30156,0x66e63e30,0x6fb30053,0x00000000}},	//   борг, гова, ंटिं,
  { {0x673d2cb6,0xb4db1c56,0x6b813f90,0x00000000}},	//   _cisj, _quàn, mulg,
  { {0x7ae40009,0xd7070076,0x656d00a4,0x00000000}},	// [b3e0] _ilit, унте_, gsah,
  { {0x661d0045,0x7afd00ea,0x05770021,0x00000000}},	//   _dysk, értv, املة_,
  { {0x2b4f0529,0x656d002c,0x753c001c,0x00000000}},	//   _încă_, asah, _virz,
  { {0xf1c5001b,0x26de001c,0x656d004a,0x00000000}},	//   _trợ_, ītos_, bsah,
  { {0x6b811255,0x31760002,0x26de008f,0x00000000}},	//   hulg, уѓет, ūtos_,
  { {0xf9930063,0x7ae427eb,0xbfaa1159,0x00000000}},	//   צרו_, _llit, етие_,
  { {0xb5fb00ea,0xe7f90053,0x661d0051,0x00000000}},	//   _leál, ृपया_, _zysk,
  { {0x62890139,0xa6db0014,0x2903007d,0x00000000}},	//   _gceo, _viðg, znja_,
  { {0xa2065915,0xf1a9005d,0xbebd005f,0x00000000}},	//   _спад, _لاله_, emūs,
  { {0x90d5001b,0x7ae45916,0x764d30df,0x00000000}},	//   _hìn, _alit, zcay,
  { {0x7ae41b46,0xf1b90024,0x447b0047,0x00000000}},	//   _blit, _vyše_, ענטע,
  { {0xb5fb000f,0xc987065b,0xd437016e,0x00000000}},	//   _beál, луги, טריק_,
  { {0x90d5008b,0x8d562e2f,0x7ae40139,0x00000000}},	//   _mìn, _стеч, _dlit,
  { {0x661d00c7,0x6b815917,0x7ae43687,0x00000000}},	//   _rysk, bulg, _elit,
  { {0x2903074f,0x66d80026,0x6aad0b54,0x00000000}},	//   rnja_, _líku, _taaf,
  { {0xdce0008f,0x7ae45918,0x29030130,0x00000000}},	//   kumī, _glit, snja_,
  { {0x764d191e,0x9f470024,0x656d2323,0x00000000}},	// [b3f0] rcay, rzné_, usah,
  { {0x656d2b3c,0x764d0c56,0x661d5919,0x00000000}},	//   rsah, scay, _vysk,
  { {0x7ae400fe,0x90d5008b,0x44270137,0x00000000}},	//   _ylit, _bìn, ån_,
  { {0x51550086,0x661d06a3,0xa2950086,0x00000000}},	//   атку, _tysk, раді,
  { {0x213e0027,0xe135000d,0x7bda00a3,0x00000000}},	//   _bith_, анды, hytu,
  { {0x6ae20053,0xa156005e,0xe4e40054,0x00000000}},	//   _पत्र, шаљу_, _лісн,
  { {0x8cc80042,0x00000000,0x00000000,0x00000000}},	//   ़ानो,   ,   ,
  { {0xfe450079,0x6b813ec7,0x2d954dbe,0x00000000}},	//   шнио, vulg, арос,
  { {0x60870021,0x51870259,0x26b60063,0x00000000}},	//   _مشاك, _љуба, בִים_,
  { {0xf1b90078,0x7ae4591a,0xb5fb0167,0x00000000}},	//   _irš_, _slit, _reál,
  { {0x66d80026,0xfd4c008d,0xa6db0014,0x00000000}},	//   _kíkt, _khiễ, _miðb,
  { {0x4e190076,0xde590086,0xa3b60053,0x00000000}},	//   _июля_, _раді_, जित_,
  { {0xd9460098,0x08d60085,0xadbc014b,0x00000000}},	//   реги, ацвя, _пацi,
  { {0xcc89006a,0x6e26013d,0x271e0042,0x00000000}},	//   _شنبه_, ükbe, पत्र_,
  { {0x366a0a36,0xbebd0a10,0xacfa009a,0x00000000}},	//   каво_, plūd, _בהסכ,
  { {0x7ae43c32,0xfd4c008b,0x29d80066,0x00000000}},	//   _ulit, _nhiễ, eľať_,

  { {0x3eaf0d19,0xd5470121,0x90d5008d,0x00000000}},	// [b400] _magt_, ипте_, _rìn,
  { {0x3eaf583b,0xdb0b004d,0x8456005e,0x00000000}},	//   _lagt_, _erfä, рњач,
  { {0x213e0025,0xa87b0165,0x287b00ff,0x00000000}},	//   _rith_, _באיר, _בנימ,
  { {0x2918591b,0xa69600e1,0xeb960047,0x00000000}},	//   lora_, _трој, ידער_,
  { {0xaa7b0080,0xdce90d77,0x7bda0022,0x00000000}},	//   lkýc, eseč, zytu,
  { {0xa6db007a,0x291813b3,0x79b70063,0x00000000}},	//   _viðe, nora_, ילנד_,
  { {0x90d5001b,0x4ea6076f,0x68fc004b,0x00000000}},	//   _tìn, арпа, iird,
  { {0x213e03e9,0xba3b00ac,0x291858be,0x00000000}},	//   _with_, deïn, hora_,
  { {0xbd870021,0x68fc005b,0xf1b900a8,0x00000000}},	//   لنين_, kird, _grš_,
  { {0x291814de,0x7bda1265,0xa5bb00ea,0x00000000}},	//   jora_, tytu, _szók,
  { {0x26c200fe,0x29180b16,0x68fc005b,0x00000000}},	//   _onko_, dora_, dird,
  { {0x1959007f,0xe57f008f,0x7bda0d07,0x00000000}},	//   ламы_, ņķis_, rytu,
  { {0x28c30053,0x7bda0078,0x2918209c,0x00000000}},	//   शालि, sytu, fora_,
  { {0x2918591c,0xd0060021,0x68fc591d,0x00000000}},	//   gora_, كل_, gird,
  { {0xbb840021,0x3ea400ca,0xdcfb0058,0x00000000}},	//   _العي, oemt_, ltuğ,
  { {0x8f9b0063,0x7c3b009a,0xdc3b009a,0x00000000}},	//   כילי, _בתוס, _בעור,
  { {0xb9950021,0x09e40001,0x2d84003b,0x00000000}},	// [b410] _الخب, _моћн, nume_,
  { {0x291802f6,0x2d8401f4,0x69dd0066,0x00000000}},	//   cora_, iume_, myse,
  { {0x7afd024a,0xa6db007a,0x92590076,0x00000000}},	//   oist, _viðb, гает_,
  { {0x7b1d006d,0x2d84004b,0xb0620072,0x00000000}},	//   céut, kume_, äänk,
  { {0x2d8418d7,0xdcb10013,0x7afd0656,0x00000000}},	//   jume_, hỏa_, iist,
  { {0x3ea400ca,0xd0090caa,0x3eaf591e,0x00000000}},	//   eemt_, леле_, _sagt_,
  { {0x3949591f,0xc0780086,0x3eaf00b9,0x00000000}},	//   _luas_, рсії_, _pagt_,
  { {0x69dd00fe,0x291814ba,0x7afd5920,0x00000000}},	//   kyse, zora_, jist,
  { {0x25a90ef2,0x3eaf35c5,0x442a00c2,0x00000000}},	//   nwal_, _vagt_, _zzb_,
  { {0x50db0053,0x98aa003b,0x2b470139,0x00000000}},	//   _भविष, imbă_, _punc_,
  { {0xeb990001,0x7f840021,0x29185921,0x00000000}},	//   ћим_, _ولكن, vora_,
  { {0x39490150,0x239a0047,0x2d845922,0x00000000}},	//   _buas_, נברײ, bume_,
  { {0x68fc005b,0x2b400050,0x59750085,0x00000000}},	//   tird, _viic_, жысу,
  { {0x394903d9,0xaa7b0024,0x6443017f,0x00000000}},	//   _duas_, tkýc, žnij,
  { {0x2ca55923,0xe0d20047,0x7afd5924,0x00000000}},	//   meld_, הײם_, bist,
  { {0x9879003d,0x69dd001f,0x29185925,0x00000000}},	//   kšķu_, byse, sora_,
  { {0x63450006,0xaa7b0114,0x9fa20014,0x00000000}},	// [b420] _mėnu, skýc, _líða_,
  { {0x37e6005e,0x2ca500ca,0x88863f17,0x00000000}},	//   _гоог, neld_, _улож,
  { {0x7b1d006d,0x6aa60229,0xf7720021,0x00000000}},	//   péut, oekf, _عاد_,
  { {0xa2940086,0x2ca55926,0x6d5b017e,0x00000000}},	//   іалі, held_, kpua,
  { {0x2ca502b0,0x6724006f,0x2b91008b,0x00000000}},	//   keld_, mlij, hác_,
  { {0x9fa20026,0x672455aa,0x2ca5069f,0x00000000}},	//   _bíða_, llij, jeld_,
  { {0xcd790047,0x2249007d,0x67242af9,0x00000000}},	//   _שפּראַ, žaka_, olij,
  { {0x67244973,0x7ce400cd,0x2d845927,0x00000000}},	//   nlij, _còrn, tume_,
  { {0x6d5b00bb,0x2ca53643,0x3ea406a5,0x00000000}},	//   gpua, feld_, remt_,
  { {0xa6db007a,0x39495928,0x2a69004b,0x00000000}},	//   _miða, _ruas_, _seab_,
  { {0x2a690004,0x39494ecf,0x74c90053,0x00000000}},	//   _peab_, _suas_, रातः,
  { {0x39490397,0xbb930076,0x7afd4184,0x00000000}},	//   _puas_, чающ, uist,
  { {0x2ca5006f,0x67244245,0x7afd5929,0x00000000}},	//   beld_, dlij, rist,
  { {0x1d07000a,0xadb7007e,0x6724592a,0x00000000}},	//   _лечи_, _دهها_, elij,
  { {0x644303f5,0x2a690019,0x7afd592b,0x00000000}},	//   žnik, _teab_, pist,
  { {0x25a9002c,0x3949017d,0x387f005b,0x00000000}},	//   twal_, _tuas_, şur_,
  { {0x8627000d,0xfaff0104,0xf8ae007e,0x00000000}},	// [b430] сьве, mië_, رکی_,
  { {0xf9900032,0xfaff0173,0x6724592c,0x00000000}},	//   _أبي_, lië_, alij,
  { {0x7d08592d,0x25a900a4,0xb5fb0025,0x00000000}},	//   inds, swal_, _meái,
  { {0xfaff0162,0x326b0021,0x7d1a592e,0x00000000}},	//   nië_, احاً_, hots,
  { {0x9f470080,0x9fa20026,0xdd86007e,0x00000000}},	//   rzní_, _síða_, _تو_,
  { {0x7bc50026,0x4f79005a,0x2f55592f,0x00000000}},	//   _áhug, ащия_, отис,
  { {0xfaff00ac,0x2ca53349,0xdb0b0e7c,0x00000000}},	//   kië_, veld_, _esfé,
  { {0x7d080d11,0x2ca55930,0x9fa20014,0x00000000}},	//   ends, weld_, _víða_,
  { {0x2ca53349,0xfaff0250,0x533404ef,0x00000000}},	//   teld_, dië_, _хетт,
  { {0x6d5b0397,0x6724007d,0x3cfe004b,0x00000000}},	//   rpua, zlij, gitv_,
  { {0x2ca504c6,0x7ced00cd,0xeb994961,0x00000000}},	//   reld_, _lúrg, шин_,
  { {0x3f87005b,0x3af6000d,0x628b58eb,0x00000000}},	//   munu_, іянс, nggo,
  { {0x7d1a5931,0x2ca5006f,0x6f1b22b6,0x00000000}},	//   bots, peld_, mouc,
  { {0x2bb7008d,0x18670320,0x290c004b,0x00000000}},	//   _tăc_, жари_, õda_,
  { {0x672446c4,0xfaff0250,0x3f87005b,0x00000000}},	//   tlij, bië_, nunu_,
  { {0x6d4b0009,0x6d435932,0x7c3e027d,0x00000000}},	//   _kuga, _hina, _úpra,
  { {0x672402b0,0x6d43053a,0x7e6b00ea,0x00000000}},	// [b440] rlij, _kina, _megp,
  { {0x672444d8,0x6d435933,0xa6db0014,0x00000000}},	//   slij, _jina, _viða,
  { {0x6d4b5934,0x6d434430,0x67245935,0x00000000}},	//   _luga, _mina, plij,
  { {0xdcfb0117,0x6d4326b2,0x6d590051,0x00000000}},	//   druč, _lina, _otwa,
  { {0x6f1b0080,0x7d080026,0x7c2300b9,0x00000000}},	//   douc, ynds, _lynr,
  { {0xfaff006f,0x6d435936,0x60f715ce,0x00000000}},	//   zië_, _nina, онія_,
  { {0xba3b00cd,0xa6db0026,0x6d4b5937,0x00000000}},	//   veïm, _miðn, _auga,
  { {0xdce9017f,0x6d4b5938,0x6d435939,0x00000000}},	//   dređ, _buga, _aina,
  { {0xfaff006f,0x612400cd,0x3f87001c,0x00000000}},	//   vië_, hòli, aunu_,
  { {0x7d08593a,0xfaff00ac,0x3f87593b,0x00000000}},	//   unds, wië_, bunu_,
  { {0x6d5900bd,0x7d1a0019,0x7c23001f,0x00000000}},	//   _etwa, rots, _cynr,
  { {0x6d43593c,0x7d1a0ff2,0x6f1b066d,0x00000000}},	//   _eina, sots, couc,
  { {0xfaff0162,0x5a44000d,0x09e4000d,0x00000000}},	//   rië_, дэра, доўн,
  { {0x6d4300bb,0xfaff0250,0x7ced0025,0x00000000}},	//   _gina, sië_, _cúrd,
  { {0x6d4b00bd,0x7c23001f,0xd66b018e,0x00000000}},	//   _zuga, _gynr, ијал_,
  { {0x6d430009,0xdb040025,0x25a20089,0x00000000}},	//   _zina, _tsná, _bpkl_,
  { {0x291a0026,0x3f870058,0x344b0988,0x00000000}},	// [b450] ófað_, zunu_, ачен_,
  { {0x612400cd,0x6f0901f4,0x6f0d0124,0x00000000}},	//   bòli, znec, čaci,
  { {0x14190021,0x6b8800b9,0xa5bb00ea,0x00000000}},	//   حياة_, nudg, _azót,
  { {0x9948006a,0x75d50044,0x00000000,0x00000000}},	//   _دلیل_, _فيجا,   ,
  { {0x81a70021,0x6f1b004c,0xd24e005d,0x00000000}},	//   تحال, vouc, اچف_,
  { {0x6b8800b9,0x3f87005b,0x6d4b593d,0x00000000}},	//   kudg, tunu_, _ruga,
  { {0x6d431470,0xceb90080,0x6d4b1c45,0x00000000}},	//   _rina, hoře_, _suga,
  { {0xdce9007d,0x6d43593e,0x3255000d,0x00000000}},	//   vređ, _sina, _хвар,
  { {0x6f09593f,0xddcb003d,0x6d4315c4,0x00000000}},	//   rnec, _iegū, _pina,
  { {0xa3df0053,0x6f095940,0x7de00139,0x00000000}},	//   _तथा_, snec, _sású,
  { {0x6d435941,0x8b260076,0x3ae20026,0x00000000}},	//   _vina, здне, _hópi_,
  { {0x6d4b4d09,0x6d435942,0xe9a60085,0x00000000}},	//   _tuga, _wina, памп,
  { {0xdc3c0418,0x6d4300bb,0x4426008b,0x00000000}},	//   kšķi, _tina, ́o_,
  { {0x61240268,0xdce9017f,0xe8e1008b,0x00000000}},	//   tòli, pređ, _đợt_,
  { {0x3f77000c,0x8cc80053,0x5fbd0053,0x00000000}},	//   nău_, ़ारो, ्मिल,
  { {0x3f51008b,0x9c7c0114,0x612401a8,0x00000000}},	//   _máu_, nkčn, ròli,
  { {0x7d010139,0xe5a3197a,0xb0620072,0x00000000}},	// [b460] oils, нити, ääkk,
  { {0xfe79004c,0xe5231410,0xe5060044,0x00000000}},	//   dkům_, едуп, أبري,
  { {0x399600b9,0x26d90331,0xa5bb013d,0x00000000}},	//   læs_, _foso_, _szót,
  { {0x7d015943,0xdc3c008f,0x8b560041,0x00000000}},	//   hils, ašķi, ליעס_,
  { {0xf1940076,0xa6db0026,0x2240004b,0x00000000}},	//   филь, _miðl, äik_,
  { {0x90c3005e,0x3f510013,0x4f6a0121,0x00000000}},	//   ебље, _báu_, бшим_,
  { {0xdfd0007e,0x7d015944,0xdd90005d,0x00000000}},	//   ئيب_, dils, چوب_,
  { {0x64620051,0x644a005b,0x7d012713,0x00000000}},	//   świę, şliğ, eils,
  { {0x21670001,0x612d23c8,0x7d0102e0,0x00000000}},	//   _нити_, súla, fils,
  { {0xa1770063,0x6b8801e1,0xacf80054,0x00000000}},	//   _מעמד_, tudg, інну_,
  { {0x60c800b9,0x3f77003b,0xa6db0014,0x00000000}},	//   _indm, cău_, _biðl,
  { {0x9657000d,0x6b881036,0x60da2cb4,0x00000000}},	//   вiны_, rudg, _hotm,
  { {0x7d01003d,0x61e25945,0x7ced0014,0x00000000}},	//   bils, nyol, _súre,
  { {0x7ae60014,0x7d7b0149,0x7d570063,0x00000000}},	//   akkt, _פרוג, _ציוד_,
  { {0x26d91899,0xb8f50053,0xdc9b089e,0x00000000}},	//   _poso_, _सच_, _הסוכ,
  { {0x2d845946,0xd6d80f63,0x36d412b9,0x00000000}},	//   orme_, пту_, носр,
  { {0x7aed1362,0xf6500021,0xdc3c001c,0x00000000}},	// [b470] _ilat, ائف_, tšķi,
  { {0xfe79004c,0x2d845947,0x64a4005e,0x00000000}},	//   vkům_, irme_, нађа,
  { {0x92950088,0x29035948,0xa91b0046,0x00000000}},	//   даец, mija_, juþi,
  { {0x60c80004,0x629e00ea,0xe2990086,0x00000000}},	//   _andm, őpon, іал_,
  { {0x20d50086,0x3f5129bb,0xb6ba009a,0x00000000}},	//   дійс, _sáu_, _וצרי,
  { {0x7aed43d1,0x7ced021a,0xc0c8005e,0x00000000}},	//   _llat, _múrc, зуће_,
  { {0x7ae6007a,0x7d015949,0x2d84594a,0x00000000}},	//   ykkt, vils, erme_,
  { {0x29032a8e,0x3f7700dd,0xc2c500de,0x00000000}},	//   hija_, rău_, _تيري,
  { {0x7d01300c,0x2903594b,0xdd8e0044,0x00000000}},	//   tils, kija_, لوي_,
  { {0x6ab604ab,0xdd8e007e,0xa6db0014,0x00000000}},	//   _sayf, گوی_, _siðl,
  { {0x2903594c,0x7aed594d,0x2d8442e4,0x00000000}},	//   dija_, _blat, arme_,
  { {0x7d0100c2,0xdd8e007e,0xa6db0014,0x00000000}},	//   sils, دوی_, _biðm,
  { {0x7aed0051,0xec79000a,0x80b40053,0x00000000}},	//   _dlat, _дпл_, _इसमे,
  { {0xdcfb008f,0x2903594e,0x7aed020f,0x00000000}},	//   bruā, gija_, _elat,
  { {0x7aed2fe3,0x61e20058,0xd9430481,0x00000000}},	//   _flat, zyol, тери,
  { {0xb6a30e82,0x7aed594f,0xdddb056c,0x00000000}},	//   кисл, _glat, mbuł,
  { {0xcb13014e,0xa5bb00ea,0x29035950,0x00000000}},	// [b480] _שלח_, _szór, bija_,
  { {0x61e20035,0xc4830062,0xb4e80053,0x00000000}},	//   vyol, клук, बसे_,
  { {0xa6db0026,0xc5e9009a,0x60da5951,0x00000000}},	//   _miðj, סד_, _rotm,
  { {0x60da0268,0x3f98008f,0xfbb00082,0x00000000}},	//   _sotm, _īru_, _जनसम,
  { {0x7bd50024,0x7584005d,0x00000000,0x00000000}},	//   äzuj, _سیام,   ,
  { {0x61e20058,0xd13000f2,0x09f7009d,0x00000000}},	//   ryol, دمت_, ומנם_,
  { {0x61e20058,0x442c009c,0xa2480043,0x00000000}},	//   syol, _ád_, _فیال_,
  { {0x3f800006,0xaa7b0066,0x2903219f,0x00000000}},	//   čiu_, tkým, zija_,
  { {0x64590045,0xa6db007a,0xa3b60053,0x00000000}},	//   świe, _biðj, जिक_,
  { {0x7aed5952,0x8c3c0058,0xe056005d,0x00000000}},	//   _slat, leği, _غیبت_,
  { {0x29035953,0x79861e8e,0x7aed5954,0x00000000}},	//   vija_, erkw, _plat,
  { {0x8c3c01f7,0x2903176c,0x3eb8008f,0x00000000}},	//   neği, wija_, ērts_,
  { {0xf2d300b7,0x29031019,0x7aed0b57,0x00000000}},	//   דער_, tija_, _vlat,
  { {0xa6db0026,0x3cf70021,0x4cb70054,0x00000000}},	//   _viðm, _يعود_, _олію_,
  { {0x7aed5955,0x29035956,0xf7940085,0x00000000}},	//   _tlat, rija_, карэ,
  { {0x7aed0019,0x2cac001f,0x98a4001c,0x00000000}},	//   _ulat, ledd_, ēmā_,
  { {0x2cac0185,0xa53556d3,0x2b98013d,0x00000000}},	// [b490] oedd_, енач, léc_,
  { {0x2cac0185,0xcd970063,0xd49b0085,0x00000000}},	//   nedd_, ודמת_, ўра_,
  { {0x29010058,0xd37b076a,0x2c34009a,0x00000000}},	//   _imha_, юча_, תָּם_,
  { {0x2cac001f,0x7ce400cd,0xf1bf013d,0x00000000}},	//   hedd_, _dòri, _áák_,
  { {0x2169182b,0x81ab0044,0x865a03c3,0x00000000}},	//   чили_, تطاف_, _מדרי,
  { {0x98ba0006,0x2cac00d1,0xd1640062,0x00000000}},	//   _tipą_, jedd_, тъци,
  { {0x2cac001f,0xf1b90240,0xdfd1014d,0x00000000}},	//   dedd_, _myši_, ايع_,
  { {0x8c3c01f7,0xb4db00cd,0x680e013d,0x00000000}},	//   ceği, _guàr, lődé,
  { {0x2cac001f,0xc1050021,0xc115005e,0x00000000}},	//   fedd_, _كوري, _змај,
  { {0xdb0b00bd,0x2cac001f,0xbebd008f,0x00000000}},	//   _erfü, gedd_, olūk,
  { {0xab2a2254,0x543a0041,0x6609005f,0x00000000}},	//   зона_, ּערא, _žekl,
  { {0x73fa0047,0x63b800b9,0xf4120047,0x00000000}},	//   פּיו, ævni, רפט_,
  { {0x2cac081c,0xdcb10013,0xd95a0085,0x00000000}},	//   bedd_, hỏi_, яшні_,
  { {0x26cb0290,0xdce9007d,0x3ead5957,0x00000000}},	//   _anco_, dseć, leet_,
  { {0x68e10026,0x07a30d34,0x17c70074,0x00000000}},	//   ölda, ларн, нгри_,
  { {0x3ead024a,0x7bc30078,0x05760044,0x00000000}},	//   neet_, _irnu, فائد,
  { {0x3f8701da,0x7ce401a8,0xd6cf00f2,0x00000000}},	// [b4a0] hrnu_, _sòri, حقق_,
  { {0x3ead5958,0x62860244,0x4416030b,0x00000000}},	//   heet_, _ökoz, нфет,
  { {0x8c3c01f7,0x69c40066,0x3ead5959,0x00000000}},	//   teği, _hrie, keet_,
  { {0x3ead00fe,0x69c4595a,0xdb190566,0x00000000}},	//   jeet_, _krie, _krvá,
  { {0x67261262,0x3ae20026,0xdddb0078,0x00000000}},	//   _ikkj, _hóps_, eguž,
  { {0x224d013d,0x69c4017c,0x2a720244,0x00000000}},	//   _egek_, _mrie, _leyb_,
  { {0x3ead0524,0x75f5013d,0xeb870044,0x00000000}},	//   feet_, _tüzé, _حظ_,
  { {0x539b014e,0x2cac0185,0x69c42b63,0x00000000}},	//   _מילו, wedd_, _orie,
  { {0x7ced0066,0x25b2002b,0xba3b01a8,0x00000000}},	//   _súra, nwyl_, neït,
  { {0x559700b7,0x9b58000a,0x85970047,0x00000000}},	//   עדיע_, миот_, עדיג_,
  { {0x2cac0185,0x9e66013c,0x69c4595b,0x00000000}},	//   redd_, _звед, _arie,
  { {0xa6db0026,0x2cac08de,0x69c42491,0x00000000}},	//   _viðk, sedd_, _brie,
  { {0x2b490024,0x7e27000d,0x69c415ae,0x00000000}},	//   _viac_, _піша_, _crie,
  { {0x69c40112,0xd006007e,0x656400a8,0x00000000}},	//   _drie, لل_, dpih,
  { {0xdce2007d,0x628052c1,0x69090066,0x00000000}},	//   _uvođ, _odmo, ežec,
  { {0x6d4a0009,0xb0630024,0x25b2001f,0x00000000}},	//   _hifa, _zväč, fwyl_,
  { {0x6d4a0009,0x7c2a001f,0x25b2002b,0x00000000}},	// [b4b0] _kifa, _hyfr, gwyl_,
  { {0x6abd05dd,0x6b881c40,0xa6db0014,0x00000000}},	//   ldsf, ordg, _miði,
  { {0x69c40024,0x6d4a0035,0xa6db0026,0x00000000}},	//   _zrie, _mifa, _liði,
  { {0xbebd003d,0xf67900b5,0x442a05b9,0x00000000}},	//   rlūk, _קאָמ, _dyb_,
  { {0x645c0185,0x7c2a001f,0xf6e4000d,0x00000000}},	//   _ffri, _lyfr, _сцэн,
  { {0xa156005e,0x672d595c,0x3ead595d,0x00000000}},	//   њају_, llaj, weet_,
  { {0x3ead0d9e,0x6fb20032,0x02a7000d,0x00000000}},	//   teet_, لموا, _прам,
  { {0x6abd01e1,0xdce0008f,0x78bc1536,0x00000000}},	//   jdsf, ksmē, zdrv,
  { {0xa6db0026,0x7bdc00bd,0x6d4a000c,0x00000000}},	//   _viðh, ärun, _bifa,
  { {0x2d8301a6,0xba3b006f,0x6f02102a,0x00000000}},	//   čje_, heïs, _emoc,
  { {0x7c2a0c70,0x6d4a595e,0x672d00c2,0x00000000}},	//   _cyfr, _difa, klaj,
  { {0x2911595f,0x799d004d,0x7c2a1780,0x00000000}},	//   enza_, ftsw, _dyfr,
  { {0x6b88006f,0x9f34000d,0x2d8d006d,0x00000000}},	//   ardg, _сеці, quee_,
  { {0x69c40ac8,0x672d383e,0x7e690104,0x00000000}},	//   _vrie, elaj, lbep,
  { {0x7c2a0185,0xa6960001,0x656f002b,0x00000000}},	//   _gyfr, крај, _awch,
  { {0xdb190080,0x29115960,0x645c00a8,0x00000000}},	//   _trvá, anza_, _sfri,
  { {0x7a49008f,0x9aeb009a,0xb91a0044,0x00000000}},	// [b4c0] _cītī, _חַיִ, _يتخذ_,
  { {0x25b2021f,0x7ce40268,0x6564014f,0x00000000}},	//   rwyl_, _fòru, rpih,
  { {0xe29a0088,0x7e6900ac,0x672d5961,0x00000000}},	//   дае_, kbep, blaj,
  { {0x672d006d,0x6d460114,0x42d50054,0x00000000}},	//   claj, íkaz, лічу,
  { {0x672400fe,0x64590051,0xe7370121,0x00000000}},	//   moij, świa, _шею_,
  { {0x28d50042,0x81c2008f,0x6f025962,0x00000000}},	//   दायि, _ķēde, _smoc,
  { {0xdfd00032,0xc29a0001,0x6d4a5963,0x00000000}},	//   صية_, _отац_, _rifa,
  { {0x7c3e0024,0x6d4a053b,0x3f8e2e69,0x00000000}},	//   _úpri, _sifa, rufu_,
  { {0x7c2a002b,0x3f9c3692,0x9f41004c,0x00000000}},	//   _syfr, stvu_, áhá_,
  { {0x9be6012c,0x3cd4012c,0x00000000,0x00000000}},	//   вімк, ужос,   ,
  { {0x6d4a0009,0x9c7c0006,0x672d056c,0x00000000}},	//   _vifa, nkči, ylaj,
  { {0xb69b49b9,0x799d004d,0xdce0008f,0x00000000}},	//   _amân, ttsw, tsmē,
  { {0x6abd5964,0x00000000,0x00000000,0x00000000}},	//   rdsf,   ,   ,
  { {0xac180138,0xdb0b0014,0x799d5965,0x00000000}},	//   _полу_, _erfð, rtsw,
  { {0xba3b00ac,0xa6db0014,0x672d0022,0x00000000}},	//   teïs, _miðv, tlaj,
  { {0x66090026,0x672d00ea,0x7d085966,0x00000000}},	//   _þekk, ulaj, lids,
  { {0x9539000a,0x7cf6003b,0x67020042,0x00000000}},	// [b4d0] езат_, _vârf, रोधक_,
  { {0x7d08007d,0x672d0072,0x04f4079f,0x00000000}},	//   nids, slaj, азую,
  { {0xd498005a,0xb4ac0053,0xd2510021,0x00000000}},	//   ърт_, कड़े_, منا_,
  { {0x9f4700ea,0x66640062,0x27ec01e1,0x00000000}},	//   sznú_, _върз, ødne_,
  { {0x656f0185,0xa1580a8f,0x7ced0066,0x00000000}},	//   _uwch, вачу_, _búrl,
  { {0x3ea6002c,0x6e2b001f,0xe134000d,0x00000000}},	//   _abot_, _rygb, анчы,
  { {0x3f580016,0x63b80146,0x7e69006f,0x00000000}},	//   _céu_, ævnt, tbep,
  { {0x3f580268,0xddc00006,0x3dc600e5,0x00000000}},	//   _déu_, jamų, _brow_,
  { {0x7e6930de,0x52150121,0x3dc61d40,0x00000000}},	//   rbep, _сдат, _crow_,
  { {0xee360088,0x3f5800cd,0x7e69006f,0x00000000}},	//   ыны_, _féu_, sbep,
  { {0xd1200042,0xfc055967,0xa2f5009a,0x00000000}},	//   मकरण_, упно, ָמָה_,
  { {0x60c60078,0x7bc100ca,0xb4e00042,0x00000000}},	//   _ėkmi, rvlu, _तव्_,
  { {0x3dc60034,0x6f090045,0x7ce4078d,0x00000000}},	//   _grow_, miec, _còrs,
  { {0xa6db007a,0x394c00c7,0x6f09001c,0x00000000}},	//   _miðu, öds_, liec,
  { {0x9d1a0063,0xdc9a07e9,0xa6db0046,0x00000000}},	//   _אוסט, _ניקל, _liðu,
  { {0x29d80066,0x6f09030f,0x3ebf5968,0x00000000}},	//   ežať_, niec, ndut_,
  { {0xa6db007a,0x3ebf0341,0x8675000d,0x00000000}},	// [b4e0] _niðu, idut_, рысц,
  { {0x69090077,0xf507030b,0xf993009a,0x00000000}},	//   lžen, гнул_, _פרת_,
  { {0x389b00b5,0x6d41002b,0x6ef50066,0x00000000}},	//   _איינ, imla, _zábe,
  { {0xa6db0026,0x7cf6003b,0xdcb1008b,0x00000000}},	//   _biðu, _târg, hẻ_,
  { {0xc05a019d,0x3f58007a,0x2813006a,0x00000000}},	//   ній_, _séu_, _نویس,
  { {0xe5a30001,0x6d4105ff,0x2d82004c,0x00000000}},	//   _ћири, jmla, ákem_,
  { {0xa6db0026,0x6d5d5969,0xdfa60021,0x00000000}},	//   _viðv, ísan, احتي,
  { {0x2d8204e9,0x3f58017d,0x26c0596a,0x00000000}},	//   škem_, _véu_, ndio_,
  { {0x5d540635,0x26c0001f,0x25a0596b,0x00000000}},	//   јкот, idio_, ntil_,
  { {0x8f76019d,0xdce90024,0x78be013d,0x00000000}},	//   _буді, ateľ, _napv,
  { {0x6f09596c,0x5b150854,0x7d08596d,0x00000000}},	//   biec, имот, rids,
  { {0x6f090022,0x6d41596e,0x25a0596f,0x00000000}},	//   ciec, amla, ktil_,
  { {0x26c00185,0x2d9f1db1,0x7d085970,0x00000000}},	//   ddio_, ctue_, pids,
  { {0x25a00146,0x5d830032,0xac970032,0x00000000}},	//   dtil_, _الول, _منها_,
  { {0xd7f80055,0xf99f00cd,0x8cbd0042,0x00000000}},	//   гут_, stè_, _वोटो,
  { {0x7c38055e,0x290a017d,0xa4ff0053,0x00000000}},	//   _izvr, aiba_, ोच्च_,
  { {0xe664128f,0x65951851,0xe8f4005d,0x00000000}},	// [b4f0] стсо, разу, _گسيخ,
  { {0x290a006d,0x753c0051,0x6f090051,0x00000000}},	//   ciba_, _chrz, ziec,
  { {0x325501e8,0x29d80024,0xa6db0046,0x00000000}},	//   авер, ržať_, _siðu,
  { {0xd6db22c1,0x6595000d,0xb7da0063,0x00000000}},	//   _что_, _каму, _סקרי,
  { {0x067a0063,0x25a018fb,0x6f09017c,0x00000000}},	//   _שנשל, ctil_, viec,
  { {0xc05b0086,0x6f090051,0xa6db0026,0x00000000}},	//   хід_, wiec, _viðu,
  { {0x6f095971,0xcef50699,0x6e950044,0x00000000}},	//   tiec, ичињ, للغا,
  { {0x2d9f4643,0x3ebf0072,0x0d852050,0x00000000}},	//   ttue_, udut_, алин,
  { {0x3ebf109b,0x7c3800c2,0xee390062,0x00000000}},	//   rdut_, _azvr, ъни_,
  { {0x6d41014f,0x2d9f0cfc,0x6f090cc4,0x00000000}},	//   umla, rtue_, siec,
  { {0x6f095174,0xeb990001,0x7a6a41b8,0x00000000}},	//   piec, њим_, кинг_,
  { {0x690916b3,0xa6db0014,0xf1bf013d,0x00000000}},	//   užen, _miðs, _áás_,
  { {0x290a5972,0x6909189f,0x0d670121,0x00000000}},	//   tiba_, ržen, _съем,
  { {0x7e7b0974,0x1a66007e,0x2ca70013,0x00000000}},	//   laup, دیکی_, _ubnd_,
  { {0x290a5973,0x61eb20e1,0x2f1a008f,0x00000000}},	//   riba_, hygl, līga_,
  { {0x25a000d1,0x290a1931,0x26c05974,0x00000000}},	//   ttil_, siba_, udio_,
  { {0x6d5b5975,0x2f1a008f,0xe64a02d8,0x00000000}},	// [b500] nqua, nīga_, тпад_,
  { {0x25a01368,0x7e7b00bd,0xa6db0026,0x00000000}},	//   rtil_, haup, _biðs,
  { {0x6d5b0034,0x25a05976,0x46a6000d,0x00000000}},	//   hqua, stil_, _канв,
  { {0x25a00031,0x7ae4024a,0xe57a005a,0x00000000}},	//   ptil_, _joit, _изм_,
  { {0x44260045,0xa6db0026,0x6d5d0024,0x00000000}},	//   ło_, _viðt, ísal,
  { {0x6d5b0034,0x7af6001f,0x753c004d,0x00000000}},	//   dqua, _llyt, _uhrz,
  { {0xd00f013a,0xa50711da,0x6909005f,0x00000000}},	//   وله_, _тера_, džel,
  { {0x7ae403fa,0x690914b3,0xddcb008f,0x00000000}},	//   _noit, ežel, _segš,
  { {0x2d8d0034,0x50b60086,0xbce60021,0x00000000}},	//   gree_, _всеу, لأدو,
  { {0x7cf6003b,0x7af60078,0x4c94005e,0x00000000}},	//   _sârb, _alyt, љинс,
  { {0xdeef0088,0x6ab20053,0x7ae42335,0x00000000}},	//   _ды_, ज़ूर, _boit,
  { {0x6da6280d,0x7ae45977,0x2d8d0089,0x00000000}},	//   _вида, _coit, bree_,
  { {0x2d8d00e5,0x298b0062,0x2f1a008f,0x00000000}},	//   cree_, ъсно_, cīga_,
  { {0xa6db0026,0xdca3005e,0x00000000,0x00000000}},	//   _niðr, _даљи,   ,
  { {0x7c38007d,0x7d1d316d,0xd9180121,0x00000000}},	//   _uzvr, ésse, рья_,
  { {0xddc9003b,0x501b0063,0x86550062,0x00000000}},	//   nceş, דולו, сках,
  { {0xc6390086,0x63ae0150,0xa6db0014,0x00000000}},	// [b510] упає_, _apbn, _biðr,
  { {0x629b051e,0x6909007d,0xd7f10013,0x00000000}},	//   _scuo, ožem, ỡ_,
  { {0xd6d10032,0x6136000c,0x6ef5013d,0x00000000}},	//   _فقد_, tâln, _lába,
  { {0xa6db5978,0x78b5013d,0xdce90058,0x00000000}},	//   _viðs, lezv, kseğ,
  { {0x68e5024a,0xf9940041,0xcb140063,0x00000000}},	//   _kohd, ַרק_, חלף_,
  { {0x68e500fe,0x61eb001f,0xe4c70121,0x00000000}},	//   _johd, rygl, _тёмн,
  { {0x9203001c,0x78b5008f,0x7e7b5979,0x00000000}},	//   _šādu, iezv, taup,
  { {0x38180063,0x2d8d21b4,0x2f1a008f,0x00000000}},	//   יקום_, tree_, tīga_,
  { {0x6b5e001c,0x7bda597a,0x78b500ea,0x00000000}},	//   _rīga, extu, kezv,
  { {0x7ae400fe,0x2f1a001c,0x6d5b597b,0x00000000}},	//   _soit, rīga_, rqua,
  { {0x7ae4597c,0x6909597d,0xb4fa0063,0x00000000}},	//   _poit, ržel, רפתי,
  { {0xdce0001c,0x3d950076,0xa96a14cd,0x00000000}},	//   rpmā, _гидр, лима_,
  { {0x7ae4434e,0x7bca5495,0x60c1597e,0x00000000}},	//   _voit, _erfu, _kalm,
  { {0x60c10072,0x78b5013d,0xcc08005d,0x00000000}},	//   _jalm, gezv, ازین_,
  { {0x6d5900bb,0xbb850032,0x7ae42bfd,0x00000000}},	//   _huwa, _البي, _toit,
  { {0x6d5926b2,0xaa7b007a,0xcaf6005d,0x00000000}},	//   _kuwa, skýr, _دستب,
  { {0x629901e1,0xe7371410,0x057a0044,0x00000000}},	// [b520] dgwo, сет_, امطة_,
  { {0x7e79004d,0x45830054,0x3f8e002b,0x00000000}},	//   _lewp, ягув, yrfu_,
  { {0x8ca90053,0xa6db0014,0x387a008f,0x00000000}},	//   ज्यो, _viðr, _iepr_,
  { {0x91860032,0x60c10dac,0x645500fc,0x00000000}},	//   مجتم, _aalm, _egzi,
  { {0x26c2017f,0x2918005b,0x2b400139,0x00000000}},	//   _iako_, onra_, _mhic_,
  { {0x629900e8,0xa50a0431,0x7ced0555,0x00000000}},	//   agwo, _сега_, _fúri,
  { {0x26c209c1,0x6ef504a6,0x60c1597f,0x00000000}},	//   _kako_, _sába, _dalm,
  { {0x6d5900bb,0x26c203a4,0x232a007b,0x00000000}},	//   _buwa, _jako_, _соби_,
  { {0x2dda0021,0x7bc6001c,0xa06a0e14,0x00000000}},	//   ابعة_, ākum, _база_,
  { {0x26c210d2,0x2d8a00c3,0x6d5900a4,0x00000000}},	//   _lako_, čbe_, _duwa,
  { {0x24870066,0xe0430002,0xead90054,0x00000000}},	//   ónmi_, _енфи, амні_,
  { {0x26c20e02,0x69090078,0x2f1a008f,0x00000000}},	//   _nako_, ržem, mīgo_,
  { {0x2f1a008f,0xaa64000d,0x68e50072,0x00000000}},	//   līgo_, ятэк, _pohd,
  { {0x2ee6021f,0x61fd0058,0x1958082d,0x00000000}},	//   _hoof_, _üsle, сары_,
  { {0x2f1a008f,0x6d593101,0x41b50042,0x00000000}},	//   nīgo_, _zuwa, _आईऍस,
  { {0xdce0003d,0xceb90080,0x613f0003,0x00000000}},	//   ksmī, toři_, mêle,
  { {0x26c702f4,0x7afd0139,0x84cb0200,0x00000000}},	// [b530] ěno_, mhst, лужб_,
  { {0xe415000d,0x26c70022,0xd7fb1bc9,0x00000000}},	//   одзь, śno_, _бум_,
  { {0xb609001c,0x7afd0244,0x7afe01d1,0x00000000}},	//   _sašķ, ohst, ďstv,
  { {0x2f1a008f,0x60c15980,0x6b610023,0x00000000}},	//   dīgo_, _salm, _jēga,
  { {0x018b0121,0x60c14d6e,0x9948005d,0x00000000}},	//   ущей_, _palm, _خلیل_,
  { {0x26c20009,0x656d3ba0,0x7ced5981,0x00000000}},	//   _zako_, mpah, _túri,
  { {0x26c210ca,0xfe710021,0x78aa0137,0x00000000}},	//   _yako_, ودة_, _öfve,
  { {0x6d5900a4,0xe2f80054,0xb3640062,0x00000000}},	//   _puwa, _лесі_, _хърк,
  { {0x30a70002,0x62895982,0x656d5983,0x00000000}},	//   _грев, _ideo, npah,
  { {0xff0800fe,0x7d090001,0x6aad03cc,0x00000000}},	//   äärä_, рног_, _abaf,
  { {0x2f1a001c,0x656d0150,0x387a1d08,0x00000000}},	//   cīgo_, hpah, _repr_,
  { {0x63a50025,0x539a0149,0x5dd50044,0x00000000}},	//   ithn, סירו, _وقائ,
  { {0x6ef500ea,0x69cd00a3,0xdb02013d,0x00000000}},	//   _hábo, _crae, ntlé,
  { {0x672f0051,0x69cd001f,0x26c25984,0x00000000}},	//   _akcj, _drae, _sako_,
  { {0x69cd004b,0x628926c7,0x8cd60042,0x00000000}},	//   _erae, _odeo, बारो,
  { {0x7afd0199,0x62890025,0x9f47011b,0x00000000}},	//   chst, _ndeo, kyní_,
  { {0x656d002c,0x3ce75985,0x64430014,0x00000000}},	// [b540] gpah, _konv_, ýnin,
  { {0x26c20009,0xe5774ff3,0xd2a6045b,0x00000000}},	//   _wako_, юзу_, _вiль,
  { {0x26c206bb,0xe3ba0001,0x6efc3525,0x00000000}},	//   _tako_, рбе_, _hébe,
  { {0x8c1a0063,0x7d06013d,0x316a0cf7,0x00000000}},	//   בועי, éksz, ашко_,
  { {0x2ee60034,0x63a50025,0xf2040053,0x00000000}},	//   _roof_, athn, _शेख़_,
  { {0xc5f3014e,0x2f8a005e,0x3f663279,0x00000000}},	//   _חדש_, аљин_, отиб,
  { {0xc8db0047,0x67360078,0x2d8b004c,0x00000000}},	//   יקסט, olyj, ácen_,
  { {0x2f1a001c,0x9f5f013d,0xe2971948,0x00000000}},	//   rīgo_, úrák_, _мас_,
  { {0xfd46000d,0x71650044,0xbebd0023,0x00000000}},	//   жэнн, _فالك, rlūp,
  { {0xa3ae0053,0xbc4a27b5,0x3ce7277f,0x00000000}},	//   _कहा_, ичне_, _conv_,
  { {0x7afd0034,0xdce2007d,0x6ef53887,0x00000000}},	//   thst, _utoč, _kábl,
  { {0xeb07019d,0x69cd5986,0x7f19000d,0x00000000}},	//   ічно, _prae, _лічу_,
  { {0xad5a0076,0x9e65007e,0x6ef50195,0x00000000}},	//   _трех_, _رانن, _zábo,
  { {0x63a5001f,0x6ef500ea,0xd90f007e,0x00000000}},	//   ythn, _lábl, ئید_,
  { {0x36d5007b,0x2d84008f,0xbd43009b,0x00000000}},	//   повр, lsme_, _تنوي,
  { {0x8b240001,0x0a6b0002,0x64580078,0x00000000}},	//   _одје, _трки_, žvil,
  { {0x61e40072,0x7d1a5987,0x5555005d,0x00000000}},	// [b550] äill, onts, سپار,
  { {0x3494000d,0x656d58d5,0x67360078,0x00000000}},	//   дафр, rpah, alyj,
  { {0x68e10026,0x29115988,0x6d480078,0x00000000}},	//   öldu, miza_, imda,
  { {0x63a50185,0x2d842886,0x29115989,0x00000000}},	//   rthn, ksme_, liza_,
  { {0x2d840080,0x41b50053,0x1a9c0041,0x00000000}},	//   jsme_, _आईओस, שידע,
  { {0xdcfb008f,0x2911598a,0x636b3fdf,0x00000000}},	//   ksuā, niza_, _враг_,
  { {0x2d84598b,0x92b70044,0x00000000,0x00000000}},	//   esme_, _وحرا,   ,
  { {0x2d9519bb,0x7f421127,0x7d1a598c,0x00000000}},	//   прос, _choq, ents,
  { {0x29110035,0xe8d90013,0x69090078,0x00000000}},	//   kiza_, _cuị_, ažei,
  { {0xeb990001,0x6efc0003,0x2481004d,0x00000000}},	//   био_, _rébe, nahm_,
  { {0xca2901d8,0xc10403eb,0x2d8410a1,0x00000000}},	//   _עם_, _تولي, asme_,
  { {0xdb040146,0x6d482e10,0x7d1a1fc4,0x00000000}},	//   _opnå, amda, ants,
  { {0x8e490044,0x7f3a009a,0xae5a009a,0x00000000}},	//   _الشك_, _פענו, _הכנר,
  { {0x29110009,0xccc40086,0x291e004b,0x00000000}},	//   giza_, _обій, õta_,
  { {0x6f1b0058,0x64430014,0xf7460054,0x00000000}},	//   onuc, ýnil, зево,
  { {0x9f5600ea,0x4b7a0047,0x05660988,0x00000000}},	//   ógép_, _פאפו, зван,
  { {0x69c0005b,0xba9b0063,0x8afb0063,0x00000000}},	// [b560] çmed, _הספי, _להקי,
  { {0x2911053c,0x7f49004d,0x68e1009c,0x00000000}},	//   ciza_, hmeq, öldt,
  { {0xd3360085,0x1877009a,0xd7ca0044,0x00000000}},	//   пэды, _מעיר_, _اوجه_,
  { {0xdcfb0058,0x73950054,0xe29a2469,0x00000000}},	//   yruğ, ьшує, сад_,
  { {0x98aa0078,0x23270002,0x7cf6003b,0x00000000}},	//   albą_, чоци_, _bârl,
  { {0x66040035,0x7cf600dd,0xd12f005d,0x00000000}},	//   mzik, _cârl, همن_,
  { {0x6ef519af,0xd0100021,0x4f670085,0x00000000}},	//   _tábl, ضلة_, пшым_,
  { {0x2d84004b,0x24530021,0x1657009a,0x00000000}},	//   tsme_, _أنفس, ּׁים_,
  { {0x27f10051,0x7d1a013d,0x9c7c004c,0x00000000}},	//   zyzn_, tnts, ejča,
  { {0x6d430025,0xe8d90013,0x7cf600dd,0x00000000}},	//   _chna, _vuị_, _gârl,
  { {0x6d48092a,0x0a950083,0x2911598d,0x00000000}},	//   rmda, маню, viza_,
  { {0x23be0080,0x6847006c,0x2417009a,0x00000000}},	//   _můj_, hédé, לחין_,
  { {0x7ced0025,0x291109c7,0xee3a01ce,0x00000000}},	//   _cúrs, tiza_, _унд_,
  { {0x7bdc0004,0xa3c10053,0xf77300f2,0x00000000}},	//   ärus, ्टम_, فار_,
  { {0x8ca10053,0x660402e2,0x672d01a8,0x00000000}},	//   _खातो, ezik, toaj,
  { {0x8c1b014e,0x70b90053,0x64430066,0x00000000}},	//   _לווי, _इस्ल, ýnim,
  { {0xdce90512,0x6b9a2545,0x95cb0094,0x00000000}},	// [b570] zpeč, lutg, щува_,
  { {0xe945005d,0xb97c0063,0x28de0042,0x00000000}},	//   _تربی, _הנזי, माणि,
  { {0xccf300b5,0xc7ab0021,0x6b9a04aa,0x00000000}},	//   עכע_, _ادخل_, nutg,
  { {0xd2510032,0xa2f50085,0xa3ae0042,0x00000000}},	//   ننا_, ьпеч, _कहर_,
  { {0x2d910051,0xdd860049,0x26d90244,0x00000000}},	//   ązek_, _جو_, _inso_,
  { {0xf770006a,0xc24415d4,0x68470003,0x00000000}},	//   _جای_, хнік, cédé,
  { {0x7cf6003b,0xe084007e,0xdce9004c,0x00000000}},	//   _cârm, رجوي, upeč,
  { {0x26c910ca,0xdb190024,0x6f1b0058,0x00000000}},	//   ndao_, _prvý, unuc,
  { {0x25a90112,0xf1940121,0xa1940131,0x00000000}},	//   ntal_, _пить, _патч,
  { {0x25a9116d,0xb114013c,0x61f604aa,0x00000000}},	//   ital_, _змуш, øyle,
  { {0x7cff00ac,0x1c450065,0xeaba1406,0x00000000}},	//   _nêre, ьном, ойн_,
  { {0xc9aa0002,0x66040061,0x00000000,0x00000000}},	//   овме_, yzik,   ,
  { {0xdca511da,0x6bd5005d,0x00000000,0x00000000}},	//   _жали, ستگر,   ,
  { {0x7cff00ac,0x6b9a598e,0xa91b0014,0x00000000}},	//   _bêre, butg, lsþj,
  { {0x25a9598f,0x07a35990,0x8b6400de,0x00000000}},	//   etal_, карн, _كايم,
  { {0x25a9006f,0xba560062,0x68e1013d,0x00000000}},	//   ftal_, _отпъ, öldr,
  { {0x54c65991,0x66045335,0x68f9013d,0x00000000}},	// [b580] мбаб, uzik, áadó,
  { {0xf53f0137,0x448a0054,0x7e7d0014,0x00000000}},	//   _spår_, ібен_, ðspj,
  { {0x25a900ae,0x68470003,0x78bc5992,0x00000000}},	//   atal_, rédé, merv,
  { {0x78bc5993,0xbec3008f,0xdb040066,0x00000000}},	//   lerv, _šūna, _apnú,
  { {0xe163007e,0x690900c2,0x71770054,0x00000000}},	//   نگلي, ržev, дбір_,
  { {0x2f1a001c,0x7bc308ea,0x6ef50025,0x00000000}},	//   mīgi_, _osnu, _hábh,
  { {0x3ead0c23,0x645c085a,0x2f1a001c,0x00000000}},	//   ffet_, _igri, līgi_,
  { {0x78a9017f,0x69c45994,0x78bc5995,0x00000000}},	//   đevi, _osie, herv,
  { {0x6909017f,0x78bc1f9b,0x2f1a001c,0x00000000}},	//   ožet, kerv, nīgi_,
  { {0x62805996,0x6efc0164,0x6b9a00d1,0x00000000}},	//   _hemo, _déba, tutg,
  { {0x78bc01ac,0x62801cc0,0x69c45997,0x00000000}},	//   derv, _kemo, _asie,
  { {0x6b9a02fb,0x60c8013d,0x44385998,0x00000000}},	//   rutg, _hadm, _myr_,
  { {0x61e201a8,0x3f9c0061,0x6b9a08a9,0x00000000}},	//   nxol, luvu_, sutg,
  { {0x25a900c7,0x62800d11,0x78bc3956,0x00000000}},	//   vtal_, _lemo, gerv,
  { {0x69c4001c,0x69095999,0xa834005e,0x00000000}},	//   _esie, džet, верљ,
  { {0x6d58000f,0xe7840001,0x25a9599a,0x00000000}},	//   _hiva, ђусо, ttal_,
  { {0x7cff021f,0x60da0162,0x6abd0290,0x00000000}},	// [b590] _wêre, _ontm, mesf,
  { {0x14740021,0x44381d8e,0x25a9599b,0x00000000}},	//   نامج, _byr_, rtal_,
  { {0x316d00c2,0xe4a40062,0x25a9599c,0x00000000}},	//   _stez_, ърто, stal_,
  { {0x6909007d,0x443802c0,0xaabc0047,0x00000000}},	//   ažet, _dyr_, ַזוכ,
  { {0x2f1a001c,0x7d080006,0x60c8599d,0x00000000}},	//   cīgi_, _kūrė, _badm,
  { {0xc0c8005e,0x98c6007d,0x7aed016c,0x00000000}},	//   дуће_, ćući_, _loat,
  { {0xa2950088,0x6ef50297,0x6efc00f4,0x00000000}},	//   _паві, _hábi, _séba,
  { {0x62802ac2,0x60da004d,0x6d58065c,0x00000000}},	//   _gemo, _entm, _aiva,
  { {0x6d584fa8,0x63b8004c,0x645c002b,0x00000000}},	//   _biva, čanš, _ygri,
  { {0x6201005b,0x3ead149c,0xeb991168,0x00000000}},	//   ızlı, sfet_, пио_,
  { {0x6ef5017d,0x7aed221f,0xa3c10053,0x00000000}},	//   _lábi, _boat, ्टि_,
  { {0x78bc09fe,0x8a060121,0x7aed599e,0x00000000}},	//   werv, езме, _coat,
  { {0x78bc1b69,0xec791f9d,0x6e9214d7,0x00000000}},	//   terv, _епл_, _صلوا,
  { {0x6ef50027,0x68e10137,0x6d580137,0x00000000}},	//   _sábh, öldp, _giva,
  { {0xfc64005a,0x78bc1a62,0x6729004c,0x00000000}},	//   _ръчн, rerv, čejn,
  { {0xc4c6006a,0x645c001f,0x69c4001f,0x00000000}},	//   کترو, _sgri, _tsie,
  { {0x443e0198,0x62803f1b,0x4438001f,0x00000000}},	// [b5a0] _št_, _remo, _syr_,
  { {0x6280003e,0x2f1a001c,0x98a30006,0x00000000}},	//   _semo, rīgi_, toją_,
  { {0x6280053b,0x6ef50025,0x69090078,0x00000000}},	//   _pemo, _tábh, ažes,
  { {0x869a0055,0xf1a60076,0xd7360086,0x00000000}},	//   _этот_, еркн, _їхнь,
  { {0x62801633,0x645c008f,0x443845a9,0x00000000}},	//   _vemo, _tgri, _wyr_,
  { {0xd175000d,0x61d7000d,0x4438599f,0x00000000}},	//   тыцы, эмія_, _tyr_,
  { {0x443e000f,0x628059a0,0x395a59a1,0x00000000}},	//   _át_, _temo, _mips_,
  { {0x03d7014e,0xc059000d,0x395a4d4b,0x00000000}},	//   _אולם_, фіі_, _lips_,
  { {0x7ced07a8,0x7aed003b,0x31260085,0x00000000}},	//   _púrp, _roat, _здаг,
  { {0xafe61810,0x7153005d,0x00000000,0x00000000}},	//   _позл, _منقض,   ,
  { {0x7aed0529,0x20180019,0x799d00ac,0x00000000}},	//   _poat, _äri_, wusw,
  { {0x78a50512,0x141b0047,0x7e6959a2,0x00000000}},	//   _schv, לויב, ccep,
  { {0x6d5859a3,0x690959a4,0xdc120058,0x00000000}},	//   _tiva, džer, rşım,
  { {0xf795000d,0x6d58006c,0xe76b0131,0x00000000}},	//   кагэ, _uiva, зјак_,
  { {0x7aed0529,0x7a49003d,0x6ef5017d,0x00000000}},	//   _toat, _sūtī, _sábi,
  { {0xdc3b0063,0x36d50062,0xdddb008f,0x00000000}},	//   _מעור, ъобр, lauš,
  { {0x395a0034,0x6594129d,0x99d70044,0x00000000}},	// [b5b0] _fips_, лату, _أتعا,
  { {0x2f1a001c,0x57f5005e,0xa3e20053,0x00000000}},	//   mīgu_, _апот, _गपशप_,
  { {0x29010016,0xd498000d,0xf8b20047,0x00000000}},	//   _ilha_, эрт_, _דשי_,
  { {0xf2e411ec,0x7e6959a5,0xa2950054,0x00000000}},	//   лючо, xcep, таді,
  { {0x2b490025,0x2f1a008f,0x10a5012d,0x00000000}},	//   _mhac_, nīgu_, вилн,
  { {0xdddb001c,0x395a00cd,0x6e39001f,0x00000000}},	//   jauš, _xips_, _rywb,
  { {0xbfa802d8,0xafe50085,0x2901004c,0x00000000}},	//   етње_, тойл, _mlha_,
  { {0x6efc0164,0x7b24007d,0x20072b92,0x00000000}},	//   _débo, eđun, rzni_,
  { {0x2901017d,0x7c990062,0x2d8b013d,0x00000000}},	//   _olha_, мънс_, éce_,
  { {0x6b5e001c,0xfc3f0080,0x9d45005e,0x00000000}},	//   _līgu, řím_, ђенд,
  { {0x5f94005a,0x2b490139,0xaadd0053,0x00000000}},	//   _бихт, _bhac_, यांक,
  { {0xdfcf005d,0x00000000,0x00000000,0x00000000}},	//   _پيچ_,   ,   ,
  { {0xed4e59a6,0x395a0222,0x82760047,0x00000000}},	//   _во_, _pips_, כערע_,
  { {0xd94605f1,0x7c8710f6,0xfce501ce,0x00000000}},	//   теги, _чуде, _јоко,
  { {0xe73a0cd6,0x26cb59a7,0x98a3005f,0x00000000}},	//   дев_, _baco_, noję_,
  { {0x07a3000a,0x3ebf00bd,0xcf920149,0x00000000}},	//   јатн, neut_, יטל_,
  { {0x2f1a001c,0x26cb003b,0x96630085,0x00000000}},	// [b5c0] cīgu_, _daco_, ркуе,
  { {0x2f1a008f,0x09f70063,0x14c8005d,0x00000000}},	//   līgt_, _סמים_, عهای_,
  { {0x9406007e,0x291859a8,0x68e80014,0x00000000}},	//   خواه, mira_, öddu,
  { {0x291859a9,0x5276005e,0x98a30078,0x00000000}},	//   lira_, тужу, doję_,
  { {0x6efc0003,0xe731009a,0x6ecc0042,0x00000000}},	//   _débl, _הֵם_, _दोगु,
  { {0x291859aa,0x3ea659ab,0xc05a0083,0x00000000}},	//   nira_, _scot_, мій_,
  { {0x73e307a1,0x2f1a008f,0x98a30078,0x00000000}},	//   _корз, zīgu_, goję_,
  { {0xbd87006a,0xa3c10053,0x291859ac,0x00000000}},	//   چنين_, ्टर_, hira_,
  { {0xf1aa006a,0x1d34005a,0x291859ad,0x00000000}},	//   _تازه_, лния, kira_,
  { {0x64430051,0xedb5007e,0x26c0017d,0x00000000}},	//   żnie, اجيک, heio_,
  { {0x69c0005b,0x291859ae,0x69d61806,0x00000000}},	//   çmen, dira_, _arye,
  { {0x25a000e8,0x69d61b20,0x291859af,0x00000000}},	//   kuil_, _brye, eira_,
  { {0xc333014e,0xd2460021,0x291859b0,0x00000000}},	//   שור_, إن_, fira_,
  { {0xd5bf003d,0x2f1a001c,0x26cb4582,0x00000000}},	//   šāku_, rīgu_, _saco_,
  { {0x6f022c30,0x26cb0d59,0xe6950121,0x00000000}},	//   _kloc, _paco_, ливы,
  { {0x25a0018d,0xd7740021,0x26c0001f,0x00000000}},	//   fuil_, شافع, geio_,
  { {0xf99f0268,0x291859b1,0x2f1a008f,0x00000000}},	// [b5d0] què_, bira_, līgs_,
  { {0x6f020994,0xa3c10053,0x291859b2,0x00000000}},	//   _lloc, ्टल_, cira_,
  { {0x7d1d00cd,0x6f0253b1,0x2f1a008f,0x00000000}},	//   éssi, _oloc, nīgs_,
  { {0x7afd59b3,0x26c059b4,0xc7d6009d,0x00000000}},	//   nkst, ceio_, _עורי_,
  { {0xf62b0086,0xf1a707a1,0x7afd0104,0x00000000}},	//   _ціни_, трен, ikst,
  { {0x6f020493,0x80cd0042,0x00c80085,0x00000000}},	//   _aloc, _धोखे, клік_,
  { {0x7afd2c24,0x6f02169b,0xa382004b,0x00000000}},	//   kkst, _bloc, õõtm,
  { {0x7afd0122,0xfe710032,0x291859b5,0x00000000}},	//   jkst, حدث_, zira_,
  { {0x6d4a0027,0x3ebf004d,0x61e40072,0x00000000}},	//   _bhfa, reut_, äilt,
  { {0x6f022bc4,0x7afd59b6,0x2fd70044,0x00000000}},	//   _eloc, ekst, _لتصح,
  { {0x7afd01e1,0x29184d94,0x6f0259b7,0x00000000}},	//   fkst, vira_, _floc,
  { {0x139a0047,0x6f0259b8,0x539a009a,0x00000000}},	//   עברע, _gloc, עירו,
  { {0x291859b9,0x27f8002b,0x7f580054,0x00000000}},	//   tira_, wyrn_, _рацс_,
  { {0x9836000d,0x69d600f5,0x7afd167e,0x00000000}},	//   гэбі, _vrye, akst,
  { {0x26c0017d,0x291859aa,0x61f9002b,0x00000000}},	//   teio_, rira_, hywl,
  { {0x291859ba,0x6ef5017d,0x7afd59bb,0x00000000}},	//   sira_, _tábu, ckst,
  { {0xd4d6000d,0xa526005e,0x26c000be,0x00000000}},	// [b5e0] ліжэ, гмад, reio_,
  { {0xe5a3101a,0x2d8d0072,0x26c059bc,0x00000000}},	//   сифи, isee_, seio_,
  { {0x1d160047,0xe29a005e,0xef19056c,0x00000000}},	//   נקער_, еае_, kiż_,
  { {0xdb0200b9,0x5c360047,0x7cf6003b,0x00000000}},	//   stlæ, ארען_, _hârt,
  { {0x25a059bd,0x67240f74,0x2f1a008f,0x00000000}},	//   quil_, mnij, zīgs_,
  { {0x6f0259be,0x672459bf,0xd0d40062,0x00000000}},	//   _sloc, lnij, рокъ,
  { {0xdfd00032,0x7afd0006,0x6f0259c0,0x00000000}},	//   زية_, ykst, _ploc,
  { {0x64430051,0xdb0200a5,0x2f1a008f,0x00000000}},	//   żnic, ntlä, vīgs_,
  { {0x69c0005b,0xe2970062,0x42260363,0x00000000}},	//   çmel, _щат_, _сдав,
  { {0x65663534,0x7e7b0150,0x4c94005e,0x00000000}},	//   _mukh, abup, јинс,
  { {0xdb020db3,0x7b160078,0xf5370041,0x00000000}},	//   ktlä, ašum, רטיר_,
  { {0x6724017f,0x2f1a003d,0xe4570047,0x00000000}},	//   jnij, rīgs_, טייט_,
  { {0x6724017f,0xb69b003b,0x7afd26f5,0x00000000}},	//   dnij, _blân, rkst,
  { {0x7afd06f1,0x6724159a,0xbd0201c8,0x00000000}},	//   skst, enij, _šéfr,
  { {0xdb0201bb,0xd7e4071f,0x7d1a59c1,0x00000000}},	//   ftlä, біто, mits,
  { {0x7d1a3596,0xc878005b,0xeafb007e,0x00000000}},	//   lits, ığa_, _سرعت_,
  { {0xdb0200ac,0xb4c20053,0x95390002,0x00000000}},	// [b5f0] kulê, ्यू_, взат_,
  { {0x656600a4,0x98aa000c,0xb69b017d,0x00000000}},	//   _dukh, robă_, _glân,
  { {0x6724017f,0x201a0066,0x7d1a004e,0x00000000}},	//   bnij, úpil_, iits,
  { {0x6724007d,0x7d1a4b10,0x6b7b07e9,0x00000000}},	//   cnij, hits, גראנ,
  { {0xd49b000a,0x91e50a1f,0x7d1a4782,0x00000000}},	//   _прв_, роле, kits,
  { {0x64430014,0x6ef5017c,0x40c80044,0x00000000}},	//   ýnis, _nábr, ُونَ_,
  { {0x7d1a0019,0xb444000d,0x799d004d,0x00000000}},	//   dits, _гэтк, hrsw,
  { {0x2d8d00fe,0x6463005b,0x0e650a91,0x00000000}},	//   tsee_, ştiğ, шкин,
  { {0x7bd80004,0x7d1a0019,0x628b59c2,0x00000000}},	//   _arvu, fits, mago,
  { {0x5f95005a,0x672459c3,0xa3bc0053,0x00000000}},	//   _вижт, znij, _अहम_,
  { {0x3b0a0afc,0x2d8d29e5,0x60c359c4,0x00000000}},	//   вено_, ssee_, menm,
  { {0x60c301f7,0xdb020137,0x628b59c5,0x00000000}},	//   lenm, xtlä, nago,
  { {0x7bca02dd,0x6724017f,0xb69b000c,0x00000000}},	//   _esfu, vnij, _plân,
  { {0x660d2902,0x395e00c7,0x6f1b0006,0x00000000}},	//   dzak, öts_, liuc,
  { {0xc716000a,0x6724017f,0x60c3001c,0x00000000}},	//   аќањ, tnij, ienm,
  { {0x6f0903d9,0x60c3004d,0x67240c39,0x00000000}},	//   nhec, henm, unij,
  { {0x2fc7001f,0xdb0201bb,0x6b83001f,0x00000000}},	// [b600] hwng_, rtlä, _hwng,
  { {0x67241181,0xb4c2016a,0x6d4159c6,0x00000000}},	//   snij, ्ये_, nlla,
  { {0x60c359c7,0x672400b2,0xd7ff003b,0x00000000}},	//   denm, pnij, ţări_,
  { {0x628b00cd,0xe61a130d,0x656659c8,0x00000000}},	//   gago, _адм_, _tukh,
  { {0x60c3004d,0x660d0022,0x867b03c3,0x00000000}},	//   fenm, czak, _ברכו,
  { {0x2fc7001f,0x3f9c007d,0x64430051,0x00000000}},	//   fwng_, trvu_, żnia,
  { {0x628b00bb,0x7b24017f,0x7b162db5,0x00000000}},	//   bago, rđuj, ršuj,
  { {0xf7730063,0x6d4159c9,0xa8570063,0x00000000}},	//   חקה_, ella, סיקה_,
  { {0x10a6019d,0xa0a60001,0xdb0200e8,0x00000000}},	//   _визн, _вазд, pulê,
  { {0x6208005b,0x7d1a2792,0x61462c16,0x00000000}},	//   ırlı, uits, _теза,
  { {0x9b59000a,0x14d90047,0xe8d90013,0x00000000}},	//   лиот_, אַרמ, _huệ_,
  { {0x7d1a59ca,0x6d4159cb,0x6f0959cc,0x00000000}},	//   sits, alla, chec,
  { {0x799d00e8,0x6b83002b,0x753c0022,0x00000000}},	//   ursw, _ewng, _okrz,
  { {0x7cf6000c,0x290559cd,0xf77314d7,0x00000000}},	//   _vârs, óla_, قار_,
  { {0xdb0b0146,0x9b9403eb,0xd7f8137c,0x00000000}},	//   _opfø, _البت, аут_,
  { {0x27ed017f,0x6c5b0063,0x628b1433,0x00000000}},	//   ćen_, _בדוח, xago,
  { {0xd6d80699,0x95d9000d,0xe7580054,0x00000000}},	// [b610] јтс_, ыдат_, риті_,
  { {0x660d59ce,0x26d206ed,0x6efc59cf,0x00000000}},	//   rzak, adyo_, _débi,
  { {0x660d00ea,0xdb02102d,0xfc3f004c,0x00000000}},	//   szak, stlå, řív_,
  { {0x3cdd0042,0x7d0d005f,0x98aa0022,0x00000000}},	//   _कोने_, _įasm, robą_,
  { {0x31c700d7,0x6aad59d0,0x6d4159d1,0x00000000}},	//   рсев, _mcaf, ylla,
  { {0x628b37a9,0x80a80086,0x2fc7002b,0x00000000}},	//   sago, ивів_, twng_,
  { {0xa1560001,0x20540062,0xa5bb0460,0x00000000}},	//   љају_, отър, _exót,
  { {0x3eb90026,0x69c00058,0x2fc7002b,0x00000000}},	//   ýst_, çmek, rwng_,
  { {0x20c70055,0x6d410268,0xc3320047,0x00000000}},	//   _всег, tlla, _זון_,
  { {0x6d4101f7,0xa5da00b5,0xdca50001,0x00000000}},	//   ulla, אַטי, љани,
  { {0x63a5053b,0x6f0959d2,0x6d41001f,0x00000000}},	//   nuhn, phec, rlla,
  { {0x6d4143d1,0xb69b0003,0xc869016e,0x00000000}},	//   slla, _blâm, _טן_,
  { {0xdb0259d3,0x22da009a,0x00000000,0x00000000}},	//   nulé, אחרא,   ,
  { {0x673d39a8,0xed440086,0xcd760063,0x00000000}},	//   _aksj, _дніп, _העסק_,
  { {0xab990021,0x66e6142a,0x00000000,0x00000000}},	//   _إختر_, бова,   ,
  { {0x9666026c,0x753c59d4,0x16660330,0x00000000}},	//   скае, _skrz, свам,
  { {0x98a60156,0x6443004d,0x7ae459d5,0x00000000}},	// [b620] _липе, ünin, _init,
  { {0x88ca0b0f,0x7ae40026,0xdb02006c,0x00000000}},	//   _слов_, _hnit, dulé,
  { {0x63a5003e,0x25b2083f,0xa7b6005e,0x00000000}},	//   guhn, styl_, _успј,
  { {0xddc90066,0xb28305ac,0x82a60083,0x00000000}},	//   dbež, пышк, садж,
  { {0xdce2017f,0x614605fb,0xddc9213c,0x00000000}},	//   _suoč, беда, ebež,
  { {0x63a5014f,0xd6270002,0x753c0022,0x00000000}},	//   buhn, _ѓоре_, _ukrz,
  { {0x7ae459d6,0x03a30505,0x33780063,0x00000000}},	//   _onit, _ниро, _כְּב,
  { {0xe8d9008b,0x3da60690,0xc3060044,0x00000000}},	//   _tuệ_, броб, _ابسو,
  { {0xdb020003,0x9df70062,0x7a1c008f,0x00000000}},	//   culé, йнът_, nātī,
  { {0x25a00d52,0x6aad59d7,0x7ae45004,0x00000000}},	//   iril_, _scaf, _anit,
  { {0x25a056da,0x6f1e013d,0x853b009a,0x00000000}},	//   hril_, épcs, רגיי,
  { {0x25a000c2,0xdb0b007e,0x8fe50044,0x00000000}},	//   kril_, ازده_, _بأكم,
  { {0xaaaa0053,0x4aaa0042,0x2d9f1b61,0x00000000}},	//   _कारक, _कारव, crue_,
  { {0x6b73000c,0x7ae400fe,0x25a059d8,0x00000000}},	//   _săge, _enit, dril_,
  { {0x28de0053,0xd7e40083,0x00000000,0x00000000}},	//   माजि, піто,   ,
  { {0x501b0063,0x07090044,0x66390044,0x00000000}},	//   אולו, جيري_, لكأس_,
  { {0xfc3f004c,0xddc9007d,0x44f50988,0x00000000}},	// [b630] řít_, zbež, опас,
  { {0x63a50150,0x4c78089e,0x0467247d,0x00000000}},	//   tuhn, שָּׁ, стам,
  { {0x25a00019,0x645a59d9,0x4735000d,0x00000000}},	//   aril_, _útil, _мнос,
  { {0xa294019d,0x63a5014f,0xdb020003,0x00000000}},	//   заці, ruhn, tulé,
  { {0x63a50089,0x20890782,0x6289004e,0x00000000}},	//   suhn, айли_, _veeo,
  { {0xaf99180e,0x2903013d,0x15440085,0x00000000}},	//   атих_, nkja_, _неўм,
  { {0x29030026,0xd01100f2,0xdce9017c,0x00000000}},	//   ikja_, بلغ_, treľ,
  { {0xdcfb001c,0x2d953e42,0x2d9f00e5,0x00000000}},	//   stuļ, орос, true_,
  { {0x29030026,0x7ae400c2,0xdd8e0021,0x00000000}},	//   kkja_, _rnit, نوي_,
  { {0x7ae4015e,0x2d9f11f5,0x9f48017c,0x00000000}},	//   _snit, rrue_, _škôd_,
  { {0xddc20051,0x28ad0053,0xdceb004c,0x00000000}},	//   _czoł, ञ्छि, řiďt,
  { {0x29030014,0xbdf8005d,0xcae40042,0x00000000}},	//   ekja_, _گرما_, गाइड_,
  { {0x7ae40080,0xa96a0a74,0x5cf5012c,0x00000000}},	//   _vnit, рига_, _мяку,
  { {0x6efc03b2,0xddc9000c,0x61f600d1,0x00000000}},	//   _débu, aceţ, øyli,
  { {0x46f60086,0x99190083,0x6443004e,0x00000000}},	//   очат, сіях_, ünil,
  { {0x7ae4053f,0x7b24007d,0x25a059da,0x00000000}},	//   _unit, eđuv, tril_,
  { {0x249800e3,0x25a0004e,0x64430022,0x00000000}},	// [b640] _pdrm_, uril_, żnil,
  { {0x25a01493,0x7a1c001c,0xd7760044,0x00000000}},	//   rril_, rātī, _واجع,
  { {0xb376006a,0x25a00150,0x935a1d48,0x00000000}},	//   زداش, sril_, арду_,
  { {0x25a026c5,0xc2463774,0x3bba0041,0x00000000}},	//   pril_, онек, ימעד,
  { {0x224d0022,0xb2d30044,0xcb13009a,0x00000000}},	//   _czek_, بينغ, ולא_,
  { {0xcf9a0001,0xa50a0121,0xdfd00049,0x00000000}},	//   аји_, _тега_, فيت_,
  { {0x28b20161,0x224d000f,0x4ea60002,0x00000000}},	//   _जानि, _ezek_, орпа,
  { {0x644e1312,0x63b30114,0x63b40051,0x00000000}},	//   _izbi, žení, ągnę,
  { {0x628211c8,0xaf330021,0x1168005d,0x00000000}},	//   mboo, بروت, _طلای_,
  { {0x62823f61,0x4cb70121,0xe08500de,0x00000000}},	//   lboo, олью_, _فجمي,
  { {0x1eaa005d,0x3cf70044,0xdcf70043,0x00000000}},	//   _ناشي_, تعيد_, تريش_,
  { {0x628205e9,0x539b0063,0x4a74014b,0x00000000}},	//   nboo, סיכו, дыёт,
  { {0xddc9000c,0x2a640062,0xfe42005d,0x00000000}},	//   rceţ, дърг, _تکثی,
  { {0x644e017f,0x6cd4005d,0x628203a7,0x00000000}},	//   _ozbi, _رقبا, hboo,
  { {0x29030627,0x368b151b,0x6282357e,0x00000000}},	//   rkja_, исан_, kboo,
  { {0x442d0a0d,0x8f9b009f,0xb9020042,0x00000000}},	//   _će_, יילי, _नो_,
  { {0x95cb000a,0x443f008f,0x29280046,0x00000000}},	// [b650] шува_, _ņu_, ðvað_,
  { {0x4d7b0047,0x628220a4,0x224d0022,0x00000000}},	//   ירמע, eboo, _rzek_,
  { {0x7b160078,0xf8b2009a,0x00000000,0x00000000}},	//   ršuv, _אשי_,   ,
  { {0x2d4b00d1,0x91bf008d,0x92590121,0x00000000}},	//   jøen_, _ngụ_, бает_,
  { {0xdb0201f2,0x21690154,0x6b7300dd,0x00000000}},	//   rtlø, щили_, _măga,
  { {0x98aa0080,0x397c069a,0x865a009a,0x00000000}},	//   době_, סטונ, _לדרי,
  { {0xa3b40054,0x3d090042,0xf0b80043,0x00000000}},	//   _обрі, िससे_, تانش_,
  { {0x6b8d0022,0x0d850ae8,0x268b069a,0x00000000}},	//   _łago, плин, ׁנֶּ,
  { {0xb364005a,0x25a959db,0x26b600ff,0x00000000}},	//   _църк, nual_, הִים_,
  { {0x7d090001,0x61ed0072,0x0d820085,0x00000000}},	//   сног_, äalu, эльн,
  { {0xe4560047,0x6b73003b,0xeb99005e,0x00000000}},	//   ּירט_, _băga, љим_,
  { {0x6910004b,0x7d0a4304,0x00000000,0x00000000}},	//   _käeg, _elfs,   ,
  { {0x316d02dd,0x25a9003e,0x38c8007e,0x00000000}},	//   _juez_, jual_, ياسی_,
  { {0x7b24017f,0x3ead59dc,0xb23a0047,0x00000000}},	//   eđut, lget_, מערז,
  { {0x3ead00b9,0x7d06001c,0x628259dd,0x00000000}},	//   oget_, īkst, yboo,
  { {0x9bfa0063,0x6efc0003,0x3ead59de,0x00000000}},	//   _להצט, _hébr, nget_,
  { {0x25a906d5,0x316d0331,0x3ead34ab,0x00000000}},	// [b660] gual_, _nuez_, iget_,
  { {0xd884007e,0x45360054,0x7413005d,0x00000000}},	//   _تهدی, їхат, کوما,
  { {0x62820007,0xdb0200dd,0xc953089e,0x00000000}},	//   tboo, mulâ, _רמת_,
  { {0x25a90089,0xe2972159,0x3f9a0014,0x00000000}},	//   bual_, зац_, ápum_,
  { {0x3ead59df,0xcb130047,0x237f007d,0x00000000}},	//   dget_, עלד_, _čuje_,
  { {0x3ead05b9,0x628259e0,0x673b15df,0x00000000}},	//   eget_, sboo, čuje,
  { {0xdfda005a,0x628259e1,0xdea2007e,0x00000000}},	//   съл_, pboo, فیای,
  { {0x3ead02ea,0x9ed70062,0x76460072,0x00000000}},	//   gget_, змът_, _kyky,
  { {0x5d54026b,0xa0a6000d,0x316500c9,0x00000000}},	//   мкит, _наад, _filz_,
  { {0xcb98019d,0xe1f7000d,0xa6170063,0x00000000}},	//   ової_, _эгу_, פקיד_,
  { {0xc0590086,0x6efc0164,0x25a900dd,0x00000000}},	//   _дії_, _débr, zual_,
  { {0xbd87007e,0x6b5f005f,0xcb0b59e2,0x00000000}},	//   _کنون_, _kūgi, сход_,
  { {0x7646024a,0x7b24007d,0x25a9095b,0x00000000}},	//   _nyky, eđus, xual_,
  { {0xd90f007e,0xa3df0053,0x52c90082,0x00000000}},	//   اید_, तिम_, _रस्स,
  { {0x1cbb01f9,0x8c4100bd,0x4cbb0165,0x00000000}},	//   _המוע, ößte, _המוג,
  { {0x6d4859e3,0xada50066,0x25a90725,0x00000000}},	//   llda, spúš, tual_,
  { {0xa6340086,0x7b160006,0xdb02017d,0x00000000}},	// [b670] енті, ršut, bulâ,
  { {0x2f25001c,0xf9920063,0xdb0e013d,0x00000000}},	//   lēgt_, _שרי_, óköt,
  { {0x3ead0137,0x6d5a59e4,0x316d59e5,0x00000000}},	//   yget_, imta, _suez_,
  { {0x69dd00c2,0x27fe0066,0x2d99004c,0x00000000}},	//   ovse, ätne_, ásek_,
  { {0xb5fb0025,0x672d309c,0x25a90783,0x00000000}},	//   _ogái, mnaj, qual_,
  { {0x69dd0019,0x4f790062,0x672d008f,0x00000000}},	//   ivse, ощия_, lnaj,
  { {0x656f0035,0xdfce00f2,0x3ead01a8,0x00000000}},	//   _huch, ليو_, tget_,
  { {0x656f0009,0x0ea90076,0xe3b20047,0x00000000}},	//   _kuch, цкий_, _שױן_,
  { {0x5187005a,0x3ead59e6,0xfde90086,0x00000000}},	//   _хуба, rget_, ідок_,
  { {0x656f048e,0x69dd00c3,0xdb020014,0x00000000}},	//   _much, dvse, rulí,
  { {0x69c459e7,0xfaa64345,0x656f59e8,0x00000000}},	//   _spie, мано, _luch,
  { {0x6d4859e9,0x6910004b,0x6d5a59ea,0x00000000}},	//   alda, _mäee, amta,
  { {0xbcf50021,0xdb1901e1,0x672d0e96,0x00000000}},	//   _يستغ, _opvæ, dnaj,
  { {0xdce2034d,0x672d2b40,0xa3c20053,0x00000000}},	//   _zvoľ, enaj, ्बम_,
  { {0x69dd0137,0x18670320,0x69c40022,0x00000000}},	//   avse, дари_, _wpie,
  { {0x656f4ae6,0x69c0005b,0x5b360021,0x00000000}},	//   _buch, çmes, _تعتر,
  { {0x65670122,0x9aeb0132,0x656f59eb,0x00000000}},	// [b680] _bijh, _וַיִ, _cuch,
  { {0x656f59ec,0xe5a31702,0x672d59ed,0x00000000}},	//   _duch, тифи, anaj,
  { {0x656f2692,0xd38a0054,0x438300de,0x00000000}},	//   _euch, ійде_, َلْق,
  { {0x2bf600b5,0x71a6000d,0xaac10042,0x00000000}},	//   ומען_, дадз, ष्पक,
  { {0x6d480026,0xc693009f,0x6d43025f,0x00000000}},	//   ylda, _באר_, _okna,
  { {0x6d46004c,0x20540085,0xa989009a,0x00000000}},	//   ůkaz, нкля, פָנִ,
  { {0xa0670001,0x64a3005e,0xd0100021,0x00000000}},	//   маља_, _јаса, طلة_,
  { {0x6d4359ee,0xdd9a59ef,0x4ea60131,0x00000000}},	//   _akna, ошо_, фрка,
  { {0x6da30001,0x660403d7,0x6616004d,0x00000000}},	//   виња, nyik, nzyk,
  { {0x672d2c3e,0x6d48113f,0x51fb009a,0x00000000}},	//   znaj, ulda, _והמצ,
  { {0x672d0051,0xeb970002,0x6d4800a5,0x00000000}},	//   ynaj, миќ_, rlda,
  { {0xdd8f006a,0xa3df0161,0xdce20066,0x00000000}},	//   _چون_, तित_, _uvoľ,
  { {0x6abd0026,0x6ef50061,0x672d59f0,0x00000000}},	//   rfsf, _náby, vnaj,
  { {0xab940001,0x656f0051,0x61e400fe,0x00000000}},	//   _закљ, _ruch, äily,
  { {0x656f0199,0xb8821994,0x672d1035,0x00000000}},	//   _such, _číta, tnaj,
  { {0x63a5027d,0xba6b0021,0x656f59f1,0x00000000}},	//   vrhn, _بحثك_, _puch,
  { {0xd5b1014d,0x672d59f2,0x6604013d,0x00000000}},	// [b690] طفا_, rnaj, gyik,
  { {0x88c40051,0x454b000d,0x63a501c8,0x00000000}},	//   ęści, ічам_, trhn,
  { {0x656f0221,0x6616027d,0x442b000d,0x00000000}},	//   _wuch, azyk, ццам_,
  { {0xe9df0024,0x92590121,0x8237007e,0x00000000}},	//   ovú_, пает_, ورشا,
  { {0x90c5047e,0x66160051,0xdb02013d,0x00000000}},	//   ебле, czyk, nulá,
  { {0x6b56006d,0x5fd51b5f,0x3f690131,0x00000000}},	//   máge, ециф, пико_,
  { {0x26d9002c,0x6b5659f3,0xa0663320,0x00000000}},	//   _kaso_, láge, наша_,
  { {0xd1bb0044,0xdb0259f4,0xff51005d,0x00000000}},	//   _واذا_, kulá, دخت_,
  { {0x2d9903e8,0x2d8b0164,0xa2d80053,0x00000000}},	//   ése_, èce_, _नोट्,
  { {0x10d80021,0xe0d30021,0x398d001c,0x00000000}},	//   _يبلغ_, _جزر_, džs_,
  { {0x8b260795,0x6b5f001c,0xd13e0022,0x00000000}},	//   едне, _lūgu, żąca_,
  { {0x7b16003d,0x26d959f5,0x2d8b0003,0x00000000}},	//   gšup, _naso_, âces_,
  { {0xfe790080,0x6724004b,0xdca559f6,0x00000000}},	//   mců_, viij, _зали,
  { {0xfe790080,0x91ba0063,0x684659f7,0x00000000}},	//   lců_, המשי, енга,
  { {0x3b0a0001,0x26d90150,0x6d4159f8,0x00000000}},	//   _неко_, _baso_, mola,
  { {0xfe790080,0x6d41366f,0x26d959f9,0x00000000}},	//   nců_, lola, _caso_,
  { {0x798d002b,0x99d60021,0xa50a0002,0x00000000}},	// [b6a0] _gwaw, _أتبا, пеаа_,
  { {0x845a0076,0x6d411894,0x66160051,0x00000000}},	//   прет_, nola, rzyk,
  { {0x04b50062,0xb69b0003,0x66041482,0x00000000}},	//   ъстя, _plât, syik,
  { {0xe2920032,0x6b5600ea,0xfe79004c,0x00000000}},	//   اذا_, lágb, jců_,
  { {0x6d410397,0xfe790080,0xf5b60054,0x00000000}},	//   kola, dců_, _ясню,
  { {0x6d411882,0x290a013d,0x6f090075,0x00000000}},	//   jola, nkba_, ekec,
  { {0x7cf6000c,0x26c0001f,0x6d4159fa,0x00000000}},	//   _târz, ofio_, dola,
  { {0xb3bb0063,0x6d4159fb,0x26c009bf,0x00000000}},	//   _ממלכ, eola, nfio_,
  { {0x6d410027,0xe2a60026,0x26c0002b,0x00000000}},	//   fola, æðum_, ifio_,
  { {0x6d4159fc,0x6b5f001c,0x2175005e,0x00000000}},	//   gola, _lūgt, _јутр,
  { {0xdce30078,0x7c340699,0xfe79004c,0x00000000}},	//   _ginč, тенх, bců_,
  { {0xdb0200ea,0xdb0900d1,0xbebd0078,0x00000000}},	//   tulá, ntdø, liūn,
  { {0xdb0201f2,0x26d90aaf,0x6d4159fd,0x00000000}},	//   kulæ, _raso_, bola,
  { {0x98b8001c,0xbebd0006,0x690b00cd,0x00000000}},	//   torā_, niūn, _güel,
  { {0x26d902dd,0x57a4007b,0x69c800dd,0x00000000}},	//   _paso_, лшта, ădea,
  { {0x798d0035,0xddc200c2,0xdb021092,0x00000000}},	//   _twaw, _zgoš, pulá,
  { {0x07080032,0x7aed59fe,0x26d90dd1,0x00000000}},	// [b6b0] ريكي_, _inat, _vaso_,
  { {0xdb020d02,0xce370063,0x7aed0014,0x00000000}},	//   gulæ, תאמת_, _hnat,
  { {0x92950088,0x26d90072,0x7d1d01a8,0x00000000}},	//   ваец, _taso_, èssi,
  { {0x6d4159ff,0x43840021,0x7d1d013d,0x00000000}},	//   zola, النق, éssz,
  { {0xfe790080,0xe4a702a9,0x7aff5a00,0x00000000}},	//   vců_, _прво, _moqt,
  { {0xe4a7000d,0x4fa5005a,0xdb1b0022,0x00000000}},	//   _ярмо, викв, owtó,
  { {0xe5340076,0x6d410114,0x7aed5a01,0x00000000}},	//   _серь, vola, _onat,
  { {0x6b5600ea,0x64555a02,0x6d41002b,0x00000000}},	//   zágb, _izzi, wola,
  { {0x2009003d,0x6d413f92,0x6f092e25,0x00000000}},	//   ņai_, tola, rkec,
  { {0x25a9002c,0xd0d90086,0x6d410b4f,0x00000000}},	//   iral_, _ідеї_, uola,
  { {0xa3da0053,0x25a90066,0x6d410955,0x00000000}},	//   ़िए_, hral_, rola,
  { {0x6d410d11,0x25a90150,0xf3f20063,0x00000000}},	//   sola, kral_, ׁ֣ר_,
  { {0x6d415a03,0x98b8003b,0xee84000d,0x00000000}},	//   pola, joră_, _сыхо,
  { {0x9c84004c,0x25a95a04,0x929d0022,0x00000000}},	//   tečň, dral_, _hołd,
  { {0x7e7b0b16,0x25a95a05,0xa9670713,0x00000000}},	//   ocup, eral_, тира_,
  { {0x6b5600ea,0x2127008d,0x7e7b1426,0x00000000}},	//   ságb, hinh_, ncup,
  { {0x26c0001f,0x68fe1036,0x25a95650,0x00000000}},	// [b6c0] rfio_, _topd, gral_,
  { {0x7aed074f,0xdb020139,0x4806000d,0x00000000}},	//   _znat, irlí, _апов,
  { {0xd3790086,0xb8e80053,0xcf85005d,0x00000000}},	//   ечі_, ोज_, _دژ_,
  { {0xf626000d,0x60da005b,0x03260062,0x00000000}},	//   _адмо, _satm, ъден,
  { {0x41b6000a,0xdb023451,0x6e2d00a8,0x00000000}},	//   тсет, pulæ, _žabn,
  { {0x7e7b5a06,0x64a605ac,0xdb020050,0x00000000}},	//   ecup, _шага, lulä,
  { {0x443e003b,0xd00f002a,0x2b59004c,0x00000000}},	//   _ât_, يله_, ůrci_,
  { {0x6d58017f,0xc0590085,0x00000000,0x00000000}},	//   _shva, хіі_,   ,
  { {0x3246150f,0x60da092a,0xd3350085,0x00000000}},	//   _реаг, _tatm, _сэры,
  { {0x645a0026,0x6b9a006f,0x7aed5a07,0x00000000}},	//   _útis, tstg, _snat,
  { {0x61e25a08,0xdb025a09,0x3fa50044,0x00000000}},	//   lvol, kulä, _مصنف,
  { {0xbb930076,0x6b9a158f,0x7e7b3012,0x00000000}},	//   шающ, rstg, ccup,
  { {0xf2d300b5,0x79a7005a,0x61e25a0a,0x00000000}},	//   בער_, ърне, nvol,
  { {0x6d58017f,0xfbcf007e,0x61e201f4,0x00000000}},	//   _uhva, حتی_, ivol,
  { {0xd9180076,0xe894000d,0x3943008f,0x00000000}},	//   тья_, рась, rojs_,
  { {0x7aed418b,0xdb0200bd,0x673b00c2,0x00000000}},	//   _unat, gulä, čujo,
  { {0x20074374,0x25a95a0b,0xe664182e,0x00000000}},	// [b6d0] zyni_, ural_, атфо,
  { {0x58d50055,0x61e20240,0x25a95a0c,0x00000000}},	//   _соот, dvol, rral_,
  { {0xb8820080,0xdd86007e,0x2f110014,0x00000000}},	//   číte, _گو_, _lága_,
  { {0xf6790047,0x61e2004d,0xef1f0022,0x00000000}},	//   _ראָמ, fvol, ężko_,
  { {0xdd86006a,0x29010019,0x21270013,0x00000000}},	//   _دو_, _koha_, tinh_,
  { {0x7bca00b9,0x95820051,0xb144000d,0x00000000}},	//   _opfu, żące, аніл,
  { {0x6455003d,0xb4c10053,0x53350002,0x00000000}},	//   _uzzi, ्जी_, _бевт,
  { {0x2f110014,0xa3c20053,0x69100072,0x00000000}},	//   _bága_, ्बर_, _näen,
  { {0x9d45000a,0xde050076,0x3f9c004b,0x00000000}},	//   леид, уппи, asvu_,
  { {0xdb02004d,0xdfa70131,0x2901195e,0x00000000}},	//   zulä, _ајдо, _noha_,
  { {0x236d0022,0x853c009a,0x1dd80042,0x00000000}},	//   _kiej_, וגזי, _बैठत,
  { {0x2f110046,0x62995a0d,0x00000000,0x00000000}},	//   _fága_, nawo,   ,
  { {0xed4e3915,0xdb0201bb,0x236d0022,0x00000000}},	//   _го_, ktlö, _miej_,
  { {0xdce3008f,0xdb0200a5,0xeb990131,0x00000000}},	//   _finā, dulå, _зик_,
  { {0xab2a0055,0x61e25a0e,0x62990051,0x00000000}},	//   _пока_, zvol, kawo,
  { {0x236d0051,0xc5f60062,0x61e20195,0x00000000}},	//   _niej_, лязъ, yvol,
  { {0xe7370055,0xdce3003d,0x6299001f,0x00000000}},	// [b6e0] ует_, _zinā, dawo,
  { {0x09f7009a,0x2807013d,0x44165a0f,0x00000000}},	//   _עמים_, ívná_, лфет,
  { {0xdb020502,0x29180139,0x6e2d007d,0x00000000}},	//   pulä, mhra_, _žabl,
  { {0x798400ac,0x2487005b,0x61e25a10,0x00000000}},	//   _ktiw, ınma_, tvol,
  { {0xf12625ec,0x00000000,0x00000000,0x00000000}},	//   лько,   ,   ,
  { {0xbebd00eb,0x61e25a11,0x26d200ac,0x00000000}},	//   siūl, rvol, leyo_,
  { {0xf8b20161,0xc04f0086,0x6aa45a12,0x00000000}},	//   _जाईय, сі_, _odif,
  { {0x61e21031,0x285b0047,0x00000000,0x00000000}},	//   pvol, עכקײ,   ,
  { {0xa0b60049,0x9d140f27,0xdceb0023,0x00000000}},	//   _محاص, идич, _sugā,
  { {0x98c1008f,0x0203080b,0xc19b009d,0x00000000}},	//   ēsīs_, _узун, _נשבי,
  { {0x9b590079,0x88c40051,0x3d28005d,0x00000000}},	//   киот_, ęśli, فتگی_,
  { {0x290100ea,0x7de60593,0x00000000,0x00000000}},	//   _soha_, _مستم,   ,
  { {0xf2d300b5,0x6aa40185,0xff57009a,0x00000000}},	//   זער_, _ddif, _עבדך_,
  { {0x6aa44a34,0x62990022,0x644e0058,0x00000000}},	//   _edif, zawo, _oybi,
  { {0xac18000d,0x6b56013d,0x2bca1849,0x00000000}},	//   _шоку_, sága, _чуло_,
  { {0x656e0027,0x2ba90053,0x6b56013d,0x00000000}},	//   _aibh, _किता, lágn,
  { {0x29180025,0x95d90062,0x35f5000d,0x00000000}},	// [b6f0] bhra_, ъдат_, шпар,
  { {0x7afd01b3,0xd7fb1def,0x29180616,0x00000000}},	//   ljst, _зум_, chra_,
  { {0x62990051,0xa87a0063,0xdb020137,0x00000000}},	//   tawo, _באתר, rtlö,
  { {0xdb025a13,0x644e1780,0x7afd5a14,0x00000000}},	//   orlá, _dybi, njst,
  { {0x7afd006f,0x6299374f,0xb6071a78,0x00000000}},	//   ijst, rawo, _сянк,
  { {0xc0e50200,0x98b80022,0x8fe50044,0x00000000}},	//   рокк, porą_, لأعم,
  { {0xfe710032,0x23e40088,0xa1560001,0x00000000}},	//   يدة_, _літв, јају_,
  { {0x3eb95a15,0xdb090046,0xb3d10082,0x00000000}},	//   üst_, itdó, सबीऍ,
  { {0x9e620062,0x6b8400c2,0x30a71c9b,0x00000000}},	//   овъд, _čiga, _брев,
  { {0x7d090001,0xdca5018e,0xec790062,0x00000000}},	//   тног_, јани, ъпо_,
  { {0x7984001f,0x2d18005d,0xfc310044,0x00000000}},	//   _stiw, دکنک_, تحة_,
  { {0xab2a2274,0xda66354e,0xbb46012c,0x00000000}},	//   тома_, ивни, ремк,
  { {0x4a43005a,0x82d6009f,0x637401d1,0x00000000}},	//   жняв, בורג_, ožný,
  { {0x26d200ac,0x6910004b,0x7afd5a16,0x00000000}},	//   weyo_, _väeo, ajst,
  { {0x96961001,0x7d030025,0xa6960095,0x00000000}},	//   ираш, _ions, ирај,
  { {0x656e0025,0x7d0300ca,0x61e95a17,0x00000000}},	//   _sibh, _hons, _orel,
  { {0xa5260088,0x78bb017f,0x6b5600ea,0x00000000}},	// [b700] амад, đuvr, lágo,
  { {0x7bc10019,0x64a65a18,0x7d035a19,0x00000000}},	//   otlu, ража, _jons,
  { {0xe29a0088,0x7d035a1a,0x14260002,0x00000000}},	//   вае_, _mons, јдем,
  { {0x61e91123,0x083b0063,0x7bc15a1b,0x00000000}},	//   _brel, _יעיל, itlu,
  { {0x644e0045,0x7bc10019,0x6b5d00ea,0x00000000}},	//   _wybi, htlu, ségg,
  { {0x25a0005b,0x644e002b,0x7d032d56,0x00000000}},	//   msil_, _tybi, _nons,
  { {0xdfd00032,0x98a3001c,0xdfda0062,0x00000000}},	//   سية_, nijā_, тъл_,
  { {0x3ec30895,0xcef4005e,0x61e95a1c,0x00000000}},	//   осьб, спић, _frel,
  { {0x9df7005a,0x6b73003b,0xdb0201e1,0x00000000}},	//   инът_, _măgu, orlæ,
  { {0xdceb0469,0xbd430021,0xc1bb0063,0x00000000}},	//   _rugă, ينيي, _בממש,
  { {0x6c340032,0x9f5c0072,0x61e90d77,0x00000000}},	//   صفحا, tyvä_, _zrel,
  { {0x25a019fb,0x98a3008f,0x6b56013d,0x00000000}},	//   ksil_, dijā_, ságn,
  { {0x7d035a1d,0x7bc1004b,0x2f18013d,0x00000000}},	//   _fons, atlu, _cége_,
  { {0x9f5c0072,0x7d035a1e,0x98a30023,0x00000000}},	//   syvä_, _gons, fijā_,
  { {0x6d485a1f,0x764f0022,0xe7a80121,0x00000000}},	//   moda, _sycy, ивёл_,
  { {0x6d485a20,0x7d03006f,0x07090044,0x00000000}},	//   loda, _zons, ديري_,
  { {0x6d480cb0,0xe6670a2f,0xd49b015b,0x00000000}},	// [b710] ooda, ртво, вре_,
  { {0x6d482b62,0x44f40c46,0xa8a71580,0x00000000}},	//   noda, опус, _трик,
  { {0x25a0003e,0x98a3001c,0x7d1a0019,0x00000000}},	//   asil_, cijā_, ihts,
  { {0x2ba90053,0x61e95a21,0x6d485a22,0x00000000}},	//   _किसा, _prel, hoda,
  { {0x672d0009,0x6b5600ea,0xc2c40021,0x00000000}},	//   miaj, zágo, تيني,
  { {0xe134000d,0x6d4823a8,0x672d5a23,0x00000000}},	//   ончы, joda, liaj,
  { {0x6d4809fc,0x7d035a24,0xaf980766,0x00000000}},	//   doda, _rons, атых_,
  { {0xf838014e,0x7d035a25,0x28380063,0x00000000}},	//   ינות_, _sons, ינוך_,
  { {0x52150001,0x6d48001f,0x7d035a26,0x00000000}},	//   _удат, foda, _pons,
  { {0x2d9f0034,0x672d0019,0x7bc11a14,0x00000000}},	//   rsue_, hiaj, ttlu,
  { {0x2d9f0cfc,0x660d0150,0x351a0063,0x00000000}},	//   ssue_, hyak, רותנ,
  { {0x2b16005a,0xa3e80053,0x6b5600ea,0x00000000}},	//   сьор, बित_, rágo,
  { {0xfce50928,0x6d485a27,0x5d850021,0x00000000}},	//   _голо, boda, _التل,
  { {0x7d1a27a0,0x6b5d00ea,0x2f1800ea,0x00000000}},	//   chts, vége, _vége_,
  { {0x660d017e,0x6b7300dd,0x31560041,0x00000000}},	//   eyak, _păgu, מישן_,
  { {0x6b5d0164,0x98a3001c,0x69cd004b,0x00000000}},	//   tége, rijā_, äleõ,
  { {0x660d00f3,0xdce9001c,0x98a3008f,0x00000000}},	// [b720] gyak, kseļ, sijā_,
  { {0x2ed40053,0xaa7b027d,0x67360006,0x00000000}},	//   _दस्त, ndýn, snyj,
  { {0x6b5d000f,0x18770063,0x25a05a28,0x00000000}},	//   sége, _לעיר_, ssil_,
  { {0x7349019d,0x1db70053,0x9f5801e1,0x00000000}},	//   ачів_, _आमंत, _ærø_,
  { {0xc2970088,0x24982b42,0x6910004b,0x00000000}},	//   скіх_, _term_, _näek,
  { {0xc05a013c,0x69c00058,0x614304e3,0x00000000}},	//   лій_, çmey, печа,
  { {0x08770047,0x6d48004a,0x6b840078,0x00000000}},	//   זעצט_, voda, _čigo,
  { {0xf7730063,0x6d480051,0x645c5a29,0x00000000}},	//   הקה_, woda, _izri,
  { {0x6ce61c15,0xa0a600d7,0x6d485a2a,0x00000000}},	//   біне, _газд, toda,
  { {0xd24f0021,0xdb02004d,0x6d480ab6,0x00000000}},	//   _أنك_, hrlä, uoda,
  { {0xb4fb2177,0x6d485a2b,0xa4fb016e,0x00000000}},	//   אפיי, roda, אליט,
  { {0x8fa3000d,0x6d485a2c,0x6f1b5a2d,0x00000000}},	//   _хаце, soda, chuc,
  { {0x2bda024c,0x63ab0051,0x6d480574,0x00000000}},	//   _बनवा, ągni, poda,
  { {0x672d0045,0x29050026,0xf7730021,0x00000000}},	//   wiaj, ðla_, كار_,
  { {0x907b014e,0x672d365b,0xd7f821d3,0x00000000}},	//   רטלי, tiaj, бут_,
  { {0xec370063,0x6b5d00ea,0xdb09013d,0x00000000}},	//   _לאור_, ségb, ordí,
  { {0x672d5a2e,0x799600a3,0xa5f85a2f,0x00000000}},	// [b730] riaj, _gwyw, бету_,
  { {0xe6c0007d,0xdb090139,0x660d107b,0x00000000}},	//   čišć, irdí, ryak,
  { {0x660d00e3,0x3e6f005b,0x73d901e2,0x00000000}},	//   syak, _kötü_, рдер_,
  { {0x3255182b,0xd6db5027,0xe7f70082,0x00000000}},	//   овер, _сто_, ीहीथ_,
  { {0x28c00053,0xf4870e82,0x5b580041,0x00000000}},	//   श्कि, _губн, זשאן_,
  { {0x64400045,0xc244000d,0xd5b802fe,0x00000000}},	//   _śmie, чнік, _усю_,
  { {0xdbf10080,0x229d0006,0x29380041,0x00000000}},	//   _přít, eškų_, זאגן_,
  { {0x38180063,0x0d85166c,0x6fd40054,0x00000000}},	//   מקום_, олин, яціє,
  { {0xa6e20014,0x313502d8,0xfe6e005d,0x00000000}},	//   öðin, _деар, نگه_,
  { {0x929d0022,0x690b0058,0x4d650085,0x00000000}},	//   _koło, _mües, ўков,
  { {0xeb990001,0x28c40053,0xdb090331,0x00000000}},	//   јим_, _लॉगि, ardí,
  { {0x3a9a0086,0xba3b006f,0x929d0022,0x00000000}},	//   штою_, zaïe, _moło,
  { {0x7de7006a,0x4e780049,0x5ca50239,0x00000000}},	//   _دسام, _احمد_, _дилб,
  { {0x779602d8,0xee38046e,0x317a009a,0x00000000}},	//   жјац, _уні_, ירשמ,
  { {0x869a2d7b,0x186a1199,0x0fa9009a,0x00000000}},	//   итат_, рави_, יֹּֽ,
  { {0x629b5a30,0xd6d20044,0x00000000,0x00000000}},	//   _neuo, بقر_,   ,
  { {0x7ae40302,0xd7f8000c,0x6f19001f,0x00000000}},	// [b740] _iait, ţă_, _mlwc,
  { {0x7ae45a31,0x2f180003,0x6f19002b,0x00000000}},	//   _hait, _méga_, _llwc,
  { {0x6b5d0164,0x7b2b0080,0x7af6060b,0x00000000}},	//   léga, dřuj, _knyt,
  { {0x929d0022,0x74130044,0xa3df0042,0x00000000}},	//   _doło, بوما, तिज_,
  { {0x69c6000f,0x6b5d0003,0x7ae45a32,0x00000000}},	//   ntke, néga, _mait,
  { {0x7ae45a33,0x45d900b5,0xbfaa0940,0x00000000}},	//   _lait, _פֿרא, атие_,
  { {0x6f190185,0xea010013,0x929d0022,0x00000000}},	//   _blwc, _đậu_, _goło,
  { {0x7ae45a34,0x3da60086,0x98a30078,0x00000000}},	//   _nait, ороб, miją_,
  { {0x98a30078,0xaf070049,0xf1a9005d,0x00000000}},	//   liją_, تقيم_, _هاله_,
  { {0x7af60034,0x85f70047,0x6b5600ea,0x00000000}},	//   _anyt, קציע_, lágh,
  { {0x98a300eb,0x6f19001f,0x69c60213,0x00000000}},	//   niją_, _flwc, etke,
  { {0x7ae40027,0x74ca0053,0x291a5a35,0x00000000}},	//   _cait, स्तृ, _alpa_,
  { {0xdb090137,0x7ae409ac,0x98a3005f,0x00000000}},	//   vudä, _dait, hiją_,
  { {0xdc2a005d,0x98a3005f,0x257f00a3,0x00000000}},	//   _پسته_, kiją_, _rîl_,
  { {0x7ae404bc,0x69c60cb0,0xf72b0085,0x00000000}},	//   _fait, atke, ацай_,
  { {0xab280d34,0x98a30078,0x7ae45a36,0x00000000}},	//   _моја_, diją_, _gait,
  { {0x690b0268,0xdb020114,0xaded0042,0x00000000}},	// [b750] _qües, nulý, जियन_,
  { {0x6abd0146,0x929d0045,0x98a30078,0x00000000}},	//   lgsf, _poło, fiją_,
  { {0x7ae400f3,0x98a30006,0x4427008b,0x00000000}},	//   _yait, giją_, àn_,
  { {0x9294000d,0xd8380066,0x6abd06f1,0x00000000}},	//   дацц, úče_, ngsf,
  { {0x8234006a,0x68e500fe,0x929d0051,0x00000000}},	//   ورها, _kahd, _woło,
  { {0x673b0117,0xd1780085,0x98a3260f,0x00000000}},	//   čuju, ісіі_, biją_,
  { {0x98a300eb,0x68e5024a,0xa2950651,0x00000000}},	//   ciją_, _mahd, _наві,
  { {0x657d0009,0xe29f0026,0xdfce01fb,0x00000000}},	//   _kush, _þð_, ايي_,
  { {0xc3320047,0x7ae45a37,0x6b56013d,0x00000000}},	//   _נומ_, _rait, ságk,
  { {0x68e50150,0x80b4018b,0x361c0063,0x00000000}},	//   _nahd, _обух, יוחד,
  { {0xe57200b5,0xdb0e00ea,0x7c95007e,0x00000000}},	//   ײַז_, űkít, يشگا,
  { {0x6abd00d1,0x0eb8000d,0xaa462df7,0x00000000}},	//   ggsf, _душы_, земл,
  { {0x4e7a014e,0x98a30078,0x7ae45a38,0x00000000}},	//   _האנצ, ziją_, _vait,
  { {0x7ae404bf,0x6b5d0003,0x6b56013d,0x00000000}},	//   _wait, réga, zágh,
  { {0xec350047,0x657d004d,0xcb6a005e,0x00000000}},	//   _מאַר_, _aush, _лаке_,
  { {0x6910004b,0x23d20053,0x657d5a39,0x00000000}},	//   _näev, _सहबद, _bush,
  { {0x7abb0063,0xf1da0053,0x657d5a3a,0x00000000}},	// [b760] _הצפו, _मैंन, _cush,
  { {0x98a30006,0x6b5600be,0xd5af0049,0x00000000}},	//   tiją_, dági, افل_,
  { {0xa87b0063,0x2897009a,0x987b3997,0x00000000}},	//   _לאיר, _מדין_, _לאיט,
  { {0x98a300eb,0xe283036a,0x657d09e3,0x00000000}},	//   riją_, елци, _fush,
  { {0xa6e20026,0x98a30006,0x673b2fb7,0x00000000}},	//   öðun, siją_, čujt,
  { {0x28c00161,0x2d820080,0x98a30006,0x00000000}},	//   श्चि, íkem_, piją_,
  { {0x6abd00c7,0xb4b80053,0x2b810013,0x00000000}},	//   ygsf, छली_, _nóc_,
  { {0x543b014e,0x040b0013,0x657d5a3b,0x00000000}},	//   _העלא, hượn, _yush,
  { {0xe1260138,0xdb0200ea,0x434304f2,0x00000000}},	//   _емаи, cslé, _четв,
  { {0x2b810013,0x6910004b,0x42530044,0x00000000}},	//   _bóc_, _käeu, _أنكر,
  { {0xdbf10080,0x69c000cd,0x2b81008b,0x00000000}},	//   _přát, àmen, _cóc_,
  { {0x7c42001c,0xe981000d,0x60c4007d,0x00000000}},	//   _ātrā, камi_, đimu,
  { {0x6abd01bb,0xdddb003b,0x00000000,0x00000000}},	//   rgsf, rcuţ,   ,
  { {0xdddb000c,0xb4ab0053,0x657d0400,0x00000000}},	//   scuţ, _गये_, _rush,
  { {0xd7f80001,0x2b81008b,0x31570047,0x00000000}},	//   пут_, _góc_, פילן_,
  { {0x443f017f,0x657d0352,0x3bbb009a,0x00000000}},	//   _ću_, _push, _המהד,
  { {0x68e50072,0x6b5d0003,0x80bc0082,0x00000000}},	// [b770] _tahd, légo, ईलाइ,
  { {0xe61f0185,0x798d00a4,0x64400051,0x00000000}},	//   _ffôn_, _itaw, _śmia,
  { {0x69100004,0x7bc838fd,0x2381005f,0x00000000}},	//   _päev, ntdu, _vėjo_,
  { {0x6b56017d,0x7d0a5a3c,0x6363004b,0x00000000}},	//   tági, _lofs, kõne,
  { {0x95d8030b,0x6455056c,0x00000000,0x00000000}},	//   _едят_, _wyzi,   ,
  { {0xe4e40086,0xdb1b0963,0x798d05b3,0x00000000}},	//   _пісн, lttä, _mtaw,
  { {0x2054005a,0xd006005a,0x9f4d0066,0x00000000}},	//   нтър, деще_, žníc_,
  { {0xdb1b024a,0x77f80063,0x6b565a3d,0x00000000}},	//   nttä, למוד_, pági,
  { {0x2d990164,0xdb093883,0x2b815a3e,0x00000000}},	//   èse_, budú, _sóc_,
  { {0xee3601e8,0x69100019,0x5ba927c8,0x00000000}},	//   ьны_, _jäet, оком_,
  { {0x3c65019d,0x798d0150,0x6910004b,0x00000000}},	//   ьког, _ataw, _mäet,
  { {0x2b810013,0x6b5d013d,0x6008009a,0x00000000}},	//   _vóc_, ségn, _מִנְ,
  { {0xbebd0078,0xddcb0022,0x6aad002b,0x00000000}},	//   siūs, _wygł, _ddaf,
  { {0x3ebf0268,0xeb991bdd,0x2b810013,0x00000000}},	//   lgut_, _дик_, _tóc_,
  { {0x3ebf00cd,0xfce20062,0x3b0a0f56,0x00000000}},	//   ogut_, _рощо, _меко_,
  { {0x3ebf5a3f,0x0bb6009a,0x9596005e,0x00000000}},	//   ngut_, _חלקם_, држљ,
  { {0x69c8003b,0xe5a30932,0x8c3c0058,0x00000000}},	// [b780] ădes, кити, mağa,
  { {0xb4b80053,0x8c3c0058,0x3ce75a40,0x00000000}},	//   छले_, lağa, _janv_,
  { {0xd7ca0044,0x03a30054,0x320a056c,0x00000000}},	//   _بوجه_, вихо, _łby_,
  { {0x958602b6,0xe29701ce,0xc4c9009a,0x00000000}},	//   _олме, дац_, יג_,
  { {0x316a1326,0xb5fb01d1,0xc448005d,0x00000000}},	//   ошко_, _vzác, _کیان_,
  { {0x26c04eaf,0x291800ea,0x3ebf00cd,0x00000000}},	//   lgio_, nkra_, egut_,
  { {0x2f110014,0xdb1b0137,0x2bdd0053,0x00000000}},	//   _lágu_, lttå, _फैला,
  { {0x69100004,0xef91007e,0x940b0063,0x00000000}},	//   _käes, ایند, _וּמֵ,
  { {0x29180026,0xbebd0006,0x1757009a,0x00000000}},	//   kkra_, tiūr, וסקר_,
  { {0x6b5d0164,0x9ffa0021,0x3ebf01a8,0x00000000}},	//   tégo, _وراء_, agut_,
  { {0xdb1b09ff,0x798d0051,0xccf80080,0x00000000}},	//   yttä, _staw, dmět_,
  { {0x7bc80162,0xef690021,0xc3340063,0x00000000}},	//   rtdu, _فإنه_, תוֹ_,
  { {0xff27007e,0x7bc800ca,0xd2460593,0x00000000}},	//   _تبلی, stdu, ان_,
  { {0xfc2f007e,0x26c0056f,0x7e620f74,0x00000000}},	//   احی_, egio_, _izop,
  { {0x9be60086,0xba3b00a1,0x36d5247f,0x00000000}},	//   _цілк, caïn, новр,
  { {0x26c002f6,0x8cca0161,0x69c8000c,0x00000000}},	//   ggio_, त्रो, ăder,
  { {0x798d0009,0x16340330,0x6d5a5a41,0x00000000}},	// [b790] _utaw, ветя, olta,
  { {0x29180137,0xdce6005f,0xdb1b0244,0x00000000}},	//   ckra_, ėmėj, sttä,
  { {0x6910004b,0xa7750d4c,0x6d5a12ff,0x00000000}},	//   _väet, _плоч, ilta,
  { {0xfe0e0161,0x65950f56,0x6d5a0244,0x00000000}},	//   िहास_, _паму, hlta,
  { {0xa15927c8,0xf1a71e1b,0xa696009a,0x00000000}},	//   паду_, френ, _רכשה_,
  { {0xd2b50088,0x2f110026,0x25a9005b,0x00000000}},	//   _гiпэ, _lágt_, msal_,
  { {0x92c70086,0x442506f1,0x644801e1,0x00000000}},	//   _ощад, _ål_, _ødip,
  { {0xc7b40063,0x6d5a24e0,0x0ea90054,0x00000000}},	//   דבק_, elta, чкий_,
  { {0x98a300eb,0x69db00cd,0x25a95a42,0x00000000}},	//   siję_, çuel, nsal_,
  { {0x3ebf004d,0x6b5d013d,0x51840092,0x00000000}},	//   sgut_, ségl, _јута,
  { {0xc4d20047,0x26c04467,0xe4a80063,0x00000000}},	//   נגט_, ygio_, וֹרָ,
  { {0xba3b00cd,0x441a0063,0x6d5a5a43,0x00000000}},	//   raïn, פורס, alta,
  { {0x8c3c0075,0x00000000,0x00000000,0x00000000}},	//   rağa,   ,   ,
  { {0x8d650edb,0x291e5a44,0x8c452a3b,0x00000000}},	//   _явле, óta_, _пеле,
  { {0xc0520047,0x29180026,0x9d1a0149,0x00000000}},	//   ָזן_, rkra_, _מוסט,
  { {0x29185a45,0x66e3129a,0xeab214d7,0x00000000}},	//   skra_, лоса, _صعب_,
  { {0xea01001b,0x26c03ad9,0x9916000d,0x00000000}},	// [b7a0] _đầu_, rgio_, _зьні,
  { {0x691000fe,0x6b56017d,0x7d7a0041,0x00000000}},	//   _väes, rágu, פרעג,
  { {0x389b00b5,0x6b8b003b,0x25a95a46,0x00000000}},	//   _מיינ, _îngă, asal_,
  { {0x2ca5007a,0xfe6701fb,0xc1ea0054,0x00000000}},	//   hald_, _مد_, зьке_,
  { {0x2ca50146,0x6d5a0137,0x6b5600ea,0x00000000}},	//   kald_, ylta, lágs,
  { {0x2ca50026,0x6724007d,0xd0d40062,0x00000000}},	//   jald_, lhij, токъ,
  { {0xe29a0083,0x7e622188,0xd0100044,0x00000000}},	//   _нав_, _szop, شلة_,
  { {0x91e61c09,0x4f670085,0x2dd40054,0x00000000}},	//   _побе, ншым_, вжир,
  { {0x2ca518a4,0x61e4005b,0xa3dc0053,0x00000000}},	//   fald_, çild, तौर_,
  { {0x6d5a5a47,0x3ea45a48,0x61e2004d,0x00000000}},	//   ulta, samt_, mwol,
  { {0x9c7c0066,0x61e20285,0x20c90044,0x00000000}},	//   ndči, lwol, _تبقي_,
  { {0xa4fd0053,0x61e20022,0x66160072,0x00000000}},	//   _उच्च_, owol, kyyk,
  { {0x2ca5103b,0x298b00a0,0xdb1b0061,0x00000000}},	//   bald_, ясно_, nuté,
  { {0x63be1bdb,0xab5d008f,0x1d070121,0x00000000}},	//   kupn, itļi, _печи_,
  { {0x9848005a,0x63be00a5,0xccf8004c,0x00000000}},	//   еята_, jupn, směs_,
  { {0x9f470024,0x63be003e,0x7bcf0051,0x00000000}},	//   yvní_, dupn, ńcuc,
  { {0x63ba0137,0x776d004d,0xf653009e,0x00000000}},	// [b7b0] _åtnj, rmax, ائز_,
  { {0x7d1a1255,0x6b56013d,0x7c28280f,0x00000000}},	//   nkts, ságt, ozdr,
  { {0x7d08006f,0x25a95a49,0x61e20022,0x00000000}},	//   ijds, ssal_, ewol,
  { {0x672402b0,0x25a90080,0x62750021,0x00000000}},	//   chij, psal_, نهائ,
  { {0x6664011c,0x6910004b,0xaad30042,0x00000000}},	//   _бърз, _käep, ध्यक,
  { {0x9f470080,0x78a7007d,0xccf8004c,0x00000000}},	//   rvní_, najv, změr_,
  { {0xa4d40086,0x22950021,0x61120002,0x00000000}},	//   _щорі, _للأس, рдју,
  { {0x25660164,0x63b80066,0x2ca54221,0x00000000}},	//   rôle_, ávne, wald_,
  { {0x2ca50137,0x6284007d,0xfd110044,0x00000000}},	//   tald_, žioc, لجد_,
  { {0x61e4005b,0x2f110331,0x8d75013a,0x00000000}},	//   çile, _págs_, خابا,
  { {0x8c452df7,0x2ca55a4a,0x4ed50044,0x00000000}},	//   тене, rald_, _لقاء,
  { {0xde950001,0x3986017d,0x2b16005a,0x00000000}},	//   _радњ, _pôs_, тьор,
  { {0xdd94000d,0xb5fb00ea,0x0b43071f,0x00000000}},	//   _бачы, _szán, рнян,
  { {0x9e64019d,0x60c300a4,0x6fd80053,0x00000000}},	//   _свід, ngnm, _महमू,
  { {0x61e20045,0xea01001b,0xdb090014,0x00000000}},	//   zwol, _đấu_, ludý,
  { {0x6b8305cc,0x6f095a4b,0x2b030042,0x00000000}},	//   _iung, njec, षाणु_,
  { {0x672431de,0x6d415a4c,0x6b8339db,0x00000000}},	// [b7c0] rhij, onla, _hung,
  { {0x6b835a4d,0x6d4149de,0x63be0114,0x00000000}},	//   _kung, nnla, tupn,
  { {0x6aa40089,0x66160072,0x6b835a4e,0x00000000}},	//   _keif, syyk, _jung,
  { {0x6b832ff8,0x79840035,0xf773007e,0x00000000}},	//   _mung, _kuiw, _پاپ_,
  { {0x2eed001f,0x9c7c0574,0x6b835a4f,0x00000000}},	//   ddef_, leče, _lung,
  { {0x61e2001f,0x6d4109fe,0x2eed005b,0x00000000}},	//   rwol, jnla, edef_,
  { {0x63630019,0x9c7c0266,0xb4de0053,0x00000000}},	//   sõna, neče, ढ़ी_,
  { {0xdb1b0164,0x6d41477a,0x7c2800a8,0x00000000}},	//   puté, enla, vzdr,
  { {0x6b5d000f,0x5d5406be,0x6d410026,0x00000000}},	//   ségk, лкит, fnla,
  { {0x6b8339b5,0x18a40041,0x8c3c0058,0x00000000}},	//   _bung, טעגאָ, bağl,
  { {0x3eb90006,0x6f095a50,0xa3e80053,0x00000000}},	//   ųsta_, bjec, बिट_,
  { {0x9c7c0562,0x6d415a51,0xddcf0130,0x00000000}},	//   deče, anla, žešk,
  { {0xdd90006a,0x7def00ea,0x645c0238,0x00000000}},	//   _اوت_, rősö, _lyri,
  { {0x798400ac,0x6b835a52,0xa6e20046,0x00000000}},	//   _duiw, _fung, æðna,
  { {0x69da003b,0x6b565a53,0xb5fb00ea,0x00000000}},	//   ătea, rágr, _ezál,
  { {0x27fe00c7,0x6aa4002b,0x78a700dd,0x00000000}},	//   åtna_, _geif, sajv,
  { {0x6b832475,0x2727008d,0x645c0058,0x00000000}},	// [b7d0] _zung, _lõng_, _ayri,
  { {0xe5c40095,0x7aed5a54,0x6b8314fa,0x00000000}},	//   јсто, _haat, _yung,
  { {0xdb020026,0x7aed0659,0x389a0063,0x00000000}},	//   lslá, _kaat, _איתנ,
  { {0x645c069f,0x2bae0022,0x7aed004b,0x00000000}},	//   _dyri, ięc_, _jaat,
  { {0x7aed4f47,0x78a50019,0xdb020014,0x00000000}},	//   _maat, _kehv, nslá,
  { {0x645c0ac6,0x7aed557a,0x1bf40161,0x00000000}},	//   _fyri, _laat, ेमाल_,
  { {0x6f09017f,0x645c001f,0xe5340299,0x00000000}},	//   tjec, _gyri, _терь,
  { {0x765d024a,0x929d0051,0x287c0063,0x00000000}},	//   _kysy, _połu, ונומ,
  { {0x6aa45a55,0x74ca0053,0x6b83374b,0x00000000}},	//   _reif, स्कृ, _sung,
  { {0x6e290051,0x61e95a56,0x6b8323bd,0x00000000}},	//   rzeb, _isel, _pung,
  { {0x91b0001b,0xb5fb00ea,0x798400ac,0x00000000}},	//   _đảm_, _szál, _suiw,
  { {0xdb020014,0x6d585a57,0xe452089e,0x00000000}},	//   fslá, _ekva, מֶר_,
  { {0x3f850397,0x9c7c2f3e,0x2727004b,0x00000000}},	//   _hulu_, veče, _mõnd_,
  { {0x2f1800ea,0x6b835a58,0x3f855a59,0x00000000}},	//   _régi_, _tung, _kulu_,
  { {0xc815019d,0xd1410051,0x3f85007d,0x00000000}},	//   аєть, czął_, _julu_,
  { {0xd7f700aa,0x7bc15a5a,0x2fd80019,0x00000000}},	//   ững_, mulu, _ärge_,
  { {0x765d0185,0x166605fb,0x645c5a5b,0x00000000}},	// [b7e0] _cysy, увам, _syri,
  { {0x645c4177,0x9c7c007c,0xda7b0047,0x00000000}},	//   _pyri, seče, _אנפר,
  { {0x657c024a,0x7bc15a5c,0x3f85114b,0x00000000}},	//   _virh, nulu, _nulu_,
  { {0x7bc1000c,0x645c1334,0x6363004b,0x00000000}},	//   iulu, _vyri, sõnn,
  { {0x765d0185,0x1a9b0047,0x7bc15a5d,0x00000000}},	//   _gysy, גינע, hulu,
  { {0xa2d40235,0xdce3003d,0x645c0006,0x00000000}},	//   _यॉर्, _minē, _tyri,
  { {0xd547005a,0x7bc134ee,0x61e95a5e,0x00000000}},	//   _спре_, julu, _esel,
  { {0x3f8508f0,0x7bc1000c,0x6d585a5f,0x00000000}},	//   _dulu_, dulu, _skva,
  { {0xd3350088,0xba49004c,0x7bc1002b,0x00000000}},	//   _тэры, omůž, eulu,
  { {0x7aed4278,0x2dd70021,0x7bc1000c,0x00000000}},	//   _saat, ابية_, fulu,
  { {0xeb97000a,0x78a5004b,0x7bc15a60,0x00000000}},	//   лиќ_, _rehv, gulu,
  { {0xb5fb03e8,0x6da60079,0x27270019,0x00000000}},	//   _szám, _бида, _kõne_,
  { {0x7aed047f,0x6936001c,0x3f855a61,0x00000000}},	//   _vaat, aņem, _zulu_,
  { {0x8cd30161,0x27270019,0x6d5800c3,0x00000000}},	//   ब्दो, _mõne_, _ukva,
  { {0xdb0200b9,0x7bc15a62,0x273f0072,0x00000000}},	//   dslæ, culu, jänä_,
  { {0xcb69006a,0x765d00fe,0x7bcf000c,0x00000000}},	//   _جمعه_, _pysy, ăcut,
  { {0xdb1b0240,0xa5353320,0xf62b0054,0x00000000}},	// [b7f0] nutí, анач, хіви_,
  { {0xdb0201e1,0x765d0566,0x98c70054,0x00000000}},	//   gslæ, _vysy, _ссил,
  { {0x765d0045,0x2901017d,0xb97a0063,0x00000000}},	//   _wysy, _inha_, _שנתי,
  { {0x92eb0032,0xdb1b00be,0x60dc0058,0x00000000}},	//   عراق_, lutâ, _ırma,
  { {0x6936001c,0x7bc11432,0x28d20042,0x00000000}},	//   zņem, zulu, द्वि,
  { {0xf77f005b,0x61e900c2,0xdb1b017d,0x00000000}},	//   _hiç_, _vsel, dutí,
  { {0x6b5d0003,0x7bc1003b,0x7e0d0042,0x00000000}},	//   légu, xulu, ाङ्ग_,
  { {0x7bc15a63,0x61e95a64,0xd343005d,0x00000000}},	//   vulu, _tsel, _افری,
  { {0x1d2527b5,0x3eb90078,0xb5fb013d,0x00000000}},	//   имим, ųsto_, _száj,
  { {0x3f850019,0x7bc15a65,0x636a0014,0x00000000}},	//   _tulu_, tulu, rýne,
  { {0x30840032,0x2a692d6f,0xc1040021,0x00000000}},	//   _المف, _azab_, _دولي,
  { {0x7bc10bfb,0xed591b83,0xb5fb0114,0x00000000}},	//   rulu, drže_, _vzáj,
  { {0xfe9a0063,0x39e9000d,0x2913120d,0x00000000}},	//   _סיסמ, льён_, _boxa_,
  { {0x827600b5,0x7bc15a66,0xa96a25dc,0x00000000}},	//   יערע_, pulu, тига_,
  { {0xbd6800e1,0xc7a60054,0xd94301e2,0x00000000}},	//   _срце_, рибк, цери,
  { {0x273f00fe,0x4424001c,0x6fd80053,0x00000000}},	//   vänä_, _ām_, _महसू,

  { {0x6ffc003b,0x96760085,0xaa7b0046,0x00000000}},	// [b800] _zăcă, рыві, sdýr,
  { {0x33f60c07,0x26cb051e,0xd52d0013,0x00000000}},	//   ичес, _ecco_, gừn,
  { {0x3958015e,0xdb0201e1,0x889b009a,0x00000000}},	//   mors_, rslæ, _שבטי,
  { {0x6b5d00ea,0x317e004d,0x3958089c,0x00000000}},	//   ségv, _sitz_, lors_,
  { {0xdb020137,0xf8aa0053,0x23270002,0x00000000}},	//   mslä, _क़ाय, шоци_,
  { {0xc05a019d,0xc1560001,0x39585a67,0x00000000}},	//   кій_, шњењ, nors_,
  { {0x98b1000c,0xf8b301f9,0xbfa70121,0x00000000}},	//   liză_, קשה_, атые_,
  { {0x9c7c017f,0xdb020d88,0x39585a68,0x00000000}},	//   ječa, nslä, hors_,
  { {0x1d340062,0x60ea0713,0x2ca75a69,0x00000000}},	//   йния, _имам_, _bend_,
  { {0x64430045,0x7fd60086,0x62590086,0x00000000}},	//   źnie, _віді, _срср_,
  { {0x39580994,0x291300be,0x3ea60072,0x00000000}},	//   dors_, _roxa_, _teot_,
  { {0x6ffc003b,0x2ca700ca,0xed5900a8,0x00000000}},	//   _văcă, _eend_, vrže_,
  { {0x8d940032,0x6ab6001f,0x39585a6a,0x00000000}},	//   _التش, _ddyf, fors_,
  { {0x6ca30062,0x7d1c0137,0x58840085,0x00000000}},	//   _дръж, örsd, жыта,
  { {0x6f020359,0xdb0900ea,0xe7873194,0x00000000}},	//   _knoc, álóz, руго,
  { {0x6c7b03c3,0x370441af,0x2cac0cc7,0x00000000}},	//   _באופ, очув, ladd_,
  { {0x69c000cd,0x87540086,0xdb1b003b,0x00000000}},	// [b810] àmet, ікує, putâ,
  { {0xe58a00ea,0x6b5d0003,0x44980121,0x00000000}},	//   óváí, régu, ивую_,
  { {0x84390044,0x14ca005d,0xc4550044,0x00000000}},	//   دكار_, اهمی_, حَاب,
  { {0x256f0019,0x2b59000c,0xd7fa0047,0x00000000}},	//   külg_, nosc_, _עהרל,
  { {0xdb1b013d,0x00000000,0x00000000,0x00000000}},	//   lttó,   ,   ,
  { {0x6f025a6b,0x64520003,0x70e10042,0x00000000}},	//   _anoc, édié, फ़ेल,
  { {0x64580019,0x26c9007d,0x63be007d,0x00000000}},	//   üvit, ogao_, crpn,
  { {0x24890006,0x2ca756a7,0x85050053,0x00000000}},	//   šimą_, _send_, रावट_,
  { {0x9c7c05c9,0xcee80021,0xdb02011d,0x00000000}},	//   veča, شرين_, nslå,
  { {0x0d820097,0xd1310021,0x7d09005e,0x00000000}},	//   яльн, _عما_, уног_,
  { {0x39585a6c,0x7f850021,0x2ca75a6d,0x00000000}},	//   vors_, _الصن, _vend_,
  { {0x7d25007e,0x2ca70917,0xa03a0047,0x00000000}},	//   _گفتن, _wend_, _געעפ,
  { {0x3ead02ab,0x9c7c0c61,0x2ca704bc,0x00000000}},	//   maet_, reča, _tend_,
  { {0x9c7c4e28,0xdb020137,0x8a390121,0x00000000}},	//   seča, dslå, ряют_,
  { {0x9c7c5a6e,0x7d0326d0,0xdb1b00cd,0x00000000}},	//   lečn, _inns, butà,
  { {0xdb020e7b,0xa68613a2,0xe7371743,0x00000000}},	//   uslä, слад, бес_,
  { {0xdb0200c7,0x7ae601f7,0x9c7c004a,0x00000000}},	// [b820] gslå, mekt, nečn,
  { {0x98b1003b,0x6b5d013d,0x63b80195,0x00000000}},	//   riză_, ségt, ávno,
  { {0x7ae60438,0xe29a000d,0x80b30053,0x00000000}},	//   oekt, гае_, ीलैं,
  { {0x7ae65a6f,0x6b5d1f20,0x61fb5a70,0x00000000}},	//   nekt, légr, _brul,
  { {0x9c7c21d6,0x61260026,0x7ae65a71,0x00000000}},	//   ječn, _aðla, iekt,
  { {0x201c0006,0x7ae60d52,0xdb1b00ea,0x00000000}},	//   tyvi_, hekt, iutá,
  { {0xdfd00021,0x7ae62dd6,0x69c6487b,0x00000000}},	//   ذية_, kekt, huke,
  { {0x69c600fe,0x3ead0150,0x6d4e00c2,0x00000000}},	//   kuke, gaet_, čbam,
  { {0xa63b00b5,0x7ae65a72,0x98b10022,0x00000000}},	//   ָגיר, dekt, lizą_,
  { {0x1d340086,0xdce30078,0x69c609db,0x00000000}},	//   іння, _minė, duke,
  { {0x7ae631d4,0x62850080,0x2cac001f,0x00000000}},	//   fekt, ěhov, radd_,
  { {0x2bb5008b,0xdcf8001c,0xe47b0041,0x00000000}},	//   ích_, _divā, טריכ,
  { {0xc33301d8,0xdb090046,0x00000000,0x00000000}},	//   פוש_, kudö,   ,
  { {0xdb0204aa,0x200d0022,0x9e770149,0x00000000}},	//   vslå, ślił_, _הגדה_,
  { {0x69c60006,0xd52d008b,0x0d3b0063,0x00000000}},	//   auke, hữn, _תגוב,
  { {0x7ae601f7,0xdb1b29c7,0x9f45017d,0x00000000}},	//   cekt, butá, _islã_,
  { {0xdb2400ea,0xb5050053,0xe6675a73,0x00000000}},	// [b830] _írás, रालय_, ство,
  { {0x6aaf0025,0x256f004d,0x6d482713,0x00000000}},	//   lacf, küle_, nnda,
  { {0x68e7003b,0x776400a5,0x6d485a74,0x00000000}},	//   mejd, blix, inda,
  { {0x61fb0122,0xc2c40021,0x321d0051,0x00000000}},	//   _prul, كيمي, tywy_,
  { {0x2bb5008b,0x6d5a0b4f,0x7e62000e,0x00000000}},	//   ách_, kota, _nyop,
  { {0x4f95000a,0x68e7007d,0x9c7c1058,0x00000000}},	//   ориу, nejd, večn,
  { {0x3d0c0053,0x69c6004d,0x7ae62133,0x00000000}},	//   ़ाने_, zuke, yekt,
  { {0x9c7c0080,0x61fb5a75,0x6d485a76,0x00000000}},	//   tečn, _trul, enda,
  { {0x6b8a0199,0x6d5a1848,0xddcb008f,0x00000000}},	//   _aufg, fota, _izgū,
  { {0x02440021,0x9c7c3932,0x63710137,0x00000000}},	//   _عَلَ, rečn, fång,
  { {0x637101e3,0x5fdd0161,0x3b0a000a,0x00000000}},	//   gång, _महिल, аено_,
  { {0x2fc700bd,0x9c7c0114,0x6d5a004b,0x00000000}},	//   mung_, pečn, aota,
  { {0x1d090079,0x2fc754ff,0x6b5d0164,0x00000000}},	//   _вели_, lung_, tégr,
  { {0x69c6076c,0x7d0300d1,0x2fc700e5,0x00000000}},	//   ruke, _unns, oung_,
  { {0x27270019,0x2fc75a77,0xd546008b,0x00000000}},	//   _sõna_, nung_, _lện,
  { {0x291e0019,0x6b5d00ea,0x2fc7004d,0x00000000}},	//   ötab_, ségr, iung_,
  { {0x68e7010a,0x2fc70199,0xf09f001b,0x00000000}},	// [b840] bejd, hung_, _đàn_,
  { {0x2fc7049d,0x91b0008b,0x672d0089,0x00000000}},	//   kung_, _đàm_, ahaj,
  { {0x2fc723f3,0xa3ea0002,0x6b841ac3,0x00000000}},	//   jung_, рдеа_, _kiig,
  { {0xe1fa0175,0x6d5a0441,0xd5460013,0x00000000}},	//   иге_, zota, _bện,
  { {0x6d5a0009,0x6d480026,0x637100b9,0x00000000}},	//   yota, ynda, dånd,
  { {0x6b842c84,0x2fc700bd,0x256f005b,0x00000000}},	//   _liig, fung_, tüle_,
  { {0x2fc75a78,0x4fc602fe,0xe97b0041,0x00000000}},	//   gung_, іска, בנסש,
  { {0x68e70051,0x3f820026,0x6d48001f,0x00000000}},	//   zejd, öku_, wnda,
  { {0xf7730063,0x1ee8007e,0x67240078,0x00000000}},	//   וקה_, لوژی_, ikij,
  { {0x61ed00cd,0x672d366a,0x2fc75a79,0x00000000}},	//   çale, zhaj, bung_,
  { {0xe61f001b,0x6d5a5a7a,0x6d485a7b,0x00000000}},	//   _ngôn_, rota, rnda,
  { {0x8ae70086,0xf1b10042,0x637100a5,0x00000000}},	//   ціол, ुंचन, rång,
  { {0x63710137,0x6d5a5a7c,0x9f4c0139,0x00000000}},	//   sång, pota, _ordú_,
  { {0x672411a1,0x63710b19,0x010a009a,0x00000000}},	//   ekij, måne, ׁלָּ,
  { {0x68e708b7,0x637105a5,0x6e20002b,0x00000000}},	//   rejd, låne, lymb,
  { {0x9f4e00cd,0x753c00c2,0x7d1835c5,0x00000000}},	//   ïnès_, _amrz, _hovs,
  { {0x7bc85a7d,0x2fc700bd,0x8627000d,0x00000000}},	// [b850] ludu, zung_, цьве,
  { {0x672d0009,0xf09f008b,0x85050053,0x00000000}},	//   shaj, _đào_, राइट_,
  { {0x3eb900eb,0x753c00c2,0x7bc85a7e,0x00000000}},	//   ųsti_, _dmrz, nudu,
  { {0x7d185a7f,0xc3480094,0x3318005d,0x00000000}},	//   _lovs, ояче_, يزند_,
  { {0x7bc80009,0xa2cc0053,0x9f650003,0x00000000}},	//   hudu, _हार्, _étés_,
  { {0x7bc80035,0x2fc75a77,0x3f8c1aa5,0x00000000}},	//   kudu, tung_, _budu_,
  { {0x637100c7,0xe8d9008b,0x2fc700bd,0x00000000}},	//   tånd, _quỹ_, uung_,
  { {0x7bc80397,0x2fc75a80,0x2bb5008f,0x00000000}},	//   dudu, rung_, vāc_,
  { {0x6b841fc9,0x2fc707c9,0xed590130,0x00000000}},	//   _riig, sung_, luži_,
  { {0x2fc72ff8,0xdb02000e,0xee36066e,0x00000000}},	//   pung_, lslø, яны_,
  { {0x7bc80019,0x7d1c0137,0xba3b006c,0x00000000}},	//   gudu, örsa, daïq,
  { {0x612f35cd,0x1bec0053,0x09e61e34,0x00000000}},	//   _bølg, _जनरल_, помн,
  { {0xb0d20161,0x7ed4007e,0xd148008b,0x00000000}},	//   _सामग, _آزما, iễn_,
  { {0xfe70006a,0x2d9f0003,0x7bc85a81,0x00000000}},	//   _شدن_, mpue_, budu,
  { {0xab990032,0x67240466,0x6b84004b,0x00000000}},	//   _اختر_, tkij, _tiig,
  { {0x612f0307,0xdaaa00d7,0x6aad00ac,0x00000000}},	//   _følg, _увид_, _geaf,
  { {0xdb02000e,0x64430014,0x9c7c007d,0x00000000}},	// [b860] dslø, únin, ječj,
  { {0x6d4103f7,0xe8ca0121,0x272e0014,0x00000000}},	//   nila, _угол_, _sýnd_,
  { {0x64a30854,0xdcb10013,0x7af601a1,0x00000000}},	//   хаха, iả_, _kayt,
  { {0xeb9600b5,0x6d411a67,0xdcb10013,0x00000000}},	//   לדער_, hila, hả_,
  { {0x6d4103f7,0x291a001c,0x3f8c5a82,0x00000000}},	//   kila, _kopa_, _sudu_,
  { {0x25a0014f,0x291a00fe,0x9f4c00cd,0x00000000}},	//   mpil_, _jopa_, _urdú_,
  { {0x6d415a83,0xc448007e,0x53a6030b,0x00000000}},	//   dila, _بیان_, _хабб,
  { {0x0eea0086,0x02460021,0x6d415a84,0x00000000}},	//   ськи_, _فَأَ, eila,
  { {0x9f6300ea,0xa2d30021,0x7d1815df,0x00000000}},	//   ívás_, _سيلت, _povs,
  { {0x25a00150,0x6d411fff,0x7bc80cdc,0x00000000}},	//   ipil_, gila, tudu,
  { {0x6db501f7,0x9c7c0080,0x7bc8112c,0x00000000}},	//   _aşağ, mečk, uudu,
  { {0x6d41002c,0x7bc83aaa,0x9c7c004c,0x00000000}},	//   aila, rudu, lečk,
  { {0xc333014e,0x6d413b3e,0x7bc80058,0x00000000}},	//   תור_, bila, sudu,
  { {0x291a5a85,0x256f004b,0x6d41331f,0x00000000}},	//   _copa_, küla_, cila,
  { {0xd148001b,0x36d50086,0xd7e40454,0x00000000}},	//   yễn_, мовр, ніто,
  { {0xf09f008b,0x649100c2,0xba3b0003,0x00000000}},	//   _đàm_, zžič, saïq,
  { {0xdb0200d1,0x2abc009a,0x3abc009a,0x00000000}},	// [b870] vslø, _המחא, _המחנ,
  { {0x9c7c5a86,0x612f00b9,0xf9940ca4,0x00000000}},	//   večj, _køle, _ארץ_,
  { {0x44275a87,0xdb0204aa,0x03940054,0x00000000}},	//   án_, tslø, ерія,
  { {0x673d0026,0x99990051,0xed5900b2,0x00000000}},	//   _umsj, mysł_, ruži_,
  { {0xd49b0095,0x6d41013d,0xb5fb013d,0x00000000}},	//   _грб_, yila, _ezár,
  { {0x9c7c1253,0x4427008b,0x3cf80053,0x00000000}},	//   rečj, ơn_, ्ञों_,
  { {0x612f00d1,0xdb0204aa,0x6d415a88,0x00000000}},	//   _nøle, pslø, vila,
  { {0x25660066,0xbf350021,0x6d415a89,0x00000000}},	//   vôli_, برتغ, wila,
  { {0x6d415a8a,0x98b800dd,0x39435a8b,0x00000000}},	//   tila, niră_, kijs_,
  { {0x251a0047,0xdcb1008b,0xfe420a36,0x00000000}},	//   ַורא, uả_, тньо,
  { {0xac390086,0xdcb1008b,0x291a5a8c,0x00000000}},	//   ючих_, rả_, _ropa_,
  { {0xf1d10161,0x2d8b006d,0x63b8027d,0x00000000}},	//   _समान, íces_, ávni,
  { {0xdb1b09ff,0x291a5a8d,0x7ae9004b,0x00000000}},	//   yttö, _popa_, õeta,
  { {0x612f02ab,0x61e4005b,0xdb0b0137,0x00000000}},	//   _føle, çili, _avfä,
  { {0xb8f6016a,0x2d8f0034,0x2574004d,0x00000000}},	//   _हा_, _huge_, näle_,
  { {0x2d8f5a8e,0x00000000,0x00000000,0x00000000}},	//   _kuge_,   ,   ,
  { {0x2d8f0164,0xb5fb00ea,0x36670001,0x00000000}},	// [b880] _juge_, _szár, дато_,
  { {0x186a0138,0xc8ca006a,0x3eaf0c84,0x00000000}},	//   _мапи_, _بودن_, _legt_,
  { {0x25a02f88,0x2d871c85,0x935a0da2,0x00000000}},	//   spil_, _mine_, орду_,
  { {0x2d875a8f,0xdb1b5a90,0x69c65a91,0x00000000}},	//   _line_, ortá, orke,
  { {0xd00f007e,0x4426008f,0x9c7c01ff,0x00000000}},	//   یله_, ņo_, tečk,
  { {0xcf9a0138,0x2d870034,0x61ed0058,0x00000000}},	//   оји_, _nine_, çala,
  { {0x399401e3,0x2d8f5a92,0xe29a0086,0x00000000}},	//   _läs_, _auge_, _мав_,
  { {0xadf4036a,0x2d875a93,0x6d4f0003,0x00000000}},	//   епиш, _aine_, écan,
  { {0x2d870529,0x9c7c0006,0x399400a5,0x00000000}},	//   _bine_, meči, _näs_,
  { {0x2b400268,0x2d8f007d,0x2d875a94,0x00000000}},	//   _amic_, _duge_, _cine_,
  { {0x2d875a95,0x69c62426,0xccf8004c,0x00000000}},	//   _dine_, erke, rdě_,
  { {0x2d870cd4,0x80da0161,0x39430122,0x00000000}},	//   _eine_, प्रे, wijs_,
  { {0x2d875a96,0x69c016fe,0x9c7c0078,0x00000000}},	//   _fine_, šmen, ieči,
  { {0x3eaf0122,0x2d875a97,0xfbcf005d,0x00000000}},	//   _zegt_, _gine_, دتی_,
  { {0x2d8f00bd,0x9c7c0006,0x39435a98,0x00000000}},	//   _zuge_, keči, rijs_,
  { {0x9c7c01b3,0xdce9001c,0xf5990062,0x00000000}},	//   ječi, zpeļ, зващ_,
  { {0x2d87005b,0x7bda00fe,0xda67007e,0x00000000}},	// [b890] _yine_, lttu, _تاثي,
  { {0xe46b0076,0x2bc50053,0x7bda5a99,0x00000000}},	//   ошел_, _विमा, ottu,
  { {0x7bda0050,0xa4d4045b,0x00000000,0x00000000}},	//   nttu, тохі,   ,
  { {0x98b8003b,0x7bda5a9a,0x5b7c0047,0x00000000}},	//   piră_, ittu, ַרגא,
  { {0x2bc50235,0xa1eb0021,0xdb2600ea,0x00000000}},	//   _विभा, تراك_, épés,
  { {0x7d1c00c7,0x332d004b,0xf6520063,0x00000000}},	//   örsl, _wlex_, _עצם_,
  { {0x13f41406,0x2d8f5a9b,0x60960044,0x00000000}},	//   _изря, _suge_, رنيس_,
  { {0x69c602ab,0x2d875a9c,0x2574004d,0x00000000}},	//   yrke, _sine_, räle_,
  { {0xdb1b00b9,0x2d875a9d,0xf1a70500,0x00000000}},	//   ortæ, _pine_, _іран,
  { {0xfd110021,0x3ea2005b,0x6e9f0053,0x00000000}},	//   اجة_, ıkta_, _ग्रु,
  { {0x2d875a9e,0xcb6a107a,0x3eb90014,0x00000000}},	//   _vine_, зане_, ósts_,
  { {0x2d870034,0x201800cd,0xef0e000d,0x00000000}},	//   _wine_, _ària_, _ём_,
  { {0x2d8719d5,0x7bda1e2c,0xed4e0304,0x00000000}},	//   _tine_, attu, _бо_,
  { {0x2eed0229,0x98b80078,0x2916005d,0x00000000}},	//   leef_, kirą_, روزآ,
  { {0x929d0022,0x1ae60085,0x66e6034b,0x00000000}},	//   _woły, _зойм, нова,
  { {0x2eed006f,0x63780331,0x9f47011b,0x00000000}},	//   neef_, míng, yvný_,
  { {0x69da003b,0x63781494,0x9c7c0077,0x00000000}},	// [b8a0] ătes, líng, veči,
  { {0x637100c7,0xb5fb01c8,0x96630085,0x00000000}},	//   våna, _vzáp, укуе,
  { {0xb0c9016a,0x20c90053,0x80c90053,0x00000000}},	//   _राजग, _राजध, रलैं,
  { {0xeb9200b5,0xa3c10042,0x179b009a,0x00000000}},	//   אָס_, ूढ़_, _מיטב,
  { {0x171b00b5,0x9c7c5a9f,0x7ae45aa0,0x00000000}},	//   _זוכע, reči, _mbit,
  { {0xdb020025,0x7bda0026,0xdfd001fb,0x00000000}},	//   osló, yttu, ليت_,
  { {0x7ae403bd,0xa87a0047,0xdb020014,0x00000000}},	//   _obit, האַר, nsló,
  { {0x9ed70062,0x78b5007d,0x20d20053,0x00000000}},	//   емът_, zazv, _सावध,
  { {0x0206019d,0xdb020164,0x657e0164,0x00000000}},	//   _язан, mplè, omph,
  { {0x7ae45aa1,0x62840078,0x3eb90022,0x00000000}},	//   _abit, žios, óstr_,
  { {0xbea60062,0x7bda5aa2,0x6c545aa3,0x00000000}},	//   _заек, uttu, ткну,
  { {0xf09f008b,0x7bda3928,0x600b009a,0x00000000}},	//   _đài_, rttu, _מִדְ,
  { {0x6e2800dd,0x7bda0244,0x7c66005d,0x00000000}},	//   âmbă, sttu, باکل,
  { {0xdb02007a,0x637816eb,0x2e37009a,0x00000000}},	//   fsló, línd, _ארדש_,
  { {0x272e007a,0xc6a702a9,0x1958000d,0x00000000}},	//   _sýna_, ерзи, хары_,
  { {0x64430051,0x00000000,0x00000000,0x00000000}},	//   źnik,   ,   ,
  { {0x273500c7,0xdb020025,0x61260026,0x00000000}},	// [b8b0] _lång_, asló, _eðli,
  { {0x48ab0076,0x27270019,0xd4982827,0x00000000}},	//   _этим_, _mõni_, ерц_,
  { {0x98c40055,0x32040037,0xd40403d1,0x00000000}},	//   _ссыл, _army_, ляци,
  { {0xe8d9008b,0x7afd212e,0x69dd5aa4,0x00000000}},	//   _tuỳ_, ndst, otse,
  { {0x69dd0702,0x7aef000c,0x7bc8004d,0x00000000}},	//   ntse, iect, hrdu,
  { {0xe61f008b,0x01650062,0xf9940149,0x00000000}},	//   _ngôi_, ъкло, ארס_,
  { {0x6296005b,0x2bc50053,0xdb1b01f2,0x00000000}},	//   ıyor, _विधा, butø,
  { {0x7afd2e30,0x69dd5aa5,0x7aef089c,0x00000000}},	//   jdst, ktse, ject,
  { {0xa195005a,0x60f50001,0x2eed0229,0x00000000}},	//   _разч, _изађ, reef_,
  { {0xdb020164,0x273502ab,0x69cf09ee,0x00000000}},	//   mplé, _hånd_, duce,
  { {0x273501e3,0x7afd0122,0x7aef02a0,0x00000000}},	//   _gång_, fdst, fect,
  { {0xe627008b,0x69dd1fe0,0x63780fb8,0x00000000}},	//   _phổ_, ftse, ríng,
  { {0x69cf007d,0xfeb8009e,0x7bc85aa6,0x00000000}},	//   guce, _سانت_, ardu,
  { {0xa021004b,0x636a0014,0x637850c6,0x00000000}},	//   _ööse, rýni, míne,
  { {0x69dd5aa7,0x290c005b,0x636a0014,0x00000000}},	//   atse, ıda_, sýni,
  { {0xc6c30c07,0xed591181,0xdb020026,0x00000000}},	//   ийск, drži_, rsló,
  { {0x69dd006f,0xceb212cd,0x6378266a,0x00000000}},	// [b8c0] ctse, יין_, níne,
  { {0xd5af0021,0x79b70063,0x657e5aa8,0x00000000}},	//   تفك_, _שליד_, umph,
  { {0x273506a5,0x6b5d00ea,0x61e95aa9,0x00000000}},	//   _bånd_, végz, _apel,
  { {0x8c1a07e9,0x33290085,0xa3d30054,0x00000000}},	//   וועי, нцін_, роїч,
  { {0x27350137,0x7d1c07fb,0x2d990061,0x00000000}},	//   _sång_, örsk, ísel_,
  { {0xdb1b04aa,0x6378004c,0x64a34a23,0x00000000}},	//   sutø, díne, _вара,
  { {0x7aef048e,0xd0100032,0x7afd00b9,0x00000000}},	//   yect, صلة_, ydst,
  { {0xd0070138,0x2ef40259,0x9df8140f,0x00000000}},	//   ђење_, узир, енит_,
  { {0xe0da041d,0x28d30161,0x629e0080,0x00000000}},	//   _ова_, _तालि, ěpod,
  { {0x21765aaa,0x9d1404d6,0x867b009a,0x00000000}},	//   _рубр, удоч, ורפו,
  { {0x5c730076,0x7bc8005b,0xeb970002,0x00000000}},	//   ильт, urdu, киќ_,
  { {0x69dd5aab,0x7afd5aac,0x69cf04d7,0x00000000}},	//   ttse, udst, tuce,
  { {0x69dd39c8,0x9c7c00c2,0x7afd17d5,0x00000000}},	//   utse, veču, rdst,
  { {0x69dd10cc,0x7aef13b6,0x27350a3f,0x00000000}},	//   rtse, sect, _måne_,
  { {0x660600fe,0x6d485aad,0x69dd5aae,0x00000000}},	//   _arkk, mida, stse,
  { {0x6d4834cc,0x69dd004d,0x2fd8004b,0x00000000}},	//   lida, ptse, _ärgu_,
  { {0x6d4800fe,0x7c28002b,0x659401a4,0x00000000}},	// [b8d0] oida, lydr, иату,
  { {0x6d4834cc,0x39470137,0xc17e0078,0x00000000}},	//   nida, _öns_, žėja_,
  { {0xe3b00021,0x66060659,0x6378013d,0x00000000}},	//   قرن_, _erkk, zíne,
  { {0x6d480029,0x9259183f,0xe3b00021,0x00000000}},	//   hida, нает_, ترك_,
  { {0xe9df0025,0x672d5aaf,0x6d4843e8,0x00000000}},	//   ntú_, mkaj, kida,
  { {0x30750055,0x6d48006d,0x61e900c2,0x00000000}},	//   луйс, jida, _vpel,
  { {0x99820080,0x6d485ab0,0xe9df0025,0x00000000}},	//   zyků_, dida, htú_,
  { {0xdb020164,0xe1f3007e,0x672d5ab1,0x00000000}},	//   pplé, _پسر_, nkaj,
  { {0x6d483df1,0x61e95552,0x4d650121,0x00000000}},	//   fida, _upel, лкив,
  { {0x6d485ab2,0xe0d3007e,0xacf5007b,0x00000000}},	//   gida, _خزر_, учиј,
  { {0x6b8d5ab3,0xe8d90013,0x7c28002b,0x00000000}},	//   _biag, _huỷ_, gydr,
  { {0x63783413,0x6d48572c,0x672d00a8,0x00000000}},	//   píne, aida, jkaj,
  { {0x2bc50053,0x6d485ab4,0x0b430086,0x00000000}},	//   _विवा, bida, снян,
  { {0x6d480fca,0x6f1b017f,0x82760047,0x00000000}},	//   cida, ljuc, טערע_,
  { {0x635c00a8,0x4fac009a,0x0d16009d,0x00000000}},	//   lčne, ֽׁמְ, _תקצט_,
  { {0x672d0089,0x6f1d004d,0x635c00c2,0x00000000}},	//   gkaj, ösch, očne,
  { {0x6e2908f0,0x635c1c7b,0xc606000d,0x00000000}},	// [b8e0] nyeb, nčne, ызай,
  { {0xdff30235,0xe794006a,0x672d0a80,0x00000000}},	//   _आनंद_, _پادک, akaj,
  { {0xe4d7007e,0x7d1c5ab5,0xceb9004c,0x00000000}},	//   اومت_, örsi, kař_,
  { {0xe73a0055,0x1288007e,0x6d485ab6,0x00000000}},	//   _чем_, نمای_, zida,
  { {0x69c00066,0x7c280022,0x00000000,0x00000000}},	//   ámeh, zydr,   ,
  { {0x6ab6007a,0xe3a4007e,0x66040137,0x00000000}},	//   _leyf, _نشری, mvik,
  { {0x6d485ab7,0x660421e6,0x9fe60067,0x00000000}},	//   vida, lvik, استه,
  { {0x6e3b004d,0x6604004b,0x63a3013d,0x00000000}},	//   fzub, ovik, ínne,
  { {0x61340268,0x7c28001f,0x10a64540,0x00000000}},	//   _càlc, wydr, _бизн,
  { {0x6b8d0150,0x6d485ab8,0x7c3a004d,0x00000000}},	//   _siag, uida, tztr,
  { {0x40930032,0x6d485ab9,0xa11300b3,0x00000000}},	//   _المر, rida, _دولت,
  { {0xee3a0138,0x8aa7000d,0x2bc50053,0x00000000}},	//   _пне_, ырод, _विरा,
  { {0x7c3a000f,0x6b8d3b82,0x6d485aba,0x00000000}},	//   sztr, _viag, pida,
  { {0x68fe32c9,0xe9df0025,0x660418cd,0x00000000}},	//   _capd, rtú_, dvik,
  { {0xdb1b0003,0x7aee003b,0x6b8d00be,0x00000000}},	//   ystè, întâ, _tiag,
  { {0xe9df00cd,0xd6d80785,0x96f8032d,0x00000000}},	//   ptú_, лту_, лест_,
  { {0x256f00ea,0x6d5d0003,0x0a6b0062,0x00000000}},	// [b8f0] lüli_, ésag, _ярки_,
  { {0x672d5abb,0x44b424f4,0x45d437c4,0x00000000}},	//   skaj, йбус, софс,
  { {0xa926003d,0x672d082a,0x53a40021,0x00000000}},	//   _dažā, pkaj, مملك,
  { {0x2d8e0037,0x63780bc8,0x929d0022,0x00000000}},	//   _life_, vínc, _małg,
  { {0x62860080,0x8627000d,0xe8d90013,0x00000000}},	//   _úkol, _сьне, _quỷ_,
  { {0xc0c80001,0x25a93986,0x635c00c2,0x00000000}},	//   гуће_, mpal_, včne,
  { {0x98b1001c,0x2a7f0066,0x24e40085,0x00000000}},	//   lizē_, ľuby_, _уцяг,
  { {0x2904001c,0x2727004b,0xcf250021,0x00000000}},	//   ēmai_, _tõnu_, شرعي,
  { {0xed5906cb,0xef16014c,0x98b1008f,0x00000000}},	//   кои_, рмы_, nizē_,
  { {0xd167011c,0x61fb5abc,0xed450086,0x00000000}},	//   _съби, _isul, рноп,
  { {0x610b001c,0x6e3b3db1,0x66090130,0x00000000}},	//   _vēlē, szub, _šekl,
  { {0x92a60022,0x8f9a0063,0x6a860cb2,0x00000000}},	//   _gałę, _סיני, илна,
  { {0x61ed0016,0x3ead5abd,0x3da70e48,0x00000000}},	//   çalh, mbet_, _среб,
  { {0xdb025abe,0x66041310,0xdca51533,0x00000000}},	//   mplí, vvik, _таки,
  { {0x29040080,0xdb1b00ea,0xa7860021,0x00000000}},	//   ěma_, gutó, لشرو,
  { {0xb6a60432,0x66045abf,0x7d1c0137,0x00000000}},	//   риал, tvik, örsv,
  { {0x59760076,0x68fe0078,0x3ead0244,0x00000000}},	// [b900] _выну, _tapd, ibet_,
  { {0x3ead005b,0x66045ac0,0xdb023f3b,0x00000000}},	//   hbet_, rvik, gslö,
  { {0x3cdd0053,0x66e621a9,0x61fb004b,0x00000000}},	//   _खाने_, _кона, _asul,
  { {0x78bc0004,0xf3c9007e,0x74130021,0x00000000}},	//   larv, ابله_, توما,
  { {0x27f8001f,0x98b10023,0x05b90043,0x00000000}},	//   lwrn_, cizē_, _مدّت_,
  { {0xd0d70086,0x78bc438a,0x3f8f0003,0x00000000}},	//   идії_, narv, _aigu_,
  { {0x61fb23c9,0xdce10023,0x42d615ce,0x00000000}},	//   _esul, amlī, _візу,
  { {0x0eea0086,0x256f00ea,0xdb21004b,0x00000000}},	//   тьки_, vüli_, õtüh,
  { {0xb5fb000f,0x0caa08b0,0x78bc1046,0x00000000}},	//   _száz, ктни_, karv,
  { {0x3f8f0dff,0x78bc0e04,0x92a60022,0x00000000}},	//   _eigu_, jarv, _wałę,
  { {0x3ead08d5,0x7bc70006,0x27350137,0x00000000}},	//   bbet_, šjun, _låna_,
  { {0x2d8e0034,0x27f8001f,0x3dcd5ac1,0x00000000}},	//   _wife_, dwrn_, brew_,
  { {0x257400c7,0x9da7005a,0x78bc00b9,0x00000000}},	//   täll_, _къща_, farv,
  { {0x3a2400c7,0x61e25ac2,0x2703008b,0x00000000}},	//   ämpa_, itol, _ổn_,
  { {0xed570001,0x27f8002b,0x7ac70062,0x00000000}},	//   _њој_, gwrn_, _кспе,
  { {0x78bc54ed,0x20110066,0x61e25ac3,0x00000000}},	//   aarv, _ázie_, ktol,
  { {0xdb020137,0x58d5005e,0x78bc5ac4,0x00000000}},	// [b910] tslö, _лопт, barv,
  { {0x25a95ac5,0x929d0051,0x78bc0d2e,0x00000000}},	//   rpal_, _małe, carv,
  { {0x75880071,0x44270c08,0xdb020137,0x00000000}},	//   рств_, ân_, rslö,
  { {0x25a900ea,0x5215218a,0xc878005b,0x00000000}},	//   ppal_, йдет, üğe_,
  { {0x877a014e,0xd5b80062,0x290300c2,0x00000000}},	//   _תארי, _всс_, odja_,
  { {0x09f80132,0x29035ac6,0xe0d80086,0x00000000}},	//   שֶׁר_, ndja_, иві_,
  { {0x61e25ac7,0x63780124,0x29015ac8,0x00000000}},	//   atol, sína, _maha_,
  { {0xaf02005a,0x63780240,0x3ead004d,0x00000000}},	//   зпъл, pína, ubet_,
  { {0xf2d200b7,0x929d0051,0x68f500ea,0x00000000}},	//   _מען_, _całe, kezd,
  { {0xa0c40032,0x68f5376f,0x29015ac9,0x00000000}},	//   _ويقو, jezd, _naha_,
  { {0xdfa70021,0xfb8a0a74,0x78bc5aca,0x00000000}},	//   _ضحاي, лбок_, varv,
  { {0x5e950021,0xdce70058,0x4e44005d,0x00000000}},	//   _الإط, ımıy, _ژئوف,
  { {0x8e850032,0x29015acb,0x78bc5acc,0x00000000}},	//   _الشه, _baha_, tarv,
  { {0x7d1c00c7,0x387a0022,0x7c300046,0x00000000}},	//   örst, _pzpr_, ökré,
  { {0x290104ab,0x6d4f0003,0x69cf3e77,0x00000000}},	//   _daha_, écau, arce,
  { {0x78bc0213,0x7bc15acd,0x2ca2011b,0x00000000}},	//   sarv, mslu, ěkde_,
  { {0x7bc10d02,0xe61f001f,0x78bc5ace,0x00000000}},	// [b920] lslu, _sgôr_, parv,
  { {0x236d0066,0xe9e80066,0x7bc15acf,0x00000000}},	//   _akej_, ľúč_, oslu,
  { {0x05770032,0x69c40024,0x7bc15ad0,0x00000000}},	//   حملة_, _hvie, nslu,
  { {0x69c400eb,0x61e23b7e,0x59af0053,0x00000000}},	//   _kvie, ttol, जीकर,
  { {0x9162008d,0x61e25ad1,0xd36f009b,0x00000000}},	//   _hử_, utol, رهه_,
  { {0x7bc10006,0x61e25ad2,0x20d6071f,0x00000000}},	//   kslu, rtol, сідс,
  { {0x443e01e3,0x61e2429c,0x26000053,0x00000000}},	//   _åt_, stol, रिकी_,
  { {0x69c43ac9,0x3f84008f,0x290300a8,0x00000000}},	//   _ovie, ummu_, zdja_,
  { {0x8e140086,0x171b0047,0x69c4034e,0x00000000}},	//   ідоц, רופע, _nvie,
  { {0x6aa400f3,0xccfa0138,0x7bc1153a,0x00000000}},	//   _afif, ући_, fslu,
  { {0x29010004,0x351b0047,0x3fcb007e,0x00000000}},	//   _raha_, אוינ, _مدنی_,
  { {0x2d8501f2,0x29015ad3,0xa3e00042,0x00000000}},	//   amle_, _saha_, _दमन_,
  { {0x4f650032,0xf2d300b5,0x6abd1bd6,0x00000000}},	//   _بالف, הער_, rasf,
  { {0x69c40006,0x637105e7,0x3ea3004c,0x00000000}},	//   _dvie, råni, ějte_,
  { {0x3cdd0394,0x7c930032,0x91620013,0x00000000}},	//   _खाते_, _عشوا, _cử_,
  { {0xdb090046,0x29010022,0xfc57009a,0x00000000}},	//   rsdó, _waha_, _לבוש_,
  { {0x29010019,0x69c0006d,0xd4b9005e,0x00000000}},	// [b930] _taha_, ámet, илац_,
  { {0xdb1b23c8,0x6f025ad4,0x9634000d,0x00000000}},	//   istí, _laoc, чнуц,
  { {0x69c40b61,0x69c0008f,0xf3f95678,0x00000000}},	//   _zvie, šmet, рнеш_,
  { {0xd251013a,0x69cb00a5,0x2d850075,0x00000000}},	//   ونا_, _åges, zmle_,
  { {0x6d4a117c,0x200c0d52,0xe4a7007b,0x00000000}},	//   _omfa, _ardi_, _грбо,
  { {0xdb1b5ad5,0x7bc100fe,0x612f00b9,0x00000000}},	//   nstâ, yslu, _køli,
  { {0x9162008b,0x7aed0150,0x69a00053,0x00000000}},	//   _xử_, _obat, _गंभी,
  { {0x249b00eb,0x7bc102f0,0x2007082a,0x00000000}},	//   šymą_, vslu, rvni_,
  { {0x200c3d66,0xcee80044,0x6ec400de,0x00000000}},	//   _erdi_, صرين_, ستيق,
  { {0x7bc10179,0x7aed5ad6,0xdc990002,0x00000000}},	//   tslu, _abat, штиш_,
  { {0xc4d20063,0x98b10078,0x2d850139,0x00000000}},	//   וגי_, lizė_, rmle_,
  { {0xf8a9014e,0x7bc15ad7,0x613d00cd,0x00000000}},	//   _יש_, rslu, _bèlg,
  { {0x916200aa,0x2bc50053,0xaa430121,0x00000000}},	//   _sử_, _विका, деял,
  { {0x7aed0019,0x7bc104c7,0xfc310021,0x00000000}},	//   _ebat, pslu, _يحث_,
  { {0x2d9f03b2,0x273c0025,0xc7a342d3,0x00000000}},	//   lque_, _líne_, диск,
  { {0x256f0d21,0x7d035ad8,0x3ebf5ad9,0x00000000}},	//   zült_, _hans, naut_,
  { {0xa526019d,0x69c40024,0xdb1b0016,0x00000000}},	// [b940] омад, _uvie, bstâ,
  { {0x2904003d,0x2d9f5ada,0x9162008b,0x00000000}},	//   ēmas_, ique_, _tử_,
  { {0x0d3a0047,0x256f013d,0x7d035adb,0x00000000}},	//   סגעב, vült_, _mans,
  { {0x386d00bd,0x7d035adc,0x4c6c0047,0x00000000}},	//   ßere_, _lans, נדאַ,
  { {0x26c01ff0,0x7d030137,0x63780124,0x00000000}},	//   maio_, _oans, síno,
  { {0x257400fe,0x26c022cc,0x320d004d,0x00000000}},	//   käli_, laio_, _drey_,
  { {0xdfd00032,0x3ebf0164,0x256f000f,0x00000000}},	//   رية_, faut_, rült_,
  { {0x7d0304c6,0x26c00290,0xdb1b017d,0x00000000}},	//   _aans, naio_, istã,
  { {0x7d03026a,0x320d5add,0x256f013d,0x00000000}},	//   _bans, _grey_, pült_,
  { {0x200c00c2,0x7aed01f4,0xbebd0078,0x00000000}},	//   _trdi_, _sbat, ukūr,
  { {0x3ebf00bd,0x635c5ade,0x7d03102b,0x00000000}},	//   baut_, nčno, _dans,
  { {0x20110066,0x635c007d,0x3ebf5adf,0x00000000}},	//   _ázia_, ično, caut_,
  { {0xed5a5ae0,0xde030c45,0x7d035ae1,0x00000000}},	//   _код_, _опци, _fans,
  { {0x6d4a3240,0x7d03420e,0x635c0061,0x00000000}},	//   _umfa, _gans, kčno,
  { {0xdb02029c,0xdb1b004b,0x28dc0053,0x00000000}},	//   splá, dutö, _बारि,
  { {0x4c3b014e,0x7aed00e3,0x291e0137,0x00000000}},	//   _כתוב, _ubat, ötar_,
  { {0x7d03005b,0xdb1b00cd,0xd49b1a2f,0x00000000}},	// [b950] _yans, mstà, аре_,
  { {0x6d5a5ae2,0xdb1b004b,0xa4d40054,0x00000000}},	//   nnta, gutö, дофі,
  { {0xa2f518e0,0x273c0139,0x612f01e1,0x00000000}},	//   зпеч, _síne_, _kølv,
  { {0x320d0034,0xdb1b00cd,0x8c1b0063,0x00000000}},	//   _prey_, nstà, יובי,
  { {0x10a50002,0xdb1b0137,0x7880013d,0x00000000}},	//   пилн, butö, _táví,
  { {0x7bc7013d,0xdb1b011b,0x8234009b,0x00000000}},	//   ájuk, vrtý, برما,
  { {0x7d035ae3,0xc9540aeb,0x8fa204d6,0x00000000}},	//   _rans, ומס_, наще,
  { {0x25740659,0x273c0139,0x6d5a37ca,0x00000000}},	//   väli_, _tíne_, enta,
  { {0x7d035ae4,0x3ebf5ae5,0x30a70988,0x00000000}},	//   _pans, raut_, _древ,
  { {0x559c00b5,0x2d9f5ae6,0x3ebf0003,0x00000000}},	//   בסזײ, rque_, saut_,
  { {0x7d035ae7,0x2d9f04bc,0x613d00cd,0x00000000}},	//   _vans, sque_, _cèle,
  { {0x2d990fac,0xf1cf0053,0xac38000d,0x00000000}},	//   íses_, _हटान, ючых_,
  { {0x7d035ae8,0x5e9a0063,0x82d6009a,0x00000000}},	//   _tans, _הבנק, הורג_,
  { {0x7d0302ab,0xdb1900a5,0x8c4510ae,0x00000000}},	//   _uans, _avvä, _неле,
  { {0xdb1b00cd,0x7b0500fe,0x26c00a02,0x00000000}},	//   bstà, öttä, taio_,
  { {0xac16005e,0xdb3a005d,0xc6920044,0x00000000}},	//   _хоћу_, _دستش_, ِّر_,
  { {0x26c0051e,0xdce1003b,0x8b3b0063,0x00000000}},	// [b960] raio_, colă, _לתקצ,
  { {0x26c013ba,0x69c65ae9,0x649a5aea,0x00000000}},	//   saio_, mske, стар_,
  { {0x389b00b5,0x69c65aeb,0xf8b3009a,0x00000000}},	//   _ליינ, lske, _אשת_,
  { {0x63780080,0x69c600fe,0x25740137,0x00000000}},	//   mínk, oske, jälv_,
  { {0x2d9d021f,0xdb0200d1,0x6d5a5aec,0x00000000}},	//   _nuwe_, pplæ, ynta,
  { {0x9f5e0024,0x98a40006,0x672400c2,0x00000000}},	//   _isté_, ėmė_, ljij,
  { {0xf3f10013,0x653b0041,0xb4ca0042,0x00000000}},	//   _ập_, _פעלד, ोली_,
  { {0x67245372,0x69c65aed,0x67360078,0x00000000}},	//   njij, kske, nkyj,
  { {0x69c65aee,0x7d6a0086,0xdfd0007e,0x00000000}},	//   jske, йшов_, ريک_,
  { {0x613d0003,0x612f06a5,0x3f9a013d,0x00000000}},	//   _pèle, _sølv, ípus_,
  { {0x44445aef,0x4c940002,0xf1d20042,0x00000000}},	//   nz_, ќинс, _सिडन,
  { {0xaf050086,0x63b80066,0x44445af0,0x00000000}},	//   _очік, ávny, iz_,
  { {0x6e930032,0x3e850164,0xc33300ff,0x00000000}},	//   _كلما, rêté_, גור_,
  { {0x2bc50161,0x3f9e5af1,0xfbcf007e,0x00000000}},	//   _विचा, _kutu_, ختی_,
  { {0xdb1b5af2,0x3f9e004b,0xc8640239,0x00000000}},	//   astá, _jutu_, етти,
  { {0x44445af3,0x7bda240d,0x6b845af4,0x00000000}},	//   dz_, mutu, _ghig,
  { {0x7bda047f,0x69c6013d,0x444428f4,0x00000000}},	// [b970] lutu, cske, ez_,
  { {0xd49b000a,0x272e0026,0xe4a40ada,0x00000000}},	//   сра_, _sýnt_, ерцо,
  { {0x9f5e2cff,0x25f90053,0xe57004f6,0x00000000}},	//   _esté_, _उनकी_, اطق_,
  { {0x799f00ac,0xa255007e,0x6280009c,0x00000000}},	//   _kuqw, وپاش, _bzmo,
  { {0x7bda0019,0x623404f2,0xa3cf0042,0x00000000}},	//   hutu, нецу, _शिव_,
  { {0x7bda5af5,0x2d9d0983,0xe1f80085,0x00000000}},	//   kutu, _ruwe_, ягі_,
  { {0x44440045,0x7bda0019,0xdb1b0026,0x00000000}},	//   cz_, jutu, mstæ,
  { {0x7bda078c,0xee3905ef,0x69c65af6,0x00000000}},	//   dutu, жни_, yske,
  { {0x6b84002b,0x6378013d,0x81d402d8,0x00000000}},	//   _rhig, zínk, _потх,
  { {0x273c0026,0x69c6104c,0xdb1b5af7,0x00000000}},	//   _mína_, vske, vstá,
  { {0x273c0026,0x7bda0019,0x660d004b,0x00000000}},	//   _lína_, gutu, hvak,
  { {0x60c34067,0x2b16005a,0x660d1df9,0x00000000}},	//   lanm, фьор, kvak,
  { {0xba230086,0x44440d11,0x612f06a5,0x00000000}},	//   вдяк, zz_, _følt,
  { {0x7bda5af8,0x69c60386,0xdd94000d,0x00000000}},	//   butu, rske, _зачы,
  { {0x660d0122,0x6d410025,0x9f5e0290,0x00000000}},	//   evak, mhla, _artù_,
  { {0x257400bd,0x6f095af9,0x44440006,0x00000000}},	//   hält_, ndec, vz_,
  { {0xa5f7000a,0xd8385afa,0x60c311f6,0x00000000}},	// [b980] меѓу_, šč_, kanm,
  { {0x637803d9,0x44445afb,0x60c30072,0x00000000}},	//   míni, tz_, janm,
  { {0x68fc053b,0xdb0200c7,0xd91b0e2a,0x00000000}},	//   merd, pplä, _וויל,
  { {0x44445afc,0x68fc5afd,0xdb0900a5,0x00000000}},	//   rz_, lerd, ssdö,
  { {0x257401e3,0x4444128b,0x6d410397,0x00000000}},	//   fält_, sz_, khla,
  { {0x3f9e1794,0x68fc5afe,0x7bda005b,0x00000000}},	//   _putu_, nerd, yutu,
  { {0x68fc021f,0x2b0e0161,0x63780025,0x00000000}},	//   ierd, ियाँ_, híni,
  { {0x7bda021e,0x68fc5aff,0x7d0800a3,0x00000000}},	//   vutu, herd, wdds,
  { {0x10a6184a,0x929d0051,0x68fc5b00,0x00000000}},	//   _жизн, _zało, kerd,
  { {0xe0d70138,0x6d415b01,0x7bda5b02,0x00000000}},	//   _ову_, ghla, tutu,
  { {0x718b0063,0x7bda0ff2,0xdb550121,0x00000000}},	//   _וְאַ, uutu, евны,
  { {0x68fc016d,0x2cb1005b,0x612f05b9,0x00000000}},	//   eerd, ızda_, _føls,
  { {0x7bda0004,0x6d410139,0x68fc5b03,0x00000000}},	//   sutu, bhla, ferd,
  { {0x6d4120ed,0x7bda5b04,0x68fc5b05,0x00000000}},	//   chla, putu, gerd,
  { {0x5c06005a,0x212c0027,0x273c0026,0x00000000}},	//   _цяла, _modh_, _sína_,
  { {0x60c3005b,0x68fc002b,0x660d5b06,0x00000000}},	//   zanm, aerd, tvak,
  { {0x35f5000d,0x6378017d,0x660d0072,0x00000000}},	// [b990] эпар, cíni, uvak,
  { {0x69dd5b07,0x68fc5b08,0x660d5b09,0x00000000}},	//   muse, cerd, rvak,
  { {0x69dd0004,0xdb1b5b0a,0x7afd0983,0x00000000}},	//   luse, rstæ, oest,
  { {0xdb1b0026,0x7afd5b0b,0x212c0139,0x00000000}},	//   sstæ, nest, _aodh_,
  { {0x69dd0004,0x9294000d,0xfe08001b,0x00000000}},	//   nuse, вацц, _nữ_,
  { {0xdb1b0502,0x7afd5b0c,0x3a240072,0x00000000}},	//   lstä, hest, ämpi_,
  { {0x6f0900bd,0x7afd5b0d,0x60c35b0e,0x00000000}},	//   tdec, kest, ranm,
  { {0xdb1b35e8,0x60c30146,0x2d8c0250,0x00000000}},	//   nstä, sanm, emde_,
  { {0x9f470024,0xdb1b0d90,0x60c30058,0x00000000}},	//   ntné_, istä, panm,
  { {0x69dd5b0f,0xfe08001b,0x50f40002,0x00000000}},	//   duse, _dữ_, _изут,
  { {0xdb1b00c7,0x69dd0164,0x116a007e,0x00000000}},	//   kstä, euse, _علمی_,
  { {0xf41200b5,0x9f470024,0x60c15b10,0x00000000}},	//   אפט_, ktné_, _helm,
  { {0x69dd0004,0x60c15b11,0x8de40021,0x00000000}},	//   guse, _kelm, _لكنه,
  { {0xf1b2014e,0x61eb004d,0x9c8200c2,0x00000000}},	//   רסם_, itgl, ščam,
  { {0xdb1b004d,0x7afd5b12,0x99890022,0x00000000}},	//   fstä, best, _brał_,
  { {0x61340994,0xb5fb006d,0x7afd5b13,0x00000000}},	//   _vàli, _exám, cest,
  { {0xdce8001c,0xcf920e2a,0x95860612,0x00000000}},	// [b9a0] lodā, רטן_, елае,
  { {0xec09001b,0x6d860014,0xe57703a6,0x00000000}},	//   _kế_, rðag, езу_,
  { {0x2b4000c3,0xdb1b004d,0xccf20063,0x00000000}},	//   _klic_, bstä, רכב_,
  { {0x4426007d,0x99890022,0xb376005d,0x00000000}},	//   ćo_, _grał_, رداش,
  { {0x2d870199,0x635c00c3,0x2005053b,0x00000000}},	//   _ohne_, nčni, _asli_,
  { {0x7afd0045,0xdb1b12f5,0xe137000d,0x00000000}},	//   zest, mstå, нзіі_,
  { {0x7afd0031,0x9162001b,0x224600ea,0x00000000}},	//   yest, _cứ_, szok_,
  { {0x60c10004,0x80030076,0x77f70063,0x00000000}},	//   _eelm, учше, תמקד_,
  { {0x916200aa,0xdb1b5b14,0xe3570063,0x00000000}},	//   _từ_, nstå, _נשמח_,
  { {0x69dd0004,0x9f5e0024,0x60c1005b,0x00000000}},	//   vuse, _istí_, _gelm,
  { {0x3f860034,0x2d8c016d,0xdb1b29c6,0x00000000}},	//   _thou_, rmde_, irtö,
  { {0x3f530529,0x7afd5b15,0x69dd5b16,0x00000000}},	//   nţul_, uest, tuse,
  { {0xdb1b00c7,0xd1380022,0xdb240014,0x00000000}},	//   vstä, _ciąg_, _ósýn,
  { {0x7afd450b,0x69dd3f2f,0xdb1b102d,0x00000000}},	//   sest, ruse, dstå,
  { {0x69dd0004,0xd7f814cf,0x63780026,0x00000000}},	//   suse, нут_, línu,
  { {0x2b40001f,0xdb1b004d,0x6c7b009a,0x00000000}},	//   _glic_, ustä, _מאופ,
  { {0xa5f80086,0xdb1b5b17,0x80e00042,0x00000000}},	// [b9b0] нету_, rstä, नलाइ,
  { {0xfaff00e8,0x9f470024,0xdb1b0502,0x00000000}},	//   leë_, rtné_, sstä,
  { {0x9f47027d,0xdb1b0137,0xec090013,0x00000000}},	//   stné_, pstä, _xế_,
  { {0xd6db22c1,0x92590076,0xd3240376,0x00000000}},	//   _это_, мает_, льчи,
  { {0xe28e000d,0x39840137,0x52740239,0x00000000}},	//   ра_, lösa_, лушу,
  { {0x7d0a003e,0x98b4007d,0xd1840454,0x00000000}},	//   _nafs, čeći_, глій,
  { {0xe8140394,0x60c10080,0xb8140053,0x00000000}},	//   डिया_, _velm, डियम_,
  { {0x27e700c7,0x43940091,0xbe390054,0x00000000}},	//   _ännu_, _басс, дчої_,
  { {0x3f8d0268,0x5f760021,0x60c13c5c,0x00000000}},	//   rmeu_, خميس_, _telm,
  { {0x29cd0024,0x635c00c2,0x80a40021,0x00000000}},	//   dľa_, včni, _ممكن,
  { {0xbb460635,0x0c22000d,0xcb6a5b18,0x00000000}},	//   венк, амэн, дане_,
  { {0xe9a6000d,0x3cdd0053,0xec090013,0x00000000}},	//   камп, _खाके_, _vế_,
  { {0x613400cd,0x8f360063,0x26c202f7,0x00000000}},	//   _vàlv, _שאנו_, _reko_,
  { {0x49990055,0xec09001b,0x23d10161,0x00000000}},	//   ется_, _tế_, _हिंद,
  { {0x929d0051,0x8c4203d6,0x8c450ace,0x00000000}},	//   _całk, _веще, _шеке,
  { {0xdb1b01b9,0x41d20053,0x2eff0003,0x00000000}},	//   tstå, _सिलस, neuf_,
  { {0x9676000d,0x64a6014b,0x00000000,0x00000000}},	// [b9c0] тыві, ваза,   ,
  { {0xdb1b3a03,0x9c7c00a8,0xdce1005f,0x00000000}},	//   rstå, lgča, tolę,
  { {0x232a000a,0xd7ca03eb,0xd4f5000d,0x00000000}},	//   можи_, _توجه_, ыяты,
  { {0xdb1b0c4a,0x29070139,0x9f4e0058,0x00000000}},	//   pstå, _ónar_, ünür_,
  { {0xe2970259,0x6b460025,0x3f53003b,0x00000000}},	//   вац_, _tógf, rţul_,
  { {0xd12f0021,0x39580edc,0xdfd00049,0x00000000}},	//   يمن_, nirs_, ميت_,
  { {0x7af60061,0x800602b6,0x7d0a5b19,0x00000000}},	//   _obyt, тчле, _rafs,
  { {0x63785b1a,0x831a0021,0x657e0168,0x00000000}},	//   tínu, _تقرر_, llph,
  { {0x613400cd,0x6467003b,0x660420ea,0x00000000}},	//   _bàlt, ăriţ, nwik,
  { {0x9162001b,0xfaff00ac,0x205611f7,0x00000000}},	//   _dữ_, weë_, _итер,
  { {0xfaff00ac,0x2eff1ca8,0xa5150041,0x00000000}},	//   teë_, beuf_, אַרג_,
  { {0xee3a0001,0x4ea30002,0x98a70058,0x00000000}},	//   _оне_, _крша, _ını_,
  { {0x7d0a2f71,0x672f007d,0xda780085,0x00000000}},	//   _tafs, _rocj, вяр_,
  { {0x7d0a00b9,0x672f0051,0x6f00005b,0x00000000}},	//   _uafs, _socj, lemc,
  { {0x3cfb0063,0xfaff00ac,0x63780530,0x00000000}},	//   _חלונ, peë_, níns,
  { {0x6aad0035,0x7b14005a,0xd6d848e4,0x00000000}},	//   _ufaf, _вдъх, кту_,
  { {0xf7940088,0x69c0017d,0xa6340086,0x00000000}},	// [b9d0] ратэ, âmet, анті,
  { {0xf8b70394,0x7af61959,0x7bda4575,0x00000000}},	//   _अभिय, _zbyt, ortu,
  { {0xc7ab0021,0x7afa00ea,0x6d5d0003,0x00000000}},	//   _تدخل_, őtte, ésai,
  { {0x2d9c5b1b,0x20110066,0x6f002904,0x00000000}},	//   _live_, _ázii_, jemc,
  { {0xd179000d,0xccf8004c,0x66f6009f,0x00000000}},	//   нскі_, vněn_, _גמרא_,
  { {0x6441004b,0xc244046e,0x00000000,0x00000000}},	//   _ülio, шнік,   ,
  { {0x7ff5006a,0xdb0200d1,0x7f420b16,0x00000000}},	//   استا, pplø, _bloq,
  { {0xa295000d,0x64580022,0xaff60021,0x00000000}},	//   _бабі, ócił, افيا_,
  { {0x7bda5b1c,0x22940156,0x63781494,0x00000000}},	//   ertu, _витя, rínt,
  { {0x9f5e0994,0xfc2909c2,0x3afe0013,0x00000000}},	//   _està_, ежок_, _ắp_,
  { {0xccf8004c,0x2d9c3183,0x9f47004c,0x00000000}},	//   mněl_, _dive_, ltní_,
  { {0x27350137,0xab2a4ab1,0xa3f6009a,0x00000000}},	//   _måns_, хома_, נמרק_,
  { {0x9f4702f4,0x2d9c0034,0xa142001c,0x00000000}},	//   ntní_, _five_, _šķie,
  { {0x2d9c08dc,0x2b590025,0x98760001,0x00000000}},	//   _give_, aisc_, губљ,
  { {0x7d015b1d,0x6d435b1e,0x18670794,0x00000000}},	//   mels, _ilna, гари_,
  { {0x290c0117,0x7c3c191f,0x66040102,0x00000000}},	//   žda_, ørre, twik,
  { {0x7d01006f,0x05661dd6,0x39584ff6,0x00000000}},	// [b9e0] oels, гван, pirs_,
  { {0x273504c7,0x7d010b19,0x66045b1f,0x00000000}},	//   _sånt_, nels, rwik,
  { {0x0d3a0047,0xa93b0041,0x61fb5b20,0x00000000}},	//   עגעב, _נײטי, _apul,
  { {0xf26a05fb,0xdb040137,0x71a6000d,0x00000000}},	//   ниел_, _utnä, гадз,
  { {0x599a0063,0x4b4d0047,0x7d0106f1,0x00000000}},	//   ֲשֶׁ, וגאַ, kels,
  { {0x7d0118a4,0xc5ff001c,0x63780195,0x00000000}},	//   jels, ģētu_, tíns,
  { {0x7d011781,0x656b00ea,0x99820006,0x00000000}},	//   dels, éghe, lykų_,
  { {0x7d01004b,0x2d9c5b21,0x2dd45b22,0x00000000}},	//   eels, _sive_, ажир,
  { {0xdb1b10c4,0x6da30002,0x7d015b23,0x00000000}},	//   mstø, биња, fels,
  { {0x7d0102ea,0xdb1b02ab,0x61e20006,0x00000000}},	//   gels, lstø, muol,
  { {0x9f5e0747,0x51930021,0x2d9c3cf3,0x00000000}},	//   _está_, _اللذ, _vive_,
  { {0xdb1b01f2,0xe9f90013,0x543b0041,0x00000000}},	//   nstø, _ngả_, געטא,
  { {0x2d9c017d,0x61e20b4f,0x2b595b24,0x00000000}},	//   _tive_, nuol, risc_,
  { {0x273c0013,0xdd90009e,0x7d015b25,0x00000000}},	//   _hính_, _بوت_, cels,
  { {0x273c008b,0xa2c70053,0x6d5a3b42,0x00000000}},	//   _kính_, ारम्, mita,
  { {0x6d5a5b26,0x61e24813,0x8b67005d,0x00000000}},	//   lita, kuol, _حاتم,
  { {0xdb1b00b9,0x6d4800fe,0xc4db0001,0x00000000}},	// [b9f0] dstø, ohda, еђе_,
  { {0x273c008b,0x6d5a516f,0x61e2004e,0x00000000}},	//   _lính_, nita, duol,
  { {0x29035b27,0x69cf3849,0xe97c0047,0x00000000}},	//   meja_, lsce, _אנזש,
  { {0x6d5a35c6,0xd2150001,0x6441004b,0x00000000}},	//   hita, имећ, _ülim,
  { {0x90c50088,0x6d5a14f1,0x7d010246,0x00000000}},	//   абле, kita, yels,
  { {0x69cf0025,0x672d3dd5,0x6d5a0b88,0x00000000}},	//   isce, ljaj, jita,
  { {0x9f470080,0x7d011a94,0xdb040003,0x00000000}},	//   stní_, vels, _funè,
  { {0x6d5a007a,0x7d010035,0x672d5b28,0x00000000}},	//   eita, wels, njaj,
  { {0x3f83003d,0x61e22437,0x7d015b29,0x00000000}},	//   ēju_, cuol, tels,
  { {0x6d5a44f8,0x69cf38bb,0x29030072,0x00000000}},	//   gita, dsce, jeja_,
  { {0x7d011c36,0x29035b2a,0x69dd5b2b,0x00000000}},	//   rels, deja_, erse,
  { {0x6b8d0009,0x6d5a572c,0xbd45007e,0x00000000}},	//   _chag, aita, انگي,
  { {0x6d5a2e0b,0x672d5b2c,0x7d015b2d,0x00000000}},	//   bita, djaj, pels,
  { {0xfce20002,0x2903021e,0x186a0086,0x00000000}},	//   _дошо, geja_, ваги_,
  { {0x63a700c3,0x5c790047,0xdb04006c,0x00000000}},	//   _nujn, _באַה, _luné,
  { {0xf8630054,0xb6a30054,0xb759012c,0x00000000}},	//   івто, житл, гшує_,
  { {0x4b7b00b5,0x6d860026,0x6e3b0360,0x00000000}},	// [ba00] _באקו, iðan, nyub,
  { {0xf53f31c8,0x14c8007e,0x443a5b2e,0x00000000}},	//   _står_, اهای_, typ_,
  { {0x35da0053,0x05770021,0xdb1b01e1,0x00000000}},	//   यूज़, جملة_, tstø,
  { {0x6d5a418d,0x69c40051,0x1bf60047,0x00000000}},	//   zita, _kwie, יצער_,
  { {0xdb1b0307,0x7c3a0022,0x2240013d,0x00000000}},	//   rstø, zytr, áik_,
  { {0x41530086,0xf1c20006,0x61e25b2f,0x00000000}},	//   овіс, višą_, ruol,
  { {0x40340088,0x61e207a0,0x6d5a5b30,0x00000000}},	//   сейс, suol, vita,
  { {0x61e2024a,0x3ea20031,0xdb040003,0x00000000}},	//   puol, økt_, _funé,
  { {0x6b8d0185,0x386d01f7,0x5d54005a,0x00000000}},	//   _rhag, ğeri_, йкит,
  { {0x2366017f,0x6d5a5b31,0xc5f30063,0x00000000}},	//   lnoj_, uita, קדת_,
  { {0x273c001b,0x29035b32,0x6280002b,0x00000000}},	//   _tính_, veja_, _hymo,
  { {0xdb02007a,0x6d5a0e5c,0x7c3a1ab7,0x00000000}},	//   pplý, sita, rytr,
  { {0x29035b33,0x69dd5b34,0x69cf006c,0x00000000}},	//   teja_, urse, usce,
  { {0x69cf00ca,0x69c40022,0x5ba600fb,0x00000000}},	//   rsce, _dwie, _криз,
  { {0x60c85b35,0x6b8d0025,0x29035b36,0x00000000}},	//   _medm, _thag, reja_,
  { {0x29035b37,0x2366017f,0xdc9b0165,0x00000000}},	//   seja_, jnoj_, _ביול,
  { {0xa3c90235,0x2366017f,0x672d1253,0x00000000}},	// [ba10] लीन_, dnoj_, rjaj,
  { {0x64410004,0x4a7c0063,0xe9df0139,0x00000000}},	//   _ülik, _ברחב, mrú_,
  { {0x69c42761,0x66160078,0xf4590044,0x00000000}},	//   _zwie, avyk, دلاع_,
  { {0x9f470066,0x66160114,0x9295000d,0x00000000}},	//   ktná_, bvyk, баец,
  { {0x62800185,0x6d585b38,0xe9df0025,0x00000000}},	//   _cymo, _omva, nrú_,
  { {0x2bac0080,0x6280292d,0xdb240046,0x00000000}},	//   _něco_, _dymo, _ósön,
  { {0xe9df0027,0x2366007d,0x7aed5b39,0x00000000}},	//   hrú_, bnoj_, _ocat,
  { {0x7535000f,0x63a05b3a,0x929d0022,0x00000000}},	//   _hozz, _gimn, _bałt,
  { {0x6d86007a,0x6280001f,0x66ef0042,0x00000000}},	//   rðan, _gymo, _छानक_,
  { {0x1d090001,0x4154042c,0xcc350021,0x00000000}},	//   ћени_, _двус, مرجع,
  { {0xe9df006d,0x75355b3b,0xeb9a058f,0x00000000}},	//   erú_, _mozz, лио_,
  { {0x1b4a005e,0xa3c90042,0x00000000,0x00000000}},	//   узми_, लीय_,   ,
  { {0x3ebf053b,0x5f740021,0xe9df0139,0x00000000}},	//   mbut_, _بالر, grú_,
  { {0x4e7a00b5,0xdd94000d,0x9f5e00fe,0x00000000}},	//   _גאנצ, _дачы, _estä_,
  { {0x7aed00fe,0x6441004b,0xa78600f2,0x00000000}},	//   ältö, _ülih, مشرو,
  { {0x7aed0025,0x69c40051,0xe9df0066,0x00000000}},	//   _gcat, _twie, brú_,
  { {0xe9df0027,0x7535051e,0x2366017f,0x00000000}},	// [ba20] crú_, _bozz, vnoj_,
  { {0x6d415b3c,0x753501f4,0x9986007e,0x00000000}},	//   nkla, _cozz, _دلخو,
  { {0x2366017f,0x75350290,0x60c81b13,0x00000000}},	//   tnoj_, _dozz, _redm,
  { {0xd3790086,0x6d860026,0x60c80ffc,0x00000000}},	//   ачі_, eðal, _sedm,
  { {0xa2aa0161,0x2366017f,0x26c03046,0x00000000}},	//   टशब्, rnoj_, mbio_,
  { {0x2366017f,0x26c00006,0x3ebf132b,0x00000000}},	//   snoj_, lbio_, ebut_,
  { {0x63a000f3,0x2366007d,0x26c0007d,0x00000000}},	//   _timn, pnoj_, obio_,
  { {0x6280001f,0xbdb40095,0xadb40699,0x00000000}},	//   _tymo, обиј, обиш,
  { {0xc2460001,0xad260044,0x6da301ce,0x00000000}},	//   _унак, مردو, пиња,
  { {0xf1bf0080,0x9f470066,0x7aed5b3d,0x00000000}},	//   ášen_, rtná_, _scat,
  { {0xdefa0055,0x30860032,0x9f47027d,0x00000000}},	//   _был_, _الاف, stná_,
  { {0x6d415b3e,0xe9df0014,0x395a5b3f,0x00000000}},	//   akla, trú_, _amps_,
  { {0x4427001b,0x6e960032,0x09e4000d,0x00000000}},	//   ̣n_, _الشا, поўн,
  { {0x6d415b40,0x273c0026,0xdb1b004d,0x00000000}},	//   ckla, _mínu_, lstü,
  { {0x273c0026,0xc051009a,0x75355b41,0x00000000}},	//   _línu_, ֵ֖ל_, _rozz,
  { {0x6b460025,0xdb1b004d,0xf62b0054,0x00000000}},	//   _tóga, nstü, лізи_,
  { {0x75352437,0xa5352254,0xf1b9007d,0x00000000}},	// [ba30] _pozz, онач, _krše_,
  { {0x98c70ac5,0x85050021,0x2b490139,0x00000000}},	//   _усил, توطن, _hlac_,
  { {0x26c0051e,0x63550086,0x75880121,0x00000000}},	//   bbio_, овжу, сств_,
  { {0xd8b8006a,0x7535298c,0xdb1b0014,0x00000000}},	//   _پدیا_, _wozz, mstó,
  { {0x753501f4,0xdb1b0014,0xd5b8005e,0x00000000}},	//   _tozz, lstó, _гсс_,
  { {0xa5bb007a,0x2b495b42,0x3ea600a4,0x00000000}},	//   _próf, _llac_, _agot_,
  { {0x6d86007a,0x6d415b43,0x661d007d,0x00000000}},	//   rðal, vkla, _hrsk,
  { {0x63b80024,0xfe45000a,0x1dd40053,0x00000000}},	//   ívne, жнио, _दिखत,
  { {0x26cb0a02,0xf1e00053,0x8237007e,0x00000000}},	//   _meco_, _नियन, _ارزا,
  { {0xbc19000d,0xdb1b5b44,0xec790121,0x00000000}},	//   аімі_, kstó, ипп_,
  { {0x25a3006f,0x6d415b45,0x26c0002b,0x00000000}},	//   _mijl_, rkla, ybio_,
  { {0xa3e10161,0x6d415b46,0x661d2a6d,0x00000000}},	//   _दिन_, skla, _orsk,
  { {0x6d415b47,0x5e58012c,0x5f7404a0,0x00000000}},	//   pkla, _лиця_, _عامر,
  { {0x07a65b48,0x25a300ca,0xac74005d,0x00000000}},	//   жавн, _nijl_, _کاهش,
  { {0xe73a1d6d,0x26cb00be,0x25b9008f,0x00000000}},	//   аев_, _beco_, _atsl_,
  { {0x661d0198,0x236d00c3,0x26cb0b10,0x00000000}},	//   _brsk, _njej_, _ceco_,
  { {0xdb043ea2,0x29130137,0x25a300ca,0x00000000}},	// [ba40] _juní, _faxa_, _bijl_,
  { {0xd5b10013,0x2d85002b,0xdb04017c,0x00000000}},	//   _ắt_, nlle_, _muní,
  { {0x386d00bd,0x273c0026,0x2d85008a,0x00000000}},	//   ßert_, _sínu_, ille_,
  { {0x03260ac5,0x32d60085,0xa5bb056c,0x00000000}},	//   юден, іцес, _bród,
  { {0x67264cfc,0x386d00dd,0xb77b0041,0x00000000}},	//   _inkj, şert_, _כאטש,
  { {0x6143093e,0x64a60085,0x70560043,0x00000000}},	//   меча, _фава, ينشا,
  { {0x9f5e0024,0x443e00b9,0xdb1b298c,0x00000000}},	//   _istú_, _æt_, istò,
  { {0x6d860026,0x2d855b49,0x9326005d,0x00000000}},	//   rðam, elle_, _برسن,
  { {0xdb1b0199,0x28bf0053,0xcd060811,0x00000000}},	//   rstü, ्रमि, очни,
  { {0xdb1b5b4a,0x63be00d1,0x62590054,0x00000000}},	//   mpté, oppn, _урср_,
  { {0xf1b9007d,0xdb1b0003,0x61e40139,0x00000000}},	//   _vrše_, lpté, áilf,
  { {0x273c0026,0x8cba0053,0x201e0072,0x00000000}},	//   _míns_, _श्रो, _irti_,
  { {0xfd0f006a,0x61e25b4b,0xf2d300ff,0x00000000}},	//   رجی_, nrol, וער_,
  { {0x6b460025,0x26cb0419,0x3c460021,0x00000000}},	//   _hógl, _seco_, _وَإِ,
  { {0x5884000d,0xa1570063,0x78b001c8,0x00000000}},	//   дыта, קבלה_, _živý,
  { {0x7d080146,0x9f5e0139,0x61e25b4c,0x00000000}},	//   leds, _astú_, krol,
  { {0x25a30122,0x29135b4d,0x7d08006f,0x00000000}},	// [ba50] _pijl_, _taxa_, oeds,
  { {0x61e25b4e,0xef190051,0x7d082a8f,0x00000000}},	//   drol, może_, neds,
  { {0x26cb01f4,0x61e24998,0xf3f9130d,0x00000000}},	//   _teco_, erol, снеш_,
  { {0x7d080146,0xdb0b00c7,0xa87a0063,0x00000000}},	//   heds, _utfä, _לאתר,
  { {0xd25b0635,0x201e50aa,0x2d855b4f,0x00000000}},	//   јце_, _arti_, ylle_,
  { {0x398400fe,0x2b920066,0xdce8004c,0x00000000}},	//   tösi_, máce_, rodě,
  { {0x2b92004c,0xdb020014,0x236d00a5,0x00000000}},	//   láce_, mplö, _tjej_,
  { {0x61e25b50,0x6d4a0e6c,0x1f55014b,0x00000000}},	//   brol, _alfa, ятлё,
  { {0x201e00e3,0x61e236ae,0x2d855b51,0x00000000}},	//   _erti_, crol, tlle_,
  { {0x2d855b52,0x660d0089,0x613d01a8,0x00000000}},	//   ulle_, iwak, _cèlt,
  { {0x212a005d,0x00000000,0x00000000,0x00000000}},	//   _ديلی_,   ,   ,
  { {0x660d00ac,0xdb040858,0x98b80078,0x00000000}},	//   kwak, _tuní, ikrą_,
  { {0x4a43005a,0x7d081eda,0xdb04003b,0x00000000}},	//   еняв, beds, _punâ,
  { {0xdce1001c,0xfbd10021,0x2718008d,0x00000000}},	//   rolē, _كتب_, _ọn_,
  { {0x99190086,0x660d3c0c,0x613d01a8,0x00000000}},	//   ціях_, ewak, _hèls,
  { {0xcc3a00b5,0xdb1b0003,0x7c3c086f,0x00000000}},	//   _לעצט, ypté, ärre,
  { {0x660d00a4,0xe7370ac5,0x273c0014,0x00000000}},	// [ba60] gwak, чет_, _síns_,
  { {0x4583000a,0x2bc20161,0x22d90047,0x00000000}},	//   егув, वीका, _פּראָט,
  { {0xe7eb0053,0xd36f5b53,0x61e2002b,0x00000000}},	//   जूदा_, еч_, wrol,
  { {0x29185b54,0xe5a6000a,0x7d080045,0x00000000}},	//   ldra_, _ними, zeds,
  { {0x26d25b55,0x29180983,0xe5a60320,0x00000000}},	//   mayo_, odra_, _хиги,
  { {0x61e22bbe,0xe4da006a,0xdfd003eb,0x00000000}},	//   rrol, _دوست_, نيت_,
  { {0x7d0802ab,0x28bf0053,0x9f980499,0x00000000}},	//   veds, ्रति, овку_,
  { {0x7dc40032,0x9989000c,0x26d20c55,0x00000000}},	//   وقعن, _oraş_, nayo_,
  { {0x7d08010a,0x91e3560e,0x91e601ce,0x00000000}},	//   teds, _поте, _хозе,
  { {0xc1bb0063,0xa06a3320,0x63ae0130,0x00000000}},	//   _לממש, _лаза_, _kubn,
  { {0x26d202ae,0x2918220d,0x6f095b56,0x00000000}},	//   kayo_, ddra_, beec,
  { {0xbebd008f,0x29180023,0x657e30e6,0x00000000}},	//   sjūr, edra_, hoph,
  { {0x63ae0089,0xd3570063,0xda7b089a,0x00000000}},	//   _lubn, ליטי_, сян_,
  { {0xada3000a,0x290a0078,0x3a200ac9,0x00000000}},	//   _зачл, geba_, _drip_,
  { {0xd6db5b57,0x67d50054,0x657e11a2,0x00000000}},	//   йта_, ьову, doph,
  { {0x29180e36,0x657e007d,0x660d1667,0x00000000}},	//   adra_, eoph, twak,
  { {0xaac30161,0x4ac30161,0x290a5b58,0x00000000}},	// [ba70] _व्यक, _व्यव, beba_,
  { {0x660d06c2,0xa5bb4aea,0x290a017d,0x00000000}},	//   rwak, _prób, ceba_,
  { {0x26d20009,0x6d860026,0xa2f51406,0x00000000}},	//   bayo_, rðah, дпеч,
  { {0x1ddd0053,0x63ae16b3,0x7aef2aa8,0x00000000}},	//   _मिलत, _dubn, ngct,
  { {0xdb020137,0xe2900021,0xa5bb0022,0x00000000}},	//   pplö, هذه_, _wrób,
  { {0xf8bf0161,0x2bac0080,0x35a4000d,0x00000000}},	//   ्रिय, _těch_, _паўг,
  { {0xe0d0006a,0x7bdc00ea,0xdb040445,0x00000000}},	//   ازه_, árul, _luná,
  { {0x321f001b,0x2f54019d,0x7afd006f,0x00000000}},	//   _truy_, етьс, jfst,
  { {0x7bca00e5,0x6b56008f,0x6f09059f,0x00000000}},	//   _awfu, kšgr, reec,
  { {0x61e40025,0x290a00ac,0xed590086,0x00000000}},	//   áile, xeba_, іон_,
  { {0x7afd051c,0x3b0a185b,0xdca50002,0x00000000}},	//   ffst, оено_, ќани,
  { {0x61e400c2,0xddc90022,0x398400a5,0x00000000}},	//   šile, rzeł, höst_,
  { {0x657e4e5e,0x39840014,0x3e69007e,0x00000000}},	//   yoph, köst_, _بجای_,
  { {0x7afd153a,0xd5b1008d,0x657e1433,0x00000000}},	//   afst, _ắp_, xoph,
  { {0x26d20380,0x29185b59,0x290a07b4,0x00000000}},	//   tayo_, rdra_, reba_,
  { {0x3a2004bf,0x61eb000e,0x7bc15b5a,0x00000000}},	//   _trip_, kugl, mplu,
  { {0x3a200150,0x24f603d6,0x63ae5b5b,0x00000000}},	// [ba80] _urip_, дчер, _subn,
  { {0x26d2006d,0x7bc1005b,0x80ac0042,0x00000000}},	//   sayo_, oplu, _चलें,
  { {0x26d200bb,0xe73a06cb,0xa3c9016a,0x00000000}},	//   payo_, _ден_, लील_,
  { {0x27e5034d,0xb286000d,0x61eb4b25,0x00000000}},	//   álne_, мылк, fugl,
  { {0x2bac0080,0x754900ea,0x2005008f,0x00000000}},	//   _věci_, ászó, _apli_,
  { {0xa5bb0051,0x5183042c,0x3cf90042,0x00000000}},	//   _wróc, куща, ौजों_,
  { {0x7afd00e8,0x61eb0026,0x6b6400ea,0x00000000}},	//   yfst, augl, zőga,
  { {0x444405fa,0xdea2007e,0x1e140330,0x00000000}},	//   my_, نیای, емия,
  { {0x753c0045,0x3ea200c7,0xa5bb0014,0x00000000}},	//   _korz, äkt_, _króa,
  { {0xdb1b252f,0xe2a60014,0x44444352,0x00000000}},	//   nstö, áðum_, oy_,
  { {0x8c43000a,0xddd1001c,0xdb1b0b58,0x00000000}},	//   веќе, ēgša, istö,
  { {0x444400a4,0x7afd004d,0x0ed6005d,0x00000000}},	//   iy_, ufst, _آغاج,
  { {0x527b00b5,0x753c0122,0x8fa3000a,0x00000000}},	//   ַנלא, _oorz, _раце,
  { {0x4444016b,0x753c0089,0x00000000,0x00000000}},	//   ky_, _norz,   ,
  { {0x7afd004d,0x6e2201d1,0x61eb0244,0x00000000}},	//   pfst, _hrob, zugl,
  { {0xf77001a7,0x7d1819e5,0x44441dbe,0x00000000}},	//   لاق_, _havs, dy_,
  { {0xddc90051,0x753c5b5c,0x44445b5d,0x00000000}},	// [ba90] czeń, _borz, ey_,
  { {0x6d485b5e,0x44445b5f,0xdb1b0014,0x00000000}},	//   nkda, fy_, gstö,
  { {0x7985028d,0x6f020066,0x36d50121,0x00000000}},	//   _ikhw, _oboc, _понр,
  { {0x1635005a,0x9f470024,0x6e2201f4,0x00000000}},	//   _земя, stnú_, _orob,
  { {0x753c0204,0x7d1800c7,0x6d4800d1,0x00000000}},	//   _forz, _oavs, kkda,
  { {0x41e00053,0x6f0212e2,0x753c0051,0x00000000}},	//   _निरस, _aboc, _gorz,
  { {0x62860831,0x44440886,0x61eb007d,0x00000000}},	//   _økon, cy_, sugl,
  { {0x6e220185,0x7bc1004b,0x61e40139,0x00000000}},	//   _brob, vplu, áilc,
  { {0x399600b9,0xe1f0007e,0x673d00d1,0x00000000}},	//   læse_, _نسل_, _mosj,
  { {0x6aad0268,0x9f5e0024,0x29cd5b60,0x00000000}},	//   _agaf, _istý_, dža_,
  { {0x63a90009,0xdb04017d,0x6b6606da,0x00000000}},	//   _kien, _junç, екна,
  { {0x7c3c00c7,0x6d485b61,0xf0920149,0x00000000}},	//   ärra, akda, _גנב_,
  { {0x63a95b62,0xdc3b08ea,0xfce50376,0x00000000}},	//   _mien, _išče, _золо,
  { {0x63a903b2,0x7f85017d,0x6b9d006f,0x00000000}},	//   _lien, róqu, amsg,
  { {0x6e220051,0x6b460460,0x27960062,0x00000000}},	//   _zrob, _lógi, ешар,
  { {0xe73719da,0x444448d9,0x6f1b095c,0x00000000}},	//   нес_, vy_, nduc,
  { {0x6b72003d,0x44442cd0,0x69cd001f,0x00000000}},	// [baa0] lāgo, wy_, _gwae,
  { {0x63b80024,0x63a90164,0xdce10006,0x00000000}},	//   ívno, _aien, rolė,
  { {0x753c00bd,0xdb1b5b63,0x9743007d,0x00000000}},	//   _vorz, rstö, šćav,
  { {0x291a0009,0x44445b64,0x63a92b2e,0x00000000}},	//   _hapa_, ry_, _cien,
  { {0x63a95b65,0x291a5b66,0xdb1b0014,0x00000000}},	//   _dien, _kapa_, pstö,
  { {0x63a95b67,0xdb040016,0x6f020290,0x00000000}},	//   _eien, _funç, _sboc,
  { {0x63a92bd1,0xa2e60062,0x291a0764,0x00000000}},	//   _fien, _повд, _mapa_,
  { {0xdb0b0031,0x291a003d,0x6e225b68,0x00000000}},	//   _utfø, _lapa_, _prob,
  { {0x8fa3005e,0x62895b69,0x6f19056c,0x00000000}},	//   ћање, _gyeo, _dawc,
  { {0x361b014e,0xd24f0021,0x63a90e42,0x00000000}},	//   לופד, _انك_, _zien,
  { {0x6d485b6a,0x69cd00f5,0x6f1b5435,0x00000000}},	//   rkda, _swae, bduc,
  { {0x6e220994,0x6f020022,0xf093009a,0x00000000}},	//   _trob, _uboc, _ענף_,
  { {0x291a00e3,0x6e220024,0x7d1801f7,0x00000000}},	//   _bapa_, _urob, _tavs,
  { {0x90d5001b,0xa3e10053,0x291a0955,0x00000000}},	//   _lòn, _दिल_, _capa_,
  { {0x673d0117,0x2d9e00bd,0xa5bb0e7c,0x00000000}},	//   _posj, mmte_, _crón,
  { {0x4788000a,0x2d8c0137,0x7bda08e9,0x00000000}},	//   есум_, llde_, mstu,
  { {0x63a95b6b,0x8f9b0063,0x7bda31b3,0x00000000}},	// [bab0] _rien, לילי, lstu,
  { {0x63a95b6c,0xd49b5b6d,0x213e0206,0x00000000}},	//   _sien, пре_, _noth_,
  { {0x2d9e016d,0x7bda5b6e,0x9cd70063,0x00000000}},	//   imte_, nstu, גובה_,
  { {0x2d9e004d,0xe6950044,0x7bda5b6f,0x00000000}},	//   hmte_, _للجد, istu,
  { {0x213e0037,0xa2940086,0xe4e70086,0x00000000}},	//   _both_, гаці, _півн,
  { {0xdb0400bd,0x26c95b70,0xc244000d,0x00000000}},	//   _zunä, lbao_, ынік,
  { {0x63a95b71,0x213e00e5,0x34940091,0x00000000}},	//   _tien, _doth_, _барр,
  { {0x2d8c0173,0x60060062,0x2d9e0203,0x00000000}},	//   elde_, тнъм_, emte_,
  { {0xc115257e,0x26c90035,0xb115026b,0x00000000}},	//   _имај, ibao_, _имаш,
  { {0x7bda0760,0xdca502b3,0x7af622b1,0x00000000}},	//   fstu, капи, _scyt,
  { {0x7bda5b72,0x2ef504dc,0xd01114d7,0x00000000}},	//   gstu, _азер, _خلا_,
  { {0x291a5b73,0x2d8c1cae,0x2d9e0244,0x00000000}},	//   _sapa_, alde_, amte_,
  { {0x98d60086,0x42da0047,0x291a0dd1,0x00000000}},	//   ківщ, וקרע, _papa_,
  { {0x3f8d2223,0xfce5046a,0x6d470137,0x00000000}},	//   lleu_, _роко, öjad,
  { {0x3f8d0268,0x6d860014,0xbc190086,0x00000000}},	//   oleu_, rðat, _цілі_,
  { {0x27e53ac0,0xfaff006f,0xba760021,0x00000000}},	//   álna_, liën_, _لاخت,
  { {0x3f8d001f,0xdcfa008f,0x291a5b74,0x00000000}},	// [bac0] ileu_, lotā, _tapa_,
  { {0xfaff006f,0xca970063,0xa5bb19e6,0x00000000}},	//   niën_, _בדפי_, _trón,
  { {0xdcfa001c,0x213e3315,0x66e6137c,0x00000000}},	//   notā, _roth_, _иона,
  { {0xa5bb0045,0x7c3a0047,0x798e002b,0x00000000}},	//   _król, וגעז, llbw,
  { {0x2d870024,0x333f0164,0x90d5008b,0x00000000}},	//   _okne_, _doux_, _vòn,
  { {0x3f8600ac,0xdcfa008f,0x7bda36fd,0x00000000}},	//   _skou_, kotā, ystu,
  { {0xcf9a000a,0x351b0063,0x929d0051,0x00000000}},	//   мји_, _קולנ, _mały,
  { {0x3f8d017f,0x2d8c006f,0xdcfa001c,0x00000000}},	//   gleu_, wlde_, dotā,
  { {0x7bda5b75,0x2dd30085,0x8fa3005e,0x00000000}},	//   wstu, ажыр, шаће,
  { {0xfe6f0021,0x7bda276d,0xfaff00ca,0x00000000}},	//   تدى_, tstu, giën_,
  { {0xa0a6005a,0xc0a90021,0x2d9e0518,0x00000000}},	//   _ражд, _كامل_, rmte_,
  { {0x7bda1517,0x6d860014,0xdce8008f,0x00000000}},	//   rstu, gðar, todē,
  { {0x9f470024,0x9b580062,0x7bda5b76,0x00000000}},	//   ntný_, тият_, sstu,
  { {0x6d86007a,0x929d0051,0x7bda06aa,0x00000000}},	//   rðas, _cały, pstu,
  { {0xed570001,0xcd970063,0xfce30141,0x00000000}},	//   _јој_, _שדות_, _тојо,
  { {0x34cb0053,0x9f470066,0x5ba4000d,0x00000000}},	//   िर्द, ktný_, _крыз,
  { {0x333f4ac9,0x387a1d24,0x00000000,0x00000000}},	// [bad0] _roux_, _expr_,   ,
  { {0xeaaa00b5,0x2d83007d,0xe29f0014,0x00000000}},	//   _אױפֿ, čjeg_, _úði_,
  { {0x316700bd,0x29111a40,0x69dd5b77,0x00000000}},	//   vinz_, meza_, lsse,
  { {0x3f84001c,0xdce100c2,0x29115b78,0x00000000}},	//   jomu_, vilč, leza_,
  { {0xcb140047,0x61e400c2,0x2ca2004c,0x00000000}},	//   ילף_, šiln, ěkdy_,
  { {0xd5fa014e,0x29115b79,0x98c6007d,0x00000000}},	//   _אפשר, neza_, čući_,
  { {0x614203d6,0xd3a70d34,0x787200ea,0x00000000}},	//   сеща, _арап, művé,
  { {0x69dd5b7a,0xdcfa008f,0x3f840130,0x00000000}},	//   ksse, votā, gomu_,
  { {0x29110035,0x917b001b,0x3f8d00cd,0x00000000}},	//   keza_, hể_, rleu_,
  { {0xdcfa0418,0x80ca0235,0x69dd0246,0x00000000}},	//   totā, _स्पे, dsse,
  { {0xfaff006f,0x9c65007e,0x29115b7b,0x00000000}},	//   riën_, اهجو, deza_,
  { {0xdcfa001c,0xa5bb0e7c,0x99f6000d,0x00000000}},	//   rotā, _pról, лягі,
  { {0x6d86007a,0xee2e023b,0x69dd5b7c,0x00000000}},	//   rðar, _ун_, gsse,
  { {0x29110009,0xdcfa008f,0xf8a50042,0x00000000}},	//   geza_, potā, _गृहय,
  { {0xac16005e,0x69dd0296,0xd9430062,0x00000000}},	//   _боју_, asse, щери,
  { {0xfaff006f,0x20d80078,0x69c6004b,0x00000000}},	//   niël_, mžių_, ppke,
  { {0x291102dd,0x7ae4017f,0x61eb00b9,0x00000000}},	// [bae0] beza_, _idit, jrgl,
  { {0x6e2400c2,0x3a370063,0xdb0b017d,0x00000000}},	//   _šibk, _ערים_, _tufã,
  { {0x78fb0165,0x61eb02d2,0x68fb089e,0x00000000}},	//   _אליפ, ergl, _אליה,
  { {0x2d854aef,0x9f47011b,0xd46701ce,0x00000000}},	//   hole_, brné_, ћице_,
  { {0xdb040025,0x60d800a8,0x61460d4c,0x00000000}},	//   _bunú, tavm, леда,
  { {0x3ff40021,0x9f470066,0xd0100021,0x00000000}},	//   لكتر, rtný_, قلت_,
  { {0xa3e10161,0x2d855b7d,0x9f47027d,0x00000000}},	//   _दिए_, dole_, stný_,
  { {0x20d800eb,0xdb190024,0xa6db0014,0x00000000}},	//   džių_, _otvá, _koða,
  { {0x63a2055b,0x5d5405fb,0x7607001c,0x00000000}},	//   mmon, икит, cīzā,
  { {0x2d8530b8,0xd5fb0047,0x7ae45b7e,0x00000000}},	//   gole_, עפיר, _adit,
  { {0x2911074f,0x63a20003,0x4c941259,0x00000000}},	//   veza_, omon, ринс,
  { {0x291110ca,0x644100cd,0x69dd2a3c,0x00000000}},	//   weza_, _àlie, tsse,
  { {0x2d855b7f,0x29115b80,0xbdd40121,0x00000000}},	//   bole_, teza_, _толщ,
  { {0x6e9301a7,0x64430093,0x7ae40530,0x00000000}},	//   _الها, ønik, _edit,
  { {0x29115b81,0x6db20045,0x67d51caf,0x00000000}},	//   reza_, _wład, робу,
  { {0x9f470260,0xa6db0046,0x63a20605,0x00000000}},	//   trné_, _boða, jmon,
  { {0x61e4095e,0x9f475b82,0x63a25b83,0x00000000}},	// [baf0] áill, urné_, dmon,
  { {0x63a25b84,0x2fc700a4,0x61eb00c2,0x00000000}},	//   emon, ypng_, vrgl,
  { {0x6b460025,0xb8f90053,0x44275b85,0x00000000}},	//   _tógt, ार_, ín_,
  { {0xd25101a7,0xe9df0139,0x63a2013d,0x00000000}},	//   ينا_, osú_, gmon,
  { {0xf1b902f7,0xe704005d,0xa6db0046,0x00000000}},	//   _krši_, _اسپی, _goða,
  { {0x98ba003d,0x7607008f,0xa0690789,0x00000000}},	//   _kopā_, rīzā, кала_,
  { {0x2d855b86,0xe9df0025,0x63a20717,0x00000000}},	//   vole_, hsú_, bmon,
  { {0xddc90051,0x8e092ba3,0x00180085,0x00000000}},	//   cześ, внив_, уўшы_,
  { {0x00e5007e,0x2d855b87,0xd24f01ce,0x00000000}},	//   _نتای, tole_, ицe_,
  { {0x1d090001,0x2d850290,0xa5bb006d,0x00000000}},	//   њени_, uole_, _prój,
  { {0x2d855b88,0x3a2922c7,0x66160051,0x00000000}},	//   role_, _arap_, zwyk,
  { {0x34b20053,0x69c4006f,0x60d7001c,0x00000000}},	//   _जल्द, _ptie, šamī,
  { {0x2d855b89,0xfdeb0121,0x3a2918c0,0x00000000}},	//   pole_, _чьей_, _crap_,
  { {0xdce1001c,0xa5bb5b8a,0xe29f0014,0x00000000}},	//   bilā, _trój, _úðu_,
  { {0x6d43527a,0x18a60817,0x63a20aa2,0x00000000}},	//   _iona, равм, ymon,
  { {0x7ae40290,0x26db00ac,0x6d430137,0x00000000}},	//   _udit, gaqo_, _hona,
  { {0x6b460027,0x05665b8b,0xe9df0025,0x00000000}},	// [bb00] _fógr, аван, csú_,
  { {0xa3e10053,0xe4520021,0x63a25b8c,0x00000000}},	//   _दिख_, يضا_, wmon,
  { {0xaaba0161,0xc2c6007e,0x6d4303a3,0x00000000}},	//   _इलाक, لياي, _mona,
  { {0xdb190146,0xa3e70121,0x4c6c0047,0x00000000}},	//   _etvæ, рдца_, עדאַ,
  { {0xddc90051,0x24860022,0x62630121,0x00000000}},	//   rześ, łom_, овца,
  { {0x26c030f9,0x63a2500f,0xc16f0054,0x00000000}},	//   lcio_, smon, ії_,
  { {0xd0100021,0x03a60054,0x320d0058,0x00000000}},	//   سلة_, _виво, _epey_,
  { {0x26c05b8d,0x6d430025,0x9c82027d,0x00000000}},	//   ncio_, _aona, _účin,
  { {0x6d435b8e,0x6db20051,0x2b920240,0x00000000}},	//   _bona, _słab, mách_,
  { {0x6d430027,0x20b90088,0x5d5406cb,0x00000000}},	//   _cona, _быць_, скот,
  { {0x69c0029c,0x34b70063,0x6d4303db,0x00000000}},	//   ímen, יפים_, _dona,
  { {0x645e001c,0x2b925b8f,0x3f77003b,0x00000000}},	//   izpi, nách_, năul_,
  { {0x6d435b90,0xe94702fe,0xfe720044,0x00000000}},	//   _fona, ахво, _بدا_,
  { {0xc98705fb,0x2b925b91,0x442a00f9,0x00000000}},	//   руми, hách_, _orb_,
  { {0xf1b9017f,0x98480062,0x2b920114,0x00000000}},	//   _vrši_, аята_, kách_,
  { {0x442d0fbf,0x6d435b92,0x9ad5005e,0x00000000}},	//   _če_, _zona, _ужич,
  { {0x61e41312,0x29050019,0xf69900d7,0x00000000}},	// [bb10] šilj, õlas_, увај_,
  { {0x94ab0021,0xdce80006,0x5887000d,0x00000000}},	//   نطاق_, rodė, _выма,
  { {0xdcf80080,0x6d5a004b,0xdb1b0db3,0x00000000}},	//   _skvě, ihta, pptä,
  { {0x26c04c0f,0x92590076,0x602000ea,0x00000000}},	//   ccio_, лает_, zámá,
  { {0x3ebf01f7,0x6d5a2075,0x442a5b93,0x00000000}},	//   vcut_, khta, _erb_,
  { {0x45d431ab,0x823401f3,0xea18009a,0x00000000}},	//   _форс, ترما, שַׁי_,
  { {0x4425099d,0x3f693734,0x6d432810,0x00000000}},	//   _él_, лико_, _rona,
  { {0x7c25007a,0x18780063,0xef19342b,0x00000000}},	//   _áhri, יעור_, уми_,
  { {0x764d1aa4,0x26d95b94,0x3cd902fe,0x00000000}},	//   nyay, _meso_, льню_,
  { {0xa5bb0025,0x3ebf109b,0x2b920066,0x00000000}},	//   _crói, scut_, máci_,
  { {0x40950032,0x6d43463a,0x6db20051,0x00000000}},	//   _الار, _vona, _płac,
  { {0x6d43004d,0x4b560062,0xa3ea0053,0x00000000}},	//   _wona, съот, _मिस_,
  { {0x6d5a0025,0x42790047,0xc3320063,0x00000000}},	//   bhta, ראָג, פוך_,
  { {0x6d5a018d,0xd99a007e,0xa6db0014,0x00000000}},	//   chta, انست_, _boðo,
  { {0x26d9006d,0x07ba0021,0x175601ce,0x00000000}},	//   _beso_, اهرة_, бњар,
  { {0x764d0075,0x5bc40044,0xd5b20044,0x00000000}},	//   fyay, _بتوف, كفر_,
  { {0x764d002c,0xf7435b95,0x64431924,0x00000000}},	// [bb20] gyay, чето, änin,
  { {0x26c05b96,0x9a3b0063,0x6a3b0041,0x00000000}},	//   scio_, _עתיק, _עגיפ,
  { {0x649a0d62,0x2b920240,0x26c009aa,0x00000000}},	//   утар_, tách_, pcio_,
  { {0xf1b9017f,0x2bb7000c,0x7c3c5ab5,0x00000000}},	//   _buš_, _căci_, ärri,
  { {0x6d5a0058,0x2b925b97,0x645e056c,0x00000000}},	//   yhta, rách_, szpi,
  { {0xdb0b00bd,0x19bb016e,0x2b9201d1,0x00000000}},	//   _zufä, אמסב, sách_,
  { {0x26d9006d,0xdc180051,0x6724007d,0x00000000}},	//   _yeso_, ołąc, odij,
  { {0x3f510026,0x660411d0,0xc7b30063,0x00000000}},	//   _fáum_, otik, הבה_,
  { {0xa5bb0025,0x50d6007e,0x66041f21,0x00000000}},	//   _prói, _هزار, ntik,
  { {0x50cf0053,0x61ed00c2,0x387f003b,0x00000000}},	//   _स्पष, šalc, şuri_,
  { {0x66040659,0x9743007d,0x0caa0121,0x00000000}},	//   htik, šćiv, ытии_,
  { {0x61e20019,0x201e01b3,0x66040b45,0x00000000}},	//   osol, _isti_, ktik,
  { {0x26d90290,0x4e9600b3,0xa5bb00be,0x00000000}},	//   _reso_, _اشار, _trói,
  { {0x61e25b98,0x25b90014,0xa5bb0022,0x00000000}},	//   isol, _rusl_, _zrów,
  { {0x26d90aca,0x660410a5,0x9d430896,0x00000000}},	//   _peso_, etik, _хејд,
  { {0x6b8d0035,0x60da0066,0xdce1003b,0x00000000}},	//   _ukag, _letm, pilă,
  { {0x660400ac,0x248d008f,0x35b40785,0x00000000}},	// [bb30] gtik, _ņem_, збур,
  { {0x60da3760,0x201e48fe,0x2b920061,0x00000000}},	//   _netm, _osti_, váci_,
  { {0x66043680,0x764d005b,0x26d901f4,0x00000000}},	//   atik, syay, _teso_,
  { {0xdb1900c7,0x7bc40078,0x764d0058,0x00000000}},	//   _utvä, _čiul, pyay,
  { {0x6d58000f,0x614503d6,0x201e5b99,0x00000000}},	//   _olva, жела, _asti_,
  { {0x2b920260,0x412918ea,0xa5040085,0x00000000}},	//   ráci_, роко_, _нясл,
  { {0xa0660062,0xdcee004c,0x14280054,0x00000000}},	//   жаща_, žděj, _літо_,
  { {0x6d585b9a,0x6e3b01a8,0x61e23f16,0x00000000}},	//   _alva, txub, bsol,
  { {0x9f5c02f4,0x61e2000f,0xbd390086,0x00000000}},	//   ctví_, csol, аїні_,
  { {0xbc84001b,0x67240734,0x8d650054,0x00000000}},	//   ườn, zdij, івне,
  { {0xca290132,0x212a007e,0xdc180051,0x00000000}},	//   _שם_, _خيلی_, yłąc,
  { {0x6d585b9b,0x66040b4f,0x60da00ca,0x00000000}},	//   _elva, ytik, _zetm,
  { {0x8d74007e,0x60da0058,0x672400a8,0x00000000}},	//   _کانا, _yetm, vdij,
  { {0xa3ea0053,0x61e40025,0x660400c2,0x00000000}},	//   _मिल_, áili, vtik,
  { {0xbb460769,0x6db20022,0xeb9a0131,0x00000000}},	//   _мекк, _kłan, _кик_,
  { {0x6604412c,0x917b008d,0x67241843,0x00000000}},	//   ttik, hề_, udij,
  { {0x67245b9c,0x66045b9d,0x9b030085,0x00000000}},	// [bb40] rdij, utik, _ўзьд,
  { {0x3a20002c,0x66045b9e,0x6d4100a5,0x00000000}},	//   _isip_, rtik, njla,
  { {0xf74615d3,0x6d41006f,0x60da00b9,0x00000000}},	//   _дено, ijla, _retm,
  { {0x60da0268,0x3d090053,0x29185b9f,0x00000000}},	//   _setm, ़्ते_, lera_,
  { {0x61e25ba0,0xc1a60002,0x9c7c08ed,0x00000000}},	//   usol, ојки, mače,
  { {0xdb0b00c7,0x29185ba1,0xc297000d,0x00000000}},	//   _utfö, nera_, цкіх_,
  { {0x29181cb0,0x6f095ba2,0x9f5c01c2,0x00000000}},	//   iera_, ffec, ství_,
  { {0x29185ba3,0x5f940002,0x27e519e6,0x00000000}},	//   hera_, џиит, álni_,
  { {0x3f98008f,0x29185ba4,0xe2c7012c,0x00000000}},	//   ēru_, kera_, _флуд_,
  { {0xa06a005a,0x29185ba5,0x63bc18d5,0x00000000}},	//   _каза_, jera_, _kurn,
  { {0x29185ba6,0x63bc26d9,0x9c7c0734,0x00000000}},	//   dera_, _jurn, kače,
  { {0xa5bb0051,0x63bc1169,0xfbcf007e,0x00000000}},	//   _krót, _murn, کتی_,
  { {0xdb190003,0x29185ba7,0xad660044,0x00000000}},	//   _juvé, fera_, _واته,
  { {0x2918324c,0x63bc0003,0x9e33014b,0x00000000}},	//   gera_, _ourn, _цешч,
  { {0x2d8c5ba8,0x36d50098,0xd6db05ef,0x00000000}},	//   mode_, зобр, ита_,
  { {0x9c7c00c3,0x27ed5ba9,0x7c3c0137,0x00000000}},	//   gače, čen_, ärru,
  { {0xe4cb0242,0x29181c6c,0x917b0013,0x00000000}},	// [bb50] لبان_, bera_, hế_,
  { {0x63bc1dbd,0x29185baa,0x27f84cfb,0x00000000}},	//   _burn, cera_, burn_,
  { {0x9c7c017f,0x29010035,0x69cf5bab,0x00000000}},	//   bače, _icha_, lpce,
  { {0xabb50047,0x42e70085,0x2d8c5bac,0x00000000}},	//   פּעס_, іцеб, hode_,
  { {0x9c7c00c2,0x2d8c5bad,0x7afd083f,0x00000000}},	//   načb, kode_, igst,
  { {0x63bc09ee,0xe8b90053,0x2178000d,0x00000000}},	//   _furn, _आलोच, ойчы_,
  { {0xb4d70235,0xa5bb5bae,0x63bc5baf,0x00000000}},	//   सरी_, _erót, _gurn,
  { {0xd00e0754,0xfe45000a,0x2b920080,0x00000000}},	//   الي_, знио, náct_,
  { {0x236d00e3,0x29185bb0,0xb0cf0053,0x00000000}},	//   _imej_, yera_, _स्थग,
  { {0x29185bb1,0x6f090e7c,0x7afd23ef,0x00000000}},	//   xera_, sfec, egst,
  { {0x29185bb2,0x317a0047,0x31560041,0x00000000}},	//   vera_, _פרעמ, _ציען_,
  { {0xe4560047,0x7afd00df,0x29015bb3,0x00000000}},	//   פירט_, ggst, _acha_,
  { {0x4426008b,0x29185bb4,0x9c7c10f5,0x00000000}},	//   ̉o_, tera_, vače,
  { {0x291859eb,0x27f822a4,0x2d8c2646,0x00000000}},	//   uera_, turn_, code_,
  { {0x29185bb5,0x200701b3,0x58950085,0x00000000}},	//   rera_, ntni_, дшту,
  { {0x29185bb6,0x29015bb7,0x63ba0460,0x00000000}},	//   sera_, _echa_, _étni,
  { {0xe4d60021,0x16660062,0x29180530,0x00000000}},	// [bb60] كتاب, чвам, pera_,
  { {0x27f80026,0x63bc5bb8,0x2007082a,0x00000000}},	//   purn_, _purn, ktni_,
  { {0xd252007e,0x9c7c00b2,0xe9a901fb,0x00000000}},	//   کنش_, pače, _بدين_,
  { {0x2d8c0734,0xa5bb5bb9,0x63690054,0x00000000}},	//   zode_, _prót, оріг_,
  { {0x61ed00c2,0x20075bba,0x929d0022,0x00000000}},	//   šaln, etni_, _obłu,
  { {0x63bc5bbb,0xf8be0042,0x301a0044,0x00000000}},	//   _turn, ्डिय, متعة_,
  { {0x35a3000d,0x2d8c5bbc,0x320618a7,0x00000000}},	//   _чарг, vode_, stoy_,
  { {0x644901f7,0xf8b30063,0x547b0063,0x00000000}},	//   çmiş, עשה_, _הטלו,
  { {0x2d8c5bbd,0x2007008f,0x8e130085,0x00000000}},	//   tode_, atni_, едыц,
  { {0xdb19003b,0x7c863d47,0x2b920feb,0x00000000}},	//   _cuvî, зуме, kács_,
  { {0xd00f006a,0x2d8c5bbe,0xf1b3009a,0x00000000}},	//   _ملل_, rode_, _נסע_,
  { {0x7afd001c,0x2d8c0238,0x290112ca,0x00000000}},	//   ugst, sode_, _scha_,
  { {0xdb04008b,0x69cf00a2,0x2d8c5bbf,0x00000000}},	//   _khiê, upce, pode_,
  { {0x7c3c0137,0x6db20022,0x4bd7005d,0x00000000}},	//   ärrs, _kłam, _کبود_,
  { {0xd90f007e,0xd1380022,0x7d1a5bc0,0x00000000}},	//   نیک_, _mną_, mets,
  { {0x95d9005a,0x6c7b0063,0x7d1a5bc1,0x00000000}},	//   ждат_, _לאופ, lets,
  { {0x59b70161,0x66f40085,0xd7740044,0x00000000}},	// [bb70] _इंटर, эпту, رافع,
  { {0xb4d70235,0xdb04001b,0x91ad0013,0x00000000}},	//   सरे_, _nhiê, _trẻ_,
  { {0xa5bb3f3c,0x9cd70063,0x00000000,0x00000000}},	//   _prós, פואה_,   ,
  { {0x27e50024,0xfbd30063,0x6d860014,0x00000000}},	//   álnu_, תתף_, rðay,
  { {0x96340085,0x7d1a5bc2,0xe28e2ceb,0x00000000}},	//   _зняц, kets, та_,
  { {0xdb04001b,0x7d1a074f,0x20070014,0x00000000}},	//   _chiê, jets, ttni_,
  { {0x7aed5bc3,0xef190022,0x2007013d,0x00000000}},	//   _odat, też_, utni_,
  { {0xa6db0026,0x3eb902ab,0x2d8302f7,0x00000000}},	//   _boði, øst_, čjem_,
  { {0x61e40027,0x200700c3,0xee390500,0x00000000}},	//   áilt, stni_, іно_,
  { {0x7aed1ae5,0x61e940cb,0x200700c2,0x00000000}},	//   _adat, _ivel, ptni_,
  { {0x61e904aa,0x61e40078,0xcc8905ac,0x00000000}},	//   _hvel, šilt, юбое_,
  { {0x61e92c24,0x7aed1177,0xc5ff008f,0x00000000}},	//   _kvel, _cdat, ģēju_,
  { {0x7d1a01e3,0x7aed0185,0x4a43130d,0x00000000}},	//   bets, _ddat, вняв,
  { {0x6d4a001f,0x25ee0053,0x7aed01a8,0x00000000}},	//   _gofa, ेंसी_, _edat,
  { {0xe71a005d,0xbbe8005d,0x00000000,0x00000000}},	//   ييست_, _فريم_,   ,
  { {0xd70a000d,0x2b050042,0x61e95bc4,0x00000000}},	//   ўнае_, _वायु_, _ovel,
  { {0x6726006f,0xbb1b006c,0x44310058,0x00000000}},	// [bb80] _vakj, roît, _arz_,
  { {0x9c7c1253,0x4431007d,0xa5bb006d,0x00000000}},	//   lača, _brz_, _prór,
  { {0x61e95bc5,0x44230089,0x67261667,0x00000000}},	//   _avel, _csj_, _takj,
  { {0x9c7c017f,0x7d1a2033,0x65c60a16,0x00000000}},	//   nača, zets, _обма,
  { {0xdb04001b,0x9343005a,0xa3de0053,0x00000000}},	//   _phiê, ънце, _दौर_,
  { {0x6f025bc6,0x44310244,0x3cf90042,0x00000000}},	//   _scoc, _frz_, ्भों_,
  { {0x442c0003,0x6f1b004d,0x7d1a5bc7,0x00000000}},	//   _éd_, feuc, vets,
  { {0x9c7c017f,0x7d1a006f,0x6d4a5bc8,0x00000000}},	//   jača, wets, _sofa,
  { {0xdb04001b,0x6d4a0b9d,0x8fa3005e,0x00000000}},	//   _thiê, _pofa, њање,
  { {0x657e0025,0xab640051,0x2056157f,0x00000000}},	//   nnph, óżni, _отер,
  { {0x7aed5bc9,0xcf8f0699,0x6db20022,0x00000000}},	//   _pdat, _ај_, _ułam,
  { {0xee3a17ab,0x9c7c007d,0xf99f01a8,0x00000000}},	//   _мне_, gača, atèl_,
  { {0x6d4a0009,0xf2d300b5,0x7d1a5bca,0x00000000}},	//   _tofa, כער_, pets,
  { {0x9f4e0139,0x5e9b009a,0x00000000,0x00000000}},	//   irfí_, _ובדק,   ,
  { {0x7aed00df,0x7527013d,0xeb9b0021,0x00000000}},	//   _tdat, _rajz, _وضعت_,
  { {0x7aed5bcb,0x998900dd,0x7c2e19e5,0x00000000}},	//   _udat, _braţ_, åbru,
  { {0x69cd0035,0x3a3200ac,0x7527013d,0x00000000}},	// [bb90] _utae, _gryp_, _pajz,
  { {0xd49b5bcc,0x7ce9013d,0xc7c701f6,0x00000000}},	//   оре_, _törő, _осми,
  { {0xf485006a,0x61e95bcd,0xa2f512b9,0x00000000}},	//   رائی, _svel, епеч,
  { {0xdb1b017c,0x3d0e0042,0xc2c50044,0x00000000}},	//   mptó, त्ते_, ريتي,
  { {0xeb9200b5,0xe5c407b0,0xe8e0008d,0x00000000}},	//   אָג_, _ассо, _hiều_,
  { {0x25b80c69,0xe8e0008b,0x9f5e006d,0x00000000}},	//   _girl_, _kiều_, _optó_,
  { {0x1fb50713,0x6f1b1ae7,0x44f40131,0x00000000}},	//   нсир, teuc, _јпсс,
  { {0xa29502fe,0x2b840075,0x00000000,0x00000000}},	//   _забі, kıca_,   ,
  { {0x61e9082a,0xe8e00013,0x80ca0042,0x00000000}},	//   _uvel, _liều_, _स्के,
  { {0x653a00b5,0x7d090001,0x1c450086,0x00000000}},	//   ִערד, чног_, еном,
  { {0x9c7c007d,0xa0380044,0xab2a0590,0x00000000}},	//   tača, _يأمر_, пона_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xb69b003b,0x9c7c02f7,0x9f8a004e,0x00000000}},	//   _scân, rača, tööl_,
  { {0xdb190529,0x395e0014,0x00000000,0x00000000}},	//   _cuvâ, óts_,   ,
  { {0x2bc60161,0x6c790047,0x9c7c5bce,0x00000000}},	//   _रूपा, _מאַפ, lačn,
  { {0xa5bb03d9,0x28d00053,0xe8e0008d,0x00000000}},	//   _próp, _त्रि, _diều_,
  { {0x61ed0117,0x9c7c5bcf,0xfaff00f5,0x00000000}},	// [bba0] šalj, načn, piër_,
  { {0x7ae64969,0x7d010046,0x9986005d,0x00000000}},	//   lakt, ngls, _سلجو,
  { {0xed560047,0x3f580014,0x799c00a3,0x00000000}},	//   עבער_, _séum_, mlrw,
  { {0x7ae65bd0,0x9c7c0a63,0xa6db0014,0x00000000}},	//   nakt, kačn, _boðu,
  { {0x799c002b,0x96760085,0x76bb009d,0x00000000}},	//   olrw, _чыні, _ממכפ,
  { {0x6fc7005b,0x6143218b,0x21670899,0x00000000}},	//   _sıca, леча, ничи_,
  { {0x64a35bd1,0xdfd00021,0x7ae62165,0x00000000}},	//   _бара, جيب_, kakt,
  { {0x63a300ac,0xceb9004c,0x7ae63dbb,0x00000000}},	//   ïnnt, zeře_, jakt,
  { {0x4444066d,0x9c7c1625,0x7ae65bd2,0x00000000}},	//   lx_, gačn, dakt,
  { {0x9162008b,0x5d5404d8,0x44445bd3,0x00000000}},	//   _dự_, ткот, ox_,
  { {0x20b9000d,0x44445bd4,0x7ae65bd5,0x00000000}},	//   _жыць_, nx_, fakt,
  { {0x44445bd6,0xdd2f0080,0x9c7c5452,0x00000000}},	//   ix_, _měři, bačn,
  { {0xc33301f9,0x99460066,0xceb9004c,0x00000000}},	//   אור_, _kôň_, teře_,
  { {0x2b8401f7,0x7e7d0024,0x7ae6006f,0x00000000}},	//   rıca_, úspe, aakt,
  { {0xe8950076,0x7b0600fe,0x6aa400ac,0x00000000}},	//   тавь, ättö, _ezif,
  { {0x7ae601f7,0xeb98005e,0x9c7c0195,0x00000000}},	//   cakt, _пиј_, lačo,
  { {0x6d5a0058,0x69c00e57,0xceb9004c,0x00000000}},	// [bbb0] okta, ímet, peře_,
  { {0xc7bb0121,0x6d5a5bd7,0x9c7c004a,0x00000000}},	//   _нём_, nkta, načo,
  { {0x9c7c0240,0xf4870320,0x6d5a5bd8,0x00000000}},	//   začn, хуан, ikta,
  { {0x29030627,0x68e7000f,0xb8d4016a,0x00000000}},	//   lgja_, lajd, जे_,
  { {0x22580055,0x6d5a55a7,0x673d0137,0x00000000}},	//   ницы_, kkta, _insj,
  { {0x672d0004,0x29035bd9,0x9c7c0240,0x00000000}},	//   ldaj, ngja_, vačn,
  { {0x7ae60031,0xe8e0001b,0x9162001b,0x00000000}},	//   yakt, _hiểu_, _sự_,
  { {0xe8e0008b,0x672d5bda,0x9c7c041f,0x00000000}},	//   _kiểu_, ndaj, tačn,
  { {0xe29f0026,0x7ae64cea,0x256400ea,0x00000000}},	//   _áð_, vakt, _föld_,
  { {0x41b5006a,0x7ae608f8,0x9c7c016b,0x00000000}},	//   _شمار, wakt, račn,
  { {0x63bb0009,0x9c7c0024,0x80ca0053,0x00000000}},	//   _kiun, sačn, _स्टे,
  { {0x6d5a00eb,0x9162001b,0x628c0051,0x00000000}},	//   akta, _tự_, żnoś,
  { {0x1d090001,0x63a9001f,0x63bb1e82,0x00000000}},	//   _жели_, _mhen, _miun,
  { {0x29030627,0x7ae6490a,0x660d5bdb,0x00000000}},	//   ggja_, sakt, dtak,
  { {0xb796005e,0x660d5bdc,0x67f50085,0x00000000}},	//   враћ, etak, лятф,
  { {0xe8e0001b,0x63bb0290,0x69c00066,0x00000000}},	//   _biểu_, _niun, ímes,
  { {0x7ae40185,0x7e6900bd,0x660d5bdd,0x00000000}},	// [bbc0] _ieit, nzep, gtak,
  { {0x7ae45bde,0xa6db007a,0x63a95bdf,0x00000000}},	//   _heit, _boðs, _ahen,
  { {0x44440c6e,0x7ae40498,0x660d5be0,0x00000000}},	//   ux_, _keit, atak,
  { {0x69c400e8,0x7bc35be1,0x7ae4017d,0x00000000}},	//   _kuie, _munu, _jeit,
  { {0x63bb014f,0x63a9004b,0x7ae45be2,0x00000000}},	//   _diun, _dhen, _meit,
  { {0x7ae45be3,0x23a7004b,0x69c4003b,0x00000000}},	//   _leit, võje_, _muie,
  { {0x7bc30150,0x9c7c0066,0x61eb002b,0x00000000}},	//   _nunu, vačo, asgl,
  { {0x63bb051e,0x2d5b017d,0x7ae45be4,0x00000000}},	//   _giun, _dêem_, _neit,
  { {0xf773014e,0x9c7c0240,0x7bc342b2,0x00000000}},	//   יקה_, tačo, _aunu,
  { {0x672d1228,0x7bc35be5,0x6d5a2401,0x00000000}},	//   zdaj, _bunu, ukta,
  { {0xfc66005a,0x7ae45be6,0xa4fb0063,0x00000000}},	//   тъпн, _beit, וליט,
  { {0x3f800006,0x7ae40025,0xa6e20026,0x00000000}},	//   čius_, _ceit, áðla,
  { {0x3ea00027,0x7e690051,0x7ae45be7,0x00000000}},	//   _áit_, czep, _deit,
  { {0xbea30001,0x7bc3001f,0x6c340021,0x00000000}},	//   _тачк, _funu, _مفتا,
  { {0x7bc3014f,0x7ae45be8,0x6db20051,0x00000000}},	//   _gunu, _feit, _sław,
  { {0x61ed00eb,0x2d9e17a0,0x68e722c7,0x00000000}},	//   šali, llte_, sajd,
  { {0x63bb051e,0x2d9e5be9,0xba74007e,0x00000000}},	// [bbd0] _riun, olte_, _پايت,
  { {0x63bb00eb,0x7ae454da,0x7bc3189e,0x00000000}},	//   _siun, _zeit, _yunu,
  { {0x63a904bf,0x2d9e0aee,0x660d07d2,0x00000000}},	//   _phen, ilte_, stak,
  { {0x2d9e00bd,0xe8e0008b,0x660d15e2,0x00000000}},	//   hlte_, _tiểu_, ptak,
  { {0x63bb0009,0x61eb004d,0x92670021,0x00000000}},	//   _viun, usgl, خدام,
  { {0x63a90034,0x2d82013d,0x64430e7b,0x00000000}},	//   _when, ékel_, änis,
  { {0x10150021,0x63a95bea,0x68e55beb,0x00000000}},	//   ابتد, _then, _mehd,
  { {0x68e500fe,0x2d5b017d,0x2d9e5bec,0x00000000}},	//   _lehd, _vêem_, elte_,
  { {0x7bc301f7,0xa3e70161,0x7ae45bed,0x00000000}},	//   _sunu, _मौत_, _reit,
  { {0x7ae45bee,0x7bc30455,0x7e690051,0x00000000}},	//   _seit, _punu, rzep,
  { {0x79950051,0x3a2904b5,0x7ae45bef,0x00000000}},	//   dozw, _asap_, _peit,
  { {0x69c4004b,0xa2aa0042,0x3a290022,0x00000000}},	//   _puie, जेक्, _bsap_,
  { {0x7ae40026,0x69c40d0f,0xe8e00013,0x00000000}},	//   _veit, _quie, _liễu_,
  { {0xdb19010a,0xa3e4016a,0x7ae4061d,0x00000000}},	//   _nuvæ, पीड_, _weit,
  { {0x7ae40185,0x3a290058,0xbbf50044,0x00000000}},	//   _teit, _esap_, _إستث,
  { {0xfbd20063,0xeb060094,0xfc56009a,0x00000000}},	//   _פתח_, _спип, _תבקש_,
  { {0x36675bf0,0x68e5004d,0x05aa0085,0x00000000}},	// [bbe0] гато_, _fehd, евай_,
  { {0x04460f34,0x00000000,0x00000000,0x00000000}},	//   лезн,   ,   ,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xb8270376,0xe8e00013,0xf74602b6,0x00000000}},	//   _союз_, _diễu_, _семо,
  { {0x5b7b0047,0x2d9e00d1,0x9c7c0066,0x00000000}},	//   ערנא, ylte_, vačm,
  { {0x31345b22,0x18362177,0x29360041,0x00000000}},	//   рекр, ָאֵל_, ראַן_,
  { {0xe8e0008d,0x6143005e,0x9c7c08b7,0x00000000}},	//   _giễu_, сеја, tačm,
  { {0x2d9e004d,0x752e007d,0xdd2f004c,0x00000000}},	//   wlte_, _habz, měřu,
  { {0xdb04006d,0x5ce6000d,0x99890066,0x00000000}},	//   _chií, люна, _hrať_,
  { {0x2d9e000c,0x44380150,0xdd74005e,0x00000000}},	//   ulte_, _krr_, ргоњ,
  { {0x9c7c0117,0x2cb800c7,0xc3340063,0x00000000}},	//   mačk, ärd_, ֑וֹ_,
  { {0x4fa3005a,0xda35093e,0xa4b70063,0x00000000}},	//   _лихв, аемы, טליה_,
  { {0x629e0051,0xed5a151b,0x63b80066,0x00000000}},	//   ępow, _под_, ívny,
  { {0x442a5bf1,0xceb30047,0x9c7c041f,0x00000000}},	//   _osb_, _פיס_, načk,
  { {0x442a4906,0x3cf701fb,0x58d4128f,0x00000000}},	//   _nsb_, _صعود_, сост,
  { {0xcb99007e,0x387e0066,0x9c7c007c,0x00000000}},	//   _جنبش_, útra_, hačk,
  { {0x64580031,0x442a5bf2,0x3a295bf3,0x00000000}},	// [bbf0] øvin, _asb_, _usap_,
  { {0x9c7c017f,0x99890066,0x00000000,0x00000000}},	//   jačk, _brať_,   ,
  { {0x63a3003b,0x9c7c218f,0xa2d50049,0x00000000}},	//   înno, dačk, ليات,
  { {0x92590076,0x442a39e8,0x91d5000d,0x00000000}},	//   кает_, _dsb_, ацкі,
  { {0x81c70418,0x44385bf4,0x442a1123,0x00000000}},	//   klēš, _err_, _esb_,
  { {0x9c7c00b2,0x2fc50331,0xe8e0008d,0x00000000}},	//   gačk, _pulg_, _tiễu_,
  { {0xa1560138,0x443800a8,0x21660121,0x00000000}},	//   рају_, _grr_, рищи_,
  { {0xbe390086,0xff51005d,0x2ba50082,0x00000000}},	//   вчої_, تخت_, _गीला,
  { {0x3eb900c7,0x9c7c007d,0xf6520047,0x00000000}},	//   äst_, bačk, ַצט_,
  { {0x8d5505fb,0x44380244,0xdce80075,0x00000000}},	//   ртич, _yrr_, ıoğl,
  { {0xcb6a5bf5,0xe8e0001b,0x55760047,0x00000000}},	//   ване_, _hiệu_, שעתן_,
  { {0x661d5bf6,0x672f0022,0x2564004b,0x00000000}},	//   _opsk, _nacj, _möla_,
  { {0x6db20045,0x7c2a017d,0xe7e80042,0x00000000}},	//   _płat, _esfr, टीना_,
  { {0xa2aa0053,0xdb19004e,0x2bc60082,0x00000000}},	//   जेट्, _auvä, _रूवा,
  { {0xe8e0001b,0x661d20ae,0xb8ce0053,0x00000000}},	//   _liệu_, _apsk, _और_,
  { {0x2b40000c,0x9c7c007d,0xdd2f004c,0x00000000}},	//   _unic_, začk, věřu,

  { {0xc4e60076,0xf50a019c,0x44381ae4,0x00000000}},	// [bc00] ижай, кнал_, _srr_,
  { {0x6db20051,0x845a08ef,0x442a5bf7,0x00000000}},	//   _ułat, крет_, _psb_,
  { {0x9c7c0117,0xb4d60053,0x72c60086,0x00000000}},	//   vačk, _सभी_, абез,
  { {0x25fe0082,0x00000000,0x00000000,0x00000000}},	//   _लिपी_,   ,   ,
  { {0x78c5000f,0x672400fe,0x2d8200ea,0x00000000}},	//   _átvá, meij, ékek_,
  { {0x442a5bf8,0xe8e00013,0x99890260,0x00000000}},	//   _tsb_, _diệu_, _trať_,
  { {0x442a5bf9,0x9c7c017f,0xa1270021,0x00000000}},	//   _usb_, račk, شكيل_,
  { {0xd1380051,0x603c003b,0x03d70063,0x00000000}},	//   _skąd_, _rămă, _כולם_,
  { {0xf11a0032,0x65ab004b,0x5f73007e,0x00000000}},	//   _لغات_, sühe, تاور,
  { {0x9c7c1bce,0x63a25bfa,0x409605c5,0x00000000}},	//   lači, llon, _крет,
  { {0xdcfa003b,0x63a25bfb,0xc3340063,0x00000000}},	//   entă, olon, ֖וֹ_,
  { {0x6db20051,0x63a25bfc,0x9c7c0a97,0x00000000}},	//   _płas, nlon, nači,
  { {0xd2460021,0x63a201f4,0x672f0022,0x00000000}},	//   أن_, ilon, _racj,
  { {0x7af60045,0x6604015c,0x6e970054,0x00000000}},	//   _edyt, duik, _твір_,
  { {0x6db20045,0x67d50239,0x672f0022,0x00000000}},	//   _włas, собу, _pacj,
  { {0x1cbb0063,0x661d0137,0x501b0063,0x00000000}},	//   _במוע, _ppsk, כולו,
  { {0x79a70002,0xd843004c,0x7bda2161,0x00000000}},	// [bc10] _врне, dičů_, lptu,
  { {0x63a25bfd,0xdce8004c,0x201e00a8,0x00000000}},	//   elon, vidě, _opti_,
  { {0xba74005d,0x7af6002b,0xd5b829c2,0x00000000}},	//   _هایت, _ydyt, рст_,
  { {0x9c7c017f,0x3384005a,0x27fe0024,0x00000000}},	//   gači, оучв, átne_,
  { {0x5694019d,0x9647000d,0x2d8500a3,0x00000000}},	//   _мают, _тэнд, ynle_,
  { {0x1a9a0047,0x27fe22e7,0x63a25bfe,0x00000000}},	//   ניװע, štne_, alon,
  { {0x6296005b,0xf99f00cd,0x7bce06d5,0x00000000}},	//   üyor, ltès_, íbul,
  { {0x645800fe,0x43850021,0x2d9c007d,0x00000000}},	//   ävie, _الرق, _akve_,
  { {0xf99f4b27,0x0d950085,0x00000000,0x00000000}},	//   ntès_, йшоў,   ,
  { {0xdce1008f,0xfd490121,0x4d650f50,0x00000000}},	//   vilē, узок_, сков,
  { {0x3f58017d,0x2d8500a3,0xac090085,0x00000000}},	//   _céus_, rnle_, ынна_,
  { {0x3f5800cd,0x9984004c,0xd37a0041,0x00000000}},	//   _déus_, ímž_, ָרשט,
  { {0xdce8005b,0xed4e0062,0x7bda13cb,0x00000000}},	//   aldı, _ео_, aptu,
  { {0x2bcf0161,0x290c004b,0x387e017c,0x00000000}},	//   _संपा, üda_, útro_,
  { {0x6d433177,0x6e294c61,0x98a607bf,0x00000000}},	//   _inna, lweb, сиве,
  { {0x6f09003e,0x7c3c00b9,0x290c0051,0x00000000}},	//   ngec, ærre, żda_,
  { {0x9c7c4325,0x05660062,0x6f090139,0x00000000}},	// [bc20] vači, бван, igec,
  { {0x660403a8,0xca37009a,0x3a37009a,0x00000000}},	//   ruik, _פניה_, _פרים_,
  { {0x63a25bff,0x6e29004d,0x2d8200ea,0x00000000}},	//   tlon, hweb, ékei_,
  { {0x63a22f1b,0xd24f005d,0x826a01a4,0x00000000}},	//   ulon, کنه_, лаев_,
  { {0x9c7c38ac,0x290500ea,0x7d080137,0x00000000}},	//   rači, ólag_, ygds,
  { {0x63a202e2,0x2918069f,0x2abb0047,0x00000000}},	//   slon, nfra_, אמנא,
  { {0xcf9a0002,0x9c7c0078,0xd46a0092,0x00000000}},	//   лји_, pači, _сиве_,
  { {0x6d4337f7,0x3f58017d,0x984c001c,0x00000000}},	//   _anna, _réus_, dēļa_,
  { {0xa5bb0fac,0x2cea0b62,0x667b0047,0x00000000}},	//   _próx, льно_, ָטיק,
  { {0xd6570063,0x71d7009a,0xa50b009d,0x00000000}},	//   ציית_, _לומד_, ְּיִ,
  { {0x459b00b5,0xaf0a00b3,0x40960021,0x00000000}},	//   רסיע, _مقام_, _الضر,
  { {0x7b671001,0xeb4b1cb9,0x65b000fe,0x00000000}},	//   стое, учок_, lähd,
  { {0x291800c7,0xbc67007e,0x5dda3a82,0x00000000}},	//   ffra_, لمین_, _сфер_,
  { {0xfbcf007e,0x7bda004b,0xdd8f0021,0x00000000}},	//   بتی_, pptu, _كون_,
  { {0x115b0047,0x37c40002,0x98480ee5,0x00000000}},	//   נדלע, зљуб, бята_,
  { {0x28d90161,0xf773007e,0x78a9004c,0x00000000}},	//   _ब्रि, ساز_, řevo,
  { {0x7bca05b3,0x9f4701f4,0xe6100044,0x00000000}},	// [bc30] _hufu, ornò_, فشل_,
  { {0x7bca5c00,0x65b00072,0x7aef5c01,0x00000000}},	//   _kufu, jähd, lact,
  { {0x69dd120a,0xa5bb0516,0xb8df0042,0x00000000}},	//   lpse, _apóc, ेश_,
  { {0x256401be,0x1dc80053,0x69dd004b,0x00000000}},	//   _höll_, रदात, opse,
  { {0x2bcf5c02,0xe29900e1,0x6e2900ac,0x00000000}},	//   _संभा, јал_, xweb,
  { {0x61420138,0xc1e8000d,0x9c7c1035,0x00000000}},	//   деша, сьце_, laču,
  { {0x7aef006f,0x7bca0058,0xb4e50042,0x00000000}},	//   kact, _nufu, नरी_,
  { {0x27e50024,0x987c00b5,0x8117007e,0x00000000}},	//   álny_, טרוק, _گذرا,
  { {0x7aef3cc8,0x97580063,0x6f090058,0x00000000}},	//   dact, מיהו_, rgec,
  { {0x6b8d004b,0x7aef2131,0x6e295136,0x00000000}},	//   _ajag, eact, rweb,
  { {0x6e3c001c,0xfb8a0b3f,0x69dd00ac,0x00000000}},	//   ārba, ибок_, epse,
  { {0x920d0235,0x20075c03,0x657e5c04,0x00000000}},	//   _समाज_, muni_, ziph,
  { {0xc9aa000a,0x645e0051,0x657e00ac,0x00000000}},	//   ивме_, zypi, yiph,
  { {0x645e00fe,0x6d435c05,0x00000000,0x00000000}},	//   yypi, _unna,   ,
  { {0x20070035,0x291802ab,0x65b000bd,0x00000000}},	//   nuni_, rfra_, nähe,
  { {0x49ca04ef,0x27c300de,0x00000000,0x00000000}},	//   _клин_, ِيِّ,   ,
  { {0x63ba00cd,0x2007053b,0x64430137,0x00000000}},	// [bc40] _ètni, huni_, ånin,
  { {0xc6030076,0x7bc4004b,0x200730ca,0x00000000}},	//   ьзуй, _hiiu, kuni_,
  { {0x2007007d,0x657e5c06,0x799c002b,0x00000000}},	//   juni_, riph, morw,
  { {0xe73a0bb3,0x20070035,0x9f5c0080,0x00000000}},	//   _тем_, duni_, prvé_,
  { {0x27ed017f,0x9c7c0024,0x799c0983,0x00000000}},	//   ćene_, lačt, oorw,
  { {0x7aef0529,0x799c0035,0x661602ab,0x00000000}},	//   zact, norw, mtyk,
  { {0xa0670001,0x20070012,0x9c7c027d,0x00000000}},	//   жаја_, guni_, načt,
  { {0x799c001f,0x7aef5c07,0x65b00072,0x00000000}},	//   horw, xact, sähd,
  { {0xc7b30a7a,0x6616091b,0x3ea20026,0x00000000}},	//   ובה_, ntyk, ækt_,
  { {0x20070009,0xdb0d0164,0x66160006,0x00000000}},	//   buni_, _chaî, ityk,
  { {0x200702f6,0x1ee8007e,0x7aef5c08,0x00000000}},	//   cuni_, _هوای_, tact,
  { {0xdce10078,0x66165c09,0x0a6b0054,0x00000000}},	//   kilė, ktyk, арги_,
  { {0x799c5200,0x69dd0072,0x6d4e004b,0x00000000}},	//   forw, upse, öbas,
  { {0x7aef4379,0x799c002b,0x7c370014,0x00000000}},	//   sact, gorw, ðarí,
  { {0xf770007e,0x7aef0955,0xa5bb00be,0x00000000}},	//   چاق_, pact, _osór,
  { {0x69dd5c0a,0x27fe0124,0x7d1a00ca,0x00000000}},	//   ppse, átna_, lfts,
  { {0x9c7c06bb,0xa6e20026,0x7e6006f8,0x00000000}},	// [bc50] raču, óðan, nymp,
  { {0x27fe00c3,0x6d58017f,0x7d1a004d,0x00000000}},	//   štna_, _jova, nfts,
  { {0x49b8006a,0x65ab0244,0x7aed5c0b,0x00000000}},	//   _بايد_, bühn, _keat,
  { {0x200701cf,0x65b00656,0x8c1b089e,0x00000000}},	//   vuni_, vähe, שואי,
  { {0x7aed057a,0x32f20021,0x61453d47,0x00000000}},	//   _meat, ركوز, зела,
  { {0x6d584447,0x2d5b021f,0x7aed057a,0x00000000}},	//   _nova, _lêer_, _leat,
  { {0xe0420200,0x2007004b,0x2bc60042,0x00000000}},	//   енщи, uuni_, _रंगा,
  { {0xd343007e,0x6e220139,0x20073d03,0x00000000}},	//   _تفری, _bpob, runi_,
  { {0xc33200b7,0xf2d200b5,0x7bc4004b,0x00000000}},	//   _און_, _װעב_, _riiu,
  { {0x1d090001,0xce18000d,0x20074ed5,0x00000000}},	//   љени_, іцыі_, puni_,
  { {0x44230089,0x75355c0c,0x6d5c004b,0x00000000}},	//   _jpj_, _mazz, öraa,
  { {0x69c5024a,0x75350314,0x10360063,0x00000000}},	//   _aihe, _lazz, _מטעם_,
  { {0x7aed0037,0x256400c7,0x23ae0014,0x00000000}},	//   _deat, _dölj_, nýja_,
  { {0x61e92cdb,0x2d8200ea,0x291e0014,0x00000000}},	//   _mwel, éket_, ýta_,
  { {0x256400c7,0x7aed1cd8,0x69c55c0d,0x00000000}},	//   _följ_, _feat, _dihe,
  { {0xfe65007e,0x97c301d5,0x7aed0934,0x00000000}},	//   نگ_, ейсе, _geat,
  { {0x0566005a,0x753501f4,0xb69b003b,0x00000000}},	// [bc60] пван, _bazz, _scâr,
  { {0x1c1f0053,0x753501f4,0xaa3b0063,0x00000000}},	//   _बहाल_, _cazz, _פתיח,
  { {0x65ab004d,0x753501c6,0x66165c0e,0x00000000}},	//   mühl, _dazz, styk,
  { {0xd3790086,0xdcfa00a8,0xf74a0044,0x00000000}},	//   очі_, vitč, _الحي_,
  { {0xebad0047,0x753501f4,0x71a6000d,0x00000000}},	//   בסאָ, _fazz, падз,
  { {0x61e9015e,0xdcfa001c,0x66041310,0x00000000}},	//   _dwel, rotī, mrik,
  { {0x66045696,0x40341224,0x6d585c0f,0x00000000}},	//   lrik, фейс, _rova,
  { {0x78a11561,0x66040656,0xd25200de,0x00000000}},	//   ülvi, orik, _كنز_,
  { {0x61e90185,0xe8e0001b,0x66045c10,0x00000000}},	//   _gwel, _chịu_, nrik,
  { {0x63ae0006,0x20560086,0x7aed5c11,0x00000000}},	//   šinė, _нтер, _seat,
  { {0x7aed0004,0x66045c12,0x9b955c13,0x00000000}},	//   _peat, hrik, динц,
  { {0xa3e40053,0x343b0041,0x660421fd,0x00000000}},	//   पीए_, צײכע, krik,
  { {0x09e40088,0x65ab00bd,0x5a44000d,0x00000000}},	//   ноўн, fühl, нэра,
  { {0x395a368c,0xdb0d0003,0x7aed27f0,0x00000000}},	//   _cops_, _thaï, _weat,
  { {0x75355c14,0x7aed5c15,0x98c1001c,0x00000000}},	//   _razz, _teat, _āpēc_,
  { {0x27ff06bb,0x75350089,0x2d8c004d,0x00000000}},	//   čun_, _sazz, lnde_,
  { {0x75350290,0x2d8c5c16,0x69c55c17,0x00000000}},	// [bc70] _pazz, onde_, _tihe,
  { {0x2d9e2b78,0xdb0d0139,0x6a140044,0x00000000}},	//   note_, _mhaí, _أبير,
  { {0x2d8c50a8,0x61e91098,0xdce8008f,0x00000000}},	//   inde_, _swel, lidē,
  { {0xe1f1007e,0x2bcf0053,0x66045c18,0x00000000}},	//   نست_, _संसा, brik,
  { {0xb90a001b,0x2d9e0006,0x75350290,0x00000000}},	//   _nghệ_, kote_, _tazz,
  { {0x2d8c0122,0x236600c2,0x2d9e5c19,0x00000000}},	//   jnde_, akoj_, jote_,
  { {0xd4040076,0x2d9e5c1a,0xd12e0044,0x00000000}},	//   _пяти, dote_, شمي_,
  { {0xfe45000a,0x61e90034,0x2d8c5809,0x00000000}},	//   днио, _twel, ende_,
  { {0xee3602dc,0xef16007f,0x2fc600a3,0x00000000}},	//   дны_, фмы_, _diog_,
  { {0xe81e0053,0x9e640021,0x2d9e0877,0x00000000}},	//   _पहला_, عاين, gote_,
  { {0x61fc008f,0x236d056c,0xa156009a,0x00000000}},	//   _ārli, _klej_, _קבעה_,
  { {0x2d8c2aad,0x66045c1b,0x7c940085,0x00000000}},	//   ande_, yrik, эрыц,
  { {0x2bcf0053,0xfe45071f,0x2d9e5c1c,0x00000000}},	//   _संवा, _інко, bote_,
  { {0x2d9e4af2,0x66045c1d,0xbbe8005d,0x00000000}},	//   cote_, vrik, _کروم_,
  { {0x3f8d0994,0x475a093e,0xb8950062,0x00000000}},	//   oneu_, орая_, ертъ,
  { {0x290401f7,0x8b95000d,0x27fe00c3,0x00000000}},	//   şma_, _прыч, štno_,
  { {0x80a40161,0xdcfa003d,0x27ed017f,0x00000000}},	// [bc80] _चुने, litā, ćena_,
  { {0x66045c1e,0x5983268e,0x05850054,0x00000000}},	//   rrik, _альб, нуєм,
  { {0xdcfa001c,0x66045c1f,0x23660130,0x00000000}},	//   nitā, srik, tkoj_,
  { {0x2d9e0009,0x2ca75c20,0xdb160003,0x00000000}},	//   zote_, _mynd_, écèd,
  { {0x2d9e077d,0x2d8c3a19,0x24f601ce,0x00000000}},	//   yote_, ynde_, _очвр,
  { {0x2366017f,0x2d9e5c21,0x98a3008f,0x00000000}},	//   skoj_, xote_, lejā_,
  { {0x2d9e1dd9,0xdb040139,0x65635c22,0x00000000}},	//   vote_, _dhiú, önhe,
  { {0x236d00c3,0x2d9e0009,0x3f8d00cd,0x00000000}},	//   _glej_, wote_, gneu_,
  { {0x2d9e0006,0xdce1008f,0x626600de,0x00000000}},	//   tote_, cilī, _غارق,
  { {0xdb040139,0xdce8008f,0x2d8c5c23,0x00000000}},	//   _ghiú, vidē, unde_,
  { {0x2d8c004d,0xdcfa008f,0x61e25c24,0x00000000}},	//   rnde_, gitā, lpol,
  { {0x61e25c25,0x3dc7004d,0x2d9e3810,0x00000000}},	//   opol, _einw_, sote_,
  { {0x2d9e4bcd,0x61e25c26,0x7e9a0021,0x00000000}},	//   pote_, npol, _بنشر_,
  { {0x2ca70185,0x3f840a1a,0x61e25c27,0x00000000}},	//   _fynd_, limu_, ipol,
  { {0x64580072,0x6d4a0fdb,0x58d40f85,0x00000000}},	//   ävil, _infa, тост,
  { {0x65ab3592,0x3f845c28,0x4bfb0063,0x00000000}},	//   rühm, nimu_, _ולהס,
  { {0x35b50079,0x60da00bd,0xd7c40121,0x00000000}},	// [bc90] ебар, _oftm, тёро,
  { {0x3f840009,0x61e25c29,0x236d00a8,0x00000000}},	//   himu_, dpol, _slej_,
  { {0x3f8408f1,0x236d5c2a,0x68f55c2b,0x00000000}},	//   kimu_, _plej_, mazd,
  { {0x14df0161,0x66020006,0x3f840006,0x00000000}},	//   _प्रण, šoka, jimu_,
  { {0xdb160164,0xdcfa008f,0x3f8416fe,0x00000000}},	//   écéd, zitā, dimu_,
  { {0x6d5c0137,0x660d0150,0xe3d70044,0x00000000}},	//   öral, muak, _يتزع,
  { {0x25a10080,0x4fa50062,0x10a241ab,0x00000000}},	//   mohl_, никв, лишн,
  { {0xdcfa003d,0x6d4a40a4,0x3f840822,0x00000000}},	//   vitā, _anfa, gimu_,
  { {0x3f8d0994,0x61e20051,0x2ca70a3f,0x00000000}},	//   rneu_, cpol, _synd_,
  { {0x128a007e,0x68f51a03,0x672d004b,0x00000000}},	//   _عملی_, jazd, heaj,
  { {0x672d0035,0x00000000,0x00000000,0x00000000}},	//   keaj,   ,   ,
  { {0x6d4a5c2c,0xdcfa001c,0x798e002b,0x00000000}},	//   _enfa, ritā, wnbw,
  { {0x672d00dd,0x8b950085,0x8b08011b,0x00000000}},	//   deaj, трэч, _apří,
  { {0x317900b5,0x68f500ea,0x2ca700b9,0x00000000}},	//   לאָד, gazd, _tynd_,
  { {0x61e208ea,0x2d853022,0xa3bf0053,0x00000000}},	//   zpol, mile_, ँगा_,
  { {0xc7a30002,0x61fb30c7,0x645801cf,0x00000000}},	//   гиск, _ovul, ävim,
  { {0x2d85290c,0x239800a8,0x66e0004c,0x00000000}},	// [bca0] oile_, nčje_, jáků,
  { {0x2d855c2d,0xdcfa003b,0xba9b089e,0x00000000}},	//   nile_, mită, _מספי,
  { {0x61fb024a,0x13060079,0xdcfa0529,0x00000000}},	//   _avul, езем, lită,
  { {0x2d85425f,0x61e230b3,0xa90a0043,0x00000000}},	//   hile_, tpol, _بيگل_,
  { {0xdcfa0529,0x3f840006,0x8b080080,0x00000000}},	//   nită, vimu_, _zpří,
  { {0x61e40529,0x61e2351f,0x916c0013,0x00000000}},	//   ţilo, rpol, _bốn_,
  { {0x3f845552,0x6d5c004b,0x239800c2,0x00000000}},	//   timu_, öram, ečje_,
  { {0x7c3e00ea,0x2d851ab2,0x61e25c2e,0x00000000}},	//   _ápri, eile_, ppol,
  { {0x63a22af2,0x916c008b,0x2d854b78,0x00000000}},	//   moon, _tồn_, file_,
  { {0xdcfa003b,0x2d855c2f,0x65b0004d,0x00000000}},	//   dită, gile_, zähn,
  { {0x201a00cd,0x4c941e1b,0xfe6f005d,0x00000000}},	//   àpid_, тинс, لدی_,
  { {0x63a2002c,0xe0df008b,0x2d850025,0x00000000}},	//   noon, _đòi_, aile_,
  { {0x645800fe,0x2d854350,0x9d180002,0x00000000}},	//   ävij, bile_, _жолт_,
  { {0x65b000bd,0x4aa50053,0x660d0124,0x00000000}},	//   wähn, _गुणव, vuak,
  { {0x27ed017f,0x63ab0026,0x63a25c30,0x00000000}},	//   ćeno_, ylgn, koon,
  { {0x25a10199,0x63a20ff2,0x2cb1005b,0x00000000}},	//   wohl_, joon, üzde_,
  { {0xdcfa000c,0xb9990001,0x63a2004b,0x00000000}},	// [bcb0] cită, _ових_, doon,
  { {0x6d9c0058,0xd251005d,0x65b00244,0x00000000}},	//   _uçağ, ینا_, sähn,
  { {0x63a20179,0x44275c31,0x8b08004c,0x00000000}},	//   foon, ïn_, _upří,
  { {0x200700c3,0x2d851106,0x9962008f,0x00000000}},	//   vrni_, zile_, _cīņu_,
  { {0xe0ce04d8,0xdb0400ca,0x68e3004e,0x00000000}},	//   ив_, _skië, _õnds,
  { {0x9102005e,0xdce80078,0x2d85004e,0x00000000}},	//   апше, midė, xile_,
  { {0xdcfa003b,0x2d855c32,0x63a2285d,0x00000000}},	//   zită, vile_, boon,
  { {0x916c0013,0xc01c0013,0x9f5c0061,0x00000000}},	//   _vốn_, _hước_, trvá_,
  { {0xdce1003d,0xe3b00242,0x81d50054,0x00000000}},	//   eklā, _طرف_, _розх,
  { {0xdcfa000c,0x4d655c33,0x1c450541,0x00000000}},	//   vită, тков, вном,
  { {0x2d855c34,0xfc050062,0x3b0a0f55,0x00000000}},	//   rile_, ъпно, мено_,
  { {0xdcfa003b,0x29015c35,0x0056009f,0x00000000}},	//   tită, _adha_, _בשעת_,
  { {0x3f7a0047,0xff500021,0x2d850fba,0x00000000}},	//   _קאנס, _دخل_, pile_,
  { {0xc01c00aa,0xdcfa000c,0x63a20035,0x00000000}},	//   _nước_, rită, zoon,
  { {0x63a20035,0xf99f00cd,0xdcfa003b,0x00000000}},	//   yoon, prèn_, sită,
  { {0x9a6a0021,0xca74007e,0xab9a0044,0x00000000}},	//   _يمثل_, _منعک, _تختر_,
  { {0xfaa6000a,0x24f6000a,0xc01c001b,0x00000000}},	// [bcc0] _јапо, вчер, _bước_,
  { {0x63a20162,0xf5070076,0xc01c008b,0x00000000}},	//   woon, кнул_, _cước_,
  { {0xdce80078,0x63a22792,0x1c090053,0x00000000}},	//   aidė, toon, _विफल_,
  { {0xc2c6007e,0x91e6032d,0xd2660c03,0x00000000}},	//   نياي, воде, ккей,
  { {0x25640026,0x63a25c36,0xdce1008f,0x00000000}},	//   _sölu_, roon, zklā,
  { {0x63a215ed,0xa0b801ce,0x04ca0044,0x00000000}},	//   soon, нглу_, _يوحي_,
  { {0x63a20035,0xf9930063,0xf1a901f3,0x00000000}},	//   poon, ברג_, راهه_,
  { {0x200e0009,0x65b000bd,0x442a2b39,0x00000000}},	//   rufi_, zähl, _ipb_,
  { {0xab5b004d,0x201c00c2,0x753c5c37,0x00000000}},	//   hmüc, stvi_, _karz,
  { {0x6b840747,0x25640026,0xdce1008f,0x00000000}},	//   _amig, _tölu_, tklā,
  { {0x753c5c38,0x217525d5,0xd00f0044,0x00000000}},	//   _marz, _сутр, _ولك_,
  { {0xf413014e,0x65b000bd,0xdce1001c,0x00000000}},	//   ספר_, wähl, rklā,
  { {0xed5a005a,0x65ab0019,0xc3330a7a,0x00000000}},	//   _оод_, sühi, בור_,
  { {0x753c0045,0xc98702d8,0x6b845c39,0x00000000}},	//   _narz, туми, _emig,
  { {0x97a70076,0xc01c008b,0x7987006f,0x00000000}},	//   врал, _rước_, rijw,
  { {0x753c006f,0xdce80078,0x25fe0042,0x00000000}},	//   _aarz, tidė, _लिखी_,
  { {0xc7c80076,0xc6a7005e,0x46150021,0x00000000}},	// [bcd0] тыре_, трви, طوار,
  { {0x6aad00e8,0xdce80006,0xe6100021,0x00000000}},	//   _iyaf, ridė, تشف_,
  { {0xdce80006,0x44380509,0x7bcd0078,0x00000000}},	//   sidė, _csr_, _kiau,
  { {0x20130268,0x386c0093,0xd7f1008b,0x00000000}},	//   àxim_, ødre_, ẫu_,
  { {0xc01c008b,0x6b7c016e,0xd5c5012c,0x00000000}},	//   _tước_, וראנ, вiдн,
  { {0x7bcd0006,0x7c38007d,0x753c3f9f,0x00000000}},	//   _liau, _osvr, _garz,
  { {0x257601e1,0xc954009f,0x321d0022,0x00000000}},	//   _sælg_, ימס_, stwy_,
  { {0x753c0045,0xee390336,0x673d00ca,0x00000000}},	//   _zarz, ени_, _jasj,
  { {0x673d34ef,0xa6e20026,0xa5bb017d,0x00000000}},	//   _masj, óðin, _apói,
  { {0x25761c2b,0x27fe00c3,0x673d00c2,0x00000000}},	//   _vælg_, štni_, _lasj,
  { {0x9f0504f6,0x63bb008b,0x6ab60022,0x00000000}},	//   _موضو, _khun, _szyf,
  { {0x673d0031,0x2bba0032,0x65ab004d,0x00000000}},	//   _nasj, عادة_, mühu,
  { {0x239800c2,0xde0519f7,0x00000000,0x00000000}},	//   nčja_, _спли,   ,
  { {0xd946005e,0x644729ce,0xfce20899,0x00000000}},	//   ћеви, _orji, _лошо,
  { {0x63a900c3,0xef26004b,0x673d342d,0x00000000}},	//   _oken, üügi_, _basj,
  { {0xe737018e,0xa6ca0002,0x6b8400a4,0x00000000}},	//   лес_, елба_, _umig,
  { {0x644300b9,0x753c5c3a,0x7e69017e,0x00000000}},	// [bce0] ænin, _parz, nyep,
  { {0x20180203,0x442a06f7,0x63a91384,0x00000000}},	//   _årig_, _ppb_, _aken,
  { {0x63bb0025,0x69d61cbe,0x130a05ac,0x00000000}},	//   _bhun, _huye, еней_,
  { {0x63bb152d,0xe29a5c3b,0x69d605b3,0x00000000}},	//   _chun, нае_, _kuye,
  { {0x5186000a,0xa6830d80,0x27f6004c,0x00000000}},	//   лука, _гляд, šeně_,
  { {0x673d007d,0x63a9115e,0x64a65c3c,0x00000000}},	//   _zasj, _eken, _бага,
  { {0x629c0045,0x257600b9,0x76440072,0x00000000}},	//   _środ, _væld_, lviy,
  { {0x7af60026,0xb4c00053,0x04930021,0x00000000}},	//   _neyt, ँधी_, _الفح,
  { {0x44445c3d,0x8fa3005e,0xa5bb0139,0x00000000}},	//   lv_, љање, _spói,
  { {0x90d5001b,0xa3d30053,0x71d70063,0x00000000}},	//   _hàn, _हूँ_, _עובד_,
  { {0xdb550055,0x6aad0397,0x7bcd1560,0x00000000}},	//   авны, _syaf, _piau,
  { {0x213e0034,0x69d60969,0x44445c3e,0x00000000}},	//   _hath_, _buye, iv_,
  { {0xc333014e,0x44440019,0xb69b000c,0x00000000}},	//   זור_, hv_, _adân,
  { {0x44445c3f,0x2018004b,0x90d50013,0x00000000}},	//   kv_, _äris_, _làn,
  { {0x213e04bf,0x76440058,0xa3d30053,0x00000000}},	//   _math_, eviy, _हूं_,
  { {0x69d0005f,0x44445c40,0x17f80044,0x00000000}},	//   _žiež, dv_, طرفة_,
  { {0x213e00e5,0x44445c41,0x673d00a8,0x00000000}},	// [bcf0] _oath_, ev_, _vasj,
  { {0x63a952d2,0x7af60433,0xd49b0a91,0x00000000}},	//   _sken, _zeyt, нре_,
  { {0xd6d10032,0x3d1c0053,0x63bb5c42,0x00000000}},	//   _وقد_, _माने_, _phun,
  { {0x90d5008b,0x00000000,0x00000000,0x00000000}},	//   _càn,   ,   ,
  { {0x4444003d,0x90d5008b,0x213e25c9,0x00000000}},	//   av_, _dàn, _bath_,
  { {0xa4d40086,0xa593007e,0x213e13d5,0x00000000}},	//   _горі, _اگرچ, _cath_,
  { {0x70520021,0x213e0139,0x63bb5b1b,0x00000000}},	//   قنوا, _dath_, _thun,
  { {0x63a90205,0x660d5c43,0x6f650a3d,0x00000000}},	//   _uken, orak, рвиз,
  { {0x44210be9,0x7af60026,0x213e0123,0x00000000}},	//   lth_, _reyt, _fath_,
  { {0x44214d4b,0x799500ca,0x213e5c44,0x00000000}},	//   oth_, jnzw, _gath_,
  { {0x44210be9,0xdcfa008f,0x644a004d,0x00000000}},	//   nth_, entē, äfix,
  { {0x660d1c11,0x1ee7007e,0x4421212f,0x00000000}},	//   krak, _صوتی_, ith_,
  { {0xeb970432,0x386a001f,0x333f0003,0x00000000}},	//   рия_, wybr_, _maux_,
  { {0xfce50138,0x1d090098,0x660d1ba6,0x00000000}},	//   _токо, _реки_, drak,
  { {0x52b2016a,0x65b00072,0x660d5c45,0x00000000}},	//   _जर्स, sähk, erak,
  { {0x44211e5b,0x8c1a0063,0xd62a005e,0x00000000}},	//   dth_, _סופי, кобе_,
  { {0x44210c70,0x67240122,0xf99f0268,0x00000000}},	// [bd00] eth_, rfij, guès_,
  { {0x44210034,0x2fcf1262,0x90d5008b,0x00000000}},	//   fth_, _ligg_, _sàn,
  { {0x6d410cc7,0x68fc5c46,0x213e5c47,0x00000000}},	//   idla, mard, _rath_,
  { {0x779404de,0x68fc01f7,0x6d410150,0x00000000}},	//   _ایرا, lard, hdla,
  { {0x98b3000c,0x44211ff2,0x213e28fa,0x00000000}},	//   _taxă_, ath_, _path_,
  { {0x333f0164,0x68fc5c48,0x6d4100ca,0x00000000}},	//   _eaux_, nard, jdla,
  { {0x21670001,0x333f12ee,0x68fc01f4,0x00000000}},	//   рији_, _faux_, iard,
  { {0x9316007e,0x543b0047,0x68fc5c49,0x00000000}},	//   _خورش, _בעלא, hard,
  { {0x27ed017f,0x2fcf5c4a,0x68fc5c4b,0x00000000}},	//   ćeni_, _digg_, kard,
  { {0xe2a6007a,0x65b000bd,0x213e0139,0x00000000}},	//   íðum_, fähi, _uath_,
  { {0x10a60086,0xdcba005a,0xd3140086,0x00000000}},	//   _тижн, ъщи_, _вiдт,
  { {0x2d870205,0xbb940076,0xdb6b33df,0x00000000}},	//   _emne_, жающ, трол_,
  { {0x68fc5c4c,0xdb0a013d,0x0f7b009d,0x00000000}},	//   fard, ónál, _בראל,
  { {0x3af5008b,0x9e65007e,0x44215c4d,0x00000000}},	//   ấp_, _دامن, yth_,
  { {0xb86802a9,0x44210034,0x2b400025,0x00000000}},	//   ајте_, xth_, _faic_,
  { {0x29180027,0x36d5005a,0x68fc326e,0x00000000}},	//   agra_, соар, aard,
  { {0x7bd801e3,0x44210034,0x2d8c006f,0x00000000}},	// [bd10] _huvu, wth_, oide_,
  { {0x2d8c0004,0x7bd80035,0xe4e70086,0x00000000}},	//   nide_, _kuvu, ріан,
  { {0x65ab0199,0x7afd13e6,0x44210238,0x00000000}},	//   führ, oast, uth_,
  { {0xa3b4019d,0x442104bf,0x2d8c044e,0x00000000}},	//   обхі, rth_, hide_,
  { {0x2d8c0004,0x7bd8024a,0x07560063,0x00000000}},	//   kide_, _luvu, _הסרט_,
  { {0x463a00b5,0x44210034,0x7afd5c4e,0x00000000}},	//   _געשע, pth_, hast,
  { {0x333f0164,0x65ab00bd,0x2d8c5c4f,0x00000000}},	//   _taux_, bühr, dide_,
  { {0x2d8c10ce,0x2918007d,0x68fc5c50,0x00000000}},	//   eide_, zgra_, zard,
  { {0x52850021,0x3eb900b8,0x7afd5c51,0x00000000}},	//   _الذك, åst_, dast,
  { {0x7bd80006,0x30a741b8,0x2d8c5c52,0x00000000}},	//   _buvu, _крев, gide_,
  { {0xcb6a2785,0xbb460b3f,0x7afd5c2e,0x00000000}},	//   гане_, бенк, fast,
  { {0xe45600b5,0x7afd3fc2,0x316500bd,0x00000000}},	//   צירט_, gast, _holz_,
  { {0x68fc055b,0x9d450076,0x139a0047,0x00000000}},	//   tard, _гелд, רברע,
  { {0x68fc0027,0x0fd60053,0x3f8d4ee2,0x00000000}},	//   uard, _ढूँढ, lieu_,
  { {0x68fc5c53,0x48070062,0x29180014,0x00000000}},	//   rard, йерн_, rgra_,
  { {0xea5a041d,0x22460066,0x2cb80378,0x00000000}},	//   _број_, yvok_, ürde_,
  { {0xe4d60021,0x96f9000d,0x68fc41a1,0x00000000}},	// [bd20] متاب, рэсу_, pard,
  { {0x3f8d1346,0x4a5b016e,0xceb203c3,0x00000000}},	//   hieu_, _עדיו, לין_,
  { {0xd8d700b5,0xa5bb42d7,0x0fd60042,0x00000000}},	//   _לויט_, _após, _ढूंढ,
  { {0xdce3004c,0x2d8c5c54,0x8bd6009a,0x00000000}},	//   _plně, zide_, צונו_,
  { {0x65ab00bd,0x2369004b,0x3f8d066d,0x00000000}},	//   rühr, öaja_, dieu_,
  { {0x6458024a,0x7afd0a63,0xdb060c38,0x00000000}},	//   ävis, zast, llkä,
  { {0x55770047,0x2d8c5c55,0x71090054,0x00000000}},	//   _פעלן_, vide_, рхів_,
  { {0x2d8c00e5,0x2d9900ea,0x38c30003,0x00000000}},	//   wide_, ésen_, léré_,
  { {0x2d8c0019,0x7afd5c56,0xed140121,0x00000000}},	//   tide_, vast, омпь,
  { {0x71650021,0x38c30003,0x7afd5c57,0x00000000}},	//   _والك, néré_, wast,
  { {0xb09a0086,0xa6db0014,0xcb990054,0x00000000}},	//   _стає_, _laða, ивої_,
  { {0x3f8d0268,0xd3660032,0xdced001c,0x00000000}},	//   cieu_, ذه_, ējād,
  { {0x256f005b,0x7afd5c58,0x2d8c5c59,0x00000000}},	//   _yılı_, rast, pide_,
  { {0x7afd3c69,0x3eb90378,0xdb060072,0x00000000}},	//   sast, üste_, elkä,
  { {0x38c30164,0x7afd5c5a,0x7ae4002b,0x00000000}},	//   déré_, past, _ffit,
  { {0xe894000d,0xc6a70002,0x89d9005d,0x00000000}},	//   чась, брзи, _پودر_,
  { {0x38c30003,0x45d40121,0x2b92011b,0x00000000}},	// [bd30] féré_, зоус, ušce_,
  { {0x67d50006,0x7d1a21bb,0x38c3006c,0x00000000}},	//   _sąju, ngts, géré_,
  { {0xe435006a,0x66d5005d,0x36d50cd6,0x00000000}},	//   تفاد, _ويدئ, _монр,
  { {0xdb06013d,0x69c7013d,0x7c3a002b,0x00000000}},	//   toké, lmje, iwtr,
  { {0x3f8d0994,0x38c9007e,0x645800fe,0x00000000}},	//   vieu_, _حاکی_, ävir,
  { {0x11d40021,0x9f91004c,0xdb060061,0x00000000}},	//   ستهد, _vší_, roké,
  { {0xdb065c5b,0xe2f9012c,0x80240044,0x00000000}},	//   soké, _вебі_, كريم,
  { {0x8e0901d5,0x984c0023,0xce590044,0x00000000}},	//   анив_, lēģa_, لشخص_,
  { {0x63ab45ed,0xfd110021,0x3f8d3145,0x00000000}},	//   mogn, وجد_, rieu_,
  { {0x98ba003d,0xfc290076,0x1d090001,0x00000000}},	//   _lapā_, ажок_, јени_,
  { {0x3f8d0268,0x61e9007d,0xdb060072,0x00000000}},	//   pieu_, _htel, ylkä,
  { {0x98b80006,0x65b010f0,0x6d5c0137,0x00000000}},	//   ndrą_, läht, örar,
  { {0x433a0047,0xa2dc0042,0xed592046,0x00000000}},	//   בערב, _फलस्, _вол_,
  { {0x65b00004,0x2eff00bd,0xa6db0026,0x00000000}},	//   näht, lauf_, _raða,
  { {0x38550062,0x6843004c,0x63ab0d1a,0x00000000}},	//   пътс, vídá, kogn,
  { {0x6d435c5c,0x6f1b003e,0x7ae40035,0x00000000}},	//   _hana, nguc, _ufit,
  { {0x05663ca8,0xd5e90021,0x6d435c5d,0x00000000}},	// [bd40] ован, معلن_, _kana,
  { {0xa5bb3fec,0x65b00072,0x6d433f9e,0x00000000}},	//   _spór, jäht, _jana,
  { {0x224d0150,0x61e95c5e,0x2eff004d,0x00000000}},	//   _arek_, _atel, kauf_,
  { {0xfe670032,0x224d0089,0x443a002b,0x00000000}},	//   _قد_, _brek_, rwp_,
  { {0x38c30003,0x11540062,0x31c60be8,0x00000000}},	//   péré_, зклю, оскв,
  { {0x7bcf0240,0x6d435c5f,0x66045c60,0x00000000}},	//   íbuz, _nana, msik,
  { {0x657e018d,0x61e900fe,0x660400d1,0x00000000}},	//   mhph, _etel, lsik,
  { {0x63ab5c61,0x69c7017f,0x6d430da5,0x00000000}},	//   cogn, zmje, _aana,
  { {0x66045c62,0x6d435c63,0x20050b42,0x00000000}},	//   nsik, _bana, _evli_,
  { {0x6d430d6a,0xfbe90013,0x66045c64,0x00000000}},	//   _cana, _tuệ_, isik,
  { {0xdd970088,0x6d435c65,0x7bc80078,0x00000000}},	//   ўшы_, _dana, įjun,
  { {0x61e90031,0x66040f2b,0x9e66013a,0x00000000}},	//   _ytel, ksik, _واشن,
  { {0x09e4000d,0x6d432e86,0x62825c66,0x00000000}},	//   моўн, _fana, nzoo,
  { {0x2735001b,0x6d435c67,0x644e09b7,0x00000000}},	//   _ấn_, _gana, _orbi,
  { {0x9848005a,0xf77303eb,0x9f58013d,0x00000000}},	//   оята_, وار_, _író_,
  { {0x69c7007d,0x6d430557,0x660b013d,0x00000000}},	//   smje, _zana, ágko,
  { {0x6d430009,0x8575005a,0xc4db0001,0x00000000}},	// [bd50] _yana, плах, ађе_,
  { {0x344b5c68,0x6f000139,0x23bc017c,0x00000000}},	//   ичен_, hamc, víja_,
  { {0x66045c69,0x917b008b,0x63ab01f4,0x00000000}},	//   asik, hệ_, togn,
  { {0x224d0198,0x883a0063,0xb866005d,0x00000000}},	//   _prek_, _פתרו, _راپو,
  { {0x65b0021e,0x6b8d0517,0xc0e502dc,0x00000000}},	//   täht, _mmag, полк,
  { {0xc2440088,0x63ab175f,0x2a3c0041,0x00000000}},	//   ьнік, sogn, יעדמ,
  { {0xddc90051,0x66020006,0x6b8d3022,0x00000000}},	//   rzeż, šokt, _omag,
  { {0x6d435c6a,0x65b00072,0x224d5c6b,0x00000000}},	//   _sana, säht, _trek_,
  { {0x2eff0199,0x61e902fb,0x6d435c6c,0x00000000}},	//   rauf_, _utel, _pana,
  { {0x6b8d5c6d,0x0d825c6e,0x41770049,0x00000000}},	//   _amag, ельн, _بارس,
  { {0x3d1c0161,0x6d431f8f,0xc1720063,0x00000000}},	//   _मारे_, _vana, _רחב_,
  { {0x6d430009,0x65b000bd,0x66045c6f,0x00000000}},	//   _wana, nähr, ysik,
  { {0x6d430397,0x433a0047,0xee2e1a6b,0x00000000}},	//   _tana, זערב, _ян_,
  { {0x6d430035,0xdce30fff,0xfe79004c,0x00000000}},	//   _uana, _konč, ncům_,
  { {0x08c30001,0xb0b50047,0x764f0051,0x00000000}},	//   ебрн, לפֿס_, _arcy,
  { {0xab660086,0x65b000bd,0xb7590086,0x00000000}},	//   _хвил, jähr, ошує_,
  { {0xfbd3014e,0x644e1181,0xf99f2986,0x00000000}},	// [bd60] _אתה_, _srbi, grès_,
  { {0x6b8d040d,0x66045c70,0xab5b004d,0x00000000}},	//   _zmag, rsik, emüh,
  { {0x65b000bd,0xc6890063,0x66045c71,0x00000000}},	//   fähr, נא_, ssik,
  { {0x6282006f,0x7bd60150,0x66045c72,0x00000000}},	//   tzoo, _jiyu, psik,
  { {0x4b4d00b5,0x7ae600a4,0xe297005e,0x00000000}},	//   יגאַ, ickt, пац_,
  { {0x7d0100c3,0x4034043a,0xdb06009c,0x00000000}},	//   jals, декс, dokí,
  { {0x644e1ce0,0x94790054,0xe366242b,0x00000000}},	//   _urbi, _дсту_, _екви,
  { {0x7bd600a4,0x749b0041,0x23270713,0x00000000}},	//   _niyu, _הילפ, _носи_,
  { {0x80a6005d,0x7d015c73,0x63a3009c,0x00000000}},	//   _کمان, fals, énne,
  { {0xc24321b9,0x6b8d5c74,0x50460054,0x00000000}},	//   _янук, _smag, _незб,
  { {0x239800c2,0x6b9d013d,0x78a9011b,0x00000000}},	//   ečji_, érgo, řevz,
  { {0x7bc4051e,0x7d010019,0xdce8005b,0x00000000}},	//   _chiu, aals, ğlıy,
  { {0x59da0161,0x7ac4018e,0x2aab03d6,0x00000000}},	//   _यूआर, есре, стно_,
  { {0x5e57014e,0x827700b5,0xd90f006a,0x00000000}},	//   _מידע_, לעכע_, دید_,
  { {0x68fe00f3,0x6d585c75,0x6d48002b,0x00000000}},	//   _depd, _inva, mdda,
  { {0x5ba40088,0x6b8d4f9c,0xf99f00cd,0x00000000}},	//   _прыз, _umag, très_,
  { {0x98ba003b,0x16340e82,0x6d48056c,0x00000000}},	// [bd70] _papă_, нетя, odda,
  { {0x65b000bd,0x6d485c76,0xf9fc0063,0x00000000}},	//   währ, ndda, _ההזמ,
  { {0x290306e1,0x6d4810ba,0xfe79004c,0x00000000}},	//   maja_, idda, vcům_,
  { {0xf99f02a7,0x7c28006f,0x9295000d,0x00000000}},	//   près_, itdr, маец,
  { {0x2d99000f,0x6d5857db,0xdce300c3,0x00000000}},	//   ések_, _onva, _sonč,
  { {0x29035c77,0x20d50054,0xab5b0244,0x00000000}},	//   naja_, мійс, smüh,
  { {0x7d010198,0x69d70034,0x7ae60137,0x00000000}},	//   vals, _mixe, yckt,
  { {0x29032237,0x69d7017d,0x6d48001f,0x00000000}},	//   haja_, _lixe, edda,
  { {0x7d015c78,0x29035c79,0x7e96007e,0x00000000}},	//   tals, kaja_, وچهر_,
  { {0x7bd6002c,0x63b9001f,0x72040021,0x00000000}},	//   _siyu, llwn, _أولم,
  { {0x7d010105,0x29035c7a,0xc10414d7,0x00000000}},	//   rals, daja_, _سوني,
  { {0x69d70268,0x6d585c7b,0x799c002b,0x00000000}},	//   _aixe, _enva, wnrw,
  { {0x7e280021,0x1d091225,0x6d48002b,0x00000000}},	//   _فسوف_, _дели_, bdda,
  { {0x3afc008b,0x98ba0078,0x29035c7c,0x00000000}},	//   ập_, _lapą_, gaja_,
  { {0x9982004c,0xb9060042,0x48e3130d,0x00000000}},	//   stků_, _फल_, тосв,
  { {0x69c5000f,0x635e003b,0x1bfa0063,0x00000000}},	//   _ehhe, _mănâ, _ולקב,
  { {0x6fea0051,0x29035c7d,0x69d702a0,0x00000000}},	// [bd80] _ięce, baja_, _fixe,
  { {0x29035c7e,0xf1e10053,0x20075c7f,0x00000000}},	//   caja_, _पढ़न, ksni_,
  { {0x53e5019d,0x47c60054,0x03260505,0x00000000}},	//   еціа, _обов, дден,
  { {0x6e2939a7,0x00000000,0x00000000,0x00000000}},	//   kteb,   ,   ,
  { {0x6d485c80,0x200700a8,0x7afb0014,0x00000000}},	//   ydda, esni_, ðuti,
  { {0xc69300b5,0x661605e7,0x61fb0022,0x00000000}},	//   _יאר_, mryk, _dwul,
  { {0x98b1003b,0x00000000,0x00000000,0x00000000}},	//   meză_,   ,   ,
  { {0x3366000d,0x98b1003b,0x29030f74,0x00000000}},	//   _ўваг, leză_, zaja_,
  { {0x29030035,0x2dd401d5,0xc7b30063,0x00000000}},	//   yaja_, нжир, כבה_,
  { {0x98b1000c,0xdb0f017d,0x3eb8008f,0x00000000}},	//   neză_, cocê, ārt_,
  { {0x2903082a,0x2366007d,0x7c281310,0x00000000}},	//   vaja_, ojoj_, utdr,
  { {0x2366007d,0x26c200c2,0x2c4c004c,0x00000000}},	//   njoj_, _ozko_, _věd_,
  { {0x29035c81,0x61e01119,0xda7b013c,0x00000000}},	//   taja_, _juml, іям_,
  { {0x66165c82,0x6d58107b,0x7bdc5c83,0x00000000}},	//   dryk, _unva, írus,
  { {0x5ba71001,0x98b1003b,0x29035c84,0x00000000}},	//   _ориз, deză_, raja_,
  { {0x36d50988,0x29035c85,0x66160022,0x00000000}},	//   еобр, saja_, fryk,
  { {0x2d9e0dc4,0xc50b0021,0x239800a8,0x00000000}},	// [bd90] onte_, قتال_, nčju_,
  { {0x2d9e5c86,0x99d70021,0x7d7b0041,0x00000000}},	//   nnte_, _تتعا, ֿראג,
  { {0x2d9900ea,0x2d9e5c87,0x61e0004b,0x00000000}},	//   ései_, inte_, _auml,
  { {0x2d9e00bd,0x79950035,0x6e2900d1,0x00000000}},	//   hnte_, lizw, yteb,
  { {0x29010019,0xc6a7007b,0xb5f401a4,0x00000000}},	//   _keha_, _црни, _изящ,
  { {0xc1050021,0x4252007e,0x34954990,0x00000000}},	//   روبي, انور, _загр,
  { {0xdce3001c,0xe057007e,0x2fc60139,0x00000000}},	//   _nonā, بیات_, _bhog_,
  { {0xfe45000a,0x2d9e5c88,0x29010089,0x00000000}},	//   енио, ente_, _leha_,
  { {0xee3617ab,0x6e29017d,0xe732089e,0x00000000}},	//   ены_, uteb, אֵת_,
  { {0xdb060114,0xdcfa008f,0x3c650141,0x00000000}},	//   doká, ditē, еког,
  { {0x6e2938ad,0xab640022,0x71d6009a,0x00000000}},	//   steb, óżow, _נועד_,
  { {0x2d9e1070,0xdb0f01a8,0x66ca013d,0x00000000}},	//   ante_, nocè, nöké,
  { {0x09e30062,0x290100ca,0x9f5c0046,0x00000000}},	//   лоян, _beha_, fsvæ_,
  { {0x644a0146,0xf99f01a8,0xdca538ff,0x00000000}},	//   æfik, ssèn_, _пали,
  { {0x0d16014e,0x3c450021,0xdcfa008f,0x00000000}},	//   _טקסט_, _أَبِ, aitē,
  { {0x6133005b,0x66165c89,0xdcfa008f,0x00000000}},	//   lılı, tryk, bitē,
  { {0x7dec0047,0x98b1003b,0x65c624fe,0x00000000}},	// [bda0] ַקאַ, teză_, ебаа,
  { {0x6133005b,0xd9460699,0xf77f0058,0x00000000}},	//   nılı, _џени, _elç_,
  { {0x61e000c2,0x98b1003b,0x69ce16f8,0x00000000}},	//   _suml, reză_, mmbe,
  { {0x237f000c,0x25760026,0x1ddf0053,0x00000000}},	//   _cluj_, _mæli_, नदात,
  { {0x6133005b,0x2d9e00d1,0x69ce5a7c,0x00000000}},	//   kılı, ynte_, ombe,
  { {0x2fcd002b,0x889a0063,0x90e6005d,0x00000000}},	//   emeg_, ּבֵי, رستن,
  { {0x2d9e02ab,0xc0e70021,0x638602fe,0x00000000}},	//   vnte_, رفين_, _згва,
  { {0x7bde0164,0xdb0f00cd,0xe3b70085,0x00000000}},	//   _épui, cocè, _збс_,
  { {0x61ba0021,0x929d0022,0xdbde0014,0x00000000}},	//   _فهرس_, _pełe, díán,
  { {0x44380dde,0x2d9e5c8a,0xdb0601d1,0x00000000}},	//   _kpr_, unte_, voká,
  { {0x2cb800b9,0x2d9e00bd,0x23ca009a,0x00000000}},	//   ærd_, rnte_, ּצָּ,
  { {0x44380150,0xab950086,0x29010089,0x00000000}},	//   _mpr_, тимі, _seha_,
  { {0x79950035,0xdb0f0153,0x44380022,0x00000000}},	//   tizw, nocé, _lpr_,
  { {0x6133005b,0x6f020139,0xdcfa008f,0x00000000}},	//   cılı, _heoc, ritē,
  { {0x443801a6,0xd8380085,0x1dc60082,0x00000000}},	//   _npr_, нэт_, _रीयत,
  { {0x799500ac,0x6d4a5c8b,0xccf8004c,0x00000000}},	//   sizw, _hafa, lbě_,
  { {0xc8f5011c,0x29010004,0xccf80080,0x00000000}},	// [bdb0] _изпъ, _teha_, obě_,
  { {0x443800e3,0xab5b004d,0x6f0200be,0x00000000}},	//   _bpr_, flüg, _leoc,
  { {0x6d4a0035,0x4438113c,0x76464562,0x00000000}},	//   _mafa, _cpr_, _esky,
  { {0x443800f3,0x6133005b,0x6f025c8c,0x00000000}},	//   _dpr_, zılı, _neoc,
  { {0x6133005b,0x7dc60014,0x291e013d,0x00000000}},	//   yılı, iðsb, ótag_,
  { {0x6d4a058c,0x7c380122,0x22b70022,0x00000000}},	//   _nafa, _opvr, _ręką_,
  { {0xa1560001,0xa3b5000d,0xccf8004c,0x00000000}},	//   тају_, _абві, dbě_,
  { {0x6455008f,0xb7dc009d,0x00000000,0x00000000}},	//   _irzi, הקהי,   ,
  { {0x0ea9019d,0x3eb92f88,0x6133005b,0x00000000}},	//   ький_, æst_, tılı,
  { {0x645a0e7c,0x6d4a1775,0xec79012c,0x00000000}},	//   _átic, _cafa, дпо_,
  { {0x5184000d,0x6133005b,0x6d4a001f,0x00000000}},	//   _сута, rılı, _dafa,
  { {0x7ff40021,0x6133005b,0x1eea007e,0x00000000}},	//   _إسلا, sılı, _قومی_,
  { {0x4a43005a,0x6133005b,0xa6db0014,0x00000000}},	//   аняв, pılı, _faði,
  { {0x6d4a3c52,0x273c0013,0x69ce5c8d,0x00000000}},	//   _gafa, _ận_, umbe,
  { {0x7aed001f,0x2d85004c,0x69ce5c8e,0x00000000}},	//   _ffat, mhle_, rmbe,
  { {0x7d0302ab,0x8c1a0063,0x6d210053,0x00000000}},	//   _hens, _חוקי, _माँग_,
  { {0x443800e3,0xc9aa0079,0xab5b004d,0x00000000}},	// [bdc0] _spr_, _овие_, rmüt,
  { {0x6455017f,0x225800c3,0x45830086,0x00000000}},	//   _brzi, _črk_, агув,
  { {0x7d035c8f,0x13060601,0xa7d60044,0x00000000}},	//   _mens, взем, _لتحص,
  { {0xe29a000d,0x7d035c90,0x59bc0053,0x00000000}},	//   мае_, _lens, ोगकर,
  { {0xccf80080,0x64555c91,0x6d210053,0x00000000}},	//   ybě_, _erzi, _मांग_,
  { {0x67240e94,0xdb0f109c,0xd0100021,0x00000000}},	//   lgij, rocé, ملت_,
  { {0xccf80080,0x44380dde,0x6d4a2f67,0x00000000}},	//   vbě_, _upr_, _rafa,
  { {0x6d4a3b3b,0x27fe0066,0x67245c92,0x00000000}},	//   _safa, átny_, ngij,
  { {0x4ea6005a,0xccf80080,0x8fa3005e,0x00000000}},	//   ърка, tbě_, јање,
  { {0x44442c2f,0x7aed000c,0x7d0303e1,0x00000000}},	//   ow_, _sfat, _cens,
  { {0xdce1003d,0xfe6f006a,0x351b0e2a,0x00000000}},	//   eklē, مدی_, ווינ,
  { {0x63a24e5c,0x6d4a3efd,0x7d0318dc,0x00000000}},	//   nnon, _wafa, _eens,
  { {0x6d4a10ca,0x4444001f,0x7d035c93,0x00000000}},	//   _tafa, hw_, _fens,
  { {0xf2d300b5,0x6e203331,0x7d032f75,0x00000000}},	//   יער_, mumb, _gens,
  { {0x7d085c94,0x6d3b0149,0x6e205c95,0x00000000}},	//   mads, _חתונ, lumb,
  { {0x7d08021f,0x4444001f,0x9f910066,0x00000000}},	//   lads, dw_, _sšú_,
  { {0x44445c96,0x87040121,0x6e204ce6,0x00000000}},	// [bdd0] ew_, рясе, numb,
  { {0x2713001b,0x7d085c97,0x44f40086,0x00000000}},	//   ện_, nads, ипус,
  { {0x98ba0080,0x787c0072,0x442b05ac,0x00000000}},	//   _mapě_, rävö, ьцам_,
  { {0x6e200009,0xddc20051,0x63a25c98,0x00000000}},	//   kumb, _proś, gnon,
  { {0x6e200009,0x444425c9,0xb604000d,0x00000000}},	//   jumb, aw_, _вяск,
  { {0x6e20006d,0x63a25c99,0xdcfa0078,0x00000000}},	//   dumb, anon, mitė,
  { {0x7d035c9a,0x660d5c9b,0xb938009a,0x00000000}},	//   _rens, lsak, דרוג_,
  { {0x2f540055,0x7d0341a8,0x4421017e,0x00000000}},	//   атьс, _sens, muh_,
  { {0x4421003e,0x7d0338f1,0x660d0f8c,0x00000000}},	//   luh_, _pens, nsak,
  { {0x660d0019,0x4d655c9c,0xbc190085,0x00000000}},	//   isak, уков, німі_,
  { {0x44210e53,0x64450034,0x7d0357e9,0x00000000}},	//   nuh_, nwhi, _vens,
  { {0x4fa4019d,0x7d030122,0xdcfa0006,0x00000000}},	//   _києв, _wens, kitė,
  { {0x2d8b0164,0x7d0800ea,0x44442082,0x00000000}},	//   èces_, bads, zw_,
  { {0x44210397,0x4444001f,0xfe9a0047,0x00000000}},	//   kuh_, yw_, _אינמ,
  { {0x4421053b,0x25760026,0xa6db0026,0x00000000}},	//   juh_, _mælt_, _maðu,
  { {0x4421053b,0x8a96007e,0x1cba0063,0x00000000}},	//   duh_, _مشخص, _אמצע,
  { {0x6d4100ac,0x6b845c9d,0x660d5c9e,0x00000000}},	// [bde0] oela, _ilig, gsak,
  { {0x6d415c9f,0x8506007e,0x628b00a8,0x00000000}},	//   nela, اوان, dzgo,
  { {0x444402b0,0x44210397,0x290a5ca0,0x00000000}},	//   uw_, guh_, maba_,
  { {0x63a200a4,0x6e200306,0x290a5ca1,0x00000000}},	//   unon, yumb, laba_,
  { {0x69de0009,0x44210150,0x63a25ca2,0x00000000}},	//   _kipe, auh_, rnon,
  { {0x290a02dd,0x6b840268,0x44210397,0x00000000}},	//   naba_, _llig, buh_,
  { {0x628b017f,0x6d415ca3,0x6b845ca4,0x00000000}},	//   azgo, dela, _olig,
  { {0xa8570063,0x6d410019,0x290a139f,0x00000000}},	//   ריקה_, eela, haba_,
  { {0x7d082f5a,0x6d41001f,0x290a4399,0x00000000}},	//   tads, fela, kaba_,
  { {0x290a5ca5,0x01d701a7,0x6d410d6e,0x00000000}},	//   jaba_, _موقع_, gela,
  { {0x290a5ca6,0x6e205ca7,0x759b0063,0x00000000}},	//   daba_, sumb, תייח,
  { {0x2b820027,0x6b8446c5,0x6d41002b,0x00000000}},	//   _póca_, _clig, aela,
  { {0x7d081c11,0x6d412327,0x69de5ca8,0x00000000}},	//   pads, bela, _bipe,
  { {0x29050027,0x290a5ca9,0x69de074f,0x00000000}},	//   úla_, gaba_, _cipe,
  { {0x6b840034,0x69de5caa,0xab5b00bd,0x00000000}},	//   _flig, _dipe, glüc,
  { {0x660d4de3,0x9f4700d1,0xb7940044,0x00000000}},	//   tsak, ppnå_, مؤقت,
  { {0x290a00bb,0x98a5005b,0x15f40021,0x00000000}},	// [bdf0] baba_, ılı_, مسلح,
  { {0x7afd00bd,0x290a0942,0x4421003e,0x00000000}},	//   lbst, caba_, tuh_,
  { {0xe5c40076,0x660d5cab,0xdcfa0078,0x00000000}},	//   ссто, ssak, sitė,
  { {0x442108f0,0x3943008f,0x02d90021,0x00000000}},	//   ruh_, lejs_, نواب_,
  { {0x4421053b,0x7bdf5cac,0x7afd004d,0x00000000}},	//   suh_, _miqu, ibst,
  { {0x6edb003d,0x6d4104fc,0x4421017e,0x00000000}},	//   _jābū, xela, puh_,
  { {0xddcb00eb,0x98b8003b,0x5184005e,0x00000000}},	//   žiūr, meră_, ључа,
  { {0x290a02dd,0xee390793,0x6d415cad,0x00000000}},	//   zaba_, вни_, wela,
  { {0x6d410373,0x63bb0c55,0x290a006d,0x00000000}},	//   tela, _ikun, yaba_,
  { {0x6b840034,0x6b965cae,0x7afd5caf,0x00000000}},	//   _slig, _smyg, ebst,
  { {0x63a9076c,0x69de23a0,0x8d54000d,0x00000000}},	//   _kjen, _ripe, стыч,
  { {0x6d415cb0,0x7bcd0269,0xeb9a1e51,0x00000000}},	//   sela, _chau, тим_,
  { {0x290a5cb1,0x63a9017f,0x3f7a0047,0x00000000}},	//   taba_, _mjen, _שאנס,
  { {0xd7f8003b,0x3943008f,0xc27a009a,0x00000000}},	//   ţăm_, gejs_, דרשי,
  { {0x7bdf0016,0x98b8000c,0x7afd00c7,0x00000000}},	//   _fiqu, deră_, bbst,
  { {0x63bb5cb2,0x63a95cb3,0x6b8401e1,0x00000000}},	//   _nkun, _njen, _ulig,
  { {0x98b8000c,0x290a006d,0x69de3c07,0x00000000}},	// [be00] feră_, paba_, _tipe,
  { {0x929d0045,0x63bb5cb4,0x63a95cb5,0x00000000}},	//   _pełn, _akun, _ajen,
  { {0xa6db0026,0x130a0121,0x2937009a,0x00000000}},	//   _baðs, вней_, _דאין_,
  { {0x7bdf00cd,0x5c360047,0x63a9007d,0x00000000}},	//   _xiqu, ירען_, _cjen,
  { {0x42540021,0xf2030d64,0x98b8003b,0x00000000}},	//   إنتر, оящо, beră_,
  { {0x63a90146,0x63bb1a81,0x33f60054,0x00000000}},	//   _ejen, _ekun, _вчас,
  { {0x63a900b9,0xd4670002,0xe3ba0062,0x00000000}},	//   _fjen, _кире_, _абв_,
  { {0x63a91609,0x7ae400a4,0xa067005e,0x00000000}},	//   _gjen, _ngit, раћа_,
  { {0x3da60086,0x7bdf22bf,0xe731089e,0x00000000}},	//   ироб, _riqu, הֵי_,
  { {0x7bdf0e7c,0x7bcd5cb6,0x7ae415ae,0x00000000}},	//   _siqu, _shau, _agit,
  { {0xa3cb016a,0xdeef17ab,0xfe180053,0x00000000}},	//   _रीड_, _мы_, _दिवस_,
  { {0x5c73013c,0x7afd156b,0x600b009a,0x00000000}},	//   ілят, ubst, _יִדְ,
  { {0x7bdf0994,0xc333014e,0x7afd3181,0x00000000}},	//   _viqu, חור_, rbst,
  { {0x7ae45cb7,0x6c34007e,0x7c6600f2,0x00000000}},	//   _egit, _هفتا, _نابل,
  { {0x3707005a,0x7bdf2a7f,0x77930043,0x00000000}},	//   ичав, _tiqu, قیدا,
  { {0x386d007d,0xb467005d,0x7cc50043,0x00000000}},	//   ćer_, یداه, _ازهم,
  { {0x6b87006a,0x85150086,0x98b8003b,0x00000000}},	// [be10] _مشکل, ймає, teră_,
  { {0x63bb0498,0x63a9007d,0xe5c40b3f,0x00000000}},	//   _skun, _sjen, осхо,
  { {0xaab8007e,0x046727b5,0x69d5004d,0x00000000}},	//   _مدیر_, штам, mmze,
  { {0x98b8000c,0x6cd90047,0x9cd90041,0x00000000}},	//   seră_, אַנצ, אַנז,
  { {0x926b005a,0x98b8003b,0x63a9007d,0x00000000}},	//   ържа_, peră_, _vjen,
  { {0x80f80062,0x61450a71,0x00000000,0x00000000}},	//   ахът_, сека,   ,
  { {0x3f8600e8,0x63a902ab,0xe0550021,0x00000000}},	//   _blou_, _tjen, إختب,
  { {0x1f650076,0x63a90035,0x63bb00ac,0x00000000}},	//   ским, _ujen, _ukun,
  { {0x6b9d5cb8,0x63b90022,0xdb06017c,0x00000000}},	//   disg, mown, pokú,
  { {0x25760146,0x51740032,0x41740032,0x00000000}},	//   _jælp_, _والأ, _والس,
  { {0x61e95cb9,0xe7c70053,0x3f86006c,0x00000000}},	//   _huel, लताप, _flou_,
  { {0x3fc9006a,0xdce100eb,0x63b95cba,0x00000000}},	//   _صدای_, yklė, nown,
  { {0x61e14d4b,0xeb972ab5,0x3a9a012c,0x00000000}},	//   _kill, сия_, утню_,
  { {0xad580062,0x61e95cbb,0x60c10072,0x00000000}},	//   _връх_, _muel, _kylm,
  { {0x7dc60ac6,0x63b90045,0x7ae91ff8,0x00000000}},	//   iðsl, kown, žeta,
  { {0x61e15cbc,0x63b90022,0x98a3012c,0x00000000}},	//   _lill, jown, чисе,
  { {0x63b95cbd,0x3c3128be,0x06ca0085,0x00000000}},	// [be20] down, láv_, угай_,
  { {0xd910006a,0x61e100a3,0xd46a173e,0x00000000}},	//   _زیر_, _nill, лизе_,
  { {0xdb0f0516,0xf7462338,0x74130044,0x00000000}},	//   locá, _лено, كولا,
  { {0x61e15cbe,0x083b0041,0x61e95cbf,0x00000000}},	//   _aill, _געטל, _buel,
  { {0x61e9006d,0x61e11dbc,0x5273005e,0x00000000}},	//   _cuel, _bill, зују,
  { {0x61e95cc0,0x2d9901a8,0x61e15cc1,0x00000000}},	//   _duel, èsel_, _cill,
  { {0x01330032,0x987a00b5,0x21670001,0x00000000}},	//   سعود, טאַט, сији_,
  { {0x63b90051,0x60c50019,0xadf40002,0x00000000}},	//   cown, ühma, опиш,
  { {0x61e91b2d,0x61e15cc2,0x00000000,0x00000000}},	//   _guel, _fill,   ,
  { {0x61ef0164,0x9c380002,0x5d660856,0x00000000}},	//   _écla, апот_, стиз,
  { {0xb5fb04a6,0x6d4f008f,0xe0850044,0x00000000}},	//   _gráf, ēcap, _وجمي,
  { {0x60db0047,0x61e15cc3,0xdce3011b,0x00000000}},	//   _עקאנ, _zill, _koně,
  { {0x3eab0066,0x753c0051,0x539b0aeb,0x00000000}},	//   čitú_, _obrz, ריכו,
  { {0x645c5cc4,0x6b9d5cc5,0x7dc60014,0x00000000}},	//   _orri, sisg, oðsm,
  { {0x6575016b,0x3934000d,0x2d8c0139,0x00000000}},	//   _rozh, чэўс, mhde_,
  { {0x4735000d,0xd794005a,0x7d0a0026,0x00000000}},	//   ўнас, писъ, _hefs,
  { {0x7dc60026,0x65750001,0xf5990062,0x00000000}},	// [be30] yðsl, огађ, аващ_,
  { {0xe4cb007e,0x09070002,0x61e911f5,0x00000000}},	//   هبان_, _учим, _ruel,
  { {0x61e902dd,0x2d8c0072,0x2ee6002b,0x00000000}},	//   _suel, ihde_, _ogof_,
  { {0x61e15cc6,0xfbc90042,0x2d9e0641,0x00000000}},	//   _sill, रतिम, hite_,
  { {0x2d9e0812,0x645c00bd,0x7dcf02ab,0x00000000}},	//   kite_, _erri, løse,
  { {0x61e9048e,0x2d9e1312,0x63b90051,0x00000000}},	//   _vuel, jite_, sown,
  { {0x2d9e5cc7,0x9475007e,0x7dc60014,0x00000000}},	//   dite_, _بگذا, rðsl,
  { {0x224d002c,0x2d9e1a14,0x61e1094f,0x00000000}},	//   _tsek_, eite_, _will,
  { {0x61e10666,0x2d870066,0x61e9004b,0x00000000}},	//   _till, _plne_, _uuel,
  { {0x2d9e03d9,0xb5fb04a6,0x2d8c0025,0x00000000}},	//   gite_, _tráf, ghde_,
  { {0x7f19007e,0xb5fb5cc8,0x04680063,0x00000000}},	//   _نياز_, _frág, ֶיךָ_,
  { {0x2c57000c,0xdb960086,0x3c31004a,0x00000000}},	//   _văd_, ішнь, ráv_,
  { {0x2d9e1312,0xab5b5cc9,0x6ec7005d,0x00000000}},	//   bite_, mlül, _اتاق,
  { {0x3f8d0016,0xedf5007e,0x2d9e5cca,0x00000000}},	//   lheu_, _هيچگ, cite_,
  { {0x765d0089,0x48e30121,0x87760002,0x00000000}},	//   _arsy, дорв, оѓаш,
  { {0xfbc3005a,0xdb06013d,0xfaa6034b,0x00000000}},	//   _общо, knké, _майо,
  { {0xb6a60432,0x6f0b00ea,0x07a3055d,0x00000000}},	// [be40] циал, _megc, фатн,
  { {0x26c20078,0x6f0b013d,0xdd250078,0x00000000}},	//   _vyko_, _legc, _lūži,
  { {0x2db60047,0xe73a5ccb,0xd2a60054,0x00000000}},	//   קלען_, _кен_, _кiль,
  { {0xd62a0001,0x2d9e5ccc,0xb8fd0053,0x00000000}},	//   _коме_, zite_, ते_,
  { {0xdce30080,0x3636007e,0xbb3b0047,0x00000000}},	//   _poně, _برجس, שעני,
  { {0x753c017f,0xab5b00ea,0x113a0121,0x00000000}},	//   _ubrz, elül, ряды_,
  { {0x2d9e1d87,0xe0d3005e,0x7d0a35d7,0x00000000}},	//   vite_, мошњ, _refs,
  { {0x93fb0063,0xdfda0062,0x2d9e0022,0x00000000}},	//   _כללי, шъл_, wite_,
  { {0xe29a0079,0xdcfa0080,0x2d9e5ccd,0x00000000}},	//   _таа_, chtě, tite_,
  { {0x6609005b,0x2d9e4438,0xa63b009d,0x00000000}},	//   _çeke, uite_, סגיר,
  { {0x7d0a0ac6,0xb5fb5cce,0x80a6007e,0x00000000}},	//   _vefs, _trág, _بمان,
  { {0x3f8d5ccf,0x7dc60014,0xd366007e,0x00000000}},	//   cheu_, oðsk, ره_,
  { {0x7fd700b7,0x2d9e5cd0,0x0dca04ef,0x00000000}},	//   _וואס_, pite_, _куки_,
  { {0x7dc6007a,0x61ed0139,0xf8070054,0x00000000}},	//   iðsk, íali, жчан,
  { {0x6d485cd1,0x67d521b9,0xd763005d,0x00000000}},	//   meda, зову, ونسی,
  { {0x7c2800f3,0x6d48164c,0x44210114,0x00000000}},	//   mudr, leda, vrh_,
  { {0x960b000d,0xd6db0065,0x16340330,0x00000000}},	// [be50] рэба_, ртв_, метя,
  { {0x6d485cd2,0x7c2812a2,0x383501e2,0x00000000}},	//   neda, oudr, _енор,
  { {0x69c7065f,0x8883007e,0xab5b0058,0x00000000}},	//   mlje, _غیرن, ylül,
  { {0x2911048e,0xdfc60032,0x6d480019,0x00000000}},	//   laza_, _سي_, heda,
  { {0x02040088,0x6d4827c4,0xd179000d,0x00000000}},	//   дзін, keda, йскі_,
  { {0x29112216,0x6d480c61,0x867a0063,0x00000000}},	//   naza_, jeda, _הרשו,
  { {0xc0e2036a,0x764d04ff,0x6d485cd3,0x00000000}},	//   ношк, lway, deda,
  { {0x672d3e4f,0xb5fb0025,0x61ef0003,0x00000000}},	//   ngaj, _trád, _éclo,
  { {0x29115cd4,0x764d12a9,0xada51f89,0x00000000}},	//   kaza_, nway, запл,
  { {0x29110035,0x61fb1acc,0x764d0089,0x00000000}},	//   jaza_, _itul, iway,
  { {0x7c28008f,0xab5b0075,0xdcfa0023,0x00000000}},	//   gudr, lmüy, uktā,
  { {0x764d0035,0x2911003b,0x6d481aff,0x00000000}},	//   kway, eaza_, aeda,
  { {0xab5b005b,0x63ab5cd5,0x6d48223f,0x00000000}},	//   nmüy, ingn, beda,
  { {0x29110035,0x6e29006d,0x27fa0150,0x00000000}},	//   gaza_, mueb, _ptpn_,
  { {0x59370085,0x764d0168,0x00000000,0x00000000}},	//   язёў_, eway,   ,
  { {0x69c7007d,0xc0520047,0xb7e3007f,0x00000000}},	//   alje, עזן_, ежск,
  { {0x69c701a6,0x6fc55cd6,0xb5fb5cd7,0x00000000}},	// [be60] blje, góci, _aráb,
  { {0xb5fb0025,0xe6170726,0xd6cf0021,0x00000000}},	//   _bráb, яду_, اقك_,
  { {0x61fb1061,0xb97b0063,0xa97b0063,0x00000000}},	//   _atul, _הניי, _האיכ,
  { {0x225f1609,0x1288007e,0x6d480051,0x00000000}},	//   _bruk_, يمای_, zeda,
  { {0x6fc5017d,0x6d482d6f,0x115409b3,0x00000000}},	//   cóci, yeda, дклю,
  { {0x225f04c6,0xb5fb0026,0x15f10053,0x00000000}},	//   _druk_, _fráb, _अंतर_,
  { {0x61fb00fe,0x6d485cd8,0x3958008f,0x00000000}},	//   _etul, veda, idrs_,
  { {0x645b0051,0x7c280137,0xafe302d8,0x00000000}},	//   śció, vudr, нојл,
  { {0xb5fb0080,0x63a25cd9,0xf2020053,0x00000000}},	//   _irác, mion, रीख़_,
  { {0x71a30001,0x667b0047,0x6d48006d,0x00000000}},	//   _зауз, צטיק, ueda,
  { {0x69c706bb,0xfe6f006a,0x764d0035,0x00000000}},	//   vlje, ندی_, zway,
  { {0x6d485cda,0x29110035,0x66160022,0x00000000}},	//   seda, waza_, ksyk,
  { {0x29110035,0xf77f00cd,0x6d485410,0x00000000}},	//   taza_, _niça_, peda,
  { {0x66160850,0xed57000d,0x69c70072,0x00000000}},	//   dsyk, _ноч_, ulje,
  { {0x63a235ac,0x2911560d,0xb5fb0e7c,0x00000000}},	//   kion, raza_, _orác,
  { {0x69c70117,0x764d0035,0x63a20035,0x00000000}},	//   slje, tway, jion,
  { {0x6b8d00bb,0x63a25cdb,0x29110035,0x00000000}},	// [be70] _ilag, dion, paza_,
  { {0x6fc50051,0xb5fb0331,0x26c7008f,0x00000000}},	//   róci, _arác, āno_,
  { {0x61fb091b,0x6b8d0853,0x53350363,0x00000000}},	//   _stul, _klag, деет,
  { {0xf65f05b9,0x63a25cdc,0x398f0244,0x00000000}},	//   _træ_, gion, _düse_,
  { {0x2d855cdd,0x68ec013d,0xa229045b,0x00000000}},	//   ykle_, _áldá, іжка_,
  { {0xa069005e,0x6b8d0857,0xf1940121,0x00000000}},	//   жака_, _llag, ничь,
  { {0x6b8d00c7,0x63a20051,0xdb06004b,0x00000000}},	//   _olag, bion, tokü,
  { {0x225f5cde,0x63a21bb7,0x9e650b69,0x00000000}},	//   _truk_, cion, двид,
  { {0xe3b00049,0xdb08006c,0x225f5cdf,0x00000000}},	//   _صرف_, _éléo, _uruk_,
  { {0x6e2902dd,0x6b8d5ce0,0x4c85344d,0x00000000}},	//   rueb, _alag, длов,
  { {0x6b8d5ce1,0x1b4a0da9,0x2d85133f,0x00000000}},	//   _blag, озни_, rkle_,
  { {0xe2870021,0xf989009a,0x4c820054,0x00000000}},	//   نذ_, _דר_, тлюв,
  { {0x6e2914ca,0xcf92009a,0x4f88009d,0x00000000}},	//   queb, _בטא_, _צָעֲ,
  { {0x63a2104f,0xdb060022,0x6b8d5ce2,0x00000000}},	//   zion, tokó, _elag,
  { {0x7c920021,0x6b8d1aaf,0x394a004d,0x00000000}},	//   _للوص, _flag, rebs_,
  { {0x29050026,0x63a2073b,0x6b8d0734,0x00000000}},	//   ðlar_, xion, _glag,
  { {0x63a25ce3,0xe61a0154,0xab5b0058,0x00000000}},	// [be80] vion, юда_, zlük,
  { {0x63a20045,0x628205b3,0x66165ce4,0x00000000}},	//   wion, vyoo, rsyk,
  { {0x661600d1,0x63a223e9,0xb5fb5ce5,0x00000000}},	//   ssyk, tion, _prác,
  { {0x27f7027d,0x7dc60026,0x63a20871,0x00000000}},	//   žené_, rðsi, uion,
  { {0xb5fb0080,0x63a25ce6,0x22161528,0x00000000}},	//   _vrác, rion, ффер,
  { {0x69dc017f,0x63a25ce7,0x75d6005d,0x00000000}},	//   nmre, sion, _آيسا,
  { {0xb5fb5ce8,0xf2020053,0x03a60336,0x00000000}},	//   _trác, रीज़_, _живо,
  { {0xab5b1c97,0x2269004c,0x0443007b,0x00000000}},	//   rlük, átký_, _шесн,
  { {0x7ae9017f,0xf3f9003b,0x113a000d,0x00000000}},	//   žetk, _ăţi_, _мяжы_,
  { {0x6b8d1781,0xfe6f0021,0xe166013a,0x00000000}},	//   _slag, ؤدي_, _تدري,
  { {0xe0460086,0x69dc00c2,0x6b8d0294,0x00000000}},	//   _інди, dmre, _plag,
  { {0x61e8001f,0x0a6b06be,0x764600ac,0x00000000}},	//   _hidl, орги_, _opky,
  { {0x657c00e8,0x6b8d5ce9,0xd24601fb,0x00000000}},	//   _oorh, _vlag, دن_,
  { {0x7dcf0205,0x657c0089,0xc8fb0053,0x00000000}},	//   løsn, _norh, ्रेम_,
  { {0x61e85cea,0x2d8e004d,0xdc3e0023,0x00000000}},	//   _midl, _ilfe_, rģēt,
  { {0x6b8d5ceb,0x61e812be,0x69dc00c2,0x00000000}},	//   _ulag, _lidl, amre,
  { {0x6d5a05dd,0x7aed0019,0x6d585cec,0x00000000}},	// [be90] odta, _igat, _kava,
  { {0x6d5a5ced,0x7c3a01f4,0xca48007e,0x00000000}},	//   ndta, ottr, _کلیه_,
  { {0x3c3800ea,0x6d5a0137,0x6d580401,0x00000000}},	//   név_, idta, _mava,
  { {0x7c3a0917,0x6d5837fe,0x7e625cee,0x00000000}},	//   ittr, _lava, _orop,
  { {0x657c04b1,0x645a017f,0x216914cd,0x00000000}},	//   _forh, _štit, зили_,
  { {0xdb1d01bb,0x3055005e,0x20550794,0x00000000}},	//   llsä, еђит, етир,
  { {0x3395000d,0x20890062,0xdb1d0003,0x00000000}},	//   _завё, яйки_, posè,
  { {0xa4d4019d,0x6d5a05b9,0xef195cef,0x00000000}},	//   _росі, edta, чми_,
  { {0x7e6204bf,0x7c3a0003,0x69dc002b,0x00000000}},	//   _crop, ettr, ymre,
  { {0x7e6245cb,0x6d583dcd,0x8c950086,0x00000000}},	//   _drop, _cava, ермі,
  { {0x7e62003e,0x6d585cf0,0xbebd008f,0x00000000}},	//   _erop, _dava, egūt,
  { {0x6d58006f,0x69c55cf1,0x2d8e006c,0x00000000}},	//   _eava, _akhe, _elfe_,
  { {0x6e45000a,0x6d585cf2,0x7c3a4df8,0x00000000}},	//   _челз, _fava, attr,
  { {0xfe700021,0x6d580bfa,0x7aed5cf3,0x00000000}},	//   _خدم_, _gava, _egat,
  { {0x18671b76,0x69dc06aa,0xf7460071,0x00000000}},	//   нари_, rmre, нево,
  { {0x9f46051e,0x7bc40035,0x6d585cf4,0x00000000}},	//   _cioè_, _ukiu, _zava,
  { {0x3ea0007a,0xcf9200b5,0x6d58005b,0x00000000}},	// [bea0] _þitt_, אטן_, _yava,
  { {0x7abb0063,0x0906123e,0x443a5cf5,0x00000000}},	//   _מצפו, _япон, ttp_,
  { {0x657c0199,0x3f8f332a,0x98a60141,0x00000000}},	//   _vorh, _olgu_, _чине,
  { {0x61e800c7,0x8cb60047,0xb5fb19e6,0x00000000}},	//   _sidl, תּמא_, _irán,
  { {0x6b9d00cd,0x6d43331a,0x71a62125,0x00000000}},	//   èrgi, _obna, надз,
  { {0x7c3a0026,0x66045cf6,0x64a65cf7,0x00000000}},	//   yttr, mpik, _зага,
  { {0x61e8017f,0xb0da0053,0x201a013d,0x00000000}},	//   _vidl, येंग, épi_,
  { {0xdb1d0164,0xdefa0088,0x395a0b34,0x00000000}},	//   posé, чык_, _laps_,
  { {0x6d5800eb,0x61e80dfb,0x6e3b00a4,0x00000000}},	//   _pava, _tidl, gtub,
  { {0x40962ba9,0x50960001,0x721b0063,0x00000000}},	//   _прет, _пређ, _מומח,
  { {0x6fc505d5,0x0caa0121,0x320d004d,0x00000000}},	//   tóct, ятии_, _zwey_,
  { {0x6d5805b3,0x7e620dd1,0x60c40058,0x00000000}},	//   _wava, _trop, ğimd,
  { {0x6d585cf8,0x60c40058,0x7c3a2755,0x00000000}},	//   _tava, şimd, sttr,
  { {0xf2d300b7,0xa0240199,0x09e40088,0x00000000}},	//   טער_, _größ, лоўн,
  { {0x8d5b014e,0x6fc502dd,0xb5fb006d,0x00000000}},	//   _זכוי, mócr, _crán,
  { {0x0aeb0021,0x7dc6590f,0x7c28002b,0x00000000}},	//   _عربي_, rðsu, mrdr,
  { {0x5694012c,0x8aa40183,0x7ac7014b,0x00000000}},	// [beb0] гатт, _брэд, _яске,
  { {0x57f500a0,0x61ef0003,0x69c500ac,0x00000000}},	//   _ипот, _écli, _ukhe,
  { {0x645a00c3,0xdcf8017f,0xe895093e,0x00000000}},	//   _štir, _novč, _рань,
  { {0x93580054,0xbebd0078,0xa3f40054,0x00000000}},	//   ершу_, igūr, упці,
  { {0x2bb6008f,0x42090054,0x7c280244,0x00000000}},	//   nāca_, єнко_, hrdr,
  { {0x25a5007a,0x7dc60026,0x614531ab,0x00000000}},	//   _öll_, iðss, тека,
  { {0x7bc60026,0x1fb52977,0x94d4079b,0x00000000}},	//   _íhug, ксир, _борц,
  { {0xfe450079,0xaf020062,0x883c0063,0x00000000}},	//   внио, апъл, פתחו,
  { {0x236d0024,0x6e3b017d,0xee360121,0x00000000}},	//   _inej_, utub, вны_,
  { {0x6e3b0228,0x3994004d,0xc6940041,0x00000000}},	//   rtub, _käse_, טאפ_,
  { {0xdbdf0014,0xdb060066,0x6e3b5cf9,0x00000000}},	//   tíðn, enká, stub,
  { {0x395a132b,0x66040072,0x62990022,0x00000000}},	//   _saps_, ypik, ozwo,
  { {0xeb970432,0x2d990003,0x7c2809fe,0x00000000}},	//   тия_, èses_, ardr,
  { {0xdbdf0014,0xc2120063,0x2d8b008f,0x00000000}},	//   síðn, שהם_, īces_,
  { {0x661d0ddc,0x6f093b26,0x2fcd1d82,0x00000000}},	//   _avsk, obec, oleg_,
  { {0x2fcd491e,0x6ce40086,0x6e290384,0x00000000}},	//   nleg_, _січе, oreb,
  { {0x6609005b,0x395a5cfa,0xa9220014,0x00000000}},	// [bec0] _çekl, _taps_, _óþol,
  { {0x66045cfb,0xb5fb5cfc,0x62990022,0x00000000}},	//   rpik, _trán, dzwo,
  { {0x291830ea,0x6e294efd,0xb5fb5cfd,0x00000000}},	//   mara_, hreb, _hrál,
  { {0xb5fb01c2,0x7c2e00cd,0x29185cfe,0x00000000}},	//   _král, àbri, lara_,
  { {0x27e0024a,0x2fcd0627,0x69ce083f,0x00000000}},	//   mmin_, dleg_, olbe,
  { {0x2fc61e79,0xf5030076,0x6e295cff,0x00000000}},	//   _skog_, _взро, dreb,
  { {0x21670001,0xf9930063,0x6e295d00,0x00000000}},	//   тији_, שרו_, ereb,
  { {0x2fcd0627,0x27e009fe,0xa067005e,0x00000000}},	//   gleg_, nmin_, ђања_,
  { {0x8e13000d,0x3246005e,0x6e295d01,0x00000000}},	//   адыц, _језг, greb,
  { {0x6f09006d,0x69ce264d,0x27e05d02,0x00000000}},	//   abec, jlbe, hmin_,
  { {0x27e01d4c,0x29185d03,0x6e295d04,0x00000000}},	//   kmin_, dara_, areb,
  { {0x29180139,0x69ce4be3,0x00000000,0x00000000}},	//   eara_, elbe,   ,
  { {0x6fc50e7c,0xdb06013d,0x7e9a0044,0x00000000}},	//   pócr, unká, _تنشر_,
  { {0x9f81007a,0x29180397,0x6ff1001c,0x00000000}},	//   lóð_, gara_, _sāci,
  { {0x28f80b0f,0x6d8b009a,0x9dd7009d,0x00000000}},	//   тесь_, _קָדְ, _שווק_,
  { {0xe4e30053,0x69ce5d05,0x37043ce8,0x00000000}},	//   _कृषि_, albe, ичув,
  { {0xdb1d000f,0x6ff1001c,0x29185d06,0x00000000}},	// [bed0] nosí, _vāci, bara_,
  { {0x27e0002c,0x29183a41,0x6609005b,0x00000000}},	//   amin_, cara_, _çekm,
  { {0x80a2016a,0xdb0f0003,0x2fcd002b,0x00000000}},	//   _केले, encé, yleg_,
  { {0x9f810026,0x2bf70041,0x662823b4,0x00000000}},	//   jóð_, דמאן_, ürkü,
  { {0x13080086,0x6d41002b,0x82a4005e,0x00000000}},	//   тній_, yfla, ишље,
  { {0xdb1d000f,0x6e29051e,0x32b80032,0x00000000}},	//   dosí, vreb, خدمة_,
  { {0x34950001,0x14c7007e,0x2fcd5d07,0x00000000}},	//   _савр, _شهری_, tleg_,
  { {0x6e293f8c,0x21290058,0x29185d08,0x00000000}},	//   treb, şah_, zara_,
  { {0x2fcd5d09,0xab5b00bd,0x291829ed,0x00000000}},	//   rleg_, hlüs, yara_,
  { {0x91e40001,0x6e295d0a,0x2918017d,0x00000000}},	//   _вође, rreb, xara_,
  { {0x29185d0b,0x6d415d0c,0x2d990006,0x00000000}},	//   vara_, rfla, ėse_,
  { {0x6e2903f5,0x29180bab,0x60c40058,0x00000000}},	//   preb, wara_, şimc,
  { {0x2905005b,0x2918134f,0x6d4100bd,0x00000000}},	//   ılan_, tara_, pfla,
  { {0x99d6007e,0x61ef0003,0xab5b004d,0x00000000}},	//   اقست, _éclu, flüs,
  { {0xe61f017d,0x29185481,0xb5fb5d0d,0x00000000}},	//   _avô_, rara_, _drám,
  { {0x3f8d00f3,0x7c3c0268,0x18670001,0x00000000}},	//   nkeu_, àrre, ћати_,
  { {0xb5fb0025,0x29185d0e,0x7ae90014,0x00000000}},	// [bee0] _frám, para_, þett,
  { {0xc88501f7,0x1a9b0047,0x7bc65d0f,0x00000000}},	//   _başı_, _נייע, loku,
  { {0xef190051,0x0d160047,0x5436014d,0x00000000}},	//   każ_, רקעט_, طرار,
  { {0x442614d5,0x7bc65d10,0xc3d50085,0x00000000}},	//   čo_, noku, аўчы,
  { {0xef190051,0xdb1d00be,0x925802fe,0x00000000}},	//   daż_, losã, талт_,
  { {0x645801e1,0xe5a607ed,0x00000000,0x00000000}},	//   ævis, _сиги,   ,
  { {0x7bc65d11,0x853b0063,0xdcf8008f,0x00000000}},	//   koku, _רגלי, _novā,
  { {0x083b0047,0x2d8300fe,0xdb1d5d12,0x00000000}},	//   געקל, öjen_, tosí,
  { {0x7bc65d13,0x0136002a,0x2007013d,0x00000000}},	//   doku, _معاد, apni_,
  { {0x6f1d0025,0x5c06066c,0xdb1d1092,0x00000000}},	//   óscr, ляма, llsø,
  { {0x7bc65d14,0xed50007e,0x0cd4012c,0x00000000}},	//   foku, مپک_, роню,
  { {0xdb1d004c,0xd00f005d,0x5f7604a0,0x00000000}},	//   posí, _رله_, _حائر,
  { {0xdb1d04aa,0x4f650044,0x00000000,0x00000000}},	//   ilsø, _خالف,   ,
  { {0xdb060072,0x3ea20014,0x9ed70054,0x00000000}},	//   enkä, úktu_, _сміт_,
  { {0x7d1a055e,0xb5fb0066,0x3cfb009a,0x00000000}},	//   mats, _vrám, _אלונ,
  { {0x291e0026,0x7d1a3317,0x9f4c00cd,0x00000000}},	//   ótar_, lats, _judà_,
  { {0xb5fb5d15,0x85150054,0x7d1a0023,0x00000000}},	// [bef0] _irák, имає, oats,
  { {0x3e7a0078,0xdcb1008d,0x7d1a5d16,0x00000000}},	//   mštą_, iản_, nats,
  { {0x54555d17,0xdcb10013,0x69c75d18,0x00000000}},	//   рвет, hản_, moje,
  { {0x69c75d19,0xdfc60021,0x64410072,0x00000000}},	//   loje, _ذي_, _älim,
  { {0x7d1a5d1a,0x471a009a,0x35be0042,0x00000000}},	//   kats, _בורג, ्तख़,
  { {0x7bc60009,0x69c7024a,0xef190045,0x00000000}},	//   zoku, noje, waż_,
  { {0x7bc60009,0x7d1a02c0,0x99590061,0x00000000}},	//   yoku, dats, kážu_,
  { {0x82f80032,0xd346007e,0x3e7a0078,0x00000000}},	//   _مركز_, _نیمه_, kštą_,
  { {0x399401e3,0x7db50002,0x63ab5d1b,0x00000000}},	//   _läsa_, исоц, mign,
  { {0x20070026,0x69c70072,0x44330003,0x00000000}},	//   ppni_, joje, oux_,
  { {0x443330d5,0x3f8d00f3,0x8f75000d,0x00000000}},	//   nux_, pkeu_, _вулі,
  { {0x7d1a0250,0x63ab5d1c,0xd0a8014a,0x00000000}},	//   aats, nign, _студ_,
  { {0x7d1a0ba5,0x628b0078,0x61ee0058,0x00000000}},	//   bats, nygo, _ünlü,
  { {0x69c708ea,0xf1b20047,0x2a69322c,0x00000000}},	//   goje, ַסן_, _drab_,
  { {0x7bc60035,0xa3d50053,0x628b001f,0x00000000}},	//   poku, हता_, hygo,
  { {0xcc3a0047,0x1cba009a,0x6f1b0022,0x00000000}},	//   _סעפט, _במצע, nauc,
  { {0x44330164,0x89d6000d,0x69c75d1d,0x00000000}},	// [bf00] eux_, _вінш, boje,
  { {0x63ab5d1e,0xf6230054,0x75d30049,0x00000000}},	//   eign, ідхо, قيقا,
  { {0x224d00e3,0x7afb4e31,0xdb04013d,0x00000000}},	//   _apek_, žute, _amié,
  { {0x6266000a,0x6b840003,0xdcb10013,0x00000000}},	//   ивеа, _joig, hảo_,
  { {0x44332464,0x3f820026,0xdb1d013d,0x00000000}},	//   aux_, ökum_, nosá,
  { {0xfad7014e,0x6b96001f,0xab5b004d,0x00000000}},	//   בונך_, _llyg, hlüp,
  { {0x7d1a5d1f,0x754700ea,0x6b96001f,0x00000000}},	//   vats, észő, _olyg,
  { {0x9fae0080,0x628b001f,0x63ab01f4,0x00000000}},	//   _tří_, bygo, cign,
  { {0x539b0063,0x3f670002,0x7d1a5d20,0x00000000}},	//   _סימו, рињо_, tats,
  { {0xeb8800b5,0xddc20045,0xb5fb027d,0x00000000}},	//   _אָ_, _społ, _dráh,
  { {0x1b190055,0x7d1a3e1f,0x672600d1,0x00000000}},	//   лжны_, rats, _odkj,
  { {0x7d1a5d21,0x69c70051,0x0ba70086,0x00000000}},	//   sats, woje, ршом,
  { {0x69c75d22,0x6b845d23,0x7d1a5d24,0x00000000}},	//   toje, _doig, pats,
  { {0x660901f7,0x88c70021,0xe3be005b,0x00000000}},	//   _çeki, لتأل, ğıya_,
  { {0x628b0051,0x6b963385,0x57a70002,0x00000000}},	//   zygo, _flyg, ашаа,
  { {0x27ef0026,0x56f50002,0x69c723ec,0x00000000}},	//   ögn_, спаѓ, soje,
  { {0x69c70512,0xa935000d,0x645c30a7,0x00000000}},	// [bf10] poje, _лепш, _asri,
  { {0x55744073,0x63ab0022,0xca36009a,0x00000000}},	//   огут, wign, _פנתה_,
  { {0xf487000a,0x63ab5d25,0x7d180058,0x00000000}},	//   јузн, tign, _mevs,
  { {0x7dcf04aa,0x386c01e1,0x7d1800a8,0x00000000}},	//   røsi, ædre_, _levs,
  { {0x6f1b0003,0xb5fb0139,0x63ab5d26,0x00000000}},	//   vauc, _orái, rign,
  { {0x7d185d27,0x628b5d28,0xf487007b,0x00000000}},	//   _nevs, rygo, _кубн,
  { {0x04950032,0xe9df006d,0x6f1b004d,0x00000000}},	//   _الأح, ctúe_, tauc,
  { {0x28b8014e,0x6f620062,0x6d4a004d,0x00000000}},	//   יפוש_, звъз, _abfa,
  { {0x63a906bb,0xdfa40032,0x22940086,0x00000000}},	//   _imen, تحوي, _дитя,
  { {0x7bcd058c,0x6f1b001c,0x6b845d29,0x00000000}},	//   _akau, sauc, _soig,
  { {0x6b96001f,0x63a901c2,0x6b845d2a,0x00000000}},	//   _plyg, _kmen, _poig,
  { {0x44210034,0x63a90080,0x8b96042c,0x00000000}},	//   ish_, _jmen, сроч,
  { {0xdef8000d,0x0a3a000d,0x63a90035,0x00000000}},	//   _тых_, ычны_, _mmen,
  { {0xd9460001,0x63bb0137,0xc27a0047,0x00000000}},	//   љеви, _ljun, ארשי,
  { {0xb9000235,0xb7960001,0x63a95d2b,0x00000000}},	//   _तर_, браћ, _omen,
  { {0x63bb00c2,0x07a3151e,0x5a960092,0x00000000}},	//   _njun, пасн, _гроф,
  { {0xdcb10013,0x75d6009b,0x44f60043,0x00000000}},	// [bf20] iảm_, ميرا, مساز,
  { {0x63bb5d2c,0x63a918b4,0x649a1225,0x00000000}},	//   _ajun, _amen, лтер_,
  { {0xab5b0019,0x7ddd006c,0xe4e30082,0x00000000}},	//   foüh, cèse, केलि_,
  { {0x63a90051,0xe29a1915,0x031a009e,0x00000000}},	//   _cmen, лае_, اتات_,
  { {0x63bb5d2d,0x291a0222,0x23270189,0x00000000}},	//   _djun, _kepa_, сочи_,
  { {0x55e30076,0x6f020290,0xf5960021,0x00000000}},	//   _нояб, _sfoc, _السج,
  { {0xe04a006a,0x6e2208c4,0xb5fb0139,0x00000000}},	//   اشته_, _svob, _rrái,
  { {0x6f190185,0xb5fb0025,0x44440421,0x00000000}},	//   _cewc, _srái, mt_,
  { {0xa3d50161,0x76445d2e,0xb5fb0025,0x00000000}},	//   हतर_, ntiy, _prái,
  { {0x63a90024,0x44441865,0x6fea0022,0x00000000}},	//   _zmen, ot_, _jęcz,
  { {0xdb550076,0x7d1800d1,0x8fa60002,0x00000000}},	//   овны, _vevs, _лаже,
  { {0x6f19001f,0x44440136,0x764400a5,0x00000000}},	//   _gewc, it_, ktiy,
  { {0x2aab0138,0x44443a9a,0xb5fb5d2f,0x00000000}},	//   утно_, ht_, _trái,
  { {0x44445d30,0x398f0019,0x291a0331,0x00000000}},	//   kt_, _küsi_, _cepa_,
  { {0x6f0d0529,0x291a2b40,0x44445d31,0x00000000}},	//   _încâ, _depa_, jt_,
  { {0x06150b3f,0xceb90080,0x7bcd0072,0x00000000}},	//   ждаю, saře_, _ukau,
  { {0x764400a4,0xaa590541,0x44445d32,0x00000000}},	// [bf30] gtiy, _типу_, et_,
  { {0x63bb00c7,0x4444244c,0x63a95d33,0x00000000}},	//   _sjun, ft_, _smen,
  { {0x444418eb,0x7dcf00b9,0x764400a4,0x00000000}},	//   gt_, møst, atiy,
  { {0x44215d34,0x7dcf0093,0x69d5004d,0x00000000}},	//   rsh_, løst, llze,
  { {0x60c4005b,0x44441865,0x97420085,0x00000000}},	//   şiml, at_, зiць_,
  { {0x29030051,0x44440359,0x660d4fbc,0x00000000}},	//   ncja_, bt_, mpak,
  { {0x644300cd,0xaf991736,0x93e90021,0x00000000}},	//   ànid, итих_, _نفسك_,
  { {0x63bb00f3,0x63a90024,0xdfd10021,0x00000000}},	//   _ujun, _umen, بيع_,
  { {0x29030051,0x3f8600be,0xaec20062,0x00000000}},	//   kcja_, _doou_, мбъл,
  { {0x61fb00a4,0x660d07b7,0xb65c0041,0x00000000}},	//   _iuul, ipak, רדזש,
  { {0xb5fb017d,0x7dcf00b9,0x61fb3768,0x00000000}},	//   _gráv, døst, _huul,
  { {0x61fb0aba,0x64455d35,0x291a5d36,0x00000000}},	//   _kuul, ithi, _sepa_,
  { {0x61fb0019,0xb69b000c,0xdb1d0137,0x00000000}},	//   _juul, _sfân, dosä,
  { {0xdb0f00cd,0x44445d37,0x61fb0213,0x00000000}},	//   ancà, yt_, _muul,
  { {0x6fea0051,0x61fb0213,0x2d875d38,0x00000000}},	//   _ręcz, _luul, _ione_,
  { {0x444406a3,0x6b9d004d,0xddc2003b,0x00000000}},	//   vt_, chsg, _troţ,
  { {0x660d002c,0xddc200c2,0x291a0150,0x00000000}},	// [bf40] gpak, _hroš, _tepa_,
  { {0x7644005b,0x22420019,0xe61705ac,0x00000000}},	//   rtiy, _äkki_, юду_,
  { {0x44445d39,0x660d5d3a,0x64455d3b,0x00000000}},	//   ut_, apak, gthi,
  { {0x764400a4,0x44442beb,0x2d875d3c,0x00000000}},	//   ptiy, rt_, _lone_,
  { {0x6445077d,0xdb0f00be,0x6fea0022,0x00000000}},	//   athi, ficê, _tęcz,
  { {0xb5fb016b,0x0219000d,0x64a6000d,0x00000000}},	//   _práv, сіць_, _дага,
  { {0xcf9a0138,0x39584ee1,0x4034012c,0x00000000}},	//   ији_, iers_, чейс,
  { {0x39580037,0x644300cd,0x9f440003,0x00000000}},	//   hers_, ànie, ommé_,
  { {0xe3be005b,0x2d875d3d,0x29030051,0x00000000}},	//   ğıda_, _bone_, ycja_,
  { {0x2d980ad3,0xddc2007d,0x39582780,0x00000000}},	//   óre_, _broš, jers_,
  { {0x2d870034,0xe4fb00b5,0x22465d3e,0x00000000}},	//   _done_, יפיש, ltok_,
  { {0xddc2003d,0xbb940076,0xb5fb004a,0x00000000}},	//   _droš, дающ, _krát,
  { {0x395818d9,0x290c005b,0x2d875d3f,0x00000000}},	//   fers_, ıdan_, _fone_,
  { {0x2d870034,0x644500f6,0x60cd000c,0x00000000}},	//   _gone_, ythi, şame,
  { {0x6ca3005a,0xdb0f017d,0x7dcf069f,0x00000000}},	//   _оръж, ancá, røst,
  { {0x22460a9f,0x7dcf05a5,0x2d871db6,0x00000000}},	//   ktok_, søst, _zone_,
  { {0x2b59000c,0x67ce0078,0x6445002b,0x00000000}},	// [bf50] mesc_, dėję, wthi,
  { {0x39580034,0x660d0397,0xe46b0076,0x00000000}},	//   cers_, rpak, ишел_,
  { {0xdb065d40,0xe9df006d,0x61fb021e,0x00000000}},	//   liká, ctúa_, _suul,
  { {0x2b59000c,0x64455d41,0xb5fb5d42,0x00000000}},	//   nesc_, rthi, _brát,
  { {0x27e92c9c,0xb5fb006d,0x2b59003b,0x00000000}},	//   mman_, _crát, iesc_,
  { {0x27e95d43,0x45fa009a,0xb5fb5d44,0x00000000}},	//   lman_, _להשג, _drát,
  { {0x7dd401a8,0xa99c07e9,0x22460066,0x00000000}},	//   càsi, שבור, atok_,
  { {0x27e900bb,0x39585d45,0xb5fb0014,0x00000000}},	//   nman_, zers_, _frát,
  { {0x28d20161,0x39580cfc,0x2d875d46,0x00000000}},	//   _दुनि, yers_, _pone_,
  { {0x27e95d47,0x2d9e0025,0xdbd7021e,0x00000000}},	//   hman_, ghte_, hääl,
  { {0x2ef5026b,0xb5fb004a,0x27e92776,0x00000000}},	//   _езер, _krás, kman_,
  { {0xdb065d48,0x39582f7b,0x27e94108,0x00000000}},	//   fiká, wers_, jman_,
  { {0x9916000d,0x2d9e0139,0xdcb10013,0x00000000}},	//   зьбі, bhte_, iải_,
  { {0x2d870035,0x2fcd006f,0xddc25d49,0x00000000}},	//   _uone_, loeg_, _troš,
  { {0x7d7a0063,0x2b59003b,0x39582a96,0x00000000}},	//   _לנסו, besc_, rers_,
  { {0x2fcd0162,0xab9a007e,0x2b59003b,0x00000000}},	//   noeg_, _دختر_, cesc_,
  { {0x39582aa2,0x41cb0042,0xbb3b009a,0x00000000}},	// [bf60] pers_, िवास, _העפי,
  { {0x27e90b38,0x78c7013d,0xa3a90082,0x00000000}},	//   aman_, érvé, गोस_,
  { {0xdb0f00cd,0x27e95d4a,0x67ce0078,0x00000000}},	//   ficè, bman_, tėję,
  { {0xb5fb0016,0x22460224,0x7dd400cd,0x00000000}},	//   _prát, ttok_, ràsi,
  { {0xb5fb37c9,0x67ce0078,0x3165004d,0x00000000}},	//   _drás, rėję, _balz_,
  { {0x4736006a,0x2246000f,0x644300cd,0x00000000}},	//   _برگز, rtok_, ànic,
  { {0x987a0047,0x34a71527,0x55770047,0x00000000}},	//   מאַט, _евро_, _צעלן_,
  { {0x69ce00bd,0xb5fb0139,0x2246013d,0x00000000}},	//   hobe, _trát, ptok_,
  { {0xed580024,0x2b59000c,0x2377004c,0x00000000}},	//   teľ_, vesc_, šejí_,
  { {0x27e95d4b,0x443a006c,0x4c940081,0x00000000}},	//   zman_, oup_, диос,
  { {0x2b59003b,0x64410072,0x69ce5d4c,0x00000000}},	//   tesc_, _älit, dobe,
  { {0xdb065d4d,0xbe4a007e,0x2d9e00ca,0x00000000}},	//   tiká, _هشتم_, shte_,
  { {0x2b59000c,0xdef4000d,0xdbd70072,0x00000000}},	//   resc_, _ўплы, vääl,
  { {0x3eb90024,0x2b59000c,0x443a5d4e,0x00000000}},	//   úste_, sesc_, kup_,
  { {0xfce30001,0xa3be0053,0x6d5a5d4f,0x00000000}},	//   _пољо, ीका_, meta,
  { {0x443a0397,0x27e95d50,0xdb1d0025,0x00000000}},	//   dup_, uman_, hosú,
  { {0x9f4c0024,0xd6db0b62,0x6d5a0019,0x00000000}},	// [bf70] _budú_, ств_, oeta,
  { {0x7bcf000c,0xf8ae007e,0x6d5a486d,0x00000000}},	//   locu, اکی_, neta,
  { {0x44270814,0x443a0397,0xdbd700fe,0x00000000}},	//   én_, gup_, pääl,
  { {0x6d5a0763,0x245e0080,0x3165004d,0x00000000}},	//   heta, _dům_, _salz_,
  { {0x2fcd021f,0x4174006a,0xa2940086,0x00000000}},	//   voeg_, کانس, наці,
  { {0x6d5a49f6,0x7c3a52a8,0x2d8a1013,0x00000000}},	//   jeta, kutr, öbel_,
  { {0x6d5a5d51,0x20540121,0x443a5d52,0x00000000}},	//   deta, етыр, cup_,
  { {0x6d5a004b,0x389c009f,0x69ce201f,0x00000000}},	//   eeta, מיונ, zobe,
  { {0x7e62000f,0x7bcf5d53,0x2fcd5d54,0x00000000}},	//   _csop, docu, roeg_,
  { {0xdc12005b,0x6d5a5d55,0xd658009a,0x00000000}},	//   _ağın, geta, ליחת_,
  { {0x656700c3,0x1bea0062,0x2fcd0a26,0x00000000}},	//   _majh, ждни_, poeg_,
  { {0x6d8d0139,0xeb970121,0x6d5a01cf,0x00000000}},	//   _cúar, дию_, aeta,
  { {0x65a00199,0x6d5a1ebe,0x69ce358d,0x00000000}},	//   _höhe, beta, tobe,
  { {0x9f5e09ff,0x64555d56,0x6d5a5d57,0x00000000}},	//   _että_, _opzi, ceta,
  { {0x69ce1017,0x65a0013d,0xe9df4556,0x00000000}},	//   robe, _jöhe, ptún_,
  { {0xe61a5d58,0x99820078,0xdb060058,0x00000000}},	//   жда_, tukų_, dikç,
  { {0x60c401f7,0xdcf80080,0x6455001c,0x00000000}},	// [bf80] ğimi, _nově, _apzi,
  { {0x60c4005b,0x443a5d59,0xe9df013d,0x00000000}},	//   şimi, tup_, ntúl_,
  { {0xba76005d,0x6d430f61,0x9346082d,0x00000000}},	//   _راکت, _mcna, днее,
  { {0x644300cd,0x645e001f,0x99820006,0x00000000}},	//   ània, rwpi, pukų_,
  { {0x7c3a00bd,0x71a6000d,0xd2500067,0x00000000}},	//   zutr, мадз, انت_,
  { {0x7dd400cd,0x67240072,0xdb060656,0x00000000}},	//   nàst, laij, likä,
  { {0xa3d90053,0x6d5a5d5a,0xc9530063,0x00000000}},	//   _ठीक_, veta, דמו_,
  { {0x6d5a0150,0xdb065d5b,0xdb1d06ea,0x00000000}},	//   weta, nikä, llsö,
  { {0x3df400d7,0x442a0089,0x6d5a0c6b,0x00000000}},	//   нзис, _hvb_, teta,
  { {0x60cd005b,0xaad20053,0x6d5a0072,0x00000000}},	//   şama, _सड़क, ueta,
  { {0x6d5a1de0,0xc0490013,0xfe6f007e,0x00000000}},	//   reta, _mướn_, هدی_,
  { {0x69c003b2,0x63a25d5c,0x7c3a5d5d,0x00000000}},	//   émen, nhon, rutr,
  { {0x7c3a00c7,0x6d5a5d5e,0x4e960021,0x00000000}},	//   sutr, peta, _تشار,
  { {0x6d430027,0x7c3a0b21,0x7bcf07a8,0x00000000}},	//   _gcna, putr, socu,
  { {0x9848005a,0x478b0be6,0x4bdb0021,0x00000000}},	//   мята_, осам_, _وبعد_,
  { {0xab5b005b,0xdb1d0137,0xb6f5005e,0x00000000}},	//   ylüy, elsö, езбј,
  { {0x1515000d,0x7c280989,0xd64b0054,0x00000000}},	// [bf90] едзя, lsdr, дiсл,
  { {0x99540024,0xc4db0001,0x63a20229,0x00000000}},	//   _päť_, ође_, ehon,
  { {0x67240035,0x7bc80003,0xddc20051,0x00000000}},	//   baij, éjug, _spoś,
  { {0xa3a90053,0xdcf80080,0xa5f91d6d,0x00000000}},	//   गों_, _sově, _нему_,
  { {0xdcf80080,0x7d0a2e38,0x91d50085,0x00000000}},	//   _pově, _offs, нцкі,
  { {0xe0450e6b,0x7c281034,0x6b8d004b,0x00000000}},	//   енки, ksdr, _loag,
  { {0x0319005e,0x741501f3,0x4f954c19,0x00000000}},	//   _новј_, _سوءا, ерпу,
  { {0x0e6500e1,0xdb1d05b9,0x63a25d5f,0x00000000}},	//   екин, cosø, chon,
  { {0xa3cc0053,0xddc20022,0x291e0046,0x00000000}},	//   रकर_, _upoś, ðtak_,
  { {0x3f820026,0xac852b4f,0x4c8513d3,0x00000000}},	//   ökur_, егол, елов,
  { {0xe5725d60,0x3f150055,0x8014000d,0x00000000}},	//   אַר_, _здес, _афіц,
  { {0xfe71006a,0x4c820086,0x8f680021,0x00000000}},	//   _مدت_, улюв, _يملك_,
  { {0x99840080,0xdd95000d,0x7dd401a8,0x00000000}},	//   émů_, _пады, tàst,
  { {0x6e2900ac,0xc21200ff,0xb5fb004c,0x00000000}},	//   mseb, רהם_, _psán,
  { {0x6e290137,0xdb060072,0x98a60062,0x00000000}},	//   lseb, tikä, хиве,
  { {0x6f0900e3,0x6e29082a,0x2a720051,0x00000000}},	//   ncec, oseb, _tryb_,
  { {0x290501f7,0x6e295d61,0x97c30376,0x00000000}},	// [bfa0] ılar_, nseb, уйте,
  { {0xdb060659,0x05850086,0x7ae45d62,0x00000000}},	//   sikä, куєм, _izit,
  { {0x98b800eb,0xdb1d0093,0x63a24825,0x00000000}},	//   merį_, tosø, thon,
  { {0x2486017f,0x8c1a0063,0x68e1121c,0x00000000}},	//   ćom_, פוני, ülde,
  { {0xe2970001,0x6e2900b9,0xc6d60021,0x00000000}},	//   нац_, jseb, _ستحت,
  { {0x20660001,0x6e2900c2,0x63a25d63,0x00000000}},	//   еђив, dseb, shon,
  { {0xdce30198,0xb8820080,0x84e302a1,0x00000000}},	//   _banč, _říjn, _борж,
  { {0xdd2500eb,0x69dc00bd,0xa8570063,0x00000000}},	//   _rūši, hlre, תיקה_,
  { {0x63a00019,0x7ae40035,0x67c50006,0x00000000}},	//   _ilmn, _nzit, nėja,
  { {0x6d410137,0x3994004b,0x7c285d64,0x00000000}},	//   ggla, _käsu_, tsdr,
  { {0xdcba005a,0x6e295080,0x80a60021,0x00000000}},	//   ящи_, aseb, _ثمان,
  { {0x67c50006,0x6d415d65,0x291804d0,0x00000000}},	//   kėja, agla, ebra_,
  { {0xdfcf04de,0x61fa005b,0x7c283566,0x00000000}},	//   _اين_, _kitl, ssdr,
  { {0x67c50006,0x17fb0021,0xdb0f5d66,0x00000000}},	//   dėja, كررة_, micí,
  { {0xdb0f02dd,0x7ae4003b,0x9d430002,0x00000000}},	//   licí, _ezit, _сејд,
  { {0x61fa0627,0x657c001f,0xca49007e,0x00000000}},	//   _litl, _anrh, _قلعه_,
  { {0x2918000f,0xdb0f5d67,0xfc45004a,0x00000000}},	// [bfb0] bbra_, nicí, žíte_,
  { {0x95d80121,0xa3a90042,0x28d20082,0x00000000}},	//   едут_, गोई_, _दुवि,
  { {0xf99f00cd,0xe3be005b,0xc9520063,0x00000000}},	//   spès_, ğına_, _דמי_,
  { {0x04c80032,0xe3be01f7,0x6e290185,0x00000000}},	//   روني_, şına_, yseb,
  { {0x6d412155,0x61fa5d68,0x216927c8,0x00000000}},	//   ygla, _bitl, дили_,
  { {0xd8380198,0x23690add,0x6664005a,0x00000000}},	//   šče_, žaj_, _съюз,
  { {0xa066005a,0x61fa10ed,0xdce35d69,0x00000000}},	//   ваща_, _ditl, _panč,
  { {0x39940137,0x8cca0053,0x9999004c,0x00000000}},	//   _häst_, _सँजो, kusů_,
  { {0x764d00bb,0xbea50002,0x6d4100ca,0x00000000}},	//   ntay, тапк, tgla,
  { {0x6e2908f0,0xfe420086,0xf42a0072,0x00000000}},	//   rseb, шньо, _äää_,
  { {0x6e2910ec,0xdb0f003b,0xdce3004c,0x00000000}},	//   sseb, dicâ, _tanč,
  { {0x399400c7,0x764d005b,0x7b960054,0x00000000}},	//   _läst_, ktay, трої,
  { {0xdb0f000c,0x2127008b,0x98b80078,0x00000000}},	//   ficâ, oanh_, terį_,
  { {0x67c50006,0x7bdd15b5,0x39940137,0x00000000}},	//   vėja, alsu, _näst_,
  { {0x3f8f0004,0x764d0058,0xdca52046,0x00000000}},	//   _kogu_, etay, _шаки,
  { {0x2127008b,0x18670001,0x67c50078,0x00000000}},	//   hanh_, њати_, tėja,
  { {0x3f8f0117,0x399400c7,0x764d002c,0x00000000}},	// [bfc0] _mogu_, _bäst_, gtay,
  { {0x67c50006,0x3f8f5d6a,0xa80608b0,0x00000000}},	//   rėja, _logu_, _изол,
  { {0x03260086,0x69c100c2,0x764d0c55,0x00000000}},	//   вден, člet, atay,
  { {0x61ca0053,0x3f8f007d,0x67c50078,0x00000000}},	//   ाक्ष, _nogu_, pėja,
  { {0x15ba000d,0x39940137,0x60cd0058,0x00000000}},	//   _жывы_, _fäst_, şaml,
  { {0x657c0185,0x7f9504a6,0xe2970001,0x00000000}},	//   _unrh, _máqu, ђај_,
  { {0x61fa0626,0x66160078,0xe423007e,0x00000000}},	//   _vitl, lpyk, _نکني,
  { {0x61fa00e8,0xe0cf0021,0x25e60042,0x00000000}},	//   _witl, غزو_, _जीती_,
  { {0x5e430021,0xc7b30a7a,0x61fa5d6b,0x00000000}},	//   لَيْ, יבה_, _titl,
  { {0x61fa0162,0x2ca90080,0x443a5d6c,0x00000000}},	//   _uitl, _řada_, orp_,
  { {0x853b0063,0xbb950054,0xbd670121,0x00000000}},	//   וגיי, ганщ, трые_,
  { {0x7e67001c,0xc4d3009a,0x00000000,0x00000000}},	//   ājpr, יגת_,   ,
  { {0xee94007e,0x4e1b0053,0x41b60042,0x00000000}},	//   _حداک, पीआई_, _अगास,
  { {0xdd930088,0xa9c40121,0x5e570063,0x00000000}},	//   _вашы, асск, _סיוע_,
  { {0xdb0f0f84,0x60e6004c,0x59f80121,0x00000000}},	//   ricâ, _úsmě, теря_,
  { {0x394d0080,0xe894000d,0x644301a8,0x00000000}},	//   řes_, шась, ànim,
  { {0x443a006f,0x8bb40049,0xeb1f0042,0x00000000}},	// [bfd0] erp_, _خصوص, परीत_,
  { {0x9f9a004b,0x7c3a5d6d,0x6b9d030c,0x00000000}},	//   _hääl_, ortr, lksg,
  { {0xf7eb0032,0xdce3003d,0x764d005b,0x00000000}},	//   _يرجى_, _kanā, stay,
  { {0x9f4c006d,0x67c50006,0xdb0f00cd,0x00000000}},	//   _mudó_, mėjo, nicà,
  { {0x67c50006,0x6b9d006f,0xdb1d5d6e,0x00000000}},	//   lėjo, iksg, losó,
  { {0x644a0268,0xa5bb0051,0xe1f80054,0x00000000}},	//   àfic, _dwóc, вгі_,
  { {0xdb1d0019,0x3f8f001c,0x2127008b,0x00000000}},	//   fosü, _pogu_, ranh_,
  { {0x6d5c0019,0xf062005a,0x439401d5,0x00000000}},	//   õran, скъп, _касс,
  { {0x69d55d6f,0x7c3a5d70,0x63b900a3,0x00000000}},	//   koze, ertr, miwn,
  { {0x67c50078,0x65a0004d,0x6b9d00ca,0x00000000}},	//   kėjo, _löhn, eksg,
  { {0x7ddd00cd,0x6299001f,0x75eb005b,0x00000000}},	//   nèsi, lywo, müzd,
  { {0x29cd0024,0x67c50006,0xe4560041,0x00000000}},	//   hľad_, dėjo, נירט_,
  { {0xff04005a,0x2005002c,0x539a00b5,0x00000000}},	//   _тяхн, _huli_, גירו,
  { {0x186a011c,0x75eb005b,0x6f1b5d71,0x00000000}},	//   наги_, nüzd, lbuc,
  { {0x58950636,0x20055d72,0xcc350085,0x00000000}},	//   ашту, _juli_, _схлы,
  { {0x200500bb,0x6f1b004d,0x68250121,0x00000000}},	//   _muli_, nbuc, рьёз,
  { {0xe57a0f92,0x69d55d73,0x85ea0c59,0x00000000}},	// [bfe0] нза_, boze, едав_,
  { {0x67c50006,0x2fdf00bd,0x6f1b004d,0x00000000}},	//   bėjo, hlug_, hbuc,
  { {0x26cb00e3,0x62995d74,0xe3be005b,0x00000000}},	//   _exco_, eywo, şıma_,
  { {0x14170032,0xa22a00a0,0xdb1d00cd,0x00000000}},	//   اينة_, ежда_, losò,
  { {0x7584006a,0xdb0f006d,0x27e03877,0x00000000}},	//   _پیام, nicá, mlin_,
  { {0x20050089,0x0f1c0053,0x27e05534,0x00000000}},	//   _buli_, नर्स_, llin_,
  { {0x6e3b0397,0xdd3a000c,0x66060ff2,0x00000000}},	//   erub, _lăţi, _hukk,
  { {0x63b90051,0x645c0290,0x5f94026b,0x00000000}},	//   ciwn, _ipri, риит,
  { {0x27e000fe,0xad66007e,0xdd900021,0x00000000}},	//   ilin_, هاده, قوة_,
  { {0xdb0f006d,0xa3b00053,0xaa7d0072,0x00000000}},	//   dicá, टोर_, _käöä_,
  { {0x660602ab,0xdce3001c,0x3cf80140,0x00000000}},	//   _lukk, _panā, ärv_,
  { {0x656e0025,0xdb0f0460,0x672600c2,0x00000000}},	//   _labh, ficá, _nekj,
  { {0x6b9d0026,0x244e0114,0x66060656,0x00000000}},	//   rksg, hým_, _nukk,
  { {0xf2d300b5,0x244e027d,0x99890051,0x00000000}},	//   מער_, kým_, _stał_,
  { {0x672607e6,0xddc200c3,0x62990051,0x00000000}},	//   _bekj, _krož, zywo,
  { {0x2d8c00c7,0x67c50006,0x2d9e05e9,0x00000000}},	//   ljde_, rėjo, lkte_,
  { {0xdb0f0019,0xab280141,0x2d8c004c,0x00000000}},	// [bff0] öjõu, _соња_, ojde_,
  { {0xd8380198,0x656e0027,0x660602ab,0x00000000}},	//   šča_, _cabh, _dukk,
  { {0xddc200c3,0x2d9e0179,0x629900a4,0x00000000}},	//   _orož, ikte_, wywo,
  { {0xae040161,0xb76718cc,0x656e0025,0x00000000}},	//   रदान_, _стой, _eabh,
  { {0x656e0025,0x2fdf00ac,0x6d581035,0x00000000}},	//   _fabh, vlug_, _obva,
  { {0x05870076,0x656e0025,0x50590062,0x00000000}},	//   _сумм, _gabh, вшия_,
  { {0xddc20124,0x34940e82,0xe588089e,0x00000000}},	//   _brož, _ларр, _עָשָ,
  { {0x2d9e0438,0xa2951c15,0x7e550002,0x00000000}},	//   ekte_, _кабі, атоц,
  { {0x6f1b5d75,0xcee90062,0xab5b013d,0x00000000}},	//   rbuc, ъдие_, tnün,
  { {0xdcf8003d,0x6e3b5d76,0x44230089,0x00000000}},	//   _novē, rrub, _kwj_,
  { {0xb17a0047,0x6e3b0504,0xab5b004d,0x00000000}},	//   _שטער, srub, rnün,
  { {0x765d002c,0x6e3b002c,0x2d9e1031,0x00000000}},	//   _opsy, prub, akte_,
  { {0x7ff4006a,0x6e22001f,0x67260026,0x00000000}},	//   _اسلا, _gwob, _rekj,
  { {0xdb0400e8,0x672600f3,0x2d9e0832,0x00000000}},	//   _klië, _sekj, ckte_,
  { {0x656e0025,0xd706026b,0xb5fb0240,0x00000000}},	//   _rabh, изви, _fráz,
  { {0xc7a30612,0x244e027d,0x656e0d12,0x00000000}},	//   оиск, vým_, _sabh,

  { {0xb69b000c,0xa50a0001,0x3ead006f,0x00000000}},	// [c000] _sfâr, веза_, nzet_,
  { {0x244e0240,0x27f2001f,0x645c04aa,0x00000000}},	//   tým_, smyn_, _ppri,
  { {0xf8ca016a,0x67260026,0x27e03bcc,0x00000000}},	//   _रशिय, _tekj, plin_,
  { {0xe29a0088,0xa3b00161,0x244e0114,0x00000000}},	//   кае_, टों_, rým_,
  { {0x656e0027,0x2d9e02ab,0x98a3001c,0x00000000}},	//   _tabh, ykte_, majā_,
  { {0x77640268,0xfe08001b,0x98a3001c,0x00000000}},	//   leix, _nữa_, lajā_,
  { {0xdb04006f,0x6e220051,0x3ead2928,0x00000000}},	//   _clië, _swob, ezet_,
  { {0x77640268,0x4fc6000a,0x98a3001c,0x00000000}},	//   neix, јска, najā_,
  { {0x61460138,0xfe080013,0x44445d77,0x00000000}},	//   _веза, _bữa_, lu_,
  { {0x44445d78,0xd6570063,0xb5fb011b,0x00000000}},	//   ou_, סיית_, _sráz,
  { {0xc57900b5,0x2d9e1b26,0x98a3001c,0x00000000}},	//   אָרט, rkte_, kajā_,
  { {0x2d9e183c,0xddc901b3,0x764400a4,0x00000000}},	//   skte_, rveš, kuiy,
  { {0x7e790185,0x77640268,0x44445d79,0x00000000}},	//   _grwp, deix, hu_,
  { {0x6b5c0146,0xeb9f00d1,0x1cba0021,0x00000000}},	//   _pågæ, skø_, _لاعب_,
  { {0xb5fb0025,0xada30095,0x44445d7a,0x00000000}},	//   _usái, _фајл, ju_,
  { {0x77640268,0x98a3001c,0xf7700021,0x00000000}},	//   geix, gajā_, واق_,
  { {0x44445d7b,0xe667018e,0x929d0022,0x00000000}},	// [c010] eu_, штво, _ogła,
  { {0x443100eb,0x44445d7c,0x6d485d7d,0x00000000}},	//   _pvz_, fu_, ngda,
  { {0x7ddd0268,0x44445d7e,0x98a3001c,0x00000000}},	//   mèst, gu_, bajā_,
  { {0x7ddd0268,0x69c700c3,0x98a3008f,0x00000000}},	//   lèst, lnje, cajā_,
  { {0x44445d7f,0xc244000d,0x4df60053,0x00000000}},	//   au_, жнік, ँगाई_,
  { {0x672d00fe,0xdca60021,0x3ead00c2,0x00000000}},	//   laaj, _فى_, vzet_,
  { {0x44445d80,0x3f9f0072,0x6565004b,0x00000000}},	//   cu_, tkuu_, mehh,
  { {0x64450455,0xfe080013,0xaf980121,0x00000000}},	//   muhi, _sữa_, итых_,
  { {0x69c700c3,0x64451668,0x3ead007d,0x00000000}},	//   knje, luhi, uzet_,
  { {0xcda9006a,0x3f9f00fe,0x3ead2928,0x00000000}},	//   اهده_, skuu_, rzet_,
  { {0x69c701a6,0x64453b40,0x672d0019,0x00000000}},	//   dnje, nuhi, kaaj,
  { {0x6d48002c,0x929d0051,0x672d021e,0x00000000}},	//   agda, _zgła, jaaj,
  { {0x98a3001c,0x44445d81,0xdb06004e,0x00000000}},	//   vajā_, zu_, mikü,
  { {0x64451383,0x69c7085a,0x44445d82,0x00000000}},	//   kuhi, gnje, yu_,
  { {0x77640994,0x68e90080,0x98a3001c,0x00000000}},	//   teix, ředn, tajā_,
  { {0x644500bb,0xd83800c2,0x07a60062,0x00000000}},	//   duhi, ščo_, щабн,
  { {0x77640994,0x98a3001c,0x69c7007d,0x00000000}},	// [c020] reix, rajā_, bnje,
  { {0x4444457a,0x1288007e,0xdb06004b,0x00000000}},	//   tu_, یمای_, hikü,
  { {0x644500bb,0x44440d74,0x6b845d83,0x00000000}},	//   guhi, uu_, _knig,
  { {0x7e690035,0xab5b013d,0x73490054,0x00000000}},	//   kwep, enüj, ичів_,
  { {0x44445d84,0xdb065d85,0x91e60e6b,0x00000000}},	//   su_, likó, боде,
  { {0xa97a00b5,0x25b800c3,0xe9df0025,0x00000000}},	//   ראַכ, _umrl_, ltúr_,
  { {0xdb060045,0x443e001b,0x44445d86,0x00000000}},	//   nikó, _ít_, qu_,
  { {0x69c700c3,0x987b009f,0x1e140062,0x00000000}},	//   znje, ראקט, омия,
  { {0x628600c3,0xf7730063,0x63a25d87,0x00000000}},	//   _škof, לקה_, mkon,
  { {0x63a2011d,0xd00a005e,0xa281005d,0x00000000}},	//   lkon, _беже_, _آیوو,
  { {0xe9df0024,0xb7fa0053,0xcb040053,0x00000000}},	//   ktúr_, ्दाम_, रखंड_,
  { {0xd90f007e,0x63a20518,0x29110022,0x00000000}},	//   کید_, nkon, wcza_,
  { {0xddc2003d,0x672d0072,0xdb1d00a5,0x00000000}},	//   _esoš, vaaj, kosö,
  { {0x6b843073,0x67c50006,0x644500a4,0x00000000}},	//   _enig, mėji, yuhi,
  { {0x67c500eb,0x69c702e2,0x5884014c,0x00000000}},	//   lėji, rnje, пыта,
  { {0x69c708ea,0x8aa7000d,0x68e90080,0x00000000}},	//   snje, _грод, ředo,
  { {0xdb0d005b,0x67c50006,0x672d00fe,0x00000000}},	// [c030] _amaç, nėji, raaj,
  { {0x672d0ff2,0x64454548,0xec090013,0x00000000}},	//   saaj, tuhi, _mến_,
  { {0x93190021,0xa988009a,0x63a20244,0x00000000}},	//   لقاء_, _הָרִ, fkon,
  { {0x67c500eb,0x64455d88,0x63a25d89,0x00000000}},	//   kėji, ruhi, gkon,
  { {0x64454fcf,0xe1f1007e,0x7a7c0047,0x00000000}},	//   suhi, وست_, ָרוס,
  { {0x67c50006,0x3f750013,0x8015184b,0x00000000}},	//   dėji, _ều_, офиц,
  { {0x299c0063,0x63a25d8a,0xa99c009a,0x00000000}},	//   רסומ, bkon, רבור,
  { {0x7bdf00ac,0xee390793,0xec09008b,0x00000000}},	//   _nkqu, ани_, _bến_,
  { {0x22ab0062,0x68e100ea,0x8e090699,0x00000000}},	//   _съвп_, üldj, јнов_,
  { {0x7bcd0072,0x7bdf004d,0x4d650ace,0x00000000}},	//   _ajau, _akqu, цков,
  { {0xa0c40021,0xdb1d0014,0x30a74250,0x00000000}},	//   _فيكو, insæ, _урав,
  { {0x67c500eb,0x06fb0161,0x9ed9005a,0x00000000}},	//   bėji, ्शाव_, _кмет_,
  { {0x7aed0051,0x7fe80054,0x68e9004c,0x00000000}},	//   _czat, _уєфа_, ředl,
  { {0x3ea20031,0x63a95d8b,0x3167004d,0x00000000}},	//   økte_, _llen, nenz_,
  { {0x929d0051,0x7bcf0003,0x63a95d8c,0x00000000}},	//   _ogło, ébuc, _olen,
  { {0x6b84001f,0x9f46008b,0xec090013,0x00000000}},	//   _unig, _khoá_, _yến_,
  { {0xe6170432,0x63a2081d,0x66e35d8d,0x00000000}},	// [c040] жду_, vkon, дота,
  { {0xdb1d1686,0x63bb5d8e,0x63a907db,0x00000000}},	//   gnsæ, _amun, _alen,
  { {0x3167004d,0x63a9050b,0x05770021,0x00000000}},	//   denz_, _blen, تملة_,
  { {0x9f4c017d,0x69dc03e1,0x475a0330,0x00000000}},	//   _judô_, lore, _троя_,
  { {0xb5fb00ea,0x7f9c00cd,0x69dc36a4,0x00000000}},	//   _csás, _xéqu, oore,
  { {0x63a95d8f,0x3167087d,0x69dc39b2,0x00000000}},	//   _elen, genz_, nore,
  { {0xe57100b5,0xbfaa5d90,0x1139000d,0x00000000}},	//   _אַן_, итие_, сячы_,
  { {0xe29a0088,0xdfd00032,0x69dc5d91,0x00000000}},	//   _каб_, عية_, hore,
  { {0x69dc5d92,0x765600fe,0x98a30022,0x00000000}},	//   kore, ntyy, mają_,
  { {0x929d0045,0x5d54000a,0x67c50006,0x00000000}},	//   _zgło, чкот, rėji,
  { {0xdb1d03b2,0x63bb0185,0x69dc0747,0x00000000}},	//   lisé, _ymun, dore,
  { {0x67c50006,0x9a870074,0x98a30022,0x00000000}},	//   pėji, оугл, nają_,
  { {0xdb1d0164,0x3f860066,0xdce30078,0x00000000}},	//   nisé, _inou_, _manę,
  { {0x7e6200a4,0xdb04013d,0x68e9004c,0x00000000}},	//   _ipop, _amió, ředm,
  { {0x98a30051,0x200c192f,0xdd0f0066,0x00000000}},	//   kają_, _judi_, _užšo,
  { {0x316700bd,0x2ca300b9,0xd7740021,0x00000000}},	//   zenz_, øjde_, واقع,
  { {0x1ab422c1,0x98a30051,0x69dc5d93,0x00000000}},	// [c050] _объя, dają_, bore,
  { {0x356b000a,0x69dc13e6,0x98a1003b,0x00000000}},	//   јран_, core, _cehă_,
  { {0x200c2483,0xfe79004c,0x63a936cf,0x00000000}},	//   _nudi_, zvů_, _plen,
  { {0x98a30051,0x7bdd5d94,0xe51b0042,0x00000000}},	//   gają_, nosu, _प्रि_,
  { {0xa2940086,0xdb7c0047,0xb224000d,0x00000000}},	//   маці, ינאכ, дміл,
  { {0x200c3c71,0x6d5a00ca,0x40950c03,0x00000000}},	//   _budi_, jfta, зрит,
  { {0x316700bd,0x98ba005b,0x68e1013d,0x00000000}},	//   renz_, _yapı_, üldh,
  { {0x69dc10a8,0x63bb2f40,0x98a30022,0x00000000}},	//   zore, _umun, cają_,
  { {0x69dc02dd,0xed590062,0x7bdd00ea,0x00000000}},	//   yore, боп_, dosu,
  { {0xc05b148d,0x67c50078,0x661b0058,0x00000000}},	//   _від_, mėju, _çuku,
  { {0x65750089,0x67c50006,0x7ae40072,0x00000000}},	//   _mazh, lėju, _syit,
  { {0x6d5a5d95,0x7bdd0580,0x7875004c,0x00000000}},	//   afta, gosu, zývá,
  { {0xde58000d,0x7c95007e,0x69dc5d96,0x00000000}},	//   _маці_, زشگا, tore,
  { {0xceb20047,0x69dc00fe,0x200c0150,0x00000000}},	//   _איד_, uore, _yudi_,
  { {0x7e7b007a,0x69dc5d97,0x7bdd0150,0x00000000}},	//   lvup, rore, bosu,
  { {0x765600fe,0x4c3a0063,0x69dc5d98,0x00000000}},	//   ttyy, _התקב, sore,
  { {0x69dc5d99,0x32050168,0x00000000,0x00000000}},	// [c060] pore, _oily_,   ,
  { {0xdb1d5d9a,0x7abb0063,0x67c50006,0x00000000}},	//   visé, _לצפו, dėju,
  { {0x999b0063,0x299b0063,0x765600fe,0x00000000}},	//   _הביט, _הסימ, styy,
  { {0x200c0009,0xb6a3001b,0x320d0331,0x00000000}},	//   _rudi_, _khẩ, _buey_,
  { {0x52130086,0x98a30051,0x6d5a0137,0x00000000}},	//   едіт, rają_, yfta,
  { {0xdb1d236b,0x98a323a8,0x672400ca,0x00000000}},	//   risé, sają_, lbij,
  { {0x6724007d,0x7e625d9b,0xf957009a,0x00000000}},	//   obij, _spop, פסקת_,
  { {0x44440dde,0x68e1004b,0x2d875d9c,0x00000000}},	//   mr_, üldi, _anne_,
  { {0x442a001f,0x7bdd007d,0x3243019c,0x00000000}},	//   _hwb_, vosu, _петг,
  { {0x200c0fbf,0x6443003d,0x7e760078,0x00000000}},	//   _tudi_, šnie, _šyps,
  { {0x7bdd5d9d,0x3a295216,0x76440075,0x00000000}},	//   tosu, _swap_, hriy,
  { {0x68e90080,0x4444057a,0x2d875d9e,0x00000000}},	//   ředk, ir_, _enne_,
  { {0x444407c7,0x753c0045,0x76440150,0x00000000}},	//   hr_, _odrz, jriy,
  { {0x444430a7,0x76440cc6,0x67245d9f,0x00000000}},	//   kr_, driy, ebij,
  { {0x4444310b,0x657500c2,0x7bdd5da0,0x00000000}},	//   jr_, _razh, posu,
  { {0x62805da1,0x44445da2,0x6724008f,0x00000000}},	//   _ormo, dr_, gbij,
  { {0x442a0d1e,0x4438066d,0x44445da3,0x00000000}},	// [c070] _awb_, _avr_, er_,
  { {0xb606001c,0x67c50006,0x4444002b,0x00000000}},	//   jošā, vėju, fr_,
  { {0x44440731,0xf9920063,0x628007b9,0x00000000}},	//   gr_, _סרט_, _armo,
  { {0x644300cd,0x32050066,0x43740002,0x00000000}},	//   àniq, _sily_, еушт,
  { {0xdce1001c,0xd25b0454,0x27e95da4,0x00000000}},	//   ielā, сце_, mlan_,
  { {0xfa78014e,0x27e95da5,0x22a3001c,0x00000000}},	//   פעות_, llan_, _rīkā_,
  { {0x67c50078,0x62805da6,0xa4d40054,0x00000000}},	//   sėju, _ermo, _зорі,
  { {0x27e95da7,0xdce90066,0x44215da8,0x00000000}},	//   nlan_, ínča, mph_,
  { {0x66070122,0xc2c40021,0x44215da9,0x00000000}},	//   _kijk, _كيفي, lph_,
  { {0xd83800c3,0xfaff00ac,0x64452271,0x00000000}},	//   šči_, reël_, orhi,
  { {0x27e94172,0x673d007d,0x660f06f9,0x00000000}},	//   klan_, _odsj, _luck,
  { {0x66070122,0xb6a3001b,0x547a0063,0x00000000}},	//   _lijk, _phẩ, קטרו,
  { {0xeb972ab5,0x8db50086,0x660f00a5,0x00000000}},	//   фия_, _оскі, _nuck,
  { {0xdd94000d,0x2ca90080,0x27e95daa,0x00000000}},	//   _пачы, _řadu_, elan_,
  { {0x6724006f,0x661d5dab,0x37e60054,0x00000000}},	//   tbij, _atsk, довг,
  { {0x660f1b85,0x2fcd5dac,0xb6a30013,0x00000000}},	//   _buck, nneg_, _thẩ,
  { {0x44440185,0x6607006f,0x67245dad,0x00000000}},	// [c080] wr_, _bijk, rbij,
  { {0x272c00aa,0x27e906a7,0x444403a4,0x00000000}},	//   ến_, alan_, tr_,
  { {0x44445dae,0x66071c79,0x27e95daf,0x00000000}},	//   ur_, _dijk, blan_,
  { {0x44445db0,0x29180089,0x23270699,0x00000000}},	//   rr_, lcra_, доци_,
  { {0xb606001c,0xb0c30053,0x27e00f38,0x00000000}},	//   tošā, _वेबग, moin_,
  { {0x644302dd,0x69ce10bc,0x27e000fe,0x00000000}},	//   ánic, nnbe, loin_,
  { {0x2167005e,0x69ce4f9d,0xb606008f,0x00000000}},	//   фији_, inbe, rošā,
  { {0x6607006f,0x69ce004d,0x27e00072,0x00000000}},	//   _zijk, hnbe, noin_,
  { {0x8d6a018e,0x23890080,0xbd6a25a6,0x00000000}},	//   ојна_, šují_, орне_,
  { {0x27e900e3,0x69ce0122,0xf1aa007e,0x00000000}},	//   zlan_, jnbe, _باره_,
  { {0x27e00072,0xdb040014,0x27e95db1,0x00000000}},	//   koin_, _smið, ylan_,
  { {0xf0b70047,0x27e05db2,0x61ea2755,0x00000000}},	//   _קלאר_, join_, llfl,
  { {0x27e90137,0x6d5c004b,0xdce1008f,0x00000000}},	//   vlan_, õras, relā,
  { {0xddc90080,0x69ce000e,0x59640062,0x00000000}},	//   kteř, gnbe, къса,
  { {0x66070122,0x27e900ea,0x3326405c,0x00000000}},	//   _rijk, tlan_, kbox_,
  { {0x27e9014f,0x69ce3775,0xba55005e,0x00000000}},	//   ulan_, anbe, _звиј,
  { {0x332601b0,0x3ea40e6c,0x27e95db3,0x00000000}},	// [c090] dbox_, nymt_, rlan_,
  { {0x2d9c368c,0x201e00fe,0x27e00025,0x00000000}},	//   _jove_, _otti_, aoin_,
  { {0x2d9c0034,0x78a10137,0x22460066,0x00000000}},	//   _move_, älvd, erok_,
  { {0x6607006f,0x2d9c212e,0x78a801f2,0x00000000}},	//   _wijk, _love_, ødve,
  { {0x201e051e,0x661d0a2e,0xdb060659,0x00000000}},	//   _atti_, _utsk, sikö,
  { {0x018b0076,0x2d9c5db4,0x00000000,0x00000000}},	//   ющей_, _nove_,   ,
  { {0xc0e20d34,0x2fcd0150,0x64740121,0x00000000}},	//   лошк, tneg_, _игру,
  { {0x68150051,0x98aa00dd,0xd00e0044,0x00000000}},	//   _lądo, labă_, حلي_,
  { {0x201e005b,0xa0220ff2,0x63a40072,0x00000000}},	//   _etti_, ööri, öine,
  { {0x2fcd0185,0x7bcf5db5,0x2d9c1098,0x00000000}},	//   sneg_, encu, _cove_,
  { {0x2d9c055b,0xdb1d0025,0x81760047,0x00000000}},	//   _dove_, aisí, _רגעס_,
  { {0xdb04017d,0x7f840021,0xc4d20041,0x00000000}},	//   _aliá, _للمن, רגט_,
  { {0x27e000fe,0xab5b0058,0x00000000,0x00000000}},	//   voin_, enüs,   ,
  { {0xe9df0026,0x20180003,0xed560054,0x00000000}},	//   trúa_, _éric_, _зош_,
  { {0xddc900b2,0x27e00072,0x69ce5db6,0x00000000}},	//   ovež, toin_, rnbe,
  { {0x2d9c017f,0xdb041bff,0xd706005e,0x00000000}},	//   _zove_, _eliá, езби,
  { {0x09e60635,0x464a0076,0x764d5db7,0x00000000}},	// [c0a0] _поин, язан_, guay,
  { {0x27e00164,0x7bc65db8,0xab5b004b,0x00000000}},	//   soin_, liku, hiül,
  { {0x75d30021,0x68e1013d,0x5b7a009a,0x00000000}},	//   ديلا, üldt, ּרְא,
  { {0x7bc65db9,0x22465dba,0x78a100a5,0x00000000}},	//   niku, trok_, älve,
  { {0x41e6126b,0xdb1d017d,0x46a3000d,0x00000000}},	//   ніка, lisã, _баяв,
  { {0xd83800c3,0xdb1d0827,0x7bc65dbb,0x00000000}},	//   šču_, visí, hiku,
  { {0x7bc65dbc,0x68e9004c,0x232a25d9,0x00000000}},	//   kiku, ředv, _нови_,
  { {0xab5b004d,0xdb1d01d1,0xd00701ce,0x00000000}},	//   hnür, tisí, неје_,
  { {0x2d9c00c3,0x7bc65dbd,0x9df80121,0x00000000}},	//   _pove_, diku, мнит_,
  { {0x2ca50146,0x50b6005e,0x7bc6008f,0x00000000}},	//   fyld_, _псеу, eiku,
  { {0x201e0290,0x7bc65dbe,0x4f260f59,0x00000000}},	//   _utti_, fiku, _здеб,
  { {0x7bcf028d,0x7bc62fb3,0x68150051,0x00000000}},	//   uncu, giku, _sądo,
  { {0x69da0080,0xada6000d,0xb5fb0014,0x00000000}},	//   čten, _падл, _spám,
  { {0x5e770063,0x2d9c01f4,0x7bc65dbf,0x00000000}},	//   _נתון_, _uove_, aiku,
  { {0xbd170063,0x7bc65dc0,0x28db0042,0x00000000}},	//   _אחוז_, biku, _मुखि,
  { {0x7c3a5dc1,0x17f80021,0x05770043,0x00000000}},	//   mstr, فرقة_, کارد,
  { {0xe6130021,0x6b8d1167,0x78a10137,0x00000000}},	// [c0b0] اشر_, _inag, älvb,
  { {0x7c3a5dc2,0x68e1004b,0xe61f002b,0x00000000}},	//   ostr, ülds, _prôb_,
  { {0x69c70117,0xdb1d0016,0x5455047e,0x00000000}},	//   mije, cisã, твет,
  { {0x69c75dc3,0x7c3a5dc4,0x8c1b009a,0x00000000}},	//   lije, istr, פודי,
  { {0xfe08001b,0xdb0f00f8,0x7c3a004d,0x00000000}},	//   _hữu_, licó, hstr,
  { {0x69c7158e,0x7bc61037,0xb604000d,0x00000000}},	//   nije, ziku, _бяск,
  { {0x7c3a5dc5,0xab5b004b,0x6b8d5dc6,0x00000000}},	//   jstr, tiül, _onag,
  { {0xa5bb00ea,0xf1a40086,0x7c3a5aac,0x00000000}},	//   _utób, _ґрун, dstr,
  { {0x7bc60705,0x3eab0080,0xab5b004b,0x00000000}},	//   viku, áct_, riül,
  { {0xb5fb0024,0x69c7007d,0x0d825dc7,0x00000000}},	//   _spáj, jije, альн,
  { {0x69c7074f,0x403501d5,0x7bc65dc8,0x00000000}},	//   dije, _реес, tiku,
  { {0xdb1d0016,0x6b8d0139,0x7bc60078,0x00000000}},	//   visã, _cnag, uiku,
  { {0x7c3a0469,0x7bc60214,0x733a0047,0x00000000}},	//   astr, riku, וערס,
  { {0x7c3a034d,0x0ea80086,0xdb0400cd,0x00000000}},	//   bstr, _якій_, _lliç,
  { {0x6e3b004d,0x61e30139,0x29cd0734,0x00000000}},	//   lsub, ionl, džad_,
  { {0x6f1b0397,0x6a860bd8,0x6b8d08a9,0x00000000}},	//   ncuc, _алиа, _gnag,
  { {0x69c7017f,0x6443007a,0x799e0618,0x00000000}},	// [c0c0] bije, ánin, _topw,
  { {0x69c7074f,0x75d30021,0xaa370047,0x00000000}},	//   cije, ليقا, _שטיק_,
  { {0x07fa0021,0x443c013d,0xdb1d10c9,0x00000000}},	//   _يرجع_, év_, lisá,
  { {0x07a6000a,0x61e300a4,0xe71a007e,0x00000000}},	//   _рамн, eonl, _زيست_,
  { {0xdce80066,0x68e9004c,0x61e3573e,0x00000000}},	//   vedč, ředt, fonl,
  { {0x41530086,0x201a0016,0x7c3a5dc9,0x00000000}},	//   ивіс, ípio_, ystr,
  { {0xa0670001,0xddc90051,0x2eca0053,0x00000000}},	//   ваја_, steś, ाप्त,
  { {0x245c01c2,0x7c3a5dca,0x657c5dcb,0x00000000}},	//   mím_, vstr, _harh,
  { {0x6e3b00bb,0x245c004a,0x657c5dcc,0x00000000}},	//   gsub, lím_, _karh,
  { {0x6b8d0117,0x7c3a2da1,0x645e007d,0x00000000}},	//   _snag, tstr, otpi,
  { {0x69c70117,0x245c0512,0x62820162,0x00000000}},	//   vije, ním_, lvoo,
  { {0xfe461599,0x7c3a5dcd,0xa3d50053,0x00000000}},	//   _андо, rstr, िचय_,
  { {0xec0a00aa,0xf773007e,0x7af60051,0x00000000}},	//   _nếu_, یار_, _czyt,
  { {0x6e2d005b,0x6d4e017d,0x7c3a5dce,0x00000000}},	//   _çaba, óbad, pstr,
  { {0x69c75dcf,0x245c004a,0x6286073e,0x00000000}},	//   rije, jím_, _škol,
  { {0xdb0f039f,0x69c75dd0,0x657c5dd1,0x00000000}},	//   ricó, sije, _aarh,
  { {0x628202b0,0x657c001f,0x61fa0019,0x00000000}},	// [c0d0] jvoo, _barh, _ohtl,
  { {0x628200f5,0xdc42004c,0x657c006c,0x00000000}},	//   dvoo, _léče, _carh,
  { {0x6282006f,0x61e30072,0xddc20066,0x00000000}},	//   evoo, vonl, _osož,
  { {0x68e90080,0x63a05dd2,0x6e220058,0x00000000}},	//   ředs, _comn, _otob,
  { {0x61e3005b,0x56b50047,0x63a05dd3,0x00000000}},	//   tonl, _עפֿן_, _domn,
  { {0xec0a001b,0x245c027d,0x11e40054,0x00000000}},	//   _hết_, bím_, ажім,
  { {0xec0a00aa,0x245c5dd4,0xc0c8005e,0x00000000}},	//   _kết_, cím_, куће_,
  { {0xdff50088,0xec0a001b,0x61e35dd5,0x00000000}},	//   ыяль, _yếu_, sonl,
  { {0x7aed003e,0x6f1b251e,0x69c5006f,0x00000000}},	//   _nyat, rcuc, _omhe,
  { {0xb5fb0025,0x6f1b006d,0xdb0d0003,0x00000000}},	//   _bpái, scuc, _plaî,
  { {0x7535051e,0x63a000ac,0x7aed5dd6,0x00000000}},	//   _mezz, _yomn, _ayat,
  { {0xfeb90635,0x69c5035a,0xab5b004b,0x00000000}},	//   _плеј_, _amhe, niüh,
  { {0x245c0080,0x6e45005e,0x0a3a0085,0x00000000}},	//   zím_, _селз, эчны_,
  { {0x99d60032,0x9d5501fb,0xdb1d1270,0x00000000}},	//   اتحا, _صنعت, risá,
  { {0x186710a3,0xf7460b3f,0xa3e30053,0x00000000}},	//   лари_, лево, नका_,
  { {0x628200ac,0x245c01c2,0x657c5dd7,0x00000000}},	//   yvoo, vím_, _sarh,
  { {0x657c5dd8,0x05660818,0xa686000d,0x00000000}},	// [c0e0] _parh, лван, ылад,
  { {0x245c0114,0x63a05dd9,0xb956005e,0x00000000}},	//   tím_, _somn, _стић,
  { {0x03260079,0x63a03c8a,0x657c0b3d,0x00000000}},	//   гден, _pomn, _varh,
  { {0x644a00cd,0x6282006f,0x245c5dda,0x00000000}},	//   àfiq, tvoo, rím_,
  { {0x71a60088,0x69c5001f,0xdce8001c,0x00000000}},	//   ладз, _ymhe, iedā,
  { {0x628203a8,0x91e30076,0x5a170047,0x00000000}},	//   rvoo, боче, אקסן_,
  { {0x5478014e,0xa5bb0051,0xf1a9007e,0x00000000}},	//   _בְּנ, _twór, خانه_,
  { {0x6d430302,0xab5b004b,0xf8b30063,0x00000000}},	//   _adna, riük, משו_,
  { {0xb5fb0025,0xd0070001,0x8e140002,0x00000000}},	//   _spái, ћење_, јдоц,
  { {0xd5b30063,0x3f8f0026,0xadb30145,0x00000000}},	//   ֶׁר_, _engu_, йбыш,
  { {0xdfcf005d,0xbdf70044,0x00000000,0x00000000}},	//   _کين_, دريا_,   ,
  { {0x6d4e00ea,0xce35005d,0x00000000,0x00000000}},	//   óbab, _چونک,   ,
  { {0x6e2200ac,0x7ac70330,0xdd940085,0x00000000}},	//   _utob, усне, _валы,
  { {0x2d9a004b,0xdee3005e,0xdd90005d,0x00000000}},	//   _õpe_, _уочи, _ذوب_,
  { {0x9848005a,0xa8350001,0x75350290,0x00000000}},	//   лята_, ребљ, _rezz,
  { {0x36d50001,0x64435ddb,0x4423004b,0x00000000}},	//   аобр, ánim, _rtj_,
  { {0x7535051e,0x260d007d,0xec0a008b,0x00000000}},	// [c0f0] _pezz, _džon_, _vết_,
  { {0x644300b2,0x69c5004d,0x99990078,0x00000000}},	//   šnim, _umhe, rusų_,
  { {0xab5b0019,0x75350290,0xec0a008b,0x00000000}},	//   tiüh, _vezz, _tết_,
  { {0xf1ed0042,0x889a009d,0x00000000,0x00000000}},	//   _चीज़_, _סברי,   ,
  { {0xab5b0019,0x672d5ddc,0x6bec0047,0x00000000}},	//   riüh, mbaj, ײַאַ,
  { {0x644a0fca,0x69d500bd,0xdb1d0072,0x00000000}},	//   áfic, nnze, lisä,
  { {0x11280086,0xf77f005b,0x69d500bd,0x00000000}},	//   уючи_, _kaç_, inze,
  { {0xfe4500d7,0xaa7d0072,0xdb1d0072,0x00000000}},	//   анио, _käää_, nisä,
  { {0x764d00e3,0xdcf800c3,0xee3603e6,0x00000000}},	//   nray, _davč, аны_,
  { {0xbc19000d,0x9f5e00cd,0xc6920063,0x00000000}},	//   кімі_, _butó_, קאי_,
  { {0xab2a2f57,0x764d0089,0x7204002a,0x00000000}},	//   кона_, hray, _اولم,
  { {0x2d9800c7,0xe4560047,0x3f8f0360,0x00000000}},	//   örer_, סירט_, _ungu_,
  { {0x539a0063,0xef0e1657,0x6d4e0022,0x00000000}},	//   דירו, _фм_, óbac,
  { {0x672d2d04,0x200f0455,0x9f5e013d,0x00000000}},	//   ebaj, _higi_, _futó_,
  { {0xac160138,0x475a005a,0x6443017f,0x00000000}},	//   _коју_, края_, šnij,
  { {0xc7a60076,0x764d0003,0x672d013d,0x00000000}},	//   шибк, fray, gbaj,
  { {0xd70a000d,0x68e9004c,0x14c8007e,0x00000000}},	// [c100] тнае_, ředp, گهای_,
  { {0xc9661dd6,0x200f5ddd,0x672d008f,0x00000000}},	//   _твой, _ligi_, abaj,
  { {0x14c8006a,0x764d005b,0xddcb008f,0x00000000}},	//   دهای_, aray, _apgū,
  { {0x82a6005a,0x317e00bd,0x764d03a1,0x00000000}},	//   ишле, _satz_, bray,
  { {0x02060076,0x20f50013,0x27f200a3,0x00000000}},	//   аздн, _ái_, mlyn_,
  { {0x2508007e,0x3958008f,0x27f25dde,0x00000000}},	//   _مرزی_, ngrs_, llyn_,
  { {0x9f442321,0x40340121,0x64a61915,0x00000000}},	//   lomé_, щейс, _тава,
  { {0x27f221bf,0x2249017f,0x64431653,0x00000000}},	//   nlyn_, šaka_, ânie,
  { {0x62330079,0xa3e30053,0x200f5ddf,0x00000000}},	//   _меѓу, नकर_, _digi_,
  { {0x200f007a,0x5046018e,0x27f2008d,0x00000000}},	//   _eigi_, _вежб, hlyn_,
  { {0x9df70088,0xdd970088,0x27f20474,0x00000000}},	//   рнэт_, ршы_, klyn_,
  { {0xee86000d,0xdb240026,0x200f5de0,0x00000000}},	//   _выко, örðu, _gigi_,
  { {0x27f21cc2,0x49a70141,0xddc20605,0x00000000}},	//   dlyn_, ајва, _epoš,
  { {0x394d00bd,0x9d17000d,0x261a0053,0x00000000}},	//   ßes_, _кошт_, _बढ़ी_,
  { {0x69d5004d,0xdb1d0072,0x27f2002b,0x00000000}},	//   rnze, tisä, flyn_,
  { {0x98b1000c,0x27f2001f,0x644308ea,0x00000000}},	//   ează_, glyn_, šnik,
  { {0x2cac0185,0x60150006,0xec0a0013,0x00000000}},	// [c110] lydd_, _išme, _iếp_,
  { {0xdb1d00fe,0xeb9f06a5,0x764d5de1,0x00000000}},	//   sisä, ljø_, rray,
  { {0x2cac0185,0x89da0063,0x96080085,0x00000000}},	//   nydd_, _תחתי, рэта_,
  { {0x77b8234b,0x644a013d,0x27f25de2,0x00000000}},	//   _píxe, áfia, clyn_,
  { {0x2cac001f,0x59bb0053,0x9f4a004c,0x00000000}},	//   hydd_, _उतार, ámým_,
  { {0xc6920047,0x27e90150,0x2cac0137,0x00000000}},	//   _זאך_, loan_, kydd_,
  { {0xa4d40086,0xc9b80063,0xbebd0023,0x00000000}},	//   _дорі, שהות_, nbūv,
  { {0x63ad0004,0xd8d8014e,0x2cac0185,0x00000000}},	//   öand, יווט_, dydd_,
  { {0xddc200c3,0xa2b50785,0xdddb0023,0x00000000}},	//   _spoš, _убач, evuš,
  { {0x2cac0185,0x27e9008d,0x81f90043,0x00000000}},	//   fydd_, hoan_, _صفار_,
  { {0x2cac001f,0x27e90150,0xec0a0013,0x00000000}},	//   gydd_, koan_, _bếp_,
  { {0x5f77007e,0x2d9e0066,0x6e290f98,0x00000000}},	//   _خاطر, ajte_, ppeb,
  { {0xa5bb5de3,0xfe700021,0x2ef53320,0x00000000}},	//   _atóm, _يده_, _уздр,
  { {0xbea2018e,0x2cac001f,0x6fde001c,0x00000000}},	//   _хашк, bydd_, rīce,
  { {0xddc20198,0x290c03b0,0x6ff90041,0x00000000}},	//   _upoš, äda_, ָפּג,
  { {0x18670001,0x7bcf0003,0x2fcd002b,0x00000000}},	//   љати_, ébut, nieg_,
  { {0x3ead4fbd,0x27f25de4,0x07a31c9d,0x00000000}},	// [c120] nyet_, rlyn_, чатн,
  { {0x27f207a7,0x8b080051,0x29cd00c2,0x00000000}},	//   slyn_, _cięż, lžan_,
  { {0x3d3a0047,0x0d3a0047,0xb4b20053,0x00000000}},	//   רגעס, רגעב, टने_,
  { {0xec0a001b,0xd36f0021,0x3ead05a5,0x00000000}},	//   _xếp_, فهم_, kyet_,
  { {0xebad0047,0x2fcd002b,0x61140092,0x00000000}},	//   כסאָ, dieg_, одлу,
  { {0x3ead00bb,0x64430016,0xe9df0026,0x00000000}},	//   dyet_, ânic, trúi_,
  { {0xe4da006a,0x7883011b,0x853b009a,0x00000000}},	//   _صورت_, mívá, _תגלי,
  { {0xdbf10080,0x69ce5de5,0xdce1008f,0x00000000}},	//   _příb, hibe, adlī,
  { {0x2cac0c70,0x26c05de6,0x69ce5de7,0x00000000}},	//   wydd_, nzio_, kibe,
  { {0x667b0149,0xec0a0013,0x2cac32e9,0x00000000}},	//   נטיק, _sếp_, tydd_,
  { {0x69ce5de8,0x2cac002b,0x2fcd0022,0x00000000}},	//   dibe, uydd_, bieg_,
  { {0x2cac0185,0x788300ea,0x78a10137,0x00000000}},	//   rydd_, hívá, älvm,
  { {0x9b58005a,0x2cac001f,0x8acb005e,0x00000000}},	//   щият_, sydd_, ућна_,
  { {0x8b080080,0x2cac002b,0x69ce5de9,0x00000000}},	//   _stří, pydd_, gibe,
  { {0x78830080,0xfdf70063,0x27e91643,0x00000000}},	//   dívá, _הצגת_, toan_,
  { {0xba19007e,0x58d40086,0xba55005e,0x00000000}},	//   _پيدا_, чост, _двиј,
  { {0x9539005a,0x27e90150,0x56940054,0x00000000}},	// [c130] изат_, roan_, патт,
  { {0x2737008b,0x69ce1558,0x6d5a5dea,0x00000000}},	//   ần_, cibe, ngta,
  { {0x442702b0,0x6d5a0078,0xb5fb259d,0x00000000}},	//   ën_, igta, _spás,
  { {0x7bcf5deb,0xa2f504ef,0xd5a30043,0x00000000}},	//   nicu, опеч, _کلسی,
  { {0x32671bdd,0x6b7c0047,0xe29901e4,0x00000000}},	//   стев, טראנ, рал_,
  { {0xd5b10013,0x7bcf49e5,0x3ead0058,0x00000000}},	//   _ố_, hicu, vyet_,
  { {0x2fcd00bd,0xa156005e,0xe1f001fb,0x00000000}},	//   tieg_, цају_, رسه_,
  { {0x6d5a21ec,0xce491406,0xef190601,0x00000000}},	//   egta, азие_, шми_,
  { {0x2fcd00bd,0x7bcf3653,0x69ce013d,0x00000000}},	//   rieg_, dicu, yibe,
  { {0xdcf8001c,0xddc50086,0x7bcf017d,0x00000000}},	//   _savā, ібни, eicu,
  { {0x3a29017e,0xc0d5007e,0x7bcf5dec,0x00000000}},	//   _atap_, _بياب, ficu,
  { {0x6d5a002c,0x3b0a0002,0x3f83008f,0x00000000}},	//   agta, иено_, ējus_,
  { {0x29cd007d,0x69ce2494,0xaffc0054,0x00000000}},	//   ržan_, tibe, _соцi,
  { {0x63b8008f,0x1d0901e2,0x395e004b,0x00000000}},	//   īvni, _кели_, üts_,
  { {0x69ce5ded,0xa7aa08b0,0x7bcf5dee,0x00000000}},	//   ribe, аква_, bicu,
  { {0xa6db0026,0x69ce5def,0x7bcf00dd,0x00000000}},	//   _meðf, sibe, cicu,
  { {0x2d850080,0xd5b20021,0x69ce0093,0x00000000}},	// [c140] odle_, وفر_, pibe,
  { {0x26c00290,0x2ca90080,0x6b845df0,0x00000000}},	//   rzio_, _řady_, _haig,
  { {0x07a60245,0x6b9600eb,0xab5b0058,0x00000000}},	//   _данн, _knyg, enüy,
  { {0x61fd001c,0x75f00066,0xa0260046,0x00000000}},	//   _īsla, väzu, hlöð,
  { {0x6b845df1,0x420a04f2,0x67240130,0x00000000}},	//   _maig, андо_, mcij,
  { {0x6b845df2,0x67240734,0x7bcf00dd,0x00000000}},	//   _laig, lcij, zicu,
  { {0x2d850969,0x999b0149,0x6724007d,0x00000000}},	//   ddle_, יבסט, ocij,
  { {0x4fc60088,0x442a0150,0x67245df3,0x00000000}},	//   ўска, _itb_, ncij,
  { {0x76445df4,0x8fa30002,0xcdda0699,0x00000000}},	//   nsiy, ќање, ињо_,
  { {0x3f82027d,0x44441f45,0x22590137,0x00000000}},	//   žku_, os_, _åska_,
  { {0x6b8400eb,0x3a290173,0x444442c0,0x00000000}},	//   _baig, _stap_, ns_,
  { {0x6b845df5,0x7644282e,0x63a25df6,0x00000000}},	//   _caig, ksiy, njon,
  { {0x6b845df7,0x69c0001c,0x60150078,0x00000000}},	//   _daig, īmen, _išma,
  { {0x7bcf1f12,0x44445df8,0x29cd007d,0x00000000}},	//   sicu, ks_, ržao_,
  { {0x6b840027,0x5cc3005a,0x44445df9,0x00000000}},	//   _faig, _осъз, js_,
  { {0x5bc40021,0xd7940062,0x7b060014,0x00000000}},	//   _يقول, мисъ, áttö,
  { {0x44380185,0xf1db0053,0x764400a4,0x00000000}},	// [c150] _awr_, _बदलन, gsiy,
  { {0x44445dfa,0x9f4401c2,0x6b8417f1,0x00000000}},	//   fs_, domí_, _zaig,
  { {0x753c00bd,0x764400a4,0x444434da,0x00000000}},	//   _derz, asiy, gs_,
  { {0x987a00b5,0x4438001f,0xa87a0041,0x00000000}},	//   _פארט, _dwr_, _פארר,
  { {0x798500e3,0x4444095b,0x4438004d,0x00000000}},	//   _kahw, as_, _ewr_,
  { {0x1a7c0063,0x81c80054,0x44442a96,0x00000000}},	//   שְׁמ, огів_, bs_,
  { {0x661d02ab,0x44445dfb,0x4438162d,0x00000000}},	//   _husk, cs_, _gwr_,
  { {0x63a20051,0x661d30fa,0x6f620062,0x00000000}},	//   cjon, _kusk, евъз,
  { {0xd14b006a,0x673d5dfc,0x63bb0150,0x00000000}},	//   _نشان_, _mesj, _ilun,
  { {0xd1310021,0x6b960137,0x4d65150f,0x00000000}},	//   _أما_, _snyg, чков,
  { {0x64455dfd,0x752500bd,0x6b840019,0x00000000}},	//   nshi, ichz, _paig,
  { {0x2d831312,0x64455dfe,0xcb6a0062,0x00000000}},	//   žje_, ishi, щаме_,
  { {0x798500f3,0x63a900e8,0x661d0006,0x00000000}},	//   _bahw, _moen, _nusk,
  { {0x661500c3,0x764401f7,0x63bb5dff,0x00000000}},	//   _nizk, vsiy, _llun,
  { {0x6d415e00,0x6b845e01,0x444400cd,0x00000000}},	//   mala, _taig, xs_,
  { {0x64455e02,0x6d415e03,0x63a900d1,0x00000000}},	//   dshi, lala, _noen,
  { {0xe7370055,0x64450035,0x6d411fdc,0x00000000}},	// [c160] яет_, eshi, oala,
  { {0x6d415e04,0x76445e05,0x44445e06,0x00000000}},	//   nala, rsiy, ts_,
  { {0xdb0d1569,0x76445e07,0x661d27e2,0x00000000}},	//   _plaç, ssiy, _eusk,
  { {0x8c1a014e,0x6d4115c4,0x76445e08,0x00000000}},	//   צוני, hala, psiy,
  { {0x753c051e,0x63a95e09,0x64455cb6,0x00000000}},	//   _terz, _doen, ashi,
  { {0x63a25e0a,0x6d41014f,0x7af600fe,0x00000000}},	//   sjon, jala, _myyt,
  { {0x6d415e0b,0x64430066,0xf9930063,0x00000000}},	//   dala, ánit, תרו_,
  { {0x63a90150,0x63bb0137,0x6d415e0c,0x00000000}},	//   _goen, _glun, eala,
  { {0x6d415e0d,0xf1b90130,0x31163f17,0x00000000}},	//   fala, _suše_, _ефес,
  { {0xdd9a005a,0x6d41437c,0x6ce6000d,0x00000000}},	//   сши_, gala, зіме,
  { {0x718b0063,0x29cd008f,0xe1650044,0x00000000}},	//   _לְאַ, užam_, _تدقي,
  { {0x6d4137de,0x22460150,0xb09b0063,0x00000000}},	//   aala, osok_, _ליבר,
  { {0xe61f0013,0x98b8008f,0x6d415e0e,0x00000000}},	//   _trôi_, varā_, bala,
  { {0x6d4a00b9,0x6d41193b,0x661d3667,0x00000000}},	//   _udfa, cala, _rusk,
  { {0x661d5e0f,0xd7f5000d,0x7ae45e10,0x00000000}},	//   _susk, дзвы, _exit,
  { {0xb8140001,0x201e5e11,0x661d5e12,0x00000000}},	//   едсј, _muti_, _pusk,
  { {0x25aa0185,0xaa540085,0x644536be,0x00000000}},	// [c170] _bobl_, _звыш, wshi,
  { {0x63bb5e13,0x63a95e14,0xdb0f004c,0x00000000}},	//   _slun, _soen, nkcí,
  { {0x752500bd,0x7bdd0c92,0x254f001c,0x00000000}},	//   rchz, onsu, vēlē_,
  { {0x644504ff,0x213e001f,0x6d415e15,0x00000000}},	//   rshi, _aeth_, zala,
  { {0x213e0185,0x64455e16,0x6d4122a7,0x00000000}},	//   _beth_, sshi, yala,
  { {0x63a9006f,0x64430080,0x7bdd004d,0x00000000}},	//   _woen, ánis, hnsu,
  { {0x63a90179,0x201e0397,0x224600a4,0x00000000}},	//   _toen, _cuti_, asok_,
  { {0x6d4115c4,0x98b8000c,0x201e0089,0x00000000}},	//   wala, lară_, _duti_,
  { {0x29cd017f,0x98b8003b,0x98b10d07,0x00000000}},	//   ržaj_, oară_, razę_,
  { {0x98b8000c,0xe29004f6,0x6d4133ab,0x00000000}},	//   nară_, _حذف_, uala,
  { {0x7af600fe,0x8cb4026c,0x6d415e17,0x00000000}},	//   _syyt, есяч, rala,
  { {0x333f0164,0x7af600fe,0x6d4108a4,0x00000000}},	//   _jeux_, _pyyt, sala,
  { {0x6d413b4e,0x539a0063,0x7fb60044,0x00000000}},	//   pala, קישו, _زهور_,
  { {0x8c65006a,0xe61f0066,0x7bdd5e18,0x00000000}},	//   _قطعن, _osôb_, ansu,
  { {0x7e695afe,0x6443003b,0x69dc53b5,0x00000000}},	//   ltep, ânil, rnre,
  { {0x7af600fe,0x9b46007e,0x7e690014,0x00000000}},	//   _tyyt, _کنکو, otep,
  { {0x25aa0185,0x99e60076,0x05aa000d,0x00000000}},	// [c180] _pobl_, _ожид, овай_,
  { {0x6e2d0058,0x98b8003b,0xe577005e,0x00000000}},	//   _çabu, gară_, мзу_,
  { {0x2d875e19,0x480601f8,0x7e69004b,0x00000000}},	//   _mane_, _опов, htep,
  { {0x333f03b2,0xf626018e,0x2d874a96,0x00000000}},	//   _ceux_, _одмо, _lane_,
  { {0x333f03b2,0x213e001f,0x2b40002b,0x00000000}},	//   _deux_, _peth_, _meic_,
  { {0x27ed01a6,0x201e0da5,0x98b8003b,0x00000000}},	//   čene_, _puti_, cară_,
  { {0x232a0086,0x333f0003,0x50660054,0x00000000}},	//   _мови_, _feux_, фтла,
  { {0x260d0078,0x60050046,0x00000000,0x00000000}},	//   _džou_, jómd,   ,
  { {0x2d875e1a,0x7e690983,0x7c2d0734,0x00000000}},	//   _bane_, gtep, _čara,
  { {0x201e0150,0x2d8713f4,0x8146005d,0x00000000}},	//   _tuti_, _cane_, _آنان,
  { {0x333f0164,0x2d870886,0x2b40002b,0x00000000}},	//   _yeux_, _dane_, _beic_,
  { {0xbb940076,0x2d98013d,0x6f930044,0x00000000}},	//   вающ, űre_, _للمض,
  { {0x2d870d02,0x7bdd2243,0xbda60021,0x00000000}},	//   _fane_, rnsu, _يحتو,
  { {0x2d875e1b,0xdb1d004b,0x29cd0078,0x00000000}},	//   _gane_, lisü, ožai_,
  { {0x9cf40086,0x2b4013d5,0x98b8003b,0x00000000}},	//   _язкі, _feic_, vară_,
  { {0xfce30002,0xdb1d004b,0x6443017d,0x00000000}},	//   _шојо, nisü, ânim,
  { {0x98b8000c,0x443f0024,0x19954099,0x00000000}},	// [c190] tară_, _ňu_, _запя,
  { {0xde880013,0x6d4e013d,0x6005009c,0x00000000}},	//   _mị_, óbah, móme,
  { {0xdb0444d1,0x98b8000c,0x333f0003,0x00000000}},	//   _hlið, rară_, _peux_,
  { {0x98b8000c,0x69d55e1c,0x9f4d00ac,0x00000000}},	//   sară_, lize, roeë_,
  { {0x60050942,0x333f0164,0x98b8003b,0x00000000}},	//   nóme, _veux_, pară_,
  { {0xf1b9007d,0xdcef0066,0x69d55e1d,0x00000000}},	//   _buša_, _čeľa, nize,
  { {0x2d870d7f,0x6ed40042,0x1fb55e1e,0x00000000}},	//   _rane_, _बेबु, еспр,
  { {0xde8800aa,0xc918014e,0x7e690019,0x00000000}},	//   _bị_, וחות_, ttep,
  { {0xc175011c,0x28d60235,0x3eb95e1f,0x00000000}},	//   _плащ, _डेनि, ást_,
  { {0x62340001,0x2b400025,0x69c0001c,0x00000000}},	//   _рефу, _seic_, īmek,
  { {0x7e6949e1,0xdc030061,0x28cf0042,0x00000000}},	//   step, ačín, _हेलि,
  { {0x69d55e20,0x76560050,0x1eea005d,0x00000000}},	//   eize, yryy, _کوهی_,
  { {0x69d5000f,0x2b40001c,0x2d87005b,0x00000000}},	//   fize, _veic_, _tane_,
  { {0xbed600b5,0x69d55e21,0xdd880054,0x00000000}},	//   _אונז_, gize, _обід_,
  { {0x25f50053,0x98b80078,0xa2d60042,0x00000000}},	//   ्तनी_, karą_, _मेन्,
  { {0xc7b20021,0x8c1a009f,0x00000000,0x00000000}},	//   دّر_, _צופי,   ,
  { {0xaffa0047,0x98b80078,0x9737014b,0x00000000}},	// [c1a0] פּלי, darą_, вiты_,
  { {0x273e0013,0x69d55e22,0x14261f89,0x00000000}},	//   ắn_, cize, еджм,
  { {0x7c2b003b,0xf7460e5e,0x2db60047,0x00000000}},	//   _înră, _пено, עלען_,
  { {0xd8d70047,0x32660002,0xe61a0002,0x00000000}},	//   _טויט_, еткв, _ндм_,
  { {0x20060185,0x27e05e23,0xa3b10053,0x00000000}},	//   _rhoi_, mnin_, _ओवर_,
  { {0x2fdf004d,0x27e00050,0x00000000,0x00000000}},	//   enug_, lnin_,   ,
  { {0x63a40019,0x64580827,0x6f0200ea,0x00000000}},	//   öins, ávid, _szoc,
  { {0x27e05e24,0x657e0592,0xdcf80078,0x00000000}},	//   nnin_, leph, _gavę,
  { {0xdb1d004b,0x8b030022,0x27e05e25,0x00000000}},	//   risü, łęzi, inin_,
  { {0xde88001b,0x628210da,0xdb1d004b,0x00000000}},	//   _vị_, mwoo, sisü,
  { {0xa5bb1112,0xa6db007a,0x62822ac2,0x00000000}},	//   _któr, _meða, lwoo,
  { {0xdb1d017d,0xde88008b,0x20553242,0x00000000}},	//   visó, _tị_, _штур,
  { {0x62825e26,0x69d50d11,0xfbdf017d,0x00000000}},	//   nwoo, tize, rnê_,
  { {0xa6db007a,0x69d5006f,0x3eb901f2,0x00000000}},	//   _neða, uize, øste_,
  { {0x645e003d,0x8d630001,0x27e00014,0x00000000}},	//   jupi, _свје, fnin_,
  { {0x628203a8,0x2d8c006f,0xbc670021,0x00000000}},	//   kwoo, ldde_, _أمين_,
  { {0x628200ca,0x2d8c5e27,0x98b8005f,0x00000000}},	// [c1b0] jwoo, odde_, varą_,
  { {0x78a100c7,0x645e0035,0x2d8c006f,0x00000000}},	//   älvs, fupi, ndde_,
  { {0x2d8c006f,0x645e0019,0x62820229,0x00000000}},	//   idde_, gupi, ewoo,
  { {0x62350bb2,0x62820983,0x9207008f,0x00000000}},	//   веду, fwoo, ināš,
  { {0x6282021f,0x44335e28,0x22940054,0x00000000}},	//   gwoo, spx_, лиця,
  { {0x26c90035,0x657e5e29,0x98b80078,0x00000000}},	//   mzao_, ceph, sarą_,
  { {0x44250529,0x645e0034,0xdcf80078,0x00000000}},	//   _îl_, cupi, _tavę,
  { {0x201900fe,0x389c0063,0x889c0047,0x00000000}},	//   ösi_, ליונ, לבוי,
  { {0x200d000c,0xaf05005a,0x5274007e,0x00000000}},	//   rmei_, ъпил, _مالز,
  { {0x64580006,0x6e22146c,0xb51d0085,0x00000000}},	//   švie, _duob, блiя,
  { {0xfce50201,0x27e05e2a,0xd35f0054,0x00000000}},	//   тоно, ynin_, _вiдч,
  { {0x2d8c25c5,0xeb970121,0xdb1d0139,0x00000000}},	//   adde_, вию_, bhsí,
  { {0xf41200b5,0x4423007d,0x8d950021,0x00000000}},	//   יפט_, _luj_, _للإش,
  { {0xaf04019d,0xddc20080,0x27e05e2b,0x00000000}},	//   _спіл, _zpož, wnin_,
  { {0x3f8d0268,0xd9430794,0x27e05e2c,0x00000000}},	//   odeu_, реси, tnin_,
  { {0x3f8d0016,0xab5b004d,0x27e05e2d,0x00000000}},	//   ndeu_, nhül, unin_,
  { {0x0566011c,0x6d430397,0x7b650092,0x00000000}},	// [c1c0] кван, _kena, _стје,
  { {0x6d43166a,0xdb04017d,0x645e5e2e,0x00000000}},	//   _jena, _goiá, tupi,
  { {0x6d435a83,0x657e318f,0x64c60044,0x00000000}},	//   _mena, reph, خيال,
  { {0x62820ac8,0x7c2d007d,0x78a10829,0x00000000}},	//   twoo, _čarl, ålve,
  { {0x2d8c1e79,0x29cd00c2,0x3e6b00d1,0x00000000}},	//   ydde_, ržav_, jøt_,
  { {0x6282477a,0xf1b9085a,0xa5bb0022,0x00000000}},	//   rwoo, _dušo_, _wtór,
  { {0x04435e2f,0x628207f3,0xdce10078,0x00000000}},	//   _весн, swoo, melė,
  { {0xfff8006a,0x62825e30,0xa8570063,0x00000000}},	//   رکات_, pwoo, דיקה_,
  { {0x6d4307c9,0x661c28e3,0xd0070001,0x00000000}},	//   _bena, _kirk, њење_,
  { {0x68e90529,0x7c230025,0x6d435e31,0x00000000}},	//   şedi, _bunr, _cena,
  { {0x6d432005,0x2d8a0066,0xd491008d,0x00000000}},	//   _dena, ľbe_, _ời_,
  { {0xab5b004d,0x60d90041,0x2d8a407b,0x00000000}},	//   chül, _אַנג, žbe_,
  { {0xdfcf08aa,0xb9080013,0xdce10078,0x00000000}},	//   _بين_, _thiị_, kelė,
  { {0x7e600425,0x6d435e32,0xda340121,0x00000000}},	//   mump, _gena, реры,
  { {0xdce10006,0x7e605e33,0x8a180caa,0x00000000}},	//   delė, lump, торс_,
  { {0x661c0150,0x7bc60e77,0x6d485e34,0x00000000}},	//   _airk, chku, lada,
  { {0x7e600277,0x661c0f58,0x644e08a9,0x00000000}},	// [c1d0] nump, _birk, _avbi,
  { {0x6d485e35,0x27460078,0x661c0e6c,0x00000000}},	//   nada, vūnų_, _cirk,
  { {0x6b8d00bb,0x661c00c3,0x6d485e36,0x00000000}},	//   _kaag, _dirk, iada,
  { {0x6d485e37,0x7e605e38,0xa3cd0053,0x00000000}},	//   hada, kump, षों_,
  { {0x69c700fe,0x98b80006,0x6b8d27bd,0x00000000}},	//   ohje, darę_, _maag,
  { {0x661c00d1,0x60150078,0x6d482013,0x00000000}},	//   _girk, _išmi, jada,
  { {0x6d485e39,0xd1640062,0xab5b004d,0x00000000}},	//   dada, ръчи, thül,
  { {0x6d435e3a,0x3e6b00d1,0x6d485e3b,0x00000000}},	//   _sena, tøt_, eada,
  { {0x7e6000bb,0x224d017f,0x3f8d14b1,0x00000000}},	//   gump, _uvek_, rdeu_,
  { {0x6d480eb4,0x4174005d,0x6289004e,0x00000000}},	//   gada, _نامس, _iseo,
  { {0x6fde001c,0x6d435e3c,0x69c704aa,0x00000000}},	//   zīci, _vena, dhje,
  { {0x4e9503eb,0x6d435e3d,0x7e600d1e,0x00000000}},	//   _مشتر, _wena, bump,
  { {0x6b8d0438,0x7e6018a7,0x6d435e3e,0x00000000}},	//   _daag, cump, _tena,
  { {0x6d48249b,0x2d940062,0x29cd2128,0x00000000}},	//   cada, _връс, džas_,
  { {0xbca80032,0xc8b502dc,0x201d5e3f,0x00000000}},	//   _لديك_, асты, _kiwi_,
  { {0x661c5e40,0xab6604f2,0x3b0a0094,0x00000000}},	//   _sirk, _свил, _пейо_,
  { {0x6722003d,0xdce10006,0x661c276c,0x00000000}},	// [c1e0] žojo, telė, _pirk,
  { {0x59862f4b,0x6b8d00ca,0x64a621a9,0x00000000}},	//   _слоб, _zaag, лаза,
  { {0x764d0fe5,0x661c19b2,0x5a170063,0x00000000}},	//   asay, _virk, _תקין_,
  { {0x661c0199,0x929d0045,0x61e30031,0x00000000}},	//   _wirk, _czło, ennl,
  { {0xe2973ba6,0x6d485e41,0xbb3b016e,0x00000000}},	//   лац_, yada, געני,
  { {0x7bc40268,0xa6db0026,0x6d4800ed,0x00000000}},	//   _lliu, _meðl, xada,
  { {0x6d4848ab,0x40340121,0x65c35e42,0x00000000}},	//   vada, шейс, _убра,
  { {0xa3b80161,0xa8e2008b,0x68150051,0x00000000}},	//   _छवि_, _đồn, _sądz,
  { {0x394a00b9,0x9ed70062,0x6d485e43,0x00000000}},	//   kabs_, лмът_, tada,
  { {0x7bc435ac,0x6b8d112c,0x5c743477,0x00000000}},	//   _aliu, _saag, алот,
  { {0x7e60458e,0x6d480eb4,0x236600c2,0x00000000}},	//   sump, rada, ogoj_,
  { {0x764d00bb,0x6d485e44,0x7e605e45,0x00000000}},	//   ysay, sada, pump,
  { {0x6d485e46,0x6b8d5560,0xda781d9d,0x00000000}},	//   pada, _vaag, ляр_,
  { {0xc2140063,0x6b8d030c,0x60050066,0x00000000}},	//   יהָ_, _waag, nómn,
  { {0xd80b0121,0x69c701f2,0xac73005d,0x00000000}},	//   ехал_, rhje, _هايش,
  { {0x47350088,0x27ed5ba9,0xddc90051,0x00000000}},	//   рнас, čeno_, kreś,
  { {0xdb1d0027,0x672d3016,0x2d8e216c,0x00000000}},	// [c1f0] bhsá, rcaj, _kafe_,
  { {0x764d4b89,0x61e40025,0x28d60053,0x00000000}},	//   rsay, éill, _डेवि,
  { {0x764d0164,0xa022004b,0xf2df00dd,0x00000000}},	//   ssay, ööli, _ţâ_,
  { {0x764d005b,0xd7950062,0x6031008f,0x00000000}},	//   psay, _тимъ, _jāme,
  { {0xe1f103eb,0xe299005e,0x27ec004c,0x00000000}},	//   يست_, ђак_, édne_,
  { {0x321e0034,0x30550001,0xdce8008f,0x00000000}},	//   _city_, ађит, nedē,
  { {0xdb1d0019,0xa6db0026,0xe042079f,0x00000000}},	//   misõ, _meðm, онщи,
  { {0x62890025,0xdb1d5e47,0x63050044,0x00000000}},	//   _tseo, lisõ, _نوزل,
  { {0x00180088,0x2003001c,0x69c5017d,0x00000000}},	//   ыўшы_, ēji_, _olhe,
  { {0x7bc8003d,0x8c950603,0x2d8e5e48,0x00000000}},	//   ījum, армі, _cafe_,
  { {0xdb06004b,0x7bc44e91,0x6bd60044,0x00000000}},	//   skkü, _pliu, لتحر,
  { {0xdb1d004b,0x69c55e49,0x4093005d,0x00000000}},	//   hisõ, _alhe, _پلچر,
  { {0x7f3a0047,0xdb1d0139,0x2ba80053,0x00000000}},	//   _סעסו, thsá, गाबा,
  { {0x8cb5011c,0x3f8f0401,0xed5936b1,0x00000000}},	//   _всич, _hagu_, _рок_,
  { {0x7aed0016,0x60050066,0x394a5e4a,0x00000000}},	//   _exat, nómo, rabs_,
  { {0x3f8f0019,0x1867005e,0x69c500ea,0x00000000}},	//   _jagu_, јати_, _elhe,
  { {0x3f8f001f,0xdcfa008f,0xabfb3997,0x00000000}},	// [c200] _magu_, metā, _שהפר,
  { {0x3f8f0397,0x399a0047,0x3ea00025,0x00000000}},	//   _lagu_, _ייִד, _áite_,
  { {0xbb1b003b,0x69dc5e4b,0x03261b41,0x00000000}},	//   neîn, mire, аден,
  { {0x3f8f0004,0xdb1d0137,0x78a8004b,0x00000000}},	//   _nagu_, risö, ädvu,
  { {0x69dc177f,0x321e00e5,0xdcfa008f,0x00000000}},	//   oire, _pity_, ietā,
  { {0xdb1d0016,0xf50a0071,0x69dc5e4c,0x00000000}},	//   cisõ, _англ_, nire,
  { {0x25f50053,0xc9530063,0x9fc60054,0x00000000}},	//   ्तरी_, קמה_, ищил,
  { {0x2d8e2872,0x69dc5e4d,0x225a0044,0x00000000}},	//   _safe_, hire, _للرد_,
  { {0x69dc25bb,0x317a007e,0xeda6315e,0x00000000}},	//   kire, _لحاظ_, ашно,
  { {0x443a0829,0x69dc003b,0x00000000,0x00000000}},	//   opp_, jire,   ,
  { {0x60050e7c,0x3f8f002b,0x61ed006c,0x00000000}},	//   cómo, _fagu_, éale,
  { {0x69dc0025,0x62080078,0x98a33164,0x00000000}},	//   eire, šplė, ncją_,
  { {0x9b58005a,0xcff5006a,0x2fc600a4,0x00000000}},	//   шият_, _اينک, _ilog_,
  { {0x61f802e2,0xda09007e,0x69dc5e4e,0x00000000}},	//   novl, ايسه_, gire,
  { {0xed570dd5,0xdb1d0016,0xe7590086,0x00000000}},	//   _тој_, visõ, ливі_,
  { {0xdddb003b,0x3f845e4f,0x69dc5e50,0x00000000}},	//   otuş, nemu_, aire,
  { {0xdb1d004b,0x645e489c,0x61f85e51,0x00000000}},	// [c210] tisõ, erpi, kovl,
  { {0x3f840009,0x7bdd021e,0x3db80047,0x00000000}},	//   hemu_, lisu, נֶּא,
  { {0x4427001b,0xe475000a,0xe4d90021,0x00000000}},	//   ên_, слењ, دوات_,
  { {0x24580088,0xdb1d0019,0x3f8426a2,0x00000000}},	//   раць_, sisõ, jemu_,
  { {0xddc90529,0x3f8f0397,0x443a5e52,0x00000000}},	//   nteţ, _ragu_, app_,
  { {0xe1f8000d,0x3f8f0360,0x61423320,0x00000000}},	//   агі_, _sagu_, пеша,
  { {0x7bdd5e53,0xb367005a,0x2fc65e54,0x00000000}},	//   kisu, _възк, _blog_,
  { {0xdce1001c,0x3f8400c2,0xfe450002,0x00000000}},	//   selī, gemu_, бнио,
  { {0xef190055,0x929d0051,0x5fa90053,0x00000000}},	//   ыми_, _byłe, काबल,
  { {0x7bdd004b,0x00000000,0x00000000,0x00000000}},	//   eisu,   ,   ,
  { {0x4095007e,0x69dc5e55,0x3f8f5e56,0x00000000}},	//   _دلار, vire, _tagu_,
  { {0x30150076,0xeb9f00b9,0x629b0078,0x00000000}},	//   _удер, eløb_, _kruo,
  { {0x3a290150,0x69dc25d0,0x539a0063,0x00000000}},	//   _cuap_, tire, אירו,
  { {0x6e3b1362,0xfe70007e,0x7bdd1102,0x00000000}},	//   mpub, _زده_, aisu,
  { {0x2d850469,0xc7a6036a,0x69dc5e57,0x00000000}},	//   mele_, бивк, rire,
  { {0x2cb800c7,0x2d855e58,0x69dc5e59,0x00000000}},	//   ärde_, lele_, sire,
  { {0xb8ff0161,0xbb3b00b5,0x2c7100ea,0x00000000}},	// [c220] _दे_, _געפי, lád_,
  { {0x99860032,0x2d855e5a,0x3f840022,0x00000000}},	//   _الدو, nele_, zemu_,
  { {0xdb0d007a,0x645e001c,0x6b860229,0x00000000}},	//   _hlað, urpi, oekg,
  { {0x63a4003d,0x629b0006,0x2d855e5b,0x00000000}},	//   ķino, _bruo, hele_,
  { {0xa3d70161,0x2d8554e4,0x3f8400c2,0x00000000}},	//   ाफ़_, kele_, vemu_,
  { {0xd9f80053,0x2d855e5c,0x3f840051,0x00000000}},	//   ंकित_, jele_, wemu_,
  { {0x7dc400cd,0x3f845e5d,0x2d855e5e,0x00000000}},	//   _bòsn, temu_, dele_,
  { {0x2d8502a8,0xb0270021,0x389b0063,0x00000000}},	//   eele_, حكيم_, ריקנ,
  { {0x629b0006,0xe2971b06,0x2fc6118f,0x00000000}},	//   _gruo, _лат_, _vlog_,
  { {0x2d855e5f,0x24860022,0x4237009a,0x00000000}},	//   gele_, łomu_, _לנמל_,
  { {0xfe6f006a,0x3a290150,0xb5fb0047,0x00000000}},	//   ودی_, _suap_, רליכ,
  { {0xdb0d0026,0x6e3b38b9,0x2fc6007d,0x00000000}},	//   _blað, bpub, _ulog_,
  { {0x442a1112,0x2f97014e,0xddc9000c,0x00000000}},	//   _lub_, _לכאן_, uteţ,
  { {0xf2d300b5,0x6ca6026b,0x2d855e60,0x00000000}},	//   לער_, _гриж, cele_,
  { {0xeb9f00b9,0xe9190086,0x4438003b,0x00000000}},	//   rløb_, рові_, _ntr_,
  { {0x6031001c,0xdc6b009a,0xa037009d,0x00000000}},	//   _jāma, _ע֣וֹ, מאלה_,
  { {0xfbdf017d,0x95d9026b,0xdb0d0014,0x00000000}},	// [c230] miê_, адат_, _glað,
  { {0x6d4a006d,0xdcfa003b,0xddc90130,0x00000000}},	//   _jefa, cetă, oteš,
  { {0x628000eb,0xd49b000d,0x44385e61,0x00000000}},	//   _apmo, ыра_, _ctr_,
  { {0x78ba00c7,0x2d855e62,0xd838004c,0x00000000}},	//   ätve, zele_, íče_,
  { {0x27e900a4,0xdcf8001c,0x6d585e63,0x00000000}},	//   mnan_, _kavē, _odva,
  { {0xddc20080,0xfa78014e,0x2d85000c,0x00000000}},	//   _tvoř, צעות_, xele_,
  { {0x27e95e64,0x2d855e65,0x7dcd0014,0x00000000}},	//   onan_, vele_, _húsg,
  { {0xdbf20080,0x60090001,0x27e95e66,0x00000000}},	//   _přís, јним_, nnan_,
  { {0xa6db0026,0x7c2a00bd,0x92b7007e,0x00000000}},	//   _beði, _aufr, _احزا,
  { {0x7c2a0031,0x2d851dc7,0x6d4a5e67,0x00000000}},	//   _bufr, uele_, _cefa,
  { {0x6e3b0006,0x2d855e68,0x20c7005e,0x00000000}},	//   spub, rele_, _усаг,
  { {0x2d855e69,0x6d585e6a,0x6722008f,0x00000000}},	//   sele_, _edva, žoji,
  { {0xeb970432,0xff50007e,0x27e90089,0x00000000}},	//   ция_, _سخن_, dnan_,
  { {0x8c450189,0x6d4a1d45,0x7b3e0051,0x00000000}},	//   _деке, _gefa, dłuż,
  { {0x6e2b0026,0x291e0137,0x290c0137,0x00000000}},	//   _hugb, äta_, åda_,
  { {0x2904003d,0x27e95e6b,0xc7a30635,0x00000000}},	//   āma_, gnan_, миск,
  { {0x99890024,0x7c2a00bd,0x442a5e6c,0x00000000}},	// [c240] _stať_, _zufr, _sub_,
  { {0x6abb00bd,0x7c240213,0xab5b004d,0x00000000}},	//   äufe, _hiir, nkün,
  { {0x6e230031,0x7c242c84,0x98a30051,0x00000000}},	//   _minb, _kiir, kcję_,
  { {0xab5b0019,0x9986007e,0x13060690,0x00000000}},	//   shüv, _الگو, озем,
  { {0x27e000fe,0x6d410104,0xc7b301f9,0x00000000}},	//   miin_, kbla, _חבר_,
  { {0x27e0315d,0x4a9b00b5,0x1a9b0047,0x00000000}},	//   liin_, יינג, יינע,
  { {0x21670138,0x316001f7,0x61ed14bd,0x00000000}},	//   цији_, ğiz_, éala,
  { {0xb6020080,0x27e000fe,0x88bb0063,0x00000000}},	//   řáda, niin_, יזצי,
  { {0x7c2a0521,0x6d41120a,0x3f980080,0x00000000}},	//   _sufr, fbla, ěru_,
  { {0x44240034,0x27e900c3,0x27ed164c,0x00000000}},	//   _him_, znan_, čeni_,
  { {0x27e000fe,0x6d4a19ce,0x6e23002b,0x00000000}},	//   kiin_, _vefa, _dinb,
  { {0x6d4a0185,0xddc9000c,0x6e233240,0x00000000}},	//   _wefa, preş, _einb,
  { {0x6d411a20,0x44245e6d,0x27e000fe,0x00000000}},	//   bbla, _mim_, diin_,
  { {0x6d585e6e,0x44245e6f,0x6d5500ea,0x00000000}},	//   _udva, _lim_, ózat,
  { {0x61ea00bd,0x7c380ecf,0x61fd0026,0x00000000}},	//   infl, _utvr, _ísle,
  { {0x27e95e70,0x44245e71,0x27e02f0c,0x00000000}},	//   unan_, _nim_, giin_,
  { {0x9f440857,0x27e95e72,0x97420054,0x00000000}},	// [c250] lomó_, rnan_, вiть_,
  { {0x69ce330b,0x27e94ca4,0xd49b0175,0x00000000}},	//   chbe, snan_, ире_,
  { {0x7aeb001c,0x6ff3003b,0x98a30051,0x00000000}},	//   ņotā, lăce, ycję_,
  { {0xab5b00bd,0x78fa0063,0x44245e73,0x00000000}},	//   chüt, _לפתו, _cim_,
  { {0x80d30161,0x442439a2,0x6d415e74,0x00000000}},	//   _भेजे, _dim_, ybla,
  { {0x76ba01f9,0x4424004d,0x6e2b5e75,0x00000000}},	//   _המשפ, _eim_, _rugb,
  { {0x44245e76,0x7dc400cd,0x98b8003b,0x00000000}},	//   _fim_, _còsm, mbră_,
  { {0xffd5000d,0x98b4007d,0xfe450002,0x00000000}},	//   яўля, žeću_, пнио,
  { {0xee390001,0x60055e77,0xa15901dd,0x00000000}},	//   љно_, nómi, _газу_,
  { {0x7c240d9e,0x6d415e78,0x0dc90121,0x00000000}},	//   _siir, ubla, слой_,
  { {0xdca55599,0x7c24047f,0xab5b00bd,0x00000000}},	//   чани, _piir, rkün,
  { {0x6d41021f,0x2cb80137,0x9f400046,0x00000000}},	//   sbla, ärda_, _ðið_,
  { {0x27e0024a,0x7c240019,0x69ce1f51,0x00000000}},	//   viin_, _viir, thbe,
  { {0x8e080086,0xab5b00ea,0x27e000a4,0x00000000}},	//   _днів_, lkül, wiin_,
  { {0x27e01fee,0xa6db0014,0xf1b20041,0x00000000}},	//   tiin_, _meðu, ײסן_,
  { {0xd6da007e,0xa6db0046,0x273c004c,0x00000000}},	//   موزش_, _leðu, kánů_,
  { {0x27e0315d,0xab5b2680,0x16661850,0x00000000}},	// [c260] riin_, rhüt, явам,
  { {0x27e0024a,0x44245e79,0x1a9b0047,0x00000000}},	//   siin_, _sim_, _פייע,
  { {0xc32a0021,0x487a005a,0x7bc64aca,0x00000000}},	//   مكان_, _успя_, okku,
  { {0x61ea001f,0x7c2e017d,0x7bc65e7a,0x00000000}},	//   wnfl, íbri, nkku,
  { {0x5693000d,0x6d5c00ea,0xd3230121,0x00000000}},	//   _заўт, órak, ньши,
  { {0x44245e7b,0x3ea00078,0xab5b013d,0x00000000}},	//   _wim_, _šito_, ekül,
  { {0x443e00cd,0x44245e7c,0xf993009a,0x00000000}},	//   _ït_, _tim_, גרו_,
  { {0x6722001c,0x67360051,0x32070051,0x00000000}},	//   žoju, ncyj, alny_,
  { {0x9f5f017d,0xdb0600a5,0x76560050,0x00000000}},	//   cluí_, njkä, nsyy,
  { {0x3eb910b9,0x60e70026,0x76560072,0x00000000}},	//   ästa_, ármá, isyy,
  { {0x67360051,0x057700ff,0x31570041,0x00000000}},	//   kcyj, הגים_, _זיבן_,
  { {0x69de5e7d,0x76560072,0x6ff300dd,0x00000000}},	//   _ampe, ksyy, tăce,
  { {0xada61dd1,0x5fa90082,0xcfb7009a,0x00000000}},	//   _надл, कारल, _מלאי_,
  { {0x7bc6112c,0xa6db0014,0x64b5004c,0x00000000}},	//   akku, _meðt, _hřiš,
  { {0x29050014,0x5d7b0063,0x7d7b3997,0x00000000}},	//   æla_, _האוק, _הרוג,
  { {0x69de5e7e,0x24830150,0xab5b0058,0x00000000}},	//   _empe, _rpjm_, oküm,
  { {0x05870076,0xe6640fe2,0x7bcd0072,0x00000000}},	// [c270] зуем, етхо, _ilau,
  { {0x7bcd0026,0x67360022,0xd7bf0042,0x00000000}},	//   _hlau, acyj, _एकवच,
  { {0x7bcd5e7f,0x6fe80080,0x6b96005b,0x00000000}},	//   _klau, pěch, _yayg,
  { {0x69c7069f,0x248d0023,0x273c011b,0x00000000}},	//   lkje, _ņems_, tánů_,
  { {0xdb0d017d,0x9404005d,0xab5b004e,0x00000000}},	//   _doaç, روهه, vkül,
  { {0x69c72bab,0x7bcd032a,0x27ed007d,0x00000000}},	//   nkje, _llau, čenu_,
  { {0x8464005a,0xab5b1d2b,0x7bc60014,0x00000000}},	//   _пъте, tkül, ykku,
  { {0x43940076,0xee390815,0x33940085,0x00000000}},	//   _пасс, они_, _пасё,
  { {0x69c744a0,0x63a900ac,0xdce8008f,0x00000000}},	//   kkje, _inen, bedī,
  { {0xf1a40161,0x6b96005b,0xde160021,0x00000000}},	//   _गोपन, _sayg, وقيت_,
  { {0x69c70031,0x7bcd5e80,0x67360022,0x00000000}},	//   dkje, _blau, ycyj,
  { {0x63bb00e8,0x3b0a27b5,0x61e35e81,0x00000000}},	//   _joun, жемо_, linl,
  { {0x63a95e82,0xdce10051,0x7bc600fe,0x00000000}},	//   _mnen, dglą, rkku,
  { {0x63a40418,0x7bcd00e3,0x61e35e83,0x00000000}},	//   ķini, _elau, ninl,
  { {0x7bcd08c9,0xabf60065,0x6cd20021,0x00000000}},	//   _flau, _очищ, _لقوا,
  { {0xa6db0026,0x7bcd5e84,0x61e30a49,0x00000000}},	//   _neðs, _glau, hinl,
  { {0x61e301f7,0xfe790080,0x67360051,0x00000000}},	// [c280] kinl, ntů_, rcyj,
  { {0x044643f9,0xc7a90047,0x60c30066,0x00000000}},	//   дежн, ױב_, kynm,
  { {0x63bb0034,0x6d5c0025,0xdce8001c,0x00000000}},	//   _boun, órai, vedī,
  { {0xfe790080,0x63bb1cd8,0x83830076,0x00000000}},	//   ktů_, _coun, выше,
  { {0x61e30035,0xfe79004c,0x63a900a8,0x00000000}},	//   finl, jtů_, _dnen,
  { {0xdcf80006,0x61e3308e,0xcad70063,0x00000000}},	//   _gavė, ginl, וונת_,
  { {0x63bb0034,0x64b50080,0xdce8001c,0x00000000}},	//   _foun, _přiš, redī,
  { {0xab5b004b,0xa6db0014,0x61e30168,0x00000000}},	//   tküm, _geðs, ainl,
  { {0x61e30058,0xd29b0085,0x41760c0a,0x00000000}},	//   binl, _нiбы, _يائس,
  { {0x60050014,0x63a90195,0xab5b07be,0x00000000}},	//   dómu, _znen, rküm,
  { {0x63bb0034,0x659b014e,0x61fd0026,0x00000000}},	//   _youn, קיטק, _ísla,
  { {0x20140051,0xaec609da,0x5457016e,0x00000000}},	//   ócić_, _обел, וסטן_,
  { {0x501b00b5,0x9f4d004d,0x69c704aa,0x00000000}},	//   _וואו, ließ_, tkje,
  { {0x7c66002a,0xc9840794,0x7c580044,0x00000000}},	//   _قابل, куси, _فلتر_,
  { {0x69c71609,0x91d90047,0xd7f50be6,0x00000000}},	//   rkje, פֿשפ, езвы,
  { {0x69c7076c,0x61e3005b,0x2d8c5e85,0x00000000}},	//   skje, zinl, lede_,
  { {0x63bb0037,0x61e3048a,0x2d8c006f,0x00000000}},	// [c290] _roun, yinl, oede_,
  { {0x9e77014e,0x63bb2cf0,0xaa88007e,0x00000000}},	//   וגמה_, _soun, _کنیم_,
  { {0x63bb5e86,0x2d8c01f4,0xa4390054,0x00000000}},	//   _poun, iede_, їзду_,
  { {0xe667011c,0x2d8c5e87,0x07350047,0x00000000}},	//   _отго, hede_, _ראָם_,
  { {0xa2940086,0x07a4000d,0xfe790080,0x00000000}},	//   каці, _раўн, xtů_,
  { {0x63bb0034,0x40951857,0x2d8c5e88,0x00000000}},	//   _woun, ерит, jede_,
  { {0x2d8c5e89,0x7055007e,0x63bb1806,0x00000000}},	//   dede_, رنظا, _toun,
  { {0x61e35e8a,0x63a90359,0x60c3002b,0x00000000}},	//   sinl, _unen, rynm,
  { {0x2ec90053,0x997d008f,0xa3be0042,0x00000000}},	//   िनेत, māņu_, ेसर_,
  { {0x2d8c5e8b,0xc6920063,0x1c450376,0x00000000}},	//   gede_, נאי_, нном,
  { {0xfe790080,0x1d940085,0x44310022,0x00000000}},	//   stů_, трыё, _juz_,
  { {0xf044000d,0xdcfa004c,0xfe79004c,0x00000000}},	//   _рэфо, letě, ptů_,
  { {0x4ae0016a,0x443106b2,0x5ac7137a,0x00000000}},	//   _पेशव, _luz_, елям_,
  { {0xf2d256e8,0x395e0164,0x2d8c5e8c,0x00000000}},	//   נעם_, ûts_, cede_,
  { {0x3eb5003b,0xdca20062,0xdb1d0014,0x00000000}},	//   ţetă_, _бащи, rksá,
  { {0xed160041,0x9f91013d,0xb86500de,0x00000000}},	//   _אַחת_, _báé_, ضافو,
  { {0x6b84002c,0x443100dd,0x7e7b5e8d,0x00000000}},	// [c2a0] _ibig, _auz_, ntup,
  { {0x44310058,0x24f60727,0xddc20022,0x00000000}},	//   _buz_, нчер, _zwoł,
  { {0x7e7b004b,0x8ca20053,0x29370041,0x00000000}},	//   htup, गियो, _ראטן_,
  { {0xe9f9001b,0x78ad0080,0xe3ba000d,0x00000000}},	//   _trả_, ňová, ябе_,
  { {0xf2061fa5,0x3d060053,0x2d8c2d12,0x00000000}},	//   няко, _सुने_, yede_,
  { {0xcb1300b5,0x27ff02e2,0x7644132d,0x00000000}},	//   אלד_, čune_, mpiy,
  { {0x6b84004d,0x4fc65e8e,0x21570021,0x00000000}},	//   _obig, еспа, رجوع_,
  { {0x2d8c002c,0x444418b9,0xf8b30063,0x00000000}},	//   wede_, mp_, רשה_,
  { {0x44445e8f,0x3ea20026,0x7e7b00a4,0x00000000}},	//   lp_, íkt_, gtup,
  { {0x2d8c02dd,0x63a4001c,0x81a50021,0x00000000}},	//   uede_, ķinu, _لحمل,
  { {0x2d8c02ab,0x9bd50086,0x6aa45e90,0x00000000}},	//   rede_, вжні, _arif,
  { {0x2d8c0198,0x6aa40185,0x44445e91,0x00000000}},	//   sede_, _brif, ip_,
  { {0x5a340612,0x2d8c5e92,0x5fbb0063,0x00000000}},	//   лнят, pede_, _מצאנ,
  { {0x6aa406f1,0x7dcd0014,0x6da30092,0x00000000}},	//   _drif, _húsn, _биља,
  { {0x4444006f,0x6aa45e93,0x0db70044,0x00000000}},	//   jp_, _erif, _ساوث_,
  { {0x6d480078,0xf7940085,0x44442db3,0x00000000}},	//   lbda, ласэ, dp_,
  { {0x645c0164,0xb9080053,0x44442f7b,0x00000000}},	// [c2b0] _avri, _मे_, ep_,
  { {0x6b840022,0x6b9d05a5,0xc7cb008d,0x00000000}},	//   _zbig, ldsg, _diêị,
  { {0x9964000d,0x98b80006,0x89dc0063,0x00000000}},	//   _стыл, darė_, _מחזי,
  { {0x6b9d5e94,0xdb1d01e1,0xf8b6089e,0x00000000}},	//   ndsg, rksæ, _ספרי_,
  { {0x7d0a0026,0x07560063,0xab5b004d,0x00000000}},	//   _lyfs, _בסרט_, rküh,
  { {0xc0e506cb,0x44440089,0x44310058,0x00000000}},	//   колк, bp_, _tuz_,
  { {0x997d001c,0xe1f000f2,0x9f5f006c,0x00000000}},	//   pāņu_, حسن_, loué_,
  { {0x6b9d1244,0x7e7b5e95,0xe425007e,0x00000000}},	//   jdsg, ttup, _شکاي,
  { {0x3f8d00cd,0x644518b9,0x62350888,0x00000000}},	//   reeu_, lphi, _резу,
  { {0x6b8401f4,0x6445509a,0x30850044,0x00000000}},	//   _sbig, ophi, _للطف,
  { {0xbebd0006,0x9f5f0003,0xcb6a5e96,0x00000000}},	//   ncūz, houé_, мане_,
  { {0x6aa4001f,0x799c00a3,0x5ea50044,0x00000000}},	//   _prif, wdrw, _لمصل,
  { {0x798e002b,0x6ec4002a,0x3af60054,0x00000000}},	//   tebw, _متوق, тянс,
  { {0xdce10051,0x6d5c130c,0x27e20150,0x00000000}},	//   zglę, órat, _smkn_,
  { {0x38c8007e,0x7e69080f,0xdd8e0021,0x00000000}},	//   راسی_, lrep, _ذوي_,
  { {0x6fde001c,0x6aa45e97,0x798e002b,0x00000000}},	//   tūci, _trif, sebw,
  { {0x78a50146,0x200d003b,0x7e690efe,0x00000000}},	// [c2c0] _erhv, ilei_, nrep,
  { {0x08c62377,0x69d505df,0xc7cb0013,0x00000000}},	//   _абон, chze, _viêị,
  { {0x44441f7d,0x39585e98,0x200d23a8,0x00000000}},	//   up_, mars_, klei_,
  { {0x39585e99,0x44442f7b,0xc7cb008d,0x00000000}},	//   lars_, rp_, _tiêị,
  { {0x98b80078,0x9f5f006c,0x44443946,0x00000000}},	//   tarė_, coué_, sp_,
  { {0x44441e79,0xdddb001c,0x7e695e9a,0x00000000}},	//   pp_, lruņ, drep,
  { {0xb0570021,0xd01a0caa,0x645c3423,0x00000000}},	//   نشيط_, мфи_, _uvri,
  { {0x200d5e9b,0x27f25e9c,0x28ba0042,0x00000000}},	//   glei_, nnyn_, _उपनि,
  { {0x8fa300e1,0x7e695e9d,0xb226195a,0x00000000}},	//   рање, grep, _амал,
  { {0x22463025,0x27010013,0x64430139,0x00000000}},	//   mpok_, ỗng_, ínig,
  { {0x7f860021,0x6d480078,0xcf8f005e,0x00000000}},	//   _للان, rbda, _кј_,
  { {0x39580034,0x7e6936b3,0xe9920023,0x00000000}},	//   ears_, brep, _īkšķ,
  { {0x4ae4000d,0x6031008f,0x6b9d13e5,0x00000000}},	//   аўра, _rāmi, rdsg,
  { {0x9f5f0003,0x27f2081c,0x39585e9e,0x00000000}},	//   voué_, enyn_, gars_,
  { {0xd90f006a,0x61ed0164,0xf8072363,0x00000000}},	//   تید_, éali, вчан,
  { {0x2d9c5e9f,0x20045ea0,0x2d9e5ea1,0x00000000}},	//   _have_, nomi_, ldte_,
  { {0x2b593df6,0x395833b5,0xa3b60042,0x00000000}},	// [c2d0] masc_, bars_, जान_,
  { {0x7c2d36b2,0x2d9e3149,0x68ee0025,0x00000000}},	//   _hiar, ndte_, ándá,
  { {0x7c2d0035,0x96080088,0x3f860080,0x00000000}},	//   _kiar, тэта_, _obou_,
  { {0xdb040016,0x2d9c5ea2,0x2b590025,0x00000000}},	//   _uniã, _lave_, nasc_,
  { {0x20041b74,0x9647000d,0x27e95ea3,0x00000000}},	//   domi_, _шэнд, mian_,
  { {0x2d9c22bf,0x2d9e3386,0x6ff3003b,0x00000000}},	//   _nave_, jdte_, tăco,
  { {0x7dcd0066,0xa4d50054,0x2054082d,0x00000000}},	//   _súso, _сові, атыр,
  { {0xc0c80001,0x2d9e0179,0x7e695ea4,0x00000000}},	//   ђује_, edte_, trep,
  { {0xa2f5000d,0x2d9c007d,0x7dcd0014,0x00000000}},	//   _спач, _bave_, _fúsl,
  { {0x7bd6001c,0xb5fb004a,0x7e693a25,0x00000000}},	//   īzum, _uvád, rrep,
  { {0x27e908f0,0x7c2d0397,0x1bea0980,0x00000000}},	//   kian_, _biar, едни_,
  { {0x27e90974,0x442d00eb,0xeb970121,0x00000000}},	//   jian_, _jie_, гию_,
  { {0xd37a00b5,0x7c2d5ea5,0x27e95d47,0x00000000}},	//   ערשט, _diar, dian_,
  { {0x2d9c0037,0xe29f0026,0x442d5ea6,0x00000000}},	//   _gave_, _áðu_, _lie_,
  { {0xb5fb00ea,0x66050089,0x7c2d053c,0x00000000}},	//   _ováb, dohk, _fiar,
  { {0x27e9014f,0x7c2d051e,0xeb9a000a,0x00000000}},	//   gian_, _giar, _чии_,
  { {0xe61a05f9,0x27f200f1,0xfaa612a5,0x00000000}},	// [c2e0] еда_, rnyn_, _сапо,
  { {0x9f4403b2,0x27ff06bb,0x7c2d5ea7,0x00000000}},	//   rimé_, čuna_, _ziar,
  { {0xdd5600b5,0x27e95ea8,0xdce3005b,0x00000000}},	//   רבעט_, bian_, _kanı,
  { {0x7c3e0164,0x28970063,0x69ce0760,0x00000000}},	//   _épre, _עדכן_, lkbe,
  { {0x442d5ea9,0x41e6126b,0x799e00a4,0x00000000}},	//   _die_, ліка, _kapw,
  { {0x442d021f,0xab5b41f7,0x69ce5eaa,0x00000000}},	//   _eie_, lküt, nkbe,
  { {0x442d2170,0x94790001,0x20045eab,0x00000000}},	//   _fie_, _исту_, tomi_,
  { {0xaa860512,0x09d10053,0x442d431b,0x00000000}},	//   _zvýš, _हत्य, _gie_,
  { {0x733b00b5,0x7c2d0025,0x141b00b5,0x00000000}},	//   _װעבס, _riar, _טולב,
  { {0x442d02b0,0xc6930063,0x5d54026b,0x00000000}},	//   _zie_, צאת_, шкот,
  { {0x645e4b29,0x7c2d5eac,0x2d9e0066,0x00000000}},	//   nspi, _piar, rdte_,
  { {0x2d9c1568,0x27e95209,0x69ce4685,0x00000000}},	//   _wave_, xian_, ekbe,
  { {0xdce3005b,0xdee3018e,0x7c2d5ead,0x00000000}},	//   _danı, _лоци, _viar,
  { {0x26c90035,0x27e90c5e,0x7c2d0051,0x00000000}},	//   vyao_, wian_, _wiar,
  { {0x248d0117,0x27e94928,0x6d5a2983,0x00000000}},	//   _ćemo_, tian_, mata,
  { {0x645e5eae,0x6d5a53b8,0x69ce0c5f,0x00000000}},	//   dspi, lata, akbe,
  { {0x27e95eaf,0x645e5eb0,0x442d5eb1,0x00000000}},	// [c2f0] rian_, espi, _rie_,
  { {0x442d0cd4,0x15150088,0x3eb901a5,0x00000000}},	//   _sie_, адзя, ästi_,
  { {0xdce301f7,0x442d356b,0x27e915a8,0x00000000}},	//   _yanı, _pie_, pian_,
  { {0x7bcf00ac,0x6d5a0231,0xa3df0053,0x00000000}},	//   nkcu, hata, धों_,
  { {0x6d5a0645,0x442d5eb2,0x49b8007e,0x00000000}},	//   kata, _vie_, _شاید_,
  { {0x6a6c0026,0x442d135e,0x6d5a5eb3,0x00000000}},	//   _höfð, _wie_, jata,
  { {0x7d1c007a,0x31580021,0x442d5eb4,0x00000000}},	//   ýrsl, اجهة_, _tie_,
  { {0x6d5a18ac,0xbfc50239,0x9e65341e,0x00000000}},	//   eata, рбик, авид,
  { {0x6d5a5eb5,0x8db501dd,0x4ed5012c,0x00000000}},	//   fata, асні, рюйт,
  { {0xdce3005b,0x0d822ad0,0x629b0078,0x00000000}},	//   _sanı, ольн, _isuo,
  { {0x32070034,0x5f95049f,0x7dcd0046,0x00000000}},	//   mony_, _виет, _húsk,
  { {0x32070886,0x6d5a0213,0x7dcd0066,0x00000000}},	//   lony_, aata, _kúsk,
  { {0x6d5a0357,0xbf34005d,0x4afa0085,0x00000000}},	//   bata, _ارمغ, тэня_,
  { {0xef18000d,0x6d5a402e,0x32360041,0x00000000}},	//   _смі_, cata, יטשן_,
  { {0xdce301f7,0x69ce5eb6,0x9836000d,0x00000000}},	//   _tanı, rkbe, рэгі,
  { {0x645e5eb7,0x32075eb8,0x57460a55,0x00000000}},	//   vspi, hony_, рнаб,
  { {0xab5b0058,0x7bd60d7c,0xd6cf002a,0x00000000}},	// [c300] rküt, _ilyu, وقف_,
  { {0x7bc40019,0xd9460001,0xe8ca0002,0x00000000}},	//   _hoiu, _њени, _агол_,
  { {0x645e5eb9,0xab5b0075,0x00000000,0x00000000}},	//   uspi, mkür,   ,
  { {0x6d5a00ea,0x07a60001,0x6e3b00ac,0x00000000}},	//   zata, _тамн, kqub,
  { {0x6d5a1c98,0x61ea005b,0x98b10022,0x00000000}},	//   yata, tifl, rczą_,
  { {0x20660001,0x6abb00bd,0x644312c7,0x00000000}},	//   ађив, äufi, ínic,
  { {0x6d5a5eba,0x61ea5ebb,0xd139046e,0x00000000}},	//   vata, rifl, ухі_,
  { {0x6d5a2323,0xbfa70076,0x201d001f,0x00000000}},	//   wata, атье_, _chwi_,
  { {0x443801e3,0xab5b005b,0x6d5a5ebc,0x00000000}},	//   _hur_, kkür, tata,
  { {0x63a046cc,0x61ed0025,0x6d5a0150,0x00000000}},	//   _hamn, éalt, uata,
  { {0xa3ab0235,0xf1c200eb,0x4c94005a,0x00000000}},	//   _कोड_, rašą_, щинс,
  { {0x2d85001f,0x6d5a06e1,0x62825ebd,0x00000000}},	//   afle_, sata, otoo,
  { {0x0a6b005a,0x6d5a1fff,0x62825ebe,0x00000000}},	//   ърни_, pata, ntoo,
  { {0x44380cfc,0x63a05ebf,0xa2a70053,0x00000000}},	//   _our_, _lamn, चित्,
  { {0x6d58003d,0x44385ec0,0x62820072,0x00000000}},	//   _ieva, _nur_, htoo,
  { {0x63a2000f,0x63a05ec1,0x78a800b9,0x00000000}},	//   jdon, _namn, ædva,
  { {0x6d580019,0x63a2001f,0xab5b1013,0x00000000}},	// [c310] _keva, ddon, sküs,
  { {0x63a2051e,0x6d58007d,0xb9950021,0x00000000}},	//   edon, _jeva, _الدب,
  { {0x44380027,0xd49b011c,0x8ca90053,0x00000000}},	//   _cur_, ъра_, टियो,
  { {0xb367005a,0x6d585ec2,0x69c55ec3,0x00000000}},	//   ръжк, _leva, _hohe,
  { {0x2d85001f,0x69c55a59,0x66640062,0x00000000}},	//   yfle_, _kohe, _мърз,
  { {0x7c3803b2,0x79950035,0x6d583c3e,0x00000000}},	//   _ouvr, nezw, _neva,
  { {0x32070045,0x44380027,0xdcfa001c,0x00000000}},	//   rony_, _gur_, ietē,
  { {0x284a0047,0xa13c008f,0x63a25ec4,0x00000000}},	//   נעפּ, _raķe, cdon,
  { {0x44380199,0x8e090055,0x79950035,0x00000000}},	//   _zur_, лнив_, kezw,
  { {0x6d5801f7,0x7e6200c2,0x7bc45ec5,0x00000000}},	//   _ceva, _dvop, _soiu,
  { {0x6d585ec6,0x5f77002a,0x2d850058,0x00000000}},	//   _deva, _ناشر, rfle_,
  { {0xe9f9001b,0x7dcd100f,0xeb9f000e,0x00000000}},	//   _trẻ_, _músi, dløs_,
  { {0xed4e5a73,0xada50091,0x69c55ec7,0x00000000}},	//   _но_, _галл, _bohe,
  { {0x6d5803a8,0x799505cc,0xceb20063,0x00000000}},	//   _geva, gezw, _מיד_,
  { {0xa3d7016a,0xab5b049c,0x63a25ec8,0x00000000}},	//   िसा_, rkür, ydon,
  { {0xdc3a0047,0xdc28008f,0xab5b0058,0x00000000}},	//   _געקר, rķēj, skür,
  { {0x44385ec9,0x6ff3003b,0xdcfa001c,0x00000000}},	// [c320] _sur_, găci, betē,
  { {0x63a05eca,0x6d412672,0x69c5002b,0x00000000}},	//   _samn, ncla, _gohe,
  { {0x69dc0025,0x443800e5,0x3636007e,0x00000000}},	//   mhre, _qur_, _گرجس,
  { {0x53e50086,0x62820bcf,0xd3790086,0x00000000}},	//   оціа, ttoo, ичі_,
  { {0x6d43001f,0x628220ea,0x6ff3003b,0x00000000}},	//   _ofna, utoo, căci,
  { {0x9f440025,0x6282015e,0x44385ecb,0x00000000}},	//   rimí_, rtoo, _tur_,
  { {0x44380173,0x63a01aa5,0x62825ecc,0x00000000}},	//   _uur_, _tamn, stoo,
  { {0x6d410529,0x6d585ecd,0x6d435ece,0x00000000}},	//   ecla, _seva, _afna,
  { {0x20d3001b,0x395a0250,0x66f80161,0x00000000}},	//   ại_, _oeps_, ंपिक_,
  { {0x44265ecf,0x9f910046,0xdd9a04f2,0x00000000}},	//   lmo_, _náæ_, уши_,
  { {0x69c50f40,0x44265ed0,0x5bb90062,0x00000000}},	//   _rohe, omo_, алня_,
  { {0x79950035,0xddc9000c,0x6d430014,0x00000000}},	//   wezw, pseş, _efna,
  { {0x7bdd0006,0x6d415ed1,0xddc0008f,0x00000000}},	//   ūruo, bcla, nsmū,
  { {0x2fc60173,0x69dc5ed2,0x44261e3d,0x00000000}},	//   _hoog_, ghre, hmo_,
  { {0x999a00ea,0x44265815,0xdcfa008f,0x00000000}},	//   _cipő_, kmo_, retē,
  { {0x69dc00bd,0x69c5004d,0x6ff3003b,0x00000000}},	//   ahre, _wohe, tăci,
  { {0xa3ac0161,0x6b8d00a4,0x69dc0139,0x00000000}},	// [c330] _औफ़_, _ibag, bhre,
  { {0x98a3005b,0x6ff3003b,0x44263182,0x00000000}},	//   sajı_, răci, emo_,
  { {0x0735005a,0x6aad0046,0x7339014b,0x00000000}},	//   _меню, _hraf, азер_,
  { {0xe3150138,0x6d41006d,0xedb50053,0x00000000}},	//   омењ, zcla, _अच्छ,
  { {0x290c004b,0x57270043,0xabfc009a,0x00000000}},	//   üdav_, _دردق, נהדר,
  { {0xd5bb000a,0x44265ed3,0x764d116d,0x00000000}},	//   _ссм_, amo_, mpay,
  { {0x6025000d,0x2fc60d1e,0x4426005f,0x00000000}},	//   одка, _boog_, bmo_,
  { {0x7a2000c7,0xfe450699,0x9f4d00ac,0x00000000}},	//   möte, онио, mieë_,
  { {0xee3608a6,0xee3900e1,0x9f4d00ac,0x00000000}},	//   оны_, јно_, lieë_,
  { {0x2708001b,0x27ed0080,0x6b8d5ed4,0x00000000}},	//   ởng_, čeny_, _abag,
  { {0x9f4d00ac,0x6aad5ed5,0x6d415ed6,0x00000000}},	//   nieë_, _araf, rcla,
  { {0x6d415ed7,0x2fc65ed8,0xab2a5ed9,0x00000000}},	//   scla, _goog_, иона_,
  { {0x6aad04bf,0x2b4d006d,0x69dc212f,0x00000000}},	//   _craf, ñeca_, thre,
  { {0x7bdd2422,0x44265eda,0x6aad5edb,0x00000000}},	//   ahsu, zmo_, _draf,
  { {0x44262626,0x98a300e2,0x475a0121,0x00000000}},	//   ymo_, мире, ирая_,
  { {0xe7370055,0x7bdd5edc,0x6aad000e,0x00000000}},	//   жет_, chsu, _fraf,
  { {0x764d002c,0x85ea0054,0x6aad5edd,0x00000000}},	// [c340] gpay, адав_, _graf,
  { {0x9f4d00ac,0xeb9f04aa,0x05660500,0x00000000}},	//   fieë_, lløp_, івен,
  { {0x9f4d00ac,0x44262c21,0x2456007e,0x00000000}},	//   gieë_, tmo_, زنشس,
  { {0x69c1004b,0xccf20063,0xe7320021,0x00000000}},	//   ölev, וכב_, _يصح_,
  { {0xa22a0905,0x25a3007d,0x44265ede,0x00000000}},	//   ажда_, _fajl_, rmo_,
  { {0x7d060045,0x44265edf,0x6fe80022,0x00000000}},	//   ększ, smo_, mści,
  { {0xd4670076,0x2fc600e8,0x30a30766,0x00000000}},	//   _мире_, _poog_, дрыв,
  { {0xef190045,0x6fe80051,0x6e660054,0x00000000}},	//   leży_, ości, отож,
  { {0x6fdc03b2,0x2fc61b35,0x2018008f,0x00000000}},	//   _néce, _voog_, ēri_,
  { {0x6b8d0290,0xeb9f00d1,0x69c810c8,0x00000000}},	//   _sbag, eløp_, ödel,
  { {0x9d140076,0xd5b80083,0xef19056c,0x00000000}},	//   ядоч, лiко, ieży_,
  { {0x6ff3003b,0x6fe80051,0x6aad5ee0,0x00000000}},	//   făcu, kści, _praf,
  { {0x6fe80045,0x64480164,0x764d0d99,0x00000000}},	//   jści, _édif, xpay,
  { {0x6fdc0164,0x3eb900c7,0x7c3e0164,0x00000000}},	//   _déce, åste_, _épro,
  { {0x6fe80051,0xe9190086,0x75e0009c,0x00000000}},	//   eści, сові_, _közf,
  { {0x7dcd0014,0xdddb0058,0x6aad5ee1,0x00000000}},	//   _dúsu, oruş, _traf,
  { {0xa3ab0053,0xf402000c,0x764d0089,0x00000000}},	// [c350] _कोष_, inţă_, upay,
  { {0x7a20045e,0x6443017d,0x764d0509,0x00000000}},	//   töte, ínio, rpay,
  { {0xd37100f2,0x84640062,0xdddb0023,0x00000000}},	//   فها_, дъче, ntuš,
  { {0x9f4d00e8,0xf3670086,0x3cfb0047,0x00000000}},	//   rieë_, ітен, סלאנ,
  { {0xd346007e,0xfbd40063,0x61452007,0x00000000}},	//   سیله_, ותף_, пела,
  { {0x9f4d00ac,0x1a9c0047,0xf402003b,0x00000000}},	//   pieë_, יידע, enţă_,
  { {0xdd1c0024,0xdcfa0078,0xf9580063,0x00000000}},	//   yšši, metė, חסות_,
  { {0xdcfa0078,0x78fc0063,0x403202d8,0x00000000}},	//   letė, ילופ, нејс,
  { {0xfe710021,0x51870fdc,0xaf35005d,0x00000000}},	//   ردة_, _мужа, يرکت,
  { {0x6fdc03b2,0xf402003b,0x11440044,0x00000000}},	//   _réce, anţă_, _يَقُ,
  { {0xcb0901d8,0x6fdc0003,0x6f021e9e,0x00000000}},	//   _על_, _séce, _exoc,
  { {0x2904005b,0x6fe80051,0xef190022,0x00000000}},	//   şmak_, yści, zeży_,
  { {0x7dcd0268,0x7d180024,0xdcfa0006,0x00000000}},	//   _búst, _časť, ketė,
  { {0xaec4000d,0xbea20cd6,0x00000000,0x00000000}},	//   _юбіл, _чашк,   ,
  { {0x291e00c7,0x6443004c,0x7bc00046,0x00000000}},	//   åta_, ínil, ömus,
  { {0xe89b005b,0x2d8200ea,0xe61f00be,0x00000000}},	//   şağı, őket_, _opôs_,
  { {0x75d3007e,0xddc9003b,0x7c240075,0x00000000}},	// [c360] کيلا, creţ, _ihir,
  { {0x690700ea,0x6fe80051,0xf5e50054,0x00000000}},	//   érdé, rści, мієм,
  { {0xb4d6016a,0x23b3007e,0xd910007e,0x00000000}},	//   िने_, کمنس, _شیر_,
  { {0xa3e60053,0xcc3a0041,0x93433371,0x00000000}},	//   यों_, צענט, енце,
  { {0x7413006a,0x6fd501c2,0x1ddb0042,0x00000000}},	//   روها, _václ, मघात,
  { {0x27e0002c,0xc297000d,0x91e311c7,0x00000000}},	//   lhin_, якіх_, ноче,
  { {0x02190088,0x7c24001f,0x76490058,0x00000000}},	//   ціць_, _ohir, _çeyr,
  { {0xdfd00032,0x27e024ca,0x28970063,0x00000000}},	//   ئية_, nhin_, פדפן_,
  { {0x44240199,0x27e0024a,0x5e83030b,0x00000000}},	//   _ihm_, ihin_, нуэз,
  { {0x27ff02e2,0x7c242422,0x3f5a0013,0x00000000}},	//   čuni_, _ahir, ẫu_,
  { {0x40560021,0x7dcd07a8,0x2b4d0331,0x00000000}},	//   _رئاس, _rúst, ñeco_,
  { {0x7dcd0024,0xddc9000c,0x4424004d,0x00000000}},	//   _súst, treţ, _jhm_,
  { {0x9b24000a,0x5af80085,0xbae50044,0x00000000}},	//   ефрл, зеяў_, ذكسي,
  { {0x3ea20026,0xadb800de,0x00000000,0x00000000}},	//   æktu_, _ذهبا_,   ,
  { {0x27e000bd,0x69d500bd,0xa8490593,0x00000000}},	//   fhin_, rkze, تلزم_,
  { {0x2d8c0ac8,0x1d1712cd,0xbd170063,0x00000000}},	//   lfde_, _מקור_, _מחוז_,
  { {0x2d8c00ca,0x69c1004b,0x96355ee2,0x00000000}},	// [c370] ofde_, öles, днац,
  { {0x06140055,0x44240150,0x27e05ee3,0x00000000}},	//   едую, _ahm_, ahin_,
  { {0xf8d10053,0x249901f3,0xd918236a,0x00000000}},	//   _हथिय, تناد_, _нью_,
  { {0x27e02494,0x23d40085,0xd8280e74,0x00000000}},	//   chin_, нцір, _ніяк_,
  { {0x46a4000d,0x59d10053,0xa2e4012c,0x00000000}},	//   _заўв, _सकार, ноїд,
  { {0x2d8c006f,0xe7d5005b,0x13080086,0x00000000}},	//   jfde_, _yığı, чній_,
  { {0xd5c50054,0x10a2076a,0x00000000,0x00000000}},	//   мiжн, вищн,   ,
  { {0x2d8c006f,0xe5340054,0x7ed50054,0x00000000}},	//   efde_, _чесь, діоч,
  { {0x236d00c2,0xc91a0053,0x52150121,0x00000000}},	//   _idej_, _धर्म_, _ждат,
  { {0x75e001f7,0x7c24077d,0x7dcd5ee4,0x00000000}},	//   _gözd, _shir, _rúss,
  { {0xddc9017f,0x2a690019,0x4424004d,0x00000000}},	//   greš, _avab_, _yhm_,
  { {0x30780044,0xf4f3012c,0x00000000,0x00000000}},	//   _رحمة_, ькiй_,   ,
  { {0xbea5000d,0xe7d50058,0xef1f004b,0x00000000}},	//   _цалк, _sığı, üüd_,
  { {0x75e0000f,0xdb0600ea,0x7c2400e5,0x00000000}},	//   _köze, ndké, _whir,
  { {0x27e00037,0x7e7b0026,0x7c24470d,0x00000000}},	//   thin_, luup, _thir,
  { {0x69c1004e,0x6ca40044,0x6d08009d,0x00000000}},	//   öler, _أصول, _מִפַ,
  { {0x27e000bd,0x7e7b0014,0x35ca005e,0x00000000}},	// [c380] rhin_, nuup, огао_,
  { {0x6fdc0164,0x27f2002b,0x44f6005d,0x00000000}},	//   _méca, siyn_, وساز,
  { {0xe73a33e7,0x799c001f,0x2fdd001f,0x00000000}},	//   _мен_, merw, _olwg_,
  { {0x799c00bd,0xd36f0021,0x7bc65ee5,0x00000000}},	//   lerw, لهم_, njku,
  { {0xddc908ea,0x91780013,0xfbd30149,0x00000000}},	//   zreš, _hởi_, כתא_,
  { {0x9f46004d,0x799c5ee6,0x7764008d,0x00000000}},	//   _bloß_, nerw, laix,
  { {0xe3660001,0x799c0051,0x753c0022,0x00000000}},	//   _окви, ierw, _igrz,
  { {0x776400cd,0x799c537f,0x7e7b0014,0x00000000}},	//   naix, herw, fuup,
  { {0x799c06aa,0xe246002a,0x2463013d,0x00000000}},	//   kerw, _آخري, _témá_,
  { {0x7dcd048e,0x6fdc3a4e,0xddc20051,0x00000000}},	//   _búsq, _déca, _stoł,
  { {0x75e0221e,0x05770063,0xdb0a027d,0x00000000}},	//   _közb, וגים_, čným,
  { {0x50650021,0x69de5ee7,0x645c00a3,0x00000000}},	//   _أطلق, _alpe, _mwri,
  { {0x44440013,0x799c2b09,0x753c0022,0x00000000}},	//   hq_, ferw, _ogrz,
  { {0x20140045,0x9178001b,0xa3ab0053,0x00000000}},	//   ścią_, _bởi_, _कोई_,
  { {0x29050058,0x37cb0131,0xda34030b,0x00000000}},	//   çla_, оѓам_, теры,
  { {0xdc2b007e,0x69de0b28,0xf773043e,0x00000000}},	//   _بسته_, _elpe, ضار_,
  { {0x644e003d,0x799c004d,0xd6db071f,0x00000000}},	// [c390] _atbi, berw, цтв_,
  { {0x645c001f,0x6b9d002b,0x4615005d,0x00000000}},	//   _bwri, lesg, روار,
  { {0x77640367,0x224d006f,0x645c002b,0x00000000}},	//   baix, _stek_, _cwri,
  { {0x64410164,0x94bf0053,0x77640858,0x00000000}},	//   _élim, _एपीआ, caix,
  { {0x5334000d,0x43740086,0x444404d1,0x00000000}},	//   вецт, туєт, aq_,
  { {0x7ff504de,0x27ff06bb,0x6fdc0164,0x00000000}},	//   کستا, čunu_, _réca,
  { {0x7985002b,0x63b800dd,0x44444819,0x00000000}},	//   _mchw, _şanţ, cq_,
  { {0x7e7b007a,0x799c0051,0x6d4a0399,0x00000000}},	//   tuup, zerw, _affa,
  { {0xcdf5026c,0x63bb14a9,0x6b9d0244,0x00000000}},	//   ечны, _inun, desg,
  { {0x22b80021,0x7e7b0137,0x7bdf5ee8,0x00000000}},	//   _تدفع_, ruup, _alqu,
  { {0x3ead00c3,0x63a90d69,0x799c0479,0x00000000}},	//   svet_, _kaen, verw,
  { {0x6d4a5ee9,0x799c5eea,0x7bcd5eeb,0x00000000}},	//   _effa, werw, _coau,
  { {0x4a43005a,0xe6a80080,0x63a93baf,0x00000000}},	//   лняв, _příš, _maen,
  { {0x63a90004,0x69c10019,0xdb0f00ea,0x00000000}},	//   _laen, ölep, ájáv,
  { {0x98aa005b,0x63bb0058,0x7e690730,0x00000000}},	//   tabı_, _onun, lsep,
  { {0x63a900c3,0x63bb0290,0xc7a324dc,0x00000000}},	//   _naen, _nnun, лиск,
  { {0xd7070184,0x7e695eec,0xf626005e,0x00000000}},	// [c3a0] енте_, nsep, едао,
  { {0x98aa01f7,0x63bb5eed,0x7e695eee,0x00000000}},	//   sabı_, _anun, isep,
  { {0x63a95eef,0xaa090044,0xddc90022,0x00000000}},	//   _baen, _تزيل_, opeł,
  { {0x6fd506b2,0xd3a50086,0xd372007e,0x00000000}},	//   _fáci, кріп, اهش_,
  { {0x79850185,0xdbc70004,0xa3e60053,0x00000000}},	//   _ychw, _tööl, योग_,
  { {0x645c001f,0x63bb3af2,0x68050078,0x00000000}},	//   _twri, _enun, mėda,
  { {0x644e00c7,0x68050006,0x7e690150,0x00000000}},	//   _utbi, lėda, esep,
  { {0x7c3e0003,0x28b30042,0x63a924bf,0x00000000}},	//   _épri, ुमति, _gaen,
  { {0x68050078,0x9c7c00c2,0x43750092,0x00000000}},	//   nėda, azčl, _јуст,
  { {0x63a900c3,0x216a0094,0x71ea0043,0x00000000}},	//   _zaen, _хижи_, _عفاف_,
  { {0x67fb00fe,0x63a90035,0x6d48001c,0x00000000}},	//   näjä, _yaen, rcda,
  { {0x79850199,0x68050078,0x7bdf0078,0x00000000}},	//   _schw, kėda, _įpus,
  { {0x6b9d442b,0xdd92005d,0xd00f04a0,0x00000000}},	//   resg, _موش_, _الن_,
  { {0x68050006,0x3ea60072,0xec6a04f2,0x00000000}},	//   dėda, _isot_, _ерик_,
  { {0x2d9e5ef0,0x4e170063,0xdca302d8,0x00000000}},	//   mete_, _רחוב_, _баји,
  { {0x2d9e5ef1,0x6fdc0003,0x7c830320,0x00000000}},	//   lete_, _méco, _суше,
  { {0x4735000d,0x788a017d,0x63a900a3,0x00000000}},	// [c3b0] тнас, têvã, _raen,
  { {0xaa64005a,0x395401c2,0x26c7007d,0x00000000}},	//   _стък, časí_, ćno_,
  { {0x75e001f7,0xf1bf008b,0xe1f1007e,0x00000000}},	//   _sözc, _đá_, یست_,
  { {0xe8d6014e,0x628b0c29,0x2d9e5ef2,0x00000000}},	//   _יותר_, ttgo, hete_,
  { {0x63a90019,0x2d9e5ef3,0x36d4079f,0x00000000}},	//   _vaen, kete_, _бояр,
  { {0x628b04aa,0x2289013d,0xddc00078,0x00000000}},	//   rtgo, rúk_, irmų,
  { {0x2d9e5ef4,0x91e20065,0xddc90022,0x00000000}},	//   dete_, роще, ypeł,
  { {0x6fdc03b2,0x7e690019,0x63bb5ef5,0x00000000}},	//   _déco, tsep, _unun,
  { {0x6fdc06b2,0x2d9e5ef6,0xed590062,0x00000000}},	//   _técn, fete_, моп_,
  { {0x6fdc0003,0x7e695ef7,0x2d9e5ef8,0x00000000}},	//   _féco, rsep, gete_,
  { {0x2b4b0509,0x3ea6008f,0x2d8b0022,0x00000000}},	//   fccc_, _esot_, ęce_,
  { {0x3167004d,0x7e69004b,0xe73f0013,0x00000000}},	//   lanz_, psep, _ngõ_,
  { {0x9f910026,0x2d9e5ef9,0xdce100a8,0x00000000}},	//   _káþ_, bete_, malč,
  { {0x2d9e3e3b,0xc27a0063,0x3167051f,0x00000000}},	//   cete_, ורשי, nanz_,
  { {0x98b8001c,0x7c84005e,0xfce52377,0x00000000}},	//   mbrī_, _буње, _шоко,
  { {0x9f4a0075,0xa8030094,0xbc7a009d,0x00000000}},	//   şköy_, азсл, _חנקת,
  { {0x3667011c,0x14c8007e,0x81bc008f,0x00000000}},	// [c3c0] като_, کهای_, _shēm,
  { {0x2fcf5efa,0x67fb024a,0x680500eb,0x00000000}},	//   _logg_, täjä, rėda,
  { {0x80a10053,0xdce100c2,0x69dc5efb,0x00000000}},	//   _कैले, kalč, mkre,
  { {0xdb041a0a,0x6fdc17fb,0xc5e90063,0x00000000}},	//   _unió, _réco, חד_,
  { {0x6fdc0164,0x2d9e005b,0x69dc5efc,0x00000000}},	//   _décl, yete_, okre,
  { {0x76560072,0xdce80066,0xa13c008f,0x00000000}},	//   mpyy, vedľ, _kaķi,
  { {0x75e0005b,0x69dc01e1,0x2d9e4eeb,0x00000000}},	//   _göza, ikre, vete_,
  { {0x27e20089,0x08770047,0xdce10066,0x00000000}},	//   _jlkn_, דעקט_, galč,
  { {0x69dc04aa,0x2d9e5efd,0x8e14005e,0x00000000}},	//   kkre, tete_, лдиц,
  { {0xdcfa001c,0xf77f005b,0x69dc006f,0x00000000}},	//   egtā, _ilçe_, jkre,
  { {0xdfd2006a,0x2d9e5efe,0x69dc5eff,0x00000000}},	//   _پيش_, rete_, dkre,
  { {0x8fa6000a,0x40ab007e,0x2d9e0d37,0x00000000}},	//   _јаде, _زخمی_, sete_,
  { {0x6ab6001f,0x929d0022,0x2d9e5f00,0x00000000}},	//   _cryf, _były, pete_,
  { {0x6ab63e7e,0xc3330063,0xacf30043,0x00000000}},	//   _dryf, יור_, اسیت,
  { {0xd83b000d,0x39e80121,0xab5d0047,0x00000000}},	//   дэа_, тьян_, ראַכן_,
  { {0x58d40086,0x6d5a2106,0x69dc0022,0x00000000}},	//   шост, lbta, akre,
  { {0x66e4000a,0x6fdc0164,0x6ab65f01,0x00000000}},	// [c3d0] аоѓа, _récl, _gryf,
  { {0x69dc5f02,0xa3e50042,0x060900de,0x00000000}},	//   ckre, _फतह_, رْضٌ_,
  { {0xdb1d0019,0x316700bd,0x61f80130,0x00000000}},	//   rksõ, vanz_, divl,
  { {0x2458000d,0x3167004d,0x44141cdf,0x00000000}},	//   таць_, wanz_, афіт,
  { {0x316700bd,0xe3b0007e,0xdce100c2,0x00000000}},	//   tanz_, ترل_, valč,
  { {0x6fd50e7c,0x20060072,0xdce1008f,0x00000000}},	//   _láct, _ajoi_, uglī,
  { {0x3167004d,0x2edb0053,0x518420fb,0x00000000}},	//   ranz_, यन्त, руча,
  { {0xfe790080,0x7bdd006f,0xa3ab0053,0x00000000}},	//   trů_, jksu, _कोच_,
  { {0xee39011c,0x2ca700a4,0xa3d40121,0x00000000}},	//   нни_, _ssnd_, _тотч,
  { {0x2b9e0013,0x7bdd1c6a,0xd1b804a0,0x00000000}},	//   _ắc_, eksu, _لاما_,
  { {0xd0840076,0x90550785,0x9f9101c8,0x00000000}},	//   _вычи, _свец, _záý_,
  { {0x61e60006,0x50da0047,0x6ab6002b,0x00000000}},	//   _įkli, _אקעא, _pryf,
  { {0xf4120047,0xadbd0054,0x6d5a087b,0x00000000}},	//   מפט_, _надi, bbta,
  { {0x69dc0006,0x6fd5017d,0x7bdd5f03,0x00000000}},	//   ukre, _vácu, aksu,
  { {0x27e20089,0x77960002,0x69dc5f04,0x00000000}},	//   _plkn_, лјац, rkre,
  { {0x69dc0844,0x7e7b5f05,0x6ab61780,0x00000000}},	//   skre, orup, _tryf,
  { {0x2d855f06,0x25a100bd,0x562a01d5,0x00000000}},	// [c3e0] ogle_, fehl_, ежам_,
  { {0xe9a60001,0x2d850c2e,0xb0b30042,0x00000000}},	//   _саоп, ngle_, ंटाग,
  { {0x765600fe,0x629b00fe,0x201f0078,0x00000000}},	//   spyy, _apuo, klui_,
  { {0xb5fb004c,0x130a007f,0x1d160041,0x00000000}},	//   _svát, нней_, אקער_,
  { {0x61f85f07,0xf6d60085,0xddc90023,0x00000000}},	//   tivl, _сіня, mpeņ,
  { {0xf1260086,0xd9f60053,0x201f5f08,0x00000000}},	//   льйо, ुचित_, elui_,
  { {0x7e7b003e,0x660b00ea,0x361b0063,0x00000000}},	//   erup, égke, _נולד,
  { {0x3eca005e,0x4fd4137a,0xdfa60044,0x00000000}},	//   ећом_, ржит, احثي,
  { {0x63a2077d,0x7306066c,0x7e7b28d7,0x00000000}},	//   meon, _спаз, grup,
  { {0x211a0021,0x2d855f09,0x2713008b,0x00000000}},	//   _كتاب_, ggle_, ệng_,
  { {0xdb04007a,0x7c660021,0xfe6f007e,0x00000000}},	//   _snið, داخل, يدی_,
  { {0x201f0016,0x9178008d,0x7dd600dd,0x00000000}},	//   clui_, _hời_, _râsu,
  { {0x7bdd08e9,0x7dd6003b,0x7e5614b4,0x00000000}},	//   rksu, _bâst, _стец,
  { {0x3eb900b9,0x3da30062,0xf402003b,0x00000000}},	//   æste_, _гръб, liţă_,
  { {0x9178001b,0xe9190086,0x6fd505d5,0x00000000}},	//   _mời_, тові_, _táct,
  { {0xb8860016,0x9178001b,0xf402003b,0x00000000}},	//   _suíç, _lời_, niţă_,
  { {0x311b0161,0x7c2d00a4,0xdab90021,0x00000000}},	// [c3f0] _पुनः_, _ihar, _شهدت_,
  { {0xf402003b,0x1efb0041,0x6805005f,0x00000000}},	//   hiţă_, גלמע, pėdo,
  { {0x7c2d2970,0xd371009e,0xd49b066e,0x00000000}},	//   _khar, قها_, эра_,
  { {0x63a246fb,0x7c2d5f0a,0x836704a0,0x00000000}},	//   geon, _jhar, ادال,
  { {0x27e90025,0x75e000ea,0xd2350062,0x00000000}},	//   mhan_, _közl, андъ,
  { {0x27e900bb,0x7e7b005b,0x867a0063,0x00000000}},	//   lhan_, vrup, _ברשו,
  { {0xc0e50245,0x225800c3,0x91780013,0x00000000}},	//   ройк, _črke_, _dời_,
  { {0x201f000c,0x27e95f0b,0x7c2d002b,0x00000000}},	//   ului_, nhan_, _nhar,
  { {0x6fdc0164,0xdce1008f,0x442d0050,0x00000000}},	//   _méch, dalā, _ihe_,
  { {0x64470009,0xfaff5f0c,0x2d850003,0x00000000}},	//   _kuji, raël_, ugle_,
  { {0x7c2d2ae5,0x27e95f0d,0x7e7b00e5,0x00000000}},	//   _bhar, khan_, srup,
  { {0x644725e5,0x7c2d0ea6,0x7f8401fb,0x00000000}},	//   _muji, _char, _هلمن,
  { {0x27e900f3,0xfc49008b,0x2c4c0080,0x00000000}},	//   dhan_, _bậc_, _věda_,
  { {0x442d03d9,0x76460150,0x65670080,0x00000000}},	//   _lhe_, _ruky, _nejh,
  { {0x7a2000bd,0x67e30019,0x291e0026,0x00000000}},	//   nöti, _sõja, æta_,
  { {0x9178001b,0x38a7001f,0x2fcd007d,0x00000000}},	//   _mới_, _dŵr_, njeg_,

  { {0x6fdc0164,0x64470078,0x6455008f,0x00000000}},	// [c400] _déch, _auji, _atzi,
  { {0x75e0005b,0x27e91169,0xd5af01f3,0x00000000}},	//   _gözl, ahan_, وفق_,
  { {0x27e9002c,0x76630080,0xb97b31d0,0x00000000}},	//   bhan_, _čtyř, _בניי,
  { {0x442d104f,0x443f5f0e,0x64480003,0x00000000}},	//   _che_, _ciu_, _édim,
  { {0x31c6011c,0x443f0268,0x63a25f0f,0x00000000}},	//   искв, _diu_, reon,
  { {0x27e0024a,0x442d00bd,0x6447193b,0x00000000}},	//   lkin_, _ehe_, _fuji,
  { {0x69ce006f,0x91780013,0x443f0a37,0x00000000}},	//   ijbe, _vời_, _fiu_,
  { {0x27e0024a,0x443f3dda,0x987b0047,0x00000000}},	//   nkin_, _giu_, דאקט,
  { {0xf402003b,0xdcea0058,0xd007005e,0x00000000}},	//   riţă_, _ınız, јење_,
  { {0x7c2d1269,0x2bb30013,0xe0da0002,0x00000000}},	//   _shar, _ệc_, _ивз_,
  { {0x27e05f10,0x64400fe3,0xa5b70047,0x00000000}},	//   kkin_, _kimi, בליק_,
  { {0x75e0005b,0x64405f11,0xaa590da2,0x00000000}},	//   _sözl, _jimi, лиму_,
  { {0x6d5c005b,0x6fdc0003,0x7e54002a,0x00000000}},	//   ırab, _réch, _انتص,
  { {0x6fdc0003,0x9f910014,0x7c2d0af9,0x00000000}},	//   _séch, _háð_, _whar,
  { {0x9848011c,0x6c840032,0x7c2d139d,0x00000000}},	//   ията_, _العم, _thar,
  { {0x7c2d0035,0x27e920af,0x27e01320,0x00000000}},	//   _uhar, uhan_, gkin_,
  { {0x443f0268,0x27e915c2,0x6fdc1090,0x00000000}},	// [c410] _riu_, rhan_, _céci,
  { {0x442d03e9,0x6fdc249d,0xef110047,0x00000000}},	//   _she_, _déci, פּן_,
  { {0xf8b1006a,0xb4e1016a,0x443f0290,0x00000000}},	//   _عکس_, धने_, _piu_,
  { {0x9f910026,0x98a1001b,0x64402f58,0x00000000}},	//   _náð_, _nghĩ_, _cimi,
  { {0x443f5f12,0x6440160d,0x479a0063,0x00000000}},	//   _viu_, _dimi, _גירס,
  { {0x64475f13,0x7a2000fe,0xdcef004c,0x00000000}},	//   _tuji, töti, _řečn,
  { {0x442d0034,0xd178000d,0x7dcd013d,0x00000000}},	//   _the_, рсіі_, _túsz,
  { {0x9178001b,0x64405f14,0x6aad004b,0x00000000}},	//   _với_, _gimi, _osaf,
  { {0x3eb95d44,0xfe710044,0xa1590201,0x00000000}},	//   íst_, أدب_, _базу_,
  { {0x9178001b,0x3f77008b,0x61ea004d,0x00000000}},	//   _tới_, ểu_, chfl,
  { {0x64411a05,0xd4790047,0xdca5170a,0x00000000}},	//   _élis, װאָל, щани,
  { {0xb035005e,0x4e95005d,0xfeb90044,0x00000000}},	//   _унеш, _هشتر, _ماتت_,
  { {0xddc900b2,0xdfb800f2,0x6e940cdb,0x00000000}},	//   mrež, _خالص_, _мицу,
  { {0x6d4300bb,0x6fdc0164,0x6d5c005b,0x00000000}},	//   _ugna, _réci, ırac,
  { {0x27e0077e,0x48e30062,0x32072c17,0x00000000}},	//   tkin_, порв, inny_,
  { {0x30da00b5,0x999a0080,0x47590121,0x00000000}},	//   אַמע, _tipů_, ируя_,
  { {0x7bc4002c,0x27e05f15,0xe9da0a74,0x00000000}},	// [c420] _iniu, rkin_, _бкп_,
  { {0x27e05f16,0xc9aa22fa,0x64405f17,0x00000000}},	//   skin_, _свое_, _simi,
  { {0x7bd6005b,0x6440006d,0x915e0013,0x00000000}},	//   _koyu, _pimi, _nắm_,
  { {0x32070051,0xd467005e,0x7a200014,0x00000000}},	//   enny_, сице_, götv,
  { {0xe296000a,0x9f910026,0x8c1b0063,0x00000000}},	//   среќ, _ráð_, נוני,
  { {0xdb0400be,0xca97009a,0xd46a0cac,0x00000000}},	//   _uniõ, מדני_, _محرم_,
  { {0x915e0013,0x644028fa,0xdb0600a5,0x00000000}},	//   _cắm_, _timi, ldkä,
  { {0xdb0600c7,0xa8570063,0x6440003b,0x00000000}},	//   odkä, זיקה_, _uimi,
  { {0xdb061013,0x2327167b,0x43750e5e,0x00000000}},	//   ndkä, _готи_, _фуст,
  { {0x6b8d0027,0x29f2001c,0x2d9900ea,0x00000000}},	//   _scag, iņas_, ősen_,
  { {0x7bd601f7,0xddc95f18,0x25f00053,0x00000000}},	//   _boyu, brež, _इतनी_,
  { {0xe6c80053,0xac1909b3,0x7bd60331,0x00000000}},	//   रमाङ, рому_, _coyu,
  { {0xdce100dd,0x9eda0044,0xa3d00042,0x00000000}},	//   tală, _حذاء_, _वचन_,
  { {0x2d570076,0x3e340044,0xcf2514d7,0x00000000}},	//   _лишь_, _بفتر, _برمي,
  { {0xfc490013,0x8078009a,0x05dc0042,0x00000000}},	//   _hận_, יְּה, _मक़ब,
  { {0xdc55007e,0xdce800a8,0x07090044,0x00000000}},	//   _بروک, nadč, ليزي_,
  { {0x6aad0b54,0x32070a8d,0x75e000ea,0x00000000}},	// [c430] _usaf, ynny_, _közh,
  { {0x96ad0053,0x99675f19,0x00000000,0x00000000}},	//   ुटबॉ, _утил,   ,
  { {0xfc49008b,0x225800c2,0x9626001c,0x00000000}},	//   _lận_, _črka_, diņā,
  { {0x78fa0063,0x61fa004d,0xef1f004b,0x00000000}},	//   _כפתו, _amtl, üük_,
  { {0x3abc0047,0x915e008d,0x4b7c016e,0x00000000}},	//   ָמונ, _sắm_, ראדו,
  { {0x51870055,0x95cb0615,0xd4e707b3,0x00000000}},	//   суда, _сума_, _люби,
  { {0xddc94e89,0x67480046,0xf994009a,0x00000000}},	//   trež, _ásjá, פרק_,
  { {0xb0680032,0x4032000a,0x60de00d1,0x00000000}},	//   حصول_, мејс, øpma,
  { {0x60060088,0xfc49008b,0x4ec50086,0x00000000}},	//   ўным_, _cận_, ійов,
  { {0x69c50014,0xb65c0041,0x915e008d,0x00000000}},	//   _nnhe, אדזש, _tắm_,
  { {0x75e00058,0x201d056c,0x8ba63df5,0x00000000}},	//   _sözk, _tkwi_, оинж,
  { {0x69c55f1a,0xfffa0050,0xeaba02f9,0x00000000}},	//   _anhe, äätö_, айм_,
  { {0x96e80001,0xcf27007e,0x69d71b3b,0x00000000}},	//   мaну_, _اراي, _boxe,
  { {0xfce50928,0x8f360063,0x7a20013d,0x00000000}},	//   _моло, _ואנו_, jött,
  { {0x186a0263,0xd943012d,0x7a20013d,0x00000000}},	//   раби_, дери, dött,
  { {0x7bc4000c,0x69c506a3,0x9626008f,0x00000000}},	//   _uniu, _enhe, ziņā,
  { {0x2fc00025,0x69d700e5,0xc5760044,0x00000000}},	// [c440] _óige_, _foxe, قطاع,
  { {0x6fdc5f1b,0x75e000ea,0x78550078,0x00000000}},	//   _héct, _közi, _sąve,
  { {0xdd7a00b7,0x136a0001,0x53465f1c,0x00000000}},	//   שטעל, ашли_, охла,
  { {0xdc8c0047,0x032600fb,0x7413005d,0x00000000}},	//   רװאָ, оден, وولا,
  { {0xdc370047,0x9626008f,0x599a009a,0x00000000}},	//   קאנט_, tiņā, ֹשֶׁ,
  { {0x91e30121,0x7c26004d,0x845a013f,0x00000000}},	//   моче, hlkr, _врат_,
  { {0x96260023,0xe6430085,0x614301ce,0x00000000}},	//   riņā, _церп, меља,
  { {0x30170021,0x645e0072,0xd0100044,0x00000000}},	//   يتية_, mppi, علة_,
  { {0x44260185,0xdee60044,0xeda62fbf,0x00000000}},	//   mlo_, تأثي, ошно,
  { {0x6fdc03b2,0xfc49001b,0xcdda0259,0x00000000}},	//   _récu, _vận_, рњи_,
  { {0xa3ae016a,0x44265f1d,0x6fdc1676,0x00000000}},	//   _कसा_, olo_, _sécu,
  { {0xfc49008b,0x321c027d,0x7a200ed5,0x00000000}},	//   _tận_, lovy_, zött,
  { {0x7a2000fe,0x643b0047,0x44265f1e,0x00000000}},	//   yött, יעטנ, ilo_,
  { {0x9e65006a,0x6fdc0003,0xddc30086,0x00000000}},	//   _راهن, _vécu, _обчи,
  { {0x62820d1e,0xdcf80058,0x44265f1f,0x00000000}},	//   hroo, _tavı, klo_,
  { {0x2d8c38f8,0x4426007d,0x907b00ff,0x00000000}},	//   lgde_, jlo_, יטלי,
  { {0xdce3003d,0x44265f20,0x2d8c0983,0x00000000}},	// [c450] _ienā, dlo_, ogde_,
  { {0x2d8c2e7a,0x44265f21,0x316c008f,0x00000000}},	//   ngde_, elo_, _nedz_,
  { {0x2d8c006f,0x2fc6007d,0x6282056f,0x00000000}},	//   igde_, _onog_, eroo,
  { {0x44265f22,0x62822bca,0x53350601,0x00000000}},	//   glo_, froo, пеет,
  { {0x59df0235,0xa7560063,0x6282191d,0x00000000}},	//   _नकार, _משרד_, groo,
  { {0x2fc600a4,0x44265f23,0x81c70121,0x00000000}},	//   _anog_, alo_, ющее,
  { {0x44265f24,0x6282004b,0xdb0a0061,0x00000000}},	//   blo_, aroo, čném,
  { {0x2d8c006f,0x62825f25,0xdce3008f,0x00000000}},	//   egde_, broo, _nenā,
  { {0x6282153e,0xb444000d,0x6d5c0058,0x00000000}},	//   croo, _цэрк, ıran,
  { {0x2d8c0137,0x271a008b,0x6fdc00ea,0x00000000}},	//   ggde_, ỏng_, _bécs,
  { {0x7c950021,0x29040058,0x1d25079f,0x00000000}},	//   أشخا, şmaz_, ямом,
  { {0xfaa60088,0x2d8c0162,0xeb9a0b3f,0x00000000}},	//   памо, agde_, щим_,
  { {0x67ea007a,0x2cac002b,0x22455f26,0x00000000}},	//   _nýja, awdd_, _kilk_,
  { {0x98560086,0x645e5f27,0xceb20ca4,0x00000000}},	//   зташ, yppi, _ניו_,
  { {0xdca20432,0x75e000ea,0x7d1c00bd,0x00000000}},	//   _защи, _közv, ürst,
  { {0x628200bb,0xdb040016,0x3f8d021a,0x00000000}},	//   yroo, _maiú, ngeu_,
  { {0x225800c2,0x3ead00ca,0x9f4a004c,0x00000000}},	// [c460] _črko_, nwet_, ímém_,
  { {0x8afb0063,0x05660054,0xdb06013d,0x00000000}},	//   _להפי, ївен, jeké,
  { {0xdb0600ea,0x316c001c,0x62822322,0x00000000}},	//   deké, _redz_, wroo,
  { {0x4420001b,0xd4690021,0x62825f28,0x00000000}},	//   ôi_, تحكم_, troo,
  { {0x44265f29,0x6282021e,0x32530086,0x00000000}},	//   rlo_, uroo, евір,
  { {0x98b804ab,0x3f8d00cd,0x1a9b0047,0x00000000}},	//   ları_, egeu_, מינע,
  { {0x30a30076,0x44265f2a,0x997d008f,0x00000000}},	//   ерыв, plo_, nāšu_,
  { {0x644e000c,0x645c00a8,0x628236a4,0x00000000}},	//   _iubi, _itri, proo,
  { {0x644e02dd,0x3ead00ac,0x74130044,0x00000000}},	//   _hubi, gwet_, _أوقا,
  { {0x67261262,0x661e00b9,0x36f70063,0x00000000}},	//   _mykj, nopk, פצים_,
  { {0x6fdc0164,0x2d8c0250,0x98b8005b,0x00000000}},	//   _décr, rgde_, karı_,
  { {0x656e004d,0x997d008f,0x2fda005d,0x00000000}},	//   _lebh, dāšu_, _دوصد_,
  { {0xdfcf00f2,0x98b80058,0x644e5f2b,0x00000000}},	//   _حين_, darı_, _lubi,
  { {0x645c08b7,0xd5c50054,0x1958082d,0x00000000}},	//   _otri, лiнн, зары_,
  { {0xda67007e,0x6aa45f2c,0x59f81501,0x00000000}},	//   _کابي, _epif, черя_,
  { {0xfc15000d,0xdb0d0046,0xdb06013d,0x00000000}},	//   _імпэ, _fnað, zeké,
  { {0x644e0992,0x645c5f2d,0x4b7c0063,0x00000000}},	// [c470] _aubi, _atri, _האחו,
  { {0x3c320024,0x7aef005b,0x3f830078,0x00000000}},	//   ráve_, ıntı, ėjui_,
  { {0x644e3069,0xdb060451,0x98b80075,0x00000000}},	//   _cubi, veké, barı_,
  { {0x224500e5,0x645c0139,0x2ca10072,0x00000000}},	//   _silk_, _dtri, _ähde_,
  { {0xdb0600ea,0x2245004b,0xfc490013,0x00000000}},	//   teké, _pilk_, _rậm_,
  { {0x9f5f0058,0x72c4000d,0xcb140041,0x00000000}},	//   onuç_, эбіз, עלס_,
  { {0x3f8d0268,0x644e14ba,0xf484290b,0x00000000}},	//   tgeu_, _gubi, _путн,
  { {0x7ff5006a,0x6b9d006f,0x6d585f2e,0x00000000}},	//   بستا, jfsg, _afva,
  { {0x644e00e3,0x799c002b,0xdce8008f,0x00000000}},	//   _zubi, yfrw, vadā,
  { {0x628b002c,0x98b8005b,0xee39000d,0x00000000}},	//   mugo, zarı_, ўно_,
  { {0x644803b2,0x628b5f2f,0x98b8005b,0x00000000}},	//   _édit, lugo, yarı_,
  { {0x27340026,0xddc2007d,0x63ab0517,0x00000000}},	//   _júní_, _gvož, negn,
  { {0xdb0600b9,0x03760063,0x629928b3,0x00000000}},	//   ndkø, ותרת_, ntwo,
  { {0x997d008f,0xbea209c8,0x200d008f,0x00000000}},	//   tāšu_, _рашк, lnei_,
  { {0x62990122,0x98b8005b,0x656e0244,0x00000000}},	//   htwo, tarı_, _rebh,
  { {0x5d4400b5,0x644e0bb6,0xc7a30f8d,0x00000000}},	//   _אָפּ_, _rubi, киск,
  { {0xcf9200b5,0x644e5f30,0x98b8005b,0x00000000}},	// [c480] כטן_, _subi, rarı_,
  { {0xe57a000d,0x98b80058,0x628b44d6,0x00000000}},	//   ізе_, sarı_, dugo,
  { {0xe3ba3c6e,0x628b0130,0x629922a1,0x00000000}},	//   жбе_, eugo, etwo,
  { {0x8cbe0161,0x644a00cd,0x53e50086,0x00000000}},	//   षितो, ífiq, нціа,
  { {0xf773014e,0x628b00a4,0x200d5f31,0x00000000}},	//   _בקר_, gugo, dnei_,
  { {0x644e0c7a,0x645c5f32,0x63b9002b,0x00000000}},	//   _tubi, _ttri, adwn,
  { {0xf65f00b9,0x63ab08ed,0x645c5f33,0x00000000}},	//   _præg_, begn, _utri,
  { {0xdfd00032,0x6d5c0058,0x4ee60054,0x00000000}},	//   اية_, ıram, діоз,
  { {0x3013005a,0x44240150,0x75d30022,0x00000000}},	//   ъдър, _ikm_, _węzł,
  { {0x200d000c,0x25b85f34,0x4d98071f,0x00000000}},	//   anei_, _jarl_, чкою_,
  { {0x4424004b,0xcf8f005e,0x9f980046,0x00000000}},	//   _kkm_, _иј_, _féð_,
  { {0x75e000ea,0x7c36001f,0xddc2085a,0x00000000}},	//   _közs, _chyr, _uvož,
  { {0x4424004b,0x6e930021,0x5e930021,0x00000000}},	//   _mkm_, _للنا, _للنط,
  { {0x20045f35,0x44242c17,0xedd40044,0x00000000}},	//   limi_, _lkm_, _سيبد,
  { {0x20040072,0xa3ae0053,0x9c7c0066,0x00000000}},	//   oimi_, क़ा_, byča,
  { {0x2d9e0321,0x20045f36,0xb5fb011b,0x00000000}},	//   lfte_, nimi_, _uváz,
  { {0x98af01f7,0xc6f90062,0x1ab40085,0x00000000}},	// [c490] ınız_, чнах_, _абыя,
  { {0x2d9e004d,0x200d11ad,0x7ae0004d,0x00000000}},	//   nfte_, znei_, ämte,
  { {0xe7590086,0x3914000d,0x63ab5f37,0x00000000}},	//   _нині_, _амэр, tegn,
  { {0x200414d5,0x25b81c7e,0x628b4d97,0x00000000}},	//   jimi_, _earl_, tugo,
  { {0x27e90974,0xe945007e,0x63ab5f38,0x00000000}},	//   mkan_, _ترکی, regn,
  { {0x27e90e53,0x63ab5f39,0x9f980026,0x00000000}},	//   lkan_, segn, _séð_,
  { {0x63ab051e,0x200d001c,0x54541410,0x00000000}},	//   pegn, tnei_, _авст,
  { {0x27e908f0,0x2004040d,0x6605053b,0x00000000}},	//   nkan_, gimi_, lihk,
  { {0x27e95f3a,0x2d9e00bd,0x5215013c,0x00000000}},	//   ikan_, ffte_, _здат,
  { {0x27e908f0,0x3c320024,0x7c240498,0x00000000}},	//   hkan_, dáva_, _skir,
  { {0x27e90397,0x20040006,0xdb0a01c2,0x00000000}},	//   kkan_, bimi_, čním,
  { {0xca29014e,0x645a04d4,0x30150376,0x00000000}},	//   _הם_, _étie, _ядер,
  { {0x27e90974,0x2bb20042,0x0e64046e,0x00000000}},	//   dkan_, ज़बा, _акін,
  { {0x67e30004,0x27e9176c,0x6d550075,0x00000000}},	//   _mõju, ekan_, ızas,
  { {0x6e21017f,0x27e9003e,0x66050360,0x00000000}},	//   molb, fkan_, dihk,
  { {0x27e9053b,0x7c240228,0x25b80003,0x00000000}},	//   gkan_, _ukir, _sarl_,
  { {0x6fa10042,0xaa570044,0x6e215f3b,0x00000000}},	// [c4a0] क्यू, _كليا_, oolb,
  { {0x27e90397,0x6e21001f,0x66050089,0x00000000}},	//   akan_, nolb, gihk,
  { {0x27e90e53,0x7ae65f3c,0x74690086,0x00000000}},	//   bkan_, lykt, дрів_,
  { {0xd5c90161,0x2cb80146,0x27e900c7,0x00000000}},	//   राउज, ærdi_, ckan_,
  { {0x2ca700f3,0xd3230b0f,0x2d9e0137,0x00000000}},	//   _lpnd_, льши, yfte_,
  { {0x6d5c005b,0xdb210066,0x69da0072,0x00000000}},	//   ırak, ätéh, öteh,
  { {0x26c00dd1,0x6722001c,0xf9930063,0x00000000}},	//   lvio_, ļoju, ארו_,
  { {0x9f4400fe,0x4424053b,0x69de4fc9,0x00000000}},	//   yhmä_, _ukm_, _lope,
  { {0x69de37f6,0x20045f3d,0x26c009ab,0x00000000}},	//   _oope, rimi_, nvio_,
  { {0x3c320024,0x69de1e29,0x27e90089,0x00000000}},	//   váva_, _nope, zkan_,
  { {0x2d9e00bd,0xc5f30063,0x61e5004d,0x00000000}},	//   rfte_, רדת_, öhle,
  { {0x3c320024,0x78550078,0x00000000,0x00000000}},	//   táva_, _sąvo,   ,
  { {0x2d9e004d,0x3f670062,0x69de002b,0x00000000}},	//   pfte_, _чичо_, _bope,
  { {0x69de562f,0x3c320114,0xc3330ca4,0x00000000}},	//   _cope, ráva_, טור_,
  { {0x27e95f3e,0x66050987,0x64580195,0x00000000}},	//   tkan_, vihk, ívil,
  { {0x27e9053b,0x6fa60053,0xf773013a,0x00000000}},	//   ukan_, _कॉमं, طار_,
  { {0x27e95f3f,0xf6533be7,0x7bcd2e47,0x00000000}},	// [c4b0] rkan_, ائر_, _inau,
  { {0x984b5f40,0x27e95f41,0x7bdf0110,0x00000000}},	//   _няма_, skan_, _hoqu,
  { {0x27e908f0,0x225f016d,0x660500a8,0x00000000}},	//   pkan_, _stuk_, rihk,
  { {0xe454000d,0x987a0047,0x69de00c2,0x00000000}},	//   укцы, _קארט, _zope,
  { {0x32670138,0x64490ec6,0xdb160003,0x00000000}},	//   хтев, _viei, _payé,
  { {0x1e1a0161,0x7bdf5f42,0x5184005e,0x00000000}},	//   नकोष_, _loqu, гућа,
  { {0x70b20032,0xd3a7126b,0x70bd0053,0x00000000}},	//   لموض, _прап, ्मेल,
  { {0x442b0013,0xc4d20063,0x9c7c0195,0x00000000}},	//   _óc_, _דגל_, tyčn,
  { {0x75e0000f,0x0cc90161,0x2284079a,0x00000000}},	//   _közp, िम्म, _бухг,
  { {0x63bb4a35,0x645a0460,0xfc3f004c,0x00000000}},	//   _haun, _étic, emí_,
  { {0xa806005b,0x909913d3,0x26c0007d,0x00000000}},	//   lmış, _цвет_, zvio_,
  { {0x63bb0418,0x3f830006,0x6e2100a4,0x00000000}},	//   _jaun, ėjus_, solb,
  { {0xa806005b,0x63bb5f43,0x69de5f44,0x00000000}},	//   nmış, _maun, _pope,
  { {0x26c00290,0x63bb1157,0x7e7b0137,0x00000000}},	//   vvio_, _laun, msup,
  { {0x44c10006,0x64c5007d,0xb796005e,0x00000000}},	//   _nė_, nčić, краћ,
  { {0x98360088,0xb8da0161,0x63bb1d0e,0x00000000}},	//   тэгі, _आई_, _naun,
  { {0x69de3e35,0x7e7b5f45,0xbab3005d,0x00000000}},	// [c4c0] _tope, nsup, _نميب,
  { {0x26c05f46,0x3207027d,0xd46a005e,0x00000000}},	//   rvio_, jiny_, диже_,
  { {0x3207027d,0x26c0017d,0x63bb5f47,0x00000000}},	//   diny_, svio_, _baun,
  { {0xd4670001,0x44c10078,0x130a007f,0x00000000}},	//   тице_, _dė_, мней_,
  { {0x63bb5f48,0x92b30021,0xab0d009a,0x00000000}},	//   _daun, لحوا, ּהוֹ,
  { {0x5333005e,0x7e7b00a5,0x32075f49,0x00000000}},	//   јешт, dsup, giny_,
  { {0xfc4a008b,0xc9530063,0x91e30001,0x00000000}},	//   _hậu_, סמה_, роје,
  { {0x63bb5f4a,0xeeb80062,0x6d4e0066,0x00000000}},	//   _gaun, елиш_, ľbam,
  { {0xef1f0019,0x7e7b395c,0x320703a4,0x00000000}},	//   üüp_, gsup, biny_,
  { {0x63a255a3,0xfc4a008b,0x7bdf00be,0x00000000}},	//   lfon, _mậu_, _soqu,
  { {0x7bdf5f4b,0xfc4a0013,0xb0630072,0x00000000}},	//   _poqu, _lậu_, ääty,
  { {0x447b00b5,0x6d5a0025,0x63a25f4c,0x00000000}},	//   ונטע, scta, nfon,
  { {0x7ceb013d,0xd64d0085,0x63a25f4d,0x00000000}},	//   törö, вiне, ifon,
  { {0x7a32010a,0xfc3f0080,0x7ae00137,0x00000000}},	//   sætn, smí_, ämta,
  { {0x7bcd0078,0x7bdf12c7,0xa8060058,0x00000000}},	//   _tnau, _toqu, zmış,
  { {0x7bcd4cd5,0x32070470,0x7a320046,0x00000000}},	//   _unau, ziny_, lætl,
  { {0x98a4001c,0x63bb29c6,0xfc4a008b,0x00000000}},	// [c4d0] āmā_, _raun, _cậu_,
  { {0xfc4a0013,0xe5c41c9b,0xdb060022,0x00000000}},	//   _dậu_, исхо, adkó,
  { {0x63bb002c,0x63a25f4e,0x3207004a,0x00000000}},	//   _paun, ffon, viny_,
  { {0x63a200ea,0xa77443bd,0xd299000d,0x00000000}},	//   gfon, _ключ, еткі_,
  { {0x63bb5f4f,0x32075f50,0x7bfc0041,0x00000000}},	//   _vaun, tiny_, ופאצ,
  { {0xa8060058,0x63bb002b,0xb2240085,0x00000000}},	//   rmış, _waun, аміл,
  { {0x41260002,0xa4d40086,0x27fe008f,0x00000000}},	//   лошо_, _корі, ūtne_,
  { {0xa806005b,0x7e7b2430,0x94b10042,0x00000000}},	//   pmış, tsup, ीटीआ,
  { {0xe3150001,0xfc4a001b,0x3207027d,0x00000000}},	//   _смањ, _mật_, piny_,
  { {0x64550009,0x4d650be6,0xfc4a008b,0x00000000}},	//   _kuzi, ыков, _lật_,
  { {0x7e7b4646,0xd13103eb,0x442f5f51,0x00000000}},	//   ssup, _اما_, olg_,
  { {0x64555f52,0x61e13cd8,0x1bba00f2,0x00000000}},	//   _muzi, _holl, راجع_,
  { {0x6da5018e,0xada5015a,0x64555f53,0x00000000}},	//   _била, _балл, _luzi,
  { {0x61e1024a,0x65750024,0xceb20063,0x00000000}},	//   _joll, _nezh, _ליד_,
  { {0xfc4a008b,0x2c46008f,0x61e1539c,0x00000000}},	//   _bật_, _mēdz_, _moll,
  { {0x61e1010e,0xeb9a0699,0xfc4a008d,0x00000000}},	//   _loll, _џип_, _cật_,
  { {0x64551052,0x7c26449c,0xfc4a0013,0x00000000}},	// [c4e0] _auzi, mokr, _dật_,
  { {0x442f0031,0xed580024,0xa2c20053,0x00000000}},	//   elg_, odľa_, लिस्,
  { {0xa3ea0062,0x35c90053,0x628b5f54,0x00000000}},	//   нджа_, राज़, ergo,
  { {0x24861401,0x64554a70,0x7c26530f,0x00000000}},	//   čom_, _duzi, nokr,
  { {0x0cb00235,0xc69400b5,0x67ea0014,0x00000000}},	//   _जन्म, _דאָ_, _nýji,
  { {0x61e11130,0x442f01f2,0x69dc0137,0x00000000}},	//   _coll, alg_, njre,
  { {0x7c26358c,0xf9930063,0x628b5f55,0x00000000}},	//   kokr, צרה_, argo,
  { {0xd252006a,0xc0340001,0xdb0b00ea,0x00000000}},	//   _هنر_, јниј, őnéz,
  { {0x61e10034,0x629e003b,0xc7d70063,0x00000000}},	//   _foll, ăpos, רופי_,
  { {0x644200fe,0x61e1001f,0x6b844c30,0x00000000}},	//   lmoi, _goll, _adig,
  { {0xc223006a,0xb5fb0047,0x7ae00137,0x00000000}},	//   _اکنو, גליכ, ämtn,
  { {0x644210d8,0xab62005b,0x44260b70,0x00000000}},	//   nmoi, şünd, noo_,
  { {0x6b840185,0x61e1005b,0x80370047,0x00000000}},	//   _ddig, _yoll, _ענדע_,
  { {0x442630d5,0x5a340086,0x8e835f56,0x00000000}},	//   hoo_, йнят, _угље,
  { {0xdcea003b,0x44265f57,0xab5b004d,0x00000000}},	//   _defă, koo_, rdüb,
  { {0xb8dd0161,0x645509fe,0x57b50002,0x00000000}},	//   _इन_, _ruzi, јбат,
  { {0xfc4a001b,0x64555f58,0x557505f1,0x00000000}},	// [c4f0] _vật_, _suzi, игат,
  { {0x60c81310,0x69da1fa7,0x98750002,0x00000000}},	//   _ordm, ötet, _клоц,
  { {0x764e001f,0xfc4a008b,0x38c9007e,0x00000000}},	//   _diby, _tật_, _شادی_,
  { {0x61e15f59,0x44260a9f,0x628b00b2,0x00000000}},	//   _soll, goo_, trgo,
  { {0x877a00b5,0x645a0003,0x7afd00e0,0x00000000}},	//   _בארי, _étin, nzst,
  { {0x64422c17,0x64550d07,0x7afd008f,0x00000000}},	//   amoi, _tuzi, izst,
  { {0xa156005e,0x61e102ce,0x44261b13,0x00000000}},	//   шају_, _voll, boo_,
  { {0x61e10359,0x20c80021,0x3fe505f4,0x00000000}},	//   _woll, ابوي_, ржив,
  { {0x63a900a4,0x61e15f5a,0xa024004d,0x00000000}},	//   _iben, _toll, _stöß,
  { {0x67ea0080,0x7afd008f,0xdb060058,0x00000000}},	//   _výji, dzst, lekç,
  { {0xcb6a0878,0x55760047,0xa3bc0053,0x00000000}},	//   кане_, ױערן_, _असम_,
  { {0xf047000d,0xdce8004c,0xbb460f8d,0x00000000}},	//   _сэзо, ladě, иенк,
  { {0x6e670086,0x63a60137,0x7c2630ca,0x00000000}},	//   _стеж, _ökne, rokr,
  { {0xfe70006a,0x7c2600ea,0x7e6900d1,0x00000000}},	//   _رده_, sokr, mpep,
  { {0x26cf00c7,0x7c262b1e,0xddc900c2,0x00000000}},	//   ågon_, pokr, osež,
  { {0x764e4905,0xb4d6005d,0x00000000,0x00000000}},	//   _siby, یغات,   ,
  { {0xa66500f2,0x69da00a5,0x44265f5b,0x00000000}},	// [c500] مطلو, ötes, voo_,
  { {0x63a95f5c,0x7a200072,0x672f0022,0x00000000}},	//   _aben, yöty, _dycj,
  { {0xb5fb5f5d,0x44265f5e,0x764e00a5,0x00000000}},	//   _itál, too_, _viby,
  { {0x8755005a,0xa87b0047,0xb5fb00ea,0x00000000}},	//   _гърц, _באטר, _után,
  { {0xdce30080,0x44260b34,0x2327005e,0x00000000}},	//   _peně, roo_, аоци_,
  { {0x63a90199,0x645a0003,0x6d4e0078,0x00000000}},	//   _eben, _étio, žbai,
  { {0x40a8005d,0x44260155,0xdb060075,0x00000000}},	//   اختی_, poo_, bekç,
  { {0x7afd5f5f,0x0fb8005e,0xa857009a,0x00000000}},	//   yzst, улић_, סיפה_,
  { {0x7ae00e77,0x7e6d0058,0x9ed70062,0x00000000}},	//   ämtl, _çapl, имът_,
  { {0x9c7c0078,0xab620058,0xbdf40092,0x00000000}},	//   lyči, şüld, спој,
  { {0x06370041,0x49060042,0x41e50043,0x00000000}},	//   שניט_, _हेलो_, _اسقف,
  { {0x7afd00bd,0x9c7c0078,0xbea60085,0x00000000}},	//   tzst, nyči, _вадк,
  { {0x6eb60044,0xd843004c,0xc334009a,0x00000000}},	//   _خصائ, načů_, מוֹ_,
  { {0x6d5c005b,0x2efb0063,0x7afd004d,0x00000000}},	//   ıras, _שִׁב, rzst,
  { {0xfc64007e,0x9c7c0078,0x201800be,0x00000000}},	//   _اختی, kyči, _íris_,
  { {0x69da112c,0x57f40141,0x87550054,0x00000000}},	//   öter, опст, скає,
  { {0x67ea007a,0x7c2d5f60,0xa3da0053,0x00000000}},	// [c510] _nýju, _ikar, ़ान_,
  { {0xddc900c2,0xd54b007e,0xfc4a0013,0x00000000}},	//   zsež, نجام_, _hập_,
  { {0xd4980002,0xd3710021,0xdce8004c,0x00000000}},	//   ирц_, كها_, vadě,
  { {0x68e800a5,0xdb060e77,0xe3b30044,0x00000000}},	//   ädde, bekä, ترط_,
  { {0x6235000a,0xdb06005b,0xfc4a0013,0x00000000}},	//   беду, rekç, _mập_,
  { {0xfc4a001b,0x91e20076,0xa4d5013c,0x00000000}},	//   _lập_, зоше, _логі,
  { {0x601e001c,0x74f9005e,0x7c2d007d,0x00000000}},	//   zīme, _севр_, _okar,
  { {0x43940076,0xc9180063,0xfc4a008d,0x00000000}},	//   _масс, יחות_, _nập_,
  { {0x6e2800b9,0xef190022,0x442d08db,0x00000000}},	//   fodb, każe_, _ike_,
  { {0x7c2d000f,0x07920080,0x6e28082a,0x00000000}},	//   _akar, _čímž_, godb,
  { {0x443f001b,0x442d0093,0x0c260154,0x00000000}},	//   _khu_, _kke_, ймон,
  { {0xfc4a001b,0x26cb405e,0xb5fb0114,0x00000000}},	//   _cập_, _orco_, _stál,
  { {0xeb97011c,0x200d000c,0xdce1001c,0x00000000}},	//   щия_, miei_, talē,
  { {0x200d000c,0x442d0229,0x433a0041,0x00000000}},	//   liei_, _lke_, טערב,
  { {0x7c950021,0x442d0150,0x26cb1095,0x00000000}},	//   _العص, _oke_, _arco_,
  { {0x200d0529,0x443f008b,0xab5b00ea,0x00000000}},	//   niei_, _nhu_, ldün,
  { {0xe61a0055,0xaea10075,0xe7e90042,0x00000000}},	// [c520] гда_, _çığl, _टकरा_,
  { {0x0556000d,0x200d003b,0xe5a30330,0x00000000}},	//   стая, hiei_, зифи,
  { {0x75e000ea,0x9c7c4e31,0x39570063,0x00000000}},	//   _közz, tyči, _לשים_,
  { {0x443f5f61,0xd843004c,0x037a0593,0x00000000}},	//   _chu_, tačů_, احات_,
  { {0x200d003b,0x1db70042,0x21780766,0x00000000}},	//   diei_, _असंत, айлы_,
  { {0x3ea00072,0x27e00883,0x9265005d,0x00000000}},	//   _äiti_, ljin_, زدهم,
  { {0x200d000c,0x2a3b0041,0x657e0168,0x00000000}},	//   fiei_, װעקמ, maph,
  { {0x7416007e,0x200d000c,0x5f94026b,0x00000000}},	//   _اورا, giei_, циит,
  { {0x6440024a,0x9205001c,0xfc4a008b,0x00000000}},	//   _ihmi, _spāņ, _rập_,
  { {0xf1a9006a,0x22f7014e,0xf77f0016,0x00000000}},	//   _نامه_, _הזמן_, _moça_,
  { {0x11d70021,0x6ca30076,0x200d003b,0x00000000}},	//   _دولة_, пряж, biei_,
  { {0x200d003b,0x68ee069f,0x320e00e5,0x00000000}},	//   ciei_, dybd, lify_,
  { {0x6e2800c2,0x80250021,0x4e17005d,0x00000000}},	//   podb, _برلم, شتید_,
  { {0x99830080,0xac73007e,0x69da0072,0x00000000}},	//   rojů_, _کاوش, ötep,
  { {0xfc4a001b,0x5a340054,0x16d10042,0x00000000}},	//   _tập_, їнст, सम्ब,
  { {0x7c2d0035,0x207b0041,0x62825f62,0x00000000}},	//   _ukar, טאלא, ksoo,
  { {0x44c8005b,0x443f0089,0x36d40f55,0x00000000}},	// [c530] _ağ_, _rhu_, потр,
  { {0x9b95006a,0x15150088,0xdb0f006d,0x00000000}},	//   _الکت, одзя, necí,
  { {0x2bdd0161,0x320e41b9,0x6282006f,0x00000000}},	//   यापा, dify_, esoo,
  { {0x437400e1,0x64400022,0x200d00dd,0x00000000}},	//   пушт, _chmi, xiei_,
  { {0x628200ac,0x200d3ecf,0x92b70021,0x00000000}},	//   gsoo, viei_, إحصا,
  { {0x20b40053,0x67460066,0x5fa60042,0x00000000}},	//   ंबंध, ňujú, क्सल,
  { {0x443f0f78,0x80c00161,0xdb0f006d,0x00000000}},	//   _thu_, विगे, decí,
  { {0x442d0031,0xa295000d,0x7cff0014,0x00000000}},	//   _uke_, _мабі, _láré,
  { {0x200d000c,0xdb0f006d,0xcee60121,0x00000000}},	//   riei_, fecí, ждые_,
  { {0x320e0034,0x200d000c,0x55760047,0x00000000}},	//   cify_, siei_, ֿערן_,
  { {0x200d003b,0xab5b0433,0x8c4631b1,0x00000000}},	//   piei_, rdün, жене,
  { {0xdb0f003b,0x7a3201e1,0xeb9a5f63,0x00000000}},	//   decâ, nætv, шим_,
  { {0xce6b005a,0xa3da0053,0xdb060066,0x00000000}},	//   _сред_, ़ात_, lekú,
  { {0x0dcb0138,0xd7f1008b,0xf77f00be,0x00000000}},	//   _људи_, ễn_, _roça_,
  { {0x9c65007e,0x75e00058,0x1089009a,0x00000000}},	//   _بهبو, _gözy, יָּֽ,
  { {0x657e00ac,0xab5b23b4,0xd9430263,0x00000000}},	//   waph, ndül, феси,
  { {0x060a0138,0x75d601a7,0x27f200ac,0x00000000}},	// [c540] анак_, ييرا, rkyn_,
  { {0x67f800ea,0x7bc40035,0x27f212be,0x00000000}},	//   _díja, _haiu, skyn_,
  { {0x78ad0080,0x2eb60053,0x657e2160,0x00000000}},	//   čová, _अन्त, raph,
  { {0xd36f0032,0x2bdd0053,0x999a0006,0x00000000}},	//   نهم_, याया, _tipų_,
  { {0x7bc45f64,0x320e07ee,0xdddb0d76,0x00000000}},	//   _maiu, tify_, druž,
  { {0x62820462,0x799c001f,0x057a0021,0x00000000}},	//   rsoo, ngrw, _خمسة_,
  { {0x320e2cb4,0x799c002b,0xa3da0042,0x00000000}},	//   rify_, igrw, ़ाद_,
  { {0x628200ac,0x7bc40bbb,0x657c5f65,0x00000000}},	//   psoo, _naiu, _herh,
  { {0xdefa1485,0xcf260032,0xdde3000c,0x00000000}},	//   рый_, غربي, ârşi,
  { {0x645c5f66,0x50d60242,0x7bc600ac,0x00000000}},	//   _kuri, _وزار, edku,
  { {0xdb0f02dd,0x26c9017f,0x657c005b,0x00000000}},	//   recí, zvao_, _merh,
  { {0x5c07000d,0x645c5f67,0x61e8004c,0x00000000}},	//   іяна, _muri, _hodl,
  { {0x61e8005b,0x657c0137,0xdb0f2aac,0x00000000}},	//   _kodl, _oerh, pecí,
  { {0xb5fb0066,0x645c1560,0xba3b002b,0x00000000}},	//   _vták, _ouri, rtïo,
  { {0xf65f0146,0x645c1ac7,0xa9540054,0x00000000}},	//   _træk_, _nuri, дкрі,
  { {0xcb0b03d6,0x9f5f0026,0x68e80137,0x00000000}},	//   _вход_, nnuð_, ädda,
  { {0x657c0e53,0xba770021,0x35f50121,0x00000000}},	// [c550] _berh, _باعت, ппар,
  { {0xdce100eb,0x645c07ee,0xdb0d0019,0x00000000}},	//   galė, _buri, _maaü,
  { {0x9f5f0026,0x645c117e,0x19ba009a,0x00000000}},	//   knuð_, _curi, _המתב,
  { {0x645c0034,0x3c16001c,0x670c0053,0x00000000}},	//   _duri, tāvi_, _सेवक_,
  { {0x69c50004,0x69c708ea,0xa3bc0053,0x00000000}},	//   _kahe, odje, _असर_,
  { {0x69c75f68,0x61e85f69,0x7a320014,0x00000000}},	//   ndje, _codl, bætu,
  { {0xd0580088,0x69c7017f,0x7582007e,0x00000000}},	//   орыі_, idje, _سینم,
  { {0x69c50004,0xb5fb0080,0xf77f017d,0x00000000}},	//   _lahe, _stáh, _moço_,
  { {0x61e8001f,0xab5b0b35,0x645c5f6a,0x00000000}},	//   _fodl, rdül, _zuri,
  { {0x69c500bd,0x765d014f,0xddca005b,0x00000000}},	//   _nahe, _musy, ğişe,
  { {0x6565004d,0xdddb218f,0x23601ee9,0x00000000}},	//   ichh, pruž, žije_,
  { {0xe672005b,0x7a320026,0xeb970121,0x00000000}},	//   _ölçü, hætt, пию_,
  { {0x75f3005b,0xdb0601e1,0x290300a8,0x00000000}},	//   _kızı, nekø, ezja_,
  { {0x7c2700c3,0xcefd005b,0x20f70013,0x00000000}},	//   čkra, ığın_, õi_,
  { {0x69c50199,0x31af01f7,0xf7720021,0x00000000}},	//   _dahe, mızı_, فاء_,
  { {0x69d7017d,0x16662324,0x765d0222,0x00000000}},	//   _enxe, звам, _busy,
  { {0xa3df0161,0x645c5f6b,0x777d00cd,0x00000000}},	// [c560] तान_, _suri, _desx,
  { {0x31af04ab,0x2c614ba3,0x3c320114,0x00000000}},	//   nızı_, _kód_, rávu_,
  { {0x5fbd0053,0x657c5f6c,0xdce10078,0x00000000}},	//   ्याल, _verh, ralė,
  { {0x2c611084,0x645c00ca,0xe3631410,0x00000000}},	//   _mód_, _vuri, екци,
  { {0x657c5f6d,0x61e85f6e,0x83360021,0x00000000}},	//   _terh, _podl, أراض,
  { {0x645c5f6f,0x26c70051,0xd25901dd,0x00000000}},	//   _turi, łnoc_, іці_,
  { {0x645c0004,0xf1a9007e,0xc5ff001c,0x00000000}},	//   _uuri, تانه_, ķēts_,
  { {0x351b0063,0x62990150,0x68e10db3,0x00000000}},	//   _הולנ, buwo, äldi,
  { {0xb5fb0027,0x4ea3000d,0x877b0041,0x00000000}},	//   _stái, нрэа, זאפי,
  { {0x6142004c,0x71a30781,0xf1aa01fb,0x00000000}},	//   _cílí, _пауз, _داره_,
  { {0x2c610027,0xdc3f0080,0x201301a8,0x00000000}},	//   _cód_, síčn, èxic_,
  { {0x69c55f70,0x6291008f,0x3fa500de,0x00000000}},	//   _sahe, ūkoš, _يصنف,
  { {0x90290021,0xab5b0058,0x69c50cb0,0x00000000}},	//   _بألف_, ldük, _pahe,
  { {0xf77f017d,0x69c72eab,0x765d27da,0x00000000}},	//   _poço_, udje, _rusy,
  { {0x69c50004,0x28f80055,0xd90f007e,0x00000000}},	//   _vahe, перь_, ایج_,
  { {0x2d9e0c23,0x984b0062,0x6565002b,0x00000000}},	//   lgte_, сяга_, wchh,
  { {0x6b8d00bb,0x69c55f71,0x2d9e0229,0x00000000}},	// [c570] _idag, _tahe, ogte_,
  { {0x317e004d,0x2d9e5f72,0x8afc0063,0x00000000}},	//   _netz_, ngte_, _להחי,
  { {0xb5fb017d,0x76550058,0x65655f73,0x00000000}},	//   _otáv, _vizy, rchh,
  { {0x7a32220c,0xe3b30032,0x76550051,0x00000000}},	//   sætt, عرض_, _wizy,
  { {0xb2ab06be,0xa3df0053,0x38c7004c,0x00000000}},	//   стеж_, ताब_, bírá_,
  { {0x7c2f0025,0x2c4d004c,0x68ec013d,0x00000000}},	//   hocr, _vědy_, _éldá,
  { {0x63b90045,0x9045007e,0x20f7008d,0x00000000}},	//   pewn, ونته, ũi_,
  { {0xa0090021,0x2d9e2670,0x2c610022,0x00000000}},	//   تقبل_, egte_, _ród_,
  { {0xa3da0053,0xfe450002,0x442f5f74,0x00000000}},	//   ़ार_, мнио, mog_,
  { {0xee36000d,0xcc890121,0x442f5f75,0x00000000}},	//   мны_, обое_, log_,
  { {0xdb1d0146,0x442f0229,0xc5f2009a,0x00000000}},	//   ndsæ, oog_, דדי_,
  { {0x442f5f76,0x2d9e083f,0x2ef50071,0x00000000}},	//   nog_, agte_, _озер,
  { {0xef0e000a,0x9f580013,0x2c610022,0x00000000}},	//   _рм_, đrô_, _wód_,
  { {0x6b8d0006,0x442f5f77,0xc9760021,0x00000000}},	//   _edag, hog_, باحث,
  { {0x442f0117,0xc7a6005a,0x98a3005a,0x00000000}},	//   kog_, мивк, кире,
  { {0xdb1602dd,0x3c16008f,0x442f0dd4,0x00000000}},	//   _mayú, tāvu_, jog_,
  { {0xe7370055,0x442f5f78,0x225f5f79,0x00000000}},	// [c580] дет_, dog_, _nuuk_,
  { {0x7a3200b9,0xfa970aeb,0x463a0085,0x00000000}},	//   ræts, _קדיש_, ічая_,
  { {0xdce1001c,0x442f001f,0xddcb001c,0x00000000}},	//   dalī, fog_, _atgū,
  { {0x44205f7a,0x442f5f7b,0xf77f005b,0x00000000}},	//   õi_, gog_, _geç_,
  { {0xc17a0086,0x2d9e00b9,0xbb1b0003,0x00000000}},	//   оїй_, ygte_, haîn,
  { {0xb5fb0114,0xeb9f01f2,0xddc200c2,0x00000000}},	//   _stáv, niør_, _otoš,
  { {0xdcfa001c,0xa2c20053,0x442f5f7c,0x00000000}},	//   katā, लिङ्, bog_,
  { {0xe29a0088,0x8fa30001,0x232a0472,0x00000000}},	//   _маб_, ваће, _доби_,
  { {0x067b0047,0x6d470046,0x00000000,0x00000000}},	//   ֿנטל, ýjan,   ,
  { {0xdb0f0016,0xdd900242,0x2d9e004d,0x00000000}},	//   lecç, دود_, ugte_,
  { {0x2d9e0518,0x559700ff,0x91e3055d,0x00000000}},	//   rgte_, ודיע_, _шофе,
  { {0xdddb008f,0xd64d0085,0xdc3400de,0x00000000}},	//   rsuš, гiле, َرَة,
  { {0x6ab90053,0xb4bb0053,0x7de60021,0x00000000}},	//   इबेर, _अन्_, _يستم,
  { {0xf77f005b,0x442f5f7d,0x3f845f7e,0x00000000}},	//   _seç_, zog_, lamu_,
  { {0xcec8001b,0xa9345f7f,0x442f0a9f,0x00000000}},	//   _hộ_, верш, yog_,
  { {0xeb9f0093,0x3f844d0e,0xdb0f00be,0x00000000}},	//   riøs_, namu_, jecç,
  { {0x442f0117,0x85a7005e,0xe6990062,0x00000000}},	// [c590] vog_, дјед, яваш_,
  { {0x3f840035,0x442f001f,0xcec8008b,0x00000000}},	//   hamu_, wog_, _mộ_,
  { {0xdb0f017d,0xcec8008b,0x7588015a,0x00000000}},	//   fecç, _lộ_, ьств_,
  { {0xdb1d00b9,0xfc4a0013,0x442f002b,0x00000000}},	//   rdsæ, _bậy_, uog_,
  { {0x442f5f80,0xfc4a008b,0x3f845f81,0x00000000}},	//   rog_, _cậy_, damu_,
  { {0xfc4a008b,0x442f39eb,0x21690200,0x00000000}},	//   _dậy_, sog_, чики_,
  { {0x3f840035,0x20555f82,0x442f007d,0x00000000}},	//   famu_, нтир, pog_,
  { {0xcec8001b,0x44390025,0xb78c00b5,0x00000000}},	//   _bộ_, _ós_, ֿריִ,
  { {0x15f30235,0xdb1d0c38,0xef191b79,0x00000000}},	//   _आकार_, ndsä, ями_,
  { {0x645a00cd,0x7d09005e,0x11d70021,0x00000000}},	//   _ètic, зног_, _تترد,
  { {0x3f840035,0x67f8013d,0x27fe0023,0x00000000}},	//   bamu_, _díjj, ūtni_,
  { {0xc4d20047,0x26c0001f,0xbb1b0003,0x00000000}},	//   אגט_, ywio_, raîn,
  { {0x539a0063,0x501a0041,0x3b83014b,0x00000000}},	//   הירו, _צונו, ыляг,
  { {0x1d0902b6,0xbea21122,0x38c8005d,0x00000000}},	//   _нели_, _сашк, وازی_,
  { {0xba3b0268,0x6e2600ea,0x2d85507c,0x00000000}},	//   duïd, ékbe, male_,
  { {0x6d43017f,0x2d85332a,0xbb460062,0x00000000}},	//   _izna, lale_, _пейк,
  { {0x3855005a,0xd70a000d,0xdcf8001c,0x00000000}},	// [c5a0] търс, чнае_, _ievā,
  { {0x386100bd,0x2d855f83,0x2bac0042,0x00000000}},	//   _fuhr_, nale_, ट्रा,
  { {0xdb060004,0xdb0f017d,0x649a000d,0x00000000}},	//   hekü, tecç, ятар_,
  { {0x7d060003,0xb5fb2de9,0xdcfa003b,0x00000000}},	//   _héré, _stát, lată,
  { {0x7d06000f,0xba3b00cd,0xdb0f017d,0x00000000}},	//   _kéré, buïd, recç,
  { {0xfc4a001b,0x2d851f72,0xcec80013,0x00000000}},	//   _vậy_, jale_, _rộ_,
  { {0x3f845f84,0xa3ea042c,0x2d855f85,0x00000000}},	//   tamu_, _едва_, dale_,
  { {0x6443006f,0xf65f05b9,0x7546008f,0x00000000}},	//   ïnit, _træt_, ērzē,
  { {0xe2970079,0x241700b5,0xfe6f007e,0x00000000}},	//   _пат_, _נחמן_, یدی_,
  { {0x7c240035,0x63a25f86,0x2d855f87,0x00000000}},	//   _ajir, lgon, gale_,
  { {0xdddb003b,0x63a25f88,0x1ac90042,0x00000000}},	//   spuş, ogon, िट्ठ,
  { {0x68f500eb,0x63a25f89,0xfbab0121,0x00000000}},	//   vyzd, ngon, чтой_,
  { {0x2d852523,0xdcf8008f,0x7d062abf,0x00000000}},	//   bale_, _devā, _béré,
  { {0x7d060164,0xc3330063,0x2d855f8a,0x00000000}},	//   _céré, רוש_, cale_,
  { {0xddc9003b,0x7e6d0058,0xdb1d04aa,0x00000000}},	//   speţ, _çapr, ddså,
  { {0x91f5001b,0xba3b01a8,0xddc908ed,0x00000000}},	//   _kíc, duïe, mpeš,
  { {0xba3b00cd,0xa3da0053,0xc987005e,0x00000000}},	// [c5b0] tuïd, ़ाई_, _пуни,
  { {0x7c3d00c7,0x63a25f8b,0x7d060003,0x00000000}},	//   llsr, egon, _géré,
  { {0xd3710067,0xba3b00cd,0x7e620072,0x00000000}},	//   لها_, ruïd, _luop,
  { {0xd370006a,0x23e4000d,0x63a25f8c,0x00000000}},	//   مهٔ_, лічв, ggon,
  { {0x2d855f8d,0xd25b000d,0xe1ee012f,0x00000000}},	//   yale_, чце_, аг_,
  { {0x63a2002c,0xc244000d,0xb5fb017d,0x00000000}},	//   agon, гнік, _etár,
  { {0x2d851f72,0xc0e502f9,0x27e90050,0x00000000}},	//   vale_, тойк, ojan_,
  { {0x27e9024a,0x201f003b,0xdb06004b,0x00000000}},	//   njan_, unui_, tekü,
  { {0x2d855f8e,0x43940062,0x27e95f8f,0x00000000}},	//   tale_, _щатс, ijan_,
  { {0x7c3600eb,0x2d855363,0x4d650062,0x00000000}},	//   _skyr, uale_, ъков,
  { {0xd00e007e,0x2d852b16,0x64490150,0x00000000}},	//   صلی_, rale_, _khei,
  { {0x0f150076,0x7d060003,0x20040066,0x00000000}},	//   _имею, _séré, chmi_,
  { {0xa3b30235,0x2d855f90,0x64492389,0x00000000}},	//   ज्य_, pale_, _mhei,
  { {0xaa46005a,0x22f60041,0x3ead013d,0x00000000}},	//   тегл, דזשן_, mtet_,
  { {0x644900fe,0x3ead0d7d,0x994a0058,0x00000000}},	//   _ohei, ltet_, _dışa_,
  { {0x6449002b,0x2fcd002b,0x98a3005e,0x00000000}},	//   _nhei, ndeg_, јите,
  { {0x9f4f0268,0x3ead1781,0x63a60137,0x00000000}},	// [c5c0] _algú_, ntet_, _ökni,
  { {0x3ead0bfc,0x27e900fe,0x6b841b85,0x00000000}},	//   itet_, ajan_, _heig,
  { {0x26cf01e3,0x64490027,0x74690086,0x00000000}},	//   ågor_, _bhei, ерів_,
  { {0x6b8400eb,0x64495f91,0xddc3000f,0x00000000}},	//   _jeig, _chei, _minő,
  { {0x236000c3,0x64490025,0x6b840d2f,0x00000000}},	//   žijo_, _dhei, _meig,
  { {0xf65f00d1,0x69ce44de,0x443d002b,0x00000000}},	//   _trær_, ndbe, alw_,
  { {0x64490027,0x69ce0190,0xf9930063,0x00000000}},	//   _fhei, idbe, ברו_,
  { {0x6b840498,0x64490025,0x3ead0105,0x00000000}},	//   _neig, _ghei, ftet_,
  { {0x3ead0146,0x3f9801f7,0xa3df0053,0x00000000}},	//   gtet_, ğru_, तार_,
  { {0x26d205b3,0xdcf8003b,0x27e95f92,0x00000000}},	//   ivyo_, _nevă, zjan_,
  { {0xf1a9006a,0x6b84179d,0x459b0047,0x00000000}},	//   _ساله_, _beig, וסיע,
  { {0xa806005b,0x91f5008b,0xdb1d00ea,0x00000000}},	//   nlığ, _tíc, lesé,
  { {0x79870035,0x69ce006f,0xddc9481d,0x00000000}},	//   tajw, fdbe, speš,
  { {0x5a34367a,0x5cd40044,0xaab6005d,0x00000000}},	//   инят, _مقتط, اگير_,
  { {0x27e900cd,0xa806005b,0x443d002b,0x00000000}},	//   tjan_, klığ, ylw_,
  { {0xb5fb02dd,0xf8040001,0x6b845f93,0x00000000}},	//   _cuán, ачун, _geig,
  { {0xc6a70062,0x644937b4,0x27e95f94,0x00000000}},	// [c5d0] ърви, _rhei, rjan_,
  { {0x6b840199,0x64492ae5,0xfc3f5f95,0x00000000}},	//   _zeig, _shei, llí_,
  { {0x290a0045,0xdce80006,0x765c001f,0x00000000}},	//   czba_, radė, _diry,
  { {0x3ead0051,0x7b080058,0x7bcf059f,0x00000000}},	//   ytet_, _örtü, ndcu,
  { {0xfc3f0027,0x877a0063,0x798500a4,0x00000000}},	//   ilí_, _ראשי, _kehw,
  { {0x7d150024,0x785c007d,0xb6da0041,0x00000000}},	//   úzsk, _učvr, _אַלט,
  { {0x64491a74,0x7bdf0003,0x35190041,0x00000000}},	//   _thei, _onqu, _װוּנ,
  { {0xb4c10161,0x3ead02ea,0x6f091c8a,0x00000000}},	//   ्टी_, ttet_, tzec,
  { {0x6b840359,0xfc3f0080,0xdbdd0026,0x00000000}},	//   _reig, dlí_, _ráðs,
  { {0x6b840164,0x6f090051,0x3ead0105,0x00000000}},	//   _seig, rzec, rtet_,
  { {0xed58034d,0x25a50026,0x3ead10eb,0x00000000}},	//   teľa_, _öllu_, stet_,
  { {0x7d1c0025,0x2d99005b,0x9f4d0072,0x00000000}},	//   úrsa, şse_, tkeä_,
  { {0xa3ab0235,0xa806005b,0xfbaa0042,0x00000000}},	//   _खान_, nlış, _काठम,
  { {0x6e920032,0x5e920032,0x9f4d00fe,0x00000000}},	//   _الوا, _الوط, rkeä_,
  { {0x3e69008b,0xfc3f056d,0x6b845f96,0x00000000}},	//   _hút_, blí_, _teig,
  { {0x63a90331,0xb5fb5f97,0x290a056c,0x00000000}},	//   _ncen, _quán, rzba_,
  { {0x66e3278d,0x464a02d8,0xda5a0121,0x00000000}},	// [c5e0] бота, езан_, _прош_,
  { {0x63a95f98,0x46130021,0x7985004d,0x00000000}},	//   _acen, موقر, _gehw,
  { {0x5316007e,0x66fa008f,0x3e69008d,0x00000000}},	//   گذار, _sākā, _lút_,
  { {0x289b0047,0x63a901f4,0x389b0041,0x00000000}},	//   _איטא, _ccen, _איטנ,
  { {0x3e69001b,0xa806005b,0x753c0051,0x00000000}},	//   _nút_, rlığ, _wyrz,
  { {0x63a95f99,0xfd4a008d,0x3c39004c,0x00000000}},	//   _ecen, _choị, névr_,
  { {0xdb1d000f,0xa8063ff0,0xab5b005b,0x00000000}},	//   resé, alış, ndür,
  { {0x3e695f9a,0xcfa63371,0x20025f9b,0x00000000}},	//   _bút_, ушки, óki_,
  { {0x9196005e,0x3e69008d,0x03260121,0x00000000}},	//   _бјеш, _cút_, _сдан,
  { {0x32070080,0x91f50013,0x60cd0051,0x00000000}},	//   chny_, _hín, łama,
  { {0x2369027c,0x7bcd13ed,0x459b0047,0x00000000}},	//   žaje_, _paau, עסטע,
  { {0xdb550076,0xac190071,0x4ea60002,0x00000000}},	//   ивны, тому_, _брка,
  { {0xdb1d000e,0xfc3f5f9c,0xdd92005d,0x00000000}},	//   ndsø, rlí_, _هوش_,
  { {0xc3330132,0xb5fb006d,0x2b95008b,0x00000000}},	//   מור_, _cuál, ục_,
  { {0x4dfb0041,0x5dfb009a,0xfc3f011b,0x00000000}},	//   _אפגא, _אפגנ, plí_,
  { {0x8ae70086,0x213e32b2,0x7bdf1ae7,0x00000000}},	//   _біол, _myth_, _unqu,
  { {0x1615000d,0xa7fb006d,0xa3e80053,0x00000000}},	// [c5f0] адаў, _niñe, बान_,
  { {0x659501ef,0x0596007e,0x63a95f9d,0x00000000}},	//   ражу, لامگ, _scen,
  { {0xb4c10053,0x213e002b,0xd5b80085,0x00000000}},	//   ्टे_, _nyth_, ыст_,
  { {0xd9e30042,0xc3cb0044,0x9cd7009a,0x00000000}},	//   खावत_, عظام_, טובה_,
  { {0xc7d80062,0x601e001c,0xb3840085,0x00000000}},	//   _смях_, nīmu, сліл,
  { {0x213e001f,0x3e69008b,0x40955f9e,0x00000000}},	//   _byth_, _rút_, арит,
  { {0x3e690013,0x78550078,0x6021008f,0x00000000}},	//   _sút_, _sąvy, lēmi,
  { {0x1f650002,0x63a93f4c,0x245e004c,0x00000000}},	//   шким, _ucen, _tůma_,
  { {0x9e650095,0xfd4a008d,0x0e650141,0x00000000}},	//   јвод, _thoị, јкон,
  { {0xfe420086,0x213e001f,0xed5902b1,0x00000000}},	//   жньо, _fyth_, коп_,
  { {0x61e100ac,0x9c260092,0x9d4510ae,0x00000000}},	//   _inll, идод, ренд,
  { {0x3f89007a,0x26d9077a,0x9f4f006c,0x00000000}},	//   _þau_, _orso_, _logé_,
  { {0xeb97011c,0xaa46047e,0x99f6000d,0x00000000}},	//   шия_, иемл, аяві,
  { {0x6021008f,0x6da20601,0xada20085,0x00000000}},	//   dēmi, _диша, _дашл,
  { {0xf7720021,0x26cb0516,0x1d060591,0x00000000}},	//   قاء_, _asco_, _вещи_,
  { {0xab5b005b,0xa8030054,0x00000000,0x00000000}},	//   rdür, озсл,   ,
  { {0x98ab008f,0xa3df0042,0x45865f9f,0x00000000}},	// [c600] ījāt_, ताई_, игав,
  { {0x2d8700bd,0xfe79004c,0xe5775fa0,0x00000000}},	//   _jene_, ipů_, изу_,
  { {0xdce8003d,0x9178008b,0x399b0149,0x00000000}},	//   vadī, _lợi_, _בייד,
  { {0x7c265fa1,0xc5e90063,0x3205059f,0x00000000}},	//   nnkr, וד_, _ally_,
  { {0x213e001f,0xe7fb0042,0x7c2618de,0x00000000}},	//   _syth_, _एकता_, inkr,
  { {0xdb1d05dd,0xa7fb006d,0x2d875fa2,0x00000000}},	//   rdsø, _viñe, _nene_,
  { {0x91f5001b,0xf9930063,0xdce8001c,0x00000000}},	//   _tín, קרה_, radī,
  { {0x61e10994,0x44c801f7,0x289b0047,0x00000000}},	//   _enll, _iş_, דיקא,
  { {0x539b014e,0x2d875fa3,0x6569005b,0x00000000}},	//   _שימו, _bene_, _şehi,
  { {0x644257b9,0x44265fa4,0x78be00d1,0x00000000}},	//   lloi, lno_, _oppv,
  { {0xd5d900b5,0xa5d90047,0x3a380d1e,0x00000000}},	//   אַרש, אַרי, dorp_,
  { {0x2d870122,0x44265fa5,0xef1a3e30,0x00000000}},	//   _eene_, nno_, _име_,
  { {0x44265fa6,0x91780013,0xcb470363,0x00000000}},	//   ino_, _gợi_, рхни,
  { {0xf3f9003b,0x68fc001f,0x44262ca3,0x00000000}},	//   _miţa_, fyrd, hno_,
  { {0x7c940021,0xaa5c0086,0x2d8c5fa7,0x00000000}},	//   _البص, терi, made_,
  { {0x442601a6,0xdb1d00ea,0x2d8c5fa8,0x00000000}},	//   jno_, lesí, lade_,
  { {0x44c8183b,0x44260a97,0xac07005d,0x00000000}},	// [c610] _aş_, dno_, _مذکو,
  { {0x7afd00fe,0x7a3b0003,0x3a385fa9,0x00000000}},	//   myst, aîtr, corp_,
  { {0x998a0078,0x7afd2f0b,0x937902d8,0x00000000}},	//   albų_, lyst, гбет_,
  { {0x44265faa,0x2d980045,0x44240086,0x00000000}},	//   gno_, órej_, оєча,
  { {0xf2c7011c,0x2d8c5fab,0xdb1d00ea,0x00000000}},	//   рсен, kade_, kesí,
  { {0x13080086,0xfa780063,0x44265fac,0x00000000}},	//   шній_, סעות_, ano_,
  { {0x2d8c13a8,0xc1980086,0x44265fad,0x00000000}},	//   dade_, ртії_, bno_,
  { {0x7afd14a3,0x2d8c004b,0x2006002b,0x00000000}},	//   kyst, eade_, _cloi_,
  { {0x2d8c2fc4,0xee3912d5,0x2d8700c4,0x00000000}},	//   fade_, лни_, _pene_,
  { {0x41e4000d,0xdb1d00ea,0x7afd1435,0x00000000}},	//   _міха, gesí, dyst,
  { {0x2d870019,0x2fcf0137,0x11d40021,0x00000000}},	//   _vene_, _tagg_, _بتقد,
  { {0xc0b2008b,0x2006002b,0x7afd4467,0x00000000}},	//   _lưới_, _gloi_, fyst,
  { {0x2d8c0019,0x3a381233,0x63bb5fae,0x00000000}},	//   bade_, torp_, _mbun,
  { {0x7f3a00b5,0x49990055,0x5d850032,0x00000000}},	//   _גענו, ится_, _الثل,
  { {0x44264ad1,0x63bb0acd,0x09d50085,0x00000000}},	//   yno_, _obun, ццяў,
  { {0x7afd01da,0x236010f5,0x6c3600f2,0x00000000}},	//   byst, žiji_, _دفعا,
  { {0x7bc60d74,0x4426115a,0x4b7b0041,0x00000000}},	// [c620] meku, vno_, _גאפו,
  { {0x2ca50034,0x44260045,0x7bc65faf,0x00000000}},	//   ould_, wno_, leku,
  { {0x442606bb,0xc0b2001b,0x78be01be,0x00000000}},	//   tno_, _dưới_, _uppv,
  { {0x7bc63407,0x2d8c5fb0,0xdb1d1954,0x00000000}},	//   neku, zade_, zesí,
  { {0x321c0080,0x2ca50c84,0x44265fb1,0x00000000}},	//   tivy_, huld_, rno_,
  { {0x4426065f,0x3c32016b,0x646300c2,0x00000000}},	//   sno_, rávy_, _žviž,
  { {0x7afd0045,0x442602e2,0x2369027c,0x00000000}},	//   zyst, pno_, žaja_,
  { {0x4fc60055,0x2ca503ac,0x7afd0072,0x00000000}},	//   сска, duld_, yyst,
  { {0xdb1d000f,0x7e7b00a4,0x2d8c5fb2,0x00000000}},	//   tesí, gpup, tade_,
  { {0xade60001,0x2737008b,0x2ca500b9,0x00000000}},	//   сцик, ủng_, fuld_,
  { {0x2d8c0924,0x7e7b00a4,0x7afd0cc4,0x00000000}},	//   rade_, apup, wyst,
  { {0x2d8c5fb3,0x7afd5fb4,0x7bc60df4,0x00000000}},	//   sade_, tyst, geku,
  { {0xa7fb006d,0xdb1d00ea,0x2d8c5fb5,0x00000000}},	//   _niña, pesí, pade_,
  { {0x7bc6004b,0x601e008f,0x7afd5fb6,0x00000000}},	//   aeku, cīmr, ryst,
  { {0x59f8005a,0x7bc60370,0x195927b8,0x00000000}},	//   щеря_, beku, равы_,
  { {0x57790085,0x96eb030b,0x8c190044,0x00000000}},	//   рбаў_, льза_, _خيبر_,
  { {0x68e800c7,0x7c2d0035,0x6b7c0047,0x00000000}},	// [c630] äddr, _ijar, _ערזנ,
  { {0xd5675fb7,0x7c2d0014,0x6aa00046,0x00000000}},	//   стап, _hjar, ámfe,
  { {0x69c700c3,0x20d80013,0x454b0002,0x00000000}},	//   meje, _nĩi_, учам_,
  { {0x6e3a0150,0x69d55fb8,0x68e800a5,0x00000000}},	//   hotb, ldze, ådde,
  { {0x68e0003d,0x6d4e0066,0xa189005e,0x00000000}},	//   āmde, ýbaj, абла_,
  { {0x7bc60051,0xdb040051,0xe5c70456,0x00000000}},	//   zeku, _zbió, _усмо,
  { {0xb5fb027d,0x7bc605b3,0xd5b80500,0x00000000}},	//   _otáz, yeku, _уся_,
  { {0x63bb5fb9,0x2ca50122,0x29115fba,0x00000000}},	//   _ubun, vuld_, izza_,
  { {0x442d0a1a,0x7bc62f39,0x8e090505,0x00000000}},	//   _ije_, veku, инив_,
  { {0x7c2d014f,0x442d0072,0xa19405ef,0x00000000}},	//   _ajar, _hje_, _науч,
  { {0x442d00c3,0xeb9f00b9,0xab5b004b,0x00000000}},	//   _kje_, dkøb_, seül,
  { {0x7e7b0072,0x69d55fbb,0xab5b004e,0x00000000}},	//   ppup, edze, peül,
  { {0x69c7000f,0xdaba000d,0x7c2d147f,0x00000000}},	//   feje, шыні_, _djar,
  { {0x201f0006,0x7bc63842,0x6d470014,0x00000000}},	//   liui_, seku, ýjas,
  { {0x7c2d007a,0x7bc60035,0x443f5fbc,0x00000000}},	//   _fjar, peku, _oku_,
  { {0x201f0006,0xac170001,0x442d5fbd,0x00000000}},	//   niui_, _моју_, _nje_,
  { {0x69c722bd,0x6d43001f,0x7c570021,0x00000000}},	// [c640] beje, _hyna, _بلير_,
  { {0xbb1b0164,0xdcf80080,0x443f20aa,0x00000000}},	//   raît, _nevě, _aku_,
  { {0x200d00f5,0xec13007e,0x201f0078,0x00000000}},	//   khei_, _روید, kiui_,
  { {0x66e60c45,0xfe670021,0x6d43530a,0x00000000}},	//   _дома, _يد_, _myna,
  { {0x6e280026,0x442d4e54,0xf773005d,0x00000000}},	//   yndb, _dje_, _تاپ_,
  { {0x442d5fbe,0x6d43005b,0xa187005e,0x00000000}},	//   _eje_, _oyna, обља_,
  { {0xdcf8004c,0xdb0f01a8,0x6d4300b8,0x00000000}},	//   _devě, necò, _nyna,
  { {0xdfda005a,0x78fb0047,0x201f0078,0x00000000}},	//   рък_, יפצו, giui_,
  { {0x6d430058,0x8dea0094,0x66ba009d,0x00000000}},	//   _ayna, афна_, ׁמֵה,
  { {0x6d43212c,0x7c2d2aaf,0x6e281fd9,0x00000000}},	//   _byna, _sjar, undb,
  { {0xdb1d0080,0x69c75fbf,0x6d430731,0x00000000}},	//   desá, veje, _cyna,
  { {0x7ee60032,0x69d50051,0xf77f017d,0x00000000}},	//   _وكان, wdze, _onça_,
  { {0xbfa3008b,0x6e3a00ea,0x69c75fc0,0x00000000}},	//   _miề, potb, teje,
  { {0x6d43002b,0xbfa30013,0x22be008f,0x00000000}},	//   _fyna, _liề, mākā_,
  { {0x63ab2d60,0x69c75fc1,0x22be001c,0x00000000}},	//   yggn, reje, lākā_,
  { {0x998300eb,0x7c2d28bb,0xbfa30013,0x00000000}},	//   tojų_, _ujar, _niề,
  { {0x356b0ab1,0x22be008f,0x29054120,0x00000000}},	// [c650] арен_, nākā_, šla_,
  { {0x6b8d4512,0xc4db005e,0x7c3d059d,0x00000000}},	//   _heag, иђе_, losr,
  { {0x6b8d014f,0xfa340021,0xd370005d,0x00000000}},	//   _keag, _تريد, چهٔ_,
  { {0x7c3d024a,0xd370005d,0x60cd0022,0x00000000}},	//   nosr, نهٔ_, łamk,
  { {0x236900c3,0x44da0066,0x27f40066,0x00000000}},	//   žajo_, _eď_, žaná_,
  { {0x7e6b0006,0x6b8d5fc2,0xbb3c0047,0x00000000}},	//   _rugp, _leag, בעדי,
  { {0xc5f201f9,0x7c3d5fc3,0x200d5fc4,0x00000000}},	//   _אדם_, kosr, thei_,
  { {0x6b8d000c,0xd3e3007e,0xf41f0ef1,0x00000000}},	//   _neag, _تقری, _öä_,
  { {0xa3e80161,0x201f0006,0xe165007e,0x00000000}},	//   बार_, riui_, _فضای,
  { {0x443d0037,0xee360076,0x201f0078,0x00000000}},	//   low_, знь_, siui_,
  { {0xa7fb02dd,0x6b8d057a,0x201f0078,0x00000000}},	//   _niño, _beag, piui_,
  { {0x22be008f,0x443d5fc5,0x3cf800a5,0x00000000}},	//   bākā_, now_, ärva_,
  { {0x6d430051,0x7c2f0003,0xcf270049,0x00000000}},	//   _wyna, ébra, _براي,
  { {0xddc3001c,0x443d5fc6,0xde580054,0x00000000}},	//   _minū, how_, _дачі_,
  { {0xdb1d004a,0x9f440066,0x69ad0042,0x00000000}},	//   resá, ajmä_, _जारी,
  { {0xdb1d0146,0xab5b004b,0xf1c70061,0x00000000}},	//   desæ, keüh, _hráč_,
  { {0x443d30a8,0xdb220072,0x00000000,0x00000000}},	// [c660] dow_, ätäy,   ,
  { {0x6569005b,0x2baa0082,0xdb37009d,0x00000000}},	//   _şehr, कलवा, _מנפח_,
  { {0x14c8006a,0x7bd60089,0xdb1d01e1,0x00000000}},	//   تهای_, _kayu, gesæ,
  { {0x68e10146,0xf789017d,0x91fc008f,0x00000000}},	//   ælde, _voçê_, _ciān,
  { {0x7bd6576e,0xbfa30013,0xc2970085,0x00000000}},	//   _mayu, _viề, зкіх_,
  { {0x7bd6002c,0x7416005d,0x0269012c,0x00000000}},	//   _layu, _کورا, ішій_,
  { {0xbfa3001b,0xddc20006,0x3d050053,0x00000000}},	//   _tiề, _nuoš, शनों_,
  { {0x22be001c,0xdb06013d,0xde780054,0x00000000}},	//   tākā_, egkí, обич_,
  { {0x7c3d00c2,0x6e2106f1,0x6b8d5fc7,0x00000000}},	//   vosr, filb, _reag,
  { {0xddcb01f7,0xab5b00ea,0xddc20022,0x00000000}},	//   ğişt, lfüg, _utoż,
  { {0x61e8010a,0x6b8d0019,0x25ed0053,0x00000000}},	//   _indl, _peag, घाती_,
  { {0xab5b050c,0x61fa5fc8,0xa7fb0331,0x00000000}},	//   nfüg, _hotl, _riño,
  { {0x7bd600a4,0x319f008f,0x7c3d013d,0x00000000}},	//   _dayu, bāzē_, rosr,
  { {0xaa645fc9,0xe8050042,0x443d5fca,0x00000000}},	//   етск, रस्थ_, zow_,
  { {0x6b8d0027,0x7c3d082a,0x61fa0f20,0x00000000}},	//   _teag, posr, _motl,
  { {0x7bd600bb,0x99980080,0x2ca30066,0x00000000}},	//   _gayu, borů_, ájde_,
  { {0x61e800ca,0x6bd40044,0x4734076a,0x00000000}},	// [c670] _ondl, _ستير, ентс,
  { {0x2d8e02dd,0xf8ae007e,0x61fa09ad,0x00000000}},	//   _jefe_, دکی_, _notl,
  { {0xf9fc0063,0x7bd60150,0x443d5fcb,0x00000000}},	//   _להזמ, _yayu, tow_,
  { {0x9f4f0066,0xdb1d01e1,0x61e85fcc,0x00000000}},	//   _logá_, resæ, _andl,
  { {0xe3b0007e,0x443d1d20,0x63a400ea,0x00000000}},	//   ارم_, row_, óina,
  { {0xa9250066,0xd5b80854,0x746b5fcd,0x00000000}},	//   poľč, _нсс_, _грав_,
  { {0xdb1d0137,0x61fe004b,0x9998004c,0x00000000}},	//   lesä, öpla, zorů_,
  { {0xddc20006,0x61e80359,0x6284003b,0x00000000}},	//   _ruoš, _endl, ţioa,
  { {0x3e720529,0x7bd65fce,0x6e214444,0x00000000}},	//   _cât_, _rayu, tilb,
  { {0x7bd6053b,0x9998004c,0x61fa5fcf,0x00000000}},	//   _sayu, vorů_, _gotl,
  { {0x7bd6017e,0x82340021,0xb5fb0331,0x00000000}},	//   _payu, _أرقا, _huás,
  { {0xea01001b,0x99980080,0x6e215fd0,0x00000000}},	//   _đạt_, torů_, silb,
  { {0x61e805b9,0x3e7245b0,0xdb1d0072,0x00000000}},	//   _yndl, _gât_, jesä,
  { {0x69d7017d,0x186a197a,0x99f50085,0x00000000}},	//   _caxe, жави_, нясі,
  { {0x2d8504bc,0xa96706b4,0x3f8f008d,0x00000000}},	//   mble_, дира_, _kegu_,
  { {0x7b07000f,0x2be40042,0x6d5c0046,0x00000000}},	//   örté, गाओं_, ýrae,
  { {0x16660062,0x2d855fd1,0x6beb0132,0x00000000}},	// [c680] двам, oble_, _וַיַ,
  { {0x2ca503ae,0xeb9f00b9,0x4d7a0041,0x00000000}},	//   orld_, nkøn_, ַרנע,
  { {0xf241000d,0x2e3a0047,0x61fa2667,0x00000000}},	//   _якiя_, קגענ, _rotl,
  { {0x3f8f0006,0x730a0021,0x60dc013d,0x00000000}},	//   _negu_, يقاف_, _ármi,
  { {0xab5b0199,0x69bb0161,0xf65f01e1,0x00000000}},	//   rfüg, श्वी, _psæt_,
  { {0xc5d5000d,0x3f8f004b,0xd25001fb,0x00000000}},	//   _пісь, _aegu_, دنت_,
  { {0x61fa55a6,0x6d47004b,0x91e3005e,0x00000000}},	//   _votl, üjal, тоје,
  { {0xf8b30063,0x442240a3,0xa3ab0042,0x00000000}},	//   דשה_, _ök_, _खाए_,
  { {0xf65f0d02,0xdb1d2d60,0xa2d50042,0x00000000}},	//   _især_, ldsö, _मैप्,
  { {0x61e80146,0xacf4005e,0x6282016c,0x00000000}},	//   _undl, епољ, mpoo,
  { {0x62820019,0xdb1d0b68,0x6aa60014,0x00000000}},	//   lpoo, ndsö, erkf,
  { {0xb5fb258b,0x2d851e3e,0xba3b002b,0x00000000}},	//   _juár, able_, trïo,
  { {0x628200ca,0xfc3f0139,0x2d855da9,0x00000000}},	//   npoo, roí_, bble_,
  { {0x7e7d0024,0x69c0013d,0x66d8009c,0x00000000}},	//   íspe, őmen, zúká,
  { {0x3a23006f,0x6aa600d1,0x91fc008f,0x00000000}},	//   rijp_, arkf, _riāl,
  { {0x7b6705bd,0xdb1d0072,0x6282004b,0x00000000}},	//   _отпе, tesä, kpoo,
  { {0x69d75fd2,0x7a290078,0xa3e80042,0x00000000}},	// [c690] _taxe, ežte, बाई_,
  { {0x628200ca,0xdb1d00a5,0x454b0f9f,0x00000000}},	//   dpoo, resä, очем_,
  { {0xf795000d,0x7c2f1795,0xdcfa008f,0x00000000}},	//   _панэ, oncr, matē,
  { {0x6284003d,0x387e0139,0xc6a701e2,0x00000000}},	//   ģion, ítre_, _орги,
  { {0x62840529,0xc2cb007e,0x7c2f0003,0x00000000}},	//   ţion, تبال_, incr,
  { {0x2cac00d1,0x3f8f004b,0xa0693d71,0x00000000}},	//   kudd_, _segu_, пака_,
  { {0x61420002,0x6282004e,0x3ced0042,0x00000000}},	//   леша, apoo, _छपें_,
  { {0xb5fb006d,0x2cac00a3,0xf4410054,0x00000000}},	//   _guár, dudd_, _собi_,
  { {0xe2350001,0x442f00a4,0x3f8f0014,0x00000000}},	//   _знањ, mng_, _vegu_,
  { {0x273e00aa,0x272c001b,0x442f5fd3,0x00000000}},	//   ững_, ếng_, lng_,
  { {0x442f5fd4,0x3f8f0019,0x2d855fd5,0x00000000}},	//   ong_, _tegu_, rble_,
  { {0x442f3576,0xf3f9003b,0xa1280044,0x00000000}},	//   nng_, _biţi_, _تكمل_,
  { {0x644b01f7,0xef0e05f7,0x200f5fd6,0x00000000}},	//   ilgi, _см_, _ilgi_,
  { {0x2fcd0179,0x6f1d1088,0x2cac001f,0x00000000}},	//   leeg_, úscu, budd_,
  { {0xe480005b,0x98560002,0xa856007b,0x00000000}},	//   örüş, еташ, етај,
  { {0xf3f9000c,0xad1a0063,0x2fcd002b,0x00000000}},	//   _fiţi_, _מוצר, neeg_,
  { {0xe7370076,0x442f00a4,0xab6602ac,0x00000000}},	// [c6a0] еет_, dng_, _явил,
  { {0x442f5fd7,0x7c265fd8,0xb5fb5fd9,0x00000000}},	//   eng_, likr, _suár,
  { {0xe475000d,0xb5fb0331,0x20d10078,0x00000000}},	//   вучэ, _cuáq, _nši_,
  { {0xdb1d00c7,0x69dc049a,0x7ae45fda,0x00000000}},	//   rdsö, ldre, _krit,
  { {0x69dc5fdb,0x69ce00ca,0x20d108ed,0x00000000}},	//   odre, oebe, _aši_,
  { {0x442f0645,0xf50a0001,0x69ce5fdc,0x00000000}},	//   ang_, _енгл_, nebe,
  { {0x2bb1016a,0x69dc5fdd,0x3ce90053,0x00000000}},	//   _झाला, idre, टमों_,
  { {0x69ce00bd,0x7c2600a8,0x603300dd,0x00000000}},	//   hebe, jikr, tăma,
  { {0x61eb03e8,0x69ce1f9b,0xcf2601a7,0x00000000}},	//   állí, kebe, عربي,
  { {0xba3b4071,0x64420104,0x44265fde,0x00000000}},	//   nuït, looi, lio_,
  { {0x69dc5fdf,0x26d2001f,0xf48e0086,0x00000000}},	//   ddre, hwyo_, алiв_,
  { {0x2cac0031,0x644200e8,0x69dc5fe0,0x00000000}},	//   rudd_, nooi, edre,
  { {0xdcfa001c,0x7ae44350,0x69dc006f,0x00000000}},	//   tatē, _crit, fdre,
  { {0x69ce0199,0x7ae400bd,0x44265fe1,0x00000000}},	//   gebe, _drit, hio_,
  { {0xba3b00cd,0xdcfa001c,0x7ae4037e,0x00000000}},	//   duït, ratē, _erit,
  { {0x442610d2,0x67d40156,0x236908ed,0x00000000}},	//   jio_, лосу, žaji_,
  { {0x7ae4177e,0x4426327f,0xb5a70071,0x00000000}},	// [c6b0] _grit, dio_, ерей,
  { {0x69ce03d9,0x442f0185,0x4426017d,0x00000000}},	//   cebe, wng_, eio_,
  { {0x44260185,0xdcf8003d,0xe5c4000d,0x00000000}},	//   fio_, _ievē, ысто,
  { {0x7ae4024a,0x442f5fe2,0xf1d90053,0x00000000}},	//   _yrit, ung_, _योजन,
  { {0xba3b00cd,0xed46007e,0x026b0121,0x00000000}},	//   buït, _چپ_, чшей_,
  { {0x2fcd00e8,0xc6920047,0x442f00a4,0x00000000}},	//   weeg_, _דאך_, sng_,
  { {0x8c3d005b,0x7bcf017e,0x62992e0b,0x00000000}},	//   luğu, kecu, sswo,
  { {0x7bcf006d,0x44265fe3,0x6abd04aa,0x00000000}},	//   jecu, cio_, ktsf,
  { {0x2fcd006f,0x7bcf5fe4,0x6d4a0058,0x00000000}},	//   reeg_, decu, _ayfa,
  { {0x7d090138,0xdcf8001c,0xee390002,0x00000000}},	//   дног_, _nevē, ќно_,
  { {0x6d4a0185,0x7c2600eb,0x7ae400eb,0x00000000}},	//   _cyfa, tikr, _srit,
  { {0xa6db0026,0x6d4a001f,0x69c5004d,0x00000000}},	//   _eyði, _dyfa, _abhe,
  { {0x68e100b9,0x69ce5fe5,0x6abd00b9,0x00000000}},	//   ældn, tebe, gtsf,
  { {0x8c3d01f7,0x44265fe6,0x4a4300a0,0x00000000}},	//   duğu, zio_, иняв,
  { {0x6d4a0185,0x7ae42e0d,0x69dc05e5,0x00000000}},	//   _gyfa, _writ, rdre,
  { {0xea01001b,0x69ce5fe7,0x69dc3520,0x00000000}},	//   _đất_, sebe, sdre,
  { {0xcf9200b5,0xba3b5fe8,0xf62a0021,0x00000000}},	// [c6c0] יטן_, tuït, وسطى_,
  { {0x4426001f,0x26d2002b,0x45831681,0x00000000}},	//   wio_, rwyo_, игув,
  { {0xe3ba0001,0x64425fe9,0x44265fea,0x00000000}},	//   дбе_, tooi, tio_,
  { {0x8c3d005b,0x64a3000d,0xba3b00cd,0x00000000}},	//   buğu, раца, suït,
  { {0xc7b30132,0x69c100cd,0x6442006f,0x00000000}},	//   _דבר_, òleg, rooi,
  { {0x44265feb,0xb0c60121,0x6d4f0022,0x00000000}},	//   sio_, вщик, ęcaj,
  { {0x44265fec,0xa3dd0053,0xe123005e,0x00000000}},	//   pio_, _थोक_, имљи,
  { {0x4fd438b3,0x7bcf5fed,0x4fc60962,0x00000000}},	//   ужит, xecu, тска,
  { {0x628000e5,0xdb06004b,0x8d861dd0,0x00000000}},	//   _utmo, ngkä, кунд,
  { {0xdb250080,0x531b0063,0x44245fee,0x00000000}},	//   ásít, _חומצ, _hmm_,
  { {0x9b950f9a,0xab950054,0x6fb600de,0x00000000}},	//   линц, лині, _لمضا,
  { {0xc0060635,0x44240150,0x6abd5fef,0x00000000}},	//   _шпек, _jmm_, ttsf,
  { {0x7bcf3016,0x7a290078,0xdb1d01f2,0x00000000}},	//   recu, ežta, nesø,
  { {0x386b001f,0x7bcf4ef7,0x9e340121,0x00000000}},	//   _sicr_, secu, _щелч,
  { {0xef190051,0x99280062,0x7bcf16eb,0x00000000}},	//   daży_, вюта_, pecu,
  { {0x80ba0053,0x6e28007d,0x8c3d0058,0x00000000}},	//   _एमने, lidb, tuğu,
  { {0x7a290078,0x96354db9,0xec38009a,0x00000000}},	// [c6d0] ažta, гнац, _שאחר_,
  { {0xdb1d069f,0x6e28007d,0x44240222,0x00000000}},	//   desø, nidb, _amm_,
  { {0xd5b8005a,0xd37101a7,0x7d08002b,0x00000000}},	//   ъст_, مها_, nyds,
  { {0xa924034d,0xfbdf017d,0x68e801e1,0x00000000}},	//   ôžet, ndê_, ædde,
  { {0xeabf0290,0xd1c934ba,0x59c00042,0x00000000}},	//   ntù_, елле_, श्वर,
  { {0x26d903d9,0xddc3003b,0x20020014,0x00000000}},	//   _isso_, _minţ, ökin_,
  { {0x046702dc,0xdcfa0078,0x40940085,0x00000000}},	//   _атам, matė, арыт,
  { {0xdb1d0d02,0x6033003b,0x44245ff0,0x00000000}},	//   besø, rămo, _gmm_,
  { {0xfe450079,0x60150024,0x2f540928,0x00000000}},	//   лнио, _náme, итьс,
  { {0xdcfa0006,0xee36007f,0x7c245ff1,0x00000000}},	//   natė, лны_, _smir,
  { {0x38604303,0xbc660002,0xd00e005d,0x00000000}},	//   ymir_, лвок, زلی_,
  { {0x236901b3,0x26d90a5c,0xde95005e,0x00000000}},	//   žaju_, _osso_, _бадњ,
  { {0x645b0025,0xdddb0077,0x2ee65ff2,0x00000000}},	//   _mhui, apuš, _grof_,
  { {0x2fc60117,0xdcfa0006,0xddc3003b,0x00000000}},	//   _zbog_, jatė, _dinţ,
  { {0x26d92f14,0x485a000d,0x64490072,0x00000000}},	//   _asso_, ераў_, _okei,
  { {0x7c245ff3,0x38600014,0x7a29005f,0x00000000}},	//   _umir, umir_, ržta,
  { {0x3ebf3ea6,0x68e10137,0x6f1b004d,0x00000000}},	// [c6e0] ntut_, åldr, nzuc,
  { {0x44240089,0x64490078,0x6f090075,0x00000000}},	//   _smm_, _akei, iyec,
  { {0x26d9051e,0x645b0025,0x9c7c007d,0x00000000}},	//   _esso_, _bhui, ovča,
  { {0x645b018d,0x290a0078,0x69de5ff4,0x00000000}},	//   _chui, myba_, _hape,
  { {0x645b0025,0x25b800ac,0x14170021,0x00000000}},	//   _dhui, _tcrl_, دينة_,
  { {0x8ca40053,0x26c05ff5,0x27e05ff6,0x00000000}},	//   _किलो, mtio_, ldin_,
  { {0x645b0027,0x69de5ff7,0x26c01039,0x00000000}},	//   _fhui, _mape, ltio_,
  { {0xa6db0026,0x244e004a,0x2ee6489c,0x00000000}},	//   _eyðu, kými_, _prof_,
  { {0xa0670001,0x60e00006,0x26c05ff8,0x00000000}},	//   ћања_, _žymė, ntio_,
  { {0x26c02cd5,0x601501c2,0x290a0078,0x00000000}},	//   itio_, _ráme, kyba_,
  { {0x85f700b5,0x765c001f,0x3ebf0360,0x00000000}},	//   אציע_, _mhry, atut_,
  { {0x7d0800b9,0x69de00a4,0x290a0006,0x00000000}},	//   ryds, _aape, dyba_,
  { {0x34d10161,0x69de0150,0x27e05ff9,0x00000000}},	//   _सन्द, _bape, ddin_,
  { {0x2b93006a,0xeabf051e,0xdddb001c,0x00000000}},	//   جیکس, rtù_, ppuš,
  { {0x7d7b0047,0x7d0e00b9,0x69de3d34,0x00000000}},	//   _אנוו, øbsd, _dape,
  { {0x6c830021,0x6d585ffa,0x60150331,0x00000000}},	//   _اليم, _izva, _táme,
  { {0x47340021,0x25ab005e,0xdcfa0078,0x00000000}},	// [c6f0] مركز, еђен_, tatė,
  { {0x645b0027,0x60da0019,0x64495ffb,0x00000000}},	//   _shui, _ostm, _skei,
  { {0x6a14007e,0x9327007e,0x26c05ffc,0x00000000}},	//   _دبير, گران, atio_,
  { {0x69de2f09,0x78fa0063,0x7bdf38ae,0x00000000}},	//   _zape, _ספרו, _jaqu,
  { {0x69de0306,0x7bdf18c9,0x60da0d98,0x00000000}},	//   _yape, _maqu, _astm,
  { {0x7bdf0164,0x46680085,0x7a7c0041,0x00000000}},	//   _laqu, _брсм_, ערוס,
  { {0x3d0e0161,0x645b15bd,0xe4e40086,0x00000000}},	//   ानों_, _thui, _літн,
  { {0xdb1d0026,0x7bdf5510,0x92b70021,0x00000000}},	//   efsí, _naqu, _محطا,
  { {0xddcb003d,0x200d004d,0x6f620062,0x00000000}},	//   _augš, rkei_, овъз,
  { {0x6f1b0045,0x200d00e8,0x3ebf5ffd,0x00000000}},	//   rzuc, skei_, rtut_,
  { {0xd1310032,0xc0d5007e,0x3ebf0659,0x00000000}},	//   _بما_, _خياب, stut_,
  { {0x69de5ffe,0x6b66065b,0x91040062,0x00000000}},	//   _sape, икна, _учуд,
  { {0x7bdf0016,0x63a40025,0x2cac002b,0x00000000}},	//   _daqu, óini, ardd_,
  { {0xc3320132,0x3ead12f5,0x290a0078,0x00000000}},	//   קום_, mret_, tyba_,
  { {0x3ead00b9,0x779600e1,0x69de5fff,0x00000000}},	//   lret_, ијац, _vape,
  { {0x69de0179,0x6ca4007e,0x2247006f,0x00000000}},	//   _wape, _اصول, honk_,
  { {0xdce101f7,0x27e06000,0x765c6001,0x00000000}},	// [c700] malı, rdin_, _phry,
  { {0x45d60002,0xa9260121,0x26c06002,0x00000000}},	//   јцат, _вдол, rtio_,
  { {0x26c06003,0x799c002b,0x3ead0378,0x00000000}},	//   stio_, marw, hret_,
  { {0x3ead6004,0xdce1005b,0x987b0047,0x00000000}},	//   kret_, nalı, _שאכט,
  { {0x3ead0146,0x765c002b,0x73360021,0x00000000}},	//   jret_, _thry, جرائ,
  { {0x5bd30161,0x3ead02ab,0x2cac001f,0x00000000}},	//   _तस्व, dret_, yrdd_,
  { {0x7d070146,0x463b00b5,0xdce1005b,0x00000000}},	//   øjsl, _סעלע, kalı,
  { {0xcfe8007e,0x63bb0025,0x3ead2c6c,0x00000000}},	//   افظه_, _gcun, fret_,
  { {0x2cac0185,0x3ead3e8d,0xdefa093e,0x00000000}},	//   wrdd_, gret_, тый_,
  { {0x7bdf06d5,0x59b20042,0x3e7b002b,0x00000000}},	//   _saqu, _जागर, _dêt_,
  { {0x9c7c00c2,0x7bdf073d,0x05770063,0x00000000}},	//   avčn, _paqu, יגים_,
  { {0x3ead6005,0xdcfa001c,0x245c0124,0x00000000}},	//   bret_, latī, bíme_,
  { {0x799c0185,0x7bdf0955,0x2aab0062,0x00000000}},	//   farw, _vaqu, ътно_,
  { {0x799c001f,0x5d840021,0x5a470085,0x00000000}},	//   garw, _الغل, рэма,
  { {0x6015007a,0x6e3d00ea,0xdce1005b,0x00000000}},	//   _háma, ésbe, balı,
  { {0x20d8008b,0x68e80014,0xbeb7004c,0x00000000}},	//   _mũi_, ædda, šíře,
  { {0xdcfa003d,0x799c0022,0x78ae008f,0x00000000}},	// [c710] katī, barw, arbv,
  { {0x79a7226b,0x63bb13cb,0x6a60004d,0x00000000}},	//   _трие, _scun, eöff,
  { {0x245c0240,0x69d56006,0x356b2ceb,0x00000000}},	//   zíme_, meze, тран_,
  { {0x3ead060b,0xddc20078,0x25fb0053,0x00000000}},	//   yret_, _nuož, लॉजी_,
  { {0x60150061,0x77f6009a,0x00000000,0x00000000}},	//   _náma, _המרד_,   ,
  { {0x42240086,0xdcfa001c,0xdd2b0006,0x00000000}},	//   одів, gatī, _lėša,
  { {0x69d5006f,0x6b9d001c,0xdce1005b,0x00000000}},	//   ieze, kasg, yalı,
  { {0x3ead6007,0x245c027d,0x29380063,0x00000000}},	//   tret_, tíme_, יאון_,
  { {0x601502dd,0xe315005e,0x224700c2,0x00000000}},	//   _cáma, _умањ, ponk_,
  { {0x245c0024,0x69d500ea,0xab5b004d,0x00000000}},	//   ríme_, jeze, rfül,
  { {0xa5da0047,0x245c0114,0x20d80013,0x00000000}},	//   אַכי, síme_, _gũi_,
  { {0x32050034,0x3ead0146,0x61e11ed2,0x00000000}},	//   _holy_, pret_, _hall,
  { {0x20c1000f,0xdce1005b,0xdce7005b,0x00000000}},	//   lói_, ralı, ılık,
  { {0x69d56008,0x7d10013d,0xdce10075,0x00000000}},	//   geze, öksé, salı,
  { {0xfbdf03d9,0x61e16009,0xdce10058,0x00000000}},	//   glês_, _mall, palı,
  { {0x998c0022,0xc9550085,0x00000000,0x00000000}},	//   ódł_, ітры,   ,
  { {0x8c1b0063,0x69d5600a,0x3f7a0047,0x00000000}},	// [c720] _תופי, beze, אָבע,
  { {0x49960601,0xc1e10042,0x20c1013d,0x00000000}},	//   _ушит, पयोग, kói_,
  { {0xd910007e,0x628b00ca,0xcd9a0041,0x00000000}},	//   _غیر_, epgo, רױער,
  { {0xdb0d0019,0xad360047,0x61e10072,0x00000000}},	//   _ebaõ, זנעס_, _aall,
  { {0x6a6000bd,0xdcfa001c,0x6033003b,0x00000000}},	//   röff, tatī, cămi,
  { {0x61e1600b,0x60150066,0x6a60004d,0x00000000}},	//   _call, _ráma, söff,
  { {0x859b014e,0x61e1055b,0xdcfa001c,0x00000000}},	//   _תשלו, _dall, ratī,
  { {0x68e11c23,0x9ee80021,0x61e11de8,0x00000000}},	//   ældi, لفعل_, _eall,
  { {0xadd8005e,0xdcfa001c,0x91ba0021,0x00000000}},	//   ампу_, patī, _مطار_,
  { {0x61e104bf,0x2d980024,0x6b9d002b,0x00000000}},	//   _gall, úre_, wasg,
  { {0x2737027d,0x9c390002,0x69d5600c,0x00000000}},	//   ožné_, ипот_, veze,
  { {0x69d51c91,0x601500ea,0x806602d8,0x00000000}},	//   weze, _táma, _увеж,
  { {0x6e46000d,0x69d530e1,0x61e10168,0x00000000}},	//   _ледз, teze, _yall,
  { {0x7f3b0047,0x6b840331,0x96d00131,0x00000000}},	//   _געדו, _efig, иiот_,
  { {0x5d9b0063,0x6b84001f,0x2006006f,0x00000000}},	//   _גבוה, _ffig, _kooi_,
  { {0xb9010053,0x2d9e071d,0x69c704aa,0x00000000}},	//   _धन_, late_, sfje,
  { {0x2d9e0529,0xdb1d0051,0x20060229,0x00000000}},	// [c730] oate_, resó, _mooi_,
  { {0xdb0400bd,0x69c8004b,0x7c2f600d,0x00000000}},	//   _heiß, õdet, licr,
  { {0x4d7b00b5,0x2d9e003b,0x7aed0014,0x00000000}},	//   ארבע, iate_, _hrat,
  { {0x2006021f,0x61e1600e,0x4cbb0047,0x00000000}},	//   _nooi_, _sall, רמאג,
  { {0x61e11be8,0xdb04004d,0x2d9e600f,0x00000000}},	//   _pall, _meiß, kate_,
  { {0x2089005a,0x20c100ea,0x7d0700b9,0x00000000}},	//   айки_, tói_, øjsk,
  { {0x61e107d2,0x2d9e6010,0x6019005e,0x00000000}},	//   _vall, date_, ицир_,
  { {0x1e850095,0x60091736,0x20c129c7,0x00000000}},	//   олим, рним_, rói_,
  { {0x61e16011,0xd5c60053,0x63a96012,0x00000000}},	//   _tall, र्वज, _iden,
  { {0xd0d5005a,0x442f1781,0x644b6013,0x00000000}},	//   _мозъ, lig_, logi,
  { {0x63a4007a,0x7aed0529,0x6d4601f7,0x00000000}},	//   ðing, _arat, şkan,
  { {0x200600e8,0x442f062e,0x644b6014,0x00000000}},	//   _gooi_, nig_, nogi,
  { {0xab5b00bd,0x2d9e6015,0x6a60004d,0x00000000}},	//   nfüh, bate_, höfe,
  { {0x2d810004,0x442f6016,0xe81c0053,0x00000000}},	//   _ühe_, hig_, नसभा_,
  { {0xab5b00bd,0x63a96017,0x7aed4942,0x00000000}},	//   hfüh, _oden, _erat,
  { {0x442f00c3,0x7aed6018,0xdb04004d,0x00000000}},	//   jig_, _frat, _geiß,
  { {0x7aed6019,0x644b001f,0x245c0066,0x00000000}},	// [c740] _grat, dogi, jíma_,
  { {0x442f00cd,0x63a92ab0,0x75d60044,0x00000000}},	//   eig_, _aden, تيطا,
  { {0x442f601a,0x16000053,0x60150114,0x00000000}},	//   fig_, लॉगर_, _námo,
  { {0x2d9e0529,0xab5b004d,0x3d0a0053,0x00000000}},	//   zate_, ffüh, ाहते_,
  { {0x200600e8,0x63a919d2,0xa294000d,0x00000000}},	//   _rooi_, _dden, чалі,
  { {0x2d9e000c,0xaab20053,0x63a91f4a,0x00000000}},	//   xate_, _जिनक, _eden,
  { {0x442f601b,0x2d9e601c,0x61140086,0x00000000}},	//   big_, vate_, ядку,
  { {0x644b4e9c,0xd0070001,0x2d9e0051,0x00000000}},	//   cogi, жеће_, wate_,
  { {0x601c00ea,0x2d9e09ee,0xdb04004d,0x00000000}},	//   _néme, tate_, _reiß,
  { {0x27370013,0x70f600f2,0x2d9e00dd,0x00000000}},	//   ầng_, _وسائ, uate_,
  { {0xdca3000a,0x2d9e1d87,0x5d541a78,0x00000000}},	//   маќи, rate_, якот,
  { {0x2d9e601d,0x7aed601e,0x60d60022,0x00000000}},	//   sate_, _prat, łyms,
  { {0x6015024b,0x2d9e601f,0xdee301ce,0x00000000}},	//   _zámo, pate_, _ооци,
  { {0xdb0400bd,0x442f102c,0x7aed6020,0x00000000}},	//   _weiß, zig_, _vrat,
  { {0x69c301f7,0x644b0150,0x1959000d,0x00000000}},	//   _önem, yogi, савы_,
  { {0x442f00c7,0x2d9c00d1,0x3ea60137,0x00000000}},	//   xig_, _heve_, _kvot_,
  { {0x7c2d0035,0x442f4a67,0x660707fb,0x00000000}},	// [c750] _imar, vig_, _pojk,
  { {0x644b001f,0x442f6021,0xe29f0046,0x00000000}},	//   wogi, wig_, _æði_,
  { {0x442f442b,0x644b6022,0x7c2d0168,0x00000000}},	//   tig_, togi, _kmar,
  { {0x245c0026,0xab5b004d,0x2d9c6023,0x00000000}},	//   tíma_, tfüh, _leve_,
  { {0x386902eb,0x24580088,0x442f0ade,0x00000000}},	//   mmar_, цаць_, rig_,
  { {0x442f6024,0x38693177,0xab5b00bd,0x00000000}},	//   sig_, lmar_, rfüh,
  { {0xb8820a63,0xab5b00bd,0x644b0f89,0x00000000}},	//   žíva, sfüh, pogi,
  { {0x63a96025,0x386926c5,0x63f70044,0x00000000}},	//   _uden, nmar_, _بأسر,
  { {0x442d06bb,0x6d46005b,0x443f6026,0x00000000}},	//   _ime_, şkal, _iju_,
  { {0x60153ae8,0x7c2d0b30,0x00000000,0x00000000}},	//   _támo, _amar,   ,
  { {0x2d9c371d,0x61ee0331,0x443f0130,0x00000000}},	//   _deve_, _óbla, _kju_,
  { {0xca29014e,0xe61f0066,0xfb85014b,0x00000000}},	//   _גם_, _stôl_, дыён,
  { {0x442d0f35,0xddca004c,0x3f7a009d,0x00000000}},	//   _mme_, řiše, _האנס,
  { {0x7c2d0164,0x6033003b,0x6e92005e,0x00000000}},	//   _emar, rămu, _џију,
  { {0xfe7004de,0x395e00c7,0x442d28dc,0x00000000}},	//   _شده_, åts_, _ome_,
  { {0xbb460088,0x443f017f,0x2ca30066,0x00000000}},	//   _нейк, _nju_, ájdu_,
  { {0x25a1004d,0x28130044,0x8c1b009a,0x00000000}},	// [c760] fahl_, روكس, _לוקי,
  { {0x7c2d0051,0x2d8528cd,0x443f004b,0x00000000}},	//   _zmar, ncle_, _aju_,
  { {0x7c2d001f,0x18a3000d,0x397b0063,0x00000000}},	//   _ymar, _паэм, _לטינ,
  { {0x394d003b,0x97da0021,0xe4520049,0x00000000}},	//   şesc_, _ابدأ_, رضا_,
  { {0x201f0035,0x2bc10042,0xfbc10082,0x00000000}},	//   dhui_, ष्टा, ष्टम,
  { {0x64a66027,0x442d6028,0x5213012c,0x00000000}},	//   _нага, _eme_, ндіт,
  { {0x67246029,0xdb06013d,0xc103005d,0x00000000}},	//   lzij, egkü, فووي,
  { {0xd0100032,0xdfda005a,0x853b0063,0x00000000}},	//   ئلة_, сък_, _הגלי,
  { {0x64430153,0x04435b53,0x67241286,0x00000000}},	//   énie, _четн, nzij,
  { {0xab5b0994,0x63a20139,0x7c2d602a,0x00000000}},	//   ngüe, laon, _smar,
  { {0x78450078,0x272c008d,0xdb1d00a5,0x00000000}},	//   lėve, ếnh_, nesö,
  { {0x25a10199,0x63a20009,0xbb940076,0x00000000}},	//   zahl_, naon, нающ,
  { {0x2d9c0016,0x6724602b,0x69c30058,0x00000000}},	//   _teve_, jzij, _önek,
  { {0x58d50086,0x6724006f,0x63a20139,0x00000000}},	//   могт, dzij, haon,
  { {0xee290021,0x26000053,0x63a2602c,0x00000000}},	//   _بأنه_, रानी_, kaon,
  { {0xab5b0268,0x63a221a8,0x25a1004d,0x00000000}},	//   egüe, jaon, wahl_,
  { {0xdce801f7,0x386905ca,0xf77f1997,0x00000000}},	// [c770] madı, rmar_, _caça_,
  { {0xdce8005b,0x442d14d5,0x443f0ddc,0x00000000}},	//   ladı, _sme_, _sju_,
  { {0xf6500032,0x387400cd,0xb883004c,0x00000000}},	//   ائق_, çarà_, říbr,
  { {0xf77f0016,0xd37108aa,0x53350121,0x00000000}},	//   _faça_, نها_, меет,
  { {0x27e9602d,0x2d851098,0x14740021,0x00000000}},	//   mdan_, ycle_, رامج,
  { {0x27e9602e,0xdb1d0137,0x96fa009a,0x00000000}},	//   ldan_, besö, _ולשת,
  { {0xa4d40086,0x9f430080,0x660300fe,0x00000000}},	//   _порі, ějí_, önku,
  { {0x27e92f70,0x442d52d0,0xdb1d004e,0x00000000}},	//   ndan_, _ume_, lesõ,
  { {0x27e900c7,0x62790066,0x26c9602f,0x00000000}},	//   idan_, _dňoc, ntao_,
  { {0x27e900fe,0xe165007e,0x64592c0e,0x00000000}},	//   hdan_, _قضای, llwi,
  { {0x4d65019d,0x27e900a4,0x4155000d,0x00000000}},	//   ьков, kdan_, _ўвес,
  { {0x443d001f,0x3f150156,0x2d85089c,0x00000000}},	//   nnw_, _одес, scle_,
  { {0x27e90ea7,0xe1e7005d,0x26000082,0x00000000}},	//   ddan_, پس_, रामी_,
  { {0x27e96030,0x9e640086,0xf77f04a5,0x00000000}},	//   edan_, _звід, _raça_,
  { {0x63a20035,0x601c0003,0x00000000,0x00000000}},	//   yaon, _héma,   ,
  { {0x6f160045,0x1dbd0053,0x27e96031,0x00000000}},	//   _życi, ्भवत, gdan_,
  { {0x060a000d,0x63a2007d,0xe5a601e2,0x00000000}},	// [c780] онак_, vaon, дизи,
  { {0x67246032,0x27e93ad5,0x7ae46033,0x00000000}},	//   rzij, adan_, _isit,
  { {0x9f420024,0x26c90035,0x63a24e0f,0x00000000}},	//   ľké_, atao_, taon,
  { {0xf77f017d,0x69dc6034,0x77830062,0x00000000}},	//   _taça_, lere, _илюз,
  { {0x69dc006f,0x63a26035,0x926a0cd6,0x00000000}},	//   oere, raon, орка_,
  { {0x201d0089,0x69dc23c9,0x66210051,0x00000000}},	//   _alwi_, nere, ązkó,
  { {0x3a370063,0xdce80058,0x64436036,0x00000000}},	//   ורסם_, yadı, énic,
  { {0xa50b0063,0x69dc6037,0x7ae46038,0x00000000}},	//   _וּמִ, here, _osit,
  { {0x69dc6039,0xa1c6005a,0xa2890021,0x00000000}},	//   kere, _обад, _فضلك_,
  { {0x27e901f7,0x601c0164,0x69dc603a,0x00000000}},	//   zdan_, _déma, jere,
  { {0xfe6f0032,0x45b70063,0x61fa25be,0x00000000}},	//   جدي_, ופיל_, _intl,
  { {0x78bc007a,0x61e8603b,0x69ce006f,0x00000000}},	//   durv, _hadl, efbe,
  { {0xdce8005b,0x69dc03db,0x63a0404d,0x00000000}},	//   radı, fere, _memn,
  { {0x69dc603c,0xdce8005b,0x3a74000d,0x00000000}},	//   gere, sadı, кляр,
  { {0x6ce60086,0x7ae4603d,0x61e8603e,0x00000000}},	//   _ціле, _esit, _madl,
  { {0x63a0603f,0xb9070161,0x9998005f,0x00000000}},	//   _nemn, _मई_, forų_,
  { {0xfc3f0080,0x61fa0250,0xf1ca0024,0x00000000}},	// [c790] mní_, _ontl, _kráľ_,
  { {0xfc3f0080,0xea01001b,0x69dc6040,0x00000000}},	//   lní_, _đặt_, cere,
  { {0x26c9017f,0xe5c4005a,0x78bc0d5f,0x00000000}},	//   stao_, ъсто, curv,
  { {0xfc3f6041,0x628000a4,0x7bdd011d,0x00000000}},	//   nní_, _bumo, nesu,
  { {0x320c0513,0xe2990098,0x6747000d,0x00000000}},	//   _body_, чал_, _цэнз,
  { {0x11d90032,0xaab20161,0xdb2600ea,0x00000000}},	//   سوعة_, _जिसक, épér,
  { {0x69c50035,0x61e8001f,0x03c72e2f,0x00000000}},	//   _mche, _dadl, _осам,
  { {0x61fa00bd,0xfc3f004a,0x69dc4ba3,0x00000000}},	//   _entl, jní_, zere,
  { {0xfc3f0080,0x7a220164,0x69dc005b,0x00000000}},	//   dní_, _hôte, yere,
  { {0x69dc02b0,0xfc3f0080,0x6cea0053,0x00000000}},	//   xere, ení_, टिंग_,
  { {0x6015006d,0x7ae40290,0x82340021,0x00000000}},	//   _lámi, _ssit, _شركا,
  { {0xeb970055,0x69c522fb,0x601c2f90,0x00000000}},	//   нию_, _ache, _téma,
  { {0x4b550062,0x69dc0a66,0x6d5c0014,0x00000000}},	//   върт, tere, ýrar,
  { {0x78bc4173,0x69dc6042,0x7d0701e1,0x00000000}},	//   turv, uere, øjss,
  { {0xfc3f0080,0xc2120063,0x69dc23c9,0x00000000}},	//   bní_, נהל_, rere,
  { {0x7bdd0529,0x7ae40004,0x69dc05e5,0x00000000}},	//   cesu, _tsit, sere,
  { {0x69dc6043,0x7ae407d5,0x63a000e5,0x00000000}},	// [c7a0] pere, _usit, _remn,
  { {0x63a00529,0xf77f0016,0x6280095b,0x00000000}},	//   _semn, _faço_, _rumo,
  { {0x62806044,0x7a226045,0xd4990054,0x00000000}},	//   _sumo, _côte, дрі_,
  { {0x61e823db,0x6280004c,0x98160044,0x00000000}},	//   _sadl, _pumo, _أبدا,
  { {0x08770047,0x61e86046,0x69c500a3,0x00000000}},	//   _רעכט_, _padl, _yche,
  { {0xfc3f0080,0x35c60161,0x7d0e00b9,0x00000000}},	//   zní_, र्ख़, øbsk,
  { {0x61e8001c,0xfc3f0080,0xe6430156,0x00000000}},	//   _vadl, yní_, _серп,
  { {0x320c0051,0xefb2007e,0xbed40699,0x00000000}},	//   _wody_, ایشگ, воиј,
  { {0xfc3f0080,0x63760075,0xc2463d6d,0x00000000}},	//   vní_, _dünü, _знак,
  { {0x6abd004b,0x00000000,0x00000000,0x00000000}},	//   vusf,   ,   ,
  { {0xfc3f01c2,0xd622000d,0xddc300a8,0x00000000}},	//   tní_, нiка, _finž,
  { {0x6376005b,0x69c5400b,0x6abd0ef5,0x00000000}},	//   _günü, _sche, tusf,
  { {0xfc3f01da,0x7bdd6047,0x601c0003,0x00000000}},	//   rní_, resu, _hémo,
  { {0xf77f017d,0x4efb0063,0xfc3f0114,0x00000000}},	//   _paço_, _מהדו, sní_,
  { {0xfc3f0240,0x248d007d,0x7bdd6048,0x00000000}},	//   pní_, _čemo_, pesu,
  { {0x601c0164,0x6aab01e1,0x36d53e42,0x00000000}},	//   _mémo, _ægfo, кобр,
  { {0xfc400080,0x69c5048c,0x7d1c00b9,0x00000000}},	// [c7b0] čít_, _tche, ørsf,
  { {0x63a4007a,0x69c5001f,0x9634000d,0x00000000}},	//   ðinn, _uche, гнуц,
  { {0xe1ff00aa,0xd5b8000d,0x44200085,0x00000000}},	//   _đó_, эст_, гi_,
  { {0x9f5f0026,0x6a60004d,0x69cd0042,0x00000000}},	//   kkuð_, höfl, द्री,
  { {0x8627000d,0xfbd30042,0x2bd30042,0x00000000}},	//   _зьве, ध्यम, ध्या,
  { {0x1a9c0047,0x26d96049,0x601c0003,0x00000000}},	//   לידע, _ipso_, _bémo,
  { {0x2ee600e8,0x9f5f01a8,0x33950044,0x00000000}},	//   _asof_, rjuí_, _للأز,
  { {0x601c03b2,0x8f75013c,0x7f750366,0x00000000}},	//   _démo, купі, купц,
  { {0xdb0d0331,0xd00e0044,0x427525de,0x00000000}},	//   _ocañ, تلي_, _агас,
  { {0x273e001b,0x6b8d04a5,0x2c7b0078,0x00000000}},	//   ắng_, _afag, _rūda_,
  { {0x644a006c,0x25a3604a,0xc5f2009a,0x00000000}},	//   éfig, _mejl_, בדי_,
  { {0x7bcb0046,0xdeb50085,0x00000000,0x00000000}},	//   _ögul, _абды,   ,
  { {0x683a004c,0xef0e204c,0x1c430145,0x00000000}},	//   hůdc, _тм_, рням,
  { {0xc3320063,0xa96a0cb2,0x200f002b,0x00000000}},	//   שוך_, дига_, _hogi_,
  { {0x3ebf1986,0x6b8d002b,0xc8b50121,0x00000000}},	//   luut_, _ffag, лсты,
  { {0xf7720032,0xab5b1fa3,0x200f0758,0x00000000}},	//   لاء_, rfür, _jogi_,
  { {0x3ebf0162,0xc8690047,0x7c650021,0x00000000}},	// [c7c0] nuut_, ַן_, _حاول,
  { {0xdb040016,0x200f37d4,0x395a004d,0x00000000}},	//   _adiç, _logi_, _typs_,
  { {0xd4f5000d,0xd6e20022,0x68460e82,0x00000000}},	//   ляцы, _siłą_, _анна,
  { {0xb4d20053,0x4420604b,0x7af61026,0x00000000}},	//   _वही_, ói_, _kryt,
  { {0x25a3010a,0x245c0080,0x27e04d5c,0x00000000}},	//   _fejl_, ními_, mein_,
  { {0xdb040016,0x62630086,0x69c30058,0x00000000}},	//   _ediç, авча, _önet,
  { {0xb606008f,0xc0ca0002,0x9f420066,0x00000000}},	//   rešā, фуле_, ľkí_,
  { {0x68230019,0x27e01a14,0x40340131,0x00000000}},	//   _tõde, nein_, ѓепс,
  { {0x6a600026,0x2e4a005a,0xa067005e,0x00000000}},	//   töfl, дяно_, њања_,
  { {0x442603d9,0x601c604c,0x27e0004d,0x00000000}},	//   lho_, _témo, hein_,
  { {0x27e000fe,0x55bb0063,0x44260114,0x00000000}},	//   kein_, ומיו, oho_,
  { {0x442603d9,0x3ebf15dc,0x644257b9,0x00000000}},	//   nho_, buut_, nnoi,
  { {0x29180014,0x3fcb005d,0x64420072,0x00000000}},	//   eyra_, _آدمی_, inoi,
  { {0x3eb9034d,0xeef7009a,0x8cf40044,0x00000000}},	//   áste_, _שמגר_, _مكتش,
  { {0x442600e8,0x27e015f8,0x19580895,0x00000000}},	//   kho_, fein_, вары_,
  { {0x44260024,0x7c26004d,0xfbdf00be,0x00000000}},	//   jho_, chkr, roês_,
  { {0x44260150,0x245c004a,0x163b0021,0x00000000}},	// [c7d0] dho_, cími_, وسطة_,
  { {0x2fdf00bd,0x44260240,0x8b580063,0x00000000}},	//   zeug_, eho_, _ביחס_,
  { {0x9f4f0137,0xf96b0456,0x27e021ab,0x00000000}},	//   _ingå_, _юрий_, bein_,
  { {0x6442066d,0x93940044,0x88f6009a,0x00000000}},	//   gnoi, لجها, _עזרו_,
  { {0x6746034d,0x1dc20161,0xab5b0058,0x00000000}},	//   čujú, _शांत, zgün,
  { {0x78ba017f,0x21692b31,0x644247d9,0x00000000}},	//   štve, нили_, anoi,
  { {0x16340121,0x41b4000d,0x2055006e,0x00000000}},	//   _теря, рсіт, лтир,
  { {0x4426604d,0x63ad0026,0x3fe514cf,0x00000000}},	//   cho_, ðand, ужив,
  { {0xcf390085,0xa3c20042,0x00000000,0x00000000}},	//   эчкі_, ्भर_,   ,
  { {0x7d090001,0x2c7b0078,0x60e80072,0x00000000}},	//   еног_, _būdo_, äsmä,
  { {0x6cc50088,0x26c00035,0x61130080,0x00000000}},	//   ыйна, zuio_, _dělá,
  { {0xab2a005e,0x9ef5009e,0x245c403d,0x00000000}},	//   еома_, _مستش, tími_,
  { {0xdd030058,0x00000000,0x00000000,0x00000000}},	//   ısıd,   ,   ,
  { {0x3ead604e,0x291823a8,0x27e0604f,0x00000000}},	//   mset_, tyra_, wein_,
  { {0x69a50053,0x3ead6050,0x27e06051,0x00000000}},	//   _क़री, lset_, tein_,
  { {0x7d1c0dfb,0x3f8d0bc8,0x3ff90047,0x00000000}},	//   ørse, nceu_, עפּע,
  { {0x44260024,0x291e6052,0x7d0e00b9,0x00000000}},	// [c7e0] vho_, šta_, øbsv,
  { {0x3ead024a,0xdb06108e,0x27e06053,0x00000000}},	//   iset_, jaké, sein_,
  { {0xe3ba08ef,0x44266054,0xab5b004d,0x00000000}},	//   ебе_, tho_, hgül,
  { {0x3ead6055,0x69c301f7,0x2497006a,0x00000000}},	//   kset_, _öner, انند_,
  { {0xf772006a,0x3ead00c2,0x26c02a64,0x00000000}},	//   _داد_, jset_, quio_,
  { {0x442610ca,0xe2970001,0xab5b00bd,0x00000000}},	//   sho_, ћај_, dgül,
  { {0x60150026,0x44266056,0xe0cf0021,0x00000000}},	//   _náms, pho_, كزي_,
  { {0xdfd00021,0x4fc66057,0x321c0061,0x00000000}},	//   آية_, уска, skvy_,
  { {0x63ad0026,0x44246058,0x741301fb,0x00000000}},	//   ðane, _ilm_, _اوقا,
  { {0x7c24003e,0x44246059,0x3cd4000d,0x00000000}},	//   _alir, _hlm_, ажос,
  { {0x3860605a,0xd6570063,0x3ead5b7a,0x00000000}},	//   klir_, ריית_, aset_,
  { {0x7c240e2f,0x60150061,0xdb1d0014,0x00000000}},	//   _clir, _dáms, rfsþ,
  { {0x442405d8,0x3860002b,0x2bc60042,0x00000000}},	//   _mlm_, dlir_, _वारा,
  { {0x7bc600a4,0x38600058,0x7c360078,0x00000000}},	//   agku, elir_, _emyr,
  { {0xbd55007e,0x195927b8,0x286b005e,0x00000000}},	//   _پروژ, тавы_, ерао_,
  { {0x7c24002b,0x6d460058,0x387d002b,0x00000000}},	//   _glir, şkas, öwr_,
  { {0x245c0080,0xd5bb032d,0x96350349,0x00000000}},	// [c7f0] nímu_, есе_, анац,
  { {0x3860006d,0x4424605b,0xa7740816,0x00000000}},	//   alir_, _alm_, случ,
  { {0x38600bbd,0x7c36001f,0x9475007e,0x00000000}},	//   blir_, _ymyr, لگرا,
  { {0x69c71609,0x3ead04d1,0x3e6b04aa,0x00000000}},	//   lgje, yset_, møte_,
  { {0x442409e9,0x245c004c,0x83880054,0x00000000}},	//   _dlm_, jímu_, убів_,
  { {0x44e5001f,0x3ead0019,0x69d5004d,0x00000000}},	//   _tŷ_, vset_, nfze,
  { {0x6e3a27a8,0x4094000d,0x644a1f20,0x00000000}},	//   ditb, брыт, éfic,
  { {0x3ead2043,0xe3b30049,0xb97c0041,0x00000000}},	//   tset_, _درس_, ענהי,
  { {0x99830006,0x3f8d605c,0x645b0072,0x00000000}},	//   nijų_, rceu_, _ikui,
  { {0x3f8d0016,0xab5b005b,0x63ab161b,0x00000000}},	//   sceu_, rgül, lagn,
  { {0x9f420024,0x3ead3451,0x6abd00ac,0x00000000}},	//   ľká_, sset_, ersf,
  { {0x69c7000f,0x61e30f99,0x76570013,0x00000000}},	//   egje, lenl, hoxy,
  { {0xde05019d,0x60c301f7,0x501a0063,0x00000000}},	//   _впли, lunm, _שונו,
  { {0x7a2b04ab,0x672d0d10,0x8d8701dd,0x00000000}},	//   _lütf, dzaj, _судд,
  { {0xc87f004d,0x7d0e05a5,0x61e30a52,0x00000000}},	//   _biß_, øbst, ienl,
  { {0x63ab017f,0x7c2400a4,0x61e3050c,0x00000000}},	//   jagn, _ulir, henl,

  { {0x63ab051e,0x99830006,0x6f1b0089,0x00000000}},	// [c800] dagn, gijų_, nyuc,
  { {0x645b0150,0xf98a0021,0x7ae90058,0x00000000}},	//   _akui, _جندي_, çete,
  { {0x20d1001b,0x84e60905,0x38605f42,0x00000000}},	//   _nơi_, роеж, plir_,
  { {0x63ab605d,0x74690054,0xe29a536d,0x00000000}},	//   gagn, грів_, вад_,
  { {0xf1940bb3,0x998300eb,0x672d0045,0x00000000}},	//   биль, cijų_, czaj,
  { {0x425600d7,0x61e31ed7,0x645b0360,0x00000000}},	//   штет, genl, _ekui,
  { {0x03a6019d,0x601c0003,0xa491007e,0x00000000}},	//   _вибо, _hémi, _فیلت,
  { {0xdfda005a,0xdb0b005b,0x20d10013,0x00000000}},	//   тък_, _çiçe, _dơi_,
  { {0x26d20150,0xe61f0013,0xde880013,0x00000000}},	//   ntyo_, _muôn_, _bịa_,
  { {0x20d6019d,0x3eb800c3,0xe61f001b,0x00000000}},	//   _відс, črt_, _luôn_,
  { {0x6e3a0838,0x99830078,0xefca005e,0x00000000}},	//   ritb, zijų_, _алел_,
  { {0x6e3a0ef2,0xab5b004b,0x711b009a,0x00000000}},	//   sitb, sgüm, _שואפ,
  { {0x6e940032,0x27f20185,0x5e940021,0x00000000}},	//   _التا, ddyn_, _التط,
  { {0x6aa40089,0x27f2002b,0x69d5004d,0x00000000}},	//   _dwif, edyn_, ufze,
  { {0x69c700d1,0xe61f008b,0x97a7012d,0x00000000}},	//   rgje, _buôn_, ирал,
  { {0x61e301f7,0x7aec00fe,0x69c7069f,0x00000000}},	//   zenl, ältä, sgje,
  { {0xf773006a,0x69d500bd,0x7c3d021e,0x00000000}},	// [c810] زار_, pfze, misr,
  { {0x60c300bb,0x645b00e8,0x99830006,0x00000000}},	//   yunm, _skui, rijų_,
  { {0x228b1609,0xb4c1016a,0x63ab605e,0x00000000}},	//   _søk_, ंढे_, tagn,
  { {0x601c0164,0x60c3005b,0x20d1008b,0x00000000}},	//   _fémi, vunm, _rơi_,
  { {0x61e3605f,0xc293007e,0x601c0153,0x00000000}},	//   tenl, زیاب, _gémi,
  { {0xdcee004c,0xe2960062,0x63ab5a99,0x00000000}},	//   áděj, щаш_, sagn,
  { {0x61e32d0a,0x63ab6060,0xd24e0021,0x00000000}},	//   renl, pagn, عنى_,
  { {0x1ec90076,0x13aa007e,0x60c3005b,0x00000000}},	//   глии_, _منفی_, runm,
  { {0x64590051,0x61e3191d,0xa2940054,0x00000000}},	//   mowi, penl, _маті,
  { {0x2d83010a,0x20d1008b,0x7985001f,0x00000000}},	//   øje_, _tơi_, _nghw,
  { {0x3085043b,0x90996061,0x718c0047,0x00000000}},	//   _الصف, _свет_, _סװאַ,
  { {0x64590045,0x6281006d,0x1dd80053,0x00000000}},	//   nowi, _hilo, ब्बत,
  { {0x7aed000f,0x6281579e,0x63a96062,0x00000000}},	//   _csat, _kilo, _meen,
  { {0x2bb8008b,0xa3d70053,0x63a9387e,0x00000000}},	//   ọc_, ़्त_, _leen,
  { {0x7aed6063,0x64590051,0x601c0003,0x00000000}},	//   _esat, kowi, _sémi,
  { {0xdb0600ea,0x63a96064,0x60dc004d,0x00000000}},	//   lakí, _neen, _ärme,
  { {0x64590051,0x27f2001f,0x3f9f0089,0x00000000}},	// [c820] dowi, rdyn_, ibuu_,
  { {0x62816065,0x2d9a004b,0xd0f90053,0x00000000}},	//   _nilo, _õpet_, ्माण_,
  { {0x2e3a00b5,0x63a905e4,0x3e3a0047,0x00000000}},	//   נגענ, _been, נגעװ,
  { {0xdc190045,0x6281001f,0x3ebf0052,0x00000000}},	//   _błęd, _ailo, krut_,
  { {0x63a90250,0x6d5c0240,0x62816066,0x00000000}},	//   _deen, ýraz, _bilo,
  { {0x60150139,0x765c6067,0x6281002b,0x00000000}},	//   _sámp, _ukry, _cilo,
  { {0x64590051,0xf0b7007e,0x6281017e,0x00000000}},	//   bowi, مايش_, _dilo,
  { {0x24b7014e,0x30140086,0xf2e8007e,0x00000000}},	//   _להלן_, ідпр, _نکته_,
  { {0x7a2b004d,0x62816068,0x05cf0042,0x00000000}},	//   _hüte, _filo, स्कब,
  { {0x26c0001f,0x7bcd1826,0xacb4005e,0x00000000}},	//   irio_, _scau, обољ,
  { {0xa3bc0053,0x8fa6007e,0x7c3d021e,0x00000000}},	//   _आया_, _هماه, tisr,
  { {0x7f860032,0x26c00ef0,0x62816069,0x00000000}},	//   _الإن, krio_, _zilo,
  { {0xe0430055,0x643b00b5,0x3ebf006c,0x00000000}},	//   _энци, רעכנ, crut_,
  { {0x2003001c,0x64590051,0x26c0606a,0x00000000}},	//   ējie_, zowi, drio_,
  { {0xde88008d,0x66150a28,0x6c350044,0x00000000}},	//   _xịn_, _rozk, _وفتا,
  { {0x2c7b003d,0x26c0606b,0x8c44005e,0x00000000}},	//   _līdz_, frio_, _неје,
  { {0x7aed0682,0x98aa001c,0x63a9073d,0x00000000}},	// [c830] _usat, ākās_, _reen,
  { {0x644a606c,0x25aa002b,0x64590022,0x00000000}},	//   éfin, _cebl_, wowi,
  { {0x26c0606d,0x657a0026,0x645908ae,0x00000000}},	//   ario_, _úthl, towi,
  { {0xdb0600ea,0x26c0606e,0x69da004b,0x00000000}},	//   zakí, brio_, õtev,
  { {0xa235000d,0x248d1aa5,0x443d002b,0x00000000}},	//   жэйш, _čemu_, riw_,
  { {0x63a90438,0x43740054,0xcad80063,0x00000000}},	//   _ween, чуєт, צוות_,
  { {0x64590045,0x7a2b00bd,0x63a9010e,0x00000000}},	//   powi, _güte, _teen,
  { {0x682a0080,0xe0d6000d,0x644301a8,0x00000000}},	//   _týde, івы_, ènid,
  { {0x6281606f,0x63b40080,0x3ebf1b19,0x00000000}},	//   _tilo, řený, urut_,
  { {0x7fb9006a,0xfe420086,0x3ebf01e9,0x00000000}},	//   _چهار_, дньо, rrut_,
  { {0x51f40021,0x7d0e00b9,0xfc3f004a,0x00000000}},	//   _عسكر, øbsp, fií_,
  { {0x5f74007e,0xdb0f00be,0xfc3f0114,0x00000000}},	//   _کامر, macê, gií_,
  { {0x62790066,0x5ac70062,0x99f60054,0x00000000}},	//   _dňov, олям_, ояві,
  { {0xa2cc0161,0x601c006c,0xdca519b6,0x00000000}},	//   _समस्, _dému, _даки,
  { {0x26c0002b,0xfc320044,0xf9830263,0x00000000}},	//   wrio_, _يحب_, дгро,
  { {0xfc3f14c0,0x57ea0002,0x26c00aca,0x00000000}},	//   cií_, јдам_, trio_,
  { {0x32050037,0xba760021,0x26c00078,0x00000000}},	// [c840] _only_, _واخت, urio_,
  { {0x26c0141a,0x6a600026,0x63ad0026,0x00000000}},	//   rrio_, töfu, ðann,
  { {0xae560041,0x186a16fc,0xd3020042,0x00000000}},	//   קסעס_, _вани_, लम्ब_,
  { {0xf8b3014e,0x26c06070,0x6a600026,0x00000000}},	//   _קשר_, prio_, röfu,
  { {0x6a7200b9,0x7a2b004d,0xe2f80083,0x00000000}},	//   ræff, _wüte, селі_,
  { {0xfc3f0195,0x64a60c46,0x5ba70042,0x00000000}},	//   zií_, _мага, _ख़्व,
  { {0x628f0164,0x3ea66071,0x4fc61dc6,0x00000000}},	//   _écon, _swot_, оспа,
  { {0x297b00b5,0xdfd00067,0x78450078,0x00000000}},	//   סטקא, ريخ_, tėvi,
  { {0x63a20277,0x63a40026,0xe2971c7a,0x00000000}},	//   mbon, ðinu, _мат_,
  { {0xddd8027c,0xba3b00ac,0x601c0003,0x00000000}},	//   _bivš, opïe, _rému,
  { {0xccf8011b,0x527501ce,0xc27b009a,0x00000000}},	//   uvě_, _хуту, _כרמי,
  { {0x2d8702ab,0xbb940121,0x63a210f9,0x00000000}},	//   _egne_, мающ, nbon,
  { {0x447b0047,0xa3dc0053,0xfc3f004a,0x00000000}},	//   ינטע, त्य_, rií_,
  { {0xfc3f0024,0x220a0063,0x44ec00e5,0x00000000}},	//   sií_, ׁפָּ, _oſ_,
  { {0x63a26072,0x7d1c0137,0x35dd0042,0x00000000}},	//   kbon, ärsd, न्फ़,
  { {0xa3dc0053,0x7a3000a5,0x2484004d,0x00000000}},	//   त्म_, _nätf, _nimm_,
  { {0x36d40055,0x4735000d,0xc58b0121,0x00000000}},	// [c850] мотр, чнас, ащее_,
  { {0x69da004b,0x63a26073,0x41c90042,0x00000000}},	//   õtet, ebon, _राइस,
  { {0xbebd109f,0x5bc40043,0x00000000,0x00000000}},	//   nzūr, _عقیل,   ,
  { {0x4429008b,0x69080063,0x58fa0047,0x00000000}},	//   óa_, _וּשְ, _פּינ,
  { {0x2338000d,0x27e93697,0xc6f81afc,0x00000000}},	//   опцы_, mean_, _днях_,
  { {0xa2cc0161,0xd25b000d,0xf6790047,0x00000000}},	//   _समर्, шце_, _לאָמ,
  { {0x7d1c0205,0x24840026,0xd4980002,0x00000000}},	//   ørsl, _fimm_, _мрт_,
  { {0x03c400d7,0xe7cb0053,0x68330078,0x00000000}},	//   _осум, िलिप, _uždė,
  { {0xe293007e,0xee390251,0x644b0137,0x00000000}},	//   _آذر_, йни_, mngi,
  { {0xdb0f01a8,0xf1a7015b,0xfe71005d,0x00000000}},	//   macè, _фран, رگش_,
  { {0x80a40032,0x27e900fe,0x644b6074,0x00000000}},	//   _يمكن, kean_, ongi,
  { {0xf0f90053,0x2e290066,0x27e96075,0x00000000}},	//   ्मीद_, _dúfa_, jean_,
  { {0xf1d20235,0x644b6076,0x4b230062,0x00000000}},	//   _सामन, ingi, емяв,
  { {0x2896007b,0x98c5004c,0x63a22a2b,0x00000000}},	//   зјас, _útěk_, zbon,
  { {0xdcfe003b,0x26cf01a8,0x52c80042,0x00000000}},	//   ăvăl, àgon_, _रम्स,
  { {0x2c7b0006,0x2fcd001f,0x27e919d9,0x00000000}},	//   _būdu_, ngeg_, gean_,
  { {0x99550080,0x6f160051,0x0cdb0053,0x00000000}},	// [c860] _výši_, _życz, _बहुम,
  { {0x63bb6077,0x7ae400a4,0xd4d6000d,0x00000000}},	//   _adun, _ipit, зідэ,
  { {0x629b017d,0x7c260026,0x644b0014,0x00000000}},	//   _atuo, okkr, fngi,
  { {0x69dc2a38,0x9f420066,0xd344007e,0x00000000}},	//   lfre, ľkú_, وفای,
  { {0x628f0164,0x69ce2a76,0x63a26078,0x00000000}},	//   _écol, ogbe, rbon,
  { {0x30a60169,0x644b6079,0x69ce4e2e,0x00000000}},	//   прив, angi, ngbe,
  { {0x7a220003,0x629b0072,0x69dc0b91,0x00000000}},	//   _côti, _etuo, ifre,
  { {0x7d1c076c,0x92c101f7,0x69dc09fd,0x00000000}},	//   ørsm, üğün, hfre,
  { {0x69dc0c42,0x644200fe,0x4426607a,0x00000000}},	//   kfre, mioi, mko_,
  { {0xd737014e,0x4426607b,0x765e00a4,0x00000000}},	//   פטית_, lko_, nopy,
  { {0xdb0f006d,0x4426607c,0xc19b0063,0x00000000}},	//   macé, oko_, _השבי,
  { {0xdb0f0164,0x4426607d,0x61ea01a8,0x00000000}},	//   lacé, nko_, lefl,
  { {0x765e607e,0x27e9177c,0x69dc607f,0x00000000}},	//   kopy, vean_, ffre,
  { {0xeb9f0031,0xdb04006d,0xa3dc0053,0x00000000}},	//   gjør_, _adió, त्त_,
  { {0x4426024a,0x69ce0053,0x78a9007d,0x00000000}},	//   kko_, _तारी, ćevo,
  { {0xdc2b007e,0x69ce00a4,0x4426394e,0x00000000}},	//   _دسته_, agbe, jko_,
  { {0xa3c20161,0x644b05dd,0x3bbc0063,0x00000000}},	// [c870] ूलन_, vngi, _המחד,
  { {0x682a0240,0xa3cf0053,0x27e96080,0x00000000}},	//   _výda, _शाह_, sean_,
  { {0x61ea01f7,0xb8350076,0x27e96081,0x00000000}},	//   defl, _женщ, pean_,
  { {0x644b6082,0x442600a4,0xc9526083,0x00000000}},	//   ungi, gko_, _ימי_,
  { {0x24580088,0x38694cc8,0x9259007e,0x00000000}},	//   чаць_, mlar_, يشتر_,
  { {0x7c2d0268,0xdd860754,0x44266084,0x00000000}},	//   _llar, _لو_, ako_,
  { {0x7c2d04ab,0xe61f008b,0x2c56001c,0x00000000}},	//   _olar, _nuôi_, lāde_,
  { {0xb69b03b2,0x386901f7,0x7e68006f,0x00000000}},	//   _grâc, nlar_, eldp,
  { {0x443f0035,0x69dc001f,0xdb1d0025,0x00000000}},	//   _imu_, yfre, agsú,
  { {0x41b5007e,0x2fcd002b,0x3869107b,0x00000000}},	//   _آمار, sgeg_, hlar_,
  { {0x7a3000fe,0x1bea0afc,0x38696085,0x00000000}},	//   _jäte, одни_, klar_,
  { {0x3869005b,0x7a300137,0xeb970121,0x00000000}},	//   jlar_, _mäte, мию_,
  { {0x38696086,0xb0dd0053,0x765e0058,0x00000000}},	//   dlar_, _महँग, yopy,
  { {0x442d54f4,0xdde9007e,0x44261ef3,0x00000000}},	//   _lle_, _گرچه_, zko_,
  { {0x7a3000c7,0x291e000c,0x442628d2,0x00000000}},	//   _näte, âta_, yko_,
  { {0x386950d3,0x683102f0,0x69dc0f4b,0x00000000}},	//   glar_, _nådd, sfre,
  { {0x7ae4017f,0x644200fe,0x2c56001c,0x00000000}},	// [c880] _upit, vioi, gāde_,
  { {0x7a2b0019,0x44260051,0x69c00006,0x00000000}},	//   _tüta, wko_, ėmes,
  { {0x442d3051,0x38696087,0x644200fe,0x00000000}},	//   _ble_, blar_, tioi,
  { {0x683117d5,0xddc10124,0x38696088,0x00000000}},	//   _rådg, silň, clar_,
  { {0x442d0080,0x644200fe,0x44261286,0x00000000}},	//   _dle_, rioi, rko_,
  { {0x20ee0080,0x38600164,0x442d6089,0x00000000}},	//   _při_, loir_, _ele_,
  { {0x442600c3,0x644200fe,0xc0e3018e,0x00000000}},	//   pko_, pioi, војк,
  { {0xd010043b,0x68e31c3f,0x61ea608a,0x00000000}},	//   الة_, _ände, sefl,
  { {0x661c608b,0x7a300137,0x6440561d,0x00000000}},	//   _kork, _mätb, _immi,
  { {0x20ee0080,0x2d8a00b9,0x3869005b,0x00000000}},	//   _tři_, øbe_, zlar_,
  { {0x44fe00eb,0x3869005b,0xdc3a0058,0x00000000}},	//   _jį_, ylar_, _açın,
  { {0x386900c7,0xdb0600fe,0x26050053,0x00000000}},	//   xlar_, kakä, _होनी_,
  { {0xdb0600fe,0x661c0250,0x62880441,0x00000000}},	//   jakä, _oork, _kido,
  { {0x68310146,0x7d2700ea,0x7afd05e7,0x00000000}},	//   _måde, össé, rvst,
  { {0x386950e8,0x6d4f000c,0x9f460025,0x00000000}},	//   tlar_, şcar, _naoú_,
  { {0x6ce3019d,0xc6a7018e,0x6c180021,0x00000000}},	//   _ріше, држи, _يتيح_,
  { {0x7a300004,0x682a0080,0x78a2017f,0x00000000}},	// [c890] _säte, _týdn, _čove,
  { {0x644002f6,0x2c56001c,0xdcfa005b,0x00000000}},	//   _ammi, rāde_, latı,
  { {0x386901f7,0x442d608c,0x443f0013,0x00000000}},	//   plar_, _ple_, _pmu_,
  { {0x2c080161,0xdcfa005b,0x683101e1,0x00000000}},	//   षाएं_, natı, _både,
  { {0x661c5cea,0xdb1d00d1,0xa2940086,0x00000000}},	//   _fork, ggsø, вачі,
  { {0x863500b5,0x7a300461,0x27f900e5,0x00000000}},	//   _טאָג_, _täte, _hasn_,
  { {0x62883397,0xdcfa0058,0x2249007d,0x00000000}},	//   _dido, katı, đak_,
  { {0x442d0035,0x443f017f,0x6f020238,0x00000000}},	//   _ule_, _umu_, _broc,
  { {0x3eb9608d,0x6f0204ca,0xdcfa005b,0x00000000}},	//   ést_, _croc, datı,
  { {0x6f020025,0x60ce0139,0xee365dc7,0x00000000}},	//   _droc, óimé, ень_,
  { {0xa3dc0053,0x1d090afc,0xdcfa0058,0x00000000}},	//   त्व_, чени_, fatı,
  { {0xce95011c,0x8cc00161,0xde950001,0x00000000}},	//   _задъ, _विरो, _задњ,
  { {0x386003b2,0x657a0046,0x6f02608e,0x00000000}},	//   voir_, _úthv, _groc,
  { {0xc332089e,0x4a75082d,0x2ca9056c,0x00000000}},	//   רוך_, выст, _ładu_,
  { {0x38601a05,0x3876005e,0xdcfa0058,0x00000000}},	//   toir_, ећат, batı,
  { {0xa887047e,0xdb0601e9,0xf1d00013,0x00000000}},	//   ейса_, takä, oạch_,
  { {0x3860066d,0x7a2b0058,0xe73a0141,0x00000000}},	// [c8a0] roir_, _kütl, чеа_,
  { {0x99160088,0x67360051,0x7af60089,0x00000000}},	//   _зьмі, rzyj, _isyt,
  { {0xf1c90161,0x6288051e,0x661c00bd,0x00000000}},	//   _राजन, _rido, _vork,
  { {0x1e1c0235,0x661c0034,0x6288608f,0x00000000}},	//   _पक्ष_, _work, _sido,
  { {0x23270002,0x7e610137,0x4803000d,0x00000000}},	//   ноци_, kolp, _спяв,
  { {0x8cc00161,0x27e06090,0xdcfa0058,0x00000000}},	//   _विलो, lfin_, zatı,
  { {0x6288418b,0xdcfa005b,0xdb04017d,0x00000000}},	//   _vido, yatı, _feiç,
  { {0x62880886,0x27e00003,0x6f021a72,0x00000000}},	//   _wido, nfin_, _proc,
  { {0x7d0340c9,0xc2c60043,0x7799009d,0x00000000}},	//   _arns, _سياي, וֹתו,
  { {0xa3dc0161,0x7e610331,0xb69b00dd,0x00000000}},	//   त्र_, golp, _orân,
  { {0x6f020051,0xc04f01dd,0x320c5de4,0x00000000}},	//   _wroc, _бі_, _indy_,
  { {0xd3140086,0x60260003,0x61fa107b,0x00000000}},	//   _пiдт, _démê, _hatl,
  { {0xdcfa01f7,0x6f020051,0x63ad0014,0x00000000}},	//   ratı, _uroc, ðani,
  { {0xaf490021,0xb69b003b,0x7e6101f4,0x00000000}},	//   _تشمل_, _brân, colp,
  { {0x61fa6091,0xdcfa005b,0xdb0f029c,0x00000000}},	//   _matl, patı, mací,
  { {0xb9090053,0x6aad0035,0xdb0f2a28,0x00000000}},	//   _यह_, _twaf, lací,
  { {0x3a750893,0xa2cc0042,0x0c740049,0x00000000}},	// [c8b0] _илир, _समग्, _حدود,
  { {0x27f90034,0xb69b003b,0x61fa4f68,0x00000000}},	//   _wasn_, _frân, _natl,
  { {0xbc68007e,0x68230019,0x59960063,0x00000000}},	//   _زمین_, _sõdu, _בכתב_,
  { {0x320c22a4,0x7af6002b,0xf4840085,0x00000000}},	//   _andy_, _ysyt, гучн,
  { {0xc987006a,0x61fa12e2,0x321e22b6,0x00000000}},	//   _تشکي, _batl, _boty_,
  { {0x6595000a,0x9f4400cd,0x61fa6092,0x00000000}},	//   _јаву, demà_, _catl,
  { {0x9f420024,0x7a300019,0x2055323e,0x00000000}},	//   ľký_, _jäta, ктир,
  { {0x26050161,0x2c56001c,0x9f4f01a8,0x00000000}},	//   _होती_, kāda_, _pagà_,
  { {0xa2950086,0xf1a7047e,0x64580003,0x00000000}},	//   _разі, _зрен, évie,
  { {0x26c9007d,0x61fa33ca,0xa294046e,0x00000000}},	//   irao_, _gatl, _сафі,
  { {0x7e610146,0x7a300137,0x2247005f,0x00000000}},	//   rolp, _näta, mink_,
  { {0x7a220003,0xeb9a0121,0x22476093,0x00000000}},	//   _nôtr, ьим_, link_,
  { {0xa03a0047,0x998e011b,0xcf240044,0x00000000}},	//   _קענפ, ínům_, _مروي,
  { {0x7d0301a8,0xb69b003b,0x8d65005e,0x00000000}},	//   _trns, _prân, _ивле,
  { {0x64d00053,0xd9590054,0x7a2b0058,0x00000000}},	//   _हमेश, ешті_, _gütm,
  { {0x2c080053,0x224700e5,0xde880013,0x00000000}},	//   षाओं_, hink_, _dịu_,
  { {0x26c9007d,0x1867336f,0x27e06094,0x00000000}},	// [c8c0] grao_, тати_, rfin_,
  { {0x8ab70063,0xb69b156c,0x66e304f2,0x00000000}},	//   _שהיו_, _trân, рофа,
  { {0xd499019d,0xa7aa0076,0xb69b017d,0x00000000}},	//   ері_, _окна_, _urân,
  { {0xfbdf001b,0x68e300c7,0x82a60086,0x00000000}},	//   hiên_, _ända, вадж,
  { {0xe3633e9a,0xe2976095,0x61fa6096,0x00000000}},	//   акци, вач_, _patl,
  { {0xbb3b009f,0x2247005f,0x35a3234f,0x00000000}},	//   ועני, gink_, _варг,
  { {0xdb0f016b,0xe6430499,0xf9930063,0x00000000}},	//   vací, _терп, סרה_,
  { {0xc9530063,0x7523004d,0xf8b30063,0x00000000}},	//   ימו_, änze, בשה_,
  { {0x61fa04d2,0x78a9007d,0x9f5f0014,0x00000000}},	//   _tatl, ćevi, örði_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x68310137,0x213805b9,0xdb0f004c,0x00000000}},	//   _låda, _årh_, rací,
  { {0x2c56008f,0x8fa61e1b,0xac190505,0x00000000}},	//   tāda_, _раде, хому_,
  { {0x7ac70062,0xde880013,0x290c6097,0x00000000}},	//   ъсне, _bịt_, ådan_,
  { {0x2c56003d,0x5a47000d,0xa9c40121,0x00000000}},	//   rāda_, тэма, исск,
  { {0x29055d42,0x6d45004c,0xe9b40054,0x00000000}},	//   íla_, _žhav, рбсь,
  { {0x26c9007d,0x7a2b004e,0xf77300de,0x00000000}},	//   trao_, _kütk, لاذ_,
  { {0x7a220003,0x41d20053,0xdb1d004d,0x00000000}},	// [c8d0] _vôtr, _सांस, ngsü,
  { {0x9634000d,0xddc1008f,0x7a3000a5,0x00000000}},	//   ануц, volū, _täta,
  { {0xcd78009a,0x5d78009a,0xf992009d,0x00000000}},	//   תְּכ, תָּנ, _לרי_,
  { {0xa2c40053,0x7a30004b,0x3e790003,0x00000000}},	//   _रिश्, _jätn, mète_,
  { {0x3e790164,0x7a300137,0x69c10051,0x00000000}},	//   lète_, _mätn, ólew,
  { {0x1fbd0053,0x722b0121,0x7a2b013d,0x00000000}},	//   ोल्ड, ьцев_, _sütj,
  { {0x3e790164,0xa0691857,0xddc1008f,0x00000000}},	//   nète_, нака_, solū,
  { {0xe3b3005d,0xdb1d0046,0xddc8004c,0x00000000}},	//   _خرس_, ngsó, lidň,
  { {0x63ad0026,0x3e790003,0xc27502d8,0x00000000}},	//   ðanu, hète_, _блај,
  { {0x7c3f0006,0x96d50053,0x63b900f1,0x00000000}},	//   _įpra, यूयॉ, lawn,
  { {0x4c8601d5,0x98c0008f,0xac866098,0x00000000}},	//   ллов, īrīt_, лгол,
  { {0x98aa0051,0xb69b00be,0xfaa635df,0x00000000}},	//   czbę_, _arâm, ламо,
  { {0xe4560047,0x76890078,0xef0e3510,0x00000000}},	//   רירט_, _ažym, _ум_,
  { {0x628f0164,0xed596099,0x68311310,0x00000000}},	//   _écou, _пол_, _råda,
  { {0x7d1c31d4,0x68314bc3,0x5895000a,0x00000000}},	//   ørst, _såda, ишту,
  { {0xf7720032,0x248d161f,0x63b90022,0x00000000}},	//   ماء_, _niem_, jawn,
  { {0xdb0f017d,0x63b90051,0x99910078,0x00000000}},	// [c8e0] racã, dawn, gizų_,
  { {0x3e790003,0x89aa0591,0xe8fa609a,0x00000000}},	//   bète_, _яков_, _зло_,
  { {0x200f0019,0x89db009a,0x00000000,0x00000000}},	//   _ongi_, _אחיי,   ,
  { {0x4420007a,0x25a70058,0x7aeb013d,0x00000000}},	//   ði_, ınla_, _ímtá,
  { {0xe2f80086,0x248d609b,0x23e5012c,0x00000000}},	//   телі_, _diem_, рієв,
  { {0x200f076c,0x366a000d,0x27f2609c,0x00000000}},	//   _angi_, _чаго_, leyn_,
  { {0x63b90022,0x31c50085,0x90e6013a,0x00000000}},	//   bawn, рсів, استن,
  { {0xa067005e,0x6aa45a2d,0x7d1c00a5,0x00000000}},	//   лаја_, _otif, ärsm,
  { {0x21a601ce,0x00000000,0x00000000,0x00000000}},	//   _бизм,   ,   ,
  { {0x248d0022,0x200f0014,0x3ea2008f,0x00000000}},	//   _ziem_, _engi_, īkt_,
  { {0x51930021,0x7a300066,0x3ea2008f,0x00000000}},	//   _المذ, _pätn, ūkt_,
  { {0xc0a903eb,0x321c00a5,0xcbc70044,0x00000000}},	//   _شامل_, ljvy_, دزدي,
  { {0x26170053,0x16040082,0x00000000,0x00000000}},	//   नामी_, रयार_,   ,
  { {0xad26006a,0xdb0f00cd,0x7bc4609d,0x00000000}},	//   _مربو, racà, _ediu,
  { {0x6cc6000d,0x6aa4002b,0xa9340074,0x00000000}},	//   _сёле, _etif, берш,
  { {0x3e790164,0xfbdf00be,0x5b250044,0x00000000}},	//   rète_, rnês_, _نفعل,
  { {0x248d609e,0xb69b0f84,0xceb9004c,0x00000000}},	// [c8f0] _riem_, _trâm, tyři_,
  { {0x26c706bb,0x2d9e609f,0x7aed60a0,0x00000000}},	//   čno_, ncte_, _ipat,
  { {0x248d001c,0x68380026,0xfbdf008b,0x00000000}},	//   _piem_, _bídd, hiêm_,
  { {0x81bc001c,0xe44e013c,0x7a30004b,0x00000000}},	//   _slēp, іж_, _lätl,
  { {0x248d0066,0x63b912cc,0x64580c77,0x00000000}},	//   _viem_, rawn, évia,
  { {0xe1250002,0x248d0051,0xdb0600b9,0x00000000}},	//   имли, _wiem_, rakø,
  { {0x248d003d,0x2c4f0022,0x90350867,0x00000000}},	//   _tiem_, lędu_, ихич,
  { {0x63ad006d,0x2d9e000c,0xaec50794,0x00000000}},	//   ñand, ecte_, абил,
  { {0x200302f4,0x644b002c,0x68310137,0x00000000}},	//   ěji_, migi, _lådo,
  { {0x7d090001,0xa2670062,0xb3a90058,0x00000000}},	//   вног_, _събл, şıdı,
  { {0x7aed16d8,0x3cc90062,0xed590b69,0x00000000}},	//   _apat, ълно_, тон_,
  { {0x644b4919,0x69c50725,0x408702f8,0x00000000}},	//   nigi, _adhe, _сузб,
  { {0x644b0019,0x628f0164,0x27f20058,0x00000000}},	//   iigi, _écos, veyn_,
  { {0x644b002c,0xa2cd0042,0x26050042,0x00000000}},	//   higi, _सिन्, _होली_,
  { {0x7aed0290,0x683800c5,0xdb0f0d2d,0x00000000}},	//   _epat, _líde, racá,
  { {0x7a300dc2,0xb8ee0042,0xa3e50042,0x00000000}},	//   _täto, _रि_, _बॉल_,
  { {0x6aa400c7,0x78a50205,0x644b60a1,0x00000000}},	// [c900] _utif, _ethv, digi,
  { {0x644b0006,0x3ebf0656,0x4b7b069a,0x00000000}},	//   eigi, isut_, _באפו,
  { {0x7c242d4e,0x7a300019,0x26d20035,0x00000000}},	//   _koir, _jätm, suyo_,
  { {0x644b00bb,0x7aed0006,0x3ebf00fe,0x00000000}},	//   gigi, _ypat, ksut_,
  { {0x69c10026,0xa3e50053,0xd36f0021,0x00000000}},	//   ðleg, ब्ध_, وهم_,
  { {0x7d1c0504,0x12a90021,0x644b0078,0x00000000}},	//   ärsk, ادنى_, aigi,
  { {0x26c00078,0x7a300137,0x00d70044,0x00000000}},	//   lsio_, _nätm, لبيت_,
  { {0xa3e50394,0x7c240164,0xb7bb008d,0x00000000}},	//   ब्द_, _noir, _loãn,
  { {0xfba70053,0xdcee0080,0xd0070d34,0x00000000}},	//   _क्षम, ědči, рење_,
  { {0x442460a2,0x26c0001f,0x1e34000d,0x00000000}},	//   _hom_, isio_, сноў,
  { {0x44240ade,0xde88008b,0x7c24109c,0x00000000}},	//   _kom_, _dịp_, _boir,
  { {0x442400e3,0x7c240025,0x628f0003,0x00000000}},	//   _jom_, _coir, _écor,
  { {0x7c240025,0x2f0f0026,0x442442c2,0x00000000}},	//   _doir, rögð_, _mom_,
  { {0x644b0122,0xfba70053,0x3e34007e,0x00000000}},	//   zigi, _क्रम, _دفتر,
  { {0x7c2451ef,0x7c36069f,0x442460a3,0x00000000}},	//   _foir, _flyr, _oom_,
  { {0x442460a4,0x6e23013d,0x2c7b008f,0x00000000}},	//   _nom_, _zonb, _lūdz_,
  { {0x7aed0035,0x69c10051,0xd5bb0121,0x00000000}},	// [c910] _upat, óles, все_,
  { {0x644b2f40,0xa2cd0042,0x160e0042,0x00000000}},	//   wigi, _सिब्, सागर_,
  { {0x644b60a5,0x9475007e,0x442460a6,0x00000000}},	//   tigi, مگرا, _bom_,
  { {0x442460a7,0x3ea6003e,0x6838006d,0x00000000}},	//   _com_, _otot_, _píde,
  { {0x26c0001f,0x644b0530,0x442460a8,0x00000000}},	//   csio_, rigi, _dom_,
  { {0x644b60a9,0xdb060114,0x32670002,0x00000000}},	//   sigi, jaký, штев,
  { {0x644b1c7c,0xe4a40002,0x3ebf002b,0x00000000}},	//   pigi, _мрто, wsut_,
  { {0x39580063,0x3ebf0659,0x397c0047,0x00000000}},	//   ישום_, tsut_, כטונ,
  { {0x6f18000d,0x64490d69,0x672d60aa,0x00000000}},	//   ацэс_, _imei, nyaj,
  { {0x30e7019d,0x7a2b0019,0xfe450076,0x00000000}},	//   _відб, _kütu, ённо,
  { {0x2c7200ea,0x2fd903eb,0x3ebf0072,0x00000000}},	//   ládi_, _مواد_, ssut_,
  { {0xca2901d8,0x6f950021,0xba3b002b,0x00000000}},	//   _אם_, _الإض, opïw,
  { {0x7c240164,0x5ea50044,0x6e230244,0x00000000}},	//   _voir, _امتل, _tonb,
  { {0x6e3a28e7,0xa2da0053,0xff50005d,0x00000000}},	//   chtb, _नमस्, _تخم_,
  { {0x7c240025,0x26c0001f,0xe8560021,0x00000000}},	//   _toir, wsio_, منسد,
  { {0xccf20063,0x7a3001a9,0x26c02348,0x00000000}},	//   _זכה_, _kätk, tsio_,
  { {0x7a300004,0x26c01404,0x29050137,0x00000000}},	// [c920] _jätk, usio_, ålar_,
  { {0x26c01bfc,0x44240070,0x644960ab,0x00000000}},	//   rsio_, _som_, _amei,
  { {0x672d0035,0x26c03bfc,0xdcea007d,0x00000000}},	//   ayaj, ssio_, čiće,
  { {0x74690086,0x7e680195,0x3c0d0078,0x00000000}},	//   арів_, zodp, _tėvų_,
  { {0x442460ac,0x7a300137,0xdb0f017d,0x00000000}},	//   _vom_, _nätk, racç,
  { {0xc5d5019d,0x78a2017f,0x2498004d,0x00000000}},	//   _місь, _čovj, _turm_,
  { {0x6ab6001f,0x50f40086,0xa2c40053,0x00000000}},	//   _lwyf, ізит, _रिक्,
  { {0x442407a0,0x7a2b004d,0x50b700f2,0x00000000}},	//   _uom_, _hütt, حدود_,
  { {0xa0670001,0x7a2b0019,0x63a200ca,0x00000000}},	//   љања_, _kütt, mcon,
  { {0xa3c20161,0x5d540062,0x99630066,0x00000000}},	//   ूलक_, жкот, _líši_,
  { {0xdd90006a,0xdb1d0d88,0x40960021,0x00000000}},	//   بود_, ngsö, _الصر,
  { {0x7e6800ea,0x63a260ad,0xfbab0121,0x00000000}},	//   sodp, ncon, ытой_,
  { {0x63a260ae,0x386900be,0x7e680dd8,0x00000000}},	//   icon, voar_, podp,
  { {0x6ab6002b,0x60cd008f,0x60dc0244,0x00000000}},	//   _dwyf, ņame, _ärms,
  { {0x28d90161,0x63a2006f,0x48770021,0x00000000}},	//   बंधि, kcon, مدرس,
  { {0x98a5005b,0x64580003,0xdb0f0139,0x00000000}},	//   çlı_, évil, ódói,
  { {0x7a2b005b,0xdb1f00fe,0x63a2006f,0x00000000}},	// [c930] _sütu, äväl, dcon,
  { {0x63a23edd,0x0587030b,0x28d90082,0x00000000}},	//   econ, буем, बंदि,
  { {0xdb1d0137,0xdb0613d9,0x6d5d0058,0x00000000}},	//   ggsö, zakü, şsav,
  { {0x69d801e3,0xd3750001,0xbec2001c,0x00000000}},	//   _över, олећ, _ķīna,
  { {0x387e03b2,0x7a2b004d,0x7bdf60af,0x00000000}},	//   ître_, _fütt, _mcqu,
  { {0x27e90185,0x644800eb,0xd25b000d,0x00000000}},	//   lfan_, _įdie, ыце_,
  { {0x63a22810,0x008502e4,0x2bbe0042,0x00000000}},	//   bcon, олко, ्णमा,
  { {0x63a20a07,0x64490035,0x2bdb0053,0x00000000}},	//   ccon, _umei, _भाषा,
  { {0x2904001c,0xcdf5026c,0x3255000d,0x00000000}},	//   āmai_, очны, _двар,
  { {0xa6e2007a,0x926b0001,0xfe450086,0x00000000}},	//   æðin, _срба_, інно,
  { {0xcb0901d8,0x63bb003e,0x2c56001c,0x00000000}},	//   _של_, _keun, lādi_,
  { {0x63bb03b2,0x59dc0053,0x629b0035,0x00000000}},	//   _jeun, _बाहर, _kuuo,
  { {0xa3e10235,0x27e9001f,0x2c56001c,0x00000000}},	//   _दान_, dfan_, nādi_,
  { {0x3ead60b0,0x27e9002b,0x63bb60b1,0x00000000}},	//   mpet_, efan_, _leun,
  { {0xfe790080,0x27e9001f,0x6e2e00ea,0x00000000}},	//   ntům_, ffan_, öbbe,
  { {0x6ab600ac,0x7b090026,0x63bb1165,0x00000000}},	//   _twyf, óstþ, _neun,
  { {0x2c56003d,0xdb0d0016,0xe64a000d,0x00000000}},	// [c940] jādi_, _reaç, апад_,
  { {0xfe79004c,0x27e900a3,0x645960b2,0x00000000}},	//   ktům_, afan_, enwi,
  { {0x69dc007a,0x63bb42ee,0xa5070062,0x00000000}},	//   mgre, _beun, жеха_,
  { {0x69dc07cf,0x87d608aa,0x6d41484f,0x00000000}},	//   lgre, _بغدا, izla,
  { {0x62810027,0x63bb001f,0x63a2144d,0x00000000}},	//   _bhlo, _deun, rcon,
  { {0x63a212d4,0xa0a60caa,0x628160b3,0x00000000}},	//   scon, ошил, _chlo,
  { {0x63a24016,0x6f091c0a,0x40340085,0x00000000}},	//   pcon, evec, зейс,
  { {0x21200117,0x3ae40137,0xf9930063,0x00000000}},	//   ćih_, köp_, ורו_,
  { {0x3169005b,0x7a3000a5,0x97c8005e,0x00000000}},	//   ğaza_, _täth, вaњу_,
  { {0x20020a80,0xb69b003b,0xdd91005d,0x00000000}},	//   žki_, _grâu, کوپ_,
  { {0xafe6019d,0x27e9001f,0xc223007e,0x00000000}},	//   _можл, yfan_, _تکنو,
  { {0x61f808af,0x1ee9005d,0x9998005f,0x00000000}},	//   levl, جویی_, kirų_,
  { {0xfad8005a,0x69dc252f,0x6d4160b4,0x00000000}},	//   одящ_, fgre, azla,
  { {0xfc46007a,0x68fc001f,0xa2cd0053,0x00000000}},	//   _þína_, fwrd, _सिस्,
  { {0x7a3f02f4,0x26050161,0x19940782,0x00000000}},	//   vště, _होगी_, даря,
  { {0x64830019,0x69dc60b5,0xdc2b005d,0x00000000}},	//   mõig, agre, _خسته_,
  { {0x27e9001f,0x69dc60b6,0x6483004b,0x00000000}},	// [c950] rfan_, bgre, lõig,
  { {0x7a3f0080,0x1a65007e,0x68fc002b,0x00000000}},	//   uště, _ریزی_, bwrd,
  { {0x93f50054,0xf9fa0063,0x6f09004c,0x00000000}},	//   зпец, _ההתמ, zvec,
  { {0x7bdd60b7,0x2c56001c,0x7afd2259,0x00000000}},	//   ngsu, tādi_, owst,
  { {0xe2a3008b,0xe2990456,0x78a2007d,0x00000000}},	//   _giữ_, щал_, _čovi,
  { {0x2c56001c,0xddda0080,0x960b000d,0x00000000}},	//   rādi_, potř, _тэма_,
  { {0x10a20062,0x7a0f0078,0x645a013d,0x00000000}},	//   нищн, mėtė, óciá,
  { {0x6f0900c7,0x7a0f0078,0x69dc0130,0x00000000}},	//   tvec, lėtė, zgre,
  { {0xed630080,0xfe79004c,0x61f800ca,0x00000000}},	//   _mužů_, stům_, bevl,
  { {0x7a3000bd,0xfe42005a,0x6f0960b8,0x00000000}},	//   _täti, еньо, rvec,
  { {0x69dc00d1,0xfbdf0013,0x6f091844,0x00000000}},	//   vgre, hiêu_, svec,
  { {0x3ead0666,0x6a7200b9,0x9f5f01a8,0x00000000}},	//   ppet_, hæft, lduí_,
  { {0xc0520047,0x7c95007e,0x69dc0c00,0x00000000}},	//   _אזא_, _کشتا, tgre,
  { {0x7bdd002c,0x69dc004d,0x99980078,0x00000000}},	//   agsu, ugre, virų_,
  { {0x69dc60b9,0x7d1c0354,0x5975014b,0x00000000}},	//   rgre, ärst, дыту,
  { {0x7a3001e3,0xfc3f0025,0x69dc60ba,0x00000000}},	//   _nätv, chí_, sgre,
  { {0xfc570063,0xdc3b009a,0x7bdb009a,0x00000000}},	// [c960] _מבקש_, _לעקר, _הקפו,
  { {0xd6cf002a,0x68fc002b,0x1be80042,0x00000000}},	//   اقل_, pwrd, ट्रल_,
  { {0xb3a901f7,0xda65007e,0x999b0063,0x00000000}},	//   ğını, _تايي, _לביט,
  { {0xb3a9005b,0x1459000d,0xd91b009a,0x00000000}},	//   şını, ошчы_, _הוטל,
  { {0x7d06008f,0xd4671849,0x46a3014b,0x00000000}},	//   āksi, чице_, _паяв,
  { {0x68310146,0xd5b200b3,0xa2cd0053,0x00000000}},	//   _rådi, _سفر_, _सिर्,
  { {0x490f0161,0x463b0047,0x61f80779,0x00000000}},	//   डियो_, _פעלע, revl,
  { {0x8f46011c,0xf9930063,0xdb0f0066,0x00000000}},	//   зход, ערה_, racú,
  { {0xb69b003b,0x2c56008f,0x141b0063,0x00000000}},	//   _urât, nādu_, _פומב,
  { {0x2d9802ab,0x6838006d,0x7bc00014,0x00000000}},	//   øre_, _oído, ðmun,
  { {0xfc3f0025,0x6fd60058,0x2c560023,0x00000000}},	//   thí_, gücü, hādu_,
  { {0x2fc0007a,0x2c56001c,0xa137009a,0x00000000}},	//   _þig_, kādu_, _מאבק_,
  { {0x7afd0122,0x64830019,0x764e0196,0x00000000}},	//   uwst, sõig, _omby,
  { {0x7de6005d,0x6f022a5a,0x4efb009a,0x00000000}},	//   _رستم, _isoc, _להדו,
  { {0x6838004c,0x7d1c08a9,0x628a60bb,0x00000000}},	//   _vídn, årsd, imfo,
  { {0x6e2a2670,0xa2cd0042,0xbd5b009d,0x00000000}},	//   _hofb, _सिल्, _לכוש,
  { {0x387e0164,0xfe780078,0x4993005d,0x00000000}},	// [c970] îtra_, olį_, بیگر,
  { {0x6aad0035,0xdce30080,0xc58b0121,0x00000000}},	//   _itaf, _nyně, бщее_,
  { {0x6a720146,0xa8a4005a,0xdb040014,0x00000000}},	//   ræft, _пряк, _heið,
  { {0x44290ac6,0x20060139,0x628a20a4,0x00000000}},	//   ða_, _naoi_, emfo,
  { {0xfe780006,0x15ab0062,0x6483004b,0x00000000}},	//   klį_, _гъби_, võid,
  { {0x6aad0035,0xdb040014,0x91fc008f,0x00000000}},	//   _mtaf, _meið, _skār,
  { {0xdb04007a,0x9477007e,0x4429008b,0x00000000}},	//   _leið, _فدرا, ưa_,
  { {0x7a3000bd,0x20060025,0xdb0600ea,0x00000000}},	//   _hätt, _caoi_, makö,
  { {0x7a300004,0x1f650499,0x72d40141,0x00000000}},	//   _kätt, ьким, _потф,
  { {0x7bcd000c,0x64830019,0x7a302043,0x00000000}},	//   _adau, sõid, _jätt,
  { {0x2006018d,0x6607017f,0x63a40014,0x00000000}},	//   _faoi_, _majk, þing,
  { {0xdb04007a,0x7a3000c7,0xfe780078,0x00000000}},	//   _beið, _lätt, alį_,
  { {0x20240024,0x63a40078,0x15ff0042,0x00000000}},	//   úsiť_, žing, ैयार_,
  { {0x3e6a007e,0x7a300137,0x660760bc,0x00000000}},	//   _وجوی_, _nätt, _najk,
  { {0x63a90955,0x26cf013d,0x6f0d60bd,0x00000000}},	//   _ofen, ágon_, _šach,
  { {0xf7720032,0x2c56008f,0x9cd6009a,0x00000000}},	//   ناء_, tādu_, _חוקה_,
  { {0x7a3000c7,0x2fc00019,0xb3a9005b,0x00000000}},	// [c980] _bätt, _õige_, ğılı,
  { {0xb3a9005b,0x7b04001c,0x2c56008f,0x00000000}},	//   şılı, ēttī, rādu_,
  { {0x29040418,0xe4a50086,0x92a30022,0x00000000}},	//   āmas_, еріо, ółno,
  { {0x25fa0053,0x6d4e0139,0x7c2660be,0x00000000}},	//   _उसकी_, úbai, njkr,
  { {0x29070014,0xd7fb009a,0x3865013d,0x00000000}},	//   _ánar_, _והכל, élre_,
  { {0x7a300072,0x63a960bf,0x27e060c0,0x00000000}},	//   _tätu, _efen, lgin_,
  { {0x63a960c1,0x2c56001c,0x2c0e0053,0x00000000}},	//   _ffen, nāds_, ियां_,
  { {0xd007005e,0x27e060c2,0xf484005d,0x00000000}},	//   деће_, ngin_, _سازی,
  { {0x64420025,0x7a30004b,0x27e060c3,0x00000000}},	//   mhoi, _jäts, igin_,
  { {0x44260198,0xddc860c4,0xdb040026,0x00000000}},	//   ljo_, widł, _reið,
  { {0x7af60006,0x828b0132,0x6c550239,0x00000000}},	//   _apyt, _וְאֶ, екну,
  { {0xbc4b0086,0x644200fe,0x442660c5,0x00000000}},	//   ічне_, nhoi, njo_,
  { {0x44260942,0x7a300db4,0xd366007e,0x00000000}},	//   ijo_, _näts, اه_,
  { {0x27e000f5,0xdb040014,0xd126013a,0x00000000}},	//   egin_, _veið, هم_,
  { {0x7a3001e3,0xdb1d0026,0x8c670da9,0x00000000}},	//   _rätt, masí, _отид,
  { {0x7a3060c6,0xdb1d60c7,0x66070130,0x00000000}},	//   _sätt, lasí, _sajk,
  { {0x6aad10ca,0x290c0137,0x929d0051,0x00000000}},	// [c990] _utaf, ådar_, _osła,
  { {0xb3a9005b,0xdb1d0014,0x44265b7b,0x00000000}},	//   ğımı, nasí, ejo_,
  { {0xb3a9005b,0x38c9007e,0x7c2d0dde,0x00000000}},	//   şımı, _عادی_, _koar,
  { {0xfd57009a,0x92070023,0x00000000,0x00000000}},	//   ושבי_, igāš,   ,
  { {0x7c2d000c,0xd301000d,0x160a0053,0x00000000}},	//   _moar, _мiнс, _होकर_,
  { {0x4426006d,0x13080086,0x52740121,0x00000000}},	//   ajo_, ьній_, кущу,
  { {0xde88008d,0xa3d50054,0x63aa011b,0x00000000}},	//   _uịy_, _повч, émní,
  { {0x644260c8,0x2c640058,0x26c9007d,0x00000000}},	//   choi, kıda_, osao_,
  { {0x645800cd,0x8e550500,0x443f60c9,0x00000000}},	//   èvie, етні, _ilu_,
  { {0x442d0102,0x7bda0006,0x60e80137,0x00000000}},	//   _hoe_, ėtum, örmö,
  { {0x7c2d60ca,0x63a40006,0x9f4f006d,0x00000000}},	//   _boar, žine, _pagó_,
  { {0xcfe9007e,0x644a0003,0x7a300137,0x00000000}},	//   _رفته_, éfix, _nätr,
  { {0x7ee40021,0x7c2d3ecf,0x683100a5,0x00000000}},	//   _لكنن, _doar, _låds,
  { {0x442d0004,0x0f56014e,0x443f001f,0x00000000}},	//   _loe_, _אינם_, _llu_,
  { {0x3da6019d,0x7c2d0529,0x443f02a8,0x00000000}},	//   _якщо_, _foar, _olu_,
  { {0x442d0031,0x7b0500fe,0x02df0053,0x00000000}},	//   _noe_, ättä, _नमून,
  { {0x442600c2,0x27e060cb,0x2c640058,0x00000000}},	// [c9a0] vjo_, rgin_, cıda_,
  { {0x7bc636a3,0x6b843288,0x4aa50053,0x00000000}},	//   laku, _izig, _गंतव,
  { {0x64420027,0x443f60cc,0x442660cd,0x00000000}},	//   thoi, _blu_, tjo_,
  { {0x7bc660ce,0xab5b004b,0x442660cf,0x00000000}},	//   naku, kaül, ujo_,
  { {0x68e32ddc,0x442660d0,0x442d41bd,0x00000000}},	//   _ändr, rjo_, _doe_,
  { {0x443f0019,0x64420019,0x673600fe,0x00000000}},	//   _elu_, shoi, myyj,
  { {0x64420027,0x443f281a,0x7bc6315d,0x00000000}},	//   phoi, _flu_, kaku,
  { {0x2c64005b,0x7bc624e5,0x68e301f2,0x00000000}},	//   yıda_, jaku, _ånde,
  { {0xdb1d000f,0xcee70001,0x38600026,0x00000000}},	//   tasí, едње_, inir_,
  { {0x7c2d5e92,0xdea3005d,0x442d5087,0x00000000}},	//   _soar, دیوی, _zoe_,
  { {0x7c2d000c,0x38600026,0xdb1d017d,0x00000000}},	//   _poar, knir_, rasí,
  { {0x629a60d1,0x7bc618d5,0x9207008f,0x00000000}},	//   _hito, gaku, rgāš,
  { {0x629a27f2,0xdd2d0024,0x2aab03d6,0x00000000}},	//   _kito, hŕňa, ятно_,
  { {0x2c64005b,0x386060d2,0xaf070044,0x00000000}},	//   rıda_, enir_, _أقوم_,
  { {0x6e3500ea,0x386020e1,0x2887005e,0x00000000}},	//   özbe, fnir_, ећав,
  { {0xc6a70bb3,0x6d7b014e,0x38600026,0x00000000}},	//   ержи, _מאוח, gnir_,
  { {0xe9f90013,0xd6d802d8,0xe6990062,0x00000000}},	// [c9b0] _cuả_, етх_, дваш_,
  { {0x629a002c,0xe784000a,0x644060d3,0x00000000}},	//   _nito, ѓуто, _almi,
  { {0x69c72f3e,0xd9440002,0x443f60d4,0x00000000}},	//   maje, _беќи, _plu_,
  { {0x63a50080,0x13a7007e,0x54550062,0x00000000}},	//   ěhno, رنتی_, ъвет,
  { {0x442d60d5,0xe7840a2f,0xe6950044,0x00000000}},	//   _voe_, _буро, _للحد,
  { {0x69c760d6,0xab5b004b,0x722b0121,0x00000000}},	//   naje, vaül, яцев_,
  { {0x7bc625e5,0x784c005b,0xf1a7007e,0x00000000}},	//   yaku, aşvu, واژه_,
  { {0x6288024a,0x64580003,0x349460d7,0x00000000}},	//   _ehdo, évit, _баср,
  { {0x629a068b,0x7bc660d8,0x84640062,0x00000000}},	//   _fito, vaku, _съре,
  { {0x7bc60035,0x69c71182,0x21a40044,0x00000000}},	//   waku, jaje, _ممكّ,
  { {0x0d820b62,0x6b8400ea,0x7bc60e29,0x00000000}},	//   ильн, _szig, taku,
  { {0x40350002,0x7d1c01f2,0x69d8013d,0x00000000}},	//   _шеес, årsa, _övez,
  { {0xdb1d0016,0xde054273,0x7bc60da7,0x00000000}},	//   vasã, _апли, raku,
  { {0xc332014e,0x7bc65c36,0x69c7001a,0x00000000}},	//   סום_, saku, gaje,
  { {0x6443001c,0x38600026,0x929d0022,0x00000000}},	//   īnij, tnir_, _osło,
  { {0x69c700fe,0x64430006,0x38600026,0x00000000}},	//   aaje, ūnij, unir_,
  { {0xe9f9001b,0x3860242a,0x683102c0,0x00000000}},	// [c9c0] _quả_, rnir_, _pådr,
  { {0x68380016,0x69c760d9,0x38600014,0x00000000}},	//   _mídi, caje, snir_,
  { {0x629a051e,0x69d90047,0x9596005e,0x00000000}},	//   _rito, _אַרו, траљ,
  { {0x6aa402ae,0xb2c60021,0x7794007e,0x00000000}},	//   _kuif, نغتو, _میزا,
  { {0x6aa40164,0x629a60da,0xddda2401,0x00000000}},	//   _juif, _pito, ultū,
  { {0x7bc40019,0x9c7d007d,0x27f2002b,0x00000000}},	//   _leiu, muče, lfyn_,
  { {0x2576006a,0x64580164,0x27f2001f,0x00000000}},	//   _شهرس, évis, ofyn_,
  { {0xdfd00021,0x6d4801d9,0x69c70758,0x00000000}},	//   حية_, vzda, zaje,
  { {0x629a4bd3,0x26c7007d,0xdde300dd,0x00000000}},	//   _tito, ćnog_, îrşi,
  { {0x43750088,0x629a006f,0x201d001f,0x00000000}},	//   _суст, _uito, _enwi_,
  { {0x69c760db,0x6e3a1a62,0x7bc400dd,0x00000000}},	//   vaje, rktb, _beiu,
  { {0x26cf00ea,0xa3ea0042,0xb5820085,0x00000000}},	//   ágok_, _माफ_, ынiк,
  { {0x9c7d02e2,0xa3ea0053,0x629d0003,0x00000000}},	//   juče, _मान_, _ésot,
  { {0xaa64060e,0x4af6005d,0x3ea20046,0x00000000}},	//   атск, اکيد_, íktu_,
  { {0xdb0f02dd,0x27f2001f,0x69c760dc,0x00000000}},	//   tacó, ffyn_, raje,
  { {0x69c70568,0x320c18b9,0x6ebf0053,0x00000000}},	//   saje, _lady_, लीवु,
  { {0x9715000d,0x69c760dd,0xe89401d5,0x00000000}},	// [c9d0] ымац, paje, рать,
  { {0x7c3d0518,0x200d00dd,0x2cb3004c,0x00000000}},	//   lksr, zdei_, řadů_,
  { {0xb4d50062,0x657c002b,0xfa34007e,0x00000000}},	//   ужещ, _cyrh, _خريد,
  { {0xccf300b5,0x7a2b00bd,0xd6db0062,0x00000000}},	//   יכע_, _nütz, _отг_,
  { {0x64580268,0x69c5053b,0x7c3d0104,0x00000000}},	//   èvia, _kehe, iksr,
  { {0x11d90021,0x69c5004d,0xd687005e,0x00000000}},	//   روعة_, _jehe, _јумп,
  { {0x41e40086,0x7c3d00d1,0x657c002b,0x00000000}},	//   річа, kksr, _gyrh,
  { {0x69c50772,0x7c3d00ca,0x200d4d78,0x00000000}},	//   _lehe, jksr, udei_,
  { {0xe8e10013,0x200d60de,0xcf250044,0x00000000}},	//   _ướp_, rdei_, ارعي,
  { {0x645912cc,0x7c3d00ca,0xddc80078,0x00000000}},	//   liwi, eksr, aldž,
  { {0xdb1d00ea,0x3e55004c,0x27f200a3,0x00000000}},	//   vasá, větě_, yfyn_,
  { {0x9f0500f2,0xe572089e,0x6459056c,0x00000000}},	//   _موصو, מַר_, niwi,
  { {0xc0b90080,0x69c50112,0xeb970121,0x00000000}},	//   žádá, _behe, лию_,
  { {0x9c7d017f,0xfce50fd0,0xfaa30457,0x00000000}},	//   vuče, _боко, саро,
  { {0xd9430daf,0xa96702b3,0xe9f9008d,0x00000000}},	//   бери, гира_, _quạ_,
  { {0xa7b50001,0x2b55007e,0xdb1d00ea,0x00000000}},	//   исуј, ایید_, sasá,
  { {0x27f2481c,0xc0ee0013,0x69c5002b,0x00000000}},	// [c9e0] rfyn_, _bướu_, _fehe,
  { {0xceb2014e,0x69c53c41,0x6459006f,0x00000000}},	//   ציב_, _gehe, eiwi,
  { {0x9916000d,0x320c60df,0xa2c10082,0x00000000}},	//   _сьпі, _rady_, रीस्,
  { {0x320c60e0,0x69c5004d,0xd4990054,0x00000000}},	//   _sady_, _zehe, врі_,
  { {0x69c500a4,0x7054005d,0x00000000,0x00000000}},	//   _yehe, ینتا,   ,
  { {0x9359005a,0xe2974dd8,0xc2c30044,0x00000000}},	//   ърху_, гач_, حيوي,
  { {0xca7b00b5,0x69c10026,0x29360041,0x00000000}},	//   ענצט, ðlei, טאַן_,
  { {0xc0340095,0xab5b004b,0x64590051,0x00000000}},	//   рниј, baüh, ciwi,
  { {0x320c0080,0x627b0051,0x44ee0114,0x00000000}},	//   _tady_, _słoń, lý_,
  { {0x1ef70032,0x98ac0080,0x9e0601e4,0x00000000}},	//   اعية_, ádě_, учил,
  { {0x44ee0114,0xd622000d,0x2fe60021,0x00000000}},	//   ný_, лiка, _مكاف,
  { {0xa2db0161,0x69c560e1,0x660e008f,0x00000000}},	//   _निम्, _sehe, _labk,
  { {0x98aa00eb,0xe4570047,0x44ee027d,0x00000000}},	//   mybę_, ריכט_, hý_,
  { {0x44ee027d,0x645914ce,0x98aa0078,0x00000000}},	//   ký_, ziwi, lybę_,
  { {0x199560e2,0x61f50058,0x69c560e3,0x00000000}},	//   равя, _özle, _vehe,
  { {0x36d50076,0x57b50786,0x98aa0078,0x00000000}},	//   иобр, рбат, nybę_,
  { {0x69c560e4,0x660e2e1b,0x49050042,0x00000000}},	// [c9f0] _tehe, _babk, _हैरो_,
  { {0x81c2001c,0x45d50a7d,0xab5b004e,0x00000000}},	//   šēja, рожс, vaüh,
  { {0x6459021f,0xc668000a,0x98aa0006,0x00000000}},	//   tiwi, уште_, kybę_,
  { {0xe3150001,0xdd000078,0x63a40445,0x00000000}},	//   имењ, štėj, žinn,
  { {0x645900f3,0x61fc00ea,0x386c009c,0x00000000}},	//   riwi, _űrla, édre_,
  { {0x8627000d,0xd5f90047,0x44ee0061,0x00000000}},	//   _сьме, _בפֿר, bý_,
  { {0x90c20c07,0xfc3f0046,0x3495012c,0x00000000}},	//   обще, kkí_, _вавр,
  { {0x44d10812,0x68380026,0x98aa0006,0x00000000}},	//   mą_, _fídu, gybę_,
  { {0xfe45000a,0x3f990019,0x44d10915,0x00000000}},	//   инио, äsu_, lą_,
  { {0xee360055,0xe0d5005e,0x611c00dd,0x00000000}},	//   ины_, _вожњ, _bălă,
  { {0x44d1078a,0x2167000d,0x611c000c,0x00000000}},	//   ną_, _стаг, _călă,
  { {0x44d1091b,0xed5620fb,0x5c5601a4,0x00000000}},	//   ią_, рою_, ртоф,
  { {0xdb1d004b,0xfaa63d47,0x4c670330,0x00000000}},	//   jasä, раго, риян_,
  { {0x44d10c47,0x200f0bba,0x7f840021,0x00000000}},	//   ką_, _hagi_, _الهن,
  { {0x5d7900b5,0x44d131a7,0xa85602d8,0x00000000}},	//   _באַק, ją_, атај,
  { {0x44ee0512,0x44d11265,0xfc3f0066,0x00000000}},	//   vý_, dą_, ckí_,
  { {0xe7370055,0x200f60e5,0xdb1d0137,0x00000000}},	// [ca00] ает_, _magi_, gasä,
  { {0x2ca700c7,0x200f0397,0x44ee0240,0x00000000}},	//   _kund_, _lagi_, tý_,
  { {0x9c7d017f,0x89db0063,0x44d12594,0x00000000}},	//   luča, _בחיי, gą_,
  { {0x04460138,0x44ee016b,0x9c7d0080,0x00000000}},	//   једн, rý_, ouča,
  { {0x63a400eb,0xddc100c2,0x98aa0006,0x00000000}},	//   žino, dolž, vybę_,
  { {0x32530086,0x683800cd,0xbb3b0047,0x00000000}},	//   овір, _vídu, כעני,
  { {0x200f0e53,0xa3ea005a,0x98aa0006,0x00000000}},	//   _bagi_, _идва_, tybę_,
  { {0x63ad006d,0x768b0058,0xa4b7009a,0x00000000}},	//   ñant, rüye, _כללה_,
  { {0xb3a901f7,0x9c7d017f,0xa0670001,0x00000000}},	//   ğıtı, juča, јања_,
  { {0x68fe076c,0x2c720114,0x9c7d007d,0x00000000}},	//   _oppd, mády_, duča,
  { {0xceb9004c,0xc27b0063,0x2c7201d1,0x00000000}},	//   apř_, _ירמי, lády_,
  { {0x515b0063,0xd00a005e,0x20330044,0x00000000}},	//   _בכבו, _једе_, _وفلس,
  { {0x291a60e6,0xba770021,0xbf16007e,0x00000000}},	//   _arpa_, لاست, _خوشب,
  { {0x64830019,0x200415e1,0xfc3f0066,0x00000000}},	//   võim, lemi_, skí_,
  { {0x22890024,0xdd8f007e,0xac950925,0x00000000}},	//   núka_, _قوه_, _лакш,
  { {0x44d10006,0xdff80053,0x200460e7,0x00000000}},	//   vą_, ्जिद_, nemi_,
  { {0x44d10045,0x85a70001,0xb5a71213,0x00000000}},	// [ca10] wą_, ајед, арей,
  { {0x44d10c47,0x2a780290,0x200460e8,0x00000000}},	//   tą_, corb_, hemi_,
  { {0x22890014,0x20045696,0xe4e70054,0x00000000}},	//   júka_, kemi_, різн,
  { {0x20040035,0xdcef017f,0x44d11265,0x00000000}},	//   jemi_, žeći, rą_,
  { {0x7764011c,0x20043bd2,0x44d1232c,0x00000000}},	//   _държ, demi_, są_,
  { {0x23260699,0x10a50062,0x44d11748,0x00000000}},	//   соши_, бикн, pą_,
  { {0x248d0034,0x200f053b,0x66050360,0x00000000}},	//   _them_, _pagi_, mehk,
  { {0x66050397,0x27e95299,0x2ca70bfc,0x00000000}},	//   lehk, ngan_, _rund_,
  { {0x200f120d,0xb3a90058,0x2ca760e9,0x00000000}},	//   _vagi_, şısı, _sund_,
  { {0x6483004b,0x2ca702e0,0x200f0022,0x00000000}},	//   kõik, _pund_, _wagi_,
  { {0x81c2008f,0x200f60ea,0xfe54005d,0x00000000}},	//   ģēta, _tagi_, تیوب_,
  { {0x20040080,0x6f19002b,0x644b008d,0x00000000}},	//   cemi_, _trwc, nhgi,
  { {0x66050089,0x70740021,0xda660021,0x00000000}},	//   kehk, _بالذ, ماسي,
  { {0x9c7d017f,0x2ca7004b,0x27e932b2,0x00000000}},	//   ruča, _tund_, egan_,
  { {0x6e2305db,0x6e3c40a3,0x7a30004d,0x00000000}},	//   _innb, örbe, _kätz,
  { {0x27e906ec,0x2a7800e5,0xc7a60121,0x00000000}},	//   ggan_, sorb_, сиак,
  { {0x7c24002c,0x64ac005b,0x6f09004d,0x00000000}},	// [ca20] _inir, _eğil, nwec,
  { {0x27e90025,0xa3ea0053,0x7ae6017e,0x00000000}},	//   agan_, _माह_, mukt,
  { {0x68fe01e3,0xeafa006a,0x69ce0026,0x00000000}},	//   _uppd, _شرکت_, mabe,
  { {0x0326137a,0xe7ef0042,0x2c210042,0x00000000}},	//   йден, _छाया_, याएं_,
  { {0x26cf00ea,0x82f7007e,0xfbd30063,0x00000000}},	//   ágot_, مروز_, לתא_,
  { {0x9c7d60eb,0x66050150,0xfe670242,0x00000000}},	//   jučn, cehk, _رد_,
  { {0x291800e8,0xeb9f02ab,0x6443017d,0x00000000}},	//   nvra_, ndør_, ênic,
  { {0x3013005a,0x69ce1fa3,0x9ed80002,0x00000000}},	//   здър, habe, амит_,
  { {0x26d2002c,0x69ce60ec,0xa75b0047,0x00000000}},	//   nsyo_, kabe, ָדיר,
  { {0x7c2400cd,0x644200fe,0x20040026,0x00000000}},	//   _anir, lkoi, semi_,
  { {0x667b00b7,0x38ae0026,0x78bc0080,0x00000000}},	//   רטיק, _nýr_, jprv,
  { {0xdee63e30,0x7ae608a9,0x64420072,0x00000000}},	//   _годи, fukt, nkoi,
  { {0xf1ac0053,0x644200fe,0x29182142,0x00000000}},	//   _चलान, ikoi, evra_,
  { {0xdb1d00ea,0x69ce330b,0x38ae0026,0x00000000}},	//   nbsé, gabe, _býr_,
  { {0x644200fe,0x27e9001f,0x7ae60078,0x00000000}},	//   kkoi, tgan_, aukt,
  { {0x63a4007d,0x7ae660ed,0x8858005e,0x00000000}},	//   žinj, bukt, бисс_,
  { {0x27e904bf,0x9c7d027d,0x69c10014,0x00000000}},	// [ca30] rgan_, lučo, ðles,
  { {0x7bcf014f,0x69ce1493,0x31b40053,0x00000000}},	//   lacu, cabe, ुरोध,
  { {0x9f4d0025,0xdb0f017d,0x44240089,0x00000000}},	//   ifeá_, racõ, _bnm_,
  { {0x26cf00ea,0x26d200a4,0x61f8006f,0x00000000}},	//   ágos_, bsyo_, efvl,
  { {0x386960ee,0xa3ea0053,0x232911c7,0x00000000}},	//   mnar_, _मार_, роли_,
  { {0x41e7019d,0x7a30004d,0x7bcf12a2,0x00000000}},	//   сіда, _sätz, hacu,
  { {0x386960ef,0x2fcd004b,0x9c7d10f5,0x00000000}},	//   onar_, taeg_, vučn,
  { {0x38690627,0x69ce60f0,0xd4980505,0x00000000}},	//   nnar_, zabe, _гру_,
  { {0x2fcd001f,0x628301d9,0x386960f1,0x00000000}},	//   raeg_, plno, inar_,
  { {0x3f83001c,0x6f0900bd,0xc0cb2317,0x00000000}},	//   āju_, rwec, _буде_,
  { {0x38693177,0xdbc70026,0x9c7d1aa5,0x00000000}},	//   knar_, töði, ručn,
  { {0x7f190086,0x320722b6,0x69ce004d,0x00000000}},	//   _віку_, leny_, wabe,
  { {0xe042019d,0x290100ac,0x69ce60f2,0x00000000}},	//   _інши, _apha_, tabe,
  { {0x9dab005a,0x9f4d0025,0x644960f3,0x00000000}},	//   _съда_, cfeá_, _llei,
  { {0x38690026,0x485a000d,0x3ce00053,0x00000000}},	//   fnar_, араў_, _किये_,
  { {0x386960f4,0x7c2460f5,0x29180066,0x00000000}},	//   gnar_, _unir, rvra_,
  { {0xa2db0161,0x35ca0001,0x63a40006,0x00000000}},	// [ca40] _निष्, игао_, žink,
  { {0x65ba0001,0x645b0025,0x26d200a4,0x00000000}},	//   руар_, _amui, rsyo_,
  { {0x32070080,0x6449136d,0x850601fb,0x00000000}},	//   deny_, _blei, توان,
  { {0x9c830a63,0xa2db0053,0x6449001f,0x00000000}},	//   _účto, _निश्, _clei,
  { {0x6442024a,0xc8b50043,0x741314d7,0x00000000}},	//   rkoi, _ولیک, بونا,
  { {0xa2db0394,0x644903d9,0x644260f6,0x00000000}},	//   _निर्, _elei, skoi,
  { {0x64490627,0xf65f0026,0x61ea004d,0x00000000}},	//   _flei, _tvær_, rgfl,
  { {0x6449162b,0x30770021,0x6abd0137,0x00000000}},	//   _glei, يحية_, ypsf,
  { {0x7e2a000d,0x320747bf,0x3f820046,0x00000000}},	//   аіна_, beny_, æku_,
  { {0x24861609,0xddaa0002,0x386d007d,0x00000000}},	//   llom_, штил_, čeri_,
  { {0x6449024a,0x248660f7,0x7bcf60f8,0x00000000}},	//   _ylei, olom_, tacu,
  { {0xa2c10053,0x9c7d0114,0x6b8d00a8,0x00000000}},	//   रीक्, ručo, _pzag,
  { {0x629800ac,0x7e7a007d,0x248604d9,0x00000000}},	//   omvo, potp, ilom_,
  { {0x7bcf006d,0x7d170026,0x6f02235d,0x00000000}},	//   sacu, ðasí, _ipoc,
  { {0x394510ba,0x38691914,0x24861a8f,0x00000000}},	//   áls_, tnar_, klom_,
  { {0x32070080,0x765c001f,0x64830019,0x00000000}},	//   zeny_, _amry, lõiv,
  { {0x24860024,0x25ab0001,0x386960f9,0x00000000}},	// [ca50] dlom_, ађен_, rnar_,
  { {0xab5b01f7,0xf1bf008b,0x1995000d,0x00000000}},	//   saüs, _đáo_, _напя,
  { {0x32070080,0x386901be,0x644960fa,0x00000000}},	//   veny_, pnar_, _plei,
  { {0x24861b7e,0x6e380093,0x3cfb0047,0x00000000}},	//   glom_, _lovb, שלאנ,
  { {0x069b006a,0x64490104,0x7bcd1dba,0x00000000}},	//   _نخست_, _vlei, _meau,
  { {0x6449001f,0x6aad3f38,0xe6010072,0x00000000}},	//   _wlei, _muaf, ävää,
  { {0x6aad0025,0x768b005b,0x320760fb,0x00000000}},	//   _luaf, lüyo, reny_,
  { {0x629800ac,0x320760fc,0x1ec90121,0x00000000}},	//   amvo, seny_, блии_,
  { {0x768b005b,0x63a960fd,0x9c7d007d,0x00000000}},	//   nüyo, _igen, ručl,
  { {0xfe710032,0x5bb60053,0x3ea30137,0x00000000}},	//   عدة_, ूर्व, öjt_,
  { {0x7bcd04bc,0x3eb9001c,0x6f024350,0x00000000}},	//   _beau, ūst_, _epoc,
  { {0x80140086,0x7bcd60fe,0x768b0058,0x00000000}},	//   _офіц, _ceau, küyo,
  { {0x63a90035,0x7ff4007e,0x0b430062,0x00000000}},	//   _mgen, _آسما, енян,
  { {0xdb0f0027,0xc3320165,0x3ebf0e4f,0x00000000}},	//   ódái, תוך_, mput_,
  { {0x929d0045,0x63a960ff,0x3ebf0150,0x00000000}},	//   _usłu, _ogen, lput_,
  { {0x7bcd0983,0x63a421e3,0x63a96100,0x00000000}},	//   _geau, žini, _ngen,
  { {0x6281017f,0x3ebf6101,0x6d410674,0x00000000}},	// [ca60] _oklo, nput_, lyla,
  { {0xa5960076,0x9c7d00c2,0xda0a005d,0x00000000}},	//   прещ, jučj, _ايده_,
  { {0x9c8300c3,0xd82605fb,0x75560095,0x00000000}},	//   ščej, _едни, чњац,
  { {0x3a3a00df,0x6d5c0139,0xaa7b0046,0x00000000}},	//   _hopp_, úrai, nrýn,
  { {0x7e6100fe,0x24070062,0xa2b30054,0x00000000}},	//   kilp, янци_, ебіч,
  { {0x26c002f6,0x6d410006,0x63a906a3,0x00000000}},	//   mpio_, kyla, _egen,
  { {0x40340ac5,0x24866102,0x62980244,0x00000000}},	//   дейс, plom_, rmvo,
  { {0x3a3a0137,0xa0a30002,0x6d415f01,0x00000000}},	//   _lopp_, најд, dyla,
  { {0xf34a0121,0x7bcd13cb,0x00000000,0x00000000}},	//   _упал_, _reau,   ,
  { {0x63a900c2,0x44d80266,0x78a66103,0x00000000}},	//   _zgen, oč_, _likv,
  { {0xc04f019d,0x7bcd2346,0x41bb0063,0x00000000}},	//   _зі_, _peau, _הצבע,
  { {0xf044007e,0x44d825ba,0x53cc0053,0x00000000}},	//   _تعطی, ič_, ारिश,
  { {0x6d41005b,0x7e610829,0x9c7d08c1,0x00000000}},	//   ayla, bilp, lučk,
  { {0xadbc000d,0x7ae0013d,0x8f9b0063,0x00000000}},	//   _такi, ámta, _הידי,
  { {0x661500c3,0x6c550076,0x26c7007d,0x00000000}},	//   _razk, _окку, ćnom_,
  { {0x44f50ddc,0xb9050053,0xf1bf008b,0x00000000}},	//   vå_, _नि_, _đám_,
  { {0x2bc30235,0x59bf0053,0x44d806b1,0x00000000}},	// [ca70] _व्या, ्रदर, eč_,
  { {0x929d0051,0xe2a3001b,0x768b3ff0,0x00000000}},	//   _opła, _chữ_, rüyo,
  { {0x58d40055,0x9c7d082a,0x13f5000d,0x00000000}},	//   _поэт, jučk, дзея,
  { {0x9f9d03d9,0x27ed00b9,0x62811871,0x00000000}},	//   nção_, _øen_, _sklo,
  { {0x9f9d0016,0x66150089,0x44f50829,0x00000000}},	//   ição_, _tazk, så_,
  { {0xc244000d,0x386d10f5,0xc3240085,0x00000000}},	//   ннік, čeru_, эмік,
  { {0x628100c3,0x9c7d007d,0x63a901e1,0x00000000}},	//   _vklo, ručj, _tgen,
  { {0x3ebf6104,0x63a96105,0xf9940047,0x00000000}},	//   tput_, _ugen, ערק_,
  { {0x59bf0053,0x7e616106,0x6d41002b,0x00000000}},	//   ्रार, tilp, wyla,
  { {0x62810117,0x9f9d017d,0x463a0047,0x00000000}},	//   _uklo, eção_, ַערע,
  { {0xac0a1705,0x00000000,0x00000000,0x00000000}},	//   онна_,   ,   ,
  { {0x64830019,0xab5b00bd,0x7e610078,0x00000000}},	//   mõis, rbün, silp,
  { {0x2d8a0066,0xe9f90013,0x64ac003b,0x00000000}},	//   ýber_, _quế_, _işie,
  { {0x9f9d0016,0xb69b003b,0x8f9a009a,0x00000000}},	//   ação_, _spân, _ויני,
  { {0x26c0002b,0x768b0058,0x2fcf0783,0x00000000}},	//   wpio_, rüyl, _kegg_,
  { {0x9f9d0016,0x7e7c00c2,0x7af7013d,0x00000000}},	//   cção_, črpe, ögtö,
  { {0x1867000a,0xd7ef0021,0x3a3a3a97,0x00000000}},	// [ca80] фати_, شكل_, _topp_,
  { {0x2fcf1609,0xa5f70138,0xc1ac0053,0x00000000}},	//   _legg_, међу_, _चलेग,
  { {0x3ea70d11,0x9e7a0047,0x88e60121,0x00000000}},	//   _mint_, קנעפ, _южне,
  { {0x26c03b1f,0x2d870104,0x3ea700bc,0x00000000}},	//   ppio_, _myne_, _lint_,
  { {0x2d870474,0x17c70086,0x6483004b,0x00000000}},	//   _lyne_, _ігри_, võit,
  { {0x2d8b0045,0x9343005a,0x8b570149,0x00000000}},	//   ęcej_, ънче, וינס_,
  { {0x20d30021,0xdfd00044,0x00000000,0x00000000}},	//   نتيج, هيث_,   ,
  { {0x3eaf01e1,0x71090054,0xddc10078,0x00000000}},	//   _bugt_, яхів_, bilū,
  { {0xdefa0088,0x69de00c2,0x929d0051,0x00000000}},	//   цый_, _odpe, _wpła,
  { {0x7bc6001c,0x6483004b,0x3eb96107,0x00000000}},	//   ebku, sõit, ísta_,
  { {0x9c7d2f23,0x7ae62b56,0xa0a60591,0x00000000}},	//   luči, erkt, _жажд,
  { {0xccf80080,0x5f2a0076,0xac190086,0x00000000}},	//   rtě_, _моем_, чому_,
  { {0xccf80080,0x9c7d00eb,0x9f9d0016,0x00000000}},	//   stě_, nuči, rção_,
  { {0xfe430062,0x2ba50023,0x9f5f0046,0x00000000}},	//   _инчо, _rīcī_, mduð_,
  { {0x9f9d0016,0x628a05b9,0xd83f0066,0x00000000}},	//   pção_, ilfo, áčov_,
  { {0xdb25000c,0xe894000d,0x764e001f,0x00000000}},	//   ăpân, вась, _alby,
  { {0x9c7d0add,0x2d87006f,0xe5e5007e,0x00000000}},	// [ca90] juči, _zyne_, فزای,
  { {0xa6350085,0x628a41e4,0x9c7d0130,0x00000000}},	//   энзі, jlfo, duči,
  { {0xdcf80418,0x69d50016,0x67d502a9,0x00000000}},	//   _izvē, maze, _пону,
  { {0x4429048e,0x64830019,0x69d56108,0x00000000}},	//   ña_, võis, laze,
  { {0xba74007e,0x9c7d007d,0xb30b002a,0x00000000}},	//   _سایت, guči, تغال_,
  { {0x38b505a5,0x69d56109,0xfe79011b,0x00000000}},	//   _kår_, naze, trům_,
  { {0x7d1c0026,0x9c7d610a,0xd1310049,0x00000000}},	//   ærsl, auči, امع_,
  { {0x3ea7414c,0x7ae608e9,0x65940092,0x00000000}},	//   _sint_, yrkt, _расу,
  { {0x63bb0035,0x2d8a004d,0x2d8704aa,0x00000000}},	//   _ifun, üben_, _syne_,
  { {0x7bdf2c1c,0x69d552c4,0xdd010078,0x00000000}},	//   _adqu, jaze, žuči,
  { {0x38b504b1,0x63a400eb,0x769000fe,0x00000000}},	//   _når_, žint, käyn,
  { {0x3ea70122,0x9c7d00c2,0xddda004c,0x00000000}},	//   _wint_, srčn, botů,
  { {0x69d5017d,0xf0920047,0x3ea750c2,0x00000000}},	//   faze, _ענד_, _tint_,
  { {0x7f5d02dd,0x2d87610b,0x7f3a0063,0x00000000}},	//   úsqu, _tyne_, _מתנג,
  { {0x9c8300c3,0xd37b0085,0xf1b2009a,0x00000000}},	//   ščaj, _лiчы, רסל_,
  { {0xf7720021,0x16020042,0x25fd0042,0x00000000}},	//   هاء_, र्नर_, र्सी_,
  { {0x69da0e7c,0x69d500f5,0xc052009f,0x00000000}},	// [caa0] ótes, baze, אזן_,
  { {0x38b531c8,0x69de0146,0x69d5610c,0x00000000}},	//   _får_, _udpe, caze,
  { {0x38b531c8,0x24840089,0x0446610d,0x00000000}},	//   _går_, _pkmm_, нежн,
  { {0x29370047,0x628a00ca,0x00000000,0x00000000}},	//   _נאכן_, wlfo,   ,
  { {0xbb3b00b5,0x33830062,0x93b30085,0x00000000}},	//   ּעצי, лушв, убіц,
  { {0x68fc00c3,0x9c7d0c19,0xb425005d,0x00000000}},	//   otrd, ruči, _یعقو,
  { {0x68e301e1,0x73e60505,0xa5073d71,0x00000000}},	//   _åndt, _повз, _пера_,
  { {0xdfd00021,0x649100d1,0x69c7007d,0x00000000}},	//   جية_, låin, zbje,
  { {0x64ac005b,0x25fd0053,0x2ca9610e,0x00000000}},	//   _eğit, र्वी_, _riad_,
  { {0x2ca90027,0xf1c30024,0x63a4610f,0x00000000}},	//   _siad_, čší_, žins,
  { {0x827700b5,0x4d980086,0xd6570063,0x00000000}},	//   _טעמע_, ькою_, גיית_,
  { {0xf1bf008d,0x6557009a,0x00000000,0x00000000}},	//   _đái_, תבטא_,   ,
  { {0xdb1d000f,0x9e14000d,0x69d56110,0x00000000}},	//   vasó, _адлі, taze,
  { {0x63ad02dd,0x8fa30001,0x69c76111,0x00000000}},	//   ñanz, _саче, ubje,
  { {0x69d50f18,0x2db7009a,0x67d51b37,0x00000000}},	//   raze, _אלון_, кову,
  { {0x38b52330,0x69d50080,0x69c701e1,0x00000000}},	//   _vår_, saze, sbje,
  { {0x69d55818,0x7c2d6112,0x17f80021,0x00000000}},	// [cab0] paze, _inar, عرفة_,
  { {0xb7140076,0x7afd004d,0x38b500a5,0x00000000}},	//   ыдущ, mtst, _tår_,
  { {0x7aef1930,0x24190086,0x63bb004d,0x00000000}},	//   luct, ділю_, _pfun,
  { {0x7af20080,0x7afd6113,0x6e3c0137,0x00000000}},	//   šetř, otst, örbj,
  { {0x7afd0518,0xf5e70054,0xb8f40042,0x00000000}},	//   ntst, _півм, सी_,
  { {0x98be0006,0xdd86007e,0x68e30093,0x00000000}},	//   štą_, _نو_, _ånds,
  { {0x7afd0717,0x7c2d27dc,0x9c7d04a8,0x00000000}},	//   htst, _onar, luču,
  { {0x63bb1147,0x3eb9004c,0x7afd0196,0x00000000}},	//   _ufun, ísto_, ktst,
  { {0xd215005e,0x7afd2a76,0x442d6114,0x00000000}},	//   _имаћ, jtst, _ine_,
  { {0x443f021f,0x3384000d,0x7afd55dc,0x00000000}},	//   _hou_, _сусв, dtst,
  { {0x2bc30235,0x7d1c04c7,0x2d950062,0x00000000}},	//   _व्हा, årsp, ърис,
  { {0x443f10e9,0x7e7c00c2,0x442d021e,0x00000000}},	//   _jou_, črpa, _jne_,
  { {0x9c7d027c,0x7afd1c1d,0x443f6115,0x00000000}},	//   juču, gtst, _mou_,
  { {0x62836116,0x7c2d47c3,0xdee20caa,0x00000000}},	//   nono, _enar, _тоши,
  { {0x7afd1203,0x442d6117,0x09d50085,0x00000000}},	//   atst, _one_, ыцяў,
  { {0x442d0035,0x63ad01b3,0xb3a9005b,0x00000000}},	//   _nne_, žanj, şıyı,
  { {0xa6861259,0xd6d90054,0x62834ccf,0x00000000}},	// [cac0] влад, етє_, kono,
  { {0x27f2001f,0x442d6118,0x62836119,0x00000000}},	//   sgyn_, _ane_, jono,
  { {0x443f611a,0x64a60454,0x6283611b,0x00000000}},	//   _bou_, важа, dono,
  { {0xb609001c,0x3d190053,0x443f4643,0x00000000}},	//   _atšķ, _बनने_, _cou_,
  { {0xd36f0021,0x442d08c4,0x443f12aa,0x00000000}},	//   يهم_, _dne_, _dou_,
  { {0x7d1c00b9,0xfe670067,0x442d611c,0x00000000}},	//   ærsk, _ضد_, _ene_,
  { {0x443f41f3,0xd1300032,0xd46a1736,0x00000000}},	//   _fou_, صمة_, _живе_,
  { {0x443f00e8,0x68e300b9,0xd3f4000d,0x00000000}},	//   _gou_, _ænde, _гiст,
  { {0xd0070fe2,0x44fc611d,0x61fc0137,0x00000000}},	//   тење_, lí_, _örlo,
  { {0x443f02b0,0x22f7014e,0x6283611e,0x00000000}},	//   _zou_, _בזמן_, cono,
  { {0x44fc1bd2,0x443f0034,0x2d8a00b9,0x00000000}},	//   ní_, _you_, æbe_,
  { {0x98aa0006,0x7afd3495,0x644021e4,0x00000000}},	//   mybė_, ttst, _jomi,
  { {0x7b64000a,0x44fc5a87,0x7afd611f,0x00000000}},	//   атре, hí_, utst,
  { {0x661c11ab,0x7aef2158,0x22890066,0x00000000}},	//   _nark, ruct, búku_,
  { {0x44fc0080,0x98aa0078,0xadf700f2,0x00000000}},	//   jí_, nybė_, _شروط_,
  { {0x7afd00bd,0x6ca4000d,0x64406120,0x00000000}},	//   ptst, _крыж, _nomi,
  { {0x661c6121,0xa3e60053,0x63ad00a8,0x00000000}},	// [cad0] _bark, पणन_, žank,
  { {0x442d00b9,0x98aa0006,0x443f6122,0x00000000}},	//   _sne_, kybė_, _sou_,
  { {0x442d0117,0x661c6123,0x99350021,0x00000000}},	//   _pne_, _dark, _صفحت,
  { {0x64401b69,0x62830022,0x00000000,0x00000000}},	//   _comi, wono,   ,
  { {0x91e50079,0x661c01f7,0x443f6124,0x00000000}},	//   голе, _fark, _vou_,
  { {0x443f0438,0x6d480006,0x38696125,0x00000000}},	//   _wou_, kyda, liar_,
  { {0x64ac005b,0x44fc6126,0x443f6127,0x00000000}},	//   _işin, cí_, _tou_,
  { {0x442d0c6e,0x629a00fe,0xd49b0002,0x00000000}},	//   _une_, _ehto, _црг_,
  { {0x7e7c00c2,0x661c5f42,0x6d480058,0x00000000}},	//   črpn, _yark, eyda,
  { {0x3869003b,0x91ca0053,0xab5b00ea,0x00000000}},	//   hiar_, _स्पै, baüz,
  { {0x8c465724,0x3ff50044,0xdfd10044,0x00000000}},	//   гене, _مكار, _هيا_,
  { {0x8c560044,0x5fb9009d,0x00000000,0x00000000}},	//   ائدا, _נֶ֣ג,   ,
  { {0x38696128,0x44fc0114,0xdee50336,0x00000000}},	//   diar_, zí_, _соли,
  { {0xc1780006,0x6d4800a3,0x9916014b,0x00000000}},	//   _odėl_, byda, льбі,
  { {0x2d94005a,0x201d0089,0xc8b50121,0x00000000}},	//   _кръс, _kawi_, исты,
  { {0x201d0089,0x201f6129,0x38690680,0x00000000}},	//   _jawi_, ndui_, giar_,
  { {0x201d00e3,0x290501f7,0x5baa0086,0x00000000}},	// [cae0] _mawi_, çlar_, _яким_,
  { {0x6440612a,0x44fc612b,0x7ae90066,0x00000000}},	//   _somi, tí_, šetc,
  { {0x3869612c,0x44fc04a5,0xa3ea0002,0x00000000}},	//   biar_, uí_, едеа_,
  { {0x98aa0006,0x44fc10c3,0x386953c4,0x00000000}},	//   vybė_, rí_, ciar_,
  { {0x661c612d,0x6d480051,0x44fc2194,0x00000000}},	//   _tark, zyda, sí_,
  { {0x98aa0006,0x661c0089,0x6440004d,0x00000000}},	//   tybė_, _uark, _womi,
  { {0x0496000d,0x6d48612e,0xf1bf008d,0x00000000}},	//   _браў, xyda, _đát_,
  { {0x64403b7e,0x769000fe,0x672418d7,0x00000000}},	//   _uomi, käyk, ovij,
  { {0xc3560062,0x6d480cc4,0x61f60021,0x00000000}},	//   _съвъ, wyda, _مساء,
  { {0x98be0006,0x6d48612f,0x715a6130,0x00000000}},	//   štę_, tyda, _прес_,
  { {0xdd94000d,0x127b0047,0x5c751fc6,0x00000000}},	//   раны, _טאמע, илот,
  { {0xc0ff008b,0x248620a4,0x6d486131,0x00000000}},	//   _lướt_, noom_, ryda,
  { {0x6d5a367f,0x38693ea0,0x9e340854,0x00000000}},	//   szta, viar_, _велч,
  { {0x24570058,0x6724007d,0x28b60042,0x00000000}},	//   _içme_, dvij, _आंशि,
  { {0x386900ae,0x6724001c,0xaa7b004a,0x00000000}},	//   tiar_, evij, krýv,
  { {0x63ad6132,0x48150141,0x321e0022,0x00000000}},	//   žani, јмас, _laty_,
  { {0x38696133,0x3eae00b9,0x291a0331,0x00000000}},	// [caf0] riar_, _kift_, _espa_,
  { {0x201f6134,0xdb1d0014,0xc6a73d6c,0x00000000}},	//   zdui_, fasö, урби,
  { {0x38692aac,0x67240077,0xe8956135,0x00000000}},	//   piar_, avij, _вань,
  { {0x69d700bd,0xa4d40054,0x3eae201a,0x00000000}},	//   _hexe, соці, _lift_,
  { {0xb7da0063,0xe3b80054,0x64ac0058,0x00000000}},	//   _בקרי, убі_, _işil,
  { {0xd25b000d,0x201d0360,0xaabc0047,0x00000000}},	//   эце_, _sawi_, עזוכ,
  { {0x69d7017d,0x321e13e4,0xdb1d004b,0x00000000}},	//   _mexe, _daty_, masõ,
  { {0xdb1d0019,0x69d76136,0xc0c8005e,0x00000000}},	//   lasõ, _lexe, ћује_,
  { {0x7cc1008f,0x201f0078,0x16020042,0x00000000}},	//   _mēre, rdui_, र्वर_,
  { {0x769000fe,0x9e65130d,0xdb1d004b,0x00000000}},	//   väyk, рвод, nasõ,
  { {0x672402e2,0x201d0035,0x2d82005b,0x00000000}},	//   zvij, _tawi_, şken_,
  { {0x8b26000d,0x20d3003b,0x645a0078,0x00000000}},	//   адме, mţi_, _įtik,
  { {0x20d30529,0x30840032,0x643a0047,0x00000000}},	//   lţi_, _النف, דערנ,
  { {0x20d3000c,0x4e790047,0xdb1d004b,0x00000000}},	//   oţi_, _שאַצ, jasõ,
  { {0x20d30529,0x290c0268,0x68460878,0x00000000}},	//   nţi_, ïda_, анва,
  { {0x20d3000c,0xe8e0008b,0x7ae9007d,0x00000000}},	//   iţi_, _liệt_, šeta,
  { {0xe7aa0062,0x18990121,0xa6aa00f2,0x00000000}},	// [cb00] твал_, утрь_, ناطق_,
  { {0xd5eb001b,0xcb9b0063,0xdb9b0063,0x00000000}},	//   _địn, _בספט, _בספר,
  { {0x24860104,0x67245935,0x69dc6137,0x00000000}},	//   toom_, svij, mare,
  { {0xcd9a0047,0x69dc09c7,0x2eed0014,0x00000000}},	//   דױער, lare, kref_,
  { {0xb8f9016a,0xe8e0001b,0x20d3000c,0x00000000}},	//   ठी_, _biệt_, eţi_,
  { {0x2eed001f,0x64590089,0xdb1f017d,0x00000000}},	//   dref_, ahwi, _reqü,
  { {0xdb1f13a3,0xe8e0008b,0xddc80078,0x00000000}},	//   _seqü, _diệt_, sidū,
  { {0xc0340138,0x64590d9d,0x69dc6138,0x00000000}},	//   сниј, chwi, hare,
  { {0x20d30529,0x25fd0053,0x69dc6139,0x00000000}},	//   aţi_, र्की_, kare,
  { {0x38bc006d,0x7e540054,0x98be004c,0x00000000}},	//   _oír_, своє, átě_,
  { {0x2d981609,0x69dc613a,0x45b70047,0x00000000}},	//   åre_, dare, יפיל_,
  { {0x98be0080,0x69ce613b,0x69d72a8a,0x00000000}},	//   ště_, ebbe, _sexe,
  { {0x69dc613c,0x8fa60f9a,0xcb44613d,0x00000000}},	//   fare, _таде, охри,
  { {0xbea3000d,0xdb1d013d,0x69dc613e,0x00000000}},	//   _дачк, ncsé, gare,
  { {0x7e7d006d,0x6e3c0137,0xdb1d4fec,0x00000000}},	//   éspe, örbu, vasõ,
  { {0x08540086,0x7d1c00b9,0x8bd5005e,0x00000000}},	//   овсю, ærsu, _ужиц,
  { {0x57a7005a,0x69dc613f,0x7bdd0214,0x00000000}},	// [cb10] ршва, bare, masu,
  { {0x69dc6140,0x69c0004c,0x78a4004b,0x00000000}},	//   care, ěmec, amiv,
  { {0x74a7018e,0xa3bb0021,0xe4a70bc7,0x00000000}},	//   ајде, ناشر_, ардо,
  { {0x68f50058,0x64ac003b,0x7bdd6141,0x00000000}},	//   muzd, _uşil, nasu,
  { {0x387e00ea,0x290300ea,0x2458000d,0x00000000}},	//   étre_, ltja_, шаць_,
  { {0xd2640086,0xf2070065,0x2903004b,0x00000000}},	//   окій, рядо, otja_,
  { {0x2a5801d8,0xe8e000aa,0x68f5005b,0x00000000}},	//   שבון_, _việt_, nuzd,
  { {0x20d30529,0x69dc03fe,0x2eed07a7,0x00000000}},	//   rţi_, zare, tref_,
  { {0x69dc01f7,0x2fcd6142,0x9e65012c,0x00000000}},	//   yare, rbeg_, йвид,
  { {0xee390001,0x20d3003b,0x69dc6143,0x00000000}},	//   уно_, pţi_, xare,
  { {0x69dc6144,0xac860086,0x2903013d,0x00000000}},	//   vare, йгол, jtja_,
  { {0xed560086,0x69dc6145,0x64ac003b,0x00000000}},	//   сою_, ware, _aşij,
  { {0x69dc6146,0x29030026,0x38bc013d,0x00000000}},	//   tare, etja_, _sír_,
  { {0x539a0047,0xfc3f0080,0x9cb2007e,0x00000000}},	//   טירו, ají_, _کميت,
  { {0x69dc6147,0x7d1c0014,0x7bdd004b,0x00000000}},	//   rare, ærst, basu,
  { {0x69dc6148,0x39450137,0x8d74005d,0x00000000}},	//   sare, älsa_, _باها,
  { {0xfc570063,0xf5b60021,0x69dc489f,0x00000000}},	// [cb20] _לבקש_, مصاد, pare,
  { {0xcf9200b5,0x38bc0025,0x78a4004b,0x00000000}},	//   לטן_, _tír_, smiv,
  { {0x7ae40031,0xf1bf008b,0x929d0051,0x00000000}},	//   _hvit, _đáp_, _usły,
  { {0x7ae41699,0x249f5137,0x54b70085,0x00000000}},	//   _kvit, _chum_, ёгія_,
  { {0x61d80085,0xf77214d7,0x00000000,0x00000000}},	//   амля_, _راح_,   ,
  { {0x46a30086,0x44206149,0x38cb007e,0x00000000}},	//   _наяв, ži_, _جایی_,
  { {0xab5b004d,0x2d910058,0x9c8300a8,0x00000000}},	//   nbür, üzel_, ščij,
  { {0xd1380051,0x7ae4614a,0x8cd20053,0x00000000}},	//   _rząd_, _ovit, _भौगो,
  { {0x10470062,0x7ae4614b,0x22450b82,0x00000000}},	//   сящи_, _nvit, _folk_,
  { {0x29030026,0x7bdd0150,0x43570063,0x00000000}},	//   ytja_, wasu, _הסמל_,
  { {0x25fd0161,0x7bdd614c,0x628a614d,0x00000000}},	//   र्टी_, tasu, mofo,
  { {0xb606001c,0x7aef0139,0x628a614e,0x00000000}},	//   lašā, trct, lofo,
  { {0x3f670076,0xab870edb,0x7cc1008f,0x00000000}},	//   _лицо_, сунк, _pērc,
  { {0x7bdd0ff2,0x628a614f,0x7ae40078,0x00000000}},	//   sasu, nofo, _dvit,
  { {0x7bdd6150,0x1958000d,0x7ae40530,0x00000000}},	//   pasu, бары_, _evit,
  { {0x290300ea,0x2ca0000c,0x2d9c00a8,0x00000000}},	//   rtja_, _ghid_, _izve_,
  { {0x29036151,0xaae70021,0x249f006c,0x00000000}},	// [cb30] stja_, _اسبو, _rhum_,
  { {0xceb30132,0x95d80121,0x85a7005e,0x00000000}},	//   פיע_, йдут_, бјед,
  { {0x24570058,0x628a6152,0x7ae400c2,0x00000000}},	//   _açma_, dofo, _zvit,
  { {0x3cfb0047,0xd371002a,0x25fd0042,0x00000000}},	//   רלאנ, وها_, र्जी_,
  { {0x923925b6,0x22456153,0x7cc1008f,0x00000000}},	//   ичку_, _polk_, _mēra,
  { {0xa4d50088,0xa2290121,0xb6040085,0x00000000}},	//   _могі, ржка_, _няск,
  { {0xa1560001,0x61420062,0x224526d3,0x00000000}},	//   жају_, деща, _volk_,
  { {0xdb210024,0x5058000d,0x22450104,0x00000000}},	//   _štýl, йшыя_, _wolk_,
  { {0x22453918,0xa2670062,0xddda013d,0x00000000}},	//   _tolk_, _лъжл, eltű,
  { {0x7d090001,0x63ad027c,0x3eb100ea,0x00000000}},	//   аног_, žans, özt_,
  { {0xc5f201f9,0xcf27007e,0x1d092c47,0x00000000}},	//   ודי_, _گراي, шени_,
  { {0x69c521ad,0xb4fa0063,0x6e3c0137,0x00000000}},	//   _afhe, ספרי, örbr,
  { {0xdb690121,0xbd45005d,0xcf2704a0,0x00000000}},	//   брёл_, _ژنتي, _دراي,
  { {0x769000fe,0xfc3f006d,0x3f8a00dd,0x00000000}},	//   näyt, rmía_, şbuc_,
  { {0xd826137a,0x66170137,0xceb2016e,0x00000000}},	//   одви, dexk, _קיו_,
  { {0xab5b0378,0x69c50046,0xdd12005d,0x00000000}},	//   rbür, _efhe, _آويخ,
  { {0x7690024a,0x39a300ea,0x7ae404aa,0x00000000}},	// [cb40] käyt, tésé_, _uvit,
  { {0xa5960062,0x7c2444f3,0x628a6154,0x00000000}},	//   орещ, _hair, xofo,
  { {0x7c246155,0x2904003b,0xd4f50085,0x00000000}},	//   _kair, ămas_, зячы,
  { {0x7c246156,0x6e23002b,0xe64a0058,0x00000000}},	//   _jair, _lanb, ıkış,
  { {0x7c246157,0x628a6158,0x2fdf4e91,0x00000000}},	//   _mair, tofo, daug_,
  { {0x7aeb00b9,0x27e04d6f,0xdbd90026,0x00000000}},	//   _ægte, lain_, hæði,
  { {0x7173007e,0x628a5344,0xe5770131,0x00000000}},	//   وهها, rofo, _дзр_,
  { {0x3013005a,0x6e2303a8,0x7c26006f,0x00000000}},	//   ддър, _aanb, jdkr,
  { {0xc106006a,0x628a0035,0x44246159,0x00000000}},	//   _ژوئي, pofo, _iam_,
  { {0xe7310019,0x27e02389,0x44243252,0x00000000}},	//   _tööü, hain_, _ham_,
  { {0x7c241610,0x27e0615a,0x4426615b,0x00000000}},	//   _bair, kain_, odo_,
  { {0xfe7800eb,0x644257b9,0x7c24615c,0x00000000}},	//   snį_, njoi, _cair,
  { {0x4426615d,0x644200fe,0x44241d9b,0x00000000}},	//   ido_, ijoi, _mam_,
  { {0xfe6f0032,0x644200fe,0x4424615e,0x00000000}},	//   _لدى_, hjoi, _lam_,
  { {0x7c2404bc,0x27e0002b,0x286b005e,0x00000000}},	//   _fair, fain_, арао_,
  { {0x7c24615f,0x44246160,0x76900072,0x00000000}},	//   _gair, _nam_, käys,
  { {0x44260185,0xf7700021,0xb9020053,0x00000000}},	// [cb50] ddo_, ناك_, _नौ_,
  { {0x4424590e,0x68e10014,0xe6130021,0x00000000}},	//   _aam_, álds, بشر_,
  { {0x44246161,0x1a9c0047,0x27e06162,0x00000000}},	//   _bam_, _דיזע, bain_,
  { {0x27e06163,0x44260150,0x44246164,0x00000000}},	//   cain_, gdo_, _cam_,
  { {0x769000fe,0x083a0047,0x883a0063,0x00000000}},	//   täyt, _הערל, _התרו,
  { {0x44260b2b,0xc244000d,0x644200fe,0x00000000}},	//   ado_, мнік, ajoi,
  { {0xa3d50001,0x6e23002b,0x44246165,0x00000000}},	//   _новч, _ranb, _fam_,
  { {0xb97c014e,0x769000fe,0x7cc1001c,0x00000000}},	//   ינוי, säyt, _bērn,
  { {0xdbd9007a,0xf207000d,0x69da0014,0x00000000}},	//   væði, _мяжо, ðtek,
  { {0x442402cc,0x7c360014,0x7c246166,0x00000000}},	//   _zam_, _snyr, _sair,
  { {0x27e000a4,0x645b6167,0x644911a1,0x00000000}},	//   yain_, _klui, _koei,
  { {0x6e2300ca,0xf65f0014,0x160b0042,0x00000000}},	//   _wanb, _stæl_, स्तर_,
  { {0x7c240418,0xeb9f010a,0xdbd9007a,0x00000000}},	//   _vair, lføj_, ræði,
  { {0x19b9019d,0x442600eb,0x645b0268,0x00000000}},	//   жуть_, zdo_, _llui,
  { {0x27e009b8,0x485a000d,0x7c246168,0x00000000}},	//   tain_, браў_, _tair,
  { {0x7c240025,0xb3420058,0xd6d20044,0x00000000}},	//   _uair, şçil, فقر_,
  { {0x27e06169,0xabfb009a,0xe737197b,0x00000000}},	// [cb60] rain_, _ההפר, пет_,
  { {0x1779019d,0x27e00dbb,0x44246117,0x00000000}},	//   ість_, sain_, _sam_,
  { {0x69de006f,0x27e01cec,0x4424616a,0x00000000}},	//   _iepe, pain_, _pam_,
  { {0x7469019d,0x645b0027,0xd3260086,0x00000000}},	//   орів_, _clui, зьки,
  { {0x6442024a,0x69de0e53,0x442406bb,0x00000000}},	//   rjoi, _kepe, _vam_,
  { {0x44240051,0x645b004b,0x76900072,0x00000000}},	//   _wam_, _elui, räys,
  { {0x769000fe,0xe1230002,0x69de0150,0x00000000}},	//   säys, емји, _mepe,
  { {0x644900e8,0x757b0063,0x5066000d,0x00000000}},	//   _goei, _הטלפ, ятла,
  { {0xa411005b,0x41b60062,0x7e2a0603,0x00000000}},	//   lığı_, _есет, біна_,
  { {0x7ae90ffb,0x69de616b,0xdbe50042,0x00000000}},	//   šetk, _nepe, कण्ड_,
  { {0x38600e53,0x7ae6616c,0xa4110058,0x00000000}},	//   khir_, eskt, nığı_,
  { {0x6ab50053,0xd0190051,0x00bb0063,0x00000000}},	//   ंद्र, ceń_, _המאמ,
  { {0x69de0102,0xdb240014,0x7ac70fc7,0x00000000}},	//   _bepe, ýrðu, ясне,
  { {0x69de0164,0x38600058,0x2d580e82,0x00000000}},	//   _cepe, ehir_, _миль_,
  { {0xdd93000d,0x6b841eb0,0x1958000d,0x00000000}},	//   _пашы, _exig, пары_,
  { {0xa41101f7,0x5d7b0149,0x62980244,0x00000000}},	//   dığı_, _לאוק, hlvo,
  { {0x6449006f,0xf77304f6,0x3d180053,0x00000000}},	// [cb70] _roei, رار_, यौरे_,
  { {0x645b04c6,0xd5bb0b3f,0xd0190051,0x00000000}},	//   _slui, сса_, zeń_,
  { {0x6449017d,0x38600139,0x645b0922,0x00000000}},	//   _poei, bhir_, _plui,
  { {0x38810006,0x84640062,0x5455000d,0x00000000}},	//   bėra_, нъче, ьвет,
  { {0x3c780063,0x4734014b,0x00000000,0x00000000}},	//   התאם_, _зняс,   ,
  { {0x7bdf0164,0x672d4f93,0xc293005d,0x00000000}},	//   _lequ, mvaj, ریاب,
  { {0x672d5184,0xf497007e,0x64ac0058,0x00000000}},	//   lvaj, _فشرد, _rşiv,
  { {0x92f20058,0x11280054,0x6298616d,0x00000000}},	//   üğüm, яючи_, alvo,
  { {0x2d98616e,0x2127005d,0x6006014b,0x00000000}},	//   üren_, زيکی_, фным_,
  { {0x916c0013,0x248f0137,0xfe450054,0x00000000}},	//   uộc_, logm_, єнно,
  { {0x16020053,0x7cc1001c,0x61e3616f,0x00000000}},	//   र्टर_, _vēro, manl,
  { {0x69de08f0,0x61e36170,0xeb9a0c46,0x00000000}},	//   _sepe, lanl, жим_,
  { {0x0b430086,0x69de0c96,0x7ff40021,0x00000000}},	//   внян, _pepe, _أسما,
  { {0x3ab50001,0x672d082a,0xfe0e0013,0x00000000}},	//   ељст, dvaj, _hững_,
  { {0x38606171,0x62720022,0x387e6172,0x00000000}},	//   thir_, kłon, étro_,
  { {0x63bb00bb,0x6f090a54,0x7bdf004d,0x00000000}},	//   _ngun, otec, _gequ,
  { {0x6f091876,0x61e30351,0xe64a02a1,0x00000000}},	// [cb80] ntec, kanl, опад_,
  { {0x63bb053b,0xa411005b,0x61e35e95,0x00000000}},	//   _agun, tığı_, janl,
  { {0x04460088,0xa5070062,0x61e36173,0x00000000}},	//   межн, деха_, danl,
  { {0x6f096174,0x7bdf017d,0x68fc6175,0x00000000}},	//   ktec, _xequ, murd,
  { {0x2b7b0047,0x61e36176,0x6e28002b,0x00000000}},	//   ֿטצײ, fanl, yddb,
  { {0x61e315e1,0x6f096177,0x68fc006c,0x00000000}},	//   ganl, dtec, ourd,
  { {0xc1030021,0x290a00ea,0xd4f50766,0x00000000}},	//   نووي, ntba_, _пяты,
  { {0xdfd00032,0x20020019,0xe8e0008d,0x00000000}},	//   دية_, üki_, _nhọt_,
  { {0x30a3005a,0x61e3005b,0xf1cf0053,0x00000000}},	//   ършв, banl, _स्वन,
  { {0x3f98001c,0x68fc5552,0x20020051,0x00000000}},	//   āru_, kurd, żki_,
  { {0x672d00c3,0x7bdf0fac,0xab5b005b,0x00000000}},	//   zvaj, _pequ, rcüm,
  { {0x83fd00ea,0x68fc175c,0x672d0066,0x00000000}},	//   _előf, durd, yvaj,
  { {0x6f09008f,0xa08b009a,0xbef700de,0x00000000}},	//   ctec, _וְגִ, _قروض_,
  { {0x62720051,0x8f9b009a,0xdb210046,0x00000000}},	//   złon, _וידי, _ótím,
  { {0x1994005a,0x7bdf6178,0x68fc6179,0x00000000}},	//   варя, _tequ, gurd,
  { {0x61e3092a,0xcc8801ce,0x9c870044,0x00000000}},	//   zanl, _обје_, _تشته,
  { {0xe8940076,0x61e3005b,0x59d00042,0x00000000}},	// [cb90] тать, yanl, _त्वर,
  { {0x7afd617a,0xc5fb0021,0x321c004c,0x00000000}},	//   must, تعرض_, jevy_,
  { {0x7afd07d2,0xe4cb007e,0x61e3617b,0x00000000}},	//   lust, زبان_, vanl,
  { {0x6f0913e4,0xb5a425ec,0x8c1c0041,0x00000000}},	//   ytec, труй, ַווי,
  { {0x61e3617c,0x7afd617d,0x78ad00ca,0x00000000}},	//   tanl, nust, mmav,
  { {0x62720051,0x7afd617e,0x78ad617f,0x00000000}},	//   słon, iust, lmav,
  { {0x7afd0004,0x2055000a,0x7bc1004c,0x00000000}},	//   hust, етпр, ěluj,
  { {0x2c620024,0xff256180,0x10a22377,0x00000000}},	//   _kóde_, емио, лищн,
  { {0xef161485,0xfe0e008b,0x7afd13f1,0x00000000}},	//   емы_, _vững_, just,
  { {0x6f096181,0xd1c50021,0x7afd27ff,0x00000000}},	//   rtec, _أيضً, dust,
  { {0xc692014e,0x6f096182,0x7afd0254,0x00000000}},	//   ראי_, stec, eust,
  { {0x68fc6183,0x61e16184,0xf1bf0013,0x00000000}},	//   vurd, _hell, _đáy_,
  { {0x61e16185,0x9f050021,0x7afd6186,0x00000000}},	//   _kell, _أوتو, gust,
  { {0x68fc0780,0x61e16187,0xf2d20149,0x00000000}},	//   turd, _jell, רעם_,
  { {0x61e16188,0x5d790047,0x68fc25d2,0x00000000}},	//   _mell, _מאַק, uurd,
  { {0x290a00ea,0x7afd6189,0xf7460094,0x00000000}},	//   rtba_, bust, небо,
  { {0x18670054,0xdb1d013d,0x68fc618a,0x00000000}},	// [cba0] хати_, pcsá, surd,
  { {0x61e1104f,0x78ad4493,0xab5b005b,0x00000000}},	//   _nell, amav, zcük,
  { {0x89db0063,0x78af0014,0xb6060195,0x00000000}},	//   _מחיי, ónvö, jváž,
  { {0x64ac0058,0xf4960021,0xc5e9009a,0x00000000}},	//   _aşir, رشاد, מד_,
  { {0x321c0066,0x61e1618b,0xe29a05ce,0x00000000}},	//   tevy_, _bell, пад_,
  { {0x60c101f7,0x61e10399,0xc2c3007e,0x00000000}},	//   _bulm, _cell, ديوي,
  { {0x61e1104f,0x26c20009,0x7afd0404,0x00000000}},	//   _dell, _huko_, zust,
  { {0xc0340001,0x26c200a4,0x61e1004b,0x00000000}},	//   тниј, _kuko_, _eell,
  { {0x61e1618c,0x9f5f01a8,0x200a0022,0x00000000}},	//   _fell, nguè_, ębi_,
  { {0x7afd612d,0x61e1001f,0xdfd0007e,0x00000000}},	//   vust, _gell, ديک_,
  { {0x2d980831,0x85f70047,0x7afd0983,0x00000000}},	//   ære_, עצטע_, wust,
  { {0x61e100bd,0x7afd618d,0x5b270121,0x00000000}},	//   _zell, tust, ньга,
  { {0x61e13eb9,0x291e005b,0x7afd01cf,0x00000000}},	//   _yell, çtan_, uust,
  { {0x764e00a4,0xe919000d,0x7afd618e,0x00000000}},	//   _noby, могі_, rust,
  { {0x1995005a,0x7afd618f,0x67266190,0x00000000}},	//   тавя, sust, _askj,
  { {0x26c200a4,0x2d820058,0xbca5002a,0x00000000}},	//   _buko_, şkes_, _جمعي,
  { {0x81c2008f,0x78ad6191,0xb606004c,0x00000000}},	// [cbb0] ģēja, rmav, zváž,
  { {0x26cf001c,0x78ad0fb8,0x4b7c0063,0x00000000}},	//   īgo_, smav, _מאחו,
  { {0x61e12f4c,0x7aed6192,0x764e1ad3,0x00000000}},	//   _rell, _hvat, _doby,
  { {0x999a0080,0x61e1010e,0xc3550002,0x00000000}},	//   _např_, _sell, ккеј,
  { {0x44290024,0x60c11f83,0x64596193,0x00000000}},	//   ľa_, _sulm, rkwi,
  { {0x764e002c,0x4429064f,0x6d470072,0x00000000}},	//   _goby, ža_, äjak,
  { {0x637300ea,0x61e16194,0xddda004c,0x00000000}},	//   _bűnö, _vell, entů,
  { {0x2ca9001f,0x9f5f0110,0x61e1537f,0x00000000}},	//   _nhad_, lgué_, _well,
  { {0xef19019d,0x61e16195,0xa2b50085,0x00000000}},	//   ємо_, _tell, _абач,
  { {0x9f5f1b84,0x2ca9053b,0x61e13318,0x00000000}},	//   ngué_, _ahad_, _uell,
  { {0x42360047,0x2ca90139,0x26060053,0x00000000}},	//   _שנעל_, _bhad_, स्टी_,
  { {0xed56019d,0x2ca96196,0x9055129a,0x00000000}},	//   тою_, _chad_, _швец,
  { {0xfaff0003,0x7cc1008f,0xddda005f,0x00000000}},	//   guë_, _mēri, gotų,
  { {0x26c20150,0xab5b0075,0x7bcd0168,0x00000000}},	//   _ruko_, nbüy, _efau,
  { {0x2ca90025,0x4ea40002,0x764e6197,0x00000000}},	//   _fhad_, _срца, _roby,
  { {0x26140053,0xfd5e008d,0xdc760085,0x00000000}},	//   न्नी_, huyề, _шыль,
  { {0xd70a000d,0x7aed1502,0x47c30d3b,0x00000000}},	// [cbc0] ьнае_, _gvat, рбув,
  { {0x787b024a,0x7cc8004c,0x7863004e,0x00000000}},	//   tävä, _měrn, _rõve,
  { {0x27e201e1,0x7aed007d,0x09f7009a,0x00000000}},	//   _tekn_, _zvat, _במים_,
  { {0x97da0021,0x787b0072,0x661e056c,0x00000000}},	//   _تبدأ_, rävä, sepk,
  { {0x7783005a,0x27fd0051,0xf77f0075,0x00000000}},	//   _вляз, ówne_, _peçe_,
  { {0xdce9004c,0x672400ca,0x98b80078,0x00000000}},	//   áněn, mwij, tyrė_,
  { {0x6724006f,0xef1f0058,0x6e2a0046,0x00000000}},	//   lwij, çün_, _rafb,
  { {0xc953014e,0x628f1088,0x98be0006,0x00000000}},	//   שמה_, _ícon, štė_,
  { {0x67240122,0xa491007e,0x2ca9001f,0x00000000}},	//   nwij, _اینت, _rhad_,
  { {0x672b0014,0xc106005d,0x8fa302f8,0x00000000}},	//   ægji, _لوئي, шање,
  { {0x7aed1aa5,0x9c7d0078,0xddc1008f,0x00000000}},	//   _svat, lsči, bilž,
  { {0x6724006f,0x01790041,0x9c7d005f,0x00000000}},	//   kwij, _אָנל, osči,
  { {0xfe6f005d,0xcff7009a,0x2ef30054,0x00000000}},	//   صدی_, _יצאה_, _взір,
  { {0x67240122,0x291a0089,0x6e2a00b9,0x00000000}},	//   dwij, _bppa_, _uafb,
  { {0x67240122,0x2ca9002b,0x644d0072,0x00000000}},	//   ewij, _thad_, öaik,
  { {0x9c7d0006,0x8c440001,0x1d070001,0x00000000}},	//   ksči, _веће, _рећи_,
  { {0xec380047,0x672400ca,0x2d9c0072,0x00000000}},	// [cbd0] _יאהר_, gwij, _hyve_,
  { {0x07080032,0x7cc1008f,0xfaa40092,0x00000000}},	//   ئيلي_, _sēri, _кањо,
  { {0xf8c60066,0x9c7d0078,0x7c2d6198,0x00000000}},	//   žéra_, esči, _kaar,
  { {0x7c2d2034,0x74a4007b,0x6f000023,0x00000000}},	//   _jaar, ајче, kumc,
  { {0x7c2d6199,0x27e9619a,0x249d002b,0x00000000}},	//   _maar, maan_, rlwm_,
  { {0xdd860032,0xd25b0088,0xdb1d0137,0x00000000}},	//   _هو_, ьце_, bbsö,
  { {0xc692014e,0x7cc1001c,0xfd5e0013,0x00000000}},	//   _האם_, _tēri, ruyề,
  { {0x27e9619b,0x7c2d619c,0x34950785,0x00000000}},	//   naan_, _naar, _сабр,
  { {0xdd2e0080,0x78bd3a49,0xe3b30049,0x00000000}},	//   měře, _misv, _ضرر_,
  { {0x27e906c2,0x2f0b0146,0x442d00fe,0x00000000}},	//   haan_, røg_, _hae_,
  { {0x2f0b010a,0x27e928d8,0x67240051,0x00000000}},	//   søg_, kaan_, zwij,
  { {0x27e9619d,0xa158005e,0x6f00619e,0x00000000}},	//   jaan_, _шаху_, bumc,
  { {0x442d0c70,0x7c2d0102,0x27e9619f,0x00000000}},	//   _mae_, _daar, daan_,
  { {0xf1bf0024,0x442d61a0,0x0d730043,0x00000000}},	//   ášho_, _lae_, _پختگ,
  { {0xa96a61a1,0xfe70007e,0x395e0026,0x00000000}},	//   хива_, _بدن_, áts_,
  { {0x6724006f,0x442d032c,0x7c2d61a2,0x00000000}},	//   twij, _nae_, _gaar,
  { {0x7ae90024,0x9f440003,0xf74332e4,0x00000000}},	// [cbe0] šetr, tamé_, бето,
  { {0x672402b0,0x3a260076,0x443f61a3,0x00000000}},	//   rwij, _смог, _anu_,
  { {0x67240122,0xde51008b,0x27e958ee,0x00000000}},	//   swij, _đặc_, baan_,
  { {0x27e961a4,0xeb9f06a5,0x442d42fa,0x00000000}},	//   caan_, mfør_, _cae_,
  { {0x68e31631,0x6e2100eb,0x442d00e8,0x00000000}},	//   _ændr, kelb, _dae_,
  { {0x623461a5,0x69dc61a6,0x11542377,0x00000000}},	//   реку, nbre, иклю,
  { {0x6e2161a7,0xc0e3018e,0xd1300021,0x00000000}},	//   delb, бојк, زمة_,
  { {0x78630019,0x8cca0053,0x442d24bf,0x00000000}},	//   _kõva, _संबो, _gae_,
  { {0xd4670079,0xe475000d,0x644061a8,0x00000000}},	//   _сите_, _турэ, _inmi,
  { {0x27e961a9,0x443f017d,0x7cd3003b,0x00000000}},	//   zaan_, _znu_, _mărf,
  { {0x27e90dbf,0xf67b0063,0xcec8008b,0x00000000}},	//   yaan_, תאימ, _bộc_,
  { {0x69dc61aa,0x9c470121,0xeb9f01e1,0x00000000}},	//   ebre, ухол, dfør_,
  { {0x27e9024a,0xeb070076,0x78bd0290,0x00000000}},	//   vaan_, ычно, _risv,
  { {0x7c2d3028,0x27e91fff,0x2d9c000e,0x00000000}},	//   _waar, waan_, _tyve_,
  { {0x7c2d0009,0x64400162,0x27e9619a,0x00000000}},	//   _taar, _onmi, taan_,
  { {0x20ca0013,0xddc10078,0x6569004c,0x00000000}},	//   _mùi_, bilų, _řeho,
  { {0xdd2e0080,0x20ca0013,0x62831246,0x00000000}},	// [cbf0] věře, _lùi_, ynno,
  { {0x27e9619b,0x6abe004d,0x61ea0046,0x00000000}},	//   saan_, _gipf, jafl,
  { {0x7bcf0b27,0x26140053,0x2eed00ea,0x00000000}},	//   occu, न्धी_, zsef_,
  { {0xd0060021,0x290361ab,0x628800a8,0x00000000}},	//   _ظل_, muja_, _ajdo,
  { {0x290300fe,0x38690025,0x53c8000d,0x00000000}},	//   luja_, mhar_, угім_,
  { {0x38690016,0x26140053,0x6d5a1404,0x00000000}},	//   lhar_, न्दी_, kyta,
  { {0x290300c3,0x7afd00bd,0xe04506b4,0x00000000}},	//   nuja_, hrst, инки,
  { {0x38690016,0x6d5a091b,0x7e7a004d,0x00000000}},	//   nhar_, dyta, eitp,
  { {0xaec20088,0x6e2161ac,0x29031668,0x00000000}},	//   обыл, telb, huja_,
  { {0x7e55257e,0x62720045,0xf8bf0164,0x00000000}},	//   ртиц, dłow, _lié_,
  { {0xc05b019d,0x32cb0031,0x6f1c000c,0x00000000}},	//   _під_, _høy_, ărca,
  { {0x6e2161ad,0x7cd3003b,0x7bdb0014,0x00000000}},	//   selb, _lărg, ðuup,
  { {0xdee50001,0x69dc2b7b,0x6e2161ae,0x00000000}},	//   _толи, tbre, pelb,
  { {0x6d5a001f,0x7d0103db,0x9f840054,0x00000000}},	//   byta, puls, _угід,
  { {0xdca60055,0xcec8001b,0x38760001,0x00000000}},	//   _каки, _tộc_, аћат,
  { {0xad1a014e,0xeb9f0d02,0x69dc61af,0x00000000}},	//   _יוצר, rfør_, sbre,

  { {0xf8bf021f,0x27fd0045,0x929d0045,0x00000000}},	// [cc00] _dié_, ówna_, _wpły,
  { {0x7df30053,0x29030331,0x45d61406,0x00000000}},	//   _आयोग_, buja_, рцат,
  { {0x38690027,0x929d0051,0x98a61bd9,0x00000000}},	//   bhar_, _upły, _вине,
  { {0x1d1600b5,0x3869122e,0x0d160041,0x00000000}},	//   יקער_, char_, יקעט_,
  { {0x6d5a0022,0xd467005e,0x61ea61b0,0x00000000}},	//   zyta, шице_, tafl,
  { {0x7ae40035,0xcb370063,0x64580051,0x00000000}},	//   _mwit, יאני_, _ścią,
  { {0x63a900ea,0x61ea61b1,0x62720022,0x00000000}},	//   _ezen, rafl, złow,
  { {0x644061b2,0x61ea61b3,0x14d70132,0x00000000}},	//   _unmi, safl, _כולל_,
  { {0x32cb00d1,0x7e461dd6,0x2486274b,0x00000000}},	//   _gøy_, ахне, mnom_,
  { {0x6d5a0006,0x7afd02e2,0x248661b4,0x00000000}},	//   tyta, vrst, lnom_,
  { {0x38600026,0x7ae400a4,0x160b0053,0x00000000}},	//   kkir_, _awit, स्टर_,
  { {0x24861609,0x290300fe,0x6298073e,0x00000000}},	//   nnom_, vuja_, lovo,
  { {0x3ed40021,0xe4510063,0x24860da5,0x00000000}},	//   _اقتر, הֶם_, inom_,
  { {0xde570086,0x6d5a0051,0xdb0d0019,0x00000000}},	//   _ваші_, pyta, _igaü,
  { {0x38690025,0x62720051,0x07e70184,0x00000000}},	//   thar_, słow, ицам,
  { {0x7cc1003d,0x7bc4051e,0xfc3f0268,0x00000000}},	//   _vērt, _ggiu, rmís_,
  { {0x395f001c,0x248624a3,0x55c7005e,0x00000000}},	// [cc10] ņus_, dnom_, аљез,
  { {0x3869028d,0x248600c7,0x61e80c68,0x00000000}},	//   shar_, enom_, _nedl,
  { {0x7ae410ce,0x91fc001c,0x38690fd1,0x00000000}},	//   _zwit, _plān, phar_,
  { {0xef1f005b,0x248600cd,0x83fd00ea,0x00000000}},	//   çük_, gnom_, _előn,
  { {0x24180086,0x8c380047,0x53980054,0x00000000}},	//   рією_, יטאס_, авця_,
  { {0x629806bb,0x60c806a5,0x95cb05ce,0x00000000}},	//   govo, _budm, _шума_,
  { {0x25a500ea,0x2486222e,0x09f8009a,0x00000000}},	//   _áll_, bnom_, שֶׂר_,
  { {0x201961b5,0x24860130,0xc2c50044,0x00000000}},	//   ýsi_, cnom_, _هيري,
  { {0x7cd3000c,0x6298004a,0x63a0457d,0x00000000}},	//   _măre, bovo, _gymn,
  { {0x69c5001f,0xfbdf00be,0x5e4949a0,0x00000000}},	//   _nghe, ebê_, упом_,
  { {0x7ae4375e,0x60c802fd,0xc1040044,0x00000000}},	//   _swit, _gudm, _ووكي,
  { {0x64940058,0xad660085,0x81685aa3,0x00000000}},	//   _güiğ, саюз_, _труб_,
  { {0xc43a0063,0xec770062,0xf43a009d,0x00000000}},	//   אתרי, спя_, אגרמ,
  { {0x248661b6,0x539a0063,0xfbd80053,0x00000000}},	//   znom_, רישו, _भ्रम,
  { {0x291e32c9,0x7cc1001c,0xa9670da9,0x00000000}},	//   ïta_, _vērs, бира_,
  { {0x7cd3000c,0x629861b7,0x787a004c,0x00000000}},	//   _căre, zovo, růvo,
  { {0x3860160e,0xe7aa05fb,0x248604c9,0x00000000}},	// [cc20] rkir_, увал_, vnom_,
  { {0x1a060612,0x35b60ac5,0x38600014,0x00000000}},	//   _упом, бщес, skir_,
  { {0x7c260162,0x2486410b,0x61e861b8,0x00000000}},	//   oekr, tnom_, _redl,
  { {0xd499019d,0xfc3f006d,0x2eff017e,0x00000000}},	//   арі_, plíe_, kruf_,
  { {0x27e04739,0xa3c90053,0x248661b9,0x00000000}},	//   mbin_, ोड़_, rnom_,
  { {0x24860ecf,0xe297000d,0x2508007e,0x00000000}},	//   snom_, бач_, _پرسی_,
  { {0x867b0047,0x7c2661ba,0x78a461bb,0x00000000}},	//   _ערלו, kekr, oliv,
  { {0x27e01362,0x741600b3,0x2eff004d,0x00000000}},	//   nbin_, _دورا, fruf_,
  { {0x33660726,0x44262adb,0x7c260dd9,0x00000000}},	//   _уваг, meo_, dekr,
  { {0x44260009,0xddc8001f,0x78a40114,0x00000000}},	//   leo_, yndŵ, hliv,
  { {0xe0da0138,0x869b0047,0x98c5008f,0x00000000}},	//   _све_, רייז, ētīt_,
  { {0x7cd3000c,0x442661bc,0x6a6b0058,0x00000000}},	//   _bărb, neo_, _müfe,
  { {0xddc8017f,0x7cd3003b,0x3b640062,0x00000000}},	//   midž, _cărb, първ,
  { {0x60c20025,0x6fa50021,0x4426008b,0x00000000}},	//   _hiom, _بإمك, heo_,
  { {0x442610ca,0x7cd3000c,0x7c2602ea,0x00000000}},	//   keo_, _păre, bekr,
  { {0x44260130,0x7c2661bd,0xc7d908f6,0x00000000}},	//   jeo_, cekr, рмах_,
  { {0x76550045,0x9f4400cd,0x442661be,0x00000000}},	// [cc30] _pozy, namà_, deo_,
  { {0x78a461bf,0x60c20139,0x83fd013d,0x00000000}},	//   aliv, _liom, _elől,
  { {0x44263c27,0x78a43036,0x27e061c0,0x00000000}},	//   feo_, bliv, bbin_,
  { {0x4426051e,0xd5b801d5,0x78a425df,0x00000000}},	//   geo_, ссу_, cliv,
  { {0x7eaf076c,0x36d5005e,0x00000000,0x00000000}},	//   løpe, _фогр,   ,
  { {0xddc8143b,0x7c261149,0x60c20072,0x00000000}},	//   eidž, zekr, _aiom,
  { {0x7cd3000c,0x442661c1,0xa3d50054,0x00000000}},	//   _mărc, beo_, _мовч,
  { {0x26c302dd,0x442661c2,0x661c0130,0x00000000}},	//   _hijo_, ceo_, _zbrk,
  { {0x62720051,0x60c23b2f,0x53473515,0x00000000}},	//   głos, _diom, _ухва,
  { {0x248d02ab,0x78a401d9,0x8cca0053,0x00000000}},	//   _hjem_, zliv, _संशो,
  { {0x248d58a0,0xf3f9000c,0x7cd3000c,0x00000000}},	//   _kjem_, _alţi_, _sărb,
  { {0x7536009f,0x16190053,0xe7310075,0x00000000}},	//   קארד_, न्तर_, _göçü,
  { {0x78a40080,0x7cd300dd,0xeb970591,0x00000000}},	//   vliv, _bărc, жия_,
  { {0x7fb60754,0xfce5010d,0x4426007d,0x00000000}},	//   _ظهور_, _доко, zeo_,
  { {0xdab7006a,0x26d90072,0x78a461c3,0x00000000}},	//   زهفت_, _atso_, tliv,
  { {0x248d08ea,0x26cb0290,0x4426006d,0x00000000}},	//   _njem_, _buco_, xeo_,
  { {0x98be0006,0x442661c4,0x18670cb5,0x00000000}},	// [cc40] štį_, veo_, цати_,
  { {0x9f440e7c,0x7dec0047,0x6d5c004b,0x00000000}},	//   namá_, ָקאַ, ärag,
  { {0x26c3048e,0x673d39a8,0x78a461c5,0x00000000}},	//   _dijo_, _ersj, pliv,
  { {0x14170021,0xa5da0042,0xf74605cf,0x00000000}},	//   قيمة_, _प्रौ, _демо,
  { {0x442661c6,0x26c3006d,0x60c20025,0x00000000}},	//   reo_, _fijo_, _riom,
  { {0x366a0088,0x442661c7,0xbb3b0047,0x00000000}},	//   _таго_, seo_, יעני,
  { {0x60c20a02,0x442661c8,0xddc80078,0x00000000}},	//   _piom, peo_, tidž,
  { {0x3ea500c7,0x656300b9,0x9f540086,0x00000000}},	//   ellt_, ønhe, звич,
  { {0x8fa3005e,0xddc81701,0xf8b3089e,0x00000000}},	//   маће, ridž, ושה_,
  { {0xbbe30042,0x6379030b,0x4357009d,0x00000000}},	//   पर्क, _усср_, _וסמל_,
  { {0x60c20025,0xa0a6000d,0x56370041,0x00000000}},	//   _tiom, _дажд, קאטע_,
  { {0x3eb90078,0x2cb2002b,0x69c80078,0x00000000}},	//   įsta_, _chyd_, ždel,
  { {0x628a61c9,0x7ba70043,0x00000000,0x00000000}},	//   onfo, تصدم,   ,
  { {0x32d00013,0x628a04aa,0x25aa0082,0x00000000}},	//   _mày_, nnfo, _करूण,
  { {0x628a61ca,0x26cb017d,0x6e2856a8,0x00000000}},	//   info, _suco_, medb,
  { {0xceb823a8,0x628a0244,0x83fd013d,0x00000000}},	//   lmę_, hnfo, _előj,
  { {0x32d000aa,0x96eb0121,0x61fa2029,0x00000000}},	// [cc50] _này_, рьба_, _odtl,
  { {0x85a7005e,0x213e0616,0x6e2801d1,0x00000000}},	//   ојед, _orth_, nedb,
  { {0x7d081b6b,0x69d50051,0x628a0066,0x00000000}},	//   nuds, mcze, dnfo,
  { {0x32d0008b,0x84640062,0x628a006c,0x00000000}},	//   _bày_, мъче, enfo,
  { {0x4c3c00b5,0xe28e000a,0xd37b0635,0x00000000}},	//   יגאצ, еа_, јче_,
  { {0x999100ea,0xe2990856,0x32d0008b,0x00000000}},	//   lező_, љак_, _dày_,
  { {0x82340021,0x81f60021,0xdb1d013d,0x00000000}},	//   برنا, سفير_, ecsü,
  { {0x628a001f,0x11280086,0x6e2800ca,0x00000000}},	//   anfo, юючи_, eedb,
  { {0x32d0008d,0x2cb2002b,0xd2590023,0x00000000}},	//   _gày_, _rhyd_, _suņu_,
  { {0x3264005a,0x7d09005e,0x313561cb,0x00000000}},	//   _отхв, бног_, _незр,
  { {0x999100ea,0x99830080,0x69d50051,0x00000000}},	//   kező_, dejů_, dcze,
  { {0x69d50051,0x672d0035,0x999100ea,0x00000000}},	//   ecze, kwaj, jező_,
  { {0x70520021,0x2903117f,0x20d10013,0x00000000}},	//   _سنوا, erja_, _hái_,
  { {0x7d0861cc,0x7f3a0063,0xcd28005d,0x00000000}},	//   buds, _לענו, حسین_,
  { {0x6e16006a,0xd94305ef,0xdb1f004c,0x00000000}},	//   _رييس_, нери, ěvák,
  { {0xfc3f61cd,0x20d1008b,0x786a004a,0x00000000}},	//   plía_, _mái_, _býva,
  { {0x20d1008b,0x290361ce,0x83fd00ea,0x00000000}},	// [cc60] _lái_, arja_, _elők,
  { {0x69d50080,0x7c36005b,0x069a0044,0x00000000}},	//   ccze, _hayr, حنطة_,
  { {0x4a5b0063,0x672d0035,0xfc3f0025,0x00000000}},	//   _הדיו, awaj, ilín_,
  { {0x136a0086,0x628a04bf,0xc20e0053,0x00000000}},	//   йшли_, wnfo, _साहब_,
  { {0x7c3600bb,0x6234000a,0x883b0063,0x00000000}},	//   _mayr, делу, _התכו,
  { {0x27f200a4,0x628a0e7c,0x20d10013,0x00000000}},	//   layn_, unfo, _bái_,
  { {0x20d1001b,0x6e2861cf,0x2918313e,0x00000000}},	//   _cái_, vedb, ntra_,
  { {0x7d0802eb,0x69d50051,0xdfd00021,0x00000000}},	//   vuds, zcze, خية_,
  { {0x213e0185,0x69d50051,0xe8e00013,0x00000000}},	//   _wrth_, ycze, _phớt_,
  { {0x7cd3000c,0x29030026,0x290a61d0,0x00000000}},	//   _săra, yrja_, kuba_,
  { {0x6e28017f,0xceb80051,0x20d1008b,0x00000000}},	//   redb, rmę_, _gái_,
  { {0x7d080146,0x672d0051,0x6e2800c2,0x00000000}},	//   ruds, ywaj, sedb,
  { {0x7d08310b,0x6e46000d,0xfc3f1f22,0x00000000}},	//   suds, _недз, blín_,
  { {0xfe6f0021,0x7d0801e1,0xadbc0085,0x00000000}},	//   _مدى_, puds, _калi,
  { {0x999100ea,0x69d50051,0x67d50086,0x00000000}},	//   tező_, rcze, добу,
  { {0x7c360058,0xdca4005e,0x7ceb089e,0x00000000}},	//   _gayr, _паји, _הַזֶ,
  { {0x290a004b,0x963502fe,0xcc340593,0x00000000}},	// [cc70] auba_, мнац, _سريع,
  { {0x672d489c,0x786a0124,0xd5bb34e0,0x00000000}},	//   rwaj, _výva, бсе_,
  { {0x290a357c,0x7863004b,0x291861d1,0x00000000}},	//   cuba_, _lõvi, ctra_,
  { {0x6b8200c2,0xf992009a,0x00000000,0x00000000}},	//   _žogi, _ירי_,   ,
  { {0x9f59005b,0xe3b00049,0x42d40054,0x00000000}},	//   üsü_, هره_, ніщу,
  { {0xa021005b,0x20f7003b,0x3f980075,0x00000000}},	//   _çöze, tăi_, ğrul_,
  { {0x90b50001,0xe1f00049,0x787a0078,0x00000000}},	//   мљиш, اسه_, eįvy,
  { {0x4277007e,0x5ef90239,0x260b0042,0x00000000}},	//   _کارآ, охор_, ालवी_,
  { {0x290a0035,0x52151849,0x6a70004d,0x00000000}},	//   zuba_, _одат, _häfe,
  { {0x20d1008b,0xddc3000c,0x8d6549fb,0x00000000}},	//   _tái_, _conş, двое,
  { {0x90e7006a,0x27f200a4,0xfc3f61d2,0x00000000}},	//   _رسان, yayn_, rlín_,
  { {0x645b0164,0x0c7a000d,0x628361d3,0x00000000}},	//   _joui, існы_, lino,
  { {0x6f090b23,0x645b0003,0xfc3f259d,0x00000000}},	//   quec, _moui, plín_,
  { {0x7e66003d,0x290a2393,0x645b18b9,0x00000000}},	//   ūkpr, tuba_, _loui,
  { {0x291859a3,0x485a000d,0x644957c4,0x00000000}},	//   utra_, ораў_, _onei,
  { {0x7c95000d,0x8c3b004d,0x29180090,0x00000000}},	//   _прыц, toße, rtra_,
  { {0x291861d4,0x62833aec,0x98a3350e,0x00000000}},	// [cc80] stra_, kino, тите,
  { {0x8c3b00bd,0x461a000d,0x64492e28,0x00000000}},	//   roße, ўцаў_, _anei,
  { {0x645b1346,0x6f1c003b,0x290a00be,0x00000000}},	//   _boui, ărci, quba_,
  { {0x62832c17,0x645b006c,0xc6890063,0x00000000}},	//   eino, _coui, בא_,
  { {0x628316f1,0x645b006c,0x23ba0044,0x00000000}},	//   fino, _doui, آداب_,
  { {0xfe6704de,0xa294000d,0x62833b4b,0x00000000}},	//   _شد_, эалі, gino,
  { {0x645b0003,0x65c357ed,0xe5a60571,0x00000000}},	//   _foui, _абра, _циви,
  { {0xcec8001b,0x62832d09,0x2c620240,0x00000000}},	//   _hội_, aino, _kódu_,
  { {0x628361d5,0x765c1026,0x27fd0022,0x00000000}},	//   bino, _kory, ówni_,
  { {0x7cd3000c,0x8d860002,0x628361d6,0x00000000}},	//   _căro, думд, cino,
  { {0xcec80013,0x765c1780,0x20560062,0x00000000}},	//   _mội_, _mory, _отдр,
  { {0x3888005b,0xcec80013,0x00000000,0x00000000}},	//   oğru_, _lội_,   ,
  { {0xa6db007a,0x5f7301f3,0x8cca0042,0x00000000}},	//   _orða, _لاور, _संको,
  { {0x99580080,0xb061021e,0x28a70053,0x00000000}},	//   láře_, _ääre, _कीजि,
  { {0xcec8001b,0x8c3b004d,0x127b0041,0x00000000}},	//   _nội_, roßb, קאלע,
  { {0x99580080,0x6e3861d7,0x628361d8,0x00000000}},	//   náře_, _havb, zino,
  { {0x645b0003,0x7bcd008f,0x6e3800c2,0x00000000}},	// [cc90] _roui, _igau, _kavb,
  { {0xcec80013,0x25ab005e,0xfc460114,0x00000000}},	//   _bội_, ођен_, šíte_,
  { {0xcec80013,0x645b0003,0x7dd1013d,0x00000000}},	//   _cội_, _poui, _hűsé,
  { {0x05df0161,0x7aed14ce,0x43950095,0x00000000}},	//   _प्रब, _kwat, наес,
  { {0x6e380137,0xe8df008b,0x628361d9,0x00000000}},	//   _oavb, _khỏe_, tino,
  { {0x386952d3,0x6449002b,0x765c0241,0x00000000}},	//   lkar_, _wnei, _gory,
  { {0x2369027c,0x02c2000d,0x442b06d5,0x00000000}},	//   šaj_, ыйшо, _ºc_,
  { {0x386902eb,0x442b008b,0x64491ae1,0x00000000}},	//   nkar_, _úc_, _unei,
  { {0x38690026,0x7aed00ac,0x7d1a2545,0x00000000}},	//   ikar_, _nwat, etts,
  { {0x5334005e,0x7d09005e,0x91fc008f,0x00000000}},	//   _јефт, пног_, _slāv,
  { {0x38690627,0xd011014d,0x26140042,0x00000000}},	//   kkar_, _ملا_, न्टी_,
  { {0x3e690024,0x60190062,0x62810066,0x00000000}},	//   _túto_, _ходя_, _hmlo,
  { {0x7aed00f1,0x4fc40131,0xdb820054,0x00000000}},	//   _cwat, _исља, урнi_,
  { {0x427900b5,0x00000000,0x00000000,0x00000000}},	//   לאָג,   ,   ,
  { {0xae780088,0x3872002b,0x48b607b3,0x00000000}},	//   _ўсіх_, thyr_, ещат,
  { {0x786a0a63,0x63a9006d,0x38690089,0x00000000}},	//   _vývo, _oyen, gkar_,
  { {0x63a961da,0x628161db,0x765c61dc,0x00000000}},	// [cca0] _nyen, _omlo, _pory,
  { {0xba76006a,0xdb9b0063,0x386961dd,0x00000000}},	//   _ساخت, _מספר, akar_,
  { {0x787110c4,0x8a170063,0x387261de,0x00000000}},	//   _såve, _אחיו_, phyr_,
  { {0x386901e3,0x787102eb,0x63a902ab,0x00000000}},	//   ckar_, _påve, _byen,
  { {0x3e720003,0x3a3a61df,0x93430121,0x00000000}},	//   _hâte_, _kapp_, лнце,
  { {0xcec8008b,0x69c10014,0x6d4361e0,0x00000000}},	//   _tội_, ýleg, _orna,
  { {0x3a3a00c7,0x50660002,0x66c90078,0x00000000}},	//   _mapp_, етпа, _užka,
  { {0x26ca0035,0xc9530063,0x3a3a61e1,0x00000000}},	//   _hibo_, רמה_, _lapp_,
  { {0xdb1d00ea,0x6306007e,0xbe86005e,0x00000000}},	//   lcsö, _سوال, ећни,
  { {0x99580080,0x7c24004b,0xdbfb0053,0x00000000}},	//   sáře_, _abir, ्ल्ड_,
  { {0xfc3f01c2,0x83fd00ea,0x6d43007d,0x00000000}},	//   slím_, _előu, _crna,
  { {0x26ca002c,0xead50076,0x7f4236f4,0x00000000}},	//   _libo_, комь, _troq,
  { {0x386900c3,0xfbab014c,0x6d4361e2,0x00000000}},	//   vkar_, ятой_, _erna,
  { {0x6e3800d1,0x64470078,0xcf890021,0x00000000}},	//   _uavb, _ėjim, _تضمن_,
  { {0x3e72000c,0x19940062,0x7c240014,0x00000000}},	//   _câte_, гаря, _fbir,
  { {0xe8e00013,0x38690360,0x91f50013,0x00000000}},	//   _chốt_, ukar_, _nón,
  { {0x38693a92,0x7c2f00cd,0x6d43007d,0x00000000}},	// [ccb0] rkar_, mecr, _zrna,
  { {0x26ca0290,0x7c24082a,0xc7c40076,0x00000000}},	//   _cibo_, _zbir, усси,
  { {0x442400f3,0xf77f0164,0x91f50013,0x00000000}},	//   _bbm_, _reçu_, _bón,
  { {0x62810080,0x6f1b0051,0x7c2f1bb0,0x00000000}},	//   _smlo, ytuc, necr,
  { {0x7c3d2943,0x27e961e3,0x442461e4,0x00000000}},	//   idsr, mban_, _dbm_,
  { {0x8218005a,0x63a90035,0x7cc90051,0x00000000}},	//   ецът_, _vyen, _ośro,
  { {0x27e900a4,0xc095005e,0x409561e5,0x00000000}},	//   oban_, кшић, крит,
  { {0x27e9000f,0x3eac006f,0xdb080058,0x00000000}},	//   nban_, eldt_, _ölçm,
  { {0x7cc2001c,0x442f0e66,0x93970021,0x00000000}},	//   _tērz, meg_, _أجزا,
  { {0x83fd000f,0x442f61e6,0x78ad0114,0x00000000}},	//   _előt, leg_, hlav,
  { {0x27e9000f,0x442f0438,0x26190053,0x00000000}},	//   kban_, oeg_, _पानी_,
  { {0x442f0322,0x20030078,0x3eac05a5,0x00000000}},	//   neg_, ėjis_, aldt_,
  { {0x207a00b5,0x27e900ea,0x78ad00b9,0x00000000}},	//   _קאנא, dban_, dlav,
  { {0x442f61e7,0x24860051,0x3e720003,0x00000000}},	//   heg_, ziom_, _pâte_,
  { {0xc212014e,0x6d4300f8,0x6f09030c,0x00000000}},	//   יהם_, _urna, lrec,
  { {0x442f0117,0x29040024,0x27e900ea,0x00000000}},	//   jeg_, čma_, gban_,
  { {0x6d4100e8,0x442f61e8,0xbc1b0063,0x00000000}},	// [ccc0] lvla, deg_, _חופש,
  { {0x78ad099a,0x6d41007d,0x27e961e9,0x00000000}},	//   alav, ovla, aban_,
  { {0x27e9000f,0x6f0900bd,0xe8e00013,0x00000000}},	//   bban_, hrec, _thốt_,
  { {0x254100eb,0x69dc61ea,0xcec80013,0x00000000}},	//   _dėl_, lcre, _hột_,
  { {0x3eac000e,0xb2d30021,0x248616bb,0x00000000}},	//   yldt_, لينغ, riom_,
  { {0x442f0019,0x443d001f,0x5b7b0047,0x00000000}},	//   aeg_, adw_, ורנא,
  { {0xcec800aa,0x764e00c7,0xeb9f06a5,0x00000000}},	//   _một_, _inby, ngør_,
  { {0x656303c8,0x75370047,0xf9930063,0x00000000}},	//   änhe, _באלד_, ירו_,
  { {0x60cb002c,0x83fd00ea,0x9f5f004d,0x00000000}},	//   _digm, _elős, rauß_,
  { {0xa80601f7,0x6d4100ac,0x290a085a,0x00000000}},	//   ldığ, fvla, krba_,
  { {0x6f090529,0x78a400fe,0x2d980058,0x00000000}},	//   arec, koiv, çre_,
  { {0xa80601f7,0x6f095a92,0x7053007e,0x00000000}},	//   ndığ, brec, _پنها,
  { {0x9b58005a,0x290a0089,0xcec80013,0x00000000}},	//   вият_, erba_, _bột_,
  { {0xcec8008b,0x61f861eb,0x6d4100c2,0x00000000}},	//   _cột_, navl, bvla,
  { {0x27e9000f,0xeb9f0146,0x443d002b,0x00000000}},	//   tban_, ggør_, ydw_,
  { {0x27e94cfa,0x69dc1098,0x7c870816,0x00000000}},	//   uban_, acre, _шуле,
  { {0xcaa70032,0xf1a90053,0x20d80025,0x00000000}},	// [ccd0] _لصدي, _चुनन, _léi_,
  { {0xe4e70086,0x61f8065f,0x27e900ea,0x00000000}},	//   відн, javl, sban_,
  { {0x27e900ea,0x76410014,0xfc3f004c,0x00000000}},	//   pban_, _ólym, odí_,
  { {0x254100eb,0xfc3f61ec,0x3eb90078,0x00000000}},	//   _vėl_, ndí_, įsti_,
  { {0x442f1ed4,0xd5bf001c,0xe73d0080,0x00000000}},	//   reg_, _šādi_, _kříž,
  { {0x442f61ed,0x026b0121,0x7afd1dd3,0x00000000}},	//   seg_, ьшей_, isst,
  { {0x2911005b,0x68e20051,0x6d5c004b,0x00000000}},	//   nuza_, _łodz, äral,
  { {0x7f59000a,0x83fd00ea,0x7afd011d,0x00000000}},	//   ејот_, _előr, ksst,
  { {0x61f8074f,0x2f54000d,0xb4bf0053,0x00000000}},	//   bavl, атэс, ँगी_,
  { {0x29110035,0xa806005b,0x7afd17d5,0x00000000}},	//   kuza_, mdış, dsst,
  { {0xcc8a0001,0x6f0905df,0x9c7d011b,0x00000000}},	//   ебне_, srec, rpčn,
  { {0x291161ee,0x6f090359,0x67030053,0x00000000}},	//   duza_, prec, _लिंक_,
  { {0x7cd30529,0xdce80080,0x6d4161ef,0x00000000}},	//   _mări, ozdě, svla,
  { {0x2911000c,0x6d4100f5,0xa806005b,0x00000000}},	//   fuza_, pvla, zdığ,
  { {0x78a40072,0x69dc61f0,0x6fe2004c,0x00000000}},	//   toiv, rcre, síců,
  { {0x69dc30a8,0x7afd01e1,0x2ba50042,0x00000000}},	//   scre, bsst, _गुवा,
  { {0x3ea50019,0x2911003b,0x3e720003,0x00000000}},	// [cce0] oolt_, auza_, _hâta_,
  { {0x66c900eb,0x7ae400a4,0x78a40072,0x00000000}},	//   _užkl, _itit, soiv,
  { {0xf2a7000d,0x04464f9b,0xd46a0074,0x00000000}},	//   _якiх_, лежн, ниже_,
  { {0xb8f80053,0x33f60021,0x3ea561f1,0x00000000}},	//   ाद_, اساس, holt_,
  { {0x61f806bb,0xa806005b,0x3ea5013d,0x00000000}},	//   tavl, rdığ, kolt_,
  { {0xd13a042c,0x68e20022,0xfc3f01d1,0x00000000}},	//   ехи_, _łody, zdí_,
  { {0x61f806bb,0x3ea5013d,0x26190042,0x00000000}},	//   ravl, dolt_, _पाती_,
  { {0x6d5c0019,0x7afd0618,0x61f8007d,0x00000000}},	//   äram, ysst, savl,
  { {0x883b0063,0x9961008f,0x5f940590,0x00000000}},	//   תתפו, cīņa_, рипт,
  { {0x073701f9,0xd7370063,0x7afd02e0,0x00000000}},	//   נאים_, נטית_, vsst,
  { {0x7ae400eb,0xa1960259,0x6c55469c,0x00000000}},	//   _atit, _сјај, акну,
  { {0xfc3f0061,0x628a61f2,0x7afd4ed8,0x00000000}},	//   udí_, lifo, tsst,
  { {0x7afd1a14,0x2f180499,0x7ae42edb,0x00000000}},	//   usst, _роль_, _ctit,
  { {0x7f3b0047,0x7ae40139,0x7ae00014,0x00000000}},	//   _רעגו, _dtit, ímta,
  { {0xd5eb008b,0x7afd004d,0xa9350054,0x00000000}},	//   _đìn, ssst, шевш,
  { {0x7afd61f3,0x291161f4,0x91bb009a,0x00000000}},	//   psst, ruza_, תמלי,
  { {0x7c94007e,0xcb350062,0xf402003b,0x00000000}},	// [ccf0] _دشوا, _тепъ, iaţă_,
  { {0x2b49001f,0x7cd3003b,0x07080044,0x00000000}},	//   _irac_, _sări, ايلي_,
  { {0xfbdf03d9,0x7cd3000c,0xceb311b4,0x00000000}},	//   ocê_, _pări, ציע_,
  { {0xd37101a7,0xb4bf0053,0xfbdf017d,0x00000000}},	//   يها_, ँगे_, ncê_,
  { {0x6d5c0659,0xd7fa009a,0x93240044,0x00000000}},	//   äraj, _שהשל, مرون,
  { {0x15ab0062,0x45d408a7,0xa8060058,0x00000000}},	//   _зъби_, _горс, rdış,
  { {0x7cd3000c,0xc6920063,0xf402000c,0x00000000}},	//   _tări, _ואם_, faţă_,
  { {0x20190019,0x5f290363,0xaf053f5d,0x00000000}},	//   üsi_, воим_, апил,
  { {0x7eaf0031,0x7f750088,0x443f61f5,0x00000000}},	//   løpi, руйц, _iau_,
  { {0x628a61f6,0x786a0124,0x92b70044,0x00000000}},	//   cifo, _vývi, _إحرا,
  { {0xb0350076,0x3ea500ea,0x443f017e,0x00000000}},	//   _внеш, rolt_, _kau_,
  { {0xcb6a0431,0x3ea500ea,0x443f20b4,0x00000000}},	//   ваме_, solt_, _jau_,
  { {0x443f61f7,0x7aa60021,0xce950062,0x00000000}},	//   _mau_, لإسل, _кадъ,
  { {0x2b4961f8,0x19960699,0x443f61f9,0x00000000}},	//   _drac_, ајбр, _lau_,
  { {0xa7fb006d,0x2eff0150,0x19870caa,0x00000000}},	//   _soña, lsuf_, абри_,
  { {0xcec8001b,0x1b4a0076,0x614000ea,0x00000000}},	//   _hộp_, _азии_, lálá,
  { {0x787803d9,0x7e6361fa,0xa686000d,0x00000000}},	// [cd00] _níve, _konp, алад,
  { {0x63a60031,0x6140000f,0x7c2608fa,0x00000000}},	//   _økni, nálá, lfkr,
  { {0x78710137,0x75560259,0xc0be0013,0x00000000}},	//   _gåvo, шњац, gýời_,
  { {0x656300fe,0x443f4c50,0x499b00ff,0x00000000}},	//   änha, _cau_, _ישיב,
  { {0x443f61fb,0xf402003b,0x628a61fc,0x00000000}},	//   _dau_, vaţă_, tifo,
  { {0x443f0164,0xcec8008b,0x7e6361fd,0x00000000}},	//   _eau_, _nộp_, _nonp,
  { {0x52750001,0xe6110063,0x628a61fe,0x00000000}},	//   ључу, _מִן_, rifo,
  { {0x2054005a,0x443f001f,0xd0100021,0x00000000}},	//   ския, _gau_, ألة_,
  { {0xcee70001,0xd46706da,0x7cd3003b,0x00000000}},	//   адње_, _тите_, _măru,
  { {0x442622bf,0x614000ea,0x644026c5,0x00000000}},	//   lfo_, gálá, _hami,
  { {0x644061ff,0xdd39003b,0x64420072,0x00000000}},	//   _kami, răşe, odoi,
  { {0x4fa6218a,0x44266200,0x6440320a,0x00000000}},	//   _киев, nfo_, _jami,
  { {0x644034a1,0xdd39000c,0xfbdf017d,0x00000000}},	//   _mami, păşe, rcê_,
  { {0x644200fe,0x64406201,0x28db0053,0x00000000}},	//   hdoi, _lami, _मंदि,
  { {0x88870002,0xdebb009a,0x3ebb009d,0x00000000}},	//   аѓал, _שמול, _שצוב,
  { {0x7cd3000c,0x6440026a,0x6d4a1cc0,0x00000000}},	//   _căru, _nami, _irfa,
  { {0x7cd3003b,0x799e6202,0xc6a70054,0x00000000}},	// [cd10] _dăru, _expw, аржи,
  { {0x443f6203,0xe61303eb,0x64420072,0x00000000}},	//   _sau_, تشر_, edoi,
  { {0xf8b1006a,0x443f6204,0x4426514b,0x00000000}},	//   _فکر_, _pau_, ffo_,
  { {0x6140000f,0x29360047,0x644033c5,0x00000000}},	//   zálá, _פארן_, _cami,
  { {0x64406205,0x443f0268,0xa6db0026,0x00000000}},	//   _dami, _vau_, _orði,
  { {0x6d4a6206,0x787805d5,0xdcfe004c,0x00000000}},	//   _orfa, _víve, ávěn,
  { {0x6140000f,0x200b017d,0x7c2600ac,0x00000000}},	//   válá, ócio_, yfkr,
  { {0x64405e0f,0x26d14fbe,0x7cd3000c,0x00000000}},	//   _gami, _hizo_, _mărt,
  { {0x33750001,0x6d4a001f,0x2eff2207,0x00000000}},	//   _угар, _arfa, usuf_,
  { {0x6f020024,0x26d904ad,0xf1a70095,0x00000000}},	//   _dvoc, _muso_, _крен,
  { {0x614000ea,0x63be0051,0x64404396,0x00000000}},	//   rálá, ępne, _yami,
  { {0x672f0045,0xfc320021,0xf8bf008b,0x00000000}},	//   _opcj, أحد_, _nhé_,
  { {0x9f400026,0x2d8b0051,0x6288002b,0x00000000}},	//   _þið_, ńce_, _ymdo,
  { {0x63bb0035,0x7cd3003b,0x7e7a0d13,0x00000000}},	//   _mzun, _săru, chtp,
  { {0x6a6b005b,0x0dc80001,0x7cd3003b,0x00000000}},	//   _nüfu, _кући_, _păru,
  { {0xf8bf0290,0xbc9302d8,0x945d0022,0x00000000}},	//   _ché_, _најј, _mińs,
  { {0x44f5034d,0x7cd300dd,0x27e06207,0x00000000}},	// [cd20] eť_, _văru, rcin_,
  { {0x77c722a6,0x05ba01fb,0x644056d7,0x00000000}},	//   слуг_, هدات_, _sami,
  { {0xd6cf0021,0x58d30002,0x26190053,0x00000000}},	//   رقم_, _ноќт, _पारी_,
  { {0x26d96208,0xf8bf008b,0xdbd7004d,0x00000000}},	//   _fuso_, _ghé_, _mäßi,
  { {0x8c1b014e,0x44f50024,0x44263482,0x00000000}},	//   רוני, ať_, rfo_,
  { {0x66e3011c,0x3860007a,0x8b060051,0x00000000}},	//   _хора, ljir_, częś,
  { {0x7af6001f,0x2ee65fe5,0x64406209,0x00000000}},	//   _lwyt, _stof_, _tami,
  { {0x3860053b,0x6a6b004d,0x049600f2,0x00000000}},	//   njir_, _hüft, _الرح,
  { {0x6d46001c,0x9f5302dc,0x6724620a,0x00000000}},	//   ākam, звыч, ntij,
  { {0x62650021,0xa3e40053,0x867b0047,0x00000000}},	//   _والق, पुर_, ָרטו,
  { {0x672410ff,0xec350054,0x6a6b0075,0x00000000}},	//   htij, оннь, _müft,
  { {0x67240748,0x7af6001f,0xac1902a1,0x00000000}},	//   ktij, _bwyt, шому_,
  { {0x6298620b,0x0b8b0899,0xdfcf0044,0x00000000}},	//   onvo, усни_, _كيم_,
  { {0x44f50024,0xb69b000c,0x7d0b00b9,0x00000000}},	//   yť_, _avân, ålsæ,
  { {0xdd930088,0x66c90078,0x61fa43c6,0x00000000}},	//   _нашы, _užki, _metl,
  { {0x67240122,0x998500ea,0x26d90696,0x00000000}},	//   ftij, ülő_, _puso_,
  { {0x6724006f,0x6d480829,0x7c2d1760,0x00000000}},	// [cd30] gtij, lvda, _ibar,
  { {0xb5950062,0x32f60051,0x60da0524,0x00000000}},	//   оизш, dły_, _outm,
  { {0xf8bf0003,0x38740331,0x63bb1556,0x00000000}},	//   _thé_, ñará_, _szun,
  { {0x7eaf00d1,0x20c10139,0x6298620c,0x00000000}},	//   løpt, móig_, envo,
  { {0x44f50024,0x32f60051,0x24180086,0x00000000}},	//   sť_, gły_, сією_,
  { {0x6d46001c,0xf990007e,0x95cb06da,0x00000000}},	//   ākaj, _آبی_, _буба_,
  { {0x32f60051,0x7c2d1ab3,0x29030022,0x00000000}},	//   ały_, _obar, nsja_,
  { {0x7c2d04aa,0x629800ca,0x4f0905ce,0x00000000}},	//   _nbar, anvo, анин_,
  { {0x63bb005b,0xc0c80001,0x442d00ac,0x00000000}},	//   _uzun, љује_, _ibe_,
  { {0xf78a0047,0xd109007e,0x29030e2c,0x00000000}},	//   ינפֿ, _نقطه_, ksja_,
  { {0x3f740013,0x60da392c,0xbc6a0044,0x00000000}},	//   àu_, _gutm, لمدن_,
  { {0x290300d1,0xe0ce071f,0x6f0e0058,0x00000000}},	//   dsja_, _ів_, üncü,
  { {0x543a0047,0x3b8301dd,0x643a0047,0x00000000}},	//   בערא, дляг, בערנ,
  { {0x3e7b0003,0x7c2d004b,0x6a70004d,0x00000000}},	//   _bête_, _ebar, _käfi,
  { {0x7cd3003b,0x442d0648,0x38600014,0x00000000}},	//   _vărs, _obe_, tjir_,
  { {0x32f60051,0xf7720021,0x6724620d,0x00000000}},	//   yły_, واء_, ttij,
  { {0xa6db0026,0x38600026,0xd5b8001c,0x00000000}},	// [cd40] _orðu, rjir_, _šā_,
  { {0x3e7b548a,0x20c10025,0x67242409,0x00000000}},	//   _fête_, lóid_, rtij,
  { {0x7eaf0031,0x2a570063,0xc68f0021,0x00000000}},	//   løps, _ובין_, خِل_,
  { {0x6724006f,0x61fa620e,0xd4990054,0x00000000}},	//   ptij, _setl, брі_,
  { {0x386f0137,0x83360593,0x61fa620f,0x00000000}},	//   ögre_, تراض, _petl,
  { {0x32f60022,0xa6e20014,0x442d47c3,0x00000000}},	//   rły_, áðun, _ebe_,
  { {0x29186210,0x32f60051,0x61fa090d,0x00000000}},	//   nura_, sły_, _vetl,
  { {0x3a38006f,0xc0ca0002,0x61fa6211,0x00000000}},	//   herp_, шуле_, _wetl,
  { {0x3a3800ac,0x7eaf00d1,0x9626001c,0x00000000}},	//   kerp_, jøps, paņā,
  { {0xcdda0001,0x35af0053,0x60da005b,0x00000000}},	//   шњи_, _जुड़, _tutm,
  { {0xc05a0086,0x3fe60062,0x705600de,0x00000000}},	//   _віл_, _джев, _ونطا,
  { {0x291822bf,0x2c62027d,0x00000000,0x00000000}},	//   dura_, _kódy_,   ,
  { {0x8ae40086,0x6e46046e,0xa2bf0042,0x00000000}},	//   дісл, _медз, _लीड्,
  { {0x29180089,0x29110022,0x290321ef,0x00000000}},	//   fura_, trza_, tsja_,
  { {0x78b6000e,0x29051123,0x29186212,0x00000000}},	//   flyv, éla_, gura_,
  { {0x29030045,0xa6db0014,0x7c2d0022,0x00000000}},	//   rsja_, _orðt, _ubar,
  { {0xc7cb05ac,0xbca40044,0x2bc70042,0x00000000}},	// [cd50] рыве_, _تميي, रेशा,
  { {0x3e7b03b2,0x2918002c,0x78b60006,0x00000000}},	//   _tête_, bura_, alyv,
  { {0x29183b58,0x74a70002,0xe4a76213,0x00000000}},	//   cura_, ојде, ордо,
  { {0xe7870001,0x787800ea,0xf992009a,0x00000000}},	//   _дуго, _hívn, _טרי_,
  { {0xa85a0063,0x91e528dd,0x185a009a,0x00000000}},	//   _הדרכ, поле, _הכרע,
  { {0x442d00a4,0x42d40054,0x72880054,0x00000000}},	//   _wbe_, міщу, обіг_,
  { {0xd24e0044,0x8234005d,0xe4e71cdf,0x00000000}},	//   طني_, ظرها, _фігн,
  { {0x60c2299e,0xa99c0063,0x442d6214,0x00000000}},	//   _chom, יבור, _ube_,
  { {0x29186215,0x60c20139,0x57b90042,0x00000000}},	//   zura_, _dhom, _आरोह,
  { {0x291800e3,0x78ad0072,0xc3320041,0x00000000}},	//   yura_, hoav, _אומ_,
  { {0x3eb9003d,0x3e72001f,0x8c466216,0x00000000}},	//   ēst_, _mâth_, пене,
  { {0x2245005b,0x3a380229,0x2918068b,0x00000000}},	//   _halk_, werp_, vura_,
  { {0xf092014e,0xeb97042c,0x20c10139,0x00000000}},	//   _אנא_, зия_, róid_,
  { {0x60c9005b,0x29186217,0xef190022,0x00000000}},	//   lmem, tura_, muż_,
  { {0x6d5c0004,0x60c900c2,0x0dcb0086,0x00000000}},	//   ärat, omem, _туди_,
  { {0x83fd000f,0x38590be6,0x60c92e99,0x00000000}},	//   _előz, орую_, nmem,
  { {0x27f20185,0x6016005b,0x8c1b0063,0x00000000}},	// [cd60] rbyn_, lümü, _הופי,
  { {0x2918180a,0xa6db0026,0xd7070085,0x00000000}},	//   pura_, _arðs, януе_,
  { {0x78b60024,0x6016005b,0x60c91f4a,0x00000000}},	//   plyv, nümü, kmem,
  { {0x7eb400cd,0x60c922ed,0xe8e00013,0x00000000}},	//   ràpi, jmem, _nhứt_,
  { {0x22450162,0x4420001c,0x60c26218,0x00000000}},	//   _balk_, ļi_, _rhom,
  { {0x60c9113c,0x912a0021,0x63b60022,0x00000000}},	//   emem, مسبق_, żyno,
  { {0x2245021f,0x787147c9,0x21670001,0x00000000}},	//   _dalk_, _såvi, зији_,
  { {0x787102ab,0x859b0063,0x60c913b0,0x00000000}},	//   _påvi, _השלו, gmem,
  { {0x71fa005d,0x64a36219,0x00000000,0x00000000}},	//   _هراس_, _чата,   ,
  { {0x78ad00be,0x60c200e5,0x4d980054,0x00000000}},	//   zoav, _whom, жкою_,
  { {0x70f60032,0x60c2050b,0x2726008d,0x00000000}},	//   _رسائ, _thom, hôn_,
  { {0xf3f9000c,0x201900cd,0xab950054,0x00000000}},	//   _poţi_, òsit_, димі,
  { {0x7680005b,0x7d0200ea,0x4ae7000d,0x00000000}},	//   _köyd, _bírá, яўна,
  { {0x6d5c0019,0x60160058,0x9961008f,0x00000000}},	//   äras, bümü, rīža_,
  { {0x39a40699,0x6d5c00a5,0x78ad621a,0x00000000}},	//   ештв, årad, toav,
  { {0x7680024a,0xf3f9000c,0x6e3a00ea,0x00000000}},	//   _löyd, _toţi_, letb,
  { {0x2726008b,0x9773000d,0x6e3a006f,0x00000000}},	// [cd70] gôn_, лiся_, oetb,
  { {0xfbd00032,0xf77001a7,0x248d00c2,0x00000000}},	//   _حتى_, داف_, _smem_,
  { {0x7d1a621b,0x9475007e,0xceb8005f,0x00000000}},	//   nuts, وگرا, ilę_,
  { {0xb9010161,0xe3b0007e,0x320c0168,0x00000000}},	//   दद_, گرم_, _addy_,
  { {0xceb80006,0x22450019,0x60160058,0x00000000}},	//   klę_, _palk_, zümü,
  { {0x6016005b,0x7d1a621c,0xe3b0005d,0x00000000}},	//   yümü, kuts, درم_,
  { {0xa1560001,0x1a9c0047,0x6142047e,0x00000000}},	//   дају_, זיגע, веща,
  { {0x44390994,0x7d1a004b,0x6a70092e,0x00000000}},	//   _ús_, duts, _häft,
  { {0xe4c40076,0x7d1a621d,0x27fd0051,0x00000000}},	//   _чёрн, euts, ówny_,
  { {0x3e89019d,0x3e7b548a,0x9db9000d,0x00000000}},	//   ійно_, _bêta_, жыму_,
  { {0x7d1a0004,0xa2aa0161,0xe135000d,0x00000000}},	//   guts, टवर्, _інды,
  { {0xa0c40021,0x6016005b,0xa134005d,0x00000000}},	//   _كيلو, rümü, _سرمش,
  { {0x6d5c0db3,0x3af6046f,0x9f4f1c83,0x00000000}},	//   ärar, ьянс, _begå_,
  { {0x201f0268,0xaec40086,0x7d1a621e,0x00000000}},	//   lgui_, _збіл, buts,
  { {0x2d94005a,0x7aed621f,0x9e320131,0x00000000}},	//   _пръс, _etat, _рејч,
  { {0x201f4953,0x6d436220,0x7878013d,0x00000000}},	//   ngui_, _isna, _vívo,
  { {0x2d856221,0x27260013,0x78a10331,0x00000000}},	// [cd80] lzle_, uôn_, élva,
  { {0x78a90198,0x4eca0047,0xff47005d,0x00000000}},	//   čeva, ַזײַ, _یخ_,
  { {0x2905000f,0x186a05c5,0xd48f06da,0x00000000}},	//   álat_, _дани_, вр_,
  { {0x60dc006d,0xf487007e,0x6e3a00ea,0x00000000}},	//   _érmi, وانی, zetb,
  { {0x6d4300ac,0x93570002,0x63be0051,0x00000000}},	//   _lsna, дрју_, ępno,
  { {0x6d436222,0xdb25013d,0x463a0044,0x00000000}},	//   _osna, ését, _بأحد_,
  { {0x28c30053,0x12a90021,0x6147013d,0x00000000}},	//   _वीडि, أدنى_, vélá,
  { {0x66c90006,0xcf9a0002,0x68e10014,0x00000000}},	//   _užkr, жјо_, íldi,
  { {0x4226005e,0xa0670002,0x3f84007d,0x00000000}},	//   _одав, ќања_, uzmu_,
  { {0x7d1a0019,0x4424008b,0x7c2419c0,0x00000000}},	//   tuts, _hcm_, _acir,
  { {0xb80e0161,0x7d1a0159,0x7aed6223,0x00000000}},	//   िणाम_, uuts, _stat,
  { {0xdefa000d,0x7d1a0a2e,0x6e3a00ea,0x00000000}},	//   _дык_, ruts, setb,
  { {0x7d1a6224,0x6d43005b,0x20042671,0x00000000}},	//   suts, _esna, mami_,
  { {0x200456d1,0x7d1a4a05,0x9f33012c,0x00000000}},	//   lami_, puts, _реші,
  { {0x99830078,0x5d830021,0xdcf70044,0x00000000}},	//   vejų_, _للول, _قريش_,
  { {0xd5f4001b,0x030e0053,0x67d5005e,0x00000000}},	//   _đán, _सिंह_, еобу,
  { {0x7aed0035,0x26d81acc,0xfe780078,0x00000000}},	// [cd90] _utat, _biro_, okį_,
  { {0x2004003e,0xfe780006,0x29050139,0x00000000}},	//   hami_, nkį_, álas_,
  { {0xd370007e,0xe4e40636,0x69c10058,0x00000000}},	//   یهٔ_, вічн, üled,
  { {0x7c3d6225,0x26d8008f,0x20046226,0x00000000}},	//   nesr, _eiro_, jami_,
  { {0x20046227,0x2d856228,0xceb9004c,0x00000000}},	//   dami_, zzle_, stři_,
  { {0x26d81ef2,0x63850003,0x442426ae,0x00000000}},	//   _giro_, _aîné, _ecm_,
  { {0x6605053b,0xf2040086,0x7c3d5668,0x00000000}},	//   mahk, тячо, kesr,
  { {0x6605014f,0x409408a6,0x60090193,0x00000000}},	//   lahk, крыт, чним_,
  { {0x64a4000a,0xd426005b,0x7c3d41bf,0x00000000}},	//   _раѓа, ıştı_, desr,
  { {0x7c240d2e,0x66056229,0x8d650121,0x00000000}},	//   _scir, nahk, евое,
  { {0x506703d6,0x21580044,0x2fd9005d,0x00000000}},	//   _отда, _يجمع_, _فواد_,
  { {0x20c1017d,0x20045e4f,0x7ebd01a8,0x00000000}},	//   bóia_, cami_, pèpo,
  { {0x6605017e,0x9983013d,0x2cbe008f,0x00000000}},	//   kahk, dejű_, ētd_,
  { {0xddc30529,0x66050089,0x60d9002b,0x00000000}},	//   _conţ, jahk, _hiwm,
  { {0x19b9019d,0x66050397,0x6d43622a,0x00000000}},	//   дуть_, dahk, _usna,
  { {0x46ea0cb5,0x26d8622b,0xdb0f00ea,0x00000000}},	//   здан_, _siro_, őjár,
  { {0x29050026,0xfd65008b,0x6f093f90,0x00000000}},	// [cda0] álar_, _nhuậ, nsec,
  { {0x98c0005b,0x2004622c,0x00000000,0x00000000}},	//   ırır_, zami_,   ,
  { {0xc5d5000d,0x26d80072,0x6d41002b,0x00000000}},	//   віць, _viro_, nwla,
  { {0x73e60088,0x26d8002b,0x60d9002b,0x00000000}},	//   ходз, _wiro_, _niwm,
  { {0xfe780006,0x44240089,0x26d80dd1,0x00000000}},	//   ykį_, _vcm_, _tiro_,
  { {0x6234000a,0x20040051,0xfe67007e,0x00000000}},	//   теку, wami_, _صد_,
  { {0x645b00ac,0x6f09622d,0x25be013d,0x00000000}},	//   _fnui, esec, _átl_,
  { {0x64490027,0xbf34005a,0xf9930063,0x00000000}},	//   _gaei, внищ, טרו_,
  { {0x03a315d3,0x2004622e,0x8fa3005e,0x00000000}},	//   _бито, rami_, лаће,
  { {0x27e902dd,0x2004622f,0x62836230,0x00000000}},	//   zcan_, sami_, chno,
  { {0x6d41001f,0xfe780078,0x867b0063,0x00000000}},	//   gwla, rkį_, פרטו,
  { {0xdee60905,0x7878004c,0x4c950121,0x00000000}},	//   _зоди, _dívk, тимс,
  { {0x9f490ac6,0x7c3d6231,0x29186232,0x00000000}},	//   _það_, resr, erra_,
  { {0x787800ea,0x443d0051,0x7eb401a8,0x00000000}},	//   _hívh, zew_, ràps,
  { {0x38c70905,0x7c3d013d,0x98c70893,0x00000000}},	//   ещав, pesr, есал,
  { {0x5dbb0063,0x78a9007d,0xed57009d,0x00000000}},	//   _מזוה, čevo, _טבור_,
  { {0x2918170c,0x27e96233,0x66050360,0x00000000}},	// [cdb0] arra_, rcan_, tahk,
  { {0x645b006f,0xdb9c0063,0x27e96234,0x00000000}},	//   _snui, _מסחר, scan_,
  { {0xddc30024,0x6605053b,0xd006007e,0x00000000}},	//   _konš, rahk, _پل_,
  { {0x6605053b,0x644b0203,0x84640062,0x00000000}},	//   sahk, udgi, лъче,
  { {0x62830185,0x387e0164,0x443d06d3,0x00000000}},	//   thno, être_, rew_,
  { {0x672d001c,0x20c10139,0x3e720003,0x00000000}},	//   mtaj, góin_, _mâts_,
  { {0x6283004c,0x672d6235,0x00000000,0x00000000}},	//   rhno, ltaj,   ,
  { {0xfd65001b,0x645b003b,0x38696236,0x00000000}},	//   _thuậ, _unui, njar_,
  { {0x672d6237,0xfc3f0061,0x290a013d,0x00000000}},	//   ntaj, deí_, zsba_,
  { {0x63bb00a4,0x672d6238,0x6f096239,0x00000000}},	//   _iyun, itaj, rsec,
  { {0x63bb623a,0x3207623b,0x672d037e,0x00000000}},	//   _hyun, many_, htaj,
  { {0x32070051,0x672d001c,0x1ae6015a,0x00000000}},	//   lany_, ktaj, комм,
  { {0xc4d200b5,0x6d4e00a5,0x9998004c,0x00000000}},	//   יגט_, åbar, terů_,
  { {0x38690118,0x32070051,0x63bb3347,0x00000000}},	//   ejar_, nany_, _myun,
  { {0x290c447d,0x9d45623c,0x99150054,0x00000000}},	//   éda_, _рейд, льті,
  { {0x63bb005b,0x63b60051,0x63a9623d,0x00000000}},	//   _oyun, żyni, _oxen,
  { {0xb607001b,0xb8e90053,0x37e3005e,0x00000000}},	// [cdc0] _thờ, _ली_, роуг,
  { {0x386900e3,0xe8e00013,0x69c10058,0x00000000}},	//   ajar_, _chợt_, ülec,
  { {0x63bb623e,0x32070051,0x7ae44841,0x00000000}},	//   _ayun, dany_, _huit,
  { {0x74130032,0x7ae4623f,0x62811130,0x00000000}},	//   لوما, _kuit, _allo,
  { {0x32074268,0xfe210082,0x00000000,0x00000000}},	//   fany_, _मांस_,   ,
  { {0x7ae46240,0xc7b3014e,0x32076241,0x00000000}},	//   _muit, _כבר_, gany_,
  { {0x4a9b00b5,0x63a9006d,0x7ae41986,0x00000000}},	//   ויסג, _exen, _luit,
  { {0x6281048e,0x44220031,0xd0100021,0x00000000}},	//   _ello, _øk_, حلة_,
  { {0xa2e6019d,0xc2465b6d,0x7ae40003,0x00000000}},	//   _розд, _инак, _nuit,
  { {0x78780016,0xb06100fe,0x7cd4003b,0x00000000}},	//   _dívi, _ääne, _gărz,
  { {0x7e7a10ce,0x38690026,0x62986242,0x00000000}},	//   rktp, yjar_, mivo,
  { {0x7ae46243,0x2bcb005e,0x4f660021,0x00000000}},	//   _buit, дуго_, _لاتف,
  { {0xce34007e,0x62980072,0x7ae427c2,0x00000000}},	//   _موشک, oivo, _cuit,
  { {0x7ae46244,0x62986245,0x20c10139,0x00000000}},	//   _duit, nivo, hóil_,
  { {0xfce30138,0x38690268,0xd7e70454,0x00000000}},	//   _којо, tjar_, візо,
  { {0x672d024a,0x7ae40003,0x32070051,0x00000000}},	//   ttaj, _fuit, zany_,
  { {0x386937f7,0x7ae418b4,0x80da0053,0x00000000}},	// [cdd0] rjar_, _guit, _पूछे,
  { {0x629801b3,0x24860066,0x7d1a0f8c,0x00000000}},	//   jivo, ehom_, orts,
  { {0x84670062,0x62986246,0xdc43004c,0x00000000}},	//   къде, divo, _léčb,
  { {0x32070045,0xa8790047,0x672d6247,0x00000000}},	//   wany_, _נאָר, ptaj,
  { {0x7d1a004d,0x8625007e,0x87040085,0x00000000}},	//   hrts, _مکال, _вясе,
  { {0xb2240054,0x62986248,0x768b056c,0x00000000}},	//   иміл, givo, rżys,
  { {0x9998000c,0x32076249,0x3a38009a,0x00000000}},	//   merţ_, rany_, דרום_,
  { {0x32070051,0xddda008f,0x248626c3,0x00000000}},	//   sany_, aktū, chom_,
  { {0x7d1a2442,0x6298624a,0x63bb0075,0x00000000}},	//   erts, bivo, _uyun,
  { {0x7ae426ad,0x225b0044,0x645e008f,0x00000000}},	//   _ruit, _تجرب_, ēpie,
  { {0x78a900c2,0x7ae4624b,0x51841849,0x00000000}},	//   čevj, _suit, _куца,
  { {0x8cb50054,0x7ae4624c,0xb1990046,0x00000000}},	//   исяч, _puit, öðuá,
  { {0xbf670021,0x7d1a28b6,0x7ae41e3e,0x00000000}},	//   _جداو, arts, _quit,
  { {0xbf9a00b5,0x7ae400cd,0x8f9a0149,0x00000000}},	//   _אינש, _vuit, _איני,
  { {0x63be0045,0x6e3400ea,0xb60601c8,0x00000000}},	//   ępni, égbő, ntáž,
  { {0x6298027c,0x38cb007e,0x7ae4059f,0x00000000}},	//   zivo, فاقی_, _tuit,
  { {0x9b4608aa,0x47c604f2,0x00000000,0x00000000}},	// [cde0] _صندو, убав,   ,
  { {0x4a460cb5,0x7c26000e,0xb6060124,0x00000000}},	//   _снов, lgkr, ktáž,
  { {0x2956005a,0x248629f6,0xd6cf0021,0x00000000}},	//   _съпр, thom_, أقل_,
  { {0x7c261833,0xb3860121,0xa2e6000d,0x00000000}},	//   ngkr, ллел, годд,
  { {0x6298624d,0xd308008d,0x78a4624e,0x00000000}},	//   tivo, uệ_, mniv,
  { {0x6f1b00bd,0xf7730063,0x78a43c7c,0x00000000}},	//   druc, _הקש_, lniv,
  { {0x6298624f,0x78a4004b,0x64a61e1b,0x00000000}},	//   rivo, oniv, _бава,
  { {0x62986250,0x78a45557,0x0edf0042,0x00000000}},	//   sivo, nniv, नदंड,
  { {0x764e1b4d,0x64420139,0x7e2a0500,0x00000000}},	//   _kaby, meoi, ніна_,
  { {0x320500ac,0x44266251,0x99980078,0x00000000}},	//   _gely_, lgo_, ndrų_,
  { {0x5275000a,0x2d810019,0x44266252,0x00000000}},	//   _туту, _ühel_, ogo_,
  { {0x44266253,0x64420025,0x6f1b6254,0x00000000}},	//   ngo_, neoi, bruc,
  { {0x6f1b1409,0x68e500fe,0x44260331,0x00000000}},	//   cruc, _suhd, igo_,
  { {0x64420025,0x78a46255,0x68e50072,0x00000000}},	//   heoi, eniv, _puhd,
  { {0x82770047,0x66cb013d,0xd918129a,0x00000000}},	//   נעלע_, nüke, льт_,
  { {0x5c07005a,0x6d580150,0x57f56256,0x00000000}},	//   _сяка, _irva, рпат,
  { {0x6d580add,0x64426257,0x57a71a78,0x00000000}},	// [cdf0] _hrva, deoi, ушва,
  { {0x4426427f,0xe4e70086,0x6d582681,0x00000000}},	//   ego_, гідн, _krva,
  { {0x320500e5,0x290c19bc,0x98480058,0x00000000}},	//   _rely_, ádat_, aşı_,
  { {0x24190076,0x44266258,0x6f020051,0x00000000}},	//   тоды_, ggo_, _owoc,
  { {0x7680005b,0x4429008f,0x872b0085,0x00000000}},	//   _köyl, ļa_, _яўна_,
  { {0x44290051,0x6f1b006f,0x44266259,0x00000000}},	//   ża_, vruc, ago_,
  { {0x272f0058,0x201900be,0x66cb013d,0x00000000}},	//   lün_, ósio_, güke,
  { {0x69c80051,0x64420025,0x764e0051,0x00000000}},	//   żdeg, ceoi, _zaby,
  { {0x6d580004,0xf77200b5,0x272f01f7,0x00000000}},	//   _arva, ַקט_, nün_,
  { {0x6f1b2443,0x2ca9004b,0x78a40266,0x00000000}},	//   rruc, _ajad_, zniv,
  { {0x26c1017d,0x7e54000d,0xddc50054,0x00000000}},	//   ilho_, стыц, рбни,
  { {0x6f1b00bd,0x272f0058,0x673d625a,0x00000000}},	//   pruc, kün_, _opsj,
  { {0x768001f7,0x6d580162,0x69c1005b,0x00000000}},	//   _böyl, _erva, ülen,
  { {0x4426625b,0x6607004c,0x272f0058,0x00000000}},	//   zgo_, _nejk, dün_,
  { {0x26c10024,0xc8960d34,0xfaa30854,0x00000000}},	//   dlho_, арањ, царо,
  { {0x7d56014e,0x7d1c006d,0xfc3f0066,0x00000000}},	//   _כיצד_, árse, rníc_,
  { {0x753c0045,0x272f005b,0x6cd30021,0x00000000}},	// [ce00] _sprz, gün_, _بقيا,
  { {0x984801f7,0x290c0025,0x78a4625c,0x00000000}},	//   rşı_, ádas_, sniv,
  { {0x64420027,0x9202001c,0x75460330,0x00000000}},	//   teoi, šāka, рнез,
  { {0x44260006,0x58d30002,0x2257007e,0x00000000}},	//   ugo_, _моќт, یلند_,
  { {0x64420025,0x4426625d,0xf2e8007e,0x00000000}},	//   reoi, rgo_, اکره_,
  { {0xc2b60001,0x8b570047,0x64420d23,0x00000000}},	//   шљењ, יינס_, seoi,
  { {0x753c0051,0xa5070121,0x7d15013d,0x00000000}},	//   _uprz, _веса_, ázsl,
  { {0x9f4f006d,0xbf660021,0xe0cf0021,0x00000000}},	//   _negó_, لدخو, وزي_,
  { {0x08770047,0x66cb013d,0x6831013d,0x00000000}},	//   שעפט_, süke, lódó,
  { {0x6d5801b3,0xd7370063,0x78a90734,0x00000000}},	//   _prva, סטית_, čevi,
  { {0xfc3f006d,0x272f005b,0x7d03002b,0x00000000}},	//   enía_, zün_, _cwns,
  { {0x768001f7,0xb17b00b5,0xc19b0063,0x00000000}},	//   _söyl, _שטאר, _בשבי,
  { {0xdef4000d,0xad66005d,0x9fe5009b,0x00000000}},	//   _уплы, _چابه, _اسمه,
  { {0x6d58027d,0x8d76005d,0x3fcb005d,0x00000000}},	//   _trva, _ناعا, _شدنی_,
  { {0x6d5803c8,0xfc3f006d,0xdd93000d,0x00000000}},	//   _urva, anía_, _машы,
  { {0x272f01f7,0x4ddb009a,0xa567005d,0x00000000}},	//   tün_, _בחוו, یدان,
  { {0x96eb0086,0x35e7625e,0xa6150054,0x00000000}},	// [ce10] тьба_, ацев, ймач,
  { {0x272f005b,0x26c1017d,0xbebd109f,0x00000000}},	//   rün_, ulho_, ltūr,
  { {0x19ab000a,0x272f0058,0x660701e1,0x00000000}},	//   _штип_, sün_, _vejk,
  { {0xe4a40086,0x5dd90047,0xbebd276c,0x00000000}},	//   орчо, אַנס, ntūr,
  { {0xb4c70053,0x29110022,0x7c2d0168,0x00000000}},	//   _उठी_, lsza_, _mcar,
  { {0xa229505a,0x2127005d,0xc51b0044,0x00000000}},	//   ужка_, ليتی_, _لغرض_,
  { {0xbebd20ae,0x5155000d,0x5467005e,0x00000000}},	//   ktūr, стлу, _књаз,
  { {0x3f8d0994,0xfbdf0016,0x40490001,0x00000000}},	//   tzeu_, ndês_, упио_,
  { {0x7e7500ea,0x442d42c2,0x249d002b,0x00000000}},	//   özpo, _ice_, miwm_,
  { {0x7c2d014f,0x628a00bd,0x42740021,0x00000000}},	//   _acar, chfo, _والآ,
  { {0xfc46027d,0x7af60026,0xbc830013,0x00000000}},	//   šíme_, _styt, ượn,
  { {0x249d001f,0xcb6a065b,0x853a0063,0x00000000}},	//   niwm_, гаме_, נגרי,
  { {0x929d0051,0x76450072,0x1c43046e,0x00000000}},	//   _zwła, kehy, чням,
  { {0xbb430002,0x7c2d57b7,0xff560041,0x00000000}},	//   џерк, _ecar, _לבנך_,
  { {0x7e7c00bd,0x39790086,0x7e6300d1,0x00000000}},	//   örpe, астю_, _innp,
  { {0x7c2d0139,0x0dc80121,0x63ad0022,0x00000000}},	//   _gcar, _тучи_, żany,
  { {0x249d001f,0x29110022,0xa686034b,0x00000000}},	// [ce20] diwm_, asza_, блад,
  { {0x672400ca,0x442d0b7f,0x5986286c,0x00000000}},	//   ruij, _ace_, _глоб,
  { {0x64a60086,0xa3da0053,0x442d625f,0x00000000}},	//   бажа, डेन_, _bce_,
  { {0xa5076260,0x442d00cd,0x75d30021,0x00000000}},	//   сеца_, _cce_, سينا,
  { {0xb8de016a,0x4373005e,0xa3d30082,0x00000000}},	//   ेत_, зујт, हेल_,
  { {0x2aad0066,0x76800072,0x92581ece,0x00000000}},	//   oľba_, _möyk, ракт_,
  { {0xd1300044,0x823304a0,0x41b40043,0x00000000}},	//   ذمة_, سروا, غمبر,
  { {0x27f20f8e,0x2ef4242b,0x2348005d,0x00000000}},	//   ncyn_, озир, _پسری_,
  { {0x3f820080,0x987b0041,0x999a005f,0x00000000}},	//   áku_, טאקט, _kapų_,
  { {0x7c2d6261,0x6e6606e0,0x29110022,0x00000000}},	//   _scar, стиж, ysza_,
  { {0xb6bb0047,0x3f826262,0x6d4f0022,0x00000000}},	//   רציי, šku_, łcan,
  { {0x69c1005b,0x999a005f,0xdfd201f3,0x00000000}},	//   ülem, _lapų_, _فيض_,
  { {0xab840002,0x29110022,0xbebd2401,0x00000000}},	//   пурк, wsza_, rtūr,
  { {0xbebd001c,0x00000000,0x00000000,0x00000000}},	//   stūr,   ,   ,
  { {0x8c3b004d,0xce370063,0x2b401b13,0x00000000}},	//   eiße, _האות_, _epic_,
  { {0x29110051,0x98770058,0xdca4007b,0x00000000}},	//   rsza_, tçı_, _наји,
  { {0x2911000f,0xe6996263,0x76800072,0x00000000}},	// [ce30] ssza_, аваш_, _köyh,
  { {0xeef70063,0x29110022,0xb71401d5,0x00000000}},	//   צמבר_, psza_, ядущ,
  { {0x442d18fb,0x2cfb0041,0x7afd6264,0x00000000}},	//   _pce_, ָלדא, lpst,
  { {0xccf300b5,0xe8e0008d,0x7afd6265,0x00000000}},	//   לכע_, _phụt_, opst,
  { {0xe3b30021,0xa3d30053,0x7c2b0137,0x00000000}},	//   أرض_, हें_, _ögru,
  { {0xd9fb0053,0x82370021,0x249d00a3,0x00000000}},	//   ्रित_, إرشا, siwm_,
  { {0xd12e0021,0xb1450086,0xdcf5008f,0x00000000}},	//   نمو_, інил, ēcīg,
  { {0xef191533,0xe8e00013,0x2eb30042,0x00000000}},	//   ами_, _thụt_, ुत्त,
  { {0xa4d40086,0x7afd00ca,0x53990085,0x00000000}},	//   _хоті, jpst, _твая_,
  { {0x273b000c,0xee36046f,0xae790062,0x00000000}},	//   mână_, онь_, рсих_,
  { {0xd0190754,0x7dc5007e,0x22473214,0x00000000}},	//   _نقاش_, تقدن, menk_,
  { {0x2d8b0045,0x8c960086,0x7d1c00ea,0x00000000}},	//   ące_, ірні, ársa,
  { {0x2d8300c3,0x25c60053,0xba560062,0x00000000}},	//   šje_, _वर्ण, отвъ,
  { {0xf8bf027d,0xefb3007e,0x09fa0021,0x00000000}},	//   _aké_, _ویژگ, شفرة_,
  { {0x38c8006a,0xce34005d,0xb86601f3,0x00000000}},	//   ماری_, _رويک, يارو,
  { {0x3eb800c2,0x3e7b0003,0x22476266,0x00000000}},	//   črte_, _vêtu_, henk_,
  { {0x62830250,0xe1ff008b,0x060a1849,0x00000000}},	// [ce40] kkno, _đón_, инак_,
  { {0xd6260021,0x657e2dd2,0xfe65005d,0x00000000}},	//   تعري, typh, رگ_,
  { {0x628300ac,0x44f6007e,0x224706aa,0x00000000}},	//   dkno, زساز, denk_,
  { {0x62836267,0x67df0078,0x6abc0c8b,0x00000000}},	//   ekno, _sąjū, lorf,
  { {0x926a0af0,0x9cd7009d,0x00000000,0x00000000}},	//   ирка_, קונה_,   ,
  { {0x27346268,0x62830186,0xdce90080,0x00000000}},	//   män_, gkno, íněn,
  { {0xe57a0001,0x273400fe,0x67366269,0x00000000}},	//   _тзв_, län_, ltyj,
  { {0xc05a0054,0xb97b009f,0x63b5006c,0x00000000}},	//   рік_, ינצי, égné,
  { {0x228b0031,0x03a30086,0xf2a6047e,0x00000000}},	//   _søke_, _жито, _диап,
  { {0x67360006,0x69c1042e,0x079b0047,0x00000000}},	//   ityj, ülek, יספל,
  { {0x2734024a,0x673600fe,0x7bcd013d,0x00000000}},	//   hän_, htyj, _szau,
  { {0xdee60259,0x656800cd,0x27340072,0x00000000}},	//   _доди, _àdhu, kän_,
  { {0x2734024a,0x320c0024,0xf4130063,0x00000000}},	//   jän_, _kedy_, ופר_,
  { {0x2734024a,0xfc3f0080,0x6abc002b,0x00000000}},	//   dän_, mním_, gorf,
  { {0xfc3f0080,0x50f8009a,0x00000000,0x00000000}},	//   lním_, מִּד,   ,
  { {0x5b150b4a,0x7afd626a,0x3aef0075,0x00000000}},	//   _емит, ppst, _tüp_,
  { {0xfc3f0080,0x8c44005e,0x00000000,0x00000000}},	// [ce50] nním_, _цење,   ,
  { {0x1efb0047,0xeb9f0093,0x07080021,0x00000000}},	//   ילמע, rbød_, تيكي_,
  { {0x7aed0027,0xea000013,0x3983007e,0x00000000}},	//   _huat, _hiếu_, _غیرف,
  { {0xe3b3007e,0x7aed1642,0xc3550062,0x00000000}},	//   ورش_, _kuat, зъкъ,
  { {0xeab0007e,0x1304000d,0x6283626b,0x00000000}},	//   _سعی_, дзім, tkno,
  { {0xfc3f0080,0xe1f1006a,0xb7da0063,0x00000000}},	//   dním_, رست_, _לקרי,
  { {0x7ae50035,0x91e240f8,0x320c0150,0x00000000}},	//   _miht, ноше, _dedy_,
  { {0x7ae50004,0xf92a0047,0x6283626c,0x00000000}},	//   _liht, צופּ, skno,
  { {0x443f3e4f,0x69c500fe,0x66d00b6e,0x00000000}},	//   _ibu_, _lyhe, säke,
  { {0x76550512,0x6eed0066,0x320c002b,0x00000000}},	//   _jazy, _hĺbk, _gedy_,
  { {0x6abc2442,0x69c54b34,0x2734004d,0x00000000}},	//   vorf, _nyhe, zän_,
  { {0x7aed003e,0xfc3f0080,0x6abc00bd,0x00000000}},	//   _buat, bním_, worf,
  { {0x7aed02dd,0x6d5a00d1,0x4b550062,0x00000000}},	//   _cuat, avta, мърт,
  { {0x2734024a,0xddc8001c,0x76550051,0x00000000}},	//   vän_, ņoša, _nazy,
  { {0xdcf9006a,0x186a6260,0x443f0051,0x00000000}},	//   _ارتش_, бави_, _obu_,
  { {0x386602dd,0x6736024a,0x7aed626d,0x00000000}},	//   ñor_, ttyj, _fuat,
  { {0xa686000a,0x7aed106e,0x76550022,0x00000000}},	// [ce60] плад, _guat, _bazy,
  { {0xdce20006,0x2734626e,0x443f2bf8,0x00000000}},	//   tylė, rän_, _abu_,
  { {0x27340072,0x4a7b0063,0xfc3f01c8,0x00000000}},	//   sän_, _הריב, zním_,
  { {0xd4990086,0x66cb0058,0xef190022,0x00000000}},	//   орі_, lükl, zyża_,
  { {0x69c0005b,0x833a0121,0x443f01e1,0x00000000}},	//   şmed, счет_, _dbu_,
  { {0xfc3f0080,0x6d43626f,0xbb3b0149,0x00000000}},	//   vním_, _opna, מעני,
  { {0x6724006f,0x320c0066,0x6d4f0022,0x00000000}},	//   lrij, _vedy_, łcaj,
  { {0xfc3f6270,0x67240b59,0x7e7800a8,0x00000000}},	//   tním_, orij, _sovp,
  { {0x7e780198,0x67240122,0x320c03a4,0x00000000}},	//   _povp, nrij, _tedy_,
  { {0x660e003d,0xfc3f0080,0x9f4d00cd,0x00000000}},	//   _jebk, rním_, cceí_,
  { {0x672402b0,0x7aed06a7,0x2486007d,0x00000000}},	//   hrij, _suat, okom_,
  { {0x7ae50004,0x672401b3,0x68e66271,0x00000000}},	//   _siht, krij, _nikd,
  { {0x60c200a4,0xfc3f0114,0x7aed6272,0x00000000}},	//   _ikom, lník_, _quat,
  { {0x67246273,0x2fc600a4,0xdfa500f2,0x00000000}},	//   drij, _iyog_, _تحمي,
  { {0xfc3f0024,0x0d660062,0x67246274,0x00000000}},	//   nník_, _хълм, erij,
  { {0x3ebe00ea,0x26da405e,0x67242482,0x00000000}},	//   lott_, empo_, frij,
  { {0x24860024,0x7ae50019,0x4735000d,0x00000000}},	// [ce70] dkom_, _tiht, ьнас,
  { {0xcb12014e,0x63bd0093,0x20c10139,0x00000000}},	//   _שלי_, _øsni, nóir_,
  { {0x3eac006f,0x67242f12,0x60c26275,0x00000000}},	//   indt_, arij, _okom,
  { {0x20c10025,0xa3f40086,0x248600ac,0x00000000}},	//   hóir_, епці, gkom_,
  { {0x78ad0b43,0x3ebe6276,0xfc3f011b,0x00000000}},	//   mnav, kott_, eník_,
  { {0xcb140047,0x78ad6144,0x60c26277,0x00000000}},	//   גלס_, lnav, _akom,
  { {0x3ebe000f,0x20c10025,0x78ad6278,0x00000000}},	//   dott_, dóir_, onav,
  { {0x40940076,0x24861401,0x78ad5d9e,0x00000000}},	//   ерьт, ckom_, nnav,
  { {0x78ad6279,0x66cb005b,0x657801e1,0x00000000}},	//   inav, yükl, øvhv,
  { {0x20c10027,0x6459190f,0x644b627a,0x00000000}},	//   góir_, ldwi, legi,
  { {0x78ad00e8,0x442f380f,0xfc3f1994,0x00000000}},	//   knav, ogg_, cník_,
  { {0x3eac00b9,0x3eb800c2,0x20c11397,0x00000000}},	//   andt_, črta_, róis_,
  { {0xeb970432,0x68e600d1,0xda66007e,0x00000000}},	//   дия_, _rikd, واسي,
  { {0x672446c4,0x248608b7,0x60c2004c,0x00000000}},	//   vrij, zkom_, _zkom,
  { {0xb9b5005a,0x66cb005b,0x200f008d,0x00000000}},	//   естъ, rükl, _kegi_,
  { {0x7680024a,0x60c901f7,0x3f89001c,0x00000000}},	//   _löyt, nlem, _ļauj_,
  { {0xfc3f0240,0x644b0078,0xc7a31d27,0x00000000}},	// [ce80] zník_, degi, витк,
  { {0x2d810019,0x442f00d1,0x78ad00fe,0x00000000}},	//   _ühes_, egg_, anav,
  { {0x60c901f7,0x644b0268,0x645900f5,0x00000000}},	//   klem, fegi, fdwi,
  { {0x3ebe000f,0x660e627b,0x6724627c,0x00000000}},	//   zott_, _webk, prij,
  { {0x2486627d,0x69c1004b,0x60c90070,0x00000000}},	//   rkom_, ülev, dlem,
  { {0x44320051,0x2486627e,0x248d00ea,0x00000000}},	//   ży_, skom_, _elem_,
  { {0x60c901f7,0xe297000a,0x21670001,0x00000000}},	//   flem, ќај_, дији_,
  { {0x60db002c,0x212008ea,0xfc3f027d,0x00000000}},	//   gmum, čih_, rník_,
  { {0x3ebe000f,0x200f0026,0x20c10025,0x00000000}},	//   tott_, _degi_, tóir_,
  { {0x60c90164,0x78ad02e2,0x78a41196,0x00000000}},	//   alem, znav, hiiv,
  { {0x3ebe627f,0x78ad05e7,0x60c96280,0x00000000}},	//   rott_, ynav, blem,
  { {0x1016007e,0x60c26281,0x20c10139,0x00000000}},	//   _آباد, _ukom, sóir_,
  { {0x78ad08ea,0x3ebe00ea,0x29180089,0x00000000}},	//   vnav, pott_, esra_,
  { {0x60c06282,0x7995004d,0x644b0022,0x00000000}},	//   lomm, tzzw, zegi,
  { {0x442f02f0,0x28f80076,0x1958000d,0x00000000}},	//   ygg_, десь_, мары_,
  { {0x60c06283,0x58d46284,0x31570041,0x00000000}},	//   nomm, вост, וילן_,
  { {0x78ad4679,0x3f846285,0x644b6286,0x00000000}},	// [ce90] rnav, nymu_, vegi,
  { {0x78ad191f,0x644b0173,0x60c90f3a,0x00000000}},	//   snav, wegi, zlem,
  { {0xab620019,0x60c9005b,0x66cb004b,0x00000000}},	//   _üürn, ylem, lükk,
  { {0x9475006a,0x7d0d0051,0x3f840078,0x00000000}},	//   رگزا, _łask, kymu_,
  { {0xa3da016a,0x13080086,0x64592493,0x00000000}},	//   डेल_, дній_, rdwi,
  { {0x200f6287,0xd5bb0062,0x3f846288,0x00000000}},	//   _segi_, _дсб_, dymu_,
  { {0x60c96289,0x349516d9,0xe5c400d9,0x00000000}},	//   tlem, _завр, _асто,
  { {0x45d40055,0x249f0397,0x60c9628a,0x00000000}},	//   _росс, _umum_, ulem,
  { {0x60c90508,0x200f00cd,0x60db092a,0x00000000}},	//   rlem, _vegi_, rmum,
  { {0xfe710032,0x26c1027d,0x2ca01244,0x00000000}},	//   ادة_, noho_, _smid_,
  { {0x2ca0473c,0x200f0019,0x60c93b09,0x00000000}},	//   _pmid_, _tegi_, plem,
  { {0x60c01823,0x7f95000d,0x672d078c,0x00000000}},	//   comm, _паех, kuaj,
  { {0x78a40659,0xdd8e007e,0x6d5c0137,0x00000000}},	//   viiv, لوی_, årar,
  { {0x3f7a0047,0x69c80022,0xdbd2004e,0x00000000}},	//   _מאנס, żdem, müüm,
  { {0x3ea90080,0x78a40aba,0x7cff003b,0x00000000}},	//   čitě_, tiiv, fârş,
  { {0x3ea5004b,0xfc3f0139,0x76800072,0x00000000}},	//   lilt_, cfí_, _nöyr,
  { {0xdbd20019,0x2903013d,0x78a4004e,0x00000000}},	// [cea0] nüüm, apja_, riiv,
  { {0x78bb017f,0x3ea50019,0xe9da0062,0x00000000}},	//   čuva, nilt_, _нкп_,
  { {0x1a9b00b5,0x69c1000f,0xd6cf0021,0x00000000}},	//   _זייע, ület, حقل_,
  { {0x3ea5628b,0x66030075,0x13a8005d,0x00000000}},	//   hilt_, ınka, ونای_,
  { {0x3ea53385,0x60c000fe,0x93f3000d,0x00000000}},	//   kilt_, vomm, упіц,
  { {0x7d1c0195,0x33260331,0x2d8501e1,0x00000000}},	//   ársk, rrox_, kyle_,
  { {0x3ea5004b,0x889a0063,0xd5b20049,0x00000000}},	//   dilt_, ּבִי, _صفر_,
  { {0xd0100032,0x81430593,0x653b0047,0x00000000}},	//   جلة_, اپيم, _מעלד,
  { {0x9ed80076,0x60c0628c,0x2d8301e1,0x00000000}},	//   ммит_, romm, øjen_,
  { {0x60c04280,0x3ea5628d,0x3f84002b,0x00000000}},	//   somm, gilt_, rymu_,
  { {0x291e017f,0xc6930063,0xac950727,0x00000000}},	//   štaj_, ראת_, ванш,
  { {0xe1ff008b,0x66cb004b,0x66d00050,0x00000000}},	//   _đói_, tükk, käko,
  { {0x9f340086,0x7cff003b,0x66d00072,0x00000000}},	//   _релі, vârş, jäko,
  { {0x628a101c,0xafe30121,0xdfcf009b,0x00000000}},	//   nkfo, _сочл, _ايه_,
  { {0x3cea0053,0xe9190054,0xdd8f045b,0x00000000}},	//   _घंटे_, ьові_, _сш_,
  { {0x7d1a13e5,0x672d628e,0x67d50054,0x00000000}},	//   msts, tuaj, вобу,
  { {0x66d000c7,0x16be0161,0x628a00d1,0x00000000}},	// [ceb0] räkn, ्तूब, kkfo,
  { {0x69c10019,0xc13b008b,0xaa470072,0x00000000}},	//   üles, _cướp_, ätää_,
  { {0x26c10035,0xddc311f0,0x66d00137,0x00000000}},	//   roho_, _manş, mäkl,
  { {0x6aa70122,0xe4e40651,0x2bde0053,0x00000000}},	//   lijf, гічн, नेवा,
  { {0x69d854e7,0x96f80062,0x76800050,0x00000000}},	//   _úver, _пеят_, _vöyr,
  { {0x7d1a05e5,0x25ac004c,0x42d40054,0x00000000}},	//   ksts, áhlá_, ліщу,
  { {0x45d4005a,0x7d1a00ca,0x6d5d008f,0x00000000}},	//   _борс, jsts, āsak,
  { {0x6aa70122,0x44f7005b,0xa4d50454,0x00000000}},	//   hijf, _iç_, _робі,
  { {0x91f5001b,0x3f8b0024,0xcf8e007e,0x00000000}},	//   _các, ácu_, يژه_,
  { {0x645b0b7b,0x3ea500e5,0xc87f004d,0x00000000}},	//   _haui, uilt_, _loß_,
  { {0x3ea50019,0xfc3f0025,0x6aa700ca,0x00000000}},	//   rilt_, hníu_, dijf,
  { {0x3ea5004b,0xdca65432,0x66cb013d,0x00000000}},	//   silt_, тами, sükh,
  { {0x3ea5628f,0xdd02008f,0x7d1a6290,0x00000000}},	//   pilt_, ārād, asts,
  { {0x66d00072,0xbea5443e,0x7d1a0244,0x00000000}},	//   väko, _шалк, bsts,
  { {0x18a60002,0x78bb007d,0x6f1b6291,0x00000000}},	//   вавм, čuvn, lsuc,
  { {0x999e013d,0xab660a91,0x3cf70023,0x00000000}},	//   ütő_, _авил, ēgvā_,
  { {0xbc790024,0x44f7005b,0x8a060062,0x00000000}},	// [cec0] úšťa, _aç_, _изпе,
  { {0x6aa7006f,0xa50a24cc,0xf7432c1b,0x00000000}},	//   cijf, дежа_, рефо,
  { {0xd826000a,0x6f1b00bd,0x98ad005b,0x00000000}},	//   _идни, hsuc, _çoğu_,
  { {0xe475000d,0x64bc0a10,0x79b7009a,0x00000000}},	//   лучэ, ičig, _יליד_,
  { {0xe3b201fb,0x645b12a9,0xe29a2c1b,0x00000000}},	//   جرا_, _daui, мад_,
  { {0x66030071,0x7d1a6292,0xe1d80085,0x00000000}},	//   _впра, ysts, ндлі_,
  { {0x91f5001b,0x6f1b00bd,0x628a27b9,0x00000000}},	//   _sác, esuc, rkfo,
  { {0x85570063,0x60d9001f,0x765c6293,0x00000000}},	//   _בשלב_, _chwm, _hary,
  { {0x765c0e53,0x2f13000d,0x7e2a0083,0x00000000}},	//   _kary, адыё, міна_,
  { {0x66cb0019,0xd3370063,0x98a30022,0x00000000}},	//   tüki, _ברמה_, mują_,
  { {0x765c06d3,0xf2970063,0xcec10022,0x00000000}},	//   _mary, _שכבר_, djęć_,
  { {0x91f5008b,0xa3d60053,0x66cb004b,0x00000000}},	//   _tác, _हरा_, rüki,
  { {0x7d1a00bd,0x98a30051,0xc87f004d,0x00000000}},	//   ssts, nują_, _roß_,
  { {0x765c0006,0xa9350054,0xf21a0042,0x00000000}},	//   _nary, легш, _नजफ़_,
  { {0x6aa70122,0x63be0051,0x59f80086,0x00000000}},	//   rijf, ępny, теся_,
  { {0x2aad017f,0x515b0063,0x98a30051,0x00000000}},	//   džbe_, וכלו, kują_,
  { {0xd7d50001,0xd7c9007e,0xf6f5007e,0x00000000}},	// [ced0] ужањ, روطه_, ازرگ,
  { {0xba55041d,0x64420164,0x98a30051,0x00000000}},	//   _свој, efoi, dują_,
  { {0x765c03e0,0x9c64005d,0xe3a50043,0x00000000}},	//   _dary, _صهیو, گشای,
  { {0xa3190ac5,0x6f0214df,0xb8f70042,0x00000000}},	//   ежду_, _otoc, ित_,
  { {0x98a30022,0x4c9c016e,0xd3b80054,0x00000000}},	//   gują_, ובאו, куші_,
  { {0xfb1600b5,0x6d4a0146,0x6d58074f,0x00000000}},	//   אַקט_, _opfa, _osva,
  { {0x98a30006,0xc6920047,0x6f023c52,0x00000000}},	//   aują_, _פאל_, _atoc,
  { {0x6615004c,0x6f1b30e6,0x765c0cb6,0x00000000}},	//   _hezk, tsuc, _zary,
  { {0x284a0041,0x98a30022,0x2127005d,0x00000000}},	//   געפּ, cują_, ريکی_,
  { {0x6f1b0199,0x2aad0066,0x291e0078,0x00000000}},	//   rsuc, oľbu_, štai_,
  { {0x273d008b,0xe1390054,0x6f1b5b7c,0x00000000}},	//   hìn_, _їзді_, ssuc,
  { {0x7f190086,0x62816294,0xeb9a173e,0x00000000}},	//   _зіку_, _holo, еим_,
  { {0x4fa4019d,0x6d5e0080,0x9f340086,0x00000000}},	//   _київ, _špat, _вечі,
  { {0xc33200b5,0x62810089,0x6615004c,0x00000000}},	//   זוך_, _jolo, _nezk,
  { {0xdcfa0006,0xd6e40086,0x98a30051,0x00000000}},	//   tytą, пiюв, zują_,
  { {0x88e600e1,0x62810b1c,0xd0190022,0x00000000}},	//   ужбе, _lolo, nań_,
  { {0x7c240027,0x0ab60021,0x99980078,0x00000000}},	// [cee0] _idir, _محدد, terų_,
  { {0x55e60054,0xd51a008d,0x55960131,0x00000000}},	//   гозб, _nặn, лјеф,
  { {0x765c16c3,0x45d602d8,0x98a30022,0x00000000}},	//   _vary, уцат, wują_,
  { {0xa85600e1,0x2aad0066,0x98a30022,0x00000000}},	//   _стој, ržbe_, tują_,
  { {0x64420164,0x8c1b014e,0xd0190051,0x00000000}},	//   rfoi, תוני, dań_,
  { {0x6442000c,0xa226007e,0x38606295,0x00000000}},	//   sfoi, ارشه, ldir_,
  { {0x62816296,0xddc30003,0x98a30051,0x00000000}},	//   _dolo, _manœ, sują_,
  { {0x7c240290,0x38606297,0x99580240,0x00000000}},	//   _ndir, ndir_, káže_,
  { {0x62810529,0xc32a0021,0xa3cb0053,0x00000000}},	//   _folo, _سكان_, _रुप_,
  { {0xa2e6253f,0x62816298,0x43830021,0x00000000}},	//   _созд, _golo, _الْق,
  { {0x38606299,0x64bc0130,0xd019056c,0x00000000}},	//   kdir_, pčid, bań_,
  { {0xd00f0021,0x69c0005b,0x7af6629a,0x00000000}},	//   _فلم_, ğmel, _buyt,
  { {0x69c0005b,0x7c24001f,0x38600762,0x00000000}},	//   şmel, _ddir, ddir_,
  { {0x8f9b00b5,0x6d58629b,0x2eb10042,0x00000000}},	//   _אידי, _tsva, ीकृत,
  { {0x6d58007d,0x442405b3,0x828b0063,0x00000000}},	//   _usva, _odm_, תְכֶ,
  { {0x6947017f,0x44240150,0x7d1c009c,0x00000000}},	//   jčeš, _ndm_, ársu,
  { {0x06150b3f,0xa5f9005e,0xa61505ce,0x00000000}},	// [cef0] идаю, везу_, имач,
  { {0x38605051,0xd5bb629c,0x44240e6c,0x00000000}},	//   adir_, нсе_, _adm_,
  { {0x91f50013,0xf4874a59,0x66cb0058,0x00000000}},	//   _bán, лудн, dükt,
  { {0xa8790047,0x44240f20,0x297a0149,0x00000000}},	//   _סאָר, _cdm_, _סטרא,
  { {0xa7fb0118,0x442400ca,0x62810f18,0x00000000}},	//   _cañe, _ddm_, _polo,
  { {0xe8e0001b,0xd0190051,0x8afc0047,0x00000000}},	//   _đức_, wań_, עהוי,
  { {0x70b20161,0x82340021,0xd0190051,0x00000000}},	//   ुकूल, إرها, tań_,
  { {0x672d082a,0xd00e0021,0x6281629d,0x00000000}},	//   oraj, ولى_, _wolo,
  { {0x98b8001c,0xef16014c,0x3f89001c,0x00000000}},	//   ntrā_, амы_, _ļaus_,
  { {0x672d017f,0x999800ea,0x3860005b,0x00000000}},	//   iraj, zerű_, zdir_,
  { {0x672d01c2,0x66cb004b,0x3860629e,0x00000000}},	//   hraj, lüks, ydir_,
  { {0x672d1587,0x0d820054,0x66d00656,0x00000000}},	//   kraj, ілян, täkk,
  { {0x64490027,0x200d003b,0x7ff4002a,0x00000000}},	//   _mbei, mbei_, _اسما,
  { {0xb69b000c,0x8f9a0165,0x6f09629f,0x00000000}},	//   _stân, _ביני, mpec,
  { {0x672d62a0,0x200d004d,0x26ca00c2,0x00000000}},	//   eraj, obei_, _rkbo_,
  { {0x7c240290,0x6d4101bb,0xf772009e,0x00000000}},	//   _udir, mtla, ياء_,
  { {0x672d62a1,0x3860499c,0x66cb0058,0x00000000}},	// [cf00] graj, rdir_, yükt,
  { {0x442400f3,0x91f5001b,0x7e610026,0x00000000}},	//   _sdm_, _sán, ndlp,
  { {0x2baa0053,0x63ad0025,0x64bc007d,0x00000000}},	//   _चेता, úann, jčic,
  { {0x3eb800c2,0xd91b0063,0x98a30022,0x00000000}},	//   črti_, _בוטל, kuję_,
  { {0x68e40019,0x6d410019,0x833a0591,0x00000000}},	//   mmid, htla, тчет_,
  { {0x68e40019,0x6d4162a2,0x6f0900e5,0x00000000}},	//   lmid, ktla, dpec,
  { {0x5bd30235,0x649301f7,0xddc80051,0x00000000}},	//   _सर्व, _için, zedł,
  { {0xddd80024,0x2fcf0829,0x68e400ca,0x00000000}},	//   _novš, _bygg_, nmid,
  { {0x6d410045,0x6e440021,0xa0670d34,0x00000000}},	//   etla, منظم, рања_,
  { {0x26c7017f,0x200d00bd,0x99870066,0x00000000}},	//   čnog_, abei_, _čiže_,
  { {0x68e400ac,0x85f70047,0x248425fd,0x00000000}},	//   kmid, יציע_, _komm_,
  { {0x2366007d,0x2aad007d,0x98a30022,0x00000000}},	//   ovoj_, džba_, buję_,
  { {0xcf770032,0x6d4162a3,0x2eee01db,0x00000000}},	//   _نصوص_, atla, _tiff_,
  { {0x68e40180,0xadbc000d,0x672d00a8,0x00000000}},	//   emid, _палi, vraj,
  { {0x2bd30161,0x3958001f,0x66cb10fd,0x00000000}},	//   _सरका, gwrs_, züks,
  { {0x88940076,0x2366007d,0x14100053,0x00000000}},	//   оисх, kvoj_, ारोह_,
  { {0xc7cb0085,0x29050078,0x68ef0058,0x00000000}},	// [cf10] тыве_, ūla_, _vicd,
  { {0x68e40019,0x672d04d0,0xddd80066,0x00000000}},	//   amid, rraj, _zovš,
  { {0x672d0659,0x2d9e004d,0x200d0078,0x00000000}},	//   sraj, nzte_, ybei_,
  { {0x6f09310b,0x321c62a4,0x672d62a5,0x00000000}},	//   ypec, eavy_, praj,
  { {0x6f090034,0xe3650f8d,0x78ad62a6,0x00000000}},	//   xpec, скли, miav,
  { {0x78ad0006,0x69da004b,0x2fcf08a9,0x00000000}},	//   liav, üteg, _rygg_,
  { {0x66cb0019,0xf5950021,0xd1c90076,0x00000000}},	//   süks, _الأج, ылке_,
  { {0x2d9e0024,0xf3f9000c,0x66d000fe,0x00000000}},	//   dzte_, _faţa_, väki,
  { {0x200d00bd,0xff510021,0x4fa50062,0x00000000}},	//   rbei_, سخة_, сипв,
  { {0x78ad097c,0x6f0962a7,0x6d412767,0x00000000}},	//   hiav, rpec, ttla,
  { {0x2d9101c2,0x6d416086,0x98b800dd,0x00000000}},	//   áze_, utla, ntră_,
  { {0x3b0a000a,0x41740021,0x69c0005b,0x00000000}},	//   лемо_, _باكس, şmek,
  { {0x64bc00eb,0xe4560047,0x9f05009e,0x00000000}},	//   nčia, זירט_, _اوتو,
  { {0xd37a00b5,0x64bc00eb,0x60c90717,0x00000000}},	//   ארשט, ičia, loem,
  { {0xc8960001,0x28960141,0xef190022,0x00000000}},	//   брањ, бјас, ryżu_,
  { {0x60c90a53,0x68e41115,0x64bc0006,0x00000000}},	//   noem, umid, kčia,
  { {0x3f8d00cd,0x64bc0024,0x15f60021,0x00000000}},	// [cf20] nyeu_, jčia, مساح,
  { {0x64bc0066,0x68e4154e,0x26080042,0x00000000}},	//   dčia, smid, ाँधी_,
  { {0x68e4006f,0x64bc0006,0x26cb005d,0x00000000}},	//   pmid, ečia, اطقی_,
  { {0x291e00eb,0x78ad62a8,0x64a6005e,0x00000000}},	//   štas_, ciav, љада,
  { {0x321c004a,0xdc8d0047,0xe29a0013,0x00000000}},	//   tavy_, כװאָ, thư_,
  { {0xe6960021,0x66cb013d,0x23660130,0x00000000}},	//   _السد, sükr, rvoj_,
  { {0x321c027d,0xd14a007e,0x72290086,0x00000000}},	//   ravy_, اشتن_, рців_,
  { {0x63a40025,0xb97b0063,0xc034005e,0x00000000}},	//   úins, טנצי, цниј,
  { {0xdfd00032,0x93590001,0x2d8c00ac,0x00000000}},	//   بية_, _врху_, wyde_,
  { {0x2d9e0199,0xa7fb02dd,0x2d8c00b9,0x00000000}},	//   tzte_, _maña, tyde_,
  { {0x3eac0d02,0xa2c50042,0x10a60054,0x00000000}},	//   ridt_, ाकर्, _лижн,
  { {0xa1770063,0xb87b0025,0x2d8c62a9,0x00000000}},	//   _לעבד_, _mhíc, ryde_,
  { {0x661e0373,0x66d00072,0x78ad62aa,0x00000000}},	//   kapk, läku, viav,
  { {0x6d5c0014,0xdd940895,0x6df40044,0x00000000}},	//   æras, _малы, _بكثا,
  { {0x66d000fe,0x661e017e,0xceb80022,0x00000000}},	//   näku, dapk, mnę_,
  { {0xb715005a,0xa7fb006d,0x3eb800c2,0x00000000}},	//   ждащ, _baña, črtu_,
  { {0xa7fb006d,0x78ad62ab,0x69c8004d,0x00000000}},	// [cf30] _caña, riav, üder,
  { {0xa7fb006d,0x6c35007e,0x1efb0047,0x00000000}},	//   _daña, _افکا, טלמע,
  { {0xb87b0013,0x25b90021,0x291e007d,0x00000000}},	//   _chíc, جهاد_, štar_,
  { {0x14c80121,0x81c7008f,0x7d0462ac,0x00000000}},	//   бычи_, nzēš, _čisl,
  { {0x98b80529,0x083a0047,0x64bc005f,0x00000000}},	//   stră_, _דערל, učia,
  { {0x661e003e,0x161d0053,0x64bc0006,0x00000000}},	//   capk, _फ़िर_, rčia,
  { {0x64bc0acf,0x91e262ad,0xb495005e,0x00000000}},	//   sčia, моше, _дивљ,
  { {0x3f42007a,0x64bc62ae,0x765700ca,0x00000000}},	//   fðu_, lčin, lexy,
  { {0x3f420026,0x60c90173,0x81c7001c,0x00000000}},	//   gðu_, roem, dzēš,
  { {0x64bc09a0,0x0ea90121,0x3ce000e5,0x00000000}},	//   nčin, ркой_, _shiv_,
  { {0xa2c60161,0x22640080,0x98b80006,0x00000000}},	//   िवर्, řská_, ltrą_,
  { {0x25e10053,0x66d00137,0xceb80051,0x00000000}},	//   _करनी_, läkt, anę_,
  { {0x98b80006,0xe79c005b,0x00000000,0x00000000}},	//   ntrą_, düğü,   ,
  { {0xbebd008f,0x64bc274b,0xdddb009c,0x00000000}},	//   grūt, jčin, őződ,
  { {0xe81a0001,0xada505f7,0x443f007d,0x00000000}},	//   ицај_, _файл, _ocu_,
  { {0x64bc14d5,0x798e002b,0x00000000,0x00000000}},	//   ečin, rybw,   ,
  { {0x661e003e,0xc7260121,0x64bc00a8,0x00000000}},	// [cf40] tapk, юдай, fčin,
  { {0x443f62af,0xd62a0e82,0xf6260054,0x00000000}},	//   _acu_, роже_, ідео,
  { {0x661e06a7,0x201f0089,0x7e630783,0x00000000}},	//   rapk, kaui_, _manp,
  { {0x64bc082a,0xe73a0121,0x69de4056,0x00000000}},	//   ačin, _кем_, _izpe,
  { {0xceb80051,0xa6960002,0x64bc0a80,0x00000000}},	//   ynę_, _дрвј, bčin,
  { {0xb87b001b,0x236d0146,0xe5a61259,0x00000000}},	//   _thíc, _drej_, _диги,
  { {0xd1300021,0xca7b009f,0x90440044,0x00000000}},	//   رمة_, ינסט, كنغه,
  { {0x7e630179,0x228b00d1,0x661c62b0,0x00000000}},	//   _aanp, _søkt_, _herk,
  { {0x66d000fe,0x661c0276,0xdfda0062,0x00000000}},	//   säku, _kerk, шък_,
  { {0x3f42007a,0x6724024a,0x52a70be6,0x00000000}},	//   rðu_, isij, _двум_,
  { {0x64bc00eb,0x63a262b1,0x661c62b2,0x00000000}},	//   nčio, lzon, _merk,
  { {0xceb8091b,0x661c62b3,0x6724594b,0x00000000}},	//   snę_, _lerk, ksij,
  { {0x7d0d0080,0x81c7001c,0x63a256ce,0x00000000}},	//   _čase, rzēš, nzon,
  { {0x62881957,0x7c3a0078,0xccfa005e,0x00000000}},	//   _jodo, ėtra, _кћи_,
  { {0x2d83010a,0x67260031,0x88870002,0x00000000}},	//   øjet_, _avkj, оѓал,
  { {0x628862b4,0x4adb0042,0x672b009c,0x00000000}},	//   _lodo, _मीरव, ágjo,
  { {0x661c5f3e,0x63a20122,0x66d000fe,0x00000000}},	// [cf50] _berk, jzon, jäks,
  { {0x7bdf02dd,0x63a20045,0x6288003d,0x00000000}},	//   _izqu, dzon, _nodo,
  { {0x63a262b5,0x64bc0255,0x661c62b6,0x00000000}},	//   ezon, rčin, _derk,
  { {0xb4d50161,0x236d00c3,0x18350047,0x00000000}},	//   हते_, _prej_, _צאָל_,
  { {0x66d000c7,0x628862b7,0x9cd80063,0x00000000}},	//   täkt, _bodo, קודה_,
  { {0x628862b8,0xf6c80085,0x6262030b,0x00000000}},	//   _codo, _дыск_, евша,
  { {0x62880b61,0x63a2006d,0x64bc085a,0x00000000}},	//   _dodo, azon, očil,
  { {0x69c101f7,0x64bc004a,0xd49b005e,0x00000000}},	//   üley, nčil, _трг_,
  { {0x63a20045,0x4e790021,0x62884d5e,0x00000000}},	//   czon, محدد_, _fodo,
  { {0x479c0063,0x6605018f,0x645962b9,0x00000000}},	//   ייחס, nchk, lewi,
  { {0xfbc90063,0xdc6a06da,0x6459006f,0x00000000}},	//   _עת_, банд_, oewi,
  { {0x6288006f,0x6283074f,0x6459162d,0x00000000}},	//   _zodo, ljno, newi,
  { {0x7e63014f,0x7693005b,0x62831235,0x00000000}},	//   _tanp, _kıyı, ojno,
  { {0x2d830146,0x8e490021,0xa7fb006d,0x00000000}},	//   øjes_, _طلبك_, _baño,
  { {0x63a2051e,0x64590034,0xa7fb006d,0x00000000}},	//   zzon, kewi, _caño,
  { {0xa7fb006d,0xfc2b0080,0x66d000fe,0x00000000}},	//   _daño, íští_, yäks,
  { {0x661c4f41,0x672400fc,0x645962ba,0x00000000}},	// [cf60] _perk, usij, dewi,
  { {0x66d0024a,0xddc1000f,0x672420b4,0x00000000}},	//   väks, lelő, rsij,
  { {0x62881dd9,0xf9fb0063,0x661c62bb,0x00000000}},	//   _rodo, _להימ, _verk,
  { {0x661c3d82,0x6ba1005b,0x66d000fe,0x00000000}},	//   _werk, _özgü, täks,
  { {0x661c0e53,0x6e2100eb,0xddc100ea,0x00000000}},	//   _terk, kalb, ielő,
  { {0x63a262bc,0xf6550121,0x66d00072,0x00000000}},	//   rzon, _отсю, räks,
  { {0x66d0024a,0xb87b0139,0x32030021,0x00000000}},	//   säks, _mhín, رِيق,
  { {0x25e10053,0xc9530063,0x55bb0063,0x00000000}},	//   _करती_, גמה_, _המלו,
  { {0x62880747,0xd0070095,0xa87b0047,0x00000000}},	//   _todo, чење_, מאקר,
  { {0x6e2100eb,0x64bc004c,0x539b009a,0x00000000}},	//   galb, zčil, _הימו,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x2cbf0019,0xddc100ea,0xeb9f0093,0x00000000}},	//   õud_, gelő, dbør_,
  { {0x2d830146,0xa0c90021,0x6e21128d,0x00000000}},	//   øjer_, _بذلك_, balb,
  { {0xb87b00aa,0x64590051,0xa7fb0331,0x00000000}},	//   _chín, zewi, _paño,
  { {0x58d50002,0x64bc007d,0xa9c4066e,0x00000000}},	//   довт, ečim, естк,
  { {0x321e62bd,0x64bc2061,0xc8d90054,0x00000000}},	//   _lety_, učil, імає_,
  { {0xb9040053,0x3834000d,0x62830022,0x00000000}},	// [cf70] _पी_, энтр, yjno,
  { {0x6d480983,0xd6db066e,0x4bd8009e,0x00000000}},	//   otda, ёта_, _عبيد_,
  { {0x64bc00c3,0x6d4802e0,0xf905005d,0x00000000}},	//   mčij, ntda, _تأخی,
  { {0xc435007e,0x6d4800ca,0x660530e6,0x00000000}},	//   بکست, itda, schk,
  { {0x321e0c7f,0x291c62be,0x386962bf,0x00000000}},	//   _bety_, _ævar_, mdar_,
  { {0x38691b80,0xddc100ea,0xbb3c0047,0x00000000}},	//   ldar_, zelő, מעדי,
  { {0x8505007e,0x7af718b4,0x6e2162c0,0x00000000}},	//   _آورن, _mixt, valb,
  { {0x386962c1,0x1dd00053,0x628301e1,0x00000000}},	//   ndar_, _हड़त, sjno,
  { {0x53341001,0x64bc007d,0x6e2162c2,0x00000000}},	//   _петт, kčij, talb,
  { {0xdd1b027d,0x9ea90086,0x7c2d2bbc,0x00000000}},	//   _váže, івна_, _adar,
  { {0x442d0114,0x386900c2,0x6da50794,0x00000000}},	//   _kde_, kdar_, фина,
  { {0x442d0080,0xb87b0025,0x929d0051,0x00000000}},	//   _jde_, _shín, _bułg,
  { {0x7c2d0185,0x386962c3,0xcf240044,0x00000000}},	//   _ddar, ddar_, _كروي,
  { {0xb87b0027,0x7c2d0089,0xddc100ea,0x00000000}},	//   _bhío, _edar, selő,
  { {0xf2d200b5,0xa9670615,0xd9432046,0x00000000}},	//   דעם_, мира_, кери,
  { {0xb87b0025,0x7f4900cd,0x442d62c4,0x00000000}},	//   _dhío, oteq, _nde_,
  { {0x4b260088,0xd6d20032,0x290c003d,0x00000000}},	// [cf80] _ўмов, نقر_, ūda_,
  { {0xb87b0025,0x442d62c5,0x64b80053,0x00000000}},	//   _fhío, _ade_, ेक्श,
  { {0x69c0005b,0x68fe00a4,0xb9260021,0x00000000}},	//   ğmes, _uupd, _تفجي,
  { {0x69c0005b,0x99980022,0x2fc00014,0x00000000}},	//   şmes, parł_, _þigg_,
  { {0x442d001f,0xb87b0025,0x23271313,0x00000000}},	//   _dde_, _mhíl, дочи_,
  { {0x442d1a62,0xe29701fc,0x05560094,0x00000000}},	//   _ede_, мач_, _отбя,
  { {0x6d48004d,0x321e0f67,0x843a00de,0x00000000}},	//   xtda, _vety_, _وكسر_,
  { {0x442d017f,0xd0100021,0xe58b009a,0x00000000}},	//   _gde_, دلة_, _וָמָ,
  { {0xc2460095,0x2ef401a4,0x93432953,0x00000000}},	//   _онак, нзир, _инте,
  { {0x442d0080,0x6d483327,0x2486017f,0x00000000}},	//   _zde_, ttda, ljom_,
  { {0x2d980024,0x442d01b0,0xfe42007e,0x00000000}},	//   áre_, _yde_, _یکدی,
  { {0x7af716c0,0x2486017f,0x6d480d7d,0x00000000}},	//   _sixt, njom_, rtda,
  { {0x386902eb,0xfc3f0025,0x69da004d,0x00000000}},	//   vdar_, rgí_, üten,
  { {0xda7b013c,0xb87b0139,0x6298087d,0x00000000}},	//   цям_, _phío, nkvo,
  { {0xa2b10053,0x64bc00c2,0x629862c6,0x00000000}},	//   _अगस्, rčij, ikvo,
  { {0x7c2d14ed,0x386962c7,0x893400de,0x00000000}},	//   _udar, udar_, ضعفا,
  { {0x3869492e,0x9bf50054,0x98aa004c,0x00000000}},	// [cf90] rdar_, _язич, lubě_,
  { {0x76d50032,0xb87b0027,0x38690150,0x00000000}},	//   رياض, _thío, sdar_,
  { {0x4420000d,0x442d01f4,0x69c00075,0x00000000}},	//   кi_, _pde_, şmer,
  { {0x629800e8,0xb69b000c,0x2aad007d,0x00000000}},	//   ekvo, _atât, džbi_,
  { {0x68ed62c8,0x98b1003b,0x442d4e54,0x00000000}},	//   mmad, auză_, _vde_,
  { {0x91e51321,0x290130d2,0x21690065,0x00000000}},	//   ноле, _kuha_, зики_,
  { {0x2419000d,0x25a50137,0x68ed62c9,0x00000000}},	//   _новы_, _åll_, omad,
  { {0x442d0146,0x68ed005b,0x62981236,0x00000000}},	//   _ude_, nmad, akvo,
  { {0x29010455,0x68ed62ca,0x2d8a004d,0x00000000}},	//   _luha_, imad, äben_,
  { {0xb87b0025,0x8e740054,0x2901004c,0x00000000}},	//   _shíl, вуюч, _ouha_,
  { {0xa6e20026,0xdd2e004c,0x68ed4158,0x00000000}},	//   íðin, těše, kmad,
  { {0x859a014e,0x8027007e,0xb87b0139,0x00000000}},	//   פשרו, _آرام, _bhím,
  { {0x0c23000d,0x9e64007e,0x68ed011b,0x00000000}},	//   ымян, راین, dmad,
  { {0x60db0004,0x249f0268,0x2aad0066,0x00000000}},	//   llum, _llum_, oľby_,
  { {0xf3f90529,0x940a0053,0xdd03008f,0x00000000}},	//   _daţi_, हुँच_, ērēt,
  { {0x248d0186,0xd5b7008b,0x29011058,0x00000000}},	//   _noem_, _ứng_, _duha_,
  { {0x17c70086,0xe7aa0062,0xa6e6228d,0x00000000}},	// [cfa0] егти_, чвал_, ежал,
  { {0x7c261d2b,0xe5a62254,0x67365c2a,0x00000000}},	//   lakr, низи, rryj,
  { {0x60db00e3,0xe45a0076,0x7d0b003b,0x00000000}},	//   klum, зже_, _însă,
  { {0x44200013,0x24070818,0x7c2662cb,0x00000000}},	//   úi_, енци_, nakr,
  { {0x7cfe001c,0x9aa9005d,0x290162cc,0x00000000}},	//   _vīri, _ردیف_, _zuha_,
  { {0xbb3b0047,0x7d0d43c6,0x60db62cd,0x00000000}},	//   פעצי, _časn, elum,
  { {0x2ca00019,0x7c2662ce,0x62983816,0x00000000}},	//   _olid_, kakr, rkvo,
  { {0x6ee60014,0x60db62cf,0x629862d0,0x00000000}},	//   iðbe, glum, skvo,
  { {0x59d2016a,0x4426017f,0xb4be0053,0x00000000}},	//   _दुसर, mao_, ीकी_,
  { {0xddd80080,0x248d00ac,0x216a09c2,0x00000000}},	//   _zavř, _zoem_, _низи_,
  { {0x68ed0058,0x2fda005d,0x60db62d1,0x00000000}},	//   ymad, _کوشد_, blum,
  { {0x6442175d,0x442662d2,0x25a5004b,0x00000000}},	//   ngoi, nao_, _ülle_,
  { {0x4426008b,0x7ac705ce,0x29010605,0x00000000}},	//   iao_, есве, _suha_,
  { {0x442662d3,0xaa6409c8,0x3f820050,0x00000000}},	//   hao_, лтск, äkuu_,
  { {0x442662d4,0x68ed27da,0x2ca001e1,0x00000000}},	//   kao_, tmad, _flid_,
  { {0x4426017f,0x26c7222e,0x6d4f0022,0x00000000}},	//   jao_, čnom_, ńcac,
  { {0x4426017f,0x248d006f,0x68ed1a4e,0x00000000}},	// [cfb0] dao_, _roem_, rmad,
  { {0xb69b003b,0xe8e00013,0x68ed62d5,0x00000000}},	//   _atâr, _đục_, smad,
  { {0x248d1729,0x68ed005b,0xe5ab0259,0x00000000}},	//   _poem_, pmad, чњак_,
  { {0x44260117,0x78a462d6,0xf4844f5c,0x00000000}},	//   gao_, chiv, лучн,
  { {0xe28e000a,0x6f0201f4,0x69e3007d,0x00000000}},	//   аа_, _nuoc, šteć,
  { {0x6d585923,0x7c2662d7,0x6d5d008f,0x00000000}},	//   _opva, zakr, āsaz,
  { {0xa1560138,0x442610d2,0x10a5005a,0x00000000}},	//   вају_, bao_, кикн,
  { {0x442662d8,0x60db01a9,0xd1780085,0x00000000}},	//   cao_, ulum, эсіі_,
  { {0x60db62d9,0x6f020290,0xb7c8000c,0x00000000}},	//   rlum, _cuoc, miţâ,
  { {0x60db007a,0x7d09005e,0xa7fb0331,0x00000000}},	//   slum, мног_, _cañi,
  { {0x60db005b,0xa7fb006d,0x4df40376,0x00000000}},	//   plum, _dañi, ляют,
  { {0x6f02051e,0x6609005b,0x6fb2007e,0x00000000}},	//   _fuoc, _şekl, امیا,
  { {0x26c7017f,0xab631915,0x7c2662da,0x00000000}},	//   čnoj_, авял, rakr,
  { {0x4426017f,0x6e440021,0x7c2662db,0x00000000}},	//   zao_, _منهم, sakr,
  { {0x2d8a0146,0x442662dc,0x26d300ed,0x00000000}},	//   øbet_, yao_, doxo_,
  { {0x6e230146,0x2aad007d,0x26c1017d,0x00000000}},	//   _henb, džbu_, enho_,
  { {0x44260117,0x6e23006f,0x7d03470f,0x00000000}},	// [cfc0] vao_, _kenb, _huns,
  { {0x7c240359,0xb69b003b,0x6d480022,0x00000000}},	//   _heir, _stâr, łmań,
  { {0x9586005a,0x442662dd,0xf5030062,0x00000000}},	//   ълже, tao_, азхо,
  { {0xb4be0053,0x7d03025c,0xb4cc0053,0x00000000}},	//   ीके_, _muns, रके_,
  { {0x44260117,0x7c2462de,0x7d030ca7,0x00000000}},	//   rao_, _meir, _luns,
  { {0x44260117,0xe8e0001b,0x395a0150,0x00000000}},	//   sao_, _độc_, _kpps_,
  { {0xa6e2007a,0x4426017f,0x6f020290,0x00000000}},	//   íðun, pao_, _suoc,
  { {0x3ea500bd,0xf9930063,0xe0cf0021,0x00000000}},	//   ehlt_, שרה_, يزي_,
  { {0xf8b3014e,0x78a3000c,0x4424001c,0x00000000}},	//   ישה_, _înve, _iem_,
  { {0x38600034,0x33d5000d,0x442462df,0x00000000}},	//   heir_, _сіст, _hem_,
  { {0x442462e0,0x06970063,0x7c2462e1,0x00000000}},	//   _kem_, דדים_, _beir,
  { {0x442462e2,0x7c245eef,0x752300dd,0x00000000}},	//   _jem_, _ceir, ânzi,
  { {0x7c245db0,0xd0070dd5,0x395a62e3,0x00000000}},	//   _deir, _рече_, _apps_,
  { {0x6e2300b9,0x0f570063,0x7d0362e4,0x00000000}},	//   _genb, _סיום_, _funs,
  { {0x7c2462e5,0xceb80051,0x69d80093,0x00000000}},	//   _feir, mię_, _øvel,
  { {0x442462e6,0x7c2419c5,0xceb80022,0x00000000}},	//   _nem_, _geir, lię_,
  { {0x64bc00eb,0x5884000d,0x7cfe008f,0x00000000}},	// [cfd0] nčiu, шыра, _vīru,
  { {0xd6280138,0x64bc00eb,0xceb80045,0x00000000}},	//   кође_, ičiu, nię_,
  { {0x442403d9,0xa9c462e7,0xa9230066,0x00000000}},	//   _bem_, _всяк, ýžde,
  { {0x6ba8005b,0x442462e8,0xd4e40086,0x00000000}},	//   _örgü, _cem_, аючи,
  { {0x44243495,0x83640021,0xa2950086,0x00000000}},	//   _dem_, لدول, ладі,
  { {0x2127007e,0x442441d6,0xdce4004c,0x00000000}},	//   نيتی_, _eem_, _brně,
  { {0x442428d7,0x91280021,0x6e2300a5,0x00000000}},	//   _fem_, نسيق_, _renb,
  { {0x442462e9,0xddc3003b,0xa4d50054,0x00000000}},	//   _gem_, _lanţ, _собі,
  { {0x672d048e,0x68fd36f0,0x7d0362ea,0x00000000}},	//   nsaj, _misd, _suns,
  { {0x7645001f,0x7c2462eb,0xceb80051,0x00000000}},	//   nghy, _seir, gię_,
  { {0x99830080,0x7c2446b8,0xc11502d8,0x00000000}},	//   dajů_, _peir, _смеј,
  { {0x442400aa,0x98b8001c,0x672d0072,0x00000000}},	//   _xem_, kurā_, ksaj,
  { {0x386000cd,0x7d0300bd,0x2d8a00b9,0x00000000}},	//   veir_, _wuns, øber_,
  { {0x7c24096c,0x64bc00a8,0xddc300dd,0x00000000}},	//   _weir, lčit, _canţ,
  { {0x68fd006f,0x3860001f,0x672d1432,0x00000000}},	//   _bisd, teir_, esaj,
  { {0x6d4118bd,0x64bc0024,0x186702a9,0x00000000}},	//   mula, nčit, ласи_,
  { {0x6d4162ec,0x46ea1225,0x44242357,0x00000000}},	// [cfe0] lula, едан_, _rem_,
  { {0x644962ed,0xcc8a007e,0x4424432c,0x00000000}},	//   _acei, _آنکه_, _sem_,
  { {0x44241c62,0x6723007d,0x6d415e17,0x00000000}},	//   _pem_, ćnja, nula,
  { {0x94260002,0x29181bb7,0x7cfe2886,0x00000000}},	//   умде, mpra_, _jūra,
  { {0x6d4162ee,0x44244065,0x7e610527,0x00000000}},	//   hula, _vem_, kelp,
  { {0x7e610031,0x29180290,0x644962ef,0x00000000}},	//   jelp, opra_, _ecei,
  { {0x442462f0,0xc5f5005a,0xa494007e,0x00000000}},	//   _tem_, _вятъ, _پیشت,
  { {0x64490027,0x7afe62f1,0xceb80022,0x00000000}},	//   _gcei, _lipt, wię_,
  { {0x7413007e,0x6e280089,0xea000013,0x00000000}},	//   _طولا, tadb, _giầu_,
  { {0x6e9806b4,0x64bc0078,0x6d54005e,0x00000000}},	//   твор_, rčiu, акођ,
  { {0x6e2800c3,0x64bc0006,0xceb80051,0x00000000}},	//   radb, sčiu, rię_,
  { {0xbd87006a,0x61e5004d,0x85f70aeb,0x00000000}},	//   چنین_, ühle, טציע_,
  { {0x68fd0089,0xceb80051,0x7e6131b3,0x00000000}},	//   _risd, pię_, belp,
  { {0x7afe003e,0x68fd0150,0xedb5007e,0x00000000}},	//   _cipt, _sisd, اجیک,
  { {0xc27b0047,0x7afe62f2,0x69de62f3,0x00000000}},	//   ערלי, _dipt, _cype,
  { {0x69de00d1,0x6d4f003b,0x98b8008f,0x00000000}},	//   _dype, ăcat, turā_,
  { {0x2918013d,0x68fd62f4,0x672d0050,0x00000000}},	// [cff0] apra_, _visd, usaj,
  { {0x68fd0034,0xba55018e,0x644962f5,0x00000000}},	//   _wisd, _твој, _scei,
  { {0x66d000fe,0x76454303,0x68fd62f6,0x00000000}},	//   näky, rghy, _tisd,
  { {0x4867011c,0xc8671c9d,0xddc300a8,0x00000000}},	//   _съоб, _стои, _janš,
  { {0xa7fb006d,0x69de1564,0x6d4162f7,0x00000000}},	//   _pañu, _zype, zula,
  { {0x6d41005b,0xd687005e,0x3318007e,0x00000000}},	//   yula, _сумп, ازند_,
  { {0x21a50086,0xf3c9005d,0x0085060d,0x00000000}},	//   рийм, ربچه_, илко,
  { {0x27e60051,0x98b8003b,0x7523003b,0x00000000}},	//   żone_, mură_, ânzu,
  { {0x2d980831,0x6d4123a5,0x64bc0240,0x00000000}},	//   øren_, wula, rčit,
  { {0xcdf50055,0x6d414197,0x7c290046,0x00000000}},	//   ичны, tula, ðern,
  { {0x628154e8,0x6d411a61,0x7e61004b,0x00000000}},	//   _inlo, uula, relp,
  { {0xeb9a36cc,0x6d4162f8,0x7e6102d2,0x00000000}},	//   вим_, rula, selp,
  { {0x6d4162f9,0xddc300c2,0x8e850062,0x00000000}},	//   sula, _danš, _вгле,
  { {0xdaba000d,0x6d4162fa,0xee390f63,0x00000000}},	//   тымі_, pula, _рнк_,
  { {0x48b600a0,0x7bcd0c77,0x610300ea,0x00000000}},	//   ащат, _exau, _főle,
  { {0x98b8003b,0x291801a8,0x6cd30021,0x00000000}},	//   dură_, rpra_, _وقوا,

  { {0x69de0051,0x186727b5,0x291862fb,0x00000000}},	// [d000] _wype, шати_, spra_,
  { {0x6111001c,0x7cff0023,0x69de62fc,0x00000000}},	//   _zāle, _jūrn, _type,
  { {0x98b8000c,0x2905004c,0xa5070062,0x00000000}},	//   gură_, ílat_, аеха_,
  { {0xed5600b5,0xc6890063,0x6a7c0137,0x00000000}},	//   יבער_, וא_, _fåfä,
  { {0x78a3003b,0xdc1d0023,0x8c29009a,0x00000000}},	//   _înva, _zņēm, רֵעֵ,
  { {0x38720093,0x62d70085,0xa2b30054,0x00000000}},	//   ldyr_, аміў_, обіч,
  { {0xc448006a,0xe2970fe2,0x1219000d,0x00000000}},	//   _میان_, рај_, уючы_,
  { {0xea00008b,0x62810e7c,0x0443006e,0x00000000}},	//   _giấu_, _enlo, _месн,
  { {0x660901f7,0x7bc20023,0x03a30131,0x00000000}},	//   _şeki, _žoun, _дито,
  { {0xc6b6009d,0x00000000,0x00000000,0x00000000}},	//   יהִי_,   ,   ,
  { {0xa0a60055,0x1ef70021,0x6abc0014,0x00000000}},	//   _кажд, جعية_, dirf,
  { {0x6abc002b,0xd00f014d,0x41bb009a,0x00000000}},	//   eirf, _قلم_, _בצבע,
  { {0xdfd2006a,0x9be70086,0x66d00072,0x00000000}},	//   _بيش_, рінк, säky,
  { {0x799c001f,0x8f9b0063,0x7c36002b,0x00000000}},	//   fyrw, _בידי, _edyr,
  { {0x9e65007e,0x6103013d,0xb9250044,0x00000000}},	//   _دانن, _tőle, إفري,
  { {0x7bc80058,0x5dfb009a,0x48a862fd,0x00000000}},	//   ğdur, _בפונ, атум_,
  { {0x28f80076,0x7d0d00c2,0x17980121,0x00000000}},	// [d010] реть_, _časi, авты_,
  { {0x98b80529,0xc7c40086,0x6b9d001f,0x00000000}},	//   tură_, істи, mysg,
  { {0x7cff0006,0x59670062,0x9539005e,0x00000000}},	//   _jūro, _тъпа, узет_,
  { {0xe3b3007e,0xe43c004c,0xb87b0046,0x00000000}},	//   يرش_, bříč, _skíf,
  { {0x6b9d0185,0x98b8000c,0xb87b0025,0x00000000}},	//   nysg, sură_, _dhít,
  { {0x98b8003b,0xdd3900dd,0xe6950044,0x00000000}},	//   pură_, năţe, _الآد,
  { {0x6b9d002b,0xba38009d,0x00000000,0x00000000}},	//   hysg, בטוח_,   ,
  { {0xe4a702a9,0x26c70114,0x929d0022,0x00000000}},	//   _трго, čnou_, _tuło,
  { {0x60060121,0xd3db0044,0xc4f800de,0x00000000}},	//   щным_, _شبرا_, _ضعفا_,
  { {0x6b9d001f,0x91fc001c,0x628100e5,0x00000000}},	//   dysg, _paāt, _unlo,
  { {0xed59005e,0x69c00058,0x11440044,0x00000000}},	//   ћом_, şmez, _وَكُ,
  { {0x6b9d0185,0x50f5005e,0x6abc0616,0x00000000}},	//   fysg, _узет, wirf,
  { {0x6abc007a,0x38720093,0xbf67007e,0x00000000}},	//   tirf, vdyr_, _خداو,
  { {0x61e100fe,0x6f1b008b,0xdd3900dd,0x00000000}},	//   _kyll, mpuc, găţe,
  { {0x395e0268,0x6abc007a,0x49990086,0x00000000}},	//   ïts_, rirf, аття_,
  { {0xd9430635,0xa928027d,0x4806000d,0x00000000}},	//   џети, _nižš, спав,
  { {0x6abc05e7,0x29050014,0x8c1b009a,0x00000000}},	// [d020] pirf, ílar_, _גופי,
  { {0x3872000e,0xdd39003b,0xe7ee0042,0x00000000}},	//   sdyr_, căţe, चेगा_,
  { {0x96f90085,0x8afb009a,0x94060044,0x00000000}},	//   рэту_, _תהיי, مواه,
  { {0xb87b0025,0x0446060c,0xe43c004c,0x00000000}},	//   _dhís, седн, příč,
  { {0x68e4005b,0x98b8001c,0xe29a4f9b,0x00000000}},	//   mlid, strē_, лад_,
  { {0x29020026,0x68e462fe,0x98a30022,0x00000000}},	//   _hika_, llid, rsją_,
  { {0x61e1001f,0xddda0022,0x68e462ff,0x00000000}},	//   _cyll, zetł, olid,
  { {0x29020397,0xbebd001c,0x50666300,0x00000000}},	//   _jika_, zsūt, стка,
  { {0xa0670001,0x68e46301,0x69c00058,0x00000000}},	//   сања_, ilid, ğmey,
  { {0x29026302,0x69c0005b,0x61e14985,0x00000000}},	//   _lika_, şmey, _fyll,
  { {0xac990021,0x61e16303,0xb87b0139,0x00000000}},	//   لندا_, _gyll, _mhír,
  { {0xb5fb0047,0x6b9d002b,0x29026304,0x00000000}},	//   טליכ, tysg, _nika_,
  { {0xdd39000c,0x9e3405fb,0xbebd008f,0x00000000}},	//   tăţe, _делч, tsūt,
  { {0x290200fe,0xcef60d34,0x7ac7007f,0x00000000}},	//   _aika_, _учењ, ссме,
  { {0xbebd001c,0xdd39003b,0x6b9d002b,0x00000000}},	//   rsūt, răţe, sysg,
  { {0x0855000d,0x3ebe6305,0x25ef0042,0x00000000}},	//   ўваю, litt_, _अरबी_,
  { {0xe894015a,0x656e0139,0x2d9e6306,0x00000000}},	// [d030] чать, _asbh, lyte_,
  { {0x3ebe0f37,0x8f9b0063,0x68e46307,0x00000000}},	//   nitt_, אימי, alid,
  { {0xb87b0025,0x2002085a,0x78a3003b,0x00000000}},	//   _dhír, žkih_, _învo,
  { {0x44290026,0x27e60051,0x98b80022,0x00000000}},	//   úa_, żona_, turą_,
  { {0x6eef0146,0x9345000d,0x2ca902f7,0x00000000}},	//   løbe, інке, _mlad_,
  { {0x236d00c2,0x26da32fe,0x78ad6308,0x00000000}},	//   _vsej_, copo_, lhav,
  { {0x3ebe0031,0xd9f90161,0xa2d20021,0x00000000}},	//   ditt_, ंधित_, بيوت,
  { {0x7f590079,0x78ad6309,0xbf590054,0x00000000}},	//   ајот_, nhav, арої_,
  { {0x7d0a00bd,0x3ebe0026,0xb4d50053,0x00000000}},	//   _aufs, fitt_, सकी_,
  { {0x3ebe0031,0x442f02e0,0x6eef01e1,0x00000000}},	//   gitt_, lag_, købe,
  { {0x2ca91cae,0xfd44000d,0x644b630a,0x00000000}},	//   _blad_, пэўн, oggi,
  { {0x442f630b,0x644b0645,0x6f1b292c,0x00000000}},	//   nag_, nggi, ppuc,
  { {0x7cd20418,0xee2e2d66,0x644b10da,0x00000000}},	//   vārd, _он_, iggi,
  { {0x60c9630c,0xe8e0008b,0x2d9e630d,0x00000000}},	//   lnem, _đốc_, byte_,
  { {0xc8960002,0x442f00a4,0x2ca900b9,0x00000000}},	//   орањ, kag_, _flad_,
  { {0x60c9630e,0x442f001c,0x6f033975,0x00000000}},	//   nnem, jag_, _hinc,
  { {0x3f8d0268,0x60c9135d,0x2902630f,0x00000000}},	// [d040] nxeu_, inem, _vika_,
  { {0x290200bb,0x644b6310,0x6d412523,0x00000000}},	//   _wika_, eggi, orla,
  { {0x2902003d,0xa2d80053,0x7d046311,0x00000000}},	//   _tika_, यवस्, _kiis,
  { {0x26da08f2,0x78ad5cd7,0x60c96312,0x00000000}},	//   sopo_, chav, jnem,
  { {0x60db007d,0x78a4004b,0x60c96313,0x00000000}},	//   doum, mkiv, dnem,
  { {0x6f03000f,0x644b051e,0x7d040ff2,0x00000000}},	//   _ninc, aggi, _liis,
  { {0xeb9f0146,0x442f0465,0x60c9006f,0x00000000}},	//   ncør_, bag_, fnem,
  { {0x2240005b,0xc0340001,0x60c96314,0x00000000}},	//   şik_, чниј, gnem,
  { {0x78a4051e,0x6f031472,0x6d411aa6,0x00000000}},	//   ikiv, _binc, erla,
  { {0xbdb40141,0x6f03095b,0x60c96315,0x00000000}},	//   збој, _cinc, anem,
  { {0x78a4003a,0x6f031c8a,0x60c90384,0x00000000}},	//   kkiv, _dinc, bnem,
  { {0x3ebe2579,0x7d0d36c5,0x2d9e0e59,0x00000000}},	//   sitt_, _čast, ryte_,
  { {0xb4fb07e9,0x6f033736,0xfe6f007e,0x00000000}},	//   ילטר, _finc, ردی_,
  { {0x49a7000a,0x2ca9001f,0x442f006f,0x00000000}},	//   ојба, _wlad_, zag_,
  { {0x442f00bb,0x644b007a,0x78ad1c40,0x00000000}},	//   yag_, yggi, thav,
  { {0x6d48053b,0xa3aa0053,0x929d0051,0x00000000}},	//   muda, खना_, _pułk,
  { {0xab280001,0x6d4821af,0x78ad2cb0,0x00000000}},	// [d050] _доња_, luda, rhav,
  { {0x442f00bb,0xc987005a,0x7c2d1a74,0x00000000}},	//   wag_, _думи, _hear,
  { {0x78ad07e6,0x7c2d281a,0x442f6316,0x00000000}},	//   phav, _kear, tag_,
  { {0xb4d50053,0x6d486317,0x442f002b,0x00000000}},	//   सके_, iuda, uag_,
  { {0xdfc60032,0x38690016,0x60c00072,0x00000000}},	//   _أي_, mear_, dimm,
  { {0x442f6318,0x7c2d6319,0x6d480014,0x00000000}},	//   sag_, _lear, kuda,
  { {0x442f0273,0xd554005a,0x6d48631a,0x00000000}},	//   pag_, _окръ, juda,
  { {0x7c2d057a,0x6f0312e8,0x6d48631b,0x00000000}},	//   _near, _sinc, duda,
  { {0xddc102f4,0x7d04021e,0xea000013,0x00000000}},	//   telů, _riis, _phẫu_,
  { {0x0ea90055,0x7d042c84,0xfe420086,0x00000000}},	//   ской_, _siis, нньо,
  { {0x7c2d0359,0x7d040ff2,0x60c93386,0x00000000}},	//   _bear, _piis, pnem,
  { {0x7c2d631c,0x6d41631d,0xdbd70072,0x00000000}},	//   _cear, rrla, kääm,
  { {0x7c2d0027,0x442d0179,0x78a40019,0x00000000}},	//   _dear, _mee_, vkiv,
  { {0x6d48003e,0x78bd0014,0x442d631e,0x00000000}},	//   buda, _amsv, _lee_,
  { {0x38690025,0xea00001b,0x7c2d057a,0x00000000}},	//   fear_, _khẩu_, _fear,
  { {0x442d0162,0x6d3a0063,0x2bf6000d,0x00000000}},	//   _nee_, _התקנ, _няпр,
  { {0x68430088,0x7cd2001c,0xb6a60121,0x00000000}},	// [d060] энта, pārb, пиал,
  { {0x6b7b00b5,0x27e60051,0x60c03024,0x00000000}},	//   _פרינ, żono_, zimm,
  { {0x7c2d0037,0x6a9b014e,0x186a000a,0x00000000}},	//   _year, _השינ, _лани_,
  { {0x7e680051,0x442d631f,0x1d160047,0x00000000}},	//   zedp, _cee_, לקער_,
  { {0x03a30001,0x3958001c,0x60c00072,0x00000000}},	//   ницо, ltrs_, vimm,
  { {0x3f8000eb,0x6d480696,0xcb130063,0x00000000}},	//   _šiuo_, yuda, עלו_,
  { {0x3958001c,0x60c06320,0x442d6321,0x00000000}},	//   ntrs_, timm, _fee_,
  { {0x442d021f,0x6d486322,0x25ae005b,0x00000000}},	//   _gee_, vuda, ıklı_,
  { {0x60c000fe,0x7c2d6323,0x2327186b,0x00000000}},	//   rimm, _rear, _ноти_,
  { {0x60c0024a,0x442d0122,0x7b0b001c,0x00000000}},	//   simm, _zee_, _kļuv,
  { {0x628806b8,0x7e6803f5,0x6d480019,0x00000000}},	//   _indo, redp, uuda,
  { {0x7cff00eb,0x0cab026b,0x629a0114,0x00000000}},	//   _kūri, стои_, _hoto,
  { {0x63a20465,0xfb87000d,0x6d482c8d,0x00000000}},	//   nyon, чынн, suda,
  { {0x7c2d0034,0x63a200a4,0x7cff0078,0x00000000}},	//   _wear, iyon, _mūri,
  { {0x38691b11,0x7c2d057a,0x629a6324,0x00000000}},	//   tear_, _tear, _moto,
  { {0xe8940088,0x6abe0199,0x25e00053,0x00000000}},	//   нась, _empf, _कड़ी_,
  { {0x62880009,0xf1bf0024,0x4c3c0063,0x00000000}},	// [d070] _ondo, čšia_, _התחב,
  { {0x442d010e,0xcb140047,0x38690460,0x00000000}},	//   _see_, _אלץ_, sear_,
  { {0x38690037,0xdbd7024a,0x54550002,0x00000000}},	//   pear_, sääm, двет,
  { {0x62886325,0x7cff0078,0xdbd70072,0x00000000}},	//   _ando, _būri, pääm,
  { {0x69d802ab,0x442d6326,0x629a6327,0x00000000}},	//   _øver, _vee_, _boto,
  { {0x629a6328,0x442d6329,0xfc3f024b,0x00000000}},	//   _coto, _wee_, chív_,
  { {0x63a2002c,0x24190088,0x442d632a,0x00000000}},	//   ayon, _мовы_, _tee_,
  { {0x6aba0053,0x63a200a4,0x6288632b,0x00000000}},	//   _उग्र, byon, _endo,
  { {0x7ead021a,0x629a632c,0x2d98632d,0x00000000}},	//   _núpc, _foto, ären_,
  { {0xddc82b27,0x629a31a9,0x6da529c2,0x00000000}},	//   cedū, _goto, диоа,
  { {0x8c460795,0x5184005e,0x2a6a013d,0x00000000}},	//   мене, _пуца, vebb_,
  { {0x4c830086,0xe3a7007e,0xe45f004b,0x00000000}},	//   влюв, نر_, _ööd_,
  { {0x4e950021,0xbbc80042,0x2a6a013d,0x00000000}},	//   _يشتر, रपेक, tebb_,
  { {0x7d0e0139,0xddc5438c,0x394a00e5,0x00000000}},	//   úisí, _обли, tubs_,
  { {0x09e30ad9,0x63a2005b,0xdce90058,0x00000000}},	//   ворн, zyon, aydı,
  { {0x2a6a000f,0xbebd0078,0x394a3996,0x00000000}},	//   sebb_, spūd, rubs_,
  { {0xdc8b0063,0x394a632e,0x3958632f,0x00000000}},	// [d080] _וְיָ, subs_, strs_,
  { {0x290c1088,0x63a20035,0x44380022,0x00000000}},	//   ídas_, vyon, _śr_,
  { {0xd8260376,0x629a1ce0,0x7cff0078,0x00000000}},	//   _одни, _roto, _sūri,
  { {0x63a200a4,0xcd960063,0x629a00d4,0x00000000}},	//   tyon, ודעת_, _soto,
  { {0x41c30161,0xe3b20021,0xfe780078,0x00000000}},	//   _वेबस, خرا_, ydį_,
  { {0x63a26330,0x7cf61b62,0x00000000,0x00000000}},	//   ryon, lárd,   ,
  { {0x629a04a6,0x6603000d,0x63a232a4,0x00000000}},	//   _voto, _апра, syon,
  { {0x1f740062,0x7cff2c46,0xc95303c3,0x00000000}},	//   елия, _tūri, דמה_,
  { {0x44266331,0x93460086,0x629a6332,0x00000000}},	//   mbo_, _інже, _toto,
  { {0x628800f6,0x7c260917,0x99980078,0x00000000}},	//   _undo, ebkr, ngrų_,
  { {0x2f12001f,0x1d34000d,0xfe780078,0x00000000}},	//   _wâg_, эння, rdį_,
  { {0x44266333,0x7cd2008f,0x4fc61857,0x00000000}},	//   nbo_, tāra, _осла,
  { {0xd366006a,0x9be40086,0x78a3000c,0x00000000}},	//   ده_, вірк, _învi,
  { {0x6eef00b9,0xe7e20053,0xc3330063,0x00000000}},	//   løbn, _खड़ा_, כוש_,
  { {0x442600bb,0x59c50044,0xe8010042,0x00000000}},	//   kbo_, ريرك, लेना_,
  { {0x2d5803b2,0x7ead0139,0x7cf6013d,0x00000000}},	//   mée_, _iúpa, várg,
  { {0x44260198,0x2d5803b2,0x2ca40137,0x00000000}},	// [d090] dbo_, lée_, ömde_,
  { {0x442602f4,0x6d5a5581,0x7c3b0026,0x00000000}},	//   ebo_, otta, ðurf,
  { {0x2d5803b2,0x7ea40268,0x7ae5014f,0x00000000}},	//   née_, _còpi, _ikht,
  { {0x6d5a024a,0x7cf60046,0xf9fa009a,0x00000000}},	//   itta, rárg, _מהתמ,
  { {0x2d580003,0x62651578,0xf8b6009a,0x00000000}},	//   hée_, евла, _נפשי_,
  { {0x7e7800c2,0x44266334,0x6d5a08a9,0x00000000}},	//   _navp, abo_, ktta,
  { {0x442634bb,0x38a7004b,0x61e8002b,0x00000000}},	//   bbo_, _nõrk_, _cydl,
  { {0x2d580164,0x2aad01d1,0x7fca0082,0x00000000}},	//   dée_, ržby_, ापूँ,
  { {0x41df0053,0x6d5a6335,0x443f6336,0x00000000}},	//   _पुरस, etta, _idu_,
  { {0xf1a70156,0x9ea90054,0x2d58006c,0x00000000}},	//   _орен, ївна_, fée_,
  { {0x6cc60088,0x2d580164,0x6d5a00b9,0x00000000}},	//   ейна, gée_, gtta,
  { {0x7ae5113c,0xa0a4005e,0x7fd5000d,0x00000000}},	//   _akht, _ишчл, _пілі,
  { {0x76550051,0x6d5a6337,0x4b550062,0x00000000}},	//   _oczy, atta, кърт,
  { {0x6ee60026,0x2d580003,0x442600c2,0x00000000}},	//   fðbu, bée_, zbo_,
  { {0x2d580164,0x2d9801f2,0x7ead0139,0x00000000}},	//   cée_, øret_, _gúpa,
  { {0x291e003d,0x443f2883,0xddc1008f,0x00000000}},	//   īta_, _ndu_, celš,
  { {0x7cd2001c,0x2b460139,0x442600c2,0x00000000}},	// [d0a0] lāro, _íoc_, vbo_,
  { {0xfc3f0025,0x443f6338,0xddc3004a,0x00000000}},	//   bhís_, _adu_, _manž,
  { {0x3abb0063,0xca570047,0x546a0062,0x00000000}},	//   _זמינ, _אייז_, заем_,
  { {0x6b842e50,0x443f6339,0x4426633a,0x00000000}},	//   _krig, _cdu_, ubo_,
  { {0x81bc001c,0x443f001f,0x4426633b,0x00000000}},	//   _neēr, _ddu_, rbo_,
  { {0x6d5a02eb,0x2d580164,0x7ea400cd,0x00000000}},	//   ytta, yée_, _tòpi,
  { {0x04460086,0x2d580003,0xa1940062,0x00000000}},	//   _певн, xée_, тайч,
  { {0x2d5803b2,0x0f260086,0xea000013,0x00000000}},	//   vée_, ньом, _nhậu_,
  { {0x68e30268,0x3f820114,0xa346007e,0x00000000}},	//   _índe, íku_, _سپاه,
  { {0x2d580164,0x61e8633c,0x6d5a0f49,0x00000000}},	//   tée_, _tydl, ttta,
  { {0x6d5a024a,0xa00a0021,0x6b84633d,0x00000000}},	//   utta, _فقال_, _arig,
  { {0x2d5803b2,0xac190086,0x61e4005b,0x00000000}},	//   rée_, ьому_, ğild,
  { {0x2d5803b2,0xbea6000d,0x7b642c99,0x00000000}},	//   sée_, _падк, лтре,
  { {0x2d9802ab,0x2d580164,0x6b84001f,0x00000000}},	//   øres_, pée_, _drig,
  { {0x62980122,0x644006ce,0x6b844851,0x00000000}},	//   ijvo, _odmi, _erig,
  { {0x6b84633e,0xed570063,0x61e5004d,0x00000000}},	//   _frig, _נבחר_, ühli,
  { {0xfc64005a,0x6b84633f,0xf773007e,0x00000000}},	// [d0b0] _същн, _grig, داز_,
  { {0x6d486340,0x38600014,0x6440275b,0x00000000}},	//   orda, afir_, _admi,
  { {0x15a8005a,0x7cf66341,0x45180054,0x00000000}},	//   нъци_, sáre, еція_,
  { {0x6b840331,0x7cf60331,0x85040021,0x00000000}},	//   _yrig, páre, هولن,
  { {0x889a0132,0xc886004d,0x66180058,0x00000000}},	//   _חברי, ößen_, çakç,
  { {0x76550051,0x68ed6342,0xd6e20051,0x00000000}},	//   _uczy, llad, _całą_,
  { {0x68ed0027,0x823403eb,0x96f80121,0x00000000}},	//   olad, ارها, _черт_,
  { {0x6111008f,0x68ed6343,0xb7f50042,0x00000000}},	//   _jāli, nlad, _आराम_,
  { {0x290b343e,0x99910080,0x6d48188b,0x00000000}},	//   _mica_, kazů_, erda,
  { {0x290b6344,0x7ec60003,0x38b50f1b,0x00000000}},	//   _lica_, _répè, _hård_,
  { {0x38600026,0x68ed1ee9,0x4d141224,0x00000000}},	//   yfir_, klad, льят,
  { {0x68ed00b9,0x6b846345,0x7cf6004c,0x00000000}},	//   jlad, _prig, dárc,
  { {0xeb970432,0x2d980dfb,0x6d486346,0x00000000}},	//   вия_, ører_, arda,
  { {0x61e401f7,0xc3320063,0xf772005d,0x00000000}},	//   şile, שום_, یاء_,
  { {0x68ed6347,0x6cda00a0,0x6b84327f,0x00000000}},	//   flad, _офис_, _wrig,
  { {0x7a3f005b,0x6b846348,0x39450014,0x00000000}},	//   _açtı, _trig, álsa_,
  { {0x290b4a02,0xd70a000d,0x6b8401b0,0x00000000}},	// [d0c0] _dica_, днае_, _urig,
  { {0x248d00cd,0x68ed586d,0x38600949,0x00000000}},	//   _anem_, alad, sfir_,
  { {0x200f051e,0x290b0016,0x68ed6349,0x00000000}},	//   _oggi_, _fica_, blad,
  { {0x6724634a,0x25d9007e,0x68ed634b,0x00000000}},	//   ppij, رهنگ_, clad,
  { {0x64a30001,0x68e400fe,0xa803005b,0x00000000}},	//   јача, moid, şırs,
  { {0xe7370138,0x248d00c3,0x290000fe,0x00000000}},	//   _јер_, _enem_, lmia_,
  { {0x244a0021,0x2ab4004d,0x2167005e,0x00000000}},	//   _يجري_, _gäbe_, вији_,
  { {0x2ca00025,0x68e4634c,0x38b50807,0x00000000}},	//   _noid_, noid, _gård_,
  { {0xa0670138,0x73060088,0x290000fe,0x00000000}},	//   тања_, _апаз, imia_,
  { {0x3c3200aa,0x68e40019,0x68ed005b,0x00000000}},	//   _được_, hoid, zlad,
  { {0x68e4634d,0x6d48006f,0x7cd2008f,0x00000000}},	//   koid, urda, pārl,
  { {0x68e400fe,0x38b50093,0x9e03000d,0x00000000}},	//   joid, _kåre_, шчыл,
  { {0xe0b700b5,0x99910080,0x290b30ea,0x00000000}},	//   _בלאט_, tazů_, _rica_,
  { {0x68ed001f,0x290b01f4,0x7c3b0014,0x00000000}},	//   wlad, _sica_, ðurb,
  { {0xeef7014e,0xada300d7,0xda340121,0x00000000}},	//   _שמור_, _вајл, ресы,
  { {0x6d5d003b,0x71d70047,0x68e4634e,0x00000000}},	//   ăsat, דולד_, goid,
  { {0x57f52254,0x68ed634f,0xd7e70054,0x00000000}},	// [d0d0] упат, rlad, тіво,
  { {0x7d0d0228,0xd51a001b,0x68ed6350,0x00000000}},	//   _hias, _bằn, slad,
  { {0xceb300b5,0x7d0d0009,0x7cf60d5d,0x00000000}},	//   סיע_, _kias, lára,
  { {0x78b600eb,0x2419026c,0x68e46351,0x00000000}},	//   chyv, ходы_, coid,
  { {0x7d0d0045,0x38b50137,0xe3b0002a,0x00000000}},	//   _mias, _vård_, يره_,
  { {0x7ead0025,0x13080086,0x78ad6352,0x00000000}},	//   _cúpl, вній_, lkav,
  { {0xe534026c,0x7ead0331,0x1a9c0041,0x00000000}},	//   _весь, _dúpl, ויגע,
  { {0xaf990062,0x248d00be,0x22490058,0x00000000}},	//   етох_, _unem_, şak_,
  { {0xf1bf0080,0x7cf600ea,0x78ad0072,0x00000000}},	//   _řád_, jára, ikav,
  { {0x63a4024a,0xe3b0007e,0xdb24013d,0x00000000}},	//   äine, _برف_, örít,
  { {0x3cca071a,0x31580021,0x78ad6353,0x00000000}},	//   елно_, _لجنة_, kkav,
  { {0xa03900b5,0x7d0d6354,0x61e5004d,0x00000000}},	//   _װײַז, _cias, ühlu,
  { {0x68e4175d,0x7d0d3ce4,0x6ee60014,0x00000000}},	//   void, _dias, rðbr,
  { {0xd51a0013,0x9af60021,0x60c96355,0x00000000}},	//   _lắn, اكست, liem,
  { {0x3916007e,0x1a66007e,0x60c9003b,0x00000000}},	//   اورز, نیکی_, oiem,
  { {0xd51a001b,0x60c96356,0x4c360085,0x00000000}},	//   _rằn, niem, _сэкт,
  { {0x9835000d,0x29006357,0x38cb005d,0x00000000}},	// [d0e0] рэсі, rmia_, رافی_,
  { {0xd7020088,0x7c360026,0x78b60072,0x00000000}},	//   пiса, _heyr, shyv,
  { {0x7c36007a,0xa9a604f2,0xda5b089e,0x00000000}},	//   _keyr, _синд, _אכיל,
  { {0x7ead1358,0x60c91d81,0x78ad21fd,0x00000000}},	//   _súpl, jiem, ckav,
  { {0x13940086,0xebd60063,0x82a66358,0x00000000}},	//   рилю, נֵ֣י_, ладж,
  { {0x38b5076c,0x2d876359,0x261a0042,0x00000000}},	//   _våre_, _orne_, मुखी_,
  { {0x60c9004c,0x72290054,0x2ee5635a,0x00000000}},	//   fiem, тців_, dolf_,
  { {0x3f860268,0x89370047,0xd51a008b,0x00000000}},	//   _prou_, ארקע_, _gắn,
  { {0xdfd00021,0x7d0d635b,0x2d87635c,0x00000000}},	//   تية_, _rias, _arne_,
  { {0x3f8600e8,0x7cf60024,0x7d0d13dc,0x00000000}},	//   _vrou_, vára, _sias,
  { {0x2d87017f,0x7d0d635d,0x61e5004d,0x00000000}},	//   _crne_, _pias, ühlt,
  { {0x60c9635e,0x3f861988,0x7cf600ea,0x00000000}},	//   ciem, _trou_, tára,
  { {0x2d870146,0x6e940086,0x7c36001f,0x00000000}},	//   _erne_, _вилу, _deyr,
  { {0xdb2400ea,0xbda601fb,0x6d5d003b,0x00000000}},	//   ásáb, _محبو, ăsar,
  { {0x7cf6635f,0x78ad1792,0x6e3a0740,0x00000000}},	//   márn, tkav, matb,
  { {0x7cf60114,0x6e3a394f,0x5c740062,0x00000000}},	//   lárn, latb, _глът,
  { {0x98b10051,0xd7940062,0x9635202f,0x00000000}},	// [d0f0] jszą_, битъ, инац,
  { {0x60c90051,0xddda00ea,0x6e3a00ea,0x00000000}},	//   ziem, lető, natb,
  { {0x7ae7017f,0x600b0058,0x78ad6360,0x00000000}},	//   mojt, _kömü, pkav,
  { {0xe4e4071f,0xdd570041,0x47d504a0,0x00000000}},	//   бічн, רבאט_, _نيجر,
  { {0x7cf60240,0x6e3a19e5,0x60c96361,0x00000000}},	//   kárn, katb, viem,
  { {0xddda000f,0x46b90161,0x57d4000a,0x00000000}},	//   hető, _इतिह, _ѓорѓ,
  { {0x60c96362,0x6e3a2f15,0x7cf60260,0x00000000}},	//   tiem, datb, dárn,
  { {0x6e3a001c,0x99830078,0xdb0a0066,0x00000000}},	//   eatb, lajų_, ľném,
  { {0x6eef05b9,0xc87f00bd,0xddda00ea,0x00000000}},	//   løbi, _maß_, dető,
  { {0x0ea90076,0x60c96363,0xcef50002,0x00000000}},	//   ткой_, siem, јчињ,
  { {0x7cd2001c,0xed590001,0x60c9001c,0x00000000}},	//   lāri, њом_, piem,
  { {0x2d8700c3,0x16070053,0xfce648ae,0x00000000}},	//   _vrne_, वेयर_, ромо,
  { {0x7cc4000f,0x7cd2008f,0x7c290331,0x00000000}},	//   nőri, nāri, ñera,
  { {0xceb80051,0x6eef00b9,0x7cf60e7c,0x00000000}},	//   chę_, købi, cárn,
  { {0x7c36001f,0x2d876364,0xa9060044,0x00000000}},	//   _teyr, _urne_, لبرن,
  { {0x645b0025,0xf1b207e9,0x600b0058,0x00000000}},	//   _ncui, קסן_, _gömü,
  { {0xc87f0199,0x7cf60024,0x07a6005e,0x00000000}},	// [d100] _daß_, láro, јазн,
  { {0xda660fec,0x98790023,0x8b3b009a,0x00000000}},	//   _твои, ršās_, _שתיצ,
  { {0x7cf6004a,0x98b10022,0xc5d50085,0x00000000}},	//   náro, wszą_, біць,
  { {0x63ab00b9,0x6e3a00ea,0x4420008d,0x00000000}},	//   fygn, zatb, ùi_,
  { {0xf7460138,0x93770032,0xe29a0001,0x00000000}},	//   _њего, لصور_, кад_,
  { {0xddda00ea,0xab5b004d,0x7cfd42bb,0x00000000}},	//   zető, szüg, mére,
  { {0x7456005a,0x7cfd0003,0x7cf601c2,0x00000000}},	//   _възх, lére, járo,
  { {0x645b0027,0x63ab0d02,0x10a3005e,0x00000000}},	//   _gcui, bygn, жићн,
  { {0x6e3a0031,0x7cfd0164,0xddda00ea,0x00000000}},	//   tatb, nére, vető,
  { {0x600b0058,0x6e8a005e,0x6d4f0022,0x00000000}},	//   _sömü, тљив_, ącan,
  { {0x7cfd236b,0xdfd0007e,0xd6570063,0x00000000}},	//   hére, تيک_, סיטת_,
  { {0x557700b5,0x6e3a001c,0x7cf63544,0x00000000}},	//   בעטן_, satb, sárn,
  { {0x00bb0063,0x2011011b,0x6e3a2717,0x00000000}},	//   _במאמ, ězit_, patb,
  { {0x7cfd3380,0x6b4c0026,0xc87f004d,0x00000000}},	//   dére, _sögð, _saß_,
  { {0xe8950076,0x63ab0051,0x38c70330,0x00000000}},	//   бавь, zygn, ащав,
  { {0x7cfd03b2,0x290f1a8a,0x91fc0023,0x00000000}},	//   fére, öga_, _abāk,
  { {0x69de04ba,0xd838000d,0x7ae70114,0x00000000}},	// [d110] _expe, рэс_, pojt,
  { {0xfaa4005e,0xf770005d,0x645b00dd,0x00000000}},	//   _мањо, باف_, _scui,
  { {0x68e30e7c,0x64150021,0x29840085,0x00000000}},	//   _índo, مواط, _дыяг,
  { {0x7cfd4ed9,0x7cd2008f,0x99830078,0x00000000}},	//   bére, tāri, sajų_,
  { {0xe28e53a7,0xdb060022,0x7cf6013d,0x00000000}},	//   па_, czkó, záro,
  { {0x7c3d3914,0x72c40054,0x65956365,0x00000000}},	//   hasr, обіз, _лагу,
  { {0xc6920047,0x7cd2008f,0xab5b004d,0x00000000}},	//   _צאל_, sāri, nzüb,
  { {0x7cf600ea,0x7cd2008f,0x61110023,0x00000000}},	//   váro, pāri, _sāls,
  { {0x93b50001,0xd25b0002,0xb4e30053,0x00000000}},	//   _убац, _аце_, नकी_,
  { {0x7cf6000f,0x7c2f0146,0xe8e0001b,0x00000000}},	//   táro, ebcr, _đọc_,
  { {0x7d0a0001,0xd0110032,0xea000013,0x00000000}},	//   лног_, _فلا_, _khấu_,
  { {0x443d1b39,0xe2a60026,0x98b30080,0x00000000}},	//   naw_, _öðru_, ědět_,
  { {0xee2e000d,0x628360e0,0xddc8007d,0x00000000}},	//   _нн_, odno, redš,
  { {0xed5902dc,0x62816366,0x62836367,0x00000000}},	//   _бок_, _jalo, ndno,
  { {0x443d5501,0x2d9801e9,0x62816368,0x00000000}},	//   kaw_, äret_, _malo,
  { {0x6281002c,0x7cfd236b,0x50190047,0x00000000}},	//   _lalo, tére, רוּו,
  { {0x98a30429,0x6d413c73,0x443d1542,0x00000000}},	// [d120] чите, lsla, daw_,
  { {0x38b501e3,0x628101a6,0x6283006f,0x00000000}},	//   _våra_, _nalo, jdno,
  { {0x99860032,0x2e3a0047,0xc7a90047,0x00000000}},	//   _الجو, רגענ, עב_,
  { {0x7cfd18b3,0x443d002c,0x99980080,0x00000000}},	//   mérc, gaw_, larů_,
  { {0x672600d1,0x62816369,0x7cf63dd4,0x00000000}},	//   _utkj, _balo, járm,
  { {0x6d410576,0x62811157,0x2480073c,0x00000000}},	//   ksla, _calo, žim_,
  { {0x443d5501,0xd12f0ed2,0x7cd2001c,0x00000000}},	//   baw_, ях_, lāru,
  { {0x7cfd006d,0x61e4095a,0x6d410196,0x00000000}},	//   iérc, şilo, dsla,
  { {0x6d41636a,0x291a2fb9,0x6281636b,0x00000000}},	//   esla, _lupa_, _falo,
  { {0x7cf600ea,0x7c24636c,0x3243290b,0x00000000}},	//   sárl, _afir, _неуг,
  { {0x7c2902dd,0xdc990086,0x7cfd05d5,0x00000000}},	//   ñero, авні_, jérc,
  { {0x4f660021,0x78a600ac,0x628126c3,0x00000000}},	//   _هاتف, _nokv, _zalo,
  { {0x6111003d,0x26ca085f,0x7c3d0089,0x00000000}},	//   _tālr, _ombo_, rasr,
  { {0xcd33007e,0x2d982939,0x28c60082,0x00000000}},	//   _کروب, äres_, रोसि,
  { {0x443d002c,0x442405b3,0x291a1826,0x00000000}},	//   yaw_, _ofm_, _cupa_,
  { {0x47350088,0x291a000c,0x26ca090c,0x00000000}},	//   жнас, _dupa_, _ambo_,
  { {0x7bda01f7,0xfc3f0025,0x28f80121,0x00000000}},	// [d130] ştur, maí_, сеть_,
  { {0xfc3f0027,0x7cfd0331,0xcb38009a,0x00000000}},	//   laí_, bérc, _הנזק_,
  { {0x7c24007a,0x443d4881,0x28c60053,0x00000000}},	//   _yfir, taw_, रोहि,
  { {0xfc3f0027,0x6b8d636d,0xb4e30053,0x00000000}},	//   naí_, _krag, नके_,
  { {0x20d3000c,0xd6db0062,0x443d1d20,0x00000000}},	//   nţie_, _бтв_, raw_,
  { {0xfc3f018d,0x672d007d,0x38690264,0x00000000}},	//   haí_, mpaj, lfar_,
  { {0x38690025,0x443d3ede,0x44240089,0x00000000}},	//   ofar_, paw_, _ffm_,
  { {0x38690025,0x6281636e,0x6b8d50b1,0x00000000}},	//   nfar_, _walo, _orag,
  { {0xdbf20080,0xfc3f0025,0xef16026c,0x00000000}},	//   _přír, daí_, омы_,
  { {0x8234006a,0x6d410610,0x672d006d,0x00000000}},	//   _فرما, tsla, ipaj,
  { {0x7cd2003d,0x6d4100eb,0x7cfd017d,0x00000000}},	//   kārt, usla, xérc,
  { {0xd00e007e,0x291a636f,0x25be004b,0x00000000}},	//   علی_, _rupa_, _ütle_,
  { {0x2d980d88,0x6d416370,0x8fa50a29,0x00000000}},	//   ärer_, ssla, _фале,
  { {0x6d416371,0x6b8d6372,0x6d46005f,0x00000000}},	//   psla, _drag, ąkar,
  { {0x78a608ea,0xed596373,0x20d3003b,0x00000000}},	//   _pokv, _той_, aţie_,
  { {0x64490025,0x38690025,0x6b8d4584,0x00000000}},	//   _ndei, gfar_, _frag,
  { {0x20d30529,0x3ea70051,0x38b501f2,0x00000000}},	// [d140] cţie_, _kont_, _tårn_,
  { {0x64490185,0x7cfd0164,0x291a0035,0x00000000}},	//   _adei, méra, _tupa_,
  { {0x6eef0146,0x7cfd0003,0x3ea76374,0x00000000}},	//   løbs, léra, _mont_,
  { {0x38690025,0x39586375,0x78a608ed,0x00000000}},	//   cfar_, murs_, _uokv,
  { {0x7cfd03b2,0x6449001f,0xf487007e,0x00000000}},	//   néra, _ddei, تالی,
  { {0x26ca0035,0x39581cac,0xe7370635,0x00000000}},	//   _umbo_, ours_, _фер_,
  { {0x7cfd0003,0x68f6002b,0x1a9b0047,0x00000000}},	//   héra, olyd, ייסע,
  { {0xddd80512,0x6eef00b9,0x6f6a0002,0x00000000}},	//   _navš, købs, ајов_,
  { {0x629e024a,0x4fd40076,0x3ea7001f,0x00000000}},	//   öpos, яжит, _bont_,
  { {0x3ea70529,0x7cfd0164,0xf3c9007e,0x00000000}},	//   _cont_, déra, _طبقه_,
  { {0x3ea703b2,0xfc3f018d,0x6b8d00f3,0x00000000}},	//   _dont_, taí_, _srag,
  { {0x24866376,0xe57100b5,0x7cfd0003,0x00000000}},	//   ndom_, ײַט_, féra,
  { {0x2bc50235,0x39580164,0xfc3f0025,0x00000000}},	//   _लेखा, eurs_, raí_,
  { {0x6b8d02b0,0xfc3f0027,0x20d3003b,0x00000000}},	//   _vrag, saí_, rţie_,
  { {0xfc3f0027,0xca14005a,0x39586377,0x00000000}},	//   paí_, ддръ, gurs_,
  { {0x7cfd0164,0x20d3000c,0x9c390001,0x00000000}},	//   béra, pţie_, _упит_,
  { {0x38696378,0xec380063,0x6b8d6379,0x00000000}},	// [d150] rfar_, _ואחר_, _urag,
  { {0x24860969,0x6127005b,0x38690025,0x00000000}},	//   edom_, _yıld, sfar_,
  { {0x7cd2001c,0x39582b63,0xe5f50044,0x00000000}},	//   pārt, curs_, أكاد,
  { {0x2458000d,0xa97a0047,0x24863b6e,0x00000000}},	//   жаць_, _פארכ, gdom_,
  { {0x889a014e,0x24180086,0x7ead0066,0x00000000}},	//   _הברי, цією_, _kúpt,
  { {0x290900fe,0x68ed637a,0x2ca928b2,0x00000000}},	//   lmaa_, load, _load_,
  { {0x3ea74605,0x29090072,0xe4530044,0x00000000}},	//   _ront_, omaa_, _يضر_,
  { {0x3ea703b2,0x38bc0025,0xbf590054,0x00000000}},	//   _sont_, _tíre_, брої_,
  { {0x2d9e3318,0x3ea7637b,0x29090072,0x00000000}},	//   exte_, _pont_, imaa_,
  { {0x7cf60016,0x92b7006a,0x32550002,0x00000000}},	//   mári, _بحرا, _ѕвер,
  { {0x7cf644a4,0x3ea7530b,0xf6520047,0x00000000}},	//   lári, _vont_, עצט_,
  { {0x7cfd0164,0x01fa0063,0x7cff0006,0x00000000}},	//   téra, _הפעל, _kūry,
  { {0x7cf6261a,0x60db0afe,0xce950062,0x00000000}},	//   nári, mnum, _надъ,
  { {0x7cf629c7,0x1e840086,0xdd01001c,0x00000000}},	//   iári, _олім, ītāj,
  { {0xda79000d,0x7cfd4ed9,0x1d0a0062,0x00000000}},	//   цяў_, séra, _леки_,
  { {0x7cfd637c,0xc7260ac5,0xe8fa000d,0x00000000}},	//   péra, здай, ёла_,
  { {0x60db56c5,0x39584e84,0x68f600a5,0x00000000}},	// [d160] inum, surs_, rlyd,
  { {0x7cf6637d,0x7cd2001c,0x2484004b,0x00000000}},	//   dári, pārs, _samm_,
  { {0xda0a007e,0x7cf6013d,0xe9d2005d,0x00000000}},	//   _ديده_, tárh, _سغد_,
  { {0x04570032,0x6ef400cd,0x7cff0078,0x00000000}},	//   كلمة_, ràbi, _būry,
  { {0x33f60032,0x7cf6637e,0x7d040025,0x00000000}},	//   أساس, gári, _mhis,
  { {0x66c001e3,0x60db637f,0x78a401b3,0x00000000}},	//   _sökf, enum, ljiv,
  { {0x386b0025,0x7c3b0026,0x9fb5004c,0x00000000}},	//   _éirí_, ðurk, _dřív_,
  { {0x78a4017f,0x5f940189,0x60db6380,0x00000000}},	//   njiv, диит, gnum,
  { {0x7cf6039f,0x2ca93d00,0x4426098d,0x00000000}},	//   cári, _road_, mco_,
  { {0x44260dd1,0x64420139,0x7d040526,0x00000000}},	//   lco_, laoi, _ahis,
  { {0x44266381,0xb582000d,0x7aee024b,0x00000000}},	//   oco_, днiк, dobt,
  { {0x644205b3,0x7d041a9a,0x442612d4,0x00000000}},	//   naoi, _chis, nco_,
  { {0x68ed0016,0x68e36382,0x78a4007d,0x00000000}},	//   voad, _índi, djiv,
  { {0x64420139,0x0fc30062,0xddc8056c,0x00000000}},	//   haoi, _яйчн, iedź,
  { {0x09940002,0x68ed6383,0x2ca96384,0x00000000}},	//   нарџ, toad, _toad_,
  { {0xe8b5005b,0x9ddb0063,0x7cfd530b,0x00000000}},	//   _dışı, _לקוח, méro,
  { {0x20d3000c,0x6d5a6385,0x44262eae,0x00000000}},	// [d170] nţia_, luta, dco_,
  { {0x6d5a0035,0x29090ff2,0xb6f4005e,0x00000000}},	//   outa, smaa_, езуј,
  { {0x7cfd12a2,0x6d5a6386,0xf5790593,0x00000000}},	//   néro, nuta, تماع_,
  { {0x7cf66387,0x6d5a19c9,0x7c3b0026,0x00000000}},	//   tári, iuta, ðurh,
  { {0x6d5a6388,0xd7e40054,0xc3240054,0x00000000}},	//   huta, _зіро, емік,
  { {0xdb06000f,0x7cf66389,0x44262ae4,0x00000000}},	//   szkö, rári, aco_,
  { {0x7cf6638a,0x10a5042c,0x6d5a638b,0x00000000}},	//   sári, дийн, juta,
  { {0x4426638c,0xf94a0047,0x6d5a3e35,0x00000000}},	//   cco_, קעפֿ, duta,
  { {0x6d5a0089,0x7cfd00ea,0x60db638d,0x00000000}},	//   euta, térn, rnum,
  { {0x443f0994,0x6d5a10ca,0x38bc0080,0x00000000}},	//   _heu_, futa, _míra_,
  { {0x20d3000c,0x6d5a638e,0x7d04638f,0x00000000}},	//   aţia_, guta, _phis,
  { {0xdfce006a,0x443f0164,0x3f8f02f7,0x00000000}},	//   ايی_, _jeu_, _trgu_,
  { {0x20d3000c,0x2d8c00b9,0x443f6390,0x00000000}},	//   cţia_, avde_, _meu_,
  { {0x44266391,0x6d5a240d,0x7d046392,0x00000000}},	//   zco_, buta, _whis,
  { {0x3f8d0016,0x6d5500ea,0x6d5a073d,0x00000000}},	//   lveu_, ázad, cuta,
  { {0x443f6393,0xe73a000a,0x6aa10026,0x00000000}},	//   _neu_, жеа_, ölfr,
  { {0x2ab40004,0x26d30016,0x7c85005e,0x00000000}},	// [d180] _läbi_, fixo_, _чује,
  { {0x257e0080,0x61e4005b,0x6b846394,0x00000000}},	//   _půl_, şili, _isig,
  { {0x39450026,0xd5b20021,0xf1c30078,0x00000000}},	//   álst_, خفض_, nešė_,
  { {0x26d3017d,0x66c00137,0x69da0003,0x00000000}},	//   aixo_, _sökd, ûteu,
  { {0x7c3b0026,0x443f6395,0x64421e8d,0x00000000}},	//   ðuri, _deu_, raoi,
  { {0x443f00e8,0x7bc600c3,0x38600026,0x00000000}},	//   _eeu_, izku, lgir_,
  { {0x443f3e26,0xdc300006,0xa1270021,0x00000000}},	//   _feu_, _užėm, وكول_,
  { {0x6b84017f,0x6d5a0004,0x272401bb,0x00000000}},	//   _osig, vuta, _kön_,
  { {0x4fc606bc,0x6b846396,0x2724013d,0x00000000}},	//   ьска, _nsig, _jön_,
  { {0x7cfd0003,0x7ead0066,0xad660021,0x00000000}},	//   téro, _súpr, واجه,
  { {0x6b846397,0x629a562f,0x6d5a00fe,0x00000000}},	//   _asig, _into, uuta,
  { {0xe57100b5,0x20d3000c,0x40930021,0x00000000}},	//   אַך_, pţia_, _للمر,
  { {0x6d5a1fc9,0x6440014f,0x752900c2,0x00000000}},	//   suta, _memi, _čezm,
  { {0x20d3000c,0x7cfd0164,0x63a2017d,0x00000000}},	//   nţin_, péro, ixon,
  { {0x6b84051e,0xaf070032,0x6127005b,0x00000000}},	//   _esig, _تقوم_, _kıla,
  { {0x6d4836e9,0x38600026,0x64406398,0x00000000}},	//   msda, ggir_, _nemi,
  { {0x6d480205,0xa6350086,0x629a6399,0x00000000}},	// [d190] lsda, ензі, _onto,
  { {0x443f639a,0x2724005b,0x7cfd00ea,0x00000000}},	//   _seu_, _dön_, zérl,
  { {0x443f0291,0x628a0185,0x6440158f,0x00000000}},	//   _peu_, ddfo, _bemi,
  { {0x629a157e,0x44290013,0x6d48639b,0x00000000}},	//   _anto, ùa_, isda,
  { {0x66c000c7,0x443f1b84,0x6440639c,0x00000000}},	//   _söke, _veu_, _demi,
  { {0x29190035,0xf8bf0026,0x6d4812f5,0x00000000}},	//   _hisa_, _hlé_, ksda,
  { {0x443f0bd1,0x6288639d,0x6440639e,0x00000000}},	//   _teu_, _dado, _femi,
  { {0x764500e3,0x629a639f,0x644033a4,0x00000000}},	//   lahy, _ento, _gemi,
  { {0x6d4a01b9,0x291963a0,0x2d981310,0x00000000}},	//   _avfa, _misa_, åren_,
  { {0x7cfd00ea,0x291963a1,0x3f8d2837,0x00000000}},	//   sérl, _lisa_, rveu_,
  { {0xab5b000f,0x6d480203,0x3f820026,0x00000000}},	//   szül, gsda, ækur_,
  { {0x6b8400e8,0x291958c6,0x62881587,0x00000000}},	//   _psig, _nisa_, _zado,
  { {0x7cfd0331,0x2bba0021,0x00c80085,0x00000000}},	//   cérm, ساحة_, _ўлік_,
  { {0x6d480146,0xc33201f9,0x2919005f,0x00000000}},	//   bsda, רום_, _aisa_,
  { {0x291900f3,0xf8bf0003,0x7ce8005b,0x00000000}},	//   _bisa_, _blé_, tırd,
  { {0xf8bf18b2,0xad1a0047,0x7cfd013d,0x00000000}},	//   _clé_, _צופר, hérj,
  { {0x27e60164,0x38600143,0x64403649,0x00000000}},	// [d1a0] çon_, rgir_, _remi,
  { {0x66c000c7,0x6ef400cd,0xf8bf00ea,0x00000000}},	//   _sökb, làbr, _elé_,
  { {0x64400e53,0x38600031,0x628848e8,0x00000000}},	//   _pemi, pgir_, _rado,
  { {0xceb80022,0xd4060200,0x44f6005d,0x00000000}},	//   zkę_, няли, رساز,
  { {0x7cf60024,0x628863a2,0xceb81435,0x00000000}},	//   lárs, _pado, ykę_,
  { {0x764e0146,0x20d3003b,0xf8bf0061,0x00000000}},	//   _udby, uţin_, _zlé_,
  { {0x66e31133,0x20d3000c,0x62881b74,0x00000000}},	//   _сора, rţin_, _vado,
  { {0xd5b90088,0xc9530063,0x62881147,0x00000000}},	//   _ўсё_, אמה_, _wado,
  { {0xceb80051,0x628863a3,0xdfd001fb,0x00000000}},	//   tkę_, _tado, شيد_,
  { {0x7cf61d6b,0x6d4863a4,0x629a270b,0x00000000}},	//   kárs, tsda, _unto,
  { {0x7cf663a5,0x752900c3,0x6d480006,0x00000000}},	//   járs, _čezk, usda,
  { {0x7cf60024,0x7f49221f,0x27e60051,0x00000000}},	//   dárs, bseq, żony_,
  { {0x291963a6,0x2ab4004b,0x6d4821ab,0x00000000}},	//   _risa_, _läbu_, ssda,
  { {0x6d480031,0x2919003e,0x8f9b009f,0x00000000}},	//   psda, _sisa_, _מידי,
  { {0xf8bf0025,0xa2b30053,0x291963a7,0x00000000}},	//   _plé_, _अवस्, _pisa_,
  { {0x76450150,0x68e90130,0x8dfb009a,0x00000000}},	//   wahy, čedo, _מהות,
  { {0x3f860080,0x291963a8,0x56f50002,0x00000000}},	// [d1b0] _jsou_, _visa_, впаѓ,
  { {0x65951736,0x79850474,0x35e70065,0x00000000}},	//   казу, _tshw, нцев,
  { {0x764563a9,0x7cf61270,0x291963aa,0x00000000}},	//   rahy, cárs, _tisa_,
  { {0x53350601,0x3eae0943,0x7cf6013d,0x00000000}},	//   ведт, _loft_, lárr,
  { {0x7cfd00ea,0x4518007e,0x80a40042,0x00000000}},	//   eérk, رآمد_, काने,
  { {0x248963ab,0x2175030b,0xf2c70085,0x00000000}},	//   žam_, вуир, эсен,
  { {0x7cfd00ea,0x2b4d0080,0x88cb009a,0x00000000}},	//   gérk, šech_, ּמִ֖,
  { {0x27ed01e1,0x7c2d0075,0x23d20042,0x00000000}},	//   _øens_, _nfar, _देवद,
  { {0x24800019,0x776d53b6,0x7cf6013d,0x00000000}},	//   õime_, ntax, zárs,
  { {0x7cfd00ea,0x7c2d3b6d,0xf7720063,0x00000000}},	//   lérh, _afar, סקי_,
  { {0xc6920063,0x7f492423,0x69d10042,0x00000000}},	//   באי_, sseq, _डेली,
  { {0x22470524,0x7f7521e9,0xd0d9012c,0x00000000}},	//   lank_, _аукц, _юдеї_,
  { {0x30d800b5,0x3b830088,0x8e8563ac,0x00000000}},	//   _אַװע, аляг, _агле,
  { {0x7cf619e6,0xc0040083,0x2d950cbd,0x00000000}},	//   társ, _спік, _арис,
  { {0x7c2d001f,0xaa430065,0xdb1d013d,0x00000000}},	//   _ffar, ресл, rzsá,
  { {0x224712a9,0x442d002b,0xdb1d013d,0x00000000}},	//   hank_, _nfe_, szsá,
  { {0x7cf60066,0xf746167b,0x7cfd013d,0x00000000}},	// [d1c0] sárs, тезо, zérk,
  { {0x39a40054,0xa9261cce,0xc7af0044,0x00000000}},	//   _блоґ, _идол, غّل_,
  { {0xdb1d00ea,0x22470760,0x546a02dc,0x00000000}},	//   özöt, dank_, даем_,
  { {0x6b96424d,0xa3bd0042,0x24530044,0x00000000}},	//   _kryg, ँईं_, لنمس,
  { {0xdb0f0080,0x7cf60e7c,0xa2b30042,0x00000000}},	//   zycí, nárq, _अवश्,
  { {0x62630138,0x442d63ad,0x61fa004c,0x00000000}},	//   авља, _efe_, _pytl,
  { {0xe2970dd5,0x518620cc,0xe5a3342b,0x00000000}},	//   тај_, тула, _кири,
  { {0x61fa01d9,0x6b960051,0x660300ea,0x00000000}},	//   _vytl, _oryg, ünke,
  { {0xd3f4000d,0x22472ff4,0x80030121,0x00000000}},	//   _лiст, bank_, ичье,
  { {0x38b50137,0x7cfd63ae,0x66c00072,0x00000000}},	//   _hårt_, méri, _yöka,
  { {0x7c2d00bd,0x61e4005b,0x7cfd63af,0x00000000}},	//   _pfar, ğils, léri,
  { {0xcb35005a,0xc5f30063,0x5c741fd8,0x00000000}},	//   лемъ, ידת_, алют,
  { {0x3f86017d,0x7cf600ea,0x9f530054,0x00000000}},	//   _usou_, tárr, _ввіч,
  { {0x6b96081c,0xf413009a,0x7cfd009c,0x00000000}},	//   _dryg, יפר_, zérh,
  { {0x7c3b007a,0x60c20438,0xddc80051,0x00000000}},	//   ðurs, _klom, nedż,
  { {0x7c2d0035,0x3872001f,0x6b964284,0x00000000}},	//   _ufar, gfyr_, _fryg,
  { {0x66c000c7,0x28f80121,0xc66b0121,0x00000000}},	// [d1d0] _söka, теть_, дшее_,
  { {0x60c200cd,0xe3b3007e,0x6d5a277e,0x00000000}},	//   _llom, یرش_, orta,
  { {0x7af50080,0x1a9a0047,0x7cfd00ea,0x00000000}},	//   mozt, _װירע, térh,
  { {0x6d5a0627,0x7cfd63b0,0x5dd90041,0x00000000}},	//   irta, féri, ײַעס,
  { {0x6d5a004d,0x785e003b,0x7cfd4754,0x00000000}},	//   hrta, săvâ, géri,
  { {0x16340076,0x60c23919,0xf990005d,0x00000000}},	//   _веря, _alom, _ابی_,
  { {0xfa7801d8,0x60c206a3,0xd148007e,0x00000000}},	//   דעות_, _blom, نشين_,
  { {0x7af500ea,0x25c50058,0x7cfd63b1,0x00000000}},	//   hozt, ıslı_, béri,
  { {0x7af500ea,0x63a400fe,0x22470019,0x00000000}},	//   kozt, äint, pank_,
  { {0x5274006a,0x6127005b,0x7ce80058,0x00000000}},	//   _نامز, _yıll, dıra,
  { {0x8db50086,0x61270058,0xddc8004c,0x00000000}},	//   успі, _kılm, nadň,
  { {0x60c263b2,0x7cf600be,0x7cd2008f,0x00000000}},	//   _glom, tárq, lārz,
  { {0x2024034d,0xa2b90161,0xfc4702dd,0x00000000}},	//   ásiť_, ्सप्, ñías_,
  { {0x7cc4000f,0x6b9600e8,0x7cf60460,0x00000000}},	//   nőrz, _vryg, rárq,
  { {0xb9b5005a,0x2d87007d,0x6d5a007d,0x00000000}},	//   астъ, _usne_, crta,
  { {0x6b9663b3,0xbc66065b,0x4dfa0041,0x00000000}},	//   _tryg, _свик, _אפצא,
  { {0xd70a000d,0xc7a325a6,0xa80663b4,0x00000000}},	// [d1e0] енае_, битк, узал,
  { {0x67360078,0x7cfd1f20,0x8c1b0063,0x00000000}},	//   rpyj, véri, _אופי,
  { {0xe45a14cd,0x96f9000d,0x7c29004c,0x00000000}},	//   еже_, тэту_, žere,
  { {0x18a60b3f,0x248d017d,0x7cfd63b5,0x00000000}},	//   _самм, _caem_, téri,
  { {0x38b52330,0xcc3b0047,0x68e40331,0x00000000}},	//   _vårt_, גענט, mnid,
  { {0x61fe0122,0x290063b6,0x37e30002,0x00000000}},	//   üplo, llia_, _ѓорг,
  { {0x68e430af,0x21670001,0x7cfd63b7,0x00000000}},	//   onid, гији_, séri,
  { {0x7cfd63b8,0x26da39b9,0x045a0021,0x00000000}},	//   péri, lipo_, _سلطة_,
  { {0x290000fe,0x68e4175c,0x60c200a8,0x00000000}},	//   ilia_, inid, _vlom,
  { {0xce6a0002,0x67260089,0x4d980086,0x00000000}},	//   хрид_, _mukj, вкою_,
  { {0x2b91034d,0xd6db0063,0x29005552,0x00000000}},	//   _môcť_, תחיל, klia_,
  { {0x6d5a0025,0x7ce8005b,0x703a0021,0x00000000}},	//   rrta, tıra, _أساس_,
  { {0x7af5000f,0x26da0ab2,0x60db0047,0x00000000}},	//   tozt, kipo_, _אקאנ,
  { {0x66c001e3,0x3d940086,0x68e463b9,0x00000000}},	//   _sökn, _викр, enid,
  { {0x68e40123,0x7af500ea,0x6d5c013d,0x00000000}},	//   fnid, rozt, árad,
  { {0x290002f6,0xfaff00ac,0x68e40460,0x00000000}},	//   glia_, duëe_, gnid,
  { {0x96f9000a,0xe8940076,0xaae7007e,0x00000000}},	// [d1f0] веат_, щать, _مسدو,
  { {0x248d017d,0x68e4004b,0x290063ba,0x00000000}},	//   _saem_, anid, alia_,
  { {0x7d0d15b8,0x66c00137,0x29004801,0x00000000}},	//   _khas, _tökn, blia_,
  { {0x63b90045,0x94190044,0xfa34005d,0x00000000}},	//   tywn, نقاذ_, _پرید,
  { {0xe28e000a,0x66c00058,0x0d180041,0x00000000}},	//   оа_, _kökl, אקאט_,
  { {0x78ad63bb,0x2d85001f,0x26da5266,0x00000000}},	//   ljav, ywle_, cipo_,
  { {0x78ad01b3,0x20d3003b,0x63b90022,0x00000000}},	//   ojav, lţii_, sywn,
  { {0x22450122,0x78ad01b3,0xb97c0047,0x00000000}},	//   _welk_, njav, גנהי,
  { {0x2019024a,0x4f250079,0x644b63bc,0x00000000}},	//   äsi_, јдоб, magi,
  { {0x644b63bd,0x78ad078c,0x2eb502b3,0x00000000}},	//   lagi, hjav, рсис,
  { {0x82a4005e,0x62831cd2,0x78ad63be,0x00000000}},	//   _уште, meno, kjav,
  { {0x628363bf,0x30e4000d,0x361a0047,0x00000000}},	//   leno, _лічб, כותד,
  { {0x76550051,0x628300c2,0x60db63c0,0x00000000}},	//   _odzy, oeno, mium,
  { {0x644b0228,0xfc030086,0x78ad00c3,0x00000000}},	//   hagi, іпро, ejav,
  { {0x66c001e3,0x628363c1,0x78ad0014,0x00000000}},	//   _söko, ieno, fjav,
  { {0x60c900fe,0x7d0d075a,0x29000306,0x00000000}},	//   nhem, _ghas, ulia_,
  { {0x644b63c2,0x26da63c3,0x68e463c4,0x00000000}},	// [d200] dagi, tipo_, rnid,
  { {0xfd4c001b,0xdcf90080,0x62830869,0x00000000}},	//   _nhiệ, _osvě, jeno,
  { {0x4a5b0063,0x29002bf6,0x26da00a4,0x00000000}},	//   _בדיו, plia_, ripo_,
  { {0x26da05b3,0x6e2d513a,0x644b63c5,0x00000000}},	//   sipo_, _şabl, gagi,
  { {0x20d3000c,0x60db0518,0x13940054,0x00000000}},	//   cţii_, dium, силю,
  { {0x628305e1,0x644b0d69,0x7cfd013d,0x00000000}},	//   geno, aagi, lért,
  { {0x644b00f3,0x69ce63c6,0x41b40021,0x00000000}},	//   bagi, nzbe, إمبر,
  { {0x7cfd013d,0x644b0075,0x60db63c7,0x00000000}},	//   nért, cagi, gium,
  { {0x61270058,0x30130062,0x232a25dc,0x00000000}},	//   _yılk, одър, _рози_,
  { {0x62330138,0xd0070d34,0x7c2463c8,0x00000000}},	//   _међу, шење_, _agir,
  { {0x06970063,0x7cfd00ea,0x0dca018b,0x00000000}},	//   בדים_, kért, тупи_,
  { {0x66c000c7,0x6f010139,0xa0a30c59,0x00000000}},	//   _sökl, allc, _махд,
  { {0x69ce007d,0x7e6b0072,0xdee626b8,0x00000000}},	//   ezbe, ämpö, _коди,
  { {0x7ce80058,0x2d8a01e1,0xd00704f2,0x00000000}},	//   lırl, æbes_, _тече_,
  { {0x6d43001f,0x78ad63c9,0x2e370063,0x00000000}},	//   _gwna, tjav, _דרוש_,
  { {0xa8a40001,0x7ce801f7,0x2f0b00b9,0x00000000}},	//   орук, nırl, røge_,
  { {0x2f0b0146,0x78ad63ca,0x628363cb,0x00000000}},	// [d210] søge_, rjav, yeno,
  { {0x20d3000c,0x6b8d4548,0x644b2a7e,0x00000000}},	//   rţii_, _isag, wagi,
  { {0x628363cc,0xb9950021,0x05680141,0x00000000}},	//   veno, _الجب, ијци_,
  { {0x77640268,0x20d3000c,0x7cfd10c9,0x00000000}},	//   buix, pţii_, mérs,
  { {0x7ce8005b,0x33870002,0x987a0047,0x00000000}},	//   dırl, руев, _גארט,
  { {0x628305ab,0x44240222,0x386963cd,0x00000000}},	//   ueno, _egm_, lgar_,
  { {0x644b02b0,0x84670062,0x628363ce,0x00000000}},	//   pagi, _възе, reno,
  { {0x38693a92,0x628363cf,0xd4980054,0x00000000}},	//   ngar_, seno, _кру_,
  { {0xfd4c001b,0x60c933a1,0x60db63d0,0x00000000}},	//   _thiệ, rhem, rium,
  { {0xe57f001c,0xaec5000d,0x60c963d1,0x00000000}},	//   šķus_, сбол, shem,
  { {0x2fcd00ea,0xa2940086,0x70590002,0x00000000}},	//   szeg_, _фахі, _баер_,
  { {0xed560054,0xb11527b7,0xfce6079f,0x00000000}},	//   щою_, _умеш, сомо,
  { {0x66c000c7,0x2d8a00b9,0x38692e48,0x00000000}},	//   _sökm, æber_, dgar_,
  { {0xa3af0235,0x3869007a,0x69ce00bd,0x00000000}},	//   _ओपन_, egar_, tzbe,
  { {0x6b8d0290,0xcd350242,0x7cfd013d,0x00000000}},	//   _esag, _ارتب, tért,
  { {0x386950d3,0x7c240035,0x69ce63d2,0x00000000}},	//   ggar_, _ugir, rzbe,
  { {0x69ce00ea,0x07a30002,0x6843000d,0x00000000}},	// [d220] szbe, патн, янта,
  { {0x7ce8005b,0x776400cd,0x386963d3,0x00000000}},	//   zırl, ruix, agar_,
  { {0x7cfd3bb8,0x644900bd,0xba9b0047,0x00000000}},	//   pért, _beei, _עסטי,
  { {0xed560047,0x44320013,0x4dfa0047,0x00000000}},	//   מבער_, ùy_, אפעא,
  { {0x20d3003b,0x442400ca,0x68f90022,0x00000000}},	//   nţiu_, _vgm_, ładó,
  { {0x26d8017f,0x7ce8005b,0x661a0014,0x00000000}},	//   _umro_, dırm, _útko,
  { {0x7ce8005b,0xfc3f0080,0x80a40053,0x00000000}},	//   tırl, ybí_, काले,
  { {0x644900bd,0x44240150,0x141a0021,0x00000000}},	//   _geei, _ugm_, _ميزة_,
  { {0xdbf10080,0x2e4a5678,0x7cfd013d,0x00000000}},	//   _příc, ляно_, zérs,
  { {0x66fa0161,0x386963d4,0x2379004b,0x00000000}},	//   ्तिक_, zgar_, _äsja_,
  { {0xd24f043e,0xa1c50044,0x720614d7,0x00000000}},	//   _سنن_, _وآمن, _اوام,
  { {0x7cfd017d,0x5cc70121,0xd12f0021,0x00000000}},	//   vérs, ссоз, _أمن_,
  { {0x06fa0161,0x7f930054,0xc4d3009a,0x00000000}},	//   ्ताव_, _наїх, פגש_,
  { {0x38bc0080,0x3869001f,0x6d4e006d,0x00000000}},	//   _míru_, wgar_, ábas,
  { {0xa803005b,0x98c7000d,0xf8bf0003,0x00000000}},	//   ğıms, бсал, _liée_,
  { {0x386916eb,0xad370aeb,0x58d463d5,0x00000000}},	//   ugar_, _פנחס_, пост,
  { {0x386963d6,0x24860024,0x32cb00d1,0x00000000}},	// [d230] rgar_, deom_, _høye_,
  { {0x64490034,0x6efd0164,0x20d3003b,0x00000000}},	//   _seei, lèbr, lţit_,
  { {0x661a0014,0x66c0013d,0xf60b0e74,0x00000000}},	//   _útkl, _zökk, ухай_,
  { {0x6efd0003,0x20d3003b,0x24861536,0x00000000}},	//   nèbr, nţit_, geom_,
  { {0x69d80014,0xd138005f,0x49020042,0x00000000}},	//   _þver, _atą_, _वीटो_,
  { {0xc348007f,0xb3840085,0xe299137e,0x00000000}},	//   сяце_, яліл, рак_,
  { {0x96080088,0x32cb0031,0xc6920041,0x00000000}},	//   _гэта_, _nøye_, _קאל_,
  { {0x7ce8005b,0x69da00be,0x2f550081,0x00000000}},	//   tırm, útei, отос,
  { {0x2d9c63d7,0x2d9806a5,0x1ec90121,0x00000000}},	//   _arve_, æren_, илии_,
  { {0x2003001c,0x61f4006c,0xd3d80044,0x00000000}},	//   āji_, éflé, _طبقا_,
  { {0xb035005a,0x66c000c7,0xdb060051,0x00000000}},	//   _днеш, _sökk, zykó,
  { {0x6efd0003,0x66c00014,0x23600130,0x00000000}},	//   gèbr, _pökk, šije_,
  { {0xb4fa0047,0x0b430062,0x7ce80058,0x00000000}},	//   שפרי, мнян, lırk,
  { {0x61ed003b,0x63b604aa,0xee39128f,0x00000000}},	//   şalu, øyni, _тнк_,
  { {0x7ce8005b,0x2d9806f1,0x48b62b70,0x00000000}},	//   nırk, året_, ощат,
  { {0xdb060051,0x66c00014,0x00000000,0x00000000}},	//   tykó, _tökk,   ,
  { {0xe8f70636,0x9d1b0063,0xb8f20042,0x00000000}},	// [d240] ілу_, _דוקט, _वत_,
  { {0xdb060022,0x463a0085,0x00000000,0x00000000}},	//   rykó, рчая_,   ,
  { {0x7afc04bf,0x842a06da,0x7d0663d8,0x00000000}},	//   mort, ажев_, olks,
  { {0xc7a60727,0x7afc0989,0xdd7a0041,0x00000000}},	//   _димк, lort, יטעל,
  { {0xdc8d0047,0x78a663d9,0x7afc63da,0x00000000}},	//   טװאָ, _inkv, oort,
  { {0x623400d7,0x7afc2894,0x7cf6013d,0x00000000}},	//   чеку, nort, gárz,
  { {0x99980078,0x889a009a,0x00000000,0x00000000}},	//   marų_, ֹבִי,   ,
  { {0x66c000c7,0x7afc63db,0x81130044,0x00000000}},	//   _sökh, hort, وذيا,
  { {0x2002007a,0x98b3017f,0xbe86005e,0x00000000}},	//   æki_, žeće_, оћни,
  { {0x2d9c01b3,0x7afc0246,0x3f9d002b,0x00000000}},	//   _prve_, jort, _drwu_,
  { {0x7afc63dc,0xa2a70042,0x4c9545f6,0x00000000}},	//   dort, चार्, пинс,
  { {0x99980078,0x644201a8,0x61ed0058,0x00000000}},	//   harų_, nboi, ğalt,
  { {0xd0070001,0x99980006,0x20d3003b,0x00000000}},	//   _деце_, karų_, rţit_,
  { {0x7afc0058,0x7c3600a3,0x1eaa005d,0x00000000}},	//   gort, _efyr, _خاصي_,
  { {0x7c36001f,0xdb1d00ea,0xf84b0bf5,0x00000000}},	//   _ffyr, nysé, ичай_,
  { {0x26ca0051,0x59f8000d,0x34b90053,0x00000000}},	//   _albo_, цеся_, _आवेद,
  { {0x7afc63dd,0x5c740085,0x9998005f,0x00000000}},	// [d250] bort, _ўльт, farų_,
  { {0x501b0063,0x26070121,0x6d670139,0x00000000}},	//   שומו, очег, _úsaí,
  { {0x63b600fe,0xe5ab005e,0xb866005d,0x00000000}},	//   äynn, шњак_, _کاپو,
  { {0xf9fa0063,0x6d55013d,0x44b50085,0x00000000}},	//   _להתמ, ázai, ябес,
  { {0x07a40085,0xb3870044,0xe50800de,0x00000000}},	//   _жаўн, تجاه, آينو_,
  { {0x77ba0063,0xaa450072,0x7ce8005b,0x00000000}},	//   _המשח, _ävää_, tırk,
  { {0x2009003d,0x98ac0078,0xca7c009f,0x00000000}},	//   _šai_, ūdą_, ינגט,
  { {0x257533fe,0x40780121,0x7ce80058,0x00000000}},	//   mål_, ощью_, rırk,
  { {0x66c000c7,0x6d5c2bc6,0x3e890044,0x00000000}},	//   _söki, áran, مَةَ_,
  { {0xf1950086,0x4d65315e,0xae580054,0x00000000}},	//   _низь, пков, орює_,
  { {0x7afc63de,0x7cfd0460,0xed59005e,0x00000000}},	//   vort, térp, љом_,
  { {0xdb0d0024,0x7afc63df,0xbfb7005d,0x00000000}},	//   ľkýc, wort, _وحشت,
  { {0x7f19000d,0xa2d20053,0x25750137,0x00000000}},	//   _ліку_, भोक्, hål_,
  { {0x6442000c,0x2f180076,0x8f9a016e,0x00000000}},	//   zboi, _дочь_, _ליני,
  { {0x7d11000f,0x3ea70014,0x7afc63e0,0x00000000}},	//   üksé, _innt_, rort,
  { {0x7afc2f7b,0xa923030b,0xdcfa0044,0x00000000}},	//   sort, едсл, _دفعت_,
  { {0x7afc2395,0x9998005f,0x00000000,0x00000000}},	// [d260] port, tarų_,   ,
  { {0x6442002b,0x7bdb009a,0x00000000,0x00000000}},	//   wboi, _לקפו,   ,
  { {0x3abb0063,0x7abb0063,0xaabb0063,0x00000000}},	//   _המינ, _הציו, _הזיכ,
  { {0x27ed074f,0x3d120042,0xd46a01ce,0x00000000}},	//   _žene_, _धीमे_, сиде_,
  { {0x29020004,0x389b0063,0x637a01d5,0x00000000}},	//   _ikka_, _היכנ, ссер_,
  { {0x32050080,0xba3a00b5,0x68fb00a8,0x00000000}},	//   _byly_, זײַט, čude,
  { {0xb909008b,0x987c0066,0x044604c3,0x00000000}},	//   _nghỉ_, _míľ_, _невн,
  { {0x61e50024,0xf484007e,0xc1040021,0x00000000}},	//   úhla, _تاسی, بوعي,
  { {0xdd1f0080,0xb3ca005e,0x250b007e,0x00000000}},	//   tížn, _улаз_, _طرفی_,
  { {0xd357009a,0x4357009a,0xeeaa51c4,0x00000000}},	//   _מימי_, _מסמל_, стик_,
  { {0xaab00161,0x2d8c006f,0xd23b0063,0x00000000}},	//   ञानक, uwde_, _הגבל,
  { {0x629863e1,0x628a63e2,0xa1130044,0x00000000}},	//   ldvo, lefo, _كولت,
  { {0xde5801dd,0x62981b9e,0x8fa3082d,0x00000000}},	//   _далі_, odvo, _паце,
  { {0x764e0080,0x753c0045,0x66c00014,0x00000000}},	//   _neby, _otrz, _köku,
  { {0xc98408ac,0xa835005e,0x6b8463e3,0x00000000}},	//   нути, дебљ, _epig,
  { {0xdd01008f,0xdde9005d,0x6d3b009d,0x00000000}},	//   ītēj, _برهه_, _פתחנ,
  { {0x628a63e4,0x764e0196,0xf7730593,0x00000000}},	// [d270] kefo, _beby, عار_,
  { {0x2a030066,0xda4b1406,0x56940893,0x00000000}},	//   _ačať_, _учил_, наут,
  { {0x764e001f,0x628a63e5,0x765c002b,0x00000000}},	//   _deby, defo, _ddry,
  { {0x765c0185,0x2458000d,0x386d00b9,0x00000000}},	//   _edry, заць_, _øer_,
  { {0x68ed63e6,0x6d4a00a3,0x889a009a,0x00000000}},	//   mnad, _lwfa, _וברי,
  { {0x66c001e3,0x628a63e7,0x764e0d02,0x00000000}},	//   _sökv, gefo, _geby,
  { {0x68ed63e8,0x2ca963e9,0x95c50021,0x00000000}},	//   onad, _onad_, _غيره,
  { {0x7f590079,0x67270089,0x6f08006f,0x00000000}},	//   ојот_, _hijj, eldc,
  { {0xa227007e,0x68ed63ea,0x66d200b9,0x00000000}},	//   _فراه, inad, _dækf,
  { {0x68ed001f,0xf4120063,0xdb0a0058,0x00000000}},	//   hnad, _יפן_, ünüm,
  { {0x6b840a02,0x68ed63eb,0x569c0063,0x00000000}},	//   _spig, knad, מיזצ,
  { {0x68ed006f,0x859a0063,0x01fa009a,0x00000000}},	//   jnad, קשרו, _ופעל,
  { {0xdce2001c,0x68ed63ec,0x66c00058,0x00000000}},	//   gulā, dnad, _kökt,
  { {0x7d070164,0x3ea70026,0x3200005b,0x00000000}},	//   térê, _unnt_, şiye_,
  { {0x62810025,0x764e00a4,0xacf6005e,0x00000000}},	//   _mblo, _reby, _очиј,
  { {0x68ed63ed,0x62980b59,0x6d4118b4,0x00000000}},	//   gnad, zdvo, mpla,
  { {0x753c0051,0x6d412d90,0x7d0463ee,0x00000000}},	// [d280] _strz, lpla, _ikis,
  { {0xc795000d,0x29090072,0x6d4163ef,0x00000000}},	//   эрсы, alaa_, opla,
  { {0x7e7e00c7,0x628a63f0,0x6d414c62,0x00000000}},	//   _öppe, vefo, npla,
  { {0xcdb60063,0xd4d5000d,0x628163f1,0x00000000}},	//   ופעה_, нічэ, _ablo,
  { {0x764e001f,0x628a35af,0x68e463f2,0x00000000}},	//   _teby, tefo, miid,
  { {0x68e40019,0x765c00b9,0x69c1004b,0x00000000}},	//   liid, _udry, äleg,
  { {0x753c0051,0xf623000d,0x6298361e,0x00000000}},	//   _utrz, _адро, rdvo,
  { {0x628a0109,0x6d4163f3,0x68e430bf,0x00000000}},	//   sefo, dpla, niid,
  { {0x628a04aa,0xbe8a0a8f,0x6d4163f4,0x00000000}},	//   pefo, осне_, epla,
  { {0x66c063f5,0x2ca90080,0x7d0456c5,0x00000000}},	//   _töku, _snad_, _akis,
  { {0x68e40019,0x01da0021,0x6d4134a6,0x00000000}},	//   kiid, _بوضع_, gpla,
  { {0xbfc6011c,0x66c02502,0x7d1663f6,0x00000000}},	//   _обек, _köks, _chys,
  { {0x5c040088,0x68e40019,0x711b0047,0x00000000}},	//   вяра, diid, _וואפ,
  { {0x6d4100c7,0x69c100d1,0x9ea70062,0x00000000}},	//   bpla, øleo, _овча_,
  { {0x6d5500ea,0x68ed63f7,0xe9190054,0x00000000}},	//   ázat, tnad, зові_,
  { {0xdce2001c,0x69d5004d,0xddc80051,0x00000000}},	//   pulā, rzze, padł,
  { {0x7c2d63f8,0x68ed0e57,0x69130058,0x00000000}},	// [d290] _igar, rnad, eçec,
  { {0x66e4005e,0x85b8005d,0x68ed63f9,0x00000000}},	//   вођа, ژانس_, snad,
  { {0xe3b0006a,0x68ed00c7,0xeb9f01e1,0x00000000}},	//   یره_, pnad, lvø_,
  { {0x66c001e3,0x62810290,0x809e0053,0x00000000}},	//   _sökt, _sblo, _खोले,
  { {0x673d63fa,0x6d41234c,0x6d5c0066,0x00000000}},	//   _utsj, zpla, áraj,
  { {0x6d4163fb,0xc7d6009a,0x00000000,0x00000000}},	//   ypla, _טורי_,   ,
  { {0x66c00014,0x7c2d0022,0x6d4100e5,0x00000000}},	//   _vökt, _ogar, xpla,
  { {0x2366007c,0x1fb56095,0x7c2d63fc,0x00000000}},	//   broj_, есор, _ngar,
  { {0x7d040072,0x6d410c5f,0xf9070042,0x00000000}},	//   _rkis, wpla, _वीज़ा_,
  { {0x7c2d312f,0x7d0405fe,0x6d4163fd,0x00000000}},	//   _agar, _skis, tpla,
  { {0x75290122,0x1d0a0c91,0x69c101f2,0x00000000}},	//   _kiez, зени_, ølel,
  { {0x55da00b5,0xa2b90053,0x6d413770,0x00000000}},	//   פֿינ, ्सक्, rpla,
  { {0x68e40019,0x75291a40,0x442d00a4,0x00000000}},	//   viid, _miez, _mge_,
  { {0x6d4112f5,0x60c932fd,0x6d55013d,0x00000000}},	//   ppla, lkem, ázas,
  { {0x2cab0025,0x38c8007e,0x78bd0104,0x00000000}},	//   áidí_, واری_, _bosv,
  { {0x75290045,0x7d040035,0x442d1233,0x00000000}},	//   _niez, _ukis, _nge_,
  { {0x68e42c84,0xdbc7004b,0xb87b01c8,0x00000000}},	// [d2a0] riid, _sööm, _smíc,
  { {0x442d0037,0xdb7b00b5,0x68e4004b,0x00000000}},	//   _age_, _צװיש, siid,
  { {0x66c000c7,0x60c91a10,0x6f01002b,0x00000000}},	//   _söks, kkem, iolc,
  { {0x236663fe,0xd49702fe,0xe45201fb,0x00000000}},	//   troj_, ерш_, اضا_,
  { {0x6abe00bd,0xf1d80161,0x43940076,0x00000000}},	//   _kopf, _भेजन, талс,
  { {0x2d8763ff,0x236000c3,0xdbc7004b,0x00000000}},	//   _opne_, šijo_, _tööm,
  { {0x7ce8005b,0x693c004c,0x20190046,0x00000000}},	//   nırs, _učed, ýsin_,
  { {0x7de00066,0xdb1d004c,0xfbd00082,0x00000000}},	//   násť, vysí, हनाम,
  { {0x2480004b,0xb4be0042,0x00000000,0x00000000}},	//   õimu_, ेसी_,   ,
  { {0x60c900fe,0x7c2d6400,0x200a008f,0x00000000}},	//   akem, _sgar, ābi_,
  { {0xdcf00058,0x00000000,0x00000000,0x00000000}},	//   çeği,   ,   ,
  { {0xbebc001c,0x60560044,0x629a6401,0x00000000}},	//   kmīg, _أنشط, _hato,
  { {0x9b58011c,0x7ebf006c,0xddcb0130,0x00000000}},	//   ният_, _vêpr, ćišt,
  { {0x2f970063,0x7ceb0137,0x629a017d,0x00000000}},	//   _נכון_, förä, _jato,
  { {0x629a6402,0x3a2501e3,0x6abe0137,0x00000000}},	//   _mato, älp_, _dopf,
  { {0x6d5a6403,0x7c2d6404,0xe8941fa0,0x00000000}},	//   msta, _ugar, лась,
  { {0x6d5a6405,0x7c840055,0xe733013a,0x00000000}},	// [d2b0] lsta, _суще, اصر_,
  { {0x66c001e3,0x7ce8005b,0x629a1026,0x00000000}},	//   _sökr, bırs, _nato,
  { {0xeef70047,0x75296406,0x6d5a5965,0x00000000}},	//   עמבר_, _piez, nsta,
  { {0x7ae71df9,0xe507007e,0x629a078c,0x00000000}},	//   lijt, رباي, _aato,
  { {0x69c70072,0xe299342a,0x6d5a6407,0x00000000}},	//   lyje, дал_, hsta,
  { {0x6d5a6408,0x62620121,0x629a0e05,0x00000000}},	//   ksta, авша, _cato,
  { {0x60c90213,0x629a6409,0xba3c0041,0x00000000}},	//   tkem, _dato, לײגט,
  { {0x442d0146,0xceb80051,0xc2ed004c,0x00000000}},	//   _uge_, eję_, _řídí,
  { {0x629a0016,0x60c94594,0xa283007e,0x00000000}},	//   _fato, rkem, _میشو,
  { {0xaec20076,0x6d5a0da0,0x629a0e0f,0x00000000}},	//   ибыл, fsta, _gato,
  { {0x6d5a640a,0x6f01640b,0xdc6a3891,0x00000000}},	//   gsta, rolc, манд_,
  { {0x7bc60045,0x83fd00ea,0x4c830086,0x00000000}},	//   tyku, _időb, алюв,
  { {0x6f01640c,0x6d5a640d,0x7e6c006c,0x00000000}},	//   polc, asta, éopâ,
  { {0xceb80045,0x6a86005a,0xef180086,0x00000000}},	//   cję_, ълга, _змі_,
  { {0x7bc60150,0xfaa30699,0x6d5a08a5,0x00000000}},	//   syku, јасо, csta,
  { {0x26d10f89,0x657a004d,0x273601e1,0x00000000}},	//   _alzo_, _äthi, _pæn_,
  { {0xc05200b5,0x7ae71236,0x97c30257,0x00000000}},	// [d2c0] יזן_, bijt, айте,
  { {0x6abe01e1,0x86430591,0x27360046,0x00000000}},	//   _uopf, инуж, _væn_,
  { {0x629a640e,0xbebc008f,0x69c7056c,0x00000000}},	//   _rato, smīg, cyje,
  { {0xa3ce0235,0x4346000d,0x6d5c0405,0x00000000}},	//   शनल_, ведв, árai,
  { {0x8c43005b,0x629a640f,0x6d5a6410,0x00000000}},	//   _öğel, _pato, zsta,
  { {0x6d5a6411,0xf8bf006c,0x9423005e,0x00000000}},	//   ysta, _zoé_, јмље,
  { {0xdb0400ca,0x6d5a33f2,0x24840058,0x00000000}},	//   _arië, xsta, _tbmm_,
  { {0x629a0035,0x2eca0053,0x6d5a6412,0x00000000}},	//   _wato, िस्त, vsta,
  { {0x6d5a0045,0x69c70051,0xb87b017d,0x00000000}},	//   wsta, zyje, _omín,
  { {0x63a20150,0x4ea60591,0x6d5a3c36,0x00000000}},	//   mvon, триа, tsta,
  { {0xdb04008b,0x42d5000d,0x6c550121,0x00000000}},	//   _triê, _сіту, лкну,
  { {0x6913005b,0xceb80051,0x6d5a144b,0x00000000}},	//   eçen, sję_, rsta,
  { {0x3f98001c,0x5bb80121,0x6d5a0f8c,0x00000000}},	//   ārus_, вляя_, ssta,
  { {0x27ed1333,0x69c70072,0x6d5a1ff4,0x00000000}},	//   _ženo_, tyje, psta,
  { {0xdf15000d,0x7ae76413,0xa9540054,0x00000000}},	//   _сьць, rijt, икрі,
  { {0x66c000c7,0x257c0080,0x68fb00c2,0x00000000}},	//   _sökp, díl_, čudo,
  { {0x7ae7006f,0xf77000f2,0xe8940200,0x00000000}},	// [d2d0] pijt, قال_, шать,
  { {0xc6a70062,0x657e009c,0x0f7b009a,0x00000000}},	//   ърби, ftph, ורמל,
  { {0x63a26414,0x56940330,0x062701ce,0x00000000}},	//   evon, рахт, тфам,
  { {0xb87b0080,0x7c3d013d,0xe7910058,0x00000000}},	//   _zmín, ncsr, _göğü,
  { {0xdb040003,0x2f190003,0x62840130,0x00000000}},	//   _briè, lège_, đion,
  { {0x24510013,0xb3640062,0xe3b0002a,0x00000000}},	//   ạm_, ръцк, ترم_,
  { {0x45d50076,0x2f19006c,0xf5273461,0x00000000}},	//   _совс, nège_, _афан,
  { {0x320c001f,0x2f190003,0x00000000,0x00000000}},	//   _dydy_, iège_,   ,
  { {0x64590051,0xd4e40121,0x93f532e5,0x00000000}},	//   mawi, _тюри, _спац,
  { {0xe7aa0019,0x64596415,0x1e951d22,0x00000000}},	//   _tööõ, lawi, урир,
  { {0x5de50085,0xacea286c,0x00000000,0x00000000}},	//   ужна, емна_,   ,
  { {0x7e7e01e3,0xdb0400ca,0x7535096c,0x00000000}},	//   _öppn, _trië, _muzz,
  { {0x691301f7,0x75350a02,0x6283002b,0x00000000}},	//   tçen, _luzz, ofno,
  { {0x2d9500e1,0x64592f40,0x31a3005b,0x00000000}},	//   _брис, hawi, _kız_,
  { {0x2d98000e,0xdd03008f,0x6459516c,0x00000000}},	//   æret_, ņrād, kawi,
  { {0x64590045,0xddc80080,0x443f002b,0x00000000}},	//   jawi, jadř, _nfu_,
  { {0x98a3005a,0x9d1b0063,0x1f360047,0x00000000}},	// [d2e0] щите, _אוקט, ָרער_,
  { {0x7d06024a,0x75353bf2,0xe6c6005d,0x00000000}},	//   loks, _buzz, دتري,
  { {0x4a7b0047,0x7d060019,0x1e560047,0x00000000}},	//   _אריב, ooks, רשער_,
  { {0x7d0609ff,0x6459002c,0x2d51017f,0x00000000}},	//   noks, gawi, iše_,
  { {0x54530086,0xdb040164,0x63a20003,0x00000000}},	//   світ, _priè, uvon,
  { {0x2d510c61,0xd24f0021,0x63a26416,0x00000000}},	//   kše_, كنه_, rvon,
  { {0x2d510198,0x91860021,0x63a2015c,0x00000000}},	//   jše_, اجتم, svon,
  { {0xc034005e,0xc953009a,0xb1141313,0x00000000}},	//   шниј, זמה_, јмиш,
  { {0x6d4300eb,0x543b0047,0x752201f4,0x00000000}},	//   _atna, _װעבא, mmoz,
  { {0x7d0600fe,0xb87b00ed,0xb77b0047,0x00000000}},	//   eoks, _amíl, עאיש,
  { {0x40860062,0xd0860121,0x1df80121,0x00000000}},	//   _булб, _были, тены_,
  { {0x7d0f000f,0x7d060050,0x91bb009a,0x00000000}},	//   ulcs, goks, _רמאי,
  { {0x3eb800c7,0x2d8b000c,0x69c8000e,0x00000000}},	//   örts_, ăcea_, øden,
  { {0x945d0045,0x64590051,0x2d5100c2,0x00000000}},	//   _końc, zawi, bše_,
  { {0x7d061781,0x76550051,0x59f80121,0x00000000}},	//   boks, _rezy, геря_,
  { {0x60c2004b,0x6d4821fd,0x38c40094,0x00000000}},	//   _joom, mpda, бщув,
  { {0x6283001f,0x62886417,0x69dc00c2,0x00000000}},	// [d2f0] yfno, _obdo, azre,
  { {0x60c20004,0x6b8d002c,0x38bc0080,0x00000000}},	//   _loom, _ipag, _míry_,
  { {0x64590045,0xc5d90044,0x95570044,0x00000000}},	//   tawi, خواص_, اخطا,
  { {0x6b8d00a4,0xfc3f6126,0x62886418,0x00000000}},	//   _kpag, ncí_, _abdo,
  { {0xb8d9016a,0x20d80027,0x27f80024,0x00000000}},	//   चा_, _méid_, čenú_,
  { {0x6b8d00a4,0x2d510066,0x26cf001c,0x00000000}},	//   _mpag, yše_, īgos_,
  { {0xfc3f0080,0x64592f40,0x60c26419,0x00000000}},	//   kcí_, pawi, _boom,
  { {0xdd020066,0x2d513d08,0x90c50121,0x00000000}},	//   _ľuďm, vše_, рбие,
  { {0x63b600fe,0x60c60137,0x98a50078,0x00000000}},	//   äynt, ökma, ūlė_,
  { {0x66d20026,0xdb040003,0xfc3f0066,0x00000000}},	//   _lækn, _trié, ecí_,
  { {0x7d06024a,0x249f07c9,0x6b8d00c5,0x00000000}},	//   toks, _kaum_, _apag,
  { {0xce18000d,0x63a9641a,0x7d0600fe,0x00000000}},	//   ыцыі_, _kren, uoks,
  { {0x9f6b011c,0x2d9806a5,0x6d4800cd,0x00000000}},	//   _чрез_, ærer_, apda,
  { {0x212f0034,0x69dc004d,0xfaa60121,0x00000000}},	//   _high_, tzre, шаго,
  { {0xa8560095,0x6d5c14ab,0x672e00a8,0x00000000}},	//   итај, árat, _ribj,
  { {0xfc3208aa,0x2360007d,0x69dc004d,0x00000000}},	//   _بحث_, šiji_, rzre,
  { {0x66d200b9,0xe737005a,0x26c355a6,0x00000000}},	// [d300] _dækn, иет_, _bojo_,
  { {0x6f1d006f,0x8696005e,0x2ca0641b,0x00000000}},	//   ïsch, јјач, _haid_,
  { {0x63a9641c,0x200f0078,0x66030002,0x00000000}},	//   _aren, _lygi_, опфа,
  { {0x63a928e2,0x443200d1,0xa53301dd,0x00000000}},	//   _bren, øy_, ініч,
  { {0x2ca0010e,0xcc3b0047,0x63a9641d,0x00000000}},	//   _maid_, דענט, _cren,
  { {0x60c20019,0x2ca00cfc,0x809e0053,0x00000000}},	//   _soom, _laid_, _खोजे,
  { {0x20f7003b,0x63a9641e,0x649a11c7,0x00000000}},	//   răin_, _eren, _итар_,
  { {0x68f60185,0x2369017f,0x2ca0001f,0x00000000}},	//   nnyd, šaja_, _naid_,
  { {0x68f60185,0x999800c2,0x63a9641f,0x00000000}},	//   inyd, jbrž_, _gren,
  { {0xeeaa0002,0x38bc004c,0x68f6002b,0x00000000}},	//   ттик_, _víry_, hnyd,
  { {0x6b8d051e,0x60c20019,0x69c806a5,0x00000000}},	//   _spag, _toom, ødel,
  { {0xfc3f0080,0x4fea0612,0x69130058,0x00000000}},	//   ucí_, _имен_, tçem,
  { {0xd010007e,0xfc3f4380,0x2ca0002b,0x00000000}},	//   _علت_, rcí_, _daid_,
  { {0x6d480a2e,0xdb240026,0x68f6001f,0x00000000}},	//   ppda, ærðu, enyd,
  { {0x68f60c70,0x394500e8,0x26c302dd,0x00000000}},	//   fnyd, ëls_, _rojo_,
  { {0x2f0b0146,0xfce400d7,0x6f0800a8,0x00000000}},	//   søgt_, _мојо, lodc,
  { {0x61350006,0x249f00bd,0x7d0d39b9,0x00000000}},	// [d310] _išle, _raum_, _ikas,
  { {0xba990086,0x85a70001,0x2ca0179b,0x00000000}},	//   _своє_, ијед, _zaid_,
  { {0x66d20026,0xa6340054,0x26c30077,0x00000000}},	//   _tækn, інці, _vojo_,
  { {0x98480062,0x63a96420,0x84670062,0x00000000}},	//   _вяра_, _pren, ръже,
  { {0x20d10025,0xdb1d0072,0x68ed6421,0x00000000}},	//   _dáil_, pysä, miad,
  { {0x68ed6422,0x0577007e,0x130801dd,0x00000000}},	//   liad, _پاسد, аній_,
  { {0x20d10027,0x7d0d002c,0x3ce9004b,0x00000000}},	//   _fáil_, _okas, _omav_,
  { {0x68ed0185,0x63a96423,0xf94a0041,0x00000000}},	//   niad, _tren, נעפֿ,
  { {0x63a90035,0xc0c80001,0x693c007d,0x00000000}},	//   _uren, рује_, _ačel,
  { {0x2ca06424,0x2011001c,0x68ed0123,0x00000000}},	//   _said_, āzi_, hiad,
  { {0x68f60185,0xdca61259,0x2ca01d1f,0x00000000}},	//   ynyd, бани, _paid_,
  { {0x29090072,0xdb0e004c,0xc5f2009a,0x00000000}},	//   joaa_, ějíc, לדי_,
  { {0x2ca00004,0x68ed6425,0x2019004b,0x00000000}},	//   _vaid_, diad, üsid_,
  { {0xce940062,0x68f6002b,0x2fdf0244,0x00000000}},	//   _мачъ, wnyd, mzug_,
  { {0x68ed0185,0x2f0b00b9,0x2ca0002b,0x00000000}},	//   fiad, søgs_, _taid_,
  { {0x60db0016,0xa3d70053,0xdb0400cd,0x00000000}},	//   nhum, ाना_, _triï,
  { {0xbb860032,0x386f0025,0xe7aa0076,0x00000000}},	// [d320] _الخي, ógra_, ывал_,
  { {0xa142008f,0x86750085,0x3bbb009a,0x00000000}},	//   šķin, жыцц, _עמיד,
  { {0x1a9b0047,0x8d5a0047,0x68ed6426,0x00000000}},	//   _גייע, ָכני, biad,
  { {0x69ce0006,0x68ed0ba0,0x045a00f2,0x00000000}},	//   mybe, ciad, اجات_,
  { {0x60db0035,0xd4670002,0xfe780078,0x00000000}},	//   dhum, сиче_, ygį_,
  { {0xd5d60475,0x067502fe,0xf7430f55,0x00000000}},	//   _любы, _муся, _херо,
  { {0x60c60137,0x6f084c1d,0xc5d50054,0x00000000}},	//   ökmo, vodc, _діть,
  { {0x765e00eb,0x78a46427,0x7c36002b,0x00000000}},	//   lapy, ndiv, _ngyr,
  { {0xd0100021,0x9f5f0014,0x69ce0575,0x00000000}},	//   بلة_, ýrði_, hybe,
  { {0x27e0005b,0x693c007d,0x7d0d0022,0x00000000}},	//   izin_, _pčel, _skas,
  { {0xc04f0651,0x6f084684,0x60db6428,0x00000000}},	//   _ні_, rodc, bhum,
  { {0x691301f7,0x69ce00b9,0x60db6429,0x00000000}},	//   rçek, dybe, chum,
  { {0x78a4051e,0x68ed33c5,0x7d0d08a9,0x00000000}},	//   ddiv, viad, _vkas,
  { {0x27e00045,0x68ed584f,0x7c36013d,0x00000000}},	//   dzin_, wiad, _egyr,
  { {0x15e80235,0x68ed642a,0x6ce7013c,0x00000000}},	//   _टेलर_, tiad, _гіпе,
  { {0x32cb0031,0x765e005f,0x6135004c,0x00000000}},	//   _høyt_, eapy, _ušle,
  { {0x68ed10c1,0xe9180054,0x69ce0058,0x00000000}},	// [d330] riad, соті_, aybe,
  { {0x98be001c,0xa3ac0053,0x68ed642b,0x00000000}},	//   ītā_, गिन_, siad,
  { {0x69ce0122,0x68ed0283,0x98a20078,0x00000000}},	//   cybe, piad, _likę_,
  { {0x76490058,0x84150a16,0xd6c30043,0x00000000}},	//   _şeyd, омех, _کمسی,
  { {0x987a0047,0xdc8c0063,0xd006013a,0x00000000}},	//   _דארט, רְבָ, _آل_,
  { {0x236900c3,0xd1c90074,0x8c1c009a,0x00000000}},	//   šajo_, илле_, אודי,
  { {0xa4d5019d,0x60db1785,0xe1250a91,0x00000000}},	//   _дові, thum, омки,
  { {0x2b49017f,0x20d10025,0xdce2008f,0x00000000}},	//   _otac_, _táim_, rtlī,
  { {0x7e990044,0x60db2fd9,0xa8cc009a,0x00000000}},	//   لنظر_, rhum, ר֖וֹ,
  { {0x7c360185,0x69c800b9,0x2fdf004d,0x00000000}},	//   _sgyr, ødek, rzug_,
  { {0xed590138,0x2b491f1c,0x60db00ac,0x00000000}},	//   јом_, _atac_, phum,
  { {0x7fd50304,0x69ce642c,0x41740049,0x00000000}},	//   _мілі, vybe, _رامس,
  { {0xf8bf0003,0xf8b80013,0x78a401d1,0x00000000}},	//   _liés_, _đĩ_, vdiv,
  { {0x69ce0006,0x7ce8013d,0xaf04012c,0x00000000}},	//   tybe, zűrh, _епіл,
  { {0xd9430259,0x19b90086,0x7c3b007d,0x00000000}},	//   деси, буть_, žura,
  { {0x27e0642d,0x69ce1a99,0x645b642e,0x00000000}},	//   tzin_, rybe, _neui,
  { {0xf0920063,0x46ea2099,0xfaa60085,0x00000000}},	// [d340] ונן_, адан_, _дапо,
  { {0x3200005b,0xa3bd0042,0xe7170043,0x00000000}},	//   şiyi_, इमन_, قيقت_,
  { {0x66d2007a,0x2d850034,0xfc3f006d,0x00000000}},	//   _hækk, ntle_, ldía_,
  { {0xfc3f006d,0x83fd00ea,0xd876005d,0x00000000}},	//   odía_, _időj, _بادب,
  { {0xfc3f02dd,0x693c1eb3,0x645b0003,0x00000000}},	//   ndía_, _oček, _deui,
  { {0x8c1b0063,0x6442642f,0x60d9002b,0x00000000}},	//   בוני, scoi, _alwm,
  { {0x645b0164,0xd259126b,0x66d20026,0x00000000}},	//   _feui, сці_, _lækk,
  { {0x765c0cc6,0x38606430,0x645b006f,0x00000000}},	//   _hery, nair_, _geui,
  { {0x60f70088,0xb6020080,0x7bcf6431,0x00000000}},	//   ўныя_, řádn, xycu,
  { {0x38600027,0x6101001c,0x66d20026,0x00000000}},	//   hair_, vēle, _sækj,
  { {0x62986432,0x06970063,0x25a500ea,0x00000000}},	//   mevo, חדים_, _állt_,
  { {0x628a001f,0x753c0022,0xa6db0046,0x00000000}},	//   lffo, _murz, _guðf,
  { {0x613500eb,0x62980122,0xd0f90047,0x00000000}},	//   _išla, oevo, _פּער,
  { {0x66d20146,0x2d8500e5,0x628a002b,0x00000000}},	//   _dækk, btle_, nffo,
  { {0x66d2007a,0x386000f6,0x273f001f,0x00000000}},	//   _tækj, fair_, _sîn_,
  { {0x66d20026,0x38602389,0x63ad0066,0x00000000}},	//   _fækk, gair_, ťani,
  { {0x14ab0053,0x62984166,0x765c6433,0x00000000}},	// [d350] _घोषण, kevo, _bery,
  { {0x62981eb3,0x645b0003,0x628a006f,0x00000000}},	//   jevo, _seui, jffo,
  { {0x38600025,0xba9a0063,0x6a9a0063,0x00000000}},	//   bair_, _הסתי, _השתנ,
  { {0x291e00cd,0x38604b46,0x27ed059d,0x00000000}},	//   ïtat_, cair_, _ženu_,
  { {0x645b0164,0x83fd00ea,0x693c0078,0x00000000}},	//   _veui, _idők, _ačeh,
  { {0x62980ac8,0xe2996434,0xe7f80042,0x00000000}},	//   gevo, сак_, ंपरा_,
  { {0x6aa55fd7,0xa156005e,0xd1790085,0x00000000}},	//   _mahf, пају_, ёскі_,
  { {0x673d0019,0x76456435,0x945d056c,0x00000000}},	//   _kusj, lchy, _końm,
  { {0xb4d70161,0x753c00bd,0x62983816,0x00000000}},	//   िसी_, _zurz, bevo,
  { {0x66d20146,0x2d850034,0xd2510021,0x00000000}},	//   _rækk, ttle_, _أنا_,
  { {0x66d201e1,0xdca60f34,0xc035005e,0x00000000}},	//   _sækk, пани, _енеј,
  { {0xd0110021,0x23720078,0x2d856436,0x00000000}},	//   _كلا_, šyje_, rtle_,
  { {0x386000cd,0x2d856437,0xf3f9003b,0x00000000}},	//   vair_, stle_, _feţe_,
  { {0xfc3f006d,0x66d200b9,0xa3ac0053,0x00000000}},	//   rdía_, _vækk, गित_,
  { {0x38605b39,0xc3320063,0x7e616438,0x00000000}},	//   tair_, תום_, malp,
  { {0xe2070051,0x38600025,0x7645001f,0x00000000}},	//   ciół_, uair_, echy,
  { {0xdb0400cd,0xfbd20021,0x36960062,0x00000000}},	// [d360] _trià, _ستة_, зшес,
  { {0x2d67007d,0xe9da0121,0x7e616439,0x00000000}},	//   ođe_, _гко_, nalp,
  { {0x80db0161,0x386016c0,0x2a570063,0x00000000}},	//   बसाइ, pair_, _מבין_,
  { {0x765c0051,0x19bb0063,0xe4a30054,0x00000000}},	//   _wery, _המטב, ершо,
  { {0x7e61003d,0x753c00bd,0x6298643a,0x00000000}},	//   kalp, _wurz, tevo,
  { {0x6298006d,0xe57f001c,0x628a192a,0x00000000}},	//   uevo, šķas_, uffo,
  { {0x78a6017f,0x628a0185,0x6913005b,0x00000000}},	//   _kakv, rffo, rçev,
  { {0x61250026,0x4034042a,0x6298643b,0x00000000}},	//   hólf, мейс, sevo,
  { {0x20d80027,0x6298643c,0x30130062,0x00000000}},	//   _féin_, pevo, ндър,
  { {0xe8040053,0x62810139,0x7e613712,0x00000000}},	//   _रखना_, _gclo, galp,
  { {0xdc990086,0x20190014,0xe2970094,0x00000000}},	//   овні_, ýsir_, _хах_,
  { {0x98ab000c,0x7e61004b,0x225e004b,0x00000000}},	//   _mică_, aalp, _hetk_,
  { {0x6b9d006f,0x66d3005b,0x7645057c,0x00000000}},	//   uwsg, _yıkı, ychy,
  { {0x8f9b0063,0x4fd30054,0x61250046,0x00000000}},	//   _לידי, _яжіт, gólf,
  { {0x673d1fc3,0x6d4a00cf,0x1a780085,0x00000000}},	//   _susj, _utfa, ябры_,
  { {0x213e0244,0x6934643d,0x5dfb009a,0x00000000}},	//   _muth_, енсу, _לפונ,
  { {0x47352fe9,0x6aa50089,0xf7940085,0x00000000}},	// [d370] днас, _tahf, натэ,
  { {0xb9990086,0x79a706da,0xb7140121,0x00000000}},	//   _двох_, _ерме, едущ,
  { {0xddcd0006,0x26ca00c2,0x7645643e,0x00000000}},	//   _įkūr, _dobo_, rchy,
  { {0x94190076,0x66150080,0x66d3005b,0x00000000}},	//   ожет_, _vyzk, _sıkı,
  { {0x213e643f,0xc1b70082,0x00000000,0x00000000}},	//   _auth_, ेङ्ग,   ,
  { {0x90d5001b,0x77ba009a,0x67ba009a,0x00000000}},	//   _cùn, _ומשח, _ומשק,
  { {0x26fb0161,0xd179000d,0x90d5008b,0x00000000}},	//   ्वीर_, іскі_, _dùn,
  { {0xb465007e,0x66d20046,0xc10501f3,0x00000000}},	//   _آگاه, _ræki, بوبي,
  { {0x7e616440,0x98ab003b,0x66d20014,0x00000000}},	//   talp, _zică_, _sæki,
  { {0xef160055,0xed450699,0xb87b4cbf,0x00000000}},	//   ммы_, мноп, _hlíd,
  { {0xfc3f006d,0x213e0139,0xddc10078,0x00000000}},	//   rdín_, _guth_, malū,
  { {0x2d67007d,0x7e616441,0x8f75012c,0x00000000}},	//   rđe_, salp, _жукі,
  { {0x69130058,0x78a66442,0x6b8b00a5,0x00000000}},	//   hçes, _rakv, _äggl,
  { {0xed590138,0x66d20026,0x6913005b,0x00000000}},	//   _док_, _tæki, kçes,
  { {0x78a600eb,0x26ca6443,0x7d0f00ea,0x00000000}},	//   _pakv, _robo_, bocs,
  { {0x693c007d,0x26ca00c2,0xd87a0021,0x00000000}},	//   _očev, _sobo_, تمرت_,
  { {0xf77201a7,0x59ba0053,0x3ea71b26,0x00000000}},	// [d380] ضاء_, _उपकर, _kant_,
  { {0xde8e008b,0x644900ed,0x61250014,0x00000000}},	//   _lịng_, _afei, bólg,
  { {0x2726001b,0x78a66444,0x60cb0104,0x00000000}},	//   hông_, _takv, _oogm,
  { {0x60cb0122,0x3ea7090d,0xc6890063,0x00000000}},	//   _nogm, _lant_, יא_,
  { {0x2b7b00b5,0x443200fe,0xa2940086,0x00000000}},	//   ַטקײ, äy_, еалі,
  { {0x64490016,0x6101003d,0x3ea7001f,0x00000000}},	//   _efei, vēla, _nant_,
  { {0x64490185,0x60cb0146,0x90d5008b,0x00000000}},	//   _ffei, _bogm, _vùn,
  { {0x6101008f,0xd702000d,0xa6db0014,0x00000000}},	//   tēla, нiча, _guðb,
  { {0x60cb2357,0x90d50013,0xde8e008d,0x00000000}},	//   _dogm, _tùn, _dịng_,
  { {0x2018001c,0x61f900ea,0x3ea76445,0x00000000}},	//   āri_, áblá, _cant_,
  { {0x6b960078,0x6449002b,0x9d191915,0x00000000}},	//   _apyg, _yfei, зонт_,
  { {0xfc3f006d,0x3eb8013d,0xad270043,0x00000000}},	//   rdío_, űrt_, برخو,
  { {0x3ea70031,0x9b58005a,0xdfd20021,0x00000000}},	//   _fant_, мият_, _جيش_,
  { {0x3ea76446,0xab2b0044,0x6e9300de,0x00000000}},	//   _gant_, تسجل_, _للها,
  { {0x20d80027,0xdb0d0003,0xdce2001c,0x00000000}},	//   _léim_, _fraî, gulē,
  { {0xe894000d,0x6913005b,0x25f40053,0x00000000}},	//   кась, eçer, ्पनी_,
  { {0xdd90005d,0x66b56447,0x6bd90044,0x00000000}},	// [d390] _شوک_, нбау, _رودس_,
  { {0x4a550086,0xfc3f01d1,0x20d10025,0x00000000}},	//   _якос, zdíl_, _háit_,
  { {0x644900bd,0x6da90047,0x6125013d,0x00000000}},	//   _pfei, ּׁנֶ, lóle,
  { {0x24580088,0xe57f008f,0x20d80139,0x00000000}},	//   даць_, šķos_, _béim_,
  { {0x20d80025,0x69d50d11,0xe6671efa,0x00000000}},	//   _céim_, lyze, _отво,
  { {0xe8040053,0x66d20026,0x1b7c0041,0x00000000}},	//   _रखता_, _bæku, קטוע,
  { {0xb87b0080,0x3ea76448,0x21270043,0x00000000}},	//   _umís, _rant_, ويتی_,
  { {0x3ea76449,0xdbc7005b,0xb87b004c,0x00000000}},	//   _sant_, _göçm, _zmír,
  { {0xde8e0013,0x3ea7644a,0x7f190085,0x00000000}},	//   _vịng_, _pant_, зіну_,
  { {0x92b40021,0xddc501ce,0xa22700de,0x00000000}},	//   _لحما, ебои, _قراه,
  { {0x3ea73327,0xa3d70053,0xc692009f,0x00000000}},	//   _vant_, ानक_, נאט_,
  { {0x3ea7644b,0x98ac001c,0x27260003,0x00000000}},	//   _want_, īdī_, mône_,
  { {0x3ea70623,0xbed5005e,0x2ca90983,0x00000000}},	//   _tant_, _подј, _daad_,
  { {0x693c08ea,0x3ea700cd,0xbea221a7,0x00000000}},	//   _očet, _uant_, _башк,
  { {0xdb0d0164,0x682a00ea,0xf2d20047,0x00000000}},	//   _traî, ködé, נעל_,
  { {0xaa870013,0xdb0d0066,0xb87b004c,0x00000000}},	//   _phýõ, ľkác, _smír,
  { {0xcb6a007e,0x6676007e,0x3935000d,0x00000000}},	// [d3a0] _عمده_, فدار, тэрс,
  { {0x2ca9006f,0x69c800b9,0x20d80139,0x00000000}},	//   _zaad_, ødes, _réim_,
  { {0x69c10019,0x6101001c,0xda5b0063,0x00000000}},	//   älet, vēln, _מכיל,
  { {0xe73a14cf,0xa5070094,0xd516005d,0x00000000}},	//   _нем_, неха_, رباغ,
  { {0x883b0063,0x291200be,0x7de6013d,0x00000000}},	//   _מתכו, moya_, _késé,
  { {0x68e40016,0x290014e0,0xb87b004c,0x00000000}},	//   lhid, lnia_, _umír,
  { {0x0496000d,0x6d475ddb,0x76430066,0x00000000}},	//   _праў, íjal, žnyc,
  { {0x7c240198,0x2900644c,0xb87b16eb,0x00000000}},	//   _ozir, nnia_, _ilíc,
  { {0xd2520032,0x289b0047,0x2ca96113,0x00000000}},	//   _منذ_, ליקא, _raad_,
  { {0x61080080,0x2ca90019,0x63a20035,0x00000000}},	//   děle, _saad_, mwon,
  { {0x20d6019d,0x3ce01368,0x68e40089,0x00000000}},	//   _підс, _bliv_, khid,
  { {0x2900644d,0xade30054,0xafe60854,0x00000000}},	//   jnia_, уцьк, _поел,
  { {0x63a2006f,0x693c00c2,0x613500c2,0x00000000}},	//   nwon, _očes, _ošlj,
  { {0x29000045,0x657e00ac,0x83fd00ea,0x00000000}},	//   enia_, kuph, _időt,
  { {0xe9190086,0x7de60003,0x7af500ea,0x00000000}},	//   дові_, _désé, rizt,
  { {0x5ba70086,0x2900644e,0xdb0d0813,0x00000000}},	//   _зроз, gnia_, _traï,
  { {0xa6db0014,0x69c806a5,0x63a2006f,0x00000000}},	// [d3b0] _auða, øder, jwon,
  { {0x7d040080,0x63a2006f,0x7d1d444e,0x00000000}},	//   _zjis, dwon, llss,
  { {0x2912006d,0x63a206aa,0x69c101e1,0x00000000}},	//   boya_, ewon, åled,
  { {0x693c0080,0x68e409ee,0x6101001c,0x00000000}},	//   _včet, chid, vēlo,
  { {0x78ad0006,0xd414000d,0x03a51d11,0x00000000}},	//   mdav, льшы, тило,
  { {0x6101001c,0x78ad644f,0xf8bf0013,0x00000000}},	//   tēlo, ldav, _khéo_,
  { {0x693c00c2,0x78ad6450,0x8aac0063,0x00000000}},	//   _hčer, odav, לֹהֶ,
  { {0x78ad6451,0x84640062,0xe534014b,0x00000000}},	//   ndav, _бъфе, _бесь,
  { {0x27e902dd,0x60090086,0x78ad6452,0x00000000}},	//   nzan_, ьним_, idav,
  { {0x29000686,0xdce2008f,0x59b30042,0x00000000}},	//   znia_, dslā, ुमार,
  { {0x753b0035,0x1d0a0c8d,0x78ad0078,0x00000000}},	//   _kiuz, дени_, kdav,
  { {0x2369017f,0x7649005b,0xcb6a026b,0x00000000}},	//   šaju_, _şeyl, маме_,
  { {0x83fd000f,0x3ce00080,0x20d10026,0x00000000}},	//   _idős, _vliv_, _fáir_,
  { {0x60db003d,0x29000051,0x62832142,0x00000000}},	//   lkum, wnia_, ngno,
  { {0x3f8d0268,0x443f007d,0xf8bf008b,0x00000000}},	//   lteu_, _ogu_, _chéo_,
  { {0xa7fb02dd,0x7d040080,0x443f0013,0x00000000}},	//   _seña, _ujis, _ngu_,
  { {0x3f8d0268,0x6d430185,0xa7fb0118,0x00000000}},	// [d3c0] nteu_, _huna, _peña,
  { {0x39460076,0x78ad0024,0x6d430e39,0x00000000}},	//   _иног, adav, _kuna,
  { {0x60c90031,0x60db0449,0x64a605fb,0x00000000}},	//   kjem, kkum, кажа,
  { {0x75290035,0x628300ac,0x6d431d12,0x00000000}},	//   _chez, egno, _muna,
  { {0xd4670001,0x31da0053,0xa8030065,0x00000000}},	//   тиче_, बन्ध, _взял,
  { {0x66d200b9,0xa3d3000d,0x7cf6008f,0x00000000}},	//   _væks, рошч, kšro,
  { {0x693c017f,0x98a0017f,0x22d50085,0x00000000}},	//   _učes, gmić_, ыццё,
  { {0x60db002c,0x7c3b0c61,0x6283159d,0x00000000}},	//   gkum, žuri, agno,
  { {0x68e3000c,0x673c0f75,0x6d436453,0x00000000}},	//   _înde, _kirj, _auna,
  { {0x661c02eb,0x6d430027,0x78ad2e6a,0x00000000}},	//   _kyrk, _buna, zdav,
  { {0x6d44034d,0x7e630150,0x867b0063,0x00000000}},	//   _čias, _denp, וריו,
  { {0x3f8d0268,0x3eb9001c,0x83fd00ea,0x00000000}},	//   bteu_, ēsta_, _időr,
  { {0x3f8d0268,0x7d1d6454,0x9f9c0014,0x00000000}},	//   cteu_, rlss, _gæða_,
  { {0xdb0d0e7c,0x67da008f,0xdce20078,0x00000000}},	//   _traí, _mājā, kulė,
  { {0x6d43003e,0x7b05001c,0x661c0072,0x00000000}},	//   _guna, _ērtā, _nyrk,
  { {0x7ce66455,0x6abe0244,0xce37009a,0x00000000}},	//   _córd, _enpf, _באות_,
  { {0x6d436456,0x78ad6457,0xbebc0023,0x00000000}},	// [d3d0] _zuna, rdav, glīg,
  { {0x60db0080,0xfd1f0290,0x6d436458,0x00000000}},	//   zkum, llì_, _yuna,
  { {0x673c00f3,0x78ad6459,0xb87b645a,0x00000000}},	//   _dirj, pdav, _elía,
  { {0x661c02ea,0x61250014,0x00000000,0x00000000}},	//   _dyrk, kóla,   ,
  { {0xf8bf0024,0xb0b60053,0xdfc601a7,0x00000000}},	//   _iné_, _अफ़ग, _اي_,
  { {0x38690162,0x61350006,0x661c0137,0x00000000}},	//   laar_, _išli, _fyrk,
  { {0x60db01a9,0x92680699,0xb2840085,0x00000000}},	//   tkum, трча_, рычк,
  { {0x386904c6,0x7ce65969,0x60db42b2,0x00000000}},	//   naar_, _kóre, ukum,
  { {0x60c9003e,0x6d4323c1,0xbebc001c,0x00000000}},	//   rjem, _suna, klīd,
  { {0xfe710032,0x6d440024,0x60c93b20,0x00000000}},	//   حدة_, _čiar, sjem,
  { {0x3f8d0268,0x38690173,0x26d1006d,0x00000000}},	//   steu_, kaar_, _mozo_,
  { {0x3f8d0268,0x7e68006f,0x38690983,0x00000000}},	//   pteu_, aadp, jaar_,
  { {0x3869006f,0xd1100053,0x7e630f20,0x00000000}},	//   daar_, ावरण_, _tenp,
  { {0x6d43645b,0x2919645c,0xbb4305ce,0x00000000}},	//   _tuna, _aksa_, серк,
  { {0x6d4300a4,0x09e30320,0x5d75013f,0x00000000}},	//   _uuna, борн, _сулф,
  { {0xbebc001c,0x4c860818,0xa855005e,0x00000000}},	//   alīd, _слив, итуј,
  { {0xdd04008f,0x673c0130,0x7ce60022,0x00000000}},	// [d3e0] šsēd, _pirj, _córe,
  { {0x661c00fe,0x6b5b009a,0x00000000,0x00000000}},	//   _pyrk, _רדיפ,   ,
  { {0x38690173,0x63a9645d,0xd62a01d5,0x00000000}},	//   baar_, _asen, хоже_,
  { {0x98ba0529,0xe97b0047,0xf8bf0139,0x00000000}},	//   _după_, _אנטש, _gné_,
  { {0x6674007e,0x63a900ea,0xb87b004c,0x00000000}},	//   _نگار, _csen, _klín,
  { {0x61080080,0x661c645e,0x26d142b1,0x00000000}},	//   děla, _tyrk, _gozo_,
  { {0x63a9645f,0xb87b0139,0xd6271849,0x00000000}},	//   _esen, _mlín, _боре_,
  { {0x6ad10161,0x63a900b9,0xe6173beb,0x00000000}},	//   _सक्र, _fsen, _сдс_,
  { {0x8406000d,0xdfd00593,0xd007005e,0x00000000}},	//   _спаж, زيد_, леће_,
  { {0x83fd00ea,0x2a6a00ea,0x612500ea,0x00000000}},	//   _időp, jabb_, róla,
  { {0xa3ac0053,0x02d51705,0xdd94000d,0x00000000}},	//   गिक_, _тютю, шаны,
  { {0x70560032,0xc5f30063,0xa6db0014,0x00000000}},	//   _إنشا, מדת_, _auðl,
  { {0x38691038,0xfd1f0290,0x7e6800a4,0x00000000}},	//   vaar_, rlì_, padp,
  { {0xa7fb02dd,0x38690250,0xb87b0e57,0x00000000}},	//   _seño, waar_, _clín,
  { {0x38692792,0xda350121,0xbebc0023,0x00000000}},	//   taar_, ревы, rlīd,
  { {0x3eae6460,0x671d0042,0xa8551f9d,0x00000000}},	//   _haft_, _बीजक_, ркач,
  { {0x9817006a,0x38690179,0x26d1006d,0x00000000}},	// [d3f0] ابزا, raar_, _pozo_,
  { {0x386925d2,0xa3b30053,0xa6db0014,0x00000000}},	//   saar_, टिस_, _guðl,
  { {0x38690518,0x32f60022,0x07080044,0x00000000}},	//   paar_, głym_, ديلي_,
  { {0xddc1000c,0xa8a703d6,0xb87b6461,0x00000000}},	//   lalţ, _срок, _zlín,
  { {0xb4640086,0x3cfd0053,0x69c8004b,0x00000000}},	//   скіл, _लगने_, ädev,
  { {0x61250045,0x3f98000c,0x877a0047,0x00000000}},	//   góln, ărul_, _באשי,
  { {0xd49b0088,0x3abc0063,0x45d50054,0x00000000}},	//   _пра_, תמונ, _товс,
  { {0x63a9004b,0x2a6a00ea,0x7ce60139,0x00000000}},	//   _tsen, zabb_, _mórc,
  { {0x6d4e02dd,0x3fc7007e,0x63a96462,0x00000000}},	//   íban, ادعی_, _usen,
  { {0xb77c0047,0x877c0047,0x3eb9008f,0x00000000}},	//   גאזש, גאזי, ēsto_,
  { {0xf2c400a0,0x6cc602e1,0xa2c20042,0x00000000}},	//   _устн, айна, लार्,
  { {0x61250e7c,0x1fb50121,0x201d002b,0x00000000}},	//   mólo, _вскр, _tywi_,
  { {0x2a6a013d,0x3b830e74,0x3fc9005d,0x00000000}},	//   tabb_, оляг, _جدای_,
  { {0xbebc001c,0xd5b8008f,0xab2a4218,0x00000000}},	//   alīb, _šām_, тога_,
  { {0x2a6a013d,0x61250516,0xa9670062,0x00000000}},	//   rabb_, nólo, иира_,
  { {0x2a6a000f,0xb87b0139,0x3eae4cce,0x00000000}},	//   sabb_, _dlío, _zaft_,

  { {0xb8fe0394,0x96660076,0x65b0013d,0x00000000}},	// [d400] _तक_, икае, kóhá,
  { {0xe9da25d9,0x06560085,0xf6260867,0x00000000}},	//   _ако_, ртаў, адзо,
  { {0xa6db0014,0x6108004c,0x7afc36cb,0x00000000}},	//   _guðm, děln, mirt,
  { {0x7afc01f7,0x32f6056c,0xe4760085,0x00000000}},	//   lirt, rłym_, ружэ,
  { {0x33f6000a,0x68e3000c,0x6101008f,0x00000000}},	//   јчес, _înda, cēli,
  { {0x66e60581,0x7afc1f83,0x78af00a8,0x00000000}},	//   _тога, nirt, _zacv,
  { {0x7afc00fe,0x32650054,0x3eae6463,0x00000000}},	//   iirt, стів, _raft_,
  { {0xa3b30053,0x3eae5768,0xc95300ff,0x00000000}},	//   टिश_, _saft_, חמה_,
  { {0x61250045,0x7522006f,0x7afc6464,0x00000000}},	//   póln, mloz, kirt,
  { {0x75226465,0xf402008f,0x69dc005f,0x00000000}},	//   lloz, riģē_, kyre,
  { {0x10a605fb,0x78a40006,0x61250460,0x00000000}},	//   _виен, keiv, cólo,
  { {0x69dc2f3a,0x7522006f,0x4c950121,0x00000000}},	//   dyre, nloz, щимс,
  { {0x69da00d1,0x657e0025,0x8f5403eb,0x00000000}},	//   øten, hrph, _انتش,
  { {0x6101003d,0x3f846466,0x3f91000c,0x00000000}},	//   vēli, mumu_, ăzut_,
  { {0x5d840032,0x89370032,0xdcfb001c,0x00000000}},	//   _العل, لعرا, autā,
  { {0xdb0d017d,0x6d5a6467,0x6101001c,0x00000000}},	//   _oraç, mpta, tēli,
  { {0x629a00c3,0x7522017f,0x7afc6468,0x00000000}},	// [d410] _obto, dloz, birt,
  { {0x45450032,0x69dc10c4,0xab28005e,0x00000000}},	//   منطق, byre, _коња_,
  { {0xdb0d01f7,0x3f840035,0x79a7018e,0x00000000}},	//   _araç, humu_, _трпе,
  { {0x78a40037,0x4518019d,0x3f844efe,0x00000000}},	//   ceiv, ація_, kumu_,
  { {0x3f840418,0x07a4000d,0x889a0063,0x00000000}},	//   jumu_, _даўн, _גברי,
  { {0x60c26469,0x3f84646a,0x69c800d1,0x00000000}},	//   _anom, dumu_, ådeg,
  { {0xe057007e,0xddda0080,0xfa780063,0x00000000}},	//   لیات_, patř, בעות_,
  { {0xf8a70161,0xdb0d017d,0x27ed0114,0x00000000}},	//   ख़िय, _fraç, _ženy_,
  { {0xdb0d0016,0xef19005a,0xfc3f0025,0x00000000}},	//   _graç, лми_, idís_,
  { {0x60c200c7,0x0d85137a,0x612537c9,0x00000000}},	//   _enom, блон, pólo,
  { {0xa6db007a,0x6da50905,0x290b0051,0x00000000}},	//   _auðk, щина, _ojca_,
  { {0x7afc00bd,0x63bb61c4,0xddc1646b,0x00000000}},	//   wirt, _krun, galš,
  { {0x69c10031,0x7ce60025,0x7afc0006,0x00000000}},	//   ålen, _córa, tirt,
  { {0x75220253,0xfe450002,0x69dc0196,0x00000000}},	//   zloz, _унко, tyre,
  { {0xf2d20047,0x7afc007a,0x3ea5646c,0x00000000}},	//   לעך_, rirt, melt_,
  { {0x26c3017d,0x7ce60066,0xdcfb008f,0x00000000}},	//   _anjo_, _fóra, putā,
  { {0x69dc63d1,0x7ce60022,0xb87b0014,0x00000000}},	// [d420] syre, _góra, _glím,
  { {0xd308008b,0x3ea5646d,0x78a4013d,0x00000000}},	//   iệc_, nelt_, seiv,
  { {0x69c80031,0xfad70047,0x63bb646e,0x00000000}},	//   åded, _הויך_, _arun,
  { {0x20d80027,0xdb0d0016,0x3ea51255,0x00000000}},	//   _léir_, _praç, helt_,
  { {0x3ea51781,0x2d851555,0xdcfb003b,0x00000000}},	//   kelt_, hule_, lută,
  { {0x3f84003d,0x2d853fbc,0x63bb646f,0x00000000}},	//   vumu_, kule_, _drun,
  { {0xd130006a,0x21670001,0x2d8514e3,0x00000000}},	//   ومت_, бији_, jule_,
  { {0x63bb000c,0x20d8017d,0xdb0d6470,0x00000000}},	//   _frun, _réis_, _traç,
  { {0x39420004,0x63bb2767,0x3ea53fc8,0x00000000}},	//   _miks_, _grun, felt_,
  { {0xd36f0021,0x3f840f3a,0x6b8600ac,0x00000000}},	//   _أهل_, rumu_, dukg,
  { {0x2d856471,0x38604a6b,0xdcfb003b,0x00000000}},	//   gule_, kbir_, jută,
  { {0xf1b3014e,0x39420438,0xdb04032a,0x00000000}},	//   _מסע_, _niks_, _asià,
  { {0x8fa30076,0x38600d87,0xdb0400cd,0x00000000}},	//   _наце, dbir_, _friü,
  { {0x3ea5001c,0x6d5a6472,0xde580454,0x00000000}},	//   celt_, ppta, _такі_,
  { {0xf3f90529,0x2d852914,0x272f0058,0x00000000}},	//   _veţi_, cule_, nüne_,
  { {0xcce7007e,0x7ce60516,0x98ba056c,0x00000000}},	//   _دستي, _tóra, _kupę_,
  { {0x69c80d88,0x6d4a0035,0x6101008f,0x00000000}},	// [d430] äder, _hufa, cēlu,
  { {0x6d4a0009,0x7c2d6473,0xba990054,0x00000000}},	//   _kufa, _izar, _твоє_,
  { {0x394200d1,0xbb3c0047,0x68e3000c,0x00000000}},	//   _fiks_, _געזי, _îndo,
  { {0x69c800d1,0xa6340086,0x6d4a20ce,0x00000000}},	//   ådee, їнці, _mufa,
  { {0x68ed3ffe,0xd37b6474,0xe28e05ef,0x00000000}},	//   mhad, уче_, ма_,
  { {0x68ed03d9,0x6d58017f,0x628a00df,0x00000000}},	//   lhad, _otva, ggfo,
  { {0x20d80027,0x2360001c,0x290900fe,0x00000000}},	//   _réir_, ģija_, onaa_,
  { {0xfbdf0016,0x68ed0a7b,0x63bb1898,0x00000000}},	//   ncês_, nhad, _trun,
  { {0x443903d9,0xb4b50235,0x63ad0016,0x00000000}},	//   _às_, जयी_, çand,
  { {0x7d0d065c,0x6d4a6475,0xa7fb0331,0x00000000}},	//   _ajas, _bufa, _ceñi,
  { {0x3ea56476,0x7d0a005e,0x3cca12d5,0x00000000}},	//   relt_, иног_, ално_,
  { {0x3ea51fc9,0x6101001c,0x2d856477,0x00000000}},	//   selt_, tēlu, rule_,
  { {0x7c2d0051,0xdb0400f8,0x351a0047,0x00000000}},	//   _czar, _asiá, שורנ,
  { {0x7ce60051,0x68ed0089,0x3ce9004b,0x00000000}},	//   _górn, ehad, _elav_,
  { {0x442d0080,0x68ed3aeb,0x39420022,0x00000000}},	//   _lze_, fhad, _piks_,
  { {0xa3e90235,0xa926019d,0xfc3f006d,0x00000000}},	//   मना_, ідал, seía_,
  { {0x6d4a00bd,0x386b0a02,0x69c8069f,0x00000000}},	// [d440] _zufa, _decr_, ådeb,
  { {0x98b9001c,0x29090072,0x272f0058,0x00000000}},	//   _visā_, anaa_, yüne_,
  { {0x3942003d,0x68ed0025,0x1a9b0041,0x00000000}},	//   _tiks_, bhad, _דייע,
  { {0x6e2300ac,0x68ed3e78,0x98be008f,0x00000000}},	//   _mynb, chad, ītē_,
  { {0xbebc001c,0x9357005e,0x02ca005e,0x00000000}},	//   dlīn, орју_, ићки_,
  { {0x6d440659,0x272f0058,0x78b60078,0x00000000}},	//   _liia, tüne_, ldyv,
  { {0x442d0122,0x84e60086,0x9e3c0066,0x00000000}},	//   _eze_, _довж, veďo,
  { {0x68e40019,0x26d801f4,0x2900003b,0x00000000}},	//   nkid, _horo_, niia_,
  { {0x6d580add,0x68e40019,0xb87b0026,0x00000000}},	//   _stva, ikid, _slík,
  { {0x232a011c,0x7f436478,0x7bcb00cd,0x00000000}},	//   _този_, _cinq, _àgui,
  { {0xf653014e,0x68e40019,0x7e6a0026,0x00000000}},	//   וצת_, kkid, _vefp,
  { {0x26d802f6,0xa0a60121,0xd48f005e,0x00000000}},	//   _loro_, _фадд, ерy_,
  { {0x9bf4000d,0xa7fb0331,0x309b009d,0x00000000}},	//   дзяч, _teñi, _כשאמ,
  { {0x2967005e,0x26d86479,0x6d4a647a,0x00000000}},	//   жњав, _noro_, _tufa,
  { {0x5b14019d,0x286b0001,0x6d580c4a,0x00000000}},	//   ємст, ирао_, _utva,
  { {0x61080080,0xd7770021,0xf8bf0013,0x00000000}},	//   dělk, قاطع, _nhét_,
  { {0x68ed014f,0xd794005a,0x7d1d647b,0x00000000}},	// [d450] rhad, митъ, moss,
  { {0xd5bb2c9e,0x26d82443,0x7d1d4fc9,0x00000000}},	//   исе_, _coro_, loss,
  { {0x69c1069f,0x25480058,0x7d1d078c,0x00000000}},	//   æled, _oğlu_, ooss,
  { {0x83fd00ea,0x3eb9001c,0xe4e415d4,0x00000000}},	//   _időz, ēsti_, мічн,
  { {0x26d83046,0x27f20051,0xdce90078,0x00000000}},	//   _foro_, czyn_, sudė,
  { {0xa6db007a,0x6d020053,0x883a0063,0x00000000}},	//   _auðv, _लगभग_, _לתרו,
  { {0xddc3000c,0x1a9c0047,0x7b090066,0x00000000}},	//   _menţ, ייגע, tľuj,
  { {0x26d8647c,0xf8bf0013,0x5455388a,0x00000000}},	//   _zoro_, _ghét_, _хват,
  { {0x442d007d,0xd12e0021,0x7d1d647d,0x00000000}},	//   _uze_, دمي_, doss,
  { {0x6d440019,0x69da00d1,0xa3d80042,0x00000000}},	//   _siia, øtek, ाहर_,
  { {0x6125006d,0x1c010053,0x7c240360,0x00000000}},	//   hóli, _लेबल_, _syir,
  { {0x692c00bd,0x6eed3436,0x7d1d647e,0x00000000}},	//   eßen, _súbd, goss,
  { {0xd308001b,0x6d440019,0xeb9703d6,0x00000000}},	//   iện_, _viia, пия_,
  { {0x5e450021,0xddc3003b,0x6fb20021,0x00000000}},	//   _عَبْ, _cenţ, _أموا,
  { {0x38c8006a,0x7ced0003,0xc3320063,0x00000000}},	//   ياری_, _sûre, גום_,
  { {0xf1b20047,0x6f0100c2,0x993a0636,0x00000000}},	//   עסן_, lilc, сягу_,
  { {0x68e40019,0xdb040026,0x6113003b,0x00000000}},	// [d460] rkid, _frið, căle,
  { {0xc7230076,0x98a90051,0x44240e7f,0x00000000}},	//   едуй, ymać_, _rym_,
  { {0x7ae100ea,0x26d80137,0x27f20022,0x00000000}},	//   ölte, _voro_, szyn_,
  { {0xdcfb001c,0x61250460,0xed560047,0x00000000}},	//   ortā, bóli, לבער_,
  { {0xd8d700b5,0x26d86232,0xa6db0014,0x00000000}},	//   _זוכט_, _toro_, _auðu,
  { {0xe737005a,0xb15c0054,0x00000000,0x00000000}},	//   _нея_, анкi,   ,
  { {0x55870002,0x6f0100c2,0x2167005e,0x00000000}},	//   _нбрм_, dilc, пији_,
  { {0x442406ce,0x2167005e,0x757b0063,0x00000000}},	//   _tym_, чићи_, _לטלפ,
  { {0x4053043b,0x7afe0005,0x7d1d47d9,0x00000000}},	//   رئيس, _ompt, voss,
  { {0xd24f0021,0x2ca007b7,0xb23a0021,0x00000000}},	//   _منك_, _abid_, _هكذا_,
  { {0x10a60071,0x612500ea,0x64490058,0x00000000}},	//   _нижн, zóli, şmiş,
  { {0x7afe00e8,0x7ce62b2e,0x239e0023,0x00000000}},	//   _ampt, _fórm, pājā_,
  { {0x7d1d647f,0xa2d30053,0x6eed1078,0x00000000}},	//   ross, बॉक्, _súbe,
  { {0xa03b014e,0x3f7b0047,0x61080080,0x00000000}},	//   _העדפ, _פאוס, děli,
  { {0x3a25010a,0xd308001b,0xfe9b014e,0x00000000}},	//   ælp_, yện_, _היומ,
  { {0x7afe0034,0x69c800d1,0x61256480,0x00000000}},	//   _empt, ådea, tóli,
  { {0x27340137,0x7b150002,0xc64b0021,0x00000000}},	// [d470] känd_, _одих, مجال_,
  { {0x3f52008b,0xaa670121,0x4a5501d5,0x00000000}},	//   _mâu_, _этик, _юкос,
  { {0x3f52008b,0x94d50454,0x61250516,0x00000000}},	//   _lâu_, можц, sóli,
  { {0xb87b017d,0x61252c74,0x6f010c6d,0x00000000}},	//   _alív, póli, zilc,
  { {0xd7f8000a,0xa6db0026,0xddc3004a,0x00000000}},	//   _еур_, _suðu, _menš,
  { {0x27340137,0xceb80022,0xa6db0014,0x00000000}},	//   väng_, jdę_, _puðu,
  { {0x6f016481,0x31560044,0x00000000,0x00000000}},	//   vilc, ولوج_,   ,
  { {0x27340137,0x6449002b,0x00000000,0x00000000}},	//   täng_, _ugei,   ,
  { {0x3f52001b,0x442b008b,0x1ef90044,0x00000000}},	//   _câu_, _ác_, قعدة_,
  { {0x273400c7,0x0ea90076,0x3f520013,0x00000000}},	//   räng_, цкой_, _dâu_,
  { {0x81bc001c,0xbebc001c,0x9db9000d,0x00000000}},	//   _dzēs, olīj, цыпу_,
  { {0xeb9a0612,0x6f016482,0xddc3001c,0x00000000}},	//   оим_, silc, _cenš,
  { {0x2734004d,0xceb80078,0x6eed0014,0x00000000}},	//   läne_, bdę_, _vúbb,
  { {0x3f98000c,0xfe71007e,0x63a4005b,0x00000000}},	//   ărut_, _شدت_, çini,
  { {0x6113000c,0xbb430cbb,0xab271579,0x00000000}},	//   călc, терк, фора_,
  { {0x52da0161,0x3eb9008f,0xd7ea01ce,0x00000000}},	//   _बक्स, ēstu_, омбе_,
  { {0x3f520013,0x61e3002b,0xf0920063,0x00000000}},	// [d480] _xâu_, hynl, כנן_,
  { {0x61e300e8,0xc9560121,0xc9aa066e,0x00000000}},	//   kynl, _отмы, _двое_,
  { {0x273401e3,0x395e013d,0xa6db0014,0x00000000}},	//   vänd_, ítsd_, _auðs,
  { {0x2d530016,0x2d850027,0xd4670001,0x00000000}},	//   _mãe_, irle_, дице_,
  { {0x9784007e,0xd5b10013,0x1bf60042,0x00000000}},	//   _سیاه, _ấn_, ीपटल_,
  { {0x98b900eb,0x24920051,0x3f523f9c,0x00000000}},	//   _visą_, żym_, _râu_,
  { {0x3f52008b,0x7ce60051,0x05660454,0x00000000}},	//   _sâu_, _córk, _іван,
  { {0xf9930063,0xceb80051,0xdfb4005e,0x00000000}},	//   דרה_, wdę_, ебињ,
  { {0xb7db00b5,0xa6db0014,0x98be0078,0x00000000}},	//   ַקטי, _guðs, ūtė_,
  { {0xceb80006,0x81bc008f,0x1fa30062,0x00000000}},	//   udę_, _dzēr, тръг,
  { {0xdb2100ea,0x6b860104,0x7ce612a6,0x00000000}},	//   _ítél, erkg, _kórh,
  { {0x6ee40268,0x4103005a,0xd3080013,0x00000000}},	//   _mòbi, _изхв, iệm_,
  { {0x69c802fb,0x2d851ba2,0xddda013d,0x00000000}},	//   åden, arle_, ratő,
  { {0xce940062,0xf2df003b,0xddd80058,0x00000000}},	//   _чакъ, _îât_, _gevş,
  { {0x39150431,0x6113003b,0xd9150121,0x00000000}},	//   емвр, lăla, едвы,
  { {0x3eac05b9,0xf8bf008b,0x2d8c004b,0x00000000}},	//   ledt_, _chép_, mude_,
  { {0x2d8c6483,0xf7700242,0xdcff0078,0x00000000}},	// [d490] lude_, لال_, _švėk,
  { {0x2d8c00ca,0xf72b000d,0x99990131,0x00000000}},	//   oude_, іцай_, _екот_,
  { {0x2d8c3244,0x3eac006f,0x00000000,0x00000000}},	//   nude_, iedt_,   ,
  { {0x395e00ea,0xd7fb005e,0xf8bf0013,0x00000000}},	//   ítse_, _дуг_, _ghép_,
  { {0xb87b0025,0x7d0f00ea,0xdb04004b,0x00000000}},	//   _dlít, incs, _eriõ,
  { {0x41b50138,0x2d8c004b,0x61e30072,0x00000000}},	//   есит, kude_, tynl,
  { {0xe97c0047,0x2d8c6484,0x56940a3a,0x00000000}},	//   ַנזש, jude_, _шарт,
  { {0x78ad0529,0xfa0d001b,0x2d8c3287,0x00000000}},	//   neav, _đầu_, dude_,
  { {0x61e30205,0x60090054,0xdee5030b,0x00000000}},	//   synl, яним_, еопи,
  { {0x6108004c,0xf8ac0053,0x78ad00e5,0x00000000}},	//   dělu, _चस्प, heav,
  { {0x2d8c0019,0x78ad0072,0xe718009a,0x00000000}},	//   gude_, keav, וחזר_,
  { {0x998d0045,0x6eed0025,0x31560047,0x00000000}},	//   łeś_, _dúba, _װיסן_,
  { {0x78ad6485,0xb87b00be,0x4d15030b,0x00000000}},	//   deav, _moíd, тьэт,
  { {0x69c80031,0x3eb9001c,0x2d8c016b,0x00000000}},	//   ådeo, ēsts_, bude_,
  { {0xf8bf001b,0x3f8d00cd,0x18a609c2,0x00000000}},	//   _phép_, lueu_, навм,
  { {0x395e003d,0xa3cf0053,0x68460256,0x00000000}},	//   īts_, षमा_, енба,
  { {0x3f8d0268,0xf7720021,0x7d066486,0x00000000}},	// [d4a0] nueu_, طاء_, miks,
  { {0x8c1b014e,0x7d066487,0x29050014,0x00000000}},	//   _מופי, liks, élar_,
  { {0xf8bf008b,0x05660062,0x35690054,0x00000000}},	//   _thép_, хвен, дрін_,
  { {0x78ad41fc,0x7d066488,0x00000000,0x00000000}},	//   ceav, niks,   ,
  { {0xd3260376,0xa2940304,0xf772014d,0x00000000}},	//   ньки, валі, _حاج_,
  { {0x60cb4190,0xd24f01fb,0xb87b0046,0x00000000}},	//   _angm, منه_, _flís,
  { {0x7d0601cf,0x44fa0085,0x799c0022,0x00000000}},	//   kiks, _ехаў_, ntrw,
  { {0x673e006f,0x859b0063,0x7bc4141b,0x00000000}},	//   lmpj, _משלו, _oriu,
  { {0x3f8d0994,0x7d066489,0xff0602dc,0x00000000}},	//   gueu_, diks, еянн,
  { {0x798e0009,0x629e00cd,0x7d06276c,0x00000000}},	//   kubw, òpod, eiks,
  { {0x3eac3149,0xa3d80053,0x69da0072,0x00000000}},	//   redt_, ाहक_, ätel,
  { {0x2d82648a,0x798e0035,0x2d8c5c4f,0x00000000}},	//   čke_, dubw, rude_,
  { {0x2d8c4ed5,0xddd800ea,0x70530021,0x00000000}},	//   sude_, _vevő, _إنها,
  { {0x7d061102,0x7f170044,0x2be20042,0x00000000}},	//   aiks, _كينز_, _पथरा,
  { {0xc9840925,0x7d060656,0xcb340062,0x00000000}},	//   лути, biks, уеръ,
  { {0x61f5000f,0x7bc4648b,0x765c0051,0x00000000}},	//   _üzle, _friu, _afry,
  { {0xab620058,0x57b50062,0x7bc4005f,0x00000000}},	// [d4b0] şüre, ъбат, _griu,
  { {0x93c7003b,0x78ad648c,0x2d6e004c,0x00000000}},	//   nvăţ, seav, oře_,
  { {0x61080080,0xd915000d,0x236d0051,0x00000000}},	//   něls, _адны, _swej_,
  { {0xd5b1008b,0xa8790047,0x69c50072,0x00000000}},	//   _ấm_, _קאָר, _irhe,
  { {0x3869648d,0x98ab0051,0x765c002b,0x00000000}},	//   mbar_, _chcą_, _ffry,
  { {0x6b9d00bd,0x386934da,0x7d06005b,0x00000000}},	//   itsg, lbar_, ziks,
  { {0x38690130,0x6b9d0244,0xe4a71313,0x00000000}},	//   obar_, htsg, _прао,
  { {0x61080080,0x9f52027d,0x3f8d00cd,0x00000000}},	//   děls, ždým_, tueu_,
  { {0x68e3003b,0x6ee401a8,0x7d06648e,0x00000000}},	//   _îndu, _lòbu, viks,
  { {0x3869648f,0x3f8302e2,0xccf9004c,0x00000000}},	//   hbar_, čju_, spěl_,
  { {0xcc8a006a,0xee390b62,0x30e70086,0x00000000}},	//   ونده_, ьно_, _підб,
  { {0x69c80031,0xd7d10161,0x6b9d0502,0x00000000}},	//   ådem, समाच, ftsg,
  { {0x3f8d0994,0xde16007e,0x7d062ee6,0x00000000}},	//   queu_, فقیت_, riks,
  { {0x212d00e3,0x2d6e0080,0x63a905b3,0x00000000}},	//   lleh_, bře_, _mpen,
  { {0x212d0397,0x6b9d102c,0xc92a0086,0x00000000}},	//   oleh_, atsg, довж_,
  { {0x63a96490,0x99430021,0x6ba50137,0x00000000}},	//   _open, لَّه, åtgä,
  { {0x657c017f,0x69c500bd,0x62814c32,0x00000000}},	// [d4c0] _svrh, _erhe, _odlo,
  { {0x96630076,0x386903e0,0xdb080072,0x00000000}},	//   икуе, abar_, äläi,
  { {0x63a96491,0x38696492,0xceb20063,0x00000000}},	//   _apen, bbar_, שיב_,
  { {0xd4d5000d,0x628135b6,0x80a10053,0x00000000}},	//   лічэ, _adlo, _कॉले,
  { {0x291206a7,0x39406493,0x98a0056c,0x00000000}},	//   mnya_, mmis_, glią_,
  { {0x2912014f,0x39400d68,0x68f66494,0x00000000}},	//   lnya_, lmis_, lhyd,
  { {0x7d0401a5,0x39400006,0x98a00078,0x00000000}},	//   _omis, omis_, alią_,
  { {0x2912014f,0x2d6e0080,0x69c30078,0x00000000}},	//   nnya_, vře_, _šnek,
  { {0xa8e0001b,0x39400025,0x291258eb,0x00000000}},	//   _độn, imis_, inya_,
  { {0x291208f0,0x7d044a93,0x2d6e004c,0x00000000}},	//   hnya_, _amis, tře_,
  { {0x2912014f,0x6113003b,0x9e3c004c,0x00000000}},	//   knya_, călo, jeďt,
  { {0x29120089,0x6b9d136f,0x6281011b,0x00000000}},	//   jnya_, ttsg, _zdlo,
  { {0x2912053b,0xdb2500ea,0x394b00cd,0x00000000}},	//   dnya_, ősít, _rics_,
  { {0x39400019,0x2fc600a4,0xd00f007e,0x00000000}},	//   emis_, _irog_, _بله_,
  { {0x386900bd,0x2912003e,0x394b6495,0x00000000}},	//   tbar_, fnya_, _pics_,
  { {0x2fc6337d,0x68f6001f,0x395e00ea,0x00000000}},	//   _krog_, ghyd, ítsa_,
  { {0x386602dd,0x383517d0,0x386941f2,0x00000000}},	// [d4d0] ñora_, унар, rbar_,
  { {0xb6f40138,0x2912003e,0x2d9e6496,0x00000000}},	//   азуј, anya_, otte_,
  { {0x2912003e,0x272f00ea,0x69c56497,0x00000000}},	//   bnya_, lünk_, _urhe,
  { {0x3ebc02ab,0x68f6001f,0x7ce66498,0x00000000}},	//   _lavt_, chyd, _fóru,
  { {0x6d4d0290,0x2d9e006f,0x3cfc0047,0x00000000}},	//   _miaa, htte_, ולאנ,
  { {0xe2960079,0x68ed6499,0x29090072,0x00000000}},	//   гаш_, lkad, liaa_,
  { {0x6eed649a,0x10a5005a,0x78bd0aba,0x00000000}},	//   _súbo, гийн, _kasv,
  { {0x272f00ea,0x7fd90002,0x78bf649b,0x00000000}},	//   künk_, ефот_, ndqv,
  { {0x7c2d4784,0xc0c80001,0x27e9649c,0x00000000}},	//   _nyar, тује_, nyan_,
  { {0x69c80031,0xb0620d9e,0x7d042483,0x00000000}},	//   ådek, ääri, _smis,
  { {0x7c2d01f7,0x27340137,0xde05268f,0x00000000}},	//   _ayar, känn_, упни,
  { {0x78bd00c3,0x27e900a4,0x9e3c0114,0x00000000}},	//   _nasv, kyan_, veďt,
  { {0xbea50c8d,0xdb0d006d,0x2d9e649d,0x00000000}},	//   _балк, _arañ, atte_,
  { {0x442d0031,0xdce2003d,0x60db004b,0x00000000}},	//   _mye_, tslē, ljum,
  { {0x2912014f,0x63be001c,0x68f60f06,0x00000000}},	//   tnya_, āpni, thyd,
  { {0x2912028d,0x27e90150,0xdce2001c,0x00000000}},	//   unya_, fyan_, rslē,
  { {0x27e900bb,0x291208f0,0x442d02ab,0x00000000}},	// [d4e0] gyan_, rnya_, _nye_,
  { {0x291208f0,0x7bcb0016,0x60db004b,0x00000000}},	//   snya_, _água, hjum,
  { {0x291206a7,0x1a9b00b5,0x3f9f00fe,0x00000000}},	//   pnya_, _אייע, htuu_,
  { {0x68ed649e,0xdb0d007a,0x4e360047,0x00000000}},	//   ckad, _hrað, אָדן_,
  { {0x6eed57f8,0x98a00051,0xa2e60054,0x00000000}},	//   _públ, elić_, лодд,
  { {0x68e3000c,0x2d9e0831,0x60db0150,0x00000000}},	//   _îndr, ytte_, ejum,
  { {0x442d5add,0x60db0026,0x81a60021,0x00000000}},	//   _eye_, fjum, احتل,
  { {0x2fc6649f,0x20540062,0x25a50137,0x00000000}},	//   _prog_, шкия, _älla_,
  { {0x98ab0051,0xd0100021,0x8cd80053,0x00000000}},	//   _chcę_, تلة_, यानो,
  { {0x979b0047,0xc7b3009a,0x68ed64a0,0x00000000}},	//   עשיק, צבת_, zkad,
  { {0x7c2d0e53,0x2d9e175f,0x2360001c,0x00000000}},	//   _syar, utte_, ģiju_,
  { {0x61e500bd,0x272f00ea,0x2d9e64a1,0x00000000}},	//   ähle, tünk_, rtte_,
  { {0xbed4000a,0x9b58005a,0x2d9e44dc,0x00000000}},	//   _волј, лият_, stte_,
  { {0x7ce60027,0x272f000f,0x78bd017f,0x00000000}},	//   _sórt, rünk_, _sasv,
  { {0xc333014e,0x7ce60e7c,0x272f013d,0x00000000}},	//   מוש_, _pórt, sünk_,
  { {0x272f013d,0xd7fb0002,0x00000000,0x00000000}},	//   pünk_, нуз_,   ,
  { {0x7c2d01f7,0x67d4000a,0xd795005a,0x00000000}},	// [d4f0] _uyar, боту, ризъ,
  { {0x2d8c021f,0x24840089,0x7ce60264,0x00000000}},	//   orde_, _admm_, _fórs,
  { {0x7ce60051,0xe4e7013c,0x545534ae,0x00000000}},	//   _górs, лідн, авет,
  { {0xf7950088,0x672500fe,0x2d8c0025,0x00000000}},	//   _камэ, sohj, irde_,
  { {0x672500fe,0xe29964a2,0x287a009a,0x00000000}},	//   pohj, вал_, _שנשמ,
  { {0x0595005d,0x91e507bf,0x98a00eb5,0x00000000}},	//   _پاسگ, иоле, tlić_,
  { {0x442d00e8,0x929200d7,0x6d5c004c,0x00000000}},	//   _wye_, цајц, íral,
  { {0x442d00e8,0x3f9f00fe,0x69c800d1,0x00000000}},	//   _tye_, ttuu_, ådei,
  { {0x2d8c03a8,0x3f9f00fe,0x80a10053,0x00000000}},	//   erde_, utuu_, क्षे,
  { {0x2ca9027b,0x63bb0089,0x2d8300c2,0x00000000}},	//   _abad_, _isun, šjem_,
  { {0xe80c0161,0x3f9f00fe,0x5184000d,0x00000000}},	//   _सेना_, stuu_, _гуча,
  { {0xe162007e,0x4c830054,0x1d0a3a58,0x00000000}},	//   _بگوي, олюв, теми_,
  { {0x63ad017d,0x2d8c08ff,0x4c360085,0x00000000}},	//   çanh, arde_, рэнт,
  { {0x80a10053,0x7ce603ea,0x7a4000ea,0x00000000}},	//   क्रे, _córr, játé,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xc95506bc,0x3f5b008b,0x993a0054,0x00000000}},	//   стры, _kêu_, тягу_,
  { {0xb8de0053,0x3f8d00cd,0x3706000d,0x00000000}},	// [d500] _इस_, nreu_, апаг,
  { {0x3f8d01a8,0x98ab008f,0x657e004d,0x00000000}},	//   ireu_, ījās_, tsph,
  { {0xd308008b,0x63bb64a3,0x7bc60093,0x00000000}},	//   iệt_, _asun, lvku,
  { {0x61ee00bd,0x938a1b76,0x26d1239c,0x00000000}},	//   _übli, вска_, _enzo_,
  { {0x3f5b008b,0x9676000d,0x657e64a4,0x00000000}},	//   _nêu_, _выбі, ssph,
  { {0x3f8d0994,0xfc3f006d,0x2d8b0051,0x00000000}},	//   dreu_, nfía_, ącej_,
  { {0x7e7a5fef,0xd2590083,0x49060042,0x00000000}},	//   vatp, уці_, सोथो_,
  { {0x3f8d0555,0x2d8c007d,0x1f740062,0x00000000}},	//   freu_, vrde_, блия,
  { {0xdfd0013a,0x50b7009e,0xdee60044,0x00000000}},	//   سيد_, شديد_, لأدي,
  { {0x9ed8000a,0xe4650026,0x52750054,0x00000000}},	//   умот_, _þörf_, _гуцу,
  { {0x2d8c46b9,0x3f8d00cd,0x667b0047,0x00000000}},	//   urde_, areu_, כטיק,
  { {0x3f8d1b84,0x3fc8007e,0x63a264a5,0x00000000}},	//   breu_, _مدتی_, oton,
  { {0x63a264a6,0x81c7001c,0x9d1800a0,0x00000000}},	//   nton, rtēš, роят_,
  { {0xdce200eb,0x63a264a7,0x81c7001c,0x00000000}},	//   kslė, iton, stēš,
  { {0xed570079,0x58d50189,0x213d3d50,0x00000000}},	//   _кој_, бовт, _yhwh_,
  { {0x3f5b001b,0x63a264a8,0xa3d60042,0x00000000}},	//   _yêu_, kton, िमा_,
  { {0xfb85007e,0x63a2007d,0x8858093d,0x00000000}},	// [d510] _ادبی, jton, риус_,
  { {0x6d580d9e,0x63a2072f,0xdce2008f,0x00000000}},	//   _kuva, dton, mplā,
  { {0x63bb00be,0xd5bb0062,0x24550593,0x00000000}},	//   _ssun, ъса_, مناس,
  { {0xb6070078,0x63a264a9,0x6d580058,0x00000000}},	//   _rašė, fton, _muva,
  { {0x7ae50aba,0xd308001b,0x63a20bc1,0x00000000}},	//   _koht, yệt_, gton,
  { {0x7ae5024a,0x217500d7,0x7ae100ea,0x00000000}},	//   _joht, буир, ölth,
  { {0x6d5864aa,0x63bb0022,0x63a245b9,0x00000000}},	//   _nuva, _wsun, aton,
  { {0x3f8d1281,0x34940002,0x5a180063,0x00000000}},	//   treu_, _маср, יקון_,
  { {0x63bb0045,0x3f8d00cd,0xd371007e,0x00000000}},	//   _usun, ureu_, _رها_,
  { {0x3f8d2fd5,0x79950035,0x59d70053,0x00000000}},	//   rreu_, kuzw, डमार,
  { {0x69c7007d,0x6d58001a,0x6eed4a7a,0x00000000}},	//   jvje, _cuva, _júbi,
  { {0xf1c30006,0xcb6a64ab,0x705936a9,0x00000000}},	//   rašė_, ламе_, _садр_,
  { {0x6f650021,0x705208aa,0x6b400014,0x00000000}},	//   _اهتم, _عنوا, nögg,
  { {0x543a0047,0x643a0047,0x611300dd,0x00000000}},	//   טערא, טערנ, dăli,
  { {0x5d850032,0x63a2000f,0x8d950021,0x00000000}},	//   _البل, zton, _العش,
  { {0x97da0076,0x3860006c,0x63a264ac,0x00000000}},	//   льзу_, ucir_, yton,
  { {0x38600110,0x69c7007d,0xddc3004c,0x00000000}},	// [d520] rcir_, avje, _jenž,
  { {0x06560088,0x6d580058,0x63a264ad,0x00000000}},	//   стаў, _yuva, vton,
  { {0x2a570063,0x463a00a0,0x27340137,0x00000000}},	//   _לבין_, учая_, länk_,
  { {0x69c80031,0x6723017f,0x63a264ae,0x00000000}},	//   ådeu, čnja, tton,
  { {0xdb0d0019,0x63a264af,0x395a0072,0x00000000}},	//   _eraõ, uton, _hups_,
  { {0x63a264b0,0xf7730063,0xf2c30062,0x00000000}},	//   rton, _מקש_, зсън,
  { {0x63a264b1,0xddda276c,0xdb1f006c,0x00000000}},	//   ston, ratū, évél,
  { {0x27340137,0xa6170063,0x63a25468,0x00000000}},	//   känk_, _הקלד_, pton,
  { {0x69c7017f,0x6d5864b2,0x1543005e,0x00000000}},	//   zvje, _suva, _хетм,
  { {0x6d4664b3,0xd7bb0041,0x69c7013d,0x00000000}},	//   emka, נציר, yvje,
  { {0xd5b10013,0x6b8464b4,0x12eb0063,0x00000000}},	//   _ất_, _avig, _עַמּ,
  { {0xb1460001,0xa1570063,0x7afc004d,0x00000000}},	//   _унел, _הבאה_, ehrt,
  { {0x69c800b9,0xeafb007e,0x7ae564b5,0x00000000}},	//   æden, هرست_, _poht,
  { {0x6b84146a,0x6d5864b6,0x6113003b,0x00000000}},	//   _dvig, _tuva, văli,
  { {0x6b84018c,0x395a12a9,0x5a440085,0x00000000}},	//   _evig, _cups_, зэта,
  { {0x6113000c,0xdcfb008f,0x22510066,0x00000000}},	//   tăli, rutē, _úzke_,
  { {0x60c20009,0xddc8017f,0x7ae50478,0x00000000}},	// [d530] _maom, nadž, _toht,
  { {0x692c00bd,0x629e00cd,0x7c290022,0x00000000}},	//   ußer, òpol, żers,
  { {0x69c8380f,0x69da0f68,0xaa640085,0x00000000}},	//   ådet, ätet, _этык,
  { {0x628864b7,0x60c219d9,0xdce2003b,0x00000000}},	//   _addo, _naom, mplă,
  { {0x93a70121,0x31a10022,0x889a089e,0x00000000}},	//   сшед, wóz_, _דברי,
  { {0xa276005e,0x1b7c0041,0x4b7c069a,0x00000000}},	//   обљу_, נטוע, נאוו,
  { {0x6a9c014e,0x6aaa00bd,0x1a9c0047,0x00000000}},	//   אשונ, _öffe, טיגע,
  { {0x613e00ac,0x7a400014,0x63ac004c,0x00000000}},	//   eëlb, _hátí, ílný,
  { {0xb87b0114,0x7d0f00ea,0x7b09189f,0x00000000}},	//   _blíz, dics, ržuj,
  { {0x5f050086,0xe4500021,0xbd850591,0x00000000}},	//   ізна, _أضف_, огок,
  { {0x6b8464b8,0xc6920063,0x7bcd64b9,0x00000000}},	//   _svig, ואי_, _arau,
  { {0x7bcd64ba,0x2d8b0080,0xbebc001c,0x00000000}},	//   _brau, čce_, slīp,
  { {0x6d5e0003,0xdce2003b,0x7c3a0022,0x00000000}},	//   _épan, eplă, ętro,
  { {0x7bcd1b74,0x2d950131,0x5f74005d,0x00000000}},	//   _drau, _дрис, _راهر,
  { {0xd308008b,0xaa4a0062,0x4c6a0094,0x00000000}},	//   iệp_, рпва_, _кийн_,
  { {0x7bcd0a04,0xe8f70002,0x27340072,0x00000000}},	//   _frau, олс_, mäni_,
  { {0x26c3048e,0xa6e60076,0xd70a000d,0x00000000}},	// [d540] _bajo_, ожал, анае_,
  { {0x249f0529,0x69c80ddc,0xeb910047,0x00000000}},	//   _acum_, ådes, _אָט_,
  { {0x1fb6016a,0xa2dd0053,0x26c300c2,0x00000000}},	//   _अन्ड, पान्, _dajo_,
  { {0x236a0141,0x69c80066,0x136a032d,0x00000000}},	//   ајко_, ťdes, ашки_,
  { {0xa5330054,0x442064bb,0xf746079b,0x00000000}},	//   єніч, çi_, _мемо,
  { {0x38720031,0x6b8b00b9,0x6b40004d,0x00000000}},	//   lbyr_, _ægge, böge,
  { {0xe297005e,0x290b32b2,0xdcfb0023,0x00000000}},	//   цај_, _ymca_, hstā,
  { {0xc0ca0138,0xdcfb001c,0x3faa005e,0x00000000}},	//   руке_, kstā, ањом_,
  { {0x63ad50b1,0x78fb069a,0x7d0f013d,0x00000000}},	//   çant, יפקו, vics,
  { {0x20180529,0x2ee70fef,0x945d0022,0x00000000}},	//   ări_, _conf_, _tańc,
  { {0x7d0f00fe,0x7bcd0006,0x69c800b9,0x00000000}},	//   tics, _srau, ædel,
  { {0xcd07019d,0x7bcd64bc,0x00000000,0x00000000}},	//   ічни, _prau,   ,
  { {0xdcfb003d,0x7ac725d8,0x6b4064bd,0x00000000}},	//   gstā, осве, zöge,
  { {0x7d0f229a,0x00000000,0x00000000,0x00000000}},	//   sics,   ,   ,
  { {0x0e750066,0xc87b005e,0xdcfb008f,0x00000000}},	//   äčší, иџа_, astā,
  { {0x6b40004d,0x5c750121,0xdcff008f,0x00000000}},	//   vöge, _элит, ēvēj,
  { {0x69da00bd,0x984b005a,0x6fbc0053,0x00000000}},	// [d550] äter, рява_, ्टिं,
  { {0xc66b000d,0x8ca70053,0xd8280085,0x00000000}},	//   ршае_, ट्रो, ціск_,
  { {0x2aba014e,0xbb3c0047,0x3aba0063,0x00000000}},	//   _המתא, _דעזי, _המתנ,
  { {0xe80c0161,0xf9920047,0x2eb70042,0x00000000}},	//   _सेवा_, _ארט_, _अस्त,
  { {0x394964be,0x26c30871,0xf8da009a,0x00000000}},	//   mmas_, _tajo_, _החרמ,
  { {0x291c0014,0x2cb9013d,0xf776009a,0x00000000}},	//   _ívar_, hesd_, _מעשי_,
  { {0xd49b0079,0x39490b2b,0x78b4000f,0x00000000}},	//   _врз_, omas_, _üdvö,
  { {0x6f1a3849,0x27340072,0x25ac0137,0x00000000}},	//   entc, väni_, _ädla_,
  { {0xdcfb0006,0x443964bf,0x3f840078,0x00000000}},	//   lutė, _ás_, gsmu_,
  { {0x3f860080,0x7d1d0026,0x3949004b,0x00000000}},	//   _dvou_, érsn, hmas_,
  { {0xdcfb00eb,0xcee8006a,0x005500de,0x00000000}},	//   nutė, ترين_, _فَاج,
  { {0x6113003b,0x61080051,0xddc30078,0x00000000}},	//   tălu, yśli, _senų,
  { {0x2fc90025,0x2bba0021,0x27340072,0x00000000}},	//   _éag_, حاجة_, säni_,
  { {0xdcfb003d,0x6113003b,0x78af64c0,0x00000000}},	//   rstā, rălu, _abcv,
  { {0x78af001b,0xdcfb0078,0xd9460505,0x00000000}},	//   _bbcv, jutė, зеви,
  { {0xdcfb0a10,0x39492810,0x7bc00014,0x00000000}},	//   dutė, gmas_, æmus,
  { {0x4c9b0063,0x387204aa,0x69d864c1,0x00000000}},	// [d560] _השפע, rbyr_, _šved,
  { {0x39493716,0x2d850734,0x61250014,0x00000000}},	//   amas_, osle_, róly,
  { {0x7e7e0004,0x6d561a3b,0xe57a0121,0x00000000}},	//   _õppe, _kiya, ёзд_,
  { {0xba76005d,0x89db009a,0x23c70082,0x00000000}},	//   _باکت, _החטי, लिंद,
  { {0x6d440025,0x291264c2,0x7ccd0041,0x00000000}},	//   _mhia, miya_, יצאַ,
  { {0x6ef60164,0x6d560222,0x2900017d,0x00000000}},	//   _câbl, _liya, lhia_,
  { {0x3f860080,0x27f200fe,0xc1b80054,0x00000000}},	//   _svou_, lyyn_, ілих_,
  { {0x751a0032,0x29000016,0x6d5664c3,0x00000000}},	//   _اقرأ_, nhia_, _niya,
  { {0xa067005e,0x2cb9013d,0x7523013d,0x00000000}},	//   чања_, vesd_, énze,
  { {0x27e00268,0x29121362,0x644064c4,0x00000000}},	//   ixin_, hiya_, _izmi,
  { {0x394900eb,0x6d5600a4,0x4c955394,0x00000000}},	//   ymas_, _biya, минс,
  { {0x660101f7,0x6d4464c5,0x27f20072,0x00000000}},	//   _ülke, _chia, kyyn_,
  { {0x6d440025,0x703a03eb,0x2d8706a5,0x00000000}},	//   _dhia, _اساس_, _evne_,
  { {0x3f8200eb,0x19590088,0xdee300fb,0x00000000}},	//   škus_, жавы_, _почи,
  { {0x6d56005b,0x69c80829,0x6d440139,0x00000000}},	//   _fiya, ådep, _fhia,
  { {0x6d44051e,0x5779000d,0xacbb0003,0x00000000}},	//   _ghia, жбаў_, goût,
  { {0x7ae1000f,0x39491f45,0xb8e50053,0x00000000}},	// [d570] ölts, rmas_, _एस_,
  { {0x6d5601f7,0x4b7c0063,0x394940ce,0x00000000}},	//   _ziya, _האזו, smas_,
  { {0x644064c6,0x18750062,0x2d54003b,0x00000000}},	//   _azmi, _огня, _oţel_,
  { {0x7d1d2713,0x290064c7,0x45180054,0x00000000}},	//   nnss, chia_, пція_,
  { {0x53a50002,0x27e00013,0x03a52c7a,0x00000000}},	//   фалб, cxin_, фило,
  { {0x2d850024,0x20040089,0x7c2b01e1,0x00000000}},	//   ysle_, dzmi_, _øgru,
  { {0xf8b20014,0x6d60008d,0x93420094,0x00000000}},	//   _þáði_, ôvá, ънше,
  { {0x35b30086,0x3aef004e,0x00000000,0x00000000}},	//   _обґр, _küps_,   ,
  { {0x9f4400fe,0x645b006d,0x6d44001f,0x00000000}},	//   kymä_, _igui, _rhia,
  { {0x6d561394,0x8e740454,0x4d65150f,0x00000000}},	//   _siya, нуюч, мков,
  { {0x57ba0161,0x6d56005b,0x112b0376,0x00000000}},	//   _उन्ह, _piya, _люди_,
  { {0xd00e006a,0x2d850f94,0x31c40086,0x00000000}},	//   الی_, rsle_, _ясув,
  { {0x2d9a0031,0x6d560058,0x5b360085,0x00000000}},	//   _åpen_, _viya, дэву,
  { {0x29120035,0x7d1d00fe,0x6d560150,0x00000000}},	//   wiya_, anss, _wiya,
  { {0x6d5600bb,0xc3320063,0x395e0003,0x00000000}},	//   _tiya, דום_, êts_,
  { {0x62830185,0x60c964c8,0x27f20072,0x00000000}},	//   hano, ndem, tyyn_,
  { {0x3af400fe,0x27340137,0x291264c9,0x00000000}},	// [d580] _läpi_, känt_, riya_,
  { {0x291200bb,0x29000035,0x68e4014f,0x00000000}},	//   siya_, shia_, sjid,
  { {0x2912002c,0x7a470003,0x3946005e,0x00000000}},	//   piya_, rété, _оног,
  { {0x60c90ff8,0x6abc64ca,0x00000000,0x00000000}},	//   jdem, lerf,   ,
  { {0x9f520080,0x7a470003,0x69ce02c0,0x00000000}},	//   ždém_, pété, lvbe,
  { {0x416a0001,0x628364cb,0xe9a9007e,0x00000000}},	//   ојим_, gano, _بدین_,
  { {0xbebc001c,0x64400022,0x6abc004d,0x00000000}},	//   lnīg, _wzmi, ierf,
  { {0x6abc007a,0x62830ddd,0xe64349ab,0x00000000}},	//   herf, aano, _респ,
  { {0x6abc2973,0x2004007d,0x64402341,0x00000000}},	//   kerf, uzmi_, _uzmi,
  { {0x628304a6,0x7ce60051,0x6abc007d,0x00000000}},	//   cano, _górz, jerf,
  { {0x0697014e,0x6abc64cc,0xbe380062,0x00000000}},	//   ודים_, derf, язох_,
  { {0x799c002b,0x0cd4012c,0x8d73005d,0x00000000}},	//   durw, воюю, کایا,
  { {0x9f440072,0x60cf0013,0x6ee60021,0x00000000}},	//   tymä_, ôcme, _يستل,
  { {0x6abc2a8f,0x8f8b0063,0x73f90041,0x00000000}},	//   gerf, _וְהֵ, פּרו,
  { {0x3eb70041,0xda340085,0xbebc0023,0x00000000}},	//   _חלומ_, веры, enīg,
  { {0x6aaa00bd,0x62834cc2,0x6abc002f,0x00000000}},	//   _öffn, zano, aerf,
  { {0x6abc64cd,0x96f90002,0xc6a70121,0x00000000}},	// [d590] berf, пеат_, дреи,
  { {0x78ad4378,0x60c9013d,0x56940769,0x00000000}},	//   sfav, zdem, каут,
  { {0x273400c7,0xc6a40062,0xdcfb64ce,0x00000000}},	//   vänt_, ърти, astą,
  { {0x26c70648,0x656a0139,0x8cbc0041,0x00000000}},	//   žno_, ífha, ַצוק,
  { {0xdb0d0019,0x62833382,0xe28e2d79,0x00000000}},	//   _osaü, tano, ла_,
  { {0x877a0149,0xeb920063,0x8c1c0063,0x00000000}},	//   _מאשי, אָה_, חודי,
  { {0x6b9d002c,0x395964cf,0xf1b10021,0x00000000}},	//   husg, _kiss_, اءت_,
  { {0x628307e1,0xa1560001,0x41b20021,0x00000000}},	//   sano, нају_, امير,
  { {0x386903cc,0x39590287,0x628364d0,0x00000000}},	//   icar_, _miss_, pano,
  { {0xfe710021,0x22510024,0x0ea9093e,0x00000000}},	//   ددة_, _úzko_, чкой_,
  { {0x7bcf005b,0x6abc502b,0x6281008f,0x00000000}},	//   evcu, verf, _ielo,
  { {0x6abc404f,0x6b400014,0xfce60690,0x00000000}},	//   werf, gögn, хомо,
  { {0x628164d1,0x69c53183,0x84fa0041,0x00000000}},	//   _kelo, _ashe, פּטה,
  { {0xa3d00161,0x799c00bd,0x6abc004d,0x00000000}},	//   षित_, turw, uerf,
  { {0x443a001b,0x62810bab,0xb062004b,0x00000000}},	//   ́p_, _melo, äägi,
  { {0x0d82005a,0xfe360063,0x6abc16c2,0x00000000}},	//   _слън, _ארצי_, serf,
  { {0x2cbf0019,0x3959304b,0x6abc1b69,0x00000000}},	// [d5a0] õude_, _diss_, perf,
  { {0xf1c5001b,0x38690331,0x628164d2,0x00000000}},	//   _đáng_, acar_, _nelo,
  { {0xceb200ff,0xbebc008f,0x8a7b0063,0x00000000}},	//   ריב_, snīg, _מאית,
  { {0x62810185,0x386927dc,0x765c057c,0x00000000}},	//   _aelo, ccar_, _wgry,
  { {0x628164d3,0xf8b30063,0xe3af0049,0x00000000}},	//   _belo, _גשר_, مرو_,
  { {0x273400c7,0x628164d4,0x3f7d0066,0x00000000}},	//   räns_, _celo, dňu_,
  { {0x628164d5,0xfb170041,0x7d1d0195,0x00000000}},	//   _delo, ײַגט_, érsk,
  { {0x6d5e0164,0xf9930063,0x6281004b,0x00000000}},	//   _épai, ארה_, _eelo,
  { {0x925a007e,0x032606c3,0x98c00078,0x00000000}},	//   _فشار_, _здан, ūrės_,
  { {0x1ddb0053,0x62814531,0x91e600fb,0x00000000}},	//   यमंत, _gelo, _позе,
  { {0x32070045,0x2d8a00ea,0x48e3030b,0x00000000}},	//   czny_, ébe_, но́в,
  { {0x26ca001c,0x6b9d1500,0xac1920fb,0x00000000}},	//   _labo_, tusg, дому_,
  { {0x69da0829,0xfd1f01f4,0x395904a7,0x00000000}},	//   åten, rnì_, _riss_,
  { {0xce940094,0xdfcf0043,0x00000000,0x00000000}},	//   _ракъ, _ديه_,   ,
  { {0x6b4000bd,0x318c0080,0xda350121,0x00000000}},	//   mögl, něz_, тевы,
  { {0x2eee1446,0x61e500bd,0xadd70063,0x00000000}},	//   _hoff_, ähli, _טווח_,
  { {0x9817006a,0x395937f7,0xf7700067,0x00000000}},	// [d5b0] ربرا, _viss_, مال_,
  { {0x26ca06b2,0x386964d6,0xbebc001c,0x00000000}},	//   _cabo_, scar_, lnīb,
  { {0x628164d7,0x2d9e4131,0x69c52839,0x00000000}},	//   _relo, nute_, _ushe,
  { {0x628164d8,0xd4e405f7,0xe4e40500,0x00000000}},	//   _selo, лючи, лічн,
  { {0x628164d9,0x69e6003b,0x3ebe64da,0x00000000}},	//   _pelo, ăreş, kett_,
  { {0x3ebe076c,0x2d9e0004,0x4b7c0047,0x00000000}},	//   jett_, kute_, לאדו,
  { {0x3ebe08d5,0x628164db,0x659502d8,0x00000000}},	//   dett_, _velo, _јабу,
  { {0x2d9e64dc,0x32070051,0xed630114,0x00000000}},	//   dute_, rzny_, _leží_,
  { {0x2d9e00bd,0x3f8b0003,0x3ebe077c,0x00000000}},	//   eute_, écu_, fett_,
  { {0x3ebe64dd,0x2d9e075a,0x6eff017d,0x00000000}},	//   gett_, fute_, _bêba,
  { {0x9d460002,0x2d9e1548,0x6b8d004e,0x00000000}},	//   кеод, gute_, _avag,
  { {0xdcfb0051,0xd1640062,0xa0c4043e,0x00000000}},	//   ostę, _съфи, _ميمو,
  { {0xed630066,0x8cb30053,0x3ebe0206,0x00000000}},	//   _beží_, ेज़ो, bett_,
  { {0x2d9e64de,0x6b40013d,0x10040062,0x00000000}},	//   bute_, rögo, _щяхм,
  { {0x19b90071,0x6a83000d,0x2d9e5c75,0x00000000}},	//   нуть_, рлса, cute_,
  { {0x26ca64df,0x6923014b,0xe9440043,0x00000000}},	//   _sabo_, амса, ارسی,
  { {0xf7720032,0x60cb64e0,0x3f420026,0x00000000}},	// [d5c0] شاء_, _magm, iðun_,
  { {0x60cb0829,0xbebc008f,0x7523013d,0x00000000}},	//   _lagm, mnīc, énzn,
  { {0xc4860cbb,0xd5d5000d,0xd6cf0242,0x00000000}},	//   влек, люцы, تقل_,
  { {0x3ebe000f,0x60cb002c,0xdb06013d,0x00000000}},	//   zett_, _nagm, itkí,
  { {0xa3b40651,0x2d9e000c,0x92940002,0x00000000}},	//   ублі, zute_, галц,
  { {0x318c004c,0x7afc00a8,0x78a464e1,0x00000000}},	//   těz_, nkrt, lgiv,
  { {0xdcfb0051,0x95d70121,0x2d91004c,0x00000000}},	//   astę, _идёт_, ázel_,
  { {0x2d9e051e,0x3f42007a,0xddd81d14,0x00000000}},	//   vute_, gðun_, _nevš,
  { {0x3ebe000f,0xff060121,0x3ce60053,0x00000000}},	//   tett_, вянн, टाने_,
  { {0x60cb0025,0x629e0516,0x2d9e64e2,0x00000000}},	//   _eagm, ópod, tute_,
  { {0x3ebe64e3,0x5d55011c,0x69da00c7,0x00000000}},	//   rett_, лкот, åtel,
  { {0x3ebe64e4,0x2d9e60f8,0x752264e5,0x00000000}},	//   sett_, rute_, nnoz,
  { {0x3ebe00ea,0x78a428d7,0xaade0053,0x00000000}},	//   pett_, dgiv, मांक,
  { {0x9b58005a,0x60c00bcf,0x78a401f2,0x00000000}},	//   кият_, lemm, egiv,
  { {0x3eab027d,0xed630066,0xa8a764e6,0x00000000}},	//   žitý_, _veží_, крак,
  { {0x60c064e7,0x78a401f4,0xdcfb0051,0x00000000}},	//   nemm, ggiv, ystę,
  { {0x5884000d,0x60c00072,0xe6790054,0x00000000}},	// [d5d0] рыса, iemm, ейзі_,
  { {0x29020150,0x60c064e8,0x75220023,0x00000000}},	//   _elka_, hemm, enoz,
  { {0x6f1d00be,0x2d8c00ca,0x60c064e9,0x00000000}},	//   ésci, nsde_, kemm,
  { {0x6d5e0164,0x2d8c006f,0x60c064ea,0x00000000}},	//   _épau, isde_, jemm,
  { {0x24580088,0x44290f76,0x289a00ff,0x00000000}},	//   ваць_, ça_, _אירא,
  { {0x60c00072,0x00000000,0x00000000,0x00000000}},	//   eemm,   ,   ,
  { {0x60cb002c,0x27e9000c,0xbebc008f,0x00000000}},	//   _pagm, ţină_, znīc,
  { {0x26c10124,0x50455e96,0x90c502b3,0x00000000}},	//   leho_, лейб, убие,
  { {0x2d8c64eb,0xddd800c2,0x3f420014,0x00000000}},	//   esde_, _revš, rðun_,
  { {0x26c164ec,0xfde9064b,0x2ca964ed,0x00000000}},	//   neho_, едок_, _acad_,
  { {0x273d008b,0x53360047,0x60cb64ee,0x00000000}},	//   rình_, _ענען_, _tagm,
  { {0x60c00164,0x61e5004d,0xeb9a3118,0x00000000}},	//   cemm, ählu, ним_,
  { {0x26c10024,0x8ca50161,0x78a40205,0x00000000}},	//   keho_, _कारो, vgiv,
  { {0xa9a60079,0x4e29000a,0x63bb0035,0x00000000}},	//   лигд, _полн_, _mpun,
  { {0xceb20063,0x66090080,0x78a402f0,0x00000000}},	//   _היו_, _řekn, tgiv,
  { {0xb87b1088,0x3f8d00cd,0x99750141,0x00000000}},	//   _aníb, oseu_, рурш,
  { {0x3f8d0268,0x7d040c55,0xd9435887,0x00000000}},	// [d5e0] nseu_, _ilis, сети,
  { {0x26c10066,0x4b7b0063,0x78a464ef,0x00000000}},	//   geho_, _ראיו, sgiv,
  { {0x7d045bb4,0x78a42883,0x63bb64f0,0x00000000}},	//   _klis, pgiv, _apun,
  { {0xf483005e,0xfc3f0046,0x05770044,0x00000000}},	//   бушн, lgía_, امنة_,
  { {0x60c00072,0x07a30085,0x752264f1,0x00000000}},	//   vemm, _лаян, rnoz,
  { {0x7d040994,0x26c10024,0x2d8c00ac,0x00000000}},	//   _llis, ceho_, ysde_,
  { {0x7d044a89,0x394064f2,0x60c03c94,0x00000000}},	//   _olis, olis_, temm,
  { {0xb87b03d9,0x76430051,0x50f4006e,0x00000000}},	//   _iníc, żnyc, рзит,
  { {0xa50764f3,0x394014c8,0x60c064f4,0x00000000}},	//   _сета_, ilis_, remm,
  { {0x60c0024a,0xd24f006a,0x7d0464f5,0x00000000}},	//   semm, _کنم_, _alis,
  { {0x63a200fe,0x61e5004d,0xc27b0063,0x00000000}},	//   luon, ählt, _נראי,
  { {0x394000e3,0xb87b0066,0x7d0464f6,0x00000000}},	//   jlis_, _mníc, _clis,
  { {0xab62005b,0x7d040139,0x8ff7013a,0x00000000}},	//   şüne, _dlis, _مرور_,
  { {0x628a01c0,0x394064f7,0x7d0464f8,0x00000000}},	//   nafo, elis_, _elis,
  { {0xe9190086,0x63a200fe,0x1efb0047,0x00000000}},	//   вові_, huon, _אלגע,
  { {0x63a20035,0xd7e70086,0x3f420026,0x00000000}},	//   kuon, лізо, iðum_,
  { {0xb7150062,0x69c801f2,0x6c780593,0x00000000}},	// [d5f0] адащ, æder, _صحيح_,
  { {0x7d1606ce,0x25a1004d,0x394064f9,0x00000000}},	//   _zmys, tuhl_, alis_,
  { {0x26c100bb,0x63bb1e6a,0x7d16001f,0x00000000}},	//   reho_, _spun, _ymys,
  { {0x4864005a,0xba74007e,0x98790047,0x00000000}},	//   _гърб, _پایت, _שאָט,
  { {0xdfc60032,0x63a23559,0xe2850363,0x00000000}},	//   _بي_, guon, алли,
  { {0x2d910080,0x69d500c2,0x68ed64fa,0x00000000}},	//   ázek_, ovze, ljad,
  { {0x6f1a02b0,0x3f420026,0xa2290062,0x00000000}},	//   ditc, gðum_, ъжка_,
  { {0x68ed014f,0xa2a70053,0x63a264fb,0x00000000}},	//   njad, _फ़ॉर्, buon,
  { {0x68ed64fc,0x3f8d1494,0xdcfb008f,0x00000000}},	//   ijad, useu_, artī,
  { {0xcef5000a,0x7d160080,0x628a01a8,0x00000000}},	//   рчињ, _smys, cafo,
  { {0x3f8d0268,0x245a005b,0x68ed0026,0x00000000}},	//   sseu_, _tümü_, kjad,
  { {0xcb6a193d,0x7fd52049,0xe3a70593,0x00000000}},	//   каме_, _вікі, ير_,
  { {0x29090009,0x66090080,0x7d04220a,0x00000000}},	//   dhaa_, _řekl, _vlis,
  { {0xbea20088,0x68ed64fd,0xfaa6005e,0x00000000}},	//   _дашк, ejad, јаво,
  { {0xfc3f1309,0xda79000d,0x7c2d64fe,0x00000000}},	//   rgía_, ыяў_, _exar,
  { {0x7529017f,0x7d040be0,0x7d160051,0x00000000}},	//   _njez, _ulis, _umys,
  { {0x394064ff,0x068608a7,0xa6860086,0x00000000}},	// [d600] rlis_, иган, илад,
  { {0x394000ac,0x6d5f0164,0xd707000d,0x00000000}},	//   slis_, _épar, ануе_,
  { {0x443f6500,0x6449017d,0x44660002,0x00000000}},	//   _ayu_, _azei, авев,
  { {0x07a60be6,0x2db60047,0x63a26501,0x00000000}},	//   _камн, ילען_, tuon,
  { {0xf863019d,0xb607003d,0x628a6502,0x00000000}},	//   _євро, ekšē, tafo,
  { {0x753b00ac,0x29001668,0x6113003b,0x00000000}},	//   _ekuz, lkia_, călz,
  { {0x442d6503,0xe81a0161,0x69d8004c,0x00000000}},	//   _exe_, _नेता_, _švej,
  { {0x3f42007a,0x29000341,0x6f1a4e6a,0x00000000}},	//   rðum_, nkia_, witc,
  { {0x29000006,0x63a20003,0x902a0062,0x00000000}},	//   ikia_, quon, ъцка_,
  { {0x6d4d6504,0x3eb80026,0x3eaa004d,0x00000000}},	//   _shaa, ýrt_, übt_,
  { {0x290000fe,0xb6d90047,0xc6d90047,0x00000000}},	//   kkia_, אַרט, אַרר,
  { {0xfbe80013,0x628826c5,0x01fb0041,0x00000000}},	//   _trễ_, _hedo, _שפאל,
  { {0x6288028d,0x6b9d00f5,0x442d1a05,0x00000000}},	//   _kedo, ursg, _xxe_,
  { {0x62880199,0x6b841f51,0x6560101f,0x00000000}},	//   _jedo, _dwig, _limh,
  { {0x68ed0268,0x8d940021,0x6b841a6c,0x00000000}},	//   tjad, _البش, _ewig,
  { {0xae5b009f,0x3171013d,0x4d73005d,0x00000000}},	//   _בכור, _ézze_, _بطور,
  { {0x68ed6505,0x6288001f,0xc0530047,0x00000000}},	// [d610] rjad, _oedo, ַזע_,
  { {0x68ed0019,0x7bcd03cc,0xe7300021,0x00000000}},	//   sjad, _isau, وصل_,
  { {0x7d1d6506,0x672500d1,0x443f0150,0x00000000}},	//   oiss, rnhj, _syu_,
  { {0x2d9e0139,0xd126014d,0xe3b10021,0x00000000}},	//   irte_, _رم_, كرت_,
  { {0x2d9e0199,0x62886507,0xe3b30593,0x00000000}},	//   hrte_, _bedo, ترض_,
  { {0x7d1d6508,0x64400022,0xb0620656,0x00000000}},	//   hiss, _dymi, ääni,
  { {0x7d1d6509,0xf4260072,0x6288650a,0x00000000}},	//   kiss, _ääni_, _dedo,
  { {0x753b00ac,0x7d1d0072,0xa507012c,0x00000000}},	//   _ukuz, jiss, _тягл,
  { {0x2d9e4806,0xf41f397a,0x2e690121,0x00000000}},	//   erte_, _ää_, липп_,
  { {0x62880162,0xaf05650b,0x7d1d0050,0x00000000}},	//   _gedo, спол, eiss,
  { {0x7d1d650c,0x200d013d,0x2d910260,0x00000000}},	//   fiss, szei_, éze_,
  { {0x7d1d650d,0x26d1650e,0x1d0a0062,0x00000000}},	//   giss, _lazo_, уеми_,
  { {0x38c8007e,0x0c231dd6,0x2d9e650f,0x00000000}},	//   یاری_, змян, arte_,
  { {0x20a70053,0x7d1d6510,0xcb6701ce,0x00000000}},	//   _गाँध, aiss, саре_,
  { {0x7bcd6511,0x29000072,0x2d940085,0x00000000}},	//   _esau, tkia_, _дрыс,
  { {0x3cf10024,0x29000006,0x7d1d6512,0x00000000}},	//   ľová_, ukia_, ciss,
  { {0x69030004,0x999a0080,0x26d11fba,0x00000000}},	// [d620] _tõen, _typů_, _bazo_,
  { {0x656000a5,0x29190526,0xc68f0044,0x00000000}},	//   _simh, _emsa_, ِّل_,
  { {0xf9920032,0x20a70053,0xb0a70053,0x00000000}},	//   _عبد_, _गांध, _गांग,
  { {0x62886513,0xe76a0049,0x6903004b,0x00000000}},	//   _sedo, _محسن_, _jõel,
  { {0x69030019,0x19570063,0x06760062,0x00000000}},	//   _mõel, _לבטל_, _губя,
  { {0x2d9e1609,0x04430121,0x64400195,0x00000000}},	//   yrte_, чечн, _vymi,
  { {0x7e7e0019,0x64400051,0x628854b0,0x00000000}},	//   _õppi, _wymi, _vedo,
  { {0x65600027,0x6b400026,0x60f8042c,0x00000000}},	//   _uimh, mögu, рния_,
  { {0x7d1d2d4e,0x6b400026,0x00000000,0x00000000}},	//   viss, lögu,   ,
  { {0x7d1d0c84,0x3eca005e,0x2d9e00a8,0x00000000}},	//   wiss, ућим_, trte_,
  { {0x20026514,0xdb060072,0x7d1d54cb,0x00000000}},	//   ški_, itkä, tiss,
  { {0xa06a0138,0x2d9e004d,0xc5f30063,0x00000000}},	//   _сада_, rrte_, לדת_,
  { {0x705600f2,0x7c220014,0x7d1d6515,0x00000000}},	//   _انشا, _þorl, riss,
  { {0xde580088,0x7d1d6516,0x2d9e0a80,0x00000000}},	//   _калі_, siss, prte_,
  { {0x7afa0137,0xc2110063,0x7d1d6517,0x00000000}},	//   ötta, ֵ֔ל_, piss,
  { {0x6b400014,0x7bcd008f,0xa9350085,0x00000000}},	//   dögu, _tsau, цебш,
  { {0x2d910080,0x56f50002,0x02fa0042,0x00000000}},	// [d630] ázev_, опаѓ, ्साह_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xef110063,0x7e6d0058,0xdcfb0058,0x00000000}},	//   וּא_, _şapk, lttı,
  { {0x26d10035,0xb87b0025,0x2e3b0047,0x00000000}},	//   _wazo_, _inío, נגאנ,
  { {0xb062004b,0x95540044,0x626521e9,0x00000000}},	//   ääli, أخلا, овла,
  { {0x69d80a10,0xfbb8009a,0xd346005d,0x00000000}},	//   _švei, צפות_, قیقه_,
  { {0x945d0045,0xdce4017f,0x29050078,0x00000000}},	//   _pańs, _sunč, ūlau_,
  { {0x3387007b,0x8505009b,0xa98c009d,0x00000000}},	//   _гужв, _بورن, נָוִ,
  { {0x23740044,0xc2c50044,0x1ef900de,0x00000000}},	//   _فالح, _ويري, لعدة_,
  { {0xdcc20053,0xea000013,0xbebc008f,0x00000000}},	//   षज्ञ, hoại_, lnīj,
  { {0x6b520146,0xacea00da,0x81c7008f,0x00000000}},	//   lægg, амна_, frēš,
  { {0x692c0058,0x81c70023,0x42040044,0x00000000}},	//   eğen, grēš, _عِنْ,
  { {0xcb6a0138,0xb87b0027,0x7af76518,0x00000000}},	//   раге_, _anío, _boxt,
  { {0x8b260054,0x6ea60042,0xda650044,0x00000000}},	//   ідве, _खाएँ, كافي,
  { {0xfd120032,0x69030019,0xab190454,0x00000000}},	//   _يجب_, _tõel, сцях_,
  { {0x18671736,0xea000013,0x48e3034b,0x00000000}},	//   жати_, goại_, мосв,
  { {0xdb06051c,0x7af737b6,0x7b760044,0x00000000}},	// [d640] ttkä, _foxt, _بطبا,
  { {0x6d466519,0x4ded0042,0x4b23030b,0x00000000}},	//   llka, _छपाई_, _омыв,
  { {0xa96a0001,0xb87b0025,0xe61a00d7,0x00000000}},	//   _њима_, _gnío, јде_,
  { {0xec3600b5,0x6b400014,0xe4e30054,0x00000000}},	//   ֿאַר_, rögu, дішн,
  { {0x6b400014,0x6d46651a,0xfbca0042,0x00000000}},	//   sögu, ilka, िबिम,
  { {0x2ae30161,0xb06200fe,0x6d46004d,0x00000000}},	//   खाएँ_, äämi, hlka,
  { {0xaab20161,0x05660054,0x4ab20042,0x00000000}},	//   _जानक, _єван, _जानव,
  { {0x61f70137,0xa2ba0042,0xd1300044,0x00000000}},	//   äxla, _शॉर्, عمة_,
  { {0xc953014e,0xdec6005e,0xcec601a4,0x00000000}},	//   ומה_, ољно, ощни,
  { {0x7b100199,0xeeb70088,0x2fdd001f,0x00000000}},	//   _häuf, ольш_, _drwg_,
  { {0x81c7001c,0x7b1000e0,0x6b400137,0x00000000}},	//   trēš, _käuf, högs,
  { {0x63a2651b,0x7afa0137,0xc05a0054,0x00000000}},	//   oron, öttn, _кіл_,
  { {0x9f4600bd,0xfc640062,0x69de2335,0x00000000}},	//   _groß_, дърн, _arpe,
  { {0x7b1000bd,0x6d461f21,0xdcfb005b,0x00000000}},	//   _läuf, alka, rttı,
  { {0x2d910080,0x59ce0053,0xa9550054,0x00000000}},	//   ázet_, _हैदर, зкві,
  { {0xdc3f2f42,0x8d180242,0x63a22feb,0x00000000}},	//   líčo, _وزير_, kron,
  { {0xe908000a,0x69de651c,0xf7700049,0x00000000}},	// [d650] цатa_, _erpe, نال_,
  { {0x3f7b0047,0x8cbc0053,0x63a2651d,0x00000000}},	//   יאמס, ष्ठो, dron,
  { {0x7e7e004b,0x63a2651e,0x9da30042,0x00000000}},	//   _õppu, eron, _कमज़ो,
  { {0xf9da00b5,0x63a2012a,0x629a651f,0x00000000}},	//   _פֿיל, fron, _adto,
  { {0x63a26520,0x248f00e5,0x316c0023,0x00000000}},	//   gron, ragm_, _audz_,
  { {0xe738000d,0x3f990014,0xc8ab0053,0x00000000}},	//   _меў_, ásum_, _छाँट,
  { {0x63a2051e,0x62080021,0x79956521,0x00000000}},	//   aron, يْهِ_, nszw,
  { {0xdcfb001c,0x78ad6522,0x7bdf1117,0x00000000}},	//   istē, ngav, _orqu,
  { {0x6b5200b9,0xef190505,0x63a202c4,0x00000000}},	//   læge, йми_, cron,
  { {0x8e74071f,0xdcfb0023,0x41e70044,0x00000000}},	//   муюч, kstē, _وساف,
  { {0x7bdf6523,0x628300c3,0xa344000d,0x00000000}},	//   _arqu, mbno, _цэтл,
  { {0x6d4600fe,0xc1ba0063,0x7c220014,0x00000000}},	//   ulka, _למעש, _þork,
  { {0x80270032,0x78ad00b9,0x69de004c,0x00000000}},	//   _برام, dgav, _srpe,
  { {0x3d020051,0x60c96524,0x290b00f8,0x00000000}},	//   _mówi_, leem, _alca_,
  { {0xdce9005b,0x7bdf2667,0x2fcd13de,0x00000000}},	//   ardı, _erqu, lweg_,
  { {0x248d04c6,0x78ad6525,0x60c96526,0x00000000}},	//   _neem_, ggav, neem,
  { {0xc8690047,0xac17005e,0x2fcd030c,0x00000000}},	// [d660] ָן_, _ноћу_, nweg_,
  { {0x69de04d9,0x60c91860,0x63a26527,0x00000000}},	//   _trpe, heem, vron,
  { {0x657e0014,0x69de01a8,0x60c9078c,0x00000000}},	//   upph, _urpe, keem,
  { {0x63a26528,0xcd9a0041,0xb0620cb0,0x00000000}},	//   tron, מױער, ääki,
  { {0x63a26529,0x645d0114,0x60c907d2,0x00000000}},	//   uron, _úsil, deem,
  { {0xb3e90032,0x236501b3,0x63a2652a,0x00000000}},	//   تعمل_, _cilj_, rron,
  { {0x7b10004d,0xe297007b,0xd1b70044,0x00000000}},	//   _täuf, чај_, كايا_,
  { {0x859b014e,0x63a2652b,0x60c900b9,0x00000000}},	//   _לשלו, pron, geem,
  { {0x2fcd006f,0xe29a303d,0x03a311fd,0x00000000}},	//   gweg_, _газ_, _пито,
  { {0xdce4008f,0x38170063,0x4d980054,0x00000000}},	//   _runā, פקים_, окою_,
  { {0x908a0032,0xc27b0063,0x127b0047,0x00000000}},	//   _هناك_, _הרבי, _האבע,
  { {0xcd070054,0x00000000,0x00000000,0x00000000}},	//   їчни,   ,   ,
  { {0x8ae70086,0x656e00a4,0x9be70054,0x00000000}},	//   півл, _lubh, чінк,
  { {0x7b640079,0x752201f4,0xb87b0114,0x00000000}},	//   етсе, hioz, _vním,
  { {0x78ad652c,0xdebb0063,0xaa5d0054,0x00000000}},	//   tgav, _המול, ревi,
  { {0x6b520146,0x8e470032,0xa3ad0042,0x00000000}},	//   væge, _عليك_, _कमल_,
  { {0x78ad02b0,0xdbdd0026,0x69da0137,0x00000000}},	// [d670] rgav, _háþr, åter,
  { {0x248d0034,0x7d0d004a,0xa81814d7,0x00000000}},	//   _seem_, _hlas, ستقر_,
  { {0x78ad57cb,0x8afc0063,0x7b1000bd,0x00000000}},	//   pgav, _להזי, _säug,
  { {0x69c500ac,0xf6500021,0x656e0d17,0x00000000}},	//   _iphe, ائك_, _dubh,
  { {0x394908eb,0xe28e126b,0x60c91b6b,0x00000000}},	//   mlas_, ка_, veem,
  { {0x49b8006a,0x7bdd0019,0x3949652d,0x00000000}},	//   _باید_, ivsu, llas_,
  { {0x39490025,0x7d0600d1,0x60c93a29,0x00000000}},	//   olas_, ykks, teem,
  { {0x7c3a0045,0xa1560001,0xa4d40086,0x00000000}},	//   ętrz, мају_, _посі,
  { {0xa2b5011c,0x60c91af3,0x69dc007d,0x00000000}},	//   _обач, reem, zvre,
  { {0x69ce001f,0xe3ca006d,0x2fcd652e,0x00000000}},	//   ywbe, señó_, rweg_,
  { {0x3cca06b4,0xcc8a007e,0x3949652f,0x00000000}},	//   олно_, ينده_, klas_,
  { {0xce18000d,0x63a40130,0x7d0d1e35,0x00000000}},	//   яцыі_, šine, _clas,
  { {0xed570086,0x2ef50263,0x39496530,0x00000000}},	//   ьою_, _оздр, dlas_,
  { {0xada10024,0x63ab0290,0xdce4003b,0x00000000}},	//   ľúbe, iugn, _bună,
  { {0xb87b0066,0x69dc0edc,0x3949002b,0x00000000}},	//   _kníh, uvre, flas_,
  { {0x691100b9,0xdce4000c,0x63ab00a4,0x00000000}},	//   _nåed, _dună, kugn,
  { {0x1dd50053,0x656e6531,0xd94300fb,0x00000000}},	// [d680] धिकत, _subh, тети,
  { {0x61e1001f,0x7d0d3cd4,0x98a00051,0x00000000}},	//   _orll, _zlas, dnią_,
  { {0x3949006d,0x75d60021,0x673e007d,0x00000000}},	//   blas_, بيضا, ropj,
  { {0x39490460,0x63ab004d,0xfdf60063,0x00000000}},	//   clas_, fugn, וצעת_,
  { {0x63ab00a4,0x3f420026,0x61e1001f,0x00000000}},	//   gugn, iður_, _arll,
  { {0x39406532,0xab5b0244,0x8b89009a,0x00000000}},	//   lois_, lwür, פָנֶ,
  { {0x63ab002c,0xaac00161,0x6d440078,0x00000000}},	//   augn, श्यक, _okia,
  { {0x399b01d8,0x39405214,0xab5b004d,0x00000000}},	//   קיפד, nois_, nwür,
  { {0x8fa30fe2,0x26d80006,0x248616ed,0x00000000}},	//   вање, _karo_, mbom_,
  { {0x7d0d6533,0x2486007d,0x39406534,0x00000000}},	//   _slas, lbom_, hois_,
  { {0x2d982a2e,0x7d0d6535,0x2d8a0003,0x00000000}},	//   ére_, _plas, èbe_,
  { {0x26d8002c,0x7e6d000c,0x3f420026,0x00000000}},	//   _laro_, _şapt, gður_,
  { {0x69c50be9,0x39400003,0x7d0d6536,0x00000000}},	//   _sphe, dois_, _vlas,
  { {0x5f03005a,0x21240139,0x7bdd01e1,0x00000000}},	//   _изча, limh_, rvsu,
  { {0x39400164,0x21240025,0xcda7007e,0x00000000}},	//   fois_, oimh_, _قهوه_,
  { {0x21240025,0x7d0d6537,0xab5b004d,0x00000000}},	//   nimh_, _ulas, gwür,
  { {0xd6db005a,0x39492727,0x20041e13,0x00000000}},	// [d690] жте_, rlas_, nymi_,
  { {0x08540055,0x39493a85,0xab5b004d,0x00000000}},	//   твую, slas_, rwüs,
  { {0xfbdf017d,0x39496538,0x69c500e5,0x00000000}},	//   lvê_, plas_, _uphe,
  { {0x68f8034d,0x20040066,0x98a00051,0x00000000}},	//   ľadá, kymi_, tnią_,
  { {0x63ab00a4,0xbcfb0003,0x26d82443,0x00000000}},	//   uugn, mméd, _faro_,
  { {0x290900fe,0x0577007e,0x63b9002b,0x00000000}},	//   lkaa_, _يازد, rtwn,
  { {0x3f420026,0x63b9001f,0x61450259,0x00000000}},	//   yður_, stwn, нека,
  { {0x63ab5209,0x74a41313,0x00000000,0x00000000}},	//   pugn, _ајфе,   ,
  { {0x290900fe,0x83350304,0xafe501dd,0x00000000}},	//   ikaa_, _знах, хопл,
  { {0x93440001,0x60c200d1,0x29090072,0x00000000}},	//   _анђе, _ebom, hkaa_,
  { {0x2909024a,0x6b8d00a4,0xd12e007e,0x00000000}},	//   kkaa_, _awag, شمی_,
  { {0x28df0235,0x657a006c,0xfd120593,0x00000000}},	//   _पोलि, _éthe, اجد_,
  { {0x3f42007a,0xeb976539,0x656900fe,0x00000000}},	//   rður_, ния_, _mieh,
  { {0x3b0a0076,0x60db30fa,0x7b10004d,0x00000000}},	//   чего_, ldum, _säub,
  { {0x1d0a0001,0x19b90086,0x395600d7,0x00000000}},	//   _неки_, муть_, ењат,
  { {0x6d440035,0x26d80474,0xed570062,0x00000000}},	//   _ukia, _saro_, _пощ_,
  { {0x394002a5,0x69c1005b,0x26d8653a,0x00000000}},	// [d6a0] rois_, çler, _paro_,
  { {0x7bd600a4,0xab5b004d,0x29090072,0x00000000}},	//   _isyu, swür, akaa_,
  { {0x394003d9,0x20040051,0x6b8d006f,0x00000000}},	//   pois_, zymi_, _zwag,
  { {0x98a00022,0xbebc008f,0xb0ae0042,0x00000000}},	//   dnić_, lnīt, _टाइग,
  { {0x98a00051,0x7afe653b,0x26d8001f,0x00000000}},	//   enić_, _kopt, _taro_,
  { {0xbcfb0003,0x7d1d013d,0xeb930041,0x00000000}},	//   mmée, érsz, אָק_,
  { {0x20040051,0x64a6000d,0x2fc600ac,0x00000000}},	//   wymi_, _пава, _spog_,
  { {0x21670138,0x7afe1235,0xdfd00021,0x00000000}},	//   нији_, _lopt, ليب_,
  { {0x7afe00a4,0x21240025,0x25af0051,0x00000000}},	//   _oopt, rimh_, ągle_,
  { {0xdcc90161,0x656900bd,0x27e00072,0x00000000}},	//   िज्ञ, _zieh, ivin_,
  { {0x7bd600e3,0x21a30062,0xddea005d,0x00000000}},	//   _asyu, _бихм, سرده_,
  { {0x6146005e,0x6b520014,0xc8df0042,0x00000000}},	//   _џеда, væga, _पोंट,
  { {0x7c670032,0x69d80078,0x6d5d2b02,0x00000000}},	//   عاجل, _švep, rmsa,
  { {0xdcfb0006,0xdee3005e,0x7afe1950,0x00000000}},	//   ystė, _бољи, _copt,
  { {0x68fd00e8,0x290900fe,0x672510f0,0x00000000}},	//   _posd, tkaa_, vihj,
  { {0x290f0139,0xc8c90593,0x79750022,0x00000000}},	//   óga_, بورن_, _wąwo,
  { {0x6b8d0045,0xbcfb1db1,0xd7950062,0x00000000}},	// [d6b0] _uwag, rméd, тизъ,
  { {0x65690199,0xa0370063,0x6b5200b9,0x00000000}},	//   _sieh, תאמה_, lægn,
  { {0x644900e3,0xfb1c0063,0x69350121,0x00000000}},	//   _syei, _מוזמ, _анну,
  { {0x48ab0055,0x7bda001c,0xd5b8000d,0x00000000}},	//   _этом_, ātuv, эсу_,
  { {0xc6a70dd5,0xda67007e,0x98a00051,0x00000000}},	//   _први, _تاکي, wnić_,
  { {0x8c1c014e,0x13080086,0xeb920063,0x00000000}},	//   הודי, нній_, בָה_,
  { {0x15a8005a,0x7afa00e0,0xf6e40085,0x00000000}},	//   _пъти_, ötti, _сцян,
  { {0x60db0035,0xbebc001c,0xf994009f,0x00000000}},	//   udum, znīt, ארק_,
  { {0xe0d606bc,0x200b0114,0x60db653c,0x00000000}},	//   твы_, áci_, rdum,
  { {0xaf05000a,0x6efe004c,0x8fc400de,0x00000000}},	//   тпол, _nábě, ازين,
  { {0x200b0743,0x7afe04aa,0x6903004b,0x00000000}},	//   šci_, _ropt, _jões,
  { {0x27e00072,0xdb0d0014,0xd48f0054,0x00000000}},	//   yvin_, _spað, арi_,
  { {0x4c360085,0x7afe653d,0x711a009a,0x00000000}},	//   тэнт, _popt, _קונפ,
  { {0xa3e20161,0xe8ff0003,0x0b433aca,0x00000000}},	//   धित_, _aoû_, инян,
  { {0xcb67653e,0x1a66005d,0x00000000,0x00000000}},	//   таре_, ضیحی_,   ,
  { {0x2d850da1,0x33272a81,0x27e00e6f,0x00000000}},	//   mple_, hinx_, tvin_,
  { {0xa6960001,0xf0920063,0x8696005e,0x00000000}},	// [d6c0] вреј, ינן_, вјеч,
  { {0xbcfb0003,0x3207004a,0x637f003b,0x00000000}},	//   rmée, kyny_, _mână,
  { {0xdbe30003,0xceb80022,0x6903004b,0x00000000}},	//   _rééc, więk_, _põet,
  { {0x7c220026,0x6efe004c,0x32070022,0x00000000}},	//   _þors, _zábě, dyny_,
  { {0x69030004,0x290c13ed,0x332701a8,0x00000000}},	//   _võet, ūdas_, finx_,
  { {0x8c1b0063,0xa894008f,0xa2b30054,0x00000000}},	//   ווני, šķīr, ибіч,
  { {0x7bc1003b,0x6aa10014,0x98a00022,0x00000000}},	//   ălui, ólfi, wnię_,
  { {0xf993014e,0x66031bd5,0x00000000,0x00000000}},	//   ברה_, änke,   ,
  { {0xa8ab0063,0x13a8005d,0x61e7013d,0x00000000}},	//   וֹיִ, _سنای_, _ájln,
  { {0x9df8000a,0x98a00022,0x00000000,0x00000000}},	//   енот_, rnię_,   ,
  { {0x236b0066,0x6db4000d,0xd176000d,0x00000000}},	//   žijú_, ыйну, _рызы,
  { {0xd02603d6,0x6298653f,0x60262953,0x00000000}},	//   _имей, lavo, _идеа,
  { {0xdcfb003d,0xd00f0032,0x9d181406,0x00000000}},	//   lstī, _ولم_, тоят_,
  { {0xb3450016,0xda7b0076,0x5b270086,0x00000000}},	//   moçã, ьям_, тьма,
  { {0x6b5200b9,0x1db60053,0x2ef80014,0x00000000}},	//   mægl, _अमित, örfu_,
  { {0x61f70137,0xdcfb008f,0x62986540,0x00000000}},	//   äxli, istī, havo,
  { {0x08550636,0x32070022,0x62986541,0x00000000}},	// [d6d0] уваю, zyny_, kavo,
  { {0xdcfb003d,0x62986132,0x6d4f3112,0x00000000}},	//   kstī, javo, llca,
  { {0x63a40025,0x62986285,0x4b380063,0x00000000}},	//   áinn, davo, _ברזל_,
  { {0x58840475,0xf48708ac,0xc4550044,0x00000000}},	//   _выра, тужн, هَاب,
  { {0xad1c00b7,0x9d1c0047,0x4ac00053,0x00000000}},	//   וואר, וואט, श्वव,
  { {0x69030019,0x629821dc,0x63540054,0x00000000}},	//   _tões, gavo, авчу,
  { {0xb594005a,0xd5b85b6d,0xdb060066,0x00000000}},	//   _висш, _ист_, nuká,
  { {0xdfd10021,0x32070051,0x7c3a095a,0x00000000}},	//   ميع_, ryny_, ştri,
  { {0xdcfb0023,0x62986542,0x9404005d,0x00000000}},	//   astī, bavo, _پوله,
  { {0x637f003b,0xc1a70131,0xc35500de,0x00000000}},	//   _vână, _ајди, _صَاع,
  { {0x4d662127,0xd2510021,0xcd2a25a6,0x00000000}},	//   лков, _انا_, ежне_,
  { {0x637f000c,0x2d856543,0xdb066544,0x00000000}},	//   _tână, rple_, stkü,
  { {0xbebc008f,0x4fa504f2,0x8b04011b,0x00000000}},	//   rnīr, _силв, ářov,
  { {0x8f9a00b7,0xe45600b5,0x2d8542a3,0x00000000}},	//   _װיקי, טירט_, pple_,
  { {0xfce60086,0xe8e0008d,0x8af70085,0x00000000}},	//   _бойо, _scốt_, ынёс_,
  { {0x629819bc,0x6903004b,0x399e005f,0x00000000}},	//   zavo, _sõer, rįs_,
  { {0x27e60027,0x6d466545,0x46ea6546,0x00000000}},	// [d6e0] íon_, moka, ндан_,
  { {0x6b84002c,0x6d466547,0x563a02f8,0x00000000}},	//   _itig, loka, нџер_,
  { {0x6937007d,0x34aa005e,0x62986548,0x00000000}},	//   mćen, евео_, vavo,
  { {0xb87b0942,0x2db60047,0x35450054,0x00000000}},	//   _caíd, טלען_, ахів,
  { {0x4420001b,0xd3260121,0x62986549,0x00000000}},	//   ài_, льки, tavo,
  { {0x533400e1,0xb345017d,0x6d46654a,0x00000000}},	//   јект, voçã, hoka,
  { {0x6298654b,0xa5d80063,0xe73724dc,0x00000000}},	//   ravo, _בַּי, _сер_,
  { {0x2902024a,0xf993014e,0x4154000a,0x00000000}},	//   _joka_, זרה_, јвис,
  { {0xe292043b,0x7ff60021,0x2902654c,0x00000000}},	//   _هذا_, اسعا, _moka_,
  { {0x3f82001c,0x2902654d,0xc7d70063,0x00000000}},	//   īku_, _loka_, נויי_,
  { {0x3f82008f,0x6d4607be,0x10a604c3,0x00000000}},	//   ūku_, foka, _биен,
  { {0x6d46654e,0x9fe600f2,0x709a0044,0x00000000}},	//   goka, _مسته, _أنشأ_,
  { {0xdb1d000f,0xc6210053,0x29d50066,0x00000000}},	//   ltsé, _मध्य_, _sťa_,
  { {0x501b014e,0x6b520046,0xcb680085,0x00000000}},	//   _אודו, lægj, лаўе_,
  { {0x2902654f,0x1995000d,0x6d46013d,0x00000000}},	//   _boka_, рабя, boka,
  { {0x2d9e6550,0x93c7000c,0x6b520026,0x00000000}},	//   mste_, ltăţ, nægj,
  { {0x2d9e1a33,0x65620066,0x7c220046,0x00000000}},	// [d6f0] lste_, dmoh, _þorp,
  { {0xb87b0016,0x2d9e00c3,0x7bcd00a4,0x00000000}},	//   _saíd, oste_, _ipau,
  { {0x2d9e6551,0xa5d50854,0x4427005d,0x00000000}},	//   nste_, ржеш, گراف,
  { {0x39a100eb,0x2d9e6552,0x9474005d,0x00000000}},	//   mės_, iste_, مدها,
  { {0x39a100eb,0x61e80139,0x2d9e004d,0x00000000}},	//   lės_, _ardl, hste_,
  { {0x6b7c00b5,0x9f4600ac,0x2d9e6553,0x00000000}},	//   ערונ, _droë_, kste_,
  { {0x39a10812,0x6d4614f9,0x2d9e6554,0x00000000}},	//   nės_, yoka, jste_,
  { {0xd1310032,0x2d9e3210,0x93c7000c,0x00000000}},	//   تمع_, dste_, etăţ,
  { {0x2d9e6555,0x692c003b,0x7f19000d,0x00000000}},	//   este_, nşea, віну_,
  { {0x39a100eb,0x21260150,0x2d9e24f5,0x00000000}},	//   kės_, _emoh_, fste_,
  { {0x6d466556,0x6b846557,0x2d9e1ff4,0x00000000}},	//   toka, _stig, gste_,
  { {0x39a100eb,0x6d4600fe,0xd1670062,0x00000000}},	//   dės_, uoka, _съзи,
  { {0x290204d9,0x2d9e6558,0x6d466559,0x00000000}},	//   _roka_, aste_, roka,
  { {0x6d462a3e,0xbcfb0d23,0x2d9e5888,0x00000000}},	//   soka, rméa, bste_,
  { {0xc8960540,0x6f030025,0x8a030612,0x00000000}},	//   ирањ, _ionc, озре,
  { {0x692c005b,0xbcfb013d,0x3b960141,0x00000000}},	//   eğer, lmén, _кјот,
  { {0x6bd7007e,0x6937007d,0xbcfb0114,0x00000000}},	// [d700] _نويس_, pćen, omén,
  { {0x39a100eb,0xdb06005b,0x6f03655a,0x00000000}},	//   bės_, dukç, _jonc,
  { {0xab5b00bd,0x69030019,0x29025434,0x00000000}},	//   stüc, _tõep, _toka_,
  { {0x7d04024a,0x660300c7,0x452a0062,0x00000000}},	//   _jois, änka, ъжен_,
  { {0x6562053b,0x64360044,0x7d04655b,0x00000000}},	//   rmoh, جراء, _mois,
  { {0xbcfb0080,0x6f0324aa,0xdb1d00ea,0x00000000}},	//   jmén, _nonc, ttsé,
  { {0xbcfb00ea,0x6028001c,0x4aad0053,0x00000000}},	//   dmén, zīmī, फ़्टव,
  { {0x7d040cfc,0x7b1000bd,0x3d100053,0x00000000}},	//   _nois, _säul, ासों_,
  { {0x39a100eb,0x60f7000d,0x2167005e,0x00000000}},	//   zės_, рныя_, шићи_,
  { {0x2d9e03a8,0x7b1000bd,0x7d040139,0x00000000}},	//   tste_, _bäum, _aois,
  { {0x7bcd00eb,0x395260a9,0x6f0334eb,0x00000000}},	//   _spau, klys_, _donc,
  { {0x7d0433ef,0x39a10006,0x2d9e655c,0x00000000}},	//   _cois, vės_, rste_,
  { {0x6f0303b2,0x2d9e0312,0x93c7003b,0x00000000}},	//   _fonc, sste_, ptăţ,
  { {0x39a100eb,0x6e940032,0xbcfb0080,0x00000000}},	//   tės_, _الثا, cmén,
  { {0xba08005a,0xe9190086,0x7d162058,0x00000000}},	//   ахте_, гові_, _flys,
  { {0x98750088,0x39a10006,0x7d16655d,0x00000000}},	//   слац, rės_, _glys,
  { {0x39a10006,0x6d4d0ddd,0x2aab0002,0x00000000}},	// [d710] sės_, _ikaa, _итно_,
  { {0x39a100eb,0x67ca003d,0xceb828d2,0x00000000}},	//   pės_, dējā, ngę_,
  { {0x09f90032,0xe535030b,0x3634005d,0x00000000}},	//   _صفحة_, бежь, يرمس,
  { {0x28f90076,0x4d790047,0xbcfb013d,0x00000000}},	//   _семь_, אָסא, zmén,
  { {0xda67005d,0x8cbc0042,0xd7f805fd,0x00000000}},	//   _حاکي, ष्टो, _кур_,
  { {0xc3240726,0x20d1008b,0x9735007e,0x00000000}},	//   омік, _ại_, _اکرا,
  { {0x200200fe,0x7582007e,0x81c7001c,0x00000000}},	//   äkin_, _فیلم, ksēš,
  { {0x7b1000bd,0x6f03655e,0x394900ed,0x00000000}},	//   _räum, _sonc, noas_,
  { {0x75290035,0xbcfb00ea,0x6f03655f,0x00000000}},	//   _imez, tmén, _ponc,
  { {0x6f1a0783,0x7d046560,0x7d160014,0x00000000}},	//   ghtc, _sois, _slys,
  { {0x7d040bcf,0x7d1605b9,0xbcfb0003,0x00000000}},	//   _pois, _plys, rmén,
  { {0xcb090132,0xd256009a,0xa3ae0042,0x00000000}},	//   _אל_, _השעה_, _किम_,
  { {0x7f850032,0x7d044365,0x6f1a0139,0x00000000}},	//   _التن, _vois, bhtc,
  { {0xbcfb013d,0x6f1a6561,0x3f760022,0x00000000}},	//   lmél, chtc, _sług_,
  { {0x75290080,0x7d046562,0x39526563,0x00000000}},	//   _omez, _tois, tlys_,
  { {0xb87b006d,0x394925a1,0x2d590003,0x00000000}},	//   _raíc, goas_, léen_,
  { {0xc6760021,0x66030137,0xd7ea000d,0x00000000}},	// [d720] مطاب, änkn, ымае_,
  { {0xe646019d,0x3952021f,0xab5b00ea,0x00000000}},	//   безп, slys_, ltün,
  { {0x645b017d,0xd9465432,0xb65a0094,0x00000000}},	//   _azui, _гени, ушах_,
  { {0x67ca001c,0x69de6564,0x98ac008f,0x00000000}},	//   tējā, _ispe, ēlēs_,
  { {0x68e40058,0xe7bc008f,0xa947009a,0x00000000}},	//   mdid, īpēš, _לָךְ_,
  { {0x67ca001c,0x11d60021,0xbcfb013d,0x00000000}},	//   rējā, متعد, emél,
  { {0x29000035,0x8c3b004d,0x68e46565,0x00000000}},	//   ojia_, maße, odid,
  { {0xd1300032,0x67ca001c,0x68e418c2,0x00000000}},	//   ظمة_, pējā, ndid,
  { {0x7523006f,0x68e4004b,0xab5b013d,0x00000000}},	//   ënze, idid, dtün,
  { {0x69de6566,0x272f0051,0x6d4d20bc,0x00000000}},	//   _ospe, ożna_, _skaa,
  { {0x629a6567,0x9e140054,0x63a26568,0x00000000}},	//   _ieto, ідмі, lson,
  { {0x6937007d,0x5c071dfd,0xd657009d,0x00000000}},	//   tćem, бяга, מיית_,
  { {0xdfd0007e,0x629a6569,0x68e4002b,0x00000000}},	//   _آيت_, _keto, ddid,
  { {0x629a0164,0xc87f00bd,0xbcfb0003,0x00000000}},	//   _jeto, _maße_, mmém,
  { {0x28a7000d,0xc3330063,0x629a656a,0x00000000}},	//   йшаг, לוש_, _meto,
  { {0x63a2656b,0x68e400a4,0x99550097,0x00000000}},	//   kson, gdid, ікац,
  { {0xdb0f029c,0x765c0089,0x69de2c1c,0x00000000}},	// [d730] lucí, _azry, _espe,
  { {0x39490016,0x63a2656c,0x68e4656d,0x00000000}},	//   soas_, dson, adid,
  { {0x65d500f2,0x63a2656e,0x7af30078,0x00000000}},	//   تياط, eson, četė,
  { {0x5455323e,0x984b0062,0xa3b901fb,0x00000000}},	//   овет, _бяга_, لاتر_,
  { {0x629a656f,0xe8240121,0x2bdf0053,0x00000000}},	//   _beto, _ефро, _पैमा,
  { {0x65951fa0,0xdb06092e,0xab5b013d,0x00000000}},	//   _магу, stkö, ztün,
  { {0xf1a8007e,0x63a225bd,0x629a3f1b,0x00000000}},	//   مايه_, ason, _deto,
  { {0x753b0035,0xdb0f006d,0x75293733,0x00000000}},	//   _ujuz, ducí, _umez,
  { {0xf41f0137,0xef19417a,0x63a22a55,0x00000000}},	//   _åä_, ими_, cson,
  { {0xc34b0088,0x629a6570,0x27e90072,0x00000000}},	//   _сябе_, _geto, ivan_,
  { {0x2919005b,0x2d590003,0xab5b00ea,0x00000000}},	//   _olsa_, réen_, ttün,
  { {0x4c830054,0xec9a01ce,0x3ff50044,0x00000000}},	//   млюв, штој_, _وكار,
  { {0x2d590164,0xdb0f000c,0x2ca9001f,0x00000000}},	//   péen_, ducâ, _ddad_,
  { {0x63a40027,0x2ca9623e,0xdaba000d,0x00000000}},	//   áini, _edad_, шымі_,
  { {0x3f8d00cd,0x7bdf1c30,0xb87b00be,0x00000000}},	//   lpeu_, _esqu, _saía,
  { {0x7d1d004d,0x63a42b27,0x6d470066,0x00000000}},	//   chss, šini, čkac,
  { {0x68e45ab0,0x98a90051,0xaa8a007e,0x00000000}},	// [d740] rdid, znać_, _پنجم_,
  { {0xab5b01f7,0x29192dba,0x98a90022,0x00000000}},	//   ntül, _elsa_, ynać_,
  { {0x69de01a6,0x8c3b00bd,0x27e900fe,0x00000000}},	//   _uspe, raße, avan_,
  { {0x62836571,0x629a6572,0x63a26573,0x00000000}},	//   ecno, _seto, tson,
  { {0xd4030612,0x43944d63,0x98a90022,0x00000000}},	//   дящи, чалс, wnać_,
  { {0xfbb20053,0x37d90047,0x47d90047,0x00000000}},	//   _जिनम, _פֿרע, _פֿרײ,
  { {0x63a204ca,0xc3270021,0x629a6574,0x00000000}},	//   sson, تكون_, _veto,
  { {0x63ad0418,0x60f80905,0x63a26575,0x00000000}},	//   šana, сния_, pson,
  { {0xf0b7006a,0xdfd00067,0x50b7007e,0x00000000}},	//   زايش_, ريد_, زديد_,
  { {0xbcfb0164,0xdb060014,0xcf260044,0x00000000}},	//   rmém, yrká, تربي,
  { {0xa3e20053,0x27e9192b,0xbfa30013,0x00000000}},	//   धिक_, zvan_, _hiế,
  { {0xbfa3001b,0x657c00fe,0x27e9005b,0x00000000}},	//   _kiế, _murh, yvan_,
  { {0x4ae70088,0xa06a0001,0xdb1d0014,0x00000000}},	//   оўва, _тада_, stsí,
  { {0xfe6f005d,0xe451009a,0x00000000,0x00000000}},	//   عدی_, גֶל_,   ,
  { {0x657c0397,0x7bc66576,0x2d59006c,0x00000000}},	//   _nurh, atku, léem_,
  { {0x8c3b004d,0xa3bb0042,0x27e96577,0x00000000}},	//   raßb, _अमल_, tvan_,
  { {0x27e90072,0xdb0f00dd,0x2bb20042,0x00000000}},	// [d750] uvan_, rucâ, _जिया,
  { {0xa9280080,0x27e96578,0x657c059e,0x00000000}},	//   _požá, rvan_, _burh,
  { {0xab5b00bd,0x056b0002,0x657c0150,0x00000000}},	//   ntüm, ајди_, _curh,
  { {0xbfa3001b,0x04c80021,0x79a40121,0x00000000}},	//   _biế, قومي_, _юрье,
  { {0x78fa0063,0x7ae5065c,0x69c73a49,0x00000000}},	//   _הפרו, _kaht, ltje,
  { {0x20e70013,0x7ae5214c,0xfbb80063,0x00000000}},	//   _ối_, _jaht, קפות_,
  { {0x46480088,0xdb24007a,0x6b5200b9,0x00000000}},	//   _дзён_, ðrét, mægt,
  { {0x7ae50ff2,0x6b5200b9,0xc5f207e9,0x00000000}},	//   _laht, lægt, _אדל_,
  { {0x69c70117,0x60c96579,0x78fc009a,0x00000000}},	//   htje, rfem, שפחו,
  { {0xa2b45d90,0xef192c47,0x7ae509ad,0x00000000}},	//   _обуч, смо_, _naht,
  { {0x24803f3d,0xab5b616e,0x9f42004c,0x00000000}},	//   žime_, gtüm, íká_,
  { {0x69c7010a,0x8c463444,0x7bc60c29,0x00000000}},	//   dtje, земе, ttku,
  { {0x7ae50cc6,0x8d75005d,0x7bc60058,0x00000000}},	//   _baht, _کاتا, utku,
  { {0xa3ae0053,0x28ce0053,0x7bc616af,0x00000000}},	//   _किस_, ह्नि, rtku,
  { {0x7bc6657a,0xab270083,0x7bdd0168,0x00000000}},	//   stku, чора_, awsu,
  { {0x657a0003,0xcf25005d,0x7786005e,0x00000000}},	//   _éthi, _برچي, злаз,
  { {0x69c72780,0x18670193,0x657c0003,0x00000000}},	// [d760] atje, зати_, _surh,
  { {0x69c70093,0x69dc00e5,0xfb3a0044,0x00000000}},	//   btje, pwre, _دأبت_,
  { {0xceb20063,0xf5b60121,0x8a7b009a,0x00000000}},	//   תיב_, ясаю, _לאית,
  { {0x7ae506bb,0xd9460d34,0x75d30044,0x00000000}},	//   _zaht, _хеми, عينا,
  { {0xf8b3014e,0xdb1d00ea,0x2d982084,0x00000000}},	//   _אשר_, ltsá, árez_,
  { {0xbfa3001b,0xd3790086,0x657c0072,0x00000000}},	//   _viế, ічі_, _turh,
  { {0x7d1d00ac,0x6b5201e1,0x68e600a8,0x00000000}},	//   ërsk, lægs, _kakd,
  { {0xbfa3001b,0xbcfb000f,0xd259000d,0x00000000}},	//   _tiế, rmék, цці_,
  { {0x44220137,0x692c005b,0x24863f63,0x00000000}},	//   _åk_, eşek, mcom_,
  { {0x2486657b,0x91e604d8,0xa3d90042,0x00000000}},	//   lcom_, _нозе, ़बर_,
  { {0x2d980c6e,0x1cd902dc,0x7ae50072,0x00000000}},	//   ère_, одны_, _raht,
  { {0x24861401,0xdca40002,0x7ae51c97,0x00000000}},	//   ncom_, наџи, _saht,
  { {0xab5b0378,0x61dc0042,0x00000000,0x00000000}},	//   stüm, _मनुष,   ,
  { {0xbcfb0025,0x32cf005b,0x26da007d,0x00000000}},	//   iméi, cıyı_, jepo_,
  { {0x6b5200b9,0x48ab05ac,0x7ae50bda,0x00000000}},	//   vægt, йтам_, _vaht,
  { {0x69c757cb,0x76550051,0xb87b004c,0x00000000}},	//   rtje, _ryzy, _hníz,
  { {0x5ba40088,0x69c7657c,0x6b5200b9,0x00000000}},	// [d770] _прэз, stje, tægt,
  { {0x6b8d002c,0x6d4f657d,0xec380063,0x00000000}},	//   _itag, loca, _מאחר_,
  { {0xfc3f0139,0x692c0058,0x317e0244,0x00000000}},	//   saíd_, kşeh, _nutz_,
  { {0x628800ca,0x6d4f5eeb,0x27fc004c,0x00000000}},	//   _afdo, noca, ózní_,
  { {0x6d4f0290,0x32cf0058,0x5c380041,0x00000000}},	//   ioca, yıyı_, ּרון_,
  { {0x6d4f0027,0x60c233c5,0x6b8d05b3,0x00000000}},	//   hoca, _acom, _mtag,
  { {0xdb2400ea,0x61450121,0x290b0058,0x00000000}},	//   éséb, мека, _koca_,
  { {0x2d83004a,0x7b10004d,0x92580044,0x00000000}},	//   íjem_, _häut, أشهر_,
  { {0x63a40025,0xd0a8013a,0x6d4f657e,0x00000000}},	//   áint, سطين_, doca,
  { {0xee3964a2,0x290b657f,0x6d4f0a37,0x00000000}},	//   жно_, _loca_, eoca,
  { {0x63a9007a,0x6b8d20ea,0x2ca200a4,0x00000000}},	//   _hven, _atag, takd_,
  { {0x60c20027,0x63a90026,0x30150156,0x00000000}},	//   _gcom, _kven, _одер,
  { {0xeb97042c,0x212a007e,0xdb060072,0x00000000}},	//   мия_, _بينی_, yrkä,
  { {0xdb1d00ea,0x6b8d0025,0xd7f8003b,0x00000000}},	//   ttsá, _dtag, _ăă_,
  { {0x290b2b2e,0xdcfb005b,0x1d0a0854,0x00000000}},	//   _boca_, artı, _меки_,
  { {0x26da0035,0x63a90205,0x8c3b004d,0x00000000}},	//   wepo_, _oven, maßn,
  { {0x24860024,0x63a900b9,0x63ad0026,0x00000000}},	// [d780] vcom_, _nven, áanl,
  { {0x24860051,0xcece0013,0x0bb7009a,0x00000000}},	//   wcom_, _lộng_, _קלים_,
  { {0x68e60b67,0x63a91e3e,0x290b2069,0x00000000}},	//   _takd, _aven, _foca_,
  { {0xe45a46a5,0xf993009d,0x00000000,0x00000000}},	//   оже_, _שרר_,   ,
  { {0x2ca00019,0x136a0a90,0xc3da0242,0x00000000}},	//   _meid_, ошки_, تباط_,
  { {0x60c26580,0x2ca00aee,0x2508007e,0x00000000}},	//   _scom, _leid_, _کرسی_,
  { {0x7b1000bd,0x24866581,0x63a9476f,0x00000000}},	//   _häus, pcom_, _even,
  { {0x2ca00004,0xcece001b,0x2167005e,0x00000000}},	//   _neid_, _cộng_, мији_,
  { {0x6d4f2283,0xc953089e,0x72c6005e,0x00000000}},	//   voca, כמה_, _обаз,
  { {0x44260009,0x2216005a,0x7b10004d,0x00000000}},	//   mzo_, _офер, _mäus,
  { {0x27e000e3,0x1df80076,0x44260290,0x00000000}},	//   hwin_, чены_, lzo_,
  { {0x6603051a,0xd01a0002,0x2ca000a3,0x00000000}},	//   änki, _мфл_, _ceid_,
  { {0x442661bc,0x290b2037,0x6d4f6582,0x00000000}},	//   nzo_, _roca_, roca,
  { {0x44266583,0x27e06584,0x00000000,0x00000000}},	//   izo_, dwin_,   ,
  { {0xd90f007e,0x290b3620,0x6d4f4ebc,0x00000000}},	//   لید_, _poca_, poca,
  { {0x58d43147,0x79540044,0xc8c90044,0x00000000}},	//   кост, نَّا, ثورن_,
  { {0xa834005e,0x58840085,0x4c9c009a,0x00000000}},	// [d790] ветљ, тыса, _ובחו,
  { {0x6937007d,0x44261308,0x60db013d,0x00000000}},	//   ećet, dzo_, zeum,
  { {0x63a91e79,0x27e0002c,0x290b0955,0x00000000}},	//   _sven, awin_, _toca_,
  { {0x7d0d6585,0xb4b90042,0x7b100244,0x00000000}},	//   _joas, चले_, _fäus,
  { {0xdb1d010a,0xcece001b,0x9474007e,0x00000000}},	//   rtsæ, _rộng_, ندها,
  { {0xfbb20161,0xdb1d00b9,0x13080054,0x00000000}},	//   _जिसम, stsæ, мній_,
  { {0x1167007e,0xf674000d,0x24800f43,0x00000000}},	//   ولتی_, _агрэ, žima_,
  { {0x7d0d0529,0x75226586,0x60093af3,0x00000000}},	//   _noas, choz, зним_,
  { {0x61f80024,0x2019000f,0xe4540088,0x00000000}},	//   _ďalš, ási_, _акты,
  { {0x7c2600c2,0x2ca00206,0x26c16587,0x00000000}},	//   vzkr, _seid_, ngho_,
  { {0xa2c40053,0x7d0d00e5,0xa2dc0042,0x00000000}},	//   _रात्, _boas, फ़र्,
  { {0x7d0d1729,0xdb0601c2,0x692c1c8a,0x00000000}},	//   _coas, mské, lşev,
  { {0x2ca00025,0xdb0601c2,0x50b8007e,0x00000000}},	//   _veid_, lské, _زدند_,
  { {0x316d005b,0x7c260244,0xada508f6,0x00000000}},	//   lmez_, rzkr, _закл,
  { {0x442602f6,0x2ca00019,0xa96a0259,0x00000000}},	//   zzo_, _teid_, зива_,
  { {0xbcfb006d,0x316d005b,0xdb1d0072,0x00000000}},	//   eléf, nmez_, etsä,
  { {0x63ad01a6,0x7f8c0047,0x96b6005e,0x00000000}},	// [d7a0] šanj, ַנאַ, есељ,
  { {0xff7a0047,0x27e06588,0x3ea53e2a,0x00000000}},	//   פטעמ, rwin_, nalt_,
  { {0x27240026,0x316d005b,0xdb060114,0x00000000}},	//   _löng_, kmez_, jské,
  { {0x3ea56589,0x7b10004d,0xdb060114,0x00000000}},	//   halt_, _täus, dské,
  { {0x3ea5341d,0xdb06004c,0xba76005d,0x00000000}},	//   kalt_, eské, _تاکت,
  { {0x3ea50004,0x213f0089,0x4426658a,0x00000000}},	//   jalt_, enuh_, rzo_,
  { {0x8cc10053,0x3ea5646c,0x6d560058,0x00000000}},	//   _वालो, dalt_, _okya,
  { {0x2567004b,0x39402cb4,0x3ea5016c,0x00000000}},	//   võlg_, nnis_, ealt_,
  { {0x7d0d0af9,0x3ea5658b,0xbcfb4ed9,0x00000000}},	//   _roas, falt_, llég,
  { {0x39400199,0x80170021,0x33d50086,0x00000000}},	//   hnis_, عزيز_, _шіст,
  { {0x39402eec,0x07370063,0xdb0600ea,0x00000000}},	//   knis_, תאים_, cské,
  { {0x27240014,0x395200e5,0x3ea500ca,0x00000000}},	//   _hönd_, joys_, aalt_,
  { {0x0b8b005a,0x7d0d000c,0x3ea5452b,0x00000000}},	//   ясни_, _voas, balt_,
  { {0x7b10004d,0x39401e7a,0x628a0b6c,0x00000000}},	//   _säur, enis_, ncfo,
  { {0xcf570063,0x799e002b,0x3940658c,0x00000000}},	//   _רבות_, _cwpw, fnis_,
  { {0x27240026,0x0e5b0063,0x3940658d,0x00000000}},	//   _lönd_, _מדוב, gnis_,
  { {0xd6db0062,0xdb1d0e77,0xdb06004c,0x00000000}},	// [d7b0] зте_, ttsä, zské,
  { {0x6d5d00c7,0x394004b4,0x63ad0078,0x00000000}},	//   llsa, anis_, šank,
  { {0xdb1d01e3,0x394000bd,0xa8990121,0x00000000}},	//   rtsä, bnis_, _окну_,
  { {0xdb06658e,0x7b10004d,0x4518071f,0x00000000}},	//   vské, _häup, нція_,
  { {0xdb1d00bd,0x68ed0058,0x68fd00ca,0x00000000}},	//   ptsä, mdad, _insd,
  { {0x27240026,0xdb060114,0x29090072,0x00000000}},	//   _röng_, tské, ljaa_,
  { {0x3ea50004,0x9f4b0080,0x6d475ab1,0x00000000}},	//   valt_, ící_, čkaj,
  { {0x3ea500bd,0x13f5005a,0x660300bd,0x00000000}},	//   walt_, _избя, änku,
  { {0x443900c7,0xa3ae0053,0x3ea5046b,0x00000000}},	//   _äs_, _किए_, talt_,
  { {0xbcfb0080,0xdb060080,0x39400ffb,0x00000000}},	//   hléd, pské, znis_,
  { {0xdc34034d,0xa3e90053,0x3ea514e3,0x00000000}},	//   rúča, यिक_, ralt_,
  { {0x3ea50004,0x6aca0161,0x4087005a,0x00000000}},	//   salt_, िभ्र, _чужб,
  { {0x68ed08eb,0x395200e5,0x3987004e,0x00000000}},	//   ddad, voys_, _aõs_,
  { {0x68ed0016,0xf8bf00cd,0x80640086,0x00000000}},	//   edad, _omés_, _свіж,
  { {0x394000bd,0xdb040016,0xc3320063,0x00000000}},	//   tnis_, _aviã, בום_,
  { {0x6d44053b,0x68ed658f,0xdcf9001c,0x00000000}},	//   _ujia, gdad, _tuvā,
  { {0xdb160026,0x39521098,0x39406590,0x00000000}},	// [d7c0] ðbót, roys_, rnis_,
  { {0x39401d56,0x6676007e,0x68ed1167,0x00000000}},	//   snis_, ندار, adad,
  { {0x75890086,0xa50a0062,0xa486005d,0x00000000}},	//   есів_, межа_, نجشن,
  { {0x6b840019,0x63b9001f,0xbcfb00ea,0x00000000}},	//   _kuig, frwn, lmér,
  { {0xbcfb017d,0x24806591,0x68f3004c,0x00000000}},	//   omér, žimo_, ájdž,
  { {0x2d5904aa,0x26de0066,0x6b84004e,0x00000000}},	//   léet_, _úto_, _muig,
  { {0xbcfb0164,0x6b846592,0x31340086,0x00000000}},	//   llée, _luig, лекр,
  { {0x63b9002b,0x69ce030c,0x9fe60044,0x00000000}},	//   brwn, itbe, نسخه,
  { {0x42ca0002,0x3f66218c,0x7413005d,0x00000000}},	//   _оган_, ктоб, _پولا,
  { {0x4d980086,0x3f760022,0x68ed18ad,0x00000000}},	//   нкою_, _tłum_, zdad,
  { {0x9e3c0024,0x7206007e,0x2fcd002b,0x00000000}},	//   raďo, _جوام, ateg_,
  { {0x6d5d0290,0xa5c20051,0x20020019,0x00000000}},	//   ulsa, łówn, äkis_,
  { {0xcfb4005a,0x69ce006f,0x2fcd002b,0x00000000}},	//   _сблъ, etbe, cteg_,
  { {0xdce6008f,0x69ce6593,0xe7f60042,0x00000000}},	//   rmkā, ftbe, ँटना_,
  { {0xaa580001,0x987e005b,0xfc3f006d,0x00000000}},	//   виру_, _açık_, caín_,
  { {0xbcfb19ad,0x3987004b,0x63ad0648,0x00000000}},	//   rmés, _võs_, šani,
  { {0x19581485,0x290900fe,0x68ed4062,0x00000000}},	// [d7d0] таты_, rjaa_, rdad,
  { {0xa2c40161,0x68ed41c1,0x7d1d087d,0x00000000}},	//   _राष्, sdad, lkss,
  { {0x6b84006f,0x69ce006f,0xe9190054,0x00000000}},	//   _zuig, ctbe, _зоні_,
  { {0x99f6014e,0x2d590164,0xbcfb0003,0x00000000}},	//   _עזרה_, mées_, blée,
  { {0x63a00185,0x2d590164,0x291e001c,0x00000000}},	//   _cwmn, lées_, ītat_,
  { {0xdb1d0164,0x56940097,0x82a4005e,0x00000000}},	//   fusé, _варт, ашће,
  { {0x2d5903b2,0xa19d0085,0x7d1d0c01,0x00000000}},	//   nées_, чылi, kkss,
  { {0x4fe9000a,0x2d590164,0x11d60021,0x00000000}},	//   емин_, iées_, اوية_,
  { {0x3fc8006a,0x63a0001f,0x2d590003,0x00000000}},	//   نگوی_, _gwmn, hées_,
  { {0x2724004d,0x6b84006f,0x8e091c9d,0x00000000}},	//   _töne_, _ruig, енов_,
  { {0x2fcd6594,0xdb1d0003,0x613e008f,0x00000000}},	//   steg_, cusé, zīli,
  { {0xa3e70053,0x2d590003,0x6b846595,0x00000000}},	//   _बना_, dées_, _puig,
  { {0xdcf9003d,0xdb04017d,0xfc3f0139,0x00000000}},	//   _atvē, _aviá, saín_,
  { {0xbcfb0153,0x69ce6596,0x703a0041,0x00000000}},	//   umér, ttbe, _אײנצ,
  { {0x2d590164,0xc3320165,0x394a0094,0x00000000}},	//   gées_, מוך_, езво_,
  { {0x6b840025,0x2895005e,0x7d1d0e77,0x00000000}},	//   _tuig, ијус, ckss,
  { {0x69ce4b07,0x9696012d,0xbcfb013d,0x00000000}},	// [d7e0] stbe, греш, pmér,
  { {0x681a001c,0x2d590003,0x613e008f,0x00000000}},	//   _rādā, bées_, rīli,
  { {0x2d590164,0x692c003b,0xd5af0044,0x00000000}},	//   cées_, uşes, كفل_,
  { {0x291e001c,0xc6890063,0xab5b004d,0x00000000}},	//   ītas_, לא_, stüt,
  { {0x628f000c,0x98a90051,0xbd2d0047,0x00000000}},	//   _şcoa, wiać_, וואָ,
  { {0xab5b0b91,0x7cfb0072,0xfbd3009a,0x00000000}},	//   ltür, _kärä, צתו_,
  { {0x1546000a,0x6ef400ea,0x47330085,0x00000000}},	//   _бевм, nübő, _унёс,
  { {0x60f8005a,0x6d5d0080,0x681a008f,0x00000000}},	//   тния_, ůraz, _tādā,
  { {0xd3f40086,0x0446218a,0x2d5904aa,0x00000000}},	//   _мiст, _сеан, kéer_,
  { {0x2d590164,0x8f3404d6,0xab5b0244,0x00000000}},	//   yées_, реоц, htür,
  { {0xbcfb00ea,0x2d590003,0x2002003b,0x00000000}},	//   jléc, xées_, ţki_,
  { {0x2d590164,0xdb1d00d1,0xac190065,0x00000000}},	//   vées_, ltsø, вому_,
  { {0xbcfb05d5,0x351b0063,0x7d1d6597,0x00000000}},	//   eléc, תוכנ, rkss,
  { {0xce94005a,0x2d590164,0xbcfb0164,0x00000000}},	//   _такъ, tées_, fléc,
  { {0xa3ab0161,0x237e00cd,0x78a6018c,0x00000000}},	//   _कौन_, _mitj_, _bekv,
  { {0x2d590164,0x0dc701ea,0xc98407ed,0x00000000}},	//   rées_, _суши_, сури,
  { {0x2d5903b2,0x2eee00d1,0xdb1d0093,0x00000000}},	// [d7f0] sées_, _kaff_, ktsø,
  { {0x2d590003,0xfc3f0139,0xab5b049c,0x00000000}},	//   pées_, naím_, atür,
  { {0x78a600ea,0x36d40121,0xdb1d01e1,0x00000000}},	//   _fekv, сохр, dtsø,
  { {0x0574006a,0xa4d50086,0x26d86598,0x00000000}},	//   ماند, роді, _ebro_,
  { {0x8d4c009a,0xbcb8009d,0x00000000,0x00000000}},	//   עֲבֵ, רפדו_,   ,
  { {0x8707000d,0x77ba0063,0x71b50121,0x00000000}},	//   _сяме, _במשח, ащих,
  { {0x2249005a,0xab5b00bd,0x636d0331,0x00000000}},	//   ъпки_, prüf, húng,
  { {0x2bb60042,0xa2d50042,0x3a38009a,0x00000000}},	//   _अटला, _मॉर्, טרום_,
  { {0xf1c70066,0xa2cd0042,0x68ef3a99,0x00000000}},	//   _snáď_, _साप्, _macd,
  { {0xef160121,0x6281007d,0x249d002b,0x00000000}},	//   имы_, _uglo, lbwm_,
  { {0x52840032,0x60b5007e,0x3f820014,0x00000000}},	//   _المك, _نمائ, íkur_,
  { {0xc19a089e,0xe167005d,0xdb060046,0x00000000}},	//   _ישעי, _صداي, rskí,
  { {0xa09a00b5,0x8d55000d,0x78a66599,0x00000000}},	//   _סיסט, стэч, _rekv,
  { {0x5e87000d,0x78a6659a,0xfaa31a5c,0x00000000}},	//   _судз, _sekv, жаро,
  { {0x2d590003,0xc3320063,0x83fd013d,0x00000000}},	//   réer_, קול_, _szől,
  { {0x2eee0089,0x3ea7500c,0xe8fa0062,0x00000000}},	//   _zaff_, _hent_, ълб_,

  { {0x3ea7659b,0x2d80006c,0xab5b659c,0x00000000}},	// [d800] _kent_, _iiie_, rtür,
  { {0xab5b004d,0x2567004b,0x3696000d,0x00000000}},	//   stür, võla_, ршас,
  { {0x2d870034,0x3ea7659d,0x6d46659e,0x00000000}},	//   _june_, _ment_, onka,
  { {0x63640268,0x6d46659f,0xab5b004d,0x00000000}},	//   tòno, nnka, trüg,
  { {0x4432001b,0x636d0026,0x9cd70063,0x00000000}},	//   ày_, kúnd, שונה_,
  { {0x8c1b0063,0xa5960121,0x68e465a0,0x00000000}},	//   כוני, _вращ, leid,
  { {0x1bed0053,0x442065a1,0xdcc60053,0x00000000}},	//   _चैनल_, ši_, _वांछ,
  { {0x4420008b,0xdb1d0093,0x68e465a2,0x00000000}},	//   ơi_, stsø, neid,
  { {0x42ea0001,0xff06000d,0xb345017d,0x00000000}},	//   _имао_, аянн, unçã,
  { {0x11d6019d,0x2d87000c,0x6d460fe9,0x00000000}},	//   _відр, _bune_, enka,
  { {0x68e41341,0x63ad0006,0x171b0047,0x00000000}},	//   keid, šant, דויע,
  { {0x68e400fe,0x65620244,0xdb060075,0x00000000}},	//   jeid, nloh, arkü,
  { {0x3ea765a3,0x69de0399,0xa2cd0053,0x00000000}},	//   _fent_, _appe, _साम्,
  { {0x3ea765a4,0xd2460021,0x2d8701f4,0x00000000}},	//   _gent_, كن_, _fune_,
  { {0x68e40027,0xc9870e34,0x29880615,0x00000000}},	//   feid, руги, исто_,
  { {0x68e400eb,0x1d080001,0x3eac22bd,0x00000000}},	//   geid, _већи_, ladt_,
  { {0xbcfb47dd,0x656201d1,0xe796005d,0x00000000}},	// [d810] cléa, dloh, مالک,
  { {0x3077014e,0x2ca9010e,0xb87b017d,0x00000000}},	//   שתמש_, _head_, _saís,
  { {0xb87b65a5,0x68e465a6,0xd6d80001,0x00000000}},	//   _país, beid, јту_,
  { {0x67050161,0x45840086,0x2d800003,0x00000000}},	//   राहक_, ігів, _xiie_,
  { {0x37e4000d,0x61fa0025,0x3eac00ea,0x00000000}},	//   _доўг, _artl, kadt_,
  { {0x2ca90592,0x78ad00fe,0xdb1d004c,0x00000000}},	//   _lead_, laav, kusí,
  { {0xdb060014,0x349565a7,0x3ea765a8,0x00000000}},	//   nská, _габр, _rent_,
  { {0x3ea765a9,0x2d8765aa,0x78ad0bda,0x00000000}},	//   _sent_, _rune_, naav,
  { {0xa156005e,0x2d8765ab,0x8ff9005d,0x00000000}},	//   љању_, _sune_, اربر_,
  { {0x27e9002c,0x2d871052,0xdb1d0026,0x00000000}},	//   iwan_, _pune_, fusí,
  { {0x78ad00fe,0x6b9665ac,0x2126004d,0x00000000}},	//   kaav, _styg, _floh_,
  { {0x3ea70037,0x2ca90025,0x6d4600ea,0x00000000}},	//   _went_, _cead_, unka,
  { {0x68e40418,0x2ca90034,0x2d800019,0x00000000}},	//   veid, _dead_, _viie_,
  { {0x6e950021,0x27e90dde,0x60c965ad,0x00000000}},	//   _الغا, dwan_, lgem,
  { {0x68e465ae,0x2ca90139,0x27e9017e,0x00000000}},	//   teid, _fead_, ewan_,
  { {0x628f000c,0xbcfb3be8,0x60c965af,0x00000000}},	//   _şcol, llén, ngem,
  { {0x68e465b0,0xb87b017d,0x27e90178,0x00000000}},	// [d820] reid, _saír, gwan_,
  { {0xab5b004d,0x7bc61bad,0x7adf0042,0x00000000}},	//   arüb, muku, _पॉपअ,
  { {0x7bc6315d,0x69de0924,0x60c900f5,0x00000000}},	//   luku, _uppe, kgem,
  { {0xab5b005b,0xdcf90078,0x60c900ca,0x00000000}},	//   crüb, _buvę, jgem,
  { {0x7bc65072,0x60c965b1,0x6562004d,0x00000000}},	//   nuku, dgem, rloh,
  { {0xff47007e,0x60c9042e,0x398e0014,0x00000000}},	//   _رخ_, egem, _kýs_,
  { {0xdb1d0016,0x2489007d,0x7bc6320a,0x00000000}},	//   lusã, žama_, huku,
  { {0x7bc665b2,0xf8ba0053,0x60c965b3,0x00000000}},	//   kuku, ेलिय, ggem,
  { {0x2ca90034,0x3eac07c6,0x60f7000d,0x00000000}},	//   _read_, tadt_, сныя_,
  { {0x7522000f,0x63b30080,0x7bc62e8d,0x00000000}},	//   lkoz, ření, duku,
  { {0x2ca90019,0x3eac00ea,0x80a6007e,0x00000000}},	//   _pead_, radt_, _همان,
  { {0x7bc60035,0x30860021,0x867b0063,0x00000000}},	//   fuku, _الإف, טריו,
  { {0x78ad00fe,0x2ca9004b,0xdb1d0014,0x00000000}},	//   vaav, _vead_, rtsþ,
  { {0xab5b00bd,0x27240026,0x26ce00cd,0x00000000}},	//   drüc, _sönn_, òfol_,
  { {0xc3390080,0x2ca9004b,0x78ad0072,0x00000000}},	//   _říká, _tead_, taav,
  { {0x7c97007e,0xdb1d017d,0x7bc609e9,0x00000000}},	//   _اشغا, fusã, buku,
  { {0x78ad024a,0x636d0367,0x69d80137,0x00000000}},	// [d830] raav, núnc, _även,
  { {0xab98006a,0x7522006f,0x7d040051,0x00000000}},	//   _اخير_, ekoz, _znis,
  { {0x78ad0072,0xc66b0085,0xdb1d0244,0x00000000}},	//   paav, ушае_, itsü,
  { {0x2ee50122,0x7ae765b4,0xab5b65b5,0x00000000}},	//   zelf_, lejt, brüc,
  { {0x394965b6,0xd2a9005e,0x69d512c8,0x00000000}},	//   mnas_, акле_, ltze,
  { {0x3949143b,0xf794000d,0x7ae7004c,0x00000000}},	//   lnas_, _харэ, nejt,
  { {0x51840001,0x34951a5c,0x754800ea,0x00000000}},	//   пуња, _мавр, ószá,
  { {0x7bc6053b,0x7ae70080,0x394965b7,0x00000000}},	//   yuku, hejt, nnas_,
  { {0x7ae70114,0x69d50206,0x39493ce9,0x00000000}},	//   kejt, htze, inas_,
  { {0x0ea901d5,0x60c91b0f,0x69c70d71,0x00000000}},	//   шкой_, sgem, kuje,
  { {0x7ae70080,0xf1dd0235,0x69c702e2,0x00000000}},	//   dejt, _महिन, juje,
  { {0x63a40529,0x2ee5015e,0x7bc665b8,0x00000000}},	//   ţine, self_, tuku,
  { {0x7bc600a4,0xbcfb65b9,0x69d50d13,0x00000000}},	//   uuku, plén, etze,
  { {0x6d4d00f3,0xa3ab0053,0x3949276c,0x00000000}},	//   _ejaa, कीय_, enas_,
  { {0xe93a0001,0x7bc60440,0x6aae004d,0x00000000}},	//   ачај_, suku, rabf,
  { {0x799c001f,0x39494596,0x7bc665ba,0x00000000}},	//   rprw, gnas_, puku,
  { {0xab5b00bd,0x69c70078,0xe73a0131,0x00000000}},	// [d840] urüc, auje, аеа_,
  { {0xab5b004d,0x69c71625,0x394965bb,0x00000000}},	//   rrüc, buje, anas_,
  { {0x7522000f,0x69c70ad6,0xab5b004d,0x00000000}},	//   tkoz, cuje, srüc,
  { {0x636400cd,0xab5b00bd,0xd5760086,0x00000000}},	//   mòni, prüc, цузь,
  { {0xb8e0016a,0x63640268,0x9e3c0124,0x00000000}},	//   ील_, lòni, laďt,
  { {0x7529051e,0x96fa000d,0x68f60078,0x00000000}},	//   _elez, _тэму_, ldyd,
  { {0x63640268,0xdb1d006c,0xdb0600a5,0x00000000}},	//   nòni, ursé, mskä,
  { {0x394000a4,0x67360051,0x31570021,0x00000000}},	//   niis_, żają, يجية_,
  { {0x68f6001f,0xd0070095,0x69c71625,0x00000000}},	//   idyd, жење_, zuje,
  { {0xa3df0053,0xdb0601bb,0x91e619b6,0x00000000}},	//   _तहत_, nskä, _мозе,
  { {0x7ae765bc,0x68f60078,0x69c70066,0x00000000}},	//   vejt, kdyd, xuje,
  { {0x636400cd,0x4093007e,0x69c765bd,0x00000000}},	//   dòni, _قلمر, vuje,
  { {0x7ae70080,0x68f6002b,0x69c70022,0x00000000}},	//   tejt, ddyd, wuje,
  { {0x63640268,0x4f570242,0x6b9d00ca,0x00000000}},	//   fòni, _وجود_, rpsg,
  { {0x3a25007a,0x69d500bd,0x636d0025,0x00000000}},	//   álp_, utze, núna,
  { {0x2d9e65be,0x91bb0063,0xdc2b007e,0x00000000}},	//   mpte_, ימלי, _نسخه_,
  { {0x394965bf,0xcd2b007e,0x9e3c0066,0x00000000}},	// [d850] rnas_, _مسکن_, raďu,
  { {0xdb060137,0x6d5d65c0,0x8f9b0063,0x00000000}},	//   gskä, losa, יימי,
  { {0xa2c40235,0x394900c7,0x752949b4,0x00000000}},	//   _राज्, pnas_, _plez,
  { {0x6b8d0035,0x636d0025,0x394001a8,0x00000000}},	//   _kuag, dúna, ciis_,
  { {0x53a506be,0x3cfc07e9,0x24590121,0x00000000}},	//   чалб, ילאנ, щадь_,
  { {0x6f18017f,0x2467004c,0x6d5d31cc,0x00000000}},	//   _novc, _nímž_, hosa,
  { {0x29190009,0xf6280086,0x7bda003b,0x00000000}},	//   _kosa_, _діти_, ătui,
  { {0xf53f0137,0x27e20150,0x6d5d0516,0x00000000}},	//   _öå_, _ypkn_, josa,
  { {0x7e630137,0x6b8d0003,0x4255007e,0x00000000}},	//   _synp, _nuag, _کنار,
  { {0x5187000d,0x636d0026,0x91f70021,0x00000000}},	//   _дуда, búna, _وأضا,
  { {0x3f99003d,0xf8bf03d9,0x68f6001f,0x00000000}},	//   ūsu_, _além_, ydyd,
  { {0x63a910ca,0x6d5d65c1,0xbcfb523e,0x00000000}},	//   _kwen, gosa, blém,
  { {0xdb0600fe,0x3940004b,0x2d9e00dd,0x00000000}},	//   yskä, viis_, apte_,
  { {0x3b0a0055,0x63a90009,0x69960086,0x00000000}},	//   щего_, _mwen, зрах,
  { {0x6d5d65c2,0x39405ebf,0x63a900ac,0x00000000}},	//   bosa, tiis_, _lwen,
  { {0x63640994,0xed57005a,0x291965c3,0x00000000}},	//   ròni, _нощ_, _cosa_,
  { {0x68f60185,0x8c46000a,0xab5b0019,0x00000000}},	// [d860] rdyd, _хепе, kuüh,
  { {0x636400cd,0xdb1d00ea,0x3940004b,0x00000000}},	//   pòni, pusá, siis_,
  { {0x29194b7c,0x63a91780,0xb5a50054,0x00000000}},	//   _fosa_, _awen, дрій,
  { {0x6e3c017d,0xdb0600a5,0x69c1004c,0x00000000}},	//   úrbi, sskä, šlec,
  { {0xe3b70083,0x07fa0044,0xa3e60082,0x00000000}},	//   зліч_, _ارجع_, यौं_,
  { {0xf1a665c4,0x2d9e65c5,0xab5b004e,0x00000000}},	//   прин, ypte_, guüh,
  { {0x64a6126b,0x63a965c6,0x6d5d0035,0x00000000}},	//   _нава, _ewen, yosa,
  { {0x55bb0063,0x636d3dd4,0xbcfb011b,0x00000000}},	//   _למלו, rúna, tlém,
  { {0x63a90185,0x79860035,0x636d0025,0x00000000}},	//   _gwen, _mikw, súna,
  { {0xd1380051,0x79865c09,0xb4bc0042,0x00000000}},	//   _stąd_, _likw, _आयु_,
  { {0x6d5d65c7,0x008610f6,0x6b8d005f,0x00000000}},	//   tosa, _елео, _suag,
  { {0xab5b00bd,0xbcfb01ca,0x6d5d0078,0x00000000}},	//   grün, plém, uosa,
  { {0xbcfb00ea,0x291908c9,0x6b8d4ddf,0x00000000}},	//   llék, _rosa_, _quag,
  { {0x6d5d021e,0x291914fa,0x2d9e0e77,0x00000000}},	//   sosa, _sosa_, ppte_,
  { {0x6edb014e,0xda780905,0x29195dd2,0x00000000}},	//   _החופ, зят_, _posa_,
  { {0x3eae030c,0xd8770044,0x319b009d,0x00000000}},	//   _heft_, كاذب, מבלנ,
  { {0x79860438,0xf6e70062,0x57190183,0x00000000}},	// [d870] _dikw, зцен, ожая_,
  { {0xdb1d0014,0x9f4d0058,0x8f9b009a,0x00000000}},	//   orsí, rveç_, ציבי,
  { {0x25aa001f,0x63a93e7e,0x2919005f,0x00000000}},	//   _cwbl_, _swen, _tosa_,
  { {0x3eae0034,0x3874017d,0xe8eb007e,0x00000000}},	//   _left_, çará_, _اردو_,
  { {0xdb060137,0x29d765c8,0xc3550062,0x00000000}},	//   rrkö, lça_, мъкъ,
  { {0xadec0042,0x13e8012c,0xc2c40044,0x00000000}},	//   जबान_, ямій_, فيهي,
  { {0x29d765c9,0x25aa001f,0xdce4007d,0x00000000}},	//   nça_, _gwbl_, _uhić,
  { {0x212b0051,0x63a965ca,0x917a008d,0x00000000}},	//   óch_, _twen, _cầy_,
  { {0x60090054,0x60db4aa6,0xdfce0044,0x00000000}},	//   іном_, rfum, ليي_,
  { {0x29d7005b,0xa29401dd,0x6d4f0331,0x00000000}},	//   kça_, _зафі, éban,
  { {0xc332014e,0xab5b004d,0x78bd0605,0x00000000}},	//   _שוב_, trün, _odsv,
  { {0x3eae006f,0x3f9f0072,0xe0d0005d,0x00000000}},	//   _eeft_, ppuu_, _مزه_,
  { {0x9f4d00e8,0xdb1d62da,0xdca3005e,0x00000000}},	//   nweë_, arsí, ђари,
  { {0x257e004c,0x09e605ef,0xbcfb004c,0x00000000}},	//   _vůli_, могн, hléh,
  { {0xab5b049c,0x9f4d0050,0xbcfb004c,0x00000000}},	//   ntüy, rveä_, kléh,
  { {0x3f870014,0x48e31dd6,0xab5b004b,0x00000000}},	//   _hinu_, косв, brüo,
  { {0x29d70016,0x79860035,0x186725f7,0x00000000}},	// [d880] aça_, _vikw, дати_,
  { {0x8c4300bd,0xbcfb01d1,0x670e0042,0x00000000}},	//   ößer, eléh, साधक_,
  { {0x3f870004,0x3f8f0019,0x917a0013,0x00000000}},	//   _minu_, _lugu_, _lấy_,
  { {0x7bc61467,0xf5250083,0xe5a31527,0x00000000}},	//   orku, нфін, тици,
  { {0xf8b30063,0x394d099e,0x8b650043,0x00000000}},	//   _בשר_, čest_, _زایم,
  { {0x65c6130d,0xae0d0042,0xc2c40044,0x00000000}},	//   _обга, िमान_, ريعي,
  { {0x91e30001,0x2d590003,0x20190072,0x00000000}},	//   воје, réez_, äsin_,
  { {0x66030146,0xab5b00ea,0x3f8765cb,0x00000000}},	//   ænke, erül, _ainu_,
  { {0xa067005e,0xc5150044,0xd48b009d,0x00000000}},	//   маћа_, _ثبّت, _וָבֹ,
  { {0x8e1400d7,0x692c0058,0x3f8f0401,0x00000000}},	//   едоц, rşey, _dugu_,
  { {0x7bc61b18,0x63a200ea,0x3f87001a,0x00000000}},	//   erku, lpon, _dinu_,
  { {0xa00a0032,0x3f87007a,0xdb1d0137,0x00000000}},	//   _وقال_, _einu_, ntsö,
  { {0x7b670619,0xfc64005a,0x7af72839,0x00000000}},	//   дтве, върн, _paxt,
  { {0x78af2edb,0xbcfb0139,0x29d70058,0x00000000}},	//   _secv, iléi, tça_,
  { {0xb345017d,0xdb1d017d,0x59f80062,0x00000000}},	//   liçã, ersã, меря_,
  { {0xfc3f02dd,0x637613f8,0x29d765cc,0x00000000}},	//   abía_, lând, rça_,
  { {0xb3450016,0xb8f70053,0x29d765cd,0x00000000}},	// [d890] niçã, _सा_, sça_,
  { {0x6376003b,0xbcfb0139,0x29d70058,0x00000000}},	//   nând, dléi, pça_,
  { {0xdb060066,0x63a265ce,0xd5bb0503,0x00000000}},	//   yskú, epon, юса_,
  { {0x78bd00b9,0x629a65cf,0x0574043e,0x00000000}},	//   _udsv, _afto, ناند,
  { {0x68ed0016,0xf8bf65d0,0xdfc60021,0x00000000}},	//   mead, _idé_, _حي_,
  { {0x68ed0027,0xb3450016,0x9f4d00ac,0x00000000}},	//   lead, diçã, rweë_,
  { {0x9f590025,0xe0d10021,0x442965d1,0x00000000}},	//   ísí_, هزة_, ša_,
  { {0x3f8765d2,0x636d006d,0x6d4f006d,0x00000000}},	//   _sinu_, múnm, ébal,
  { {0xbcfb0025,0x637600be,0x39950196,0x00000000}},	//   cléi, fând, _lås_,
  { {0x27e400c7,0x24980080,0x6d4f65d3,0x00000000}},	//   _ämne_, čemž_, enca,
  { {0x68ed00d1,0x399506a3,0x290b00a8,0x00000000}},	//   kead, _nås_, _onca_,
  { {0xb3450016,0x3f8f0150,0x63761c2e,0x00000000}},	//   biçã, _tugu_, tâng,
  { {0x69c10512,0x6376000c,0x68ed65d4,0x00000000}},	//   álen, bând, dead,
  { {0x637665d5,0xab2a000d,0x643a0047,0x00000000}},	//   râng, чога_, לערנ,
  { {0x63a2000f,0x69c10080,0x68ed0025,0x00000000}},	//   zpon, šlen, fead,
  { {0x6376000c,0x63bb0290,0xba17007e,0x00000000}},	//   mâne, _ovun, ريقا_,
  { {0x69c765d6,0x6d4665d7,0x27e665d8,0x00000000}},	// [d8a0] arje, mika, ïon_,
  { {0x6d4665d9,0x248d00be,0x39952a41,0x00000000}},	//   lika, _agem_, _fås_,
  { {0xfad700b5,0x39950137,0x68ed0139,0x00000000}},	//   _אויך_, _gås_, bead,
  { {0x61350026,0x6376000c,0x69dc3425,0x00000000}},	//   _hálf, zând, mtre,
  { {0xe2f80086,0x69ce0026,0x69dc65da,0x00000000}},	//   делі_, lube, ltre,
  { {0x6d4665db,0xdb1d0137,0x69dc65dc,0x00000000}},	//   hika, stsö, otre,
  { {0x61350026,0x27f2035a,0x6d4665dd,0x00000000}},	//   _málf, lwyn_, kika,
  { {0x63a24385,0xb3450016,0x6d46053b,0x00000000}},	//   ppon, tiçã, jika,
  { {0x6376000c,0x6d463106,0x27f2001f,0x00000000}},	//   tând, dika, nwyn_,
  { {0xb34503d9,0x6d463a37,0x69dc05f8,0x00000000}},	//   riçã, eika, ktre,
  { {0xb34503d9,0xa0a60581,0x442600a4,0x00000000}},	//   siçã, _заед, lyo_,
  { {0x69dc65de,0x6376003b,0x69ce0150,0x00000000}},	//   dtre, sând, dube,
  { {0x44260273,0x48fb0053,0xd0070002,0x00000000}},	//   nyo_, _लोगो_, _пеце_,
  { {0x69c700c3,0x27f2001f,0x69dc0321,0x00000000}},	//   trje, dwyn_, ftre,
  { {0xdb0402dd,0x99850080,0x442600a4,0x00000000}},	//   _avió, álů_, hyo_,
  { {0x7bda0529,0x6d461c80,0x24890a80,0x00000000}},	//   ătur, cika, žami_,
  { {0xdb1d0025,0x68ed057a,0xa9540086,0x00000000}},	// [d8b0] arsá, read, укті,
  { {0x68ed65df,0x44261bfe,0xbcfb00ea,0x00000000}},	//   sead, dyo_, glév,
  { {0xceb300b5,0x69dc19d9,0x7bcf3f38,0x00000000}},	//   ריע_, ctre, lucu,
  { {0x7bdd0019,0xa567007e,0x290b00be,0x00000000}},	//   otsu, ردان, _unca_,
  { {0x7bcf01f7,0xe28e000a,0x7bdd0019,0x00000000}},	//   nucu, иа_, ntsu,
  { {0x02c2126b,0xdbcc0014,0x6d4665e0,0x00000000}},	//   айшо, _móðg, zika,
  { {0x95c80001,0x44261128,0x1a9c00b5,0x00000000}},	//   _пута_, ayo_, ליגע,
  { {0x44260150,0x63bb06a3,0xa156005e,0x00000000}},	//   byo_, _tvun, кају_,
  { {0x4395005a,0xb87b0027,0xe5340121,0x00000000}},	//   _разс, _mbío, _сеть,
  { {0x8464005a,0x6376017d,0x6d462f40,0x00000000}},	//   _съсе, tâne, wika,
  { {0x61350026,0x6d4665e1,0x69dc65e2,0x00000000}},	//   _nálg, tika, xtre,
  { {0x6376017d,0xd24e007e,0x7bdd2523,0x00000000}},	//   râne, _بچه_, ftsu,
  { {0x317f005b,0x6d462ee6,0x7bcf007d,0x00000000}},	//   mmuz_, rika, gucu,
  { {0x6d46351f,0x316d2500,0x69dc65e3,0x00000000}},	//   sika, llez_, ttre,
  { {0x69dc0164,0x7bdd3339,0x6d4665e4,0x00000000}},	//   utre, atsu, pika,
  { {0xdb0f0025,0x69dc65e5,0xe579002b,0x00000000}},	//   rscá, rtre, _nhŷ_,
  { {0x3ff900b5,0x69dc6005,0x7bcf0089,0x00000000}},	// [d8c0] ופּע, stre, cucu,
  { {0x44260009,0x9bb70063,0x27f2001f,0x00000000}},	//   vyo_, _שהיה_, rwyn_,
  { {0x4426001f,0x14c8007e,0xd48f31ab,0x00000000}},	//   wyo_, فهای_, ир_,
  { {0x44262133,0xf4b4007e,0xf5030062,0x00000000}},	//   tyo_, اشاگ, изхо,
  { {0x07a6000a,0x4426006d,0xd843027d,0x00000000}},	//   _јагн, uyo_, ročí_,
  { {0x44263b40,0xcc3b0041,0x04433aca,0x00000000}},	//   ryo_, וענט, шечн,
  { {0x442600bb,0xf743032d,0x6b4900a8,0x00000000}},	//   syo_, _теро, nžga,
  { {0x50f40055,0x6376017d,0x2d982847,0x00000000}},	//   узит, fânc, írem_,
  { {0xe8050161,0x60f7000d,0x6376017d,0x00000000}},	//   रिया_, тныя_, gânc,
  { {0xbcfb0003,0xaf060b3f,0x6d44406a,0x00000000}},	//   hlét, тчик, _amia,
  { {0x316d0003,0x39520078,0x2d83004c,0x00000000}},	//   blez_, knys_, ňkem_,
  { {0x7bdd00b8,0x5d640121,0x7bcf0058,0x00000000}},	//   ttsu, итяз, tucu,
  { {0x1013007e,0x6f0d0080,0x637600be,0x00000000}},	//   _نبود, áncí, cânc,
  { {0x395200cd,0x69c10240,0x6d4400ea,0x00000000}},	//   enys_, šlem, _emia,
  { {0x27360146,0xa9230024,0xbcfb0003,0x00000000}},	//   _mænd_, áľov, flét,
  { {0x7d0d075a,0x7bcf4675,0xdb060114,0x00000000}},	//   _unas, pucu, mský,
  { {0x60c20035,0xdb0601c2,0x6aa2003b,0x00000000}},	// [d8d0] _mdom, lský, _şofe,
  { {0x6d440045,0x473406c9,0x00000000,0x00000000}},	//   _zmia, анус,   ,
  { {0xdb06004a,0x60c265e6,0xe784128f,0x00000000}},	//   nský, _odom, руто,
  { {0x26ce01a8,0xe7950043,0x00000000,0x00000000}},	//   òfor_, _ماسک,   ,
  { {0xfbdf017d,0xceb80078,0x636d017d,0x00000000}},	//   ntê_, nkęs_, lúni,
  { {0x63760016,0x27f965e7,0x61355d42,0x00000000}},	//   vânc, _issn_, _mále,
  { {0x68fd0006,0x21690928,0xbbe00053,0x00000000}},	//   _kasd, ники_, _पङ्क,
  { {0x63760016,0xdb060114,0x316d0003,0x00000000}},	//   tânc, dský, ulez_,
  { {0x68fd0150,0x316d0003,0x6135004a,0x00000000}},	//   _masd, rlez_, _nále,
  { {0x2006001f,0x63762b1f,0x39491b18,0x00000000}},	//   _droi_, rânc, hias_,
  { {0x39490006,0x200649ee,0xd12e005d,0x00000000}},	//   kias_, _eroi_, زمی_,
  { {0x63760f84,0xc19a0047,0x2cb9013d,0x00000000}},	//   mâna, _טשעי, gasd_,
  { {0xeb972ab5,0x394965e8,0xd0870121,0x00000000}},	//   лия_, dias_, _рыжи,
  { {0x2d91017d,0x99f60054,0xdb0601d1,0x00000000}},	//   ízes_, лябі, bský,
  { {0xbcfb2868,0x3949444c,0xc348008b,0x00000000}},	//   glés, fias_, uổi_,
  { {0x394965e9,0x6d440022,0xe8f707ed,0x00000000}},	//   gias_, _umia, ллс_,
  { {0xd70a000d,0x7d7b0149,0xc8b50121,0x00000000}},	// [d8e0] ннае_, _אנקו, рссы,
  { {0x6676007e,0xbcfb00ea,0x3949004b,0x00000000}},	//   هدار, slét, aias_,
  { {0xf8bf03b2,0xbcfb65ea,0x6135004a,0x00000000}},	//   _clés_, clés, _zále,
  { {0x39490747,0x27e665eb,0x68fd087d,0x00000000}},	//   cias_, çons_, _gasd,
  { {0x7afe08d5,0x9cd70063,0xe4e50054,0x00000000}},	//   _kapt, רונה_, рієн,
  { {0xf746015a,0x29000fb8,0x68e465ec,0x00000000}},	//   _сего, ldia_, lfid,
  { {0x27e065ed,0x68ed013d,0x2ca0002b,0x00000000}},	//   ltin_, _üldö, _ofid_,
  { {0x21670001,0x290065ee,0xdb0665ef,0x00000000}},	//   лији_, ndia_, vský,
  { {0x273600b9,0x2ef430fe,0x6287013d,0x00000000}},	//   _tænd_, азпр, _újon,
  { {0x138a0032,0x7afe00ea,0x2474008b,0x00000000}},	//   _أخرى_, _napt, _ìm_,
  { {0x2293043b,0xde580086,0x2cb900ea,0x00000000}},	//   _المس, тані_, tasd_,
  { {0x40a8006a,0x2006001f,0x0e330086,0x00000000}},	//   _شخصی_, _troi_, снюю,
  { {0xdb060014,0x68e40139,0x394965f0,0x00000000}},	//   sský, dfid, vias_,
  { {0x61350080,0xdb060080,0x6b96005b,0x00000000}},	//   _vále, pský, _duyg,
  { {0x13d10161,0xbd6b005a,0x7afe00a4,0x00000000}},	//   _सम्भ, _прие_, _dapt,
  { {0xbcfb000f,0x290000cd,0x68e40139,0x00000000}},	//   rlés, gdia_, gfid,
  { {0x7afe0529,0x394965f1,0x67d50c0b,0x00000000}},	// [d8f0] _fapt, rias_, розу,
  { {0x657b0222,0x394965f2,0x27ff0078,0x00000000}},	//   _shuh, sias_, _šuns_,
  { {0x394906b2,0x2474008b,0x68fd2eda,0x00000000}},	//   pias_, _àm_, _tasd,
  { {0x68e40025,0x23b50044,0x7afe0075,0x00000000}},	//   cfid, لمؤس, _zapt,
  { {0x7afe01f7,0x78ad65f3,0x27e065f4,0x00000000}},	//   _yapt, mbav, ctin_,
  { {0xab5b004d,0x569402d7,0x2d44013d,0x00000000}},	//   lsüb, _гарт, tűek_,
  { {0x3ce90080,0xe4a702f8,0x78ad65f5,0x00000000}},	//   _obav_, _брзо, obav,
  { {0xab5b004d,0x2d44013d,0xe534046e,0x00000000}},	//   nsüb, rűek_, _лесь,
  { {0x61fa65f6,0xa156005e,0x2ca065f7,0x00000000}},	//   _estl, јању_, _rfid_,
  { {0x2fdf01f2,0x613500be,0x29000066,0x00000000}},	//   rtug_, _bálc, zdia_,
  { {0x50f5005a,0x61350297,0xd25101a7,0x00000000}},	//   _взет, _cálc, _بنا_,
  { {0xd0110032,0x6ff50021,0xeb9a65f8,0x00000000}},	//   _ولا_, _نستط, ким_,
  { {0x2d8200ac,0xdb1d006c,0x99710022,0x00000000}},	//   rmke_, ossè, _wąś_,
  { {0x2fcd00ac,0xa3e80053,0x61fa002b,0x00000000}},	//   mreg_, _बहस_, _ystl,
  { {0x63a4003d,0xc332014e,0x3195001c,0x00000000}},	//   ģini, חום_, _bāzi_,
  { {0xdb060014,0xab5b004d,0x63a400dd,0x00000000}},	//   tskó, gsüb, ţini,
  { {0x2fcd00ac,0x7afe65f9,0x290065fa,0x00000000}},	// [d900] nreg_, _tapt, rdia_,
  { {0x4a460076,0xbcfb00ea,0x78ad5168,0x00000000}},	//   _внов, llép, abav,
  { {0xdb060026,0xc5d60086,0x27e065fb,0x00000000}},	//   sskó, різь, stin_,
  { {0x84e601dd,0x6abc242f,0xa5070062,0x00000000}},	//   родж, larf, иеха_,
  { {0x2d52017f,0x43940121,0x257c0014,0x00000000}},	//   ašeg_, щалс, víld_,
  { {0x69ce65fc,0x6abc65fd,0xf746005e,0x00000000}},	//   orbe, narf, _ђево,
  { {0xe2970001,0xd24f03eb,0x2fcd00ac,0x00000000}},	//   шај_, ونه_, ereg_,
  { {0xbcfb0080,0x2fcd00ac,0x6abc65fe,0x00000000}},	//   jlép, freg_, harf,
  { {0xd0e20053,0x69ce004d,0x89370041,0x00000000}},	//   क्षण_, hrbe, ירקע_,
  { {0x257501e3,0x80a60053,0xbcfb00ea,0x00000000}},	//   håll_, _ट्रे, elép,
  { {0x06970ca4,0x6abc0e77,0x78ad0061,0x00000000}},	//   ידים_, darf, ybav,
  { {0x61350080,0x6a8000ea,0x6abc0d17,0x00000000}},	//   _válc, záfé, earf,
  { {0x6abc0185,0x69ce65ff,0x4f960a91,0x00000000}},	//   farf, erbe, _треу,
  { {0xe2a3008b,0x7b6700d7,0x6d5d0003,0x00000000}},	//   _ngữ_, ртме, érab,
  { {0xff7b0047,0xc1780078,0xab5b004d,0x00000000}},	//   _שטומ, _upės_, tsüb,
  { {0xe8940b3f,0x2d52007d,0xdb1d2346,0x00000000}},	//   жать, všeg_, issé,
  { {0xdb040016,0x286b0001,0x5887014c,0x00000000}},	// [d910] _aviõ, трво_, рыва,
  { {0x26070121,0xab5b004d,0x61356600,0x00000000}},	//   ичег, ssüb, _mála,
  { {0xd006007e,0x04950021,0xdb1d004b,0x00000000}},	//   _کل_, ملاح, iusü,
  { {0x7af5013d,0x95090044,0x69d5011b,0x00000000}},	//   lezt, طقتك_, muze,
  { {0xab5b004d,0xfc3f004c,0xdb1d004e,0x00000000}},	//   brüt, nzí_, kusü,
  { {0xf36700e1,0xebf80063,0x257c0260,0x00000000}},	//   штен, שֶׁת_, víle_,
  { {0x27f50058,0xdb1d004b,0x00000000,0x00000000}},	//   şanı_, dusü,   ,
  { {0x2fcd4910,0x7af5009c,0x94d4014b,0x00000000}},	//   treg_, hezt, _мосц,
  { {0xdee506be,0x7af500ea,0xc4d20063,0x00000000}},	//   бопи, kezt, _מגן_,
  { {0xfc3f0024,0x7af500ea,0x2fcd0e7f,0x00000000}},	//   dzí_, jezt, rreg_,
  { {0x2fcd00ac,0x7bcf6601,0x7af500ea,0x00000000}},	//   sreg_, ercu, dezt,
  { {0x40950032,0x69d56602,0x399c0046,0x00000000}},	//   _الإر, duze, _rís_,
  { {0x6abc007a,0x30850021,0x69d51a62,0x00000000}},	//   tarf, _الشف, euze,
  { {0xfaa31a5c,0x7af500ea,0xab5b004d,0x00000000}},	//   заро, gezt, drüs,
  { {0x49990086,0x6abc0989,0x69ce6603,0x00000000}},	//   иття_, rarf, urbe,
  { {0x3a2500c7,0x399c00cd,0xab5b004d,0x00000000}},	//   älpa_, _vís_, früs,
  { {0x06ea06da,0x7984002b,0x6abc6604,0x00000000}},	// [d920] лмак_, rmiw, parf,
  { {0xf7720021,0xdb1d006c,0xab5b004d,0x00000000}},	//   ساء_, yssé, rsüc,
  { {0x2348007e,0xa50a2360,0x8a063320,0x00000000}},	//   یستی_, лежа_, _узне,
  { {0x93aa0032,0xd910007e,0x5a170063,0x00000000}},	//   هاتف_, _تیر_, _הקטן_,
  { {0x4432008b,0xa2940054,0x68f60050,0x00000000}},	//   áy_, оалі, meyd,
  { {0xf6d5019d,0x29026605,0x68f60075,0x00000000}},	//   _міся, _haka_, leyd,
  { {0xdb1d0003,0xf1a3000d,0x1a9b0047,0x00000000}},	//   ussé, прын, ניקע,
  { {0xf993014e,0xc4c50021,0x68f60058,0x00000000}},	//   הרה_, _وتقو, neyd,
  { {0xaed4000a,0x29021acc,0x69d56606,0x00000000}},	//   оопш, _maka_, zuze,
  { {0x613503e8,0x11d6126b,0x29022341,0x00000000}},	//   _vála, _гідр, _laka_,
  { {0x2d9800e8,0x7af51954,0x7de30085,0x00000000}},	//   êre_, vezt, піяд,
  { {0xd7fe00aa,0x290200bb,0x63a4000c,0x00000000}},	//   _đăng_, _naka_, ţinu,
  { {0xbc4b0138,0x2d92005b,0xdb1d05dd,0x00000000}},	//   учне_, _diye_, orsø,
  { {0xfc3f02f4,0x637f017d,0xdce9005b,0x00000000}},	//   rzí_, cênd, ılıy,
  { {0x68f6001f,0x29026607,0xdeb30066,0x00000000}},	//   feyd, _baka_, äčša_,
  { {0x4975000d,0x57b505fb,0x09750086,0x00000000}},	//   ілас, жбат, ігаю,
  { {0x29070080,0x8c440001,0x6d4f03e1,0x00000000}},	// [d930] ěna_, _неће, mica,
  { {0xec38014e,0x6d4f3dcd,0x8f9b0063,0x00000000}},	//   _לאחר_, lica, טימי,
  { {0xab5b004d,0x3ebe00ea,0x8895007b,0x00000000}},	//   srüs, iatt_, _минх,
  { {0x68f66608,0x85c80021,0x3ebe00a5,0x00000000}},	//   ceyd, إِنْ_, hatt_,
  { {0x3ebe00df,0x24590121,0x83c40054,0x00000000}},	//   katt_, шадь_, збіж,
  { {0x55bb006a,0xdcb60053,0x04420002,0x00000000}},	//   _مطرح_, _अज्ञ, ќешн,
  { {0x7aea004d,0x6135004c,0x91d5000d,0x00000000}},	//   _öfte, _dáln, іцкі,
  { {0x6d4f3795,0xefc90081,0xa99c009a,0x00000000}},	//   jica, алил_, נבחר,
  { {0x200b004a,0x3cef0053,0x7f19000d,0x00000000}},	//   íci_, ेजने_, аіну_,
  { {0x63a962e8,0x656b235d,0x68f6005b,0x00000000}},	//   _iten, logh, zeyd,
  { {0x637f017d,0x442f6609,0x6d4f660a,0x00000000}},	//   gêne, lyg_, fica,
  { {0x6d4f03e1,0xdb0601bb,0xed570e74,0x00000000}},	//   gica, nskö, жою_,
  { {0x69c51609,0xae17006a,0xde55001c,0x00000000}},	//   _avhe, _گذشت, _šādā_,
  { {0x3b0a0055,0x63a90035,0x3ea10019,0x00000000}},	//   шего_, _mten, _üht_,
  { {0x68f6024a,0x6f03003b,0xdb060137,0x00000000}},	//   teyd, _ianc, kskö,
  { {0x63a9160e,0xe8fa0856,0x60db660b,0x00000000}},	//   _oten, јла_, ngum,
  { {0xc726130d,0x60db008f,0xdc9b009f,0x00000000}},	// [d940] одай, igum, _דיפל,
  { {0x7d04660c,0x68f607a5,0x44380023,0x00000000}},	//   _hais, seyd, _ār_,
  { {0x7d04660d,0x63a90b16,0x2902660e,0x00000000}},	//   _kais, _aten, _taka_,
  { {0x186a0071,0x63a906d5,0x6f03660f,0x00000000}},	//   _вами_, _bten, _lanc,
  { {0x69c1004a,0x25ad0114,0x7d042157,0x00000000}},	//   šlet, _čele_, _mais,
  { {0x60db001c,0x6d4f455f,0xe73a015a,0x00000000}},	//   egum, zica, _тег_,
  { {0xf1f7007e,0x21264b6a,0x613500ea,0x00000000}},	//   قعيت_, _pooh_, _váln,
  { {0x442f0185,0x26c70024,0x7d046610,0x00000000}},	//   byg_, ónov_, _nais,
  { {0x3ebe10bc,0x6d4f6611,0x6f036612,0x00000000}},	//   tatt_, vica, _banc,
  { {0x6f03055b,0x60db00a4,0x6d4f0051,0x00000000}},	//   _canc, agum, wica,
  { {0x613c000f,0x1df80076,0x6f031568,0x00000000}},	//   _péld, щены_, _danc,
  { {0x3ebe02f0,0x7d046168,0x613c3a77,0x00000000}},	//   satt_, _cais, _béle,
  { {0xe1330088,0x61356613,0x60c000fe,0x00000000}},	//   _іншы, _zálo, mamm,
  { {0x637f017d,0x78a60046,0x6f036614,0x00000000}},	//   mênc, _afkv, _ganc,
  { {0x637f0016,0xd90f006a,0x9e66006a,0x00000000}},	//   lênc, نید_, _باشن,
  { {0x29c5003d,0x60c0238f,0x613c013d,0x00000000}},	//   rķa_, namm, _féle,
  { {0x637f017d,0x2d9c0019,0x6f031770,0x00000000}},	// [d950] nênc, _huve_, _yanc,
  { {0x637f017d,0x60c028bb,0x1bf4000d,0x00000000}},	//   iênc, hamm, _ўпэў,
  { {0x7d16001f,0x7afa004b,0x63a96615,0x00000000}},	//   _ynys, õtte, _sten,
  { {0x442f01e3,0x2fc60117,0x656b0290,0x00000000}},	//   tyg_, _ovog_, uogh,
  { {0x18350047,0xdb060137,0xc6d70021,0x00000000}},	//   _זאָל_, rskö, _وتست,
  { {0x637f0016,0x2d9c017d,0x442f001f,0x00000000}},	//   dênc, _ouve_, ryg_,
  { {0x6f036616,0x6d4d0213,0xe5c404dc,0x00000000}},	//   _ranc, _omaa, _осто,
  { {0x63a9077a,0x26c100a4,0x613500ea,0x00000000}},	//   _tten, laho_, _válo,
  { {0x637f0016,0x63a96617,0x7d0404bc,0x00000000}},	//   gênc, _uten, _rais,
  { {0x6d5d0164,0xfe4503d6,0xdb1d0026,0x00000000}},	//   éran, зноо, fssí,
  { {0x613c6618,0xc3320ca4,0x2d9c0003,0x00000000}},	//   _séle, _רוב_, _cuve_,
  { {0xc1040021,0xc27a0063,0xdbd70072,0x00000000}},	//   _يولي, _הרעי, kääj,
  { {0x6f036619,0x637f017d,0xab5b0b91,0x00000000}},	//   _tanc, cênc, rsün,
  { {0xade9006a,0xdb060024,0x7d04077d,0x00000000}},	//   _هفتم_, jskô, _wais,
  { {0x78bd5b14,0xd3560063,0x7d04661a,0x00000000}},	//   _besv, לישי_, _tais,
  { {0x7d040139,0xdb060066,0x613c661b,0x00000000}},	//   _uais, eskô, _téle,
  { {0xd7f90086,0x78bd661c,0xed570063,0x00000000}},	// [d960] жує_, _desv, _מבקר_,
  { {0x2b1d0161,0x869a1001,0x78a40787,0x00000000}},	//   माणु_, стат_, sciv,
  { {0xba9b0063,0x4a9b0047,0x75290f89,0x00000000}},	//   _לסיי, _לייג, _boez,
  { {0x63760529,0xdb0d007a,0x7bc63f03,0x00000000}},	//   mâni, _hvað, osku,
  { {0x26c1002c,0x6135000f,0x60c000fe,0x00000000}},	//   baho_, _váll, vamm,
  { {0x637f017d,0xfc3f006d,0x273f003b,0x00000000}},	//   vênc, ncía_, _cînd_,
  { {0x2fc6017f,0xa50a0f92,0x60c0661d,0x00000000}},	//   _svog_, _лева_, tamm,
  { {0xd1300032,0x637f0016,0xf55a0021,0x00000000}},	//   ئمة_, tênc, _الرب_,
  { {0xd0070002,0x60c015f2,0x7bc622f4,0x00000000}},	//   зење_, ramm, jsku,
  { {0x637f03d9,0xdb1d5e49,0x60c0661e,0x00000000}},	//   rênc, tssí, samm,
  { {0xbfa5001b,0x637f0016,0x6e940021,0x00000000}},	//   _hiệ, sênc, بلدا,
  { {0xbfa5001b,0x06570047,0x2fc6007d,0x00000000}},	//   _kiệ, לייך_, _tvog_,
  { {0x78bd661f,0x7bc60a8c,0x6abe004d,0x00000000}},	//   _resv, gsku, _bepf,
  { {0x6ffb0063,0xab5b00ea,0x2d9c4e15,0x00000000}},	//   _להדפ, csül, _tuve_,
  { {0xbfa5001b,0xde570086,0x63762b1f,0x00000000}},	//   _liệ, _наші_, gâni,
  { {0x6d4d002c,0x286b00d7,0xfc3f006d,0x00000000}},	//   _umaa, брзо_, acía_,
  { {0x2ca90509,0xb9050053,0xbfa50013,0x00000000}},	// [d970] _ifad_, _ना_, _niệ,
  { {0x6abe004d,0x6376017d,0x753b39d0,0x00000000}},	//   _gepf, bâni, _sluz,
  { {0x6376017d,0x6d5d6620,0x75294d9e,0x00000000}},	//   câni, onsa, _poez,
  { {0xbfa5008b,0x39405096,0xdbd70072,0x00000000}},	//   _biệ, chis_, pääj,
  { {0x2d5200c3,0xdce6001c,0x6d5d6621,0x00000000}},	//   kšen_, nokā, insa,
  { {0xbfa5001b,0x78a20024,0x69c7017f,0x00000000}},	//   _diệ, ľove, osje,
  { {0x69c710b2,0x7529006f,0xa1890086,0x00000000}},	//   nsje, _toez, обка_,
  { {0x6d5d0164,0x290921a8,0x68ed1230,0x00000000}},	//   éral, ndaa_, nfad,
  { {0xc0c80001,0x69d50d25,0x68ed0035,0x00000000}},	//   чује_, hrze, ifad,
  { {0x3339006a,0x27e90397,0x69c700d1,0x00000000}},	//   _بزرگ_, itan_, ksje,
  { {0x69d50051,0x225900f2,0x98a20023,0x00000000}},	//   jrze, _بلاد_, _lokā_,
  { {0x27e901f7,0x69c76622,0x69d50051,0x00000000}},	//   ktan_, dsje, drze,
  { {0x68ed0025,0x2003008f,0x7bc60e7b,0x00000000}},	//   dfad, ājis_, usku,
  { {0x63760016,0x9f84019d,0x7bc66623,0x00000000}},	//   tâni, _згід, rsku,
  { {0xfc3f1493,0x613c0003,0xdb1d0026,0x00000000}},	//   rcía_, _héla, ersó,
  { {0x6376017d,0xdb1d0019,0x7bc60583,0x00000000}},	//   râni, dusõ, psku,
  { {0xb87b0080,0x48e3005a,0x637600be,0x00000000}},	// [d980] _sbír, ъотв, sâni,
  { {0x613c0164,0x68ed0035,0x69d50051,0x00000000}},	//   _méla, afad, brze,
  { {0x27e906a7,0x6a870003,0x7afc6624,0x00000000}},	//   atan_, réfé, mert,
  { {0x61355d42,0x7afc364c,0x69dc6625,0x00000000}},	//   _dálk, lert, mure,
  { {0x27e9006d,0x53fa0021,0x628100a8,0x00000000}},	//   ctan_, تراح_, _azlo,
  { {0xbfa5001b,0x7afc6626,0xe71a007e,0x00000000}},	//   _việ, nert, _بيست_,
  { {0x660301e1,0x6d5d0014,0x7afc6627,0x00000000}},	//   ænkt, ynsa, iert,
  { {0xbfa5008b,0xbcfb004c,0x613c006c,0x00000000}},	//   _tiệ, sléz, _béla,
  { {0xbcfb03b2,0x6d5d6628,0x7afc6629,0x00000000}},	//   nnée, éram, kert,
  { {0x613c0164,0x7afc662a,0xdce6008f,0x00000000}},	//   _déla, jert, vokā,
  { {0x2ca900bd,0x68ed339f,0x69dc59b7,0x00000000}},	//   _pfad_, yfad, jure,
  { {0x20020026,0x613c0026,0x69d50080,0x00000000}},	//   ækis_, _féla, vrze,
  { {0x61ea0199,0x7afc662b,0x69dc2986,0x00000000}},	//   ltfl, fert, eure,
  { {0x69d50045,0x7afc1a4b,0x69c72494,0x00000000}},	//   trze, gert, tsje,
  { {0xda7803d6,0x69dc662c,0x69d5087d,0x00000000}},	//   дят_, gure, urze,
  { {0x69c70f4e,0x2d52007d,0x6376003b,0x00000000}},	//   rsje, nšel_, mânu,
  { {0x69c700d1,0xbcfb0003,0x69dc662d,0x00000000}},	// [d990] ssje, gnée, aure,
  { {0x7bdd00bb,0x69d50045,0x9f9a024a,0x00000000}},	//   musu, prze, mään_,
  { {0x9f9a0072,0x7bdd3bf6,0x63bb00e5,0x00000000}},	//   lään_, lusu, _swun,
  { {0x61350080,0xe3b100f2,0x27e9662e,0x00000000}},	//   _válk, هرت_, ptan_,
  { {0x9f9a00fe,0x7bdd662f,0x62810758,0x00000000}},	//   nään_, nusu, _szlo,
  { {0x63a00469,0xec380047,0x798d0150,0x00000000}},	//   _dumn, ונדז_, lmaw,
  { {0xa4d5019d,0xe296000a,0xe1f100b3,0x00000000}},	//   _пові, наш_, است_,
  { {0x9f9a00fe,0x645a1d6b,0x7afc4068,0x00000000}},	//   kään_, áciá, zert,
  { {0x9f9a00fe,0x7afc2ee0,0x63c1004c,0x00000000}},	//   jään_, yert, ávně,
  { {0x200d3889,0x61350026,0xf4840062,0x00000000}},	//   rvei_, _máli, _русн,
  { {0x200d6630,0x7afc0112,0x20020026,0x00000000}},	//   svei_, vert, ækir_,
  { {0x7ae50b8f,0xc0e9007e,0x98a000c2,0x00000000}},	//   _acht, _رفتن_, tjič_,
  { {0x7bdd6631,0x7afc3991,0x61351358,0x00000000}},	//   gusu, tert, _náli,
  { {0x7afc3f06,0xdbd2004b,0x69dc2158,0x00000000}},	//   uert, müüj, ture,
  { {0x7afc6632,0x2cab0025,0x63760a50,0x00000000}},	//   rert, éidí_, mânt,
  { {0x7ae53848,0x63760016,0x273600b9,0x00000000}},	//   _echt, lânt, _tænk_,
  { {0xe73a000a,0x77860001,0x61353b1c,0x00000000}},	// [d9a0] пеа_, елаз, _cáli,
  { {0x8f9a014e,0xe205001b,0xbcfb6633,0x00000000}},	//   פיעי, _đóng_, rnée,
  { {0x1f3600b5,0x63a052f3,0x2d52004c,0x00000000}},	//   ערער_, _sumn, yšel_,
  { {0x80be0053,0x89360021,0x63a0003b,0x00000000}},	//   _एजें, _أعدا, _pumn,
  { {0x2d5200c2,0x3f8c0014,0x61356634,0x00000000}},	//   jšem_, ymdu_, _gáli,
  { {0x98a90022,0xae1f0042,0xdb1d013d,0x00000000}},	//   tkać_, यमान_, űzöt,
  { {0x61350114,0xf7770063,0x271b0041,0x00000000}},	//   _záli, _נעלי_, _צולײ,
  { {0x9f9a00fe,0x7bdd0949,0xab5b004b,0x00000000}},	//   yään_, yusu, tsük,
  { {0x04570021,0x98a90051,0x6376003b,0x00000000}},	//   _كلفة_, skać_, fânt,
  { {0x9f9a00fe,0x798d0051,0x3f980014,0x00000000}},	//   vään_, zmaw, öru_,
  { {0xb1e50021,0x798d0dde,0x35d80053,0x00000000}},	//   _لأنه, ymaw, _डिफ़,
  { {0x9f9a024a,0x7bdd01f7,0x2d52122a,0x00000000}},	//   tään_, tusu, lšej_,
  { {0x3c460003,0xfc640094,0x9c380094,0x00000000}},	//   _rêvé_, гърн, епят_,
  { {0xf8b8008b,0xa0070021,0x63763ecf,0x00000000}},	//   _đĩa_, _أقول_, cânt,
  { {0x7bdd240d,0x9f9a00fe,0xe987005e,0x00000000}},	//   susu, rään_, ећан,
  { {0x9f9a024a,0x798d002c,0x613c0003,0x00000000}},	//   sään_, umaw, _mélo,
  { {0xa7750001,0x798d39e8,0x671c0053,0x00000000}},	// [d9b0] влач, rmaw, नांक_,
  { {0x78a20024,0x368b000a,0x61356635,0x00000000}},	//   ľova, псен_, _váli,
  { {0x2d520024,0xb606001c,0x2d9b013d,0x00000000}},	//   dšej_, jušā, _épes_,
  { {0xa4d50086,0xb606001c,0x60c20562,0x00000000}},	//   тоді, dušā, _neom,
  { {0x290b003b,0xdb1d01e1,0x0d160041,0x00000000}},	//   _iaca_, rssæ, כקײט_,
  { {0x33940121,0x613c006c,0x2d5214c1,0x00000000}},	//   гачё, _bélo, všem_,
  { {0x63760529,0x290b053b,0x613c00ea,0x00000000}},	//   vânt, _kaca_, _célo,
  { {0x2d520024,0x613c6636,0x672e00a8,0x00000000}},	//   ašej_, _délo, _zobj,
  { {0x9564005a,0xd5640856,0x63b40240,0x00000000}},	//   _сърд, _стрп, čený,
  { {0xddd80006,0x2d521035,0x21cc004c,0x00000000}},	//   _gyvū, ršem_, běh_,
  { {0x26c300c3,0x7bcd00fe,0x1e820121,0x00000000}},	//   _mejo_, _avau, ильм,
  { {0x7052007e,0xc0cb0121,0x2d5200a8,0x00000000}},	//   انیا, _хуже_, mšek_,
  { {0xd0090a25,0xafe50200,0x600a013d,0x00000000}},	//   _целе_, _ролл, römá,
  { {0xeb97011c,0xfc03007b,0xdde9005d,0x00000000}},	//   кия_, јпро, _قرعه_,
  { {0x4420001b,0x290b2c8d,0xdcfb005b,0x00000000}},	//   ̣i_, _baca_, aptı,
  { {0x290b1c07,0xdb1d0072,0xa3d20042,0x00000000}},	//   _caca_, essä, _विल_,
  { {0x672e017f,0x290b000c,0xd70a0085,0x00000000}},	// [d9c0] _pobj, _daca_, мнае_,
  { {0x249f00f3,0x6fd40161,0x98b3001c,0x00000000}},	//   _agum_, _दिसं, ādāt_,
  { {0xe7fe0053,0xa6960095,0x26c3006d,0x00000000}},	//   _उनका_, трај, _dejo_,
  { {0xceb80051,0x613c013d,0xb6060023,0x00000000}},	//   zbę_, _céll, vušā,
  { {0x68e400e8,0x6d5d0164,0x4432001b,0x00000000}},	//   mgid, érai, ây_,
  { {0x290025a1,0x68e464b6,0x60c20139,0x00000000}},	//   leia_, lgid, _seom,
  { {0x44200469,0x2d520066,0x31c30121,0x00000000}},	//   ţi_, ršej_, асыв,
  { {0x68e46637,0x613c0003,0x29006638,0x00000000}},	//   ngid, _vélo, neia_,
  { {0x60c2017f,0xc9530a7a,0x27e06639,0x00000000}},	//   _veom, ימה_, nuin_,
  { {0x6376003b,0x2900663a,0xfc3f011b,0x00000000}},	//   râns, heia_, ucím_,
  { {0x0219000d,0x212f01e1,0x27e000ca,0x00000000}},	//   _піць_, _fogh_, huin_,
  { {0x27e0663b,0x212f663c,0xfc3f013d,0x00000000}},	//   kuin_, _gogh_, scím_,
  { {0x29000016,0xdb1d0072,0x6562017c,0x00000000}},	//   deia_, yssä, inoh,
  { {0x442603d9,0x6d46053b,0x290b05d5,0x00000000}},	//   ixo_, ahka, _saca_,
  { {0x4f9b014e,0x4a540001,0x39a40095,0x00000000}},	//   _קבוצ, акрс, иштв,
  { {0x58d40076,0x26c3085a,0x6d46254c,0x00000000}},	//   иост, _sejo_, chka,
  { {0x27e00994,0x48150088,0x65620080,0x00000000}},	// [d9d0] guin_, ымас, dnoh,
  { {0x656200fe,0x4ab70053,0x7d0d663d,0x00000000}},	//   enoh, _अभिव, _haas,
  { {0x7d0d0004,0x68e400e8,0x290b5020,0x00000000}},	//   _kaas, bgid, _taca_,
  { {0x2d5200b2,0x290000be,0x38c6005f,0x00000000}},	//   všek_, ceia_, tūrų_,
  { {0x61352946,0x26c3039f,0x286b007b,0x00000000}},	//   _mált, _tejo_, _црно_,
  { {0x7d0d021f,0x98a2005f,0x00000000,0x00000000}},	//   _laas, _voką_,   ,
  { {0x799d0009,0x51f50032,0x256e004c,0x00000000}},	//   _kisw, استر, hýly_,
  { {0x7d0d663e,0x661a00ea,0x3495000d,0x00000000}},	//   _naas, _átka, _бабр,
  { {0x3494663f,0x78ad2069,0x1477005d,0x00000000}},	//   _ватр, icav, _شارج,
  { {0x481600b7,0x257c01c2,0x20d3008b,0x00000000}},	//   אַטן_, víli_, ợi_,
  { {0x7d0d0019,0x6468003b,0x3f9c0db7,0x00000000}},	//   _baas, ăsiţ, _divu_,
  { {0x6d464f75,0xcb09009a,0x1015009b,0x00000000}},	//   uhka, _מל_, _مبتد,
  { {0xbad6000d,0x60c9004b,0x29001494,0x00000000}},	//   лівы, maem, veia_,
  { {0x257c0066,0xa03a0041,0x644b0075,0x00000000}},	//   ríli_, _רעספ, izgi,
  { {0x799d004d,0x7d0d0bda,0x290020c5,0x00000000}},	//   _bisw, _faas, teia_,
  { {0x7d0d0019,0x27e06640,0x78a20066,0x00000000}},	//   _gaas, tuin_, ľovo,
  { {0x6d44075a,0x799d001f,0x29006641,0x00000000}},	// [d9e0] _ilia, _disw, reia_,
  { {0x27e00250,0x613c00ea,0x29002b1f,0x00000000}},	//   ruin_, _célj, seia_,
  { {0x2900017d,0x3a250137,0x6562011b,0x00000000}},	//   peia_, älpt_, tnoh,
  { {0x25b7006a,0x78ad0a02,0x4426032a,0x00000000}},	//   اهند_, ccav, txo_,
  { {0x27e06642,0x69ce0b84,0x613c013d,0x00000000}},	//   quin_, lsbe, _félj,
  { {0x69dc20c1,0x442601a8,0x63520022,0x00000000}},	//   orre, rxo_, ołni,
  { {0x366a0076,0x6f016643,0xbcfb013d,0x00000000}},	//   _чаво_, delc, dnén,
  { {0x3d0e0161,0x3f9c024a,0x31340259,0x00000000}},	//   ियों_, _sivu_, реир,
  { {0xddcf0b59,0x69dc004d,0x60f70085,0x00000000}},	//   _češn, hrre, уныя_,
  { {0x8ff70032,0x69ce023a,0x7d0d6644,0x00000000}},	//   ارير_, ksbe, _saas,
  { {0x6d440027,0x3f82001c,0x69ce006f,0x00000000}},	//   _blia, ēku_, jsbe,
  { {0x6d440025,0x6288001c,0xa0a6037c,0x00000000}},	//   _clia, _izdo, _садд,
  { {0x613503e8,0x7d00004b,0x7d0d23b3,0x00000000}},	//   _vált, õmsa, _vaas,
  { {0x799d0373,0xce940062,0x7d0d1a62,0x00000000}},	//   _sisw, _калъ, _waas,
  { {0x613c000f,0x7d0d5c36,0x69ce32eb,0x00000000}},	//   _nélk, _taas, gsbe,
  { {0x62880195,0x127b0041,0x6d44255a,0x00000000}},	//   _mzdo, גאלע, _glia,
  { {0x69dc6645,0x78ad34a3,0x6d5d0003,0x00000000}},	// [d9f0] arre, rcav, érau,
  { {0x69da0080,0x69ce1c1d,0x78ad6646,0x00000000}},	//   átec, bsbe, scav,
  { {0x613c00ea,0xf6550002,0x6d440072,0x00000000}},	//   _célk, јвеќ, _ylia,
  { {0x637f315a,0xf8b1007e,0x613c2de9,0x00000000}},	//   mêni, _ذکر_, _délk,
  { {0x7bcf0521,0xd0060754,0x39490025,0x00000000}},	//   nscu, _بل_, mhas_,
  { {0x39490016,0x7bcf6647,0x257c0080,0x00000000}},	//   lhas_, iscu, dílu_,
  { {0x2002005b,0xe1250601,0x3949004b,0x00000000}},	//   çkin_, имки, ohas_,
  { {0x394903d9,0xb4f90047,0x6f0103a7,0x00000000}},	//   nhas_, _שפּי, welc,
  { {0x443900b9,0xbcfb00ea,0xab5b2586,0x00000000}},	//   _æs_, tnén, nsüs,
  { {0x28980047,0x69dc6648,0x6d440139,0x00000000}},	//   נדזן_, yrre, _slia,
  { {0x23ab0146,0x4d66151b,0xd12e007e,0x00000000}},	//   _høj_, иков, سمی_,
  { {0x6f0118d3,0xa2af0053,0x8d5601d5,0x00000000}},	//   selc, ुरक्, рточ,
  { {0x5d670121,0x6569007d,0x40e8009a,0x00000000}},	//   риям_, _mjeh, _תַעֲ,
  { {0xbb760062,0x6fb20021,0x4ea7005e,0x00000000}},	//   румъ, _بموا, _срда,
  { {0x3956000a,0x637f0016,0x7e7900b5,0x00000000}},	//   ањат, gêni, _באַז,
  { {0x6d5d03b2,0x39490027,0x6d440035,0x00000000}},	//   érat, ghas_, _ulia,
  { {0xf99f01f4,0xe8f7005e,0x69ce5780,0x00000000}},	// [da00] _diè_, јлу_, ssbe,
  { {0x8c1b014e,0x57470001,0x69ce6649,0x00000000}},	//   _יופי, азум_, psbe,
  { {0x39490027,0xaadb2177,0x1dab0042,0x00000000}},	//   bhas_, _בחיר, _घूमत,
  { {0x3949664a,0xfdf60063,0x88c7030b,0x00000000}},	//   chas_, יצעת_, _клюв_,
  { {0xb6a60086,0xe3af0593,0xab5b013d,0x00000000}},	//   _вигл, ورو_, psüt,
  { {0x68f6001f,0x3940664b,0x657b00ac,0x00000000}},	//   lfyd, lkis_, _ekuh,
  { {0x6684007e,0x61e3132d,0x613c541f,0x00000000}},	//   _ایال, gunl, _héli,
  { {0x23ab0146,0x39400006,0x68f6001f,0x00000000}},	//   _føj_, nkis_, nfyd,
  { {0x27f2001f,0x29370047,0xa2e61314,0x00000000}},	//   ntyn_, שאפן_, _возд,
  { {0x2d820122,0x613c00f4,0xa2d30044,0x00000000}},	//   elke_, _méli, _ويقت,
  { {0x6288001c,0x39404aca,0x4d990086,0x00000000}},	//   _uzdo, kkis_, лкою_,
  { {0x637f017d,0xfcab005d,0xdde0009c,0x00000000}},	//   vêni, کاگو_, ítőj,
  { {0xed58000d,0x2d85001c,0xda09007e,0x00000000}},	//   роў_, ēle_, گيزه_,
  { {0x68f6001f,0xdb1d000e,0xbcfb0061,0x00000000}},	//   efyd, nssø, mném,
  { {0xf99f0290,0x68f6162d,0x3949664c,0x00000000}},	//   _piè_, ffyd, thas_,
  { {0x61350014,0x613c28f4,0x5e9b0063,0x00000000}},	//   _jálp, _béli, _בבוק,
  { {0xf09300b5,0xc6f90121,0x613c110e,0x00000000}},	// [da10] ַנע_, лнах_, _céli,
  { {0x613c0164,0xf7700067,0x6d5d664d,0x00000000}},	//   _déli, وال_, lisa,
  { {0xab5b0019,0x95d90076,0xdb1d00b9,0x00000000}},	//   ssüs, удет_, dssø,
  { {0x613c664e,0x3940591d,0x26c70022,0x00000000}},	//   _féli, ckis_, źno_,
  { {0xdb230014,0x6d5d078c,0x7c3d002b,0x00000000}},	//   _þróa, iisa, nysr,
  { {0xfbb8014e,0xdb040025,0x61e3005b,0x00000000}},	//   ספות_, _stiú, tunl,
  { {0xdb04048e,0x6d5d2150,0x45d40c46,0x00000000}},	//   _quié, kisa, _морс,
  { {0x6b4b000f,0x6d5d0035,0x61e301f7,0x00000000}},	//   _függ, jisa, runl,
  { {0xf92a0047,0x673500b2,0xe45f0072,0x00000000}},	//   רופּ, _kozj, _äö_,
  { {0x9171008b,0x3ea300b9,0xd25b005e,0x00000000}},	//   _mở_, øjt_, _ице_,
  { {0x212d017f,0x63a90035,0x39400006,0x00000000}},	//   pjeh_, _huen, ykis_,
  { {0x63a90009,0x200b00b9,0x3cf40053,0x00000000}},	//   _kuen, æcis_, ेजें_,
  { {0x814c00b5,0x51740021,0x41740021,0x00000000}},	//   _בעאַ, _بالأ, _بالس,
  { {0x6d5d664f,0x7fb4007e,0x63a96650,0x00000000}},	//   érar, _بلوچ, _muen,
  { {0x6d5d6651,0x443d001f,0x2fdf29d9,0x00000000}},	//   bisa, hyw_, lrug_,
  { {0x6d5d6652,0xccc60ac5,0x62813b89,0x00000000}},	//   cisa, _убий, _mylo,
  { {0x7d061c02,0x63a900ca,0x2fdf002b,0x00000000}},	// [da20] meks, _nuen, nrug_,
  { {0xcc570063,0xdb0e00fe,0x7d066653,0x00000000}},	//   _לספק_, äkär, leks,
  { {0xb5a90032,0x2f5a0047,0x7d06006f,0x00000000}},	//   لانك_, נדענ, oeks,
  { {0x63a96654,0x56930086,0x7d066655,0x00000000}},	//   _buen, чаєт, neks,
  { {0x63a9048e,0x6ba1005b,0xbcfb0003,0x00000000}},	//   _cuen, _üzgü, siég,
  { {0x62810006,0x63a1001c,0x6d5d20c4,0x00000000}},	//   _bylo, _ciln, zisa,
  { {0xbcfb0003,0x6135017d,0x2fdf0983,0x00000000}},	//   liée, _pálp, erug_,
  { {0x63a902dd,0x463b0047,0x7d066656,0x00000000}},	//   _fuen, _געלע, jeks,
  { {0xdb1d00d1,0x2fdf001f,0x6b4b004d,0x00000000}},	//   pssø, grug_, _hüge,
  { {0x6d5d00f3,0x9df80079,0x320d0072,0x00000000}},	//   wisa, анот_, äkyä_,
  { {0xa016006a,0x52860021,0xdd95000d,0x00000000}},	//   _گذاش, _الاك, жаны,
  { {0x63a10529,0x26ca0024,0xdc990086,0x00000000}},	//   _ziln, _lebo_, ивні_,
  { {0x40960032,0x69da0024,0x79840051,0x00000000}},	//   _الشر, áten, dliw,
  { {0x26ca0080,0x7b671001,0x6d5d55f4,0x00000000}},	//   _nebo_, стме, sisa,
  { {0x69da0117,0x9171001b,0x6ce7000d,0x00000000}},	//   šten, _sở_, _ліпе,
  { {0x8e830032,0x7d0601f7,0xbcfb0164,0x00000000}},	//   _عليه, ceks, fiée,
  { {0x58870076,0xe8940076,0x76a70021,0x00000000}},	// [da30] сыва, зать, محاك,
  { {0x79846657,0xdb1f0072,0xbd04004c,0x00000000}},	//   aliw, äväm, riéř,
  { {0xdf36001b,0x26ca02dd,0x63a927df,0x00000000}},	//   _đặt_, _debo_, _suen,
  { {0x63a902dd,0x63a11959,0x27e06658,0x00000000}},	//   _puen, _siln, brin_,
  { {0xbcfb0164,0x62816659,0x63a120ae,0x00000000}},	//   ciée, _sylo, _piln,
  { {0x6d88006d,0x6b4b00bd,0x443d001f,0x00000000}},	//   eñal, _füge, ryw_,
  { {0x7d06419f,0x63a12d70,0x63bc00c2,0x00000000}},	//   yeks, _viln, _črne,
  { {0x13a7007e,0x628101c2,0x2fdf665a,0x00000000}},	//   _هنری_, _vylo, trug_,
  { {0xe81c0161,0x63a11607,0x63a90019,0x00000000}},	//   निया_, _tiln, _uuen,
  { {0x2fdf00b9,0x289c0047,0xbcfb004a,0x00000000}},	//   rrug_, ניזא, lnéh,
  { {0x79960051,0x2bdc0053,0x27e00089,0x00000000}},	//   ymyw, _बिहा, zrin_,
  { {0xbcfb027d,0x6d5d0003,0x200e00fe,0x00000000}},	//   nnéh, érap, äjiä_,
  { {0x4c360088,0x613c48ab,0x7d06665b,0x00000000}},	//   цэнт, _célu, reks,
  { {0x7d06665c,0x637f017d,0x68ef01a8,0x00000000}},	//   seks, cênt, _accd,
  { {0x999e0080,0x26ca078d,0x79840051,0x00000000}},	//   átů_, _rebo_, tliw,
  { {0xbcfb0114,0x201d0051,0x27e04d3a,0x00000000}},	//   jnéh, _krwi_, trin_,
  { {0x60cb00ea,0xbcfb027d,0x49990076,0x00000000}},	// [da40] _megm, dnéh, ётся_,
  { {0x60cb00ea,0xbcfb0003,0x27e0665d,0x00000000}},	//   _legm, riée, rrin_,
  { {0xb87b0139,0x8afb0063,0x79840022,0x00000000}},	//   _scít, _דהיי, pliw,
  { {0x92a60051,0x86990121,0x5dfa0041,0x00000000}},	//   zyłą, стут_, יפענ,
  { {0x3947003b,0x613c013d,0xd6da005d,0x00000000}},	//   _însa_, _mélt, _پوزش_,
  { {0x8c1b0063,0x84130085,0x7c0b009a,0x00000000}},	//   יוני, ьміх, שִׁ֔,
  { {0xbcfb027d,0x2d800078,0xe5060021,0x00000000}},	//   bnéh, _okie_, _وبري,
  { {0x1a9b0047,0x3f85004b,0xb034007b,0x00000000}},	//   סיקע, ellu_, зниш,
  { {0xf9930a7a,0xff0603d6,0x637f017d,0x00000000}},	//   ורה_, оянн, tênt,
  { {0x2d800022,0xa6fa009d,0x00000000,0x00000000}},	//   _akie_, בִ֛י,   ,
  { {0x69da02f4,0x637f017d,0x8266007e,0x00000000}},	//   átel, rênt, _بهان,
  { {0x8fa60189,0x3f85001f,0x613c1270,0x00000000}},	//   _даде, allu_, _célt,
  { {0x98a90024,0x459b0047,0x9f440003,0x00000000}},	//   tiaľ_, יסטע, humé_,
  { {0xada50024,0xbcfb665e,0x613c0014,0x00000000}},	//   _skúš, inéi, _vélu,
  { {0xda350076,0xf1b80063,0xbcfb0139,0x00000000}},	//   чевы, מֶּל, hnéi,
  { {0xed580459,0xdb0d017d,0x98a90066,0x00000000}},	//   _мој_, _otaç, siaľ_,
  { {0xbcfb027d,0xfc3f00cd,0x0855000d,0x00000000}},	// [da50] vnéh, rcís_, чваю,
  { {0x1ab4030b,0xbb550043,0xd7740043,0x00000000}},	//   _обья, _رنجب, والع,
  { {0xbcfb004a,0x6376003b,0x248d013d,0x00000000}},	//   tnéh, bânz, _szem_,
  { {0x69d500ea,0xaba8007e,0xaae7005d,0x00000000}},	//   msze, _دهیم_, _اسکو,
  { {0x60cb00ac,0xbcfb0240,0x63bc00c2,0x00000000}},	//   _regm, rnéh, _črnc,
  { {0x27e9014f,0x60cb665f,0xbcfb0240,0x00000000}},	//   muan_, _segm, snéh,
  { {0x4429000c,0x27e96660,0x69d52440,0x00000000}},	//   ţa_, luan_, nsze,
  { {0x68ed6661,0x26000053,0x2055130d,0x00000000}},	//   ngad, _रहती_, зтор,
  { {0x27e900a4,0x7f1916f2,0x00000000,0x00000000}},	//   nuan_, біну_,   ,
  { {0x2ca9002c,0x2d99599c,0x69d514e0,0x00000000}},	//   _agad_, ïren_, ksze,
  { {0x27e906a7,0x69d50051,0x656b0a9f,0x00000000}},	//   huan_, jsze, ongh,
  { {0x27e9014f,0x69d55425,0x311401dd,0x00000000}},	//   kuan_, dsze, _офіс,
  { {0x27e9014f,0x50670032,0x68ed6662,0x00000000}},	//   juan_, _بطاق, dgad,
  { {0x27e90397,0x2d99016d,0x63bb0035,0x00000000}},	//   duan_, amse_, _mtun,
  { {0x6b5001e3,0xda660021,0x69d50d21,0x00000000}},	//   _lägg, ساسي, gsze,
  { {0x68ed6663,0x6e3c004d,0xc2120041,0x00000000}},	//   ggad, ärbe, עהן_,
  { {0x27e90277,0x6b420013,0x69d50022,0x00000000}},	// [da60] guan_, _lôgi, asze,
  { {0x656b053b,0x6d4601b2,0x9f440003,0x00000000}},	//   engh, lkka, tumé_,
  { {0x63bb0529,0x7d166664,0x6d466665,0x00000000}},	//   _atun, _kays, okka,
  { {0x27e9003e,0x6b500137,0x6d466666,0x00000000}},	//   buan_, _bägg, nkka,
  { {0x29370047,0x9f440164,0x27e9017e,0x00000000}},	//   _זאכן_, sumé_, cuan_,
  { {0x6b500137,0x656b6667,0xfaff0023,0x00000000}},	//   _dägg, angh, ļīgi_,
  { {0xbcfb0025,0xf1070053,0x63bb0072,0x00000000}},	//   snéi, वजूद_, _etun,
  { {0xb6a31b29,0x9c87004c,0xbcfb013d,0x00000000}},	//   _числ, _jičí, lnév,
  { {0x69d54fd9,0x5f9402b6,0x998a005f,0x00000000}},	//   zsze, миит, lybų_,
  { {0x68ed2574,0xa8570063,0x69d50686,0x00000000}},	//   zgad, פייה_, ysze,
  { {0x6f080066,0x69da436d,0x7d165404,0x00000000}},	//   redc, štej, _bays,
  { {0x656200fe,0x27e96668,0xd84301c2,0x00000000}},	//   nioh, yuan_, ničí_,
  { {0x69d50051,0x613c00ea,0xa3cf0053,0x00000000}},	//   wsze, _félr, वीप_,
  { {0x6d46024a,0x69d56669,0xfe6f005d,0x00000000}},	//   akka, tsze, ئدی_,
  { {0x656b001f,0xd90f007e,0x29090072,0x00000000}},	//   yngh, هید_, teaa_,
  { {0x27e9014f,0x68ed666a,0x6d460e77,0x00000000}},	//   tuan_, ugad, ckka,
  { {0x69d5000f,0x68ed666b,0x7aee0139,0x00000000}},	// [da70] ssze, rgad, úntá,
  { {0xfbd20063,0x27e91320,0x69d51504,0x00000000}},	//   _שתי_, ruan_, psze,
  { {0x63bb666c,0xe4d90032,0x27e912ca,0x00000000}},	//   _stun, قوات_, suan_,
  { {0x27e913b8,0x656b3dd1,0x6562002b,0x00000000}},	//   puan_, ungh, gioh,
  { {0xe1f1007e,0xb8860066,0xa4870021,0x00000000}},	//   چسب_, _príť, أجان,
  { {0x07a4000d,0x6b500137,0xaabf0053,0x00000000}},	//   _паўн, _vägg, ्रिक,
  { {0x9195000a,0xf5390260,0x8235005d,0x00000000}},	//   мјиш, _toť_, ظرتا,
  { {0x7fd90002,0xa5350085,0x3495666d,0x00000000}},	//   офот_, _ўнач, _жабр,
  { {0x6b5000a5,0x61ea0244,0x1abf0042,0x00000000}},	//   _häge, aufl, ्राथ,
  { {0x200d0035,0x7d1600a4,0x6d4d666e,0x00000000}},	//   rwei_, _says, _alaa,
  { {0x6d4d021f,0x7d160164,0x7529074f,0x00000000}},	//   _blaa, _pays, _knez,
  { {0x6d460072,0x6b501013,0x69da0078,0x00000000}},	//   ukka, _mäge, štek,
  { {0x6b5000c7,0x6d4600fe,0x6b4b0019,0x00000000}},	//   _läge, rkka, _süga,
  { {0xa3cf0161,0x2f180076,0x9f340054,0x00000000}},	//   वीय_, _ночь_, _печі,
  { {0x316d000c,0x6b501255,0x99710078,0x00000000}},	//   onez_, _näge, _sąš_,
  { {0x316d0003,0x6d4d0757,0xe8fa000d,0x00000000}},	//   nnez_, _glaa, ўла_,
  { {0xbf8a001b,0xd7f90086,0x9171008d,0x00000000}},	// [da80] _đoạn_, зує_, _mờ_,
  { {0x6ac60032,0xbcfb006d,0xdb0400cd,0x00000000}},	//   _تقدم, nién, _etiò,
  { {0x753b666f,0x65626670,0x6b5000a5,0x00000000}},	//   _bouz, tioh, _vägd,
  { {0x273f003b,0x998a0078,0x448a1527,0x00000000}},	//   _sînt_, rybų_, обен_,
  { {0x753b0164,0x645d0078,0x78a20066,0x00000000}},	//   _douz, _žsir, ľovs,
  { {0x75290035,0x4373005e,0xa2942049,0x00000000}},	//   _enez, кујт, налі,
  { {0xbcfb006d,0x753b0089,0xe1ef0021,0x00000000}},	//   dién, _fouz, لسي_,
  { {0xd1300032,0x61f8006f,0x316d4da0,0x00000000}},	//   امة_, rtvl, gnez_,
  { {0xd007000a,0x673c0659,0x61ea003b,0x00000000}},	//   дење_, _korj, sufl,
  { {0x6d4d1103,0x3eaa00b9,0xbcfb6671,0x00000000}},	//   _slaa, øbt_, gién,
  { {0x673c00c3,0x6d4d1f8f,0x917a008b,0x00000000}},	//   _morj, _plaa, _cậy_,
  { {0xdfcf007e,0x61e50080,0x63a800a4,0x00000000}},	//   _چين_, áhle, _hidn,
  { {0x6d4d016d,0x673c00ac,0xbcfb006d,0x00000000}},	//   _vlaa, _oorj, bién,
  { {0xbcfb05d5,0x673c00fe,0xab5b0058,0x00000000}},	//   cién, _norj, lsüz,
  { {0x63a86672,0x0f7b009a,0xf98900de,0x00000000}},	//   _midn, _ורגל, كنسي_,
  { {0xac95000d,0xcda90047,0x6d4d6673,0x00000000}},	//   _пайш, _ציפֿ, _ulaa,
  { {0x6b500d88,0x673c6674,0xd7f8093d,0x00000000}},	// [da90] _säge, _borj, дух_,
  { {0x368b02b6,0x753b6675,0x317f00ca,0x00000000}},	//   осен_, _souz, zouz_,
  { {0x753b0be1,0x2d8b01f4,0x74b90320,0x00000000}},	//   _pouz, olce_, пулс_,
  { {0xa8350138,0x6b500140,0x6a9a0063,0x00000000}},	//   _земљ, _väge, _משתנ,
  { {0x673c0955,0xfd580063,0x62880058,0x00000000}},	//   _forj, ושאי_, _aydo,
  { {0x29190009,0x94740021,0xdb0d05d5,0x00000000}},	//   _hasa_, خدما, _ataú,
  { {0x20060529,0x2369017f,0x4b380063,0x00000000}},	//   _apoi_, đaj_, ורגל_,
  { {0x2919014f,0x39491867,0x69da017d,0x00000000}},	//   _jasa_, nkas_, átei,
  { {0x29190e60,0xbcfb006d,0x600602dc,0x00000000}},	//   _masa_, tién, еным_,
  { {0xbcfb006d,0x6d9600ea,0x29196676,0x00000000}},	//   uién, záad, _lasa_,
  { {0xbcfb006d,0x39491b35,0x62881f28,0x00000000}},	//   rién, kkas_, _gydo,
  { {0x917a008b,0x29190465,0x2d846677,0x00000000}},	//   _vậy_, _nasa_, ôme_,
  { {0x2ca40137,0xbc190054,0x66f00042,0x00000000}},	//   ämd_, мірі_, _चालक_,
  { {0x39496678,0x5dd90062,0x2919004e,0x00000000}},	//   ekas_, _ефир_, _aasa_,
  { {0x49966679,0x2919667a,0x6381004c,0x00000000}},	//   ешат, _basa_, míně,
  { {0x29191d88,0x39493986,0xa3c10042,0x00000000}},	//   _casa_, gkas_, ूठा_,
  { {0x6b500137,0x25bf007d,0x63bc00c2,0x00000000}},	// [daa0] _vägb, _čula_, _črno,
  { {0x394900fe,0x2d820075,0x9b460044,0x00000000}},	//   akas_, loke_, _أندو,
  { {0x2919667b,0xd639000d,0xd946032d,0x00000000}},	//   _fasa_, мяці_, _зени,
  { {0x3a25010a,0x394901e3,0xcdda00b5,0x00000000}},	//   ælpe_, ckas_, פֿבר,
  { {0x6615000f,0x673c00fe,0x6288667c,0x00000000}},	//   _eszk, _torj, _sydo,
  { {0x9f4d0072,0x3f490014,0x29002321,0x00000000}},	//   nteä_, _búum_, lfia_,
  { {0x7d04667d,0x63a8667e,0x2919005b,0x00000000}},	//   _obis, _vidn, _yasa_,
  { {0x7afb0117,0x9f4d00fe,0x6f182de1,0x00000000}},	//   đuti, hteä_, _savc,
  { {0x63a800c7,0x62880051,0xf0b7007e,0x00000000}},	//   _tidn, _wydo, رايش_,
  { {0x7d04667f,0xbcfb006c,0x6d4000a5,0x00000000}},	//   _abis, ynés, öman,
  { {0x44240526,0x3949005f,0x91e3218c,0x00000000}},	//   _hrm_, ykas_, _бохе,
  { {0x9171008d,0x6c3500f2,0xc05a014b,0x00000000}},	//   _tớ_, نفجا, _ніл_,
  { {0x29190397,0x5c04000d,0xcff5005d,0x00000000}},	//   _rasa_, ляра, _لينک,
  { {0x29190009,0x3e340021,0xe451009a,0x00000000}},	//   _sasa_, _لفتر, בֶל_,
  { {0xb9e4019d,0xda78005a,0x29196680,0x00000000}},	//   літи, еят_, _pasa_,
  { {0x69da0164,0x44240027,0x39490006,0x00000000}},	//   âtea, _orm_, ukas_,
  { {0xb8d90161,0xf6e722ce,0x29196681,0x00000000}},	// [dab0] _चल_, ецен, _vasa_,
  { {0x2aee0053,0x29000019,0x7d1d6682,0x00000000}},	//   _जाएँ_, afia_, ldss,
  { {0x3f9e0026,0x29196683,0x86240071,0x00000000}},	//   imtu_, _tasa_, льце,
  { {0x9475007e,0x59b60053,0xdb1d0137,0x00000000}},	//   نگذا, _आंतर, gssö,
  { {0x7d1d36f5,0x53e00053,0xe3b80054,0x00000000}},	//   idss, _निःश, ебі_,
  { {0x044205fb,0x63850062,0xb87b0066,0x00000000}},	//   решн, ъгла, _edíc,
  { {0x69da22f1,0x66150051,0x6b500504,0x00000000}},	//   štev, _uszk, _jäga,
  { {0x3f8c0026,0x27e93646,0x7d1d188f,0x00000000}},	//   eldu_, oran_, jdss,
  { {0x7d1d00d1,0x2fd6007e,0xe315005e,0x00000000}},	//   ddss, نويد_, _имањ,
  { {0x4f220121,0x798d0373,0x257c004c,0x00000000}},	//   адьб, hlaw, díly_,
  { {0xbcfb006d,0x798d6684,0x9171008b,0x00000000}},	//   piél, klaw, _cỡ_,
  { {0xd00e007e,0x64590051,0x7c24407b,0x00000000}},	//   حلی_, ozwi, _prir,
  { {0x2d826685,0x6459030c,0xef0e5ed9,0x00000000}},	//   roke_, nzwi, _км_,
  { {0x0056014e,0x27e96686,0x798d0150,0x00000000}},	//   _בשנת_, dran_, elaw,
  { {0x798d001f,0x9171008b,0x27e96687,0x00000000}},	//   flaw, _gỡ_, eran_,
  { {0x7d046688,0x4ea4005e,0x7c246689,0x00000000}},	//   _ubis, _срча, _trir,
  { {0x186725f7,0x27e9668a,0x629c004a,0x00000000}},	// [dac0] вати_, gran_, _úrov,
  { {0x798d002c,0x998d007d,0x64590022,0x00000000}},	//   alaw, ćeš_, dzwi,
  { {0xd5b90086,0x60c900ac,0x2a36000d,0x00000000}},	//   есі_, kbem, _рэпр,
  { {0x44240492,0xdb1d00ea,0xb7bb017d,0x00000000}},	//   _prm_, özös, _grão,
  { {0x3f8704e9,0x3f8c0014,0x27e9668b,0x00000000}},	//   _oknu_, yldu_, cran_,
  { {0x69dc1253,0x232731d7,0x7d0f013d,0x00000000}},	//   osre, кочи_, zecs,
  { {0x672e01e3,0xd24f03eb,0x7d1d00b9,0x00000000}},	//   _inbj, ينه_, ydss,
  { {0xdce600eb,0x60f8005a,0x660d00ea,0x00000000}},	//   mokė, хния_, őnké,
  { {0x4fd3000d,0x67020053,0x44241423,0x00000000}},	//   ажыт, र्थक_, _urm_,
  { {0xa2c10053,0x69dc0b0c,0xbebc008f,0x00000000}},	//   रुद्, ksre, idīg,
  { {0x6e940021,0xc106005d,0xe8190082,0x00000000}},	//   طلحا, _لواي, _नैना_,
  { {0x7d1d006f,0xa00a0021,0x69dc396a,0x00000000}},	//   udss, _يقال_, dsre,
  { {0x6b500137,0x7d1d39c0,0x2018008f,0x00000000}},	//   _säga, rdss, āris_,
  { {0x2bb50053,0x6abf0053,0x69dc0244,0x00000000}},	//   ंदबा, ्रेर, fsre,
  { {0x798d00e5,0x69dc2beb,0x7d0f013d,0x00000000}},	//   tlaw, gsre, pecs,
  { {0x2e590088,0x2d6800ea,0x27e9668c,0x00000000}},	//   _яшчэ_, lően_, tran_,
  { {0x798d053b,0x5887014c,0x27e9668d,0x00000000}},	// [dad0] rlaw, тыва, uran_,
  { {0xd6db000a,0x5b150e34,0x798d004d,0x00000000}},	//   ќта_, _смот, slaw,
  { {0xc6a70076,0x57a434ba,0x37040092,0x00000000}},	//   траи, ршта, јчув,
  { {0x45180086,0x98b3001c,0x7bdd4fec,0x00000000}},	//   кція_, ādēt_, ossu,
  { {0x69da082a,0xdfc60021,0xe8e00013,0x00000000}},	//   štet, _دي_, _ngột_,
  { {0x66010137,0xb384000d,0x7bdd5138,0x00000000}},	//   _älko, аліл, issu,
  { {0x45d40076,0xbb3c0047,0x2d68013d,0x00000000}},	//   _восс, ועגי, dően_,
  { {0x7bdd41b6,0x41b200de,0x00000000,0x00000000}},	//   kssu, حمير,   ,
  { {0xe4750001,0x236700c2,0x40940121,0x00000000}},	//   _слањ, pinj_, ирьт,
  { {0x69dc3160,0xa2ca0053,0x60c60058,0x00000000}},	//   ysre, _स्प्, ıkma,
  { {0xfbdf008b,0x6807008f,0x7bdd668e,0x00000000}},	//   uyên_, lījā, essu,
  { {0x69dc0831,0xc6920063,0xab5b004d,0x00000000}},	//   vsre, מאי_, spül,
  { {0x69c7006f,0x6807008f,0x69dc668f,0x00000000}},	//   epje, nījā, wsre,
  { {0x69dc2181,0x6008009a,0x00000000,0x00000000}},	//   tsre, _יִצְ,   ,
  { {0x4432001b,0xb9b5005a,0x79840035,0x00000000}},	//   ̣y_, истъ, toiw,
  { {0x69dc6690,0xfe70007e,0x3f8541f7,0x00000000}},	//   rsre, _بده_, lolu_,
  { {0x69dc004d,0xdb240014,0x7d7700de,0x00000000}},	// [dae0] ssre, þrót, _حمير_,
  { {0x6807001c,0x69dc6691,0x442a004c,0x00000000}},	//   dījā, psre, _čb_,
  { {0x8afb0aeb,0xa696005e,0xceb2089e,0x00000000}},	//   _אהיי, урај, ציא_,
  { {0x89360032,0x25ad3de3,0xd5af01fb,0x00000000}},	//   _إعدا, _ciel_, سفه_,
  { {0x4346066c,0x44320013,0x25ad1078,0x00000000}},	//   ледв, ãy_, _diel_,
  { {0x2bb70053,0x68f600a3,0xdb1d011b,0x00000000}},	//   _इंसा, lgyd, opsá,
  { {0x394200cc,0x3f85339f,0x25ad6692,0x00000000}},	//   _koks_, dolu_, _fiel_,
  { {0x394200cc,0x7bdd4645,0xc2170054,0x00000000}},	//   _joks_, yssu, уєш_,
  { {0x2d6800ea,0x9f54018e,0xdb0d017d,0x00000000}},	//   tően_, ивич, _suaí,
  { {0x26da0035,0x25ad0c84,0x38170063,0x00000000}},	//   napo_, _ziel_, נקים_,
  { {0x1d350726,0x69da0003,0x2d68013d,0x00000000}},	//   ання, âtel, rően_,
  { {0xc27b0047,0x7bdd0244,0xade50042,0x00000000}},	//   _ארבי, tssu, _किरन_,
  { {0x26da0035,0xfd1f0290,0x9f34000d,0x00000000}},	//   kapo_, rdì_, _велі,
  { {0x90970086,0xdb16008b,0x40930021,0x00000000}},	//   _світ_, _huyê, _الهر,
  { {0xf99300b3,0x26da0035,0x39426693,0x00000000}},	//   مبر_, dapo_, _boks_,
  { {0x391502d8,0x24890022,0xe918012c,0x00000000}},	//   јмар, żami_, лосі_,
  { {0x69c7017f,0x7d74007e,0xbebc008f,0x00000000}},	// [daf0] spje, _داوط, mdīb,
  { {0x613c000f,0xbebc001c,0x25ad00ac,0x00000000}},	//   _célz, ldīb, _siel_,
  { {0xcf9300b5,0x25ad02dd,0x2d6f0080,0x00000000}},	//   צטע_, _piel_, před_,
  { {0x6807001c,0xcdf7009d,0x00000000,0x00000000}},	//   tījā, רמאי_,   ,
  { {0x26da0035,0x6d9d0025,0x25ad0c84,0x00000000}},	//   bapo_, méad, _viel_,
  { {0x26da17c2,0x02c20086,0x25ad0983,0x00000000}},	//   capo_, ойшо, _wiel_,
  { {0x6807001c,0x25ad017c,0x3f856694,0x00000000}},	//   sījā, _tiel_, volu_,
  { {0x60091491,0x69c500ac,0x3fe51321,0x00000000}},	//   вним_, _mthe, ажив,
  { {0xdb16001b,0x656b00e5,0x3f856695,0x00000000}},	//   _duyê, migh, tolu_,
  { {0x69c50034,0x93970032,0x656b17d5,0x00000000}},	//   _othe, _إجرا, ligh,
  { {0x644b172a,0xdb1d00b9,0x63bc00c2,0x00000000}},	//   lygi, opsæ, _črni,
  { {0x3f85448b,0xdb160013,0xb87b0139,0x00000000}},	//   solu_, _guyê, _ndío,
  { {0x69c55176,0x6b4b004d,0x3942008f,0x00000000}},	//   _athe, _zügi, _roks_,
  { {0xfc030085,0xbebc0023,0x68f600a3,0x00000000}},	//   ўпро, adīb, wgyd,
  { {0x6d9d0025,0xa96a1001,0xfaa63821,0x00000000}},	//   féad, вива_, раво,
  { {0x26da0035,0xdb16008b,0x69c10025,0x00000000}},	//   wapo_, _xuyê, ílea,
  { {0x26da5552,0xe766000d,0x656b018c,0x00000000}},	// [db00] tapo_, авап, digh,
  { {0x6d440019,0x7f4300c6,0x644b002b,0x00000000}},	//   _hoia, _jonq, dygi,
  { {0x67020161,0x39420006,0x8675000d,0x00000000}},	//   र्षक_, _toks_, быцц,
  { {0x656b264d,0x6d9d0139,0x6d40004b,0x00000000}},	//   gigh, réag, ömah,
  { {0x6b4b0019,0x9836000d,0xe45a0062,0x00000000}},	//   _sügi, _тэні, ъжд_,
  { {0x656b0025,0x6d44003b,0x23e50054,0x00000000}},	//   aigh, _loia, сіїв,
  { {0x6d5600ea,0x27e02ed6,0xe5a60893,0x00000000}},	//   _olya, lsin_, _виви,
  { {0xdb16001b,0x26d81269,0x60db008f,0x00000000}},	//   _quyê, _hero_, gaum,
  { {0x27e06696,0xe3aa35e0,0x25b80168,0x00000000}},	//   nsin_, _акад_, _hurl_,
  { {0x75206697,0x27e06698,0x26d800ae,0x00000000}},	//   _hamz, isin_, _jero_,
  { {0xdb16001b,0x6b500137,0x44260419,0x00000000}},	//   _tuyê, _vägl, lvo_,
  { {0xa2ca0161,0xdcbb005a,0x75226369,0x00000000}},	//   _स्त्, ъщо_, ndoz,
  { {0x6b5000bd,0x6d9d0025,0xae43007e,0x00000000}},	//   _tägl, véad, مپیو,
  { {0x26d831a2,0x656b6699,0x4426669a,0x00000000}},	//   _nero_, zigh, ivo_,
  { {0xbcfb0003,0x4f9b0063,0x6d5605e7,0x00000000}},	//   diév, _שבוצ, _flya,
  { {0x4426017f,0x6d44017d,0x644b0050,0x00000000}},	//   kvo_, _goia, yygi,
  { {0xd6db0472,0x656b08ad,0x26d86097,0x00000000}},	// [db10] вте_, vigh, _bero_,
  { {0xcdd4014e,0x26d8669b,0x656b0c5f,0x00000000}},	//   ֶךְ_, _cero_, wigh,
  { {0x60db0164,0x69c5669c,0x442621b7,0x00000000}},	//   yaum, _uthe, evo_,
  { {0xeb9f00b9,0x26d80b49,0x6d96013d,0x00000000}},	//   stød_, _eero_, jáal,
  { {0x4429669d,0x27e002b5,0xd7e4013c,0x00000000}},	//   ía_, csin_, _міро,
  { {0x656b015e,0xb8ca0053,0x67d4232e,0x00000000}},	//   sigh, गे_, _фору,
  { {0x442600eb,0x9207001c,0x656b0d02,0x00000000}},	//   avo_, ksāš, pigh,
  { {0xc69200b5,0x9a780063,0xf8bf006d,0x00000000}},	//   _זאל_, יתוף_, _inés_,
  { {0x60db3cb5,0x65690035,0xe8d90013,0x00000000}},	//   raum, _imeh, ghỉ_,
  { {0xf2070088,0x26c12e47,0xdce6005f,0x00000000}},	//   _вядо, ncho_, rikč,
  { {0x22950032,0xb87b0080,0x26c137c9,0x00000000}},	//   _الاس, _sdíl, icho_,
  { {0x27e000fe,0x8d5613d3,0x9f5f006c,0x00000000}},	//   ysin_, сточ, itué_,
  { {0x69c10080,0xd4790047,0x6d444498,0x00000000}},	//   ílen, ראָל, _voia,
  { {0xaa460abb,0x316d5f08,0xcb76005e,0x00000000}},	//   бегл, liez_, сумњ,
  { {0x27e05dcb,0x6d4400dd,0xfbd2005d,0x00000000}},	//   wsin_, _toia, _کتب_,
  { {0x26c1006d,0x44260078,0x316d0a2c,0x00000000}},	//   echo_, yvo_, niez_,
  { {0x26d8669e,0x7520669f,0xd94316fc,0x00000000}},	// [db20] _pero_, _ramz, чети,
  { {0x65690035,0x27e066a0,0x9b460043,0x00000000}},	//   _ameh, rsin_, _طنجو,
  { {0x26d866a1,0x14c8007e,0x27e06000,0x00000000}},	//   _vero_, لهای_, ssin_,
  { {0x38bd00ea,0x75890086,0x661c00a8,0x00000000}},	//   _váró_, асів_, _vsrk,
  { {0x44265c19,0x6d9d0025,0x316d66a2,0x00000000}},	//   uvo_, léac, diez_,
  { {0x8c1b0063,0x442666a3,0xf756043e,0x00000000}},	//   טוני, rvo_, _انسج,
  { {0x316d0164,0x6d9d0027,0x9f5f0164,0x00000000}},	//   fiez_, néac, ctué_,
  { {0x39400fd1,0x20540062,0x3952005f,0x00000000}},	//   njis_, жкия, nkys_,
  { {0x6d9d0025,0x25bf007d,0xdb0d0014,0x00000000}},	//   héac, _čuli_, _otað,
  { {0xdbd40871,0x5457009a,0xb356005d,0x00000000}},	//   _núñe, _הסמן_, _دیتا_,
  { {0xab5b0555,0x6f230044,0x00000000,0x00000000}},	//   nqüe, سَّن,   ,
  { {0x25a6001f,0x06970063,0xbcfb013d,0x00000000}},	//   nmol_, מדים_, lnéz,
  { {0xed58000d,0x7c870054,0x2cad004b,0x00000000}},	//   соў_, суне, äed_,
  { {0x139b0047,0x38600089,0x0eba02dc,0x00000000}},	//   ָבלע, dzir_, _суды_,
  { {0x6d9d0164,0x9985004c,0x60cd00dd,0x00000000}},	//   réab, ílů_, _înmâ,
  { {0x5887030b,0x00000000,0x00000000,0x00000000}},	//   быза,   ,   ,
  { {0x7d0d00a4,0x20040066,0xab5b04a5,0x00000000}},	// [db30] _ibas, ntmi_, eqüe,
  { {0x2d8b0290,0x26c166a4,0x65690077,0x00000000}},	//   loce_, ucho_, _smeh,
  { {0x3f52003b,0x7c21008f,0xd4b92a21,0x00000000}},	//   _râul_, ālru, алец_,
  { {0xbcfb03b2,0x2d8b1d4b,0x20040066,0x00000000}},	//   ciét, noce_, ktmi_,
  { {0xdb1d0140,0x316d0003,0xdce6001c,0x00000000}},	//   ppsä, viez_, nikā,
  { {0xbcfb00ea,0x2d6800ea,0x232908b9,0x00000000}},	//   gnéz, tőek_, роки_,
  { {0x316d0003,0x3ce9004b,0x5afc0041,0x00000000}},	//   tiez_, _odav_, אלוצ,
  { {0x7c2d1386,0x65690035,0xbfc5065b,0x00000000}},	//   _orar, _umeh, обик,
  { {0x316d0164,0x29090035,0xf94a0047,0x00000000}},	//   riez_, ifaa_, שעפֿ,
  { {0xddc800ea,0x7d0d66a5,0x316d0003,0x00000000}},	//   ezdő, _abas, siez_,
  { {0x6da6000a,0x316d0164,0xe8d9008b,0x00000000}},	//   жина, piez_, ghị_,
  { {0xdb0d0ac6,0xdce6003d,0x63bb35ac,0x00000000}},	//   _stað, fikā, _kuun,
  { {0x63bb0019,0xbcfb3cf3,0x442d004d,0x00000000}},	//   _juun, viét, _jre_,
  { {0x7d0d0019,0x63bb66a6,0x1fa7089d,0x00000000}},	//   _ebas, _muun, _урег,
  { {0x6d5d0025,0x7c2d66a7,0x2d8b004c,0x00000000}},	//   bhsa, _erar, boce_,
  { {0x6d9d0025,0xae780304,0x7c2d66a8,0x00000000}},	//   réac, _усіх_, _frar,
  { {0xbcfb0164,0x97da0121,0x574624cc,0x00000000}},	// [db40] riét, рьбу_, онаб,
  { {0x9696000a,0xa696007b,0xe73a005e,0x00000000}},	//   ореш, ореј, јеж_,
  { {0x442d0034,0x63bb00a4,0xe61a14cd,0x00000000}},	//   _are_, _auun, рде_,
  { {0x7546000d,0xa50a293a,0x69ce66a9,0x00000000}},	//   ўндз, реда_, mpbe,
  { {0x2480005b,0x25a6258b,0x9f4d0871,0x00000000}},	//   çim_, rmol_, nteó_,
  { {0x442d162d,0x7996125d,0x53330002,0x00000000}},	//   _dre_, llyw, дешт,
  { {0x98a20006,0x442d66aa,0xdce6008f,0x00000000}},	//   _kokį_, _ere_, zikā,
  { {0x442d0246,0x463b0041,0x799600a3,0x00000000}},	//   _fre_, _דעלע, nlyw,
  { {0x442d00c3,0xc05a0086,0xb0a40053,0x00000000}},	//   _gre_, рій_, खेंग,
  { {0xf8370063,0xceba01ce,0xf2a6012c,0x00000000}},	//   קנית_, шљи_, _дизп,
  { {0x2004018a,0xb4ab0026,0xdd95000d,0x00000000}},	//   stmi_, _íþró, заны,
  { {0x7c2d0498,0xd00a0086,0xdce6008f,0x00000000}},	//   _prar, _веде_, tikā,
  { {0x98b3001c,0x3e55008b,0x9f5f00cd,0x00000000}},	//   ādīt_, át_, ctuï_,
  { {0x2d8b22b6,0xdce6001c,0x7053014d,0x00000000}},	//   soce_, rikā, _تنها,
  { {0xbcfb0164,0x2bb70042,0x6e630062,0x00000000}},	//   théd, _इंका, _отъж,
  { {0x3f8c003d,0x7c2d66ab,0x27f2001f,0x00000000}},	//   lodu_, _trar, fryn_,
  { {0xe8940121,0xbcfb0331,0x27f2002b,0x00000000}},	// [db50] дать, biér, gryn_,
  { {0x4e1e0053,0x8af9005e,0x442d013d,0x00000000}},	//   _बनाई_, _унос_, _rre_,
  { {0x672500d1,0x63bb037e,0x442d66ac,0x00000000}},	//   rdhj, _suun, _sre_,
  { {0x442d66ad,0x63bb0072,0xa923017c,0x00000000}},	//   _pre_, _puun, ážde,
  { {0xbcfb0164,0xdb04006d,0x69da003b,0x00000000}},	//   chée, _guió, âtev,
  { {0xfc3f0268,0x442d00dd,0x3e55008d,0x00000000}},	//   ixí_, _vre_, ýt_,
  { {0x94d50001,0xa4d5013c,0x2d6f004c,0x00000000}},	//   _новц, _нові, vřen_,
  { {0x6b500019,0x442d50bc,0xdcfd001c,0x00000000}},	//   _vägi, _tre_, ilsē,
  { {0x24580076,0x442d66ae,0x69c10080,0x00000000}},	//   _дать_, _ure_, ílej,
  { {0xf8b80053,0x249f0130,0x9e654454,0x00000000}},	//   _अल्प, _izum_, звод,
  { {0xc7b4014e,0x27f20089,0x2277007e,0x00000000}},	//   ובץ_, zryn_, _بلاگ_,
  { {0x670b0053,0x070b0053,0xe29a0063,0x00000000}},	//   स्तक_, स्तव_, _השער,
  { {0x9f350086,0x2d6f004c,0xbcfb05ab,0x00000000}},	//   _неді, mřel_, tiér,
  { {0x3b0a005e,0xef180023,0x00000000,0x00000000}},	//   љево_, ceļ_,   ,
  { {0xb87b02dd,0xc3320063,0xbcfb66af,0x00000000}},	//   _leíd, עול_, riér,
  { {0x27f20051,0xa9670187,0xd9431321,0x00000000}},	//   tryn_, писа_, неси,
  { {0x27e60003,0x7996002b,0x1dd70042,0x00000000}},	// [db60] éon_, rlyw, भीरत,
  { {0xf7720032,0xd7ef0021,0x2ca000c2,0x00000000}},	//   راء_, اكل_, _izid_,
  { {0x98a20006,0x14ca0076,0x7abb0063,0x00000000}},	//   _tokį_, были_, _לציו,
  { {0x35690086,0x6d9d14bd,0xbcfb0003,0x00000000}},	//   орін_, héan, phée,
  { {0x999e0078,0x32070022,0xab5b013d,0x00000000}},	//   štų_, etny_, mpür,
  { {0x67030053,0x421a0021,0x229404d6,0x00000000}},	//   _लायक_, مزعج_, миля,
  { {0x07a30088,0x6d9d0025,0x3f8c51c0,0x00000000}},	//   _чарн, déan, vodu_,
  { {0x3f8c0051,0x867b0063,0xc03402d8,0x00000000}},	//   wodu_, _הרלו, дниј,
  { {0x7ff60021,0x6b50004b,0x3f8c66b0,0x00000000}},	//   أسعا, _hägu, todu_,
  { {0x20ec001b,0x3eb80205,0x7413007e,0x00000000}},	//   ới_, ørt_, _سوما,
  { {0x3f8c3ce2,0x00000000,0x00000000,0x00000000}},	//   rodu_,   ,   ,
  { {0x75c50078,0x5bb50042,0xa3e00042,0x00000000}},	//   _jėza, ंद्व, _दबा_,
  { {0xdb07013d,0xe16500de,0x00000000,0x00000000}},	//   lmjé, _تدلي,   ,
  { {0x6d9d3a7d,0x90530085,0x6d400072,0x00000000}},	//   céan, _явіц, ömar,
  { {0xf402000c,0x6e93050f,0x6b50004b,0x00000000}},	//   luţă_, _пишу, _nägu,
  { {0x69c80516,0x99990e74,0x7e7b009a,0x00000000}},	//   ídea, ікат_, _לאוז,
  { {0x57b522ce,0x5c740062,0xb8d50042,0x00000000}},	// [db70] дбат, _плът, _छः_,
  { {0xb8f40053,0x64d50053,0xa03b0047,0x00000000}},	//   _स्_, दर्श, זעמפ,
  { {0x74b90062,0xdb040331,0x249f0022,0x00000000}},	//   оулс_, _guiñ, _szum_,
  { {0x7f9400cd,0xceb303c3,0xa4d50054,0x00000000}},	//   màqu, גיע_, фоді,
  { {0xe454000d,0x6b500137,0x2d6f004c,0x00000000}},	//   нкцы, _vägv, vřel_,
  { {0x9735007e,0xe78706b4,0x26c5004b,0x00000000}},	//   _تکرا, _хумо, _ülo_,
  { {0x6fd50161,0x22540024,0xd56721f2,0x00000000}},	//   _मौजू, _čaká_, _етап,
  { {0x394b0268,0x659420fb,0xefc9182e,0x00000000}},	//   _jocs_, _засу, олил_,
  { {0x320716bb,0x394b155f,0x7bcd0023,0x00000000}},	//   stny_, _mocs_, _ntau,
  { {0xbebc001c,0x4ed40086,0x337402fe,0x00000000}},	//   ldīj, нюют, _згур,
  { {0x7bcd1169,0x6727004b,0x2d6f004c,0x00000000}},	//   _atau, _majj, přel_,
  { {0xed5720fb,0x90550054,0x31a400de,0x00000000}},	//   дою_, _овец, _كملف,
  { {0xf40200dd,0xbebc0023,0x1c430505,0x00000000}},	//   cuţă_, idīj, вням,
  { {0x6d9d0025,0x2d99152e,0x672766b1,0x00000000}},	//   léal, alse_, _najj,
  { {0x394b001f,0x2018003b,0x7bcd0014,0x00000000}},	//   _bocs_, ărie_, _etau,
  { {0x61ee01e1,0x6d9d228a,0x24920022,0x00000000}},	//   _æble, néal, żymi_,
  { {0x60dd0026,0x394b66b2,0x3b8618ea,0x00000000}},	// [db80] ósmy, _docs_, _олиг,
  { {0xbcfb0025,0x6d460b59,0xab5b0244,0x00000000}},	//   mhéa, ljka, spür,
  { {0x5b57009a,0xd5b20021,0xe5c50086,0x00000000}},	//   _חייב_, نفط_, есіо,
  { {0x6d4608ea,0x6e2300e5,0x6f1a0130,0x00000000}},	//   njka, _msnb, zetc,
  { {0x2776000d,0x68e466b3,0xd38a0054,0x00000000}},	//   _жывё, maid, ойде_,
  { {0x290066b4,0xbebc001c,0x68e466b5,0x00000000}},	//   lgia_, adīj, laid,
  { {0x65c30088,0x2900004b,0xddc80022,0x00000000}},	//   _абса, ogia_, zydł,
  { {0x29004fae,0x68e466b6,0x46a3007b,0x00000000}},	//   ngia_, naid, _расв,
  { {0xdb1d0031,0xe5710132,0x73060f92,0x00000000}},	//   ppsø, _עַל_, _опаз,
  { {0x68e40027,0x03260086,0xbcfb0139,0x00000000}},	//   haid, _іден, dhéa,
  { {0x6b5000c7,0x6f1a0034,0xf402003b,0x00000000}},	//   _lägs, retc, suţă_,
  { {0xc0a9006a,0x7f9400cd,0x68e40441,0x00000000}},	//   _کامل_, vàqu, jaid,
  { {0xf1c4016a,0xe0432254,0x718b0063,0x00000000}},	//   _लंडन, _инци, _וְגַ,
  { {0xfe6f006a,0x44242075,0xccf90022,0x00000000}},	//   ادی_, _msm_, óśb_,
  { {0x394b0268,0x44241140,0x68e40025,0x00000000}},	//   _pocs_, _lsm_, faid,
  { {0x290066b7,0xbcfb0025,0x44240080,0x00000000}},	//   ggia_, bhéa, _osm_,
  { {0xbcfb0003,0x4735000d,0xe8d90013,0x00000000}},	// [db90] chéa, ннас, ghề_,
  { {0x70bb0053,0x7d1d6416,0x00000000,0x00000000}},	//   _उल्ल, less,   ,
  { {0xfad6014e,0x7afa0014,0x6b500137,0x00000000}},	//   _אותך_, ótte, _vägt,
  { {0xbebc008f,0x68e466b8,0x31a1017c,0x00000000}},	//   udīj, caid, kóza_,
  { {0x9475007e,0xc7c40121,0x442466b9,0x00000000}},	//   رگرا, _асси, _csm_,
  { {0x7d1d66ba,0x27e900a5,0x44241fad,0x00000000}},	//   hess, msan_, _dsm_,
  { {0x07a40088,0x41b5065b,0x44241d2a,0x00000000}},	//   _раён, нсит, _esm_,
  { {0x65620035,0x27e90072,0xdb0a004c,0x00000000}},	//   choh, osan_, ěnéh,
  { {0x27e966bb,0xa2ca0053,0x7d1d66bc,0x00000000}},	//   nsan_, _स्क्, dess,
  { {0x6b5000c7,0x68e40089,0x7d041b2d,0x00000000}},	//   _lägr, zaid, _scis,
  { {0x52380021,0x753b01e1,0x7d1d0e97,0x00000000}},	//   _يسمح_, _knuz, fess,
  { {0x27e966bd,0xbcfb0025,0xb883027d,0x00000000}},	//   ksan_, théa, olíč,
  { {0xdfd10021,0x636d0022,0x68e466be,0x00000000}},	//   _صيغ_, eźni, vaid,
  { {0x68e40009,0x70760047,0x60c91ff0,0x00000000}},	//   waid, _אײנע_, lcem,
  { {0x290000cd,0x27e90360,0x1d960121,0x00000000}},	//   tgia_, esan_, _приё,
  { {0xb87b0139,0x7d1d0e5c,0xeb9f01e1,0x00000000}},	//   _ndís, cess, ntøj_,
  { {0x60c966bf,0xd7f90086,0x9f4d00cd,0x00000000}},	// [dba0] icem, дує_, oreà_,
  { {0x68e40009,0x6b500137,0x3a2601dd,0x00000000}},	//   said, _vägs, _змог,
  { {0xeb9f0146,0x27e9003e,0x68e466c0,0x00000000}},	//   ktøj_, asan_, paid,
  { {0x2ee5077d,0xd4060054,0xf3e6030b,0x00000000}},	//   half_, еяки, еждо,
  { {0xb87b0016,0x6562004d,0x88bb0063,0x00000000}},	//   _veíc, rhoh, _מזכי,
  { {0xf487007e,0x7d1d66c1,0x08770047,0x00000000}},	//   رانی, zess, _װעלט_,
  { {0x75290089,0x7d1d58f4,0xa22702f8,0x00000000}},	//   _faez, yess, ежја_,
  { {0xdcef008f,0x72290054,0xb6370063,0x00000000}},	//   rocī, ьців_, _ארלס_,
  { {0xd007000a,0x44240222,0x251b0047,0x00000000}},	//   еење_, _usm_, _צומא,
  { {0xd47b0047,0x636d0022,0x31a10445,0x00000000}},	//   _זאמל, yźni, róza_,
  { {0x26c7017f,0xdce60078,0x7d1d11cc,0x00000000}},	//   žnog_, likę, tess,
  { {0x27e966c2,0x63ba5935,0x7d1d1806,0x00000000}},	//   ysan_, _hitn, uess,
  { {0x7c840189,0x7d1d17ec,0x0ca81122,0x00000000}},	//   гуре, ress, етри_,
  { {0x7d1d66c3,0x61f800ca,0x99d70021,0x00000000}},	//   sess, orvl, فترا,
  { {0xe3b30047,0x7d1d66c4,0x39a75ccb,0x00000000}},	//   טױש_, pess, ешав,
  { {0x19940062,0x0e9b0063,0x629a2a2a,0x00000000}},	//   гася, _משול, _myto,
  { {0x60dd0026,0x6b500137,0x27e91462,0x00000000}},	// [dbb0] ðsmi, _vägr, usan_,
  { {0xb883004c,0x27e93b0e,0x63ba00a8,0x00000000}},	//   vlíč, rsan_, _nitn,
  { {0x27e966c5,0x3a740121,0xf7480021,0x00000000}},	//   ssan_, _блэр, علمي_,
  { {0x7ae714d5,0xdced00c2,0xa3d5007f,0x00000000}},	//   lajt, _omač, водч,
  { {0x63ba027c,0x2fc00025,0x2458000d,0x00000000}},	//   _bitn, _éigh_, наць_,
  { {0x39493226,0x7ae70ffb,0xe29966c6,0x00000000}},	//   ljas_, najt, мал_,
  { {0x629a5cba,0x6352018e,0x39490460,0x00000000}},	//   _cyto, рвју, ojas_,
  { {0x56941a58,0x394966c7,0x7ae766c8,0x00000000}},	//   _саст, njas_, hajt,
  { {0x386902dd,0x60060076,0x7ed50086,0x00000000}},	//   nzar_, вным_, кінч,
  { {0x63ba002c,0x7ae7082a,0xdb170003,0x00000000}},	//   _gitn, jajt, _fixé,
  { {0x7ae766c9,0x6d5f0078,0xa2ca0053,0x00000000}},	//   dajt, _įpar, _स्ट्,
  { {0x6e3c0137,0x2127005d,0xed5a224c,0x00000000}},	//   årba, _سيتی_, фом_,
  { {0x644f00cd,0x5d670121,0x0d830ddf,0x00000000}},	//   _àcid, тиям_, рлян,
  { {0x7ae700c3,0x3949008f,0xd83838d3,0x00000000}},	//   gajt, ejas_, _čč_,
  { {0x1ae30076,0xbcfb0164,0x499625dc,0x00000000}},	//   росм, chéo, вшат,
  { {0x6d960014,0x9627008f,0x00000000,0x00000000}},	//   ráas, ieņē,   ,
  { {0xcc8a007e,0x7ae7389e,0xa6e70013,0x00000000}},	// [dbc0] _زنده_, bajt, _thừ,
  { {0x7bfb014e,0xcb6a006a,0x44380080,0x00000000}},	//   _קפיצ, _آمده_, _čr_,
  { {0xb87b006d,0xf50a0002,0xd245007e,0x00000000}},	//   _veía, днел_, _اچ_,
  { {0x63ba0f74,0x629a0078,0xceb20063,0x00000000}},	//   _sitn, _ryto, ביב_,
  { {0x14270054,0x938a0571,0x2d8266ca,0x00000000}},	//   віщо_, мска_, inke_,
  { {0x61ea080f,0x232702d8,0x9f4e0075,0x00000000}},	//   tsfl, вољи_, ünüp_,
  { {0x29120035,0xdd020080,0x63ba55a7,0x00000000}},	//   ofya_, ítěz, _vitn,
  { {0x63ba0034,0xc05a0086,0x2d54017d,0x00000000}},	//   _witn, діо_, _mães_,
  { {0x63ba0078,0x50b7005d,0x5f940cb2,0x00000000}},	//   _titn, پديد_, лиит,
  { {0x7d160080,0x63ba04c6,0x9f530121,0x00000000}},	//   _abys, _uitn, ивыч,
  { {0x7ae70d58,0x200d45ca,0x7d1b004b,0x00000000}},	//   vajt, atei_, õuso,
  { {0xdb160026,0xc69300ff,0x11e900de,0x00000000}},	//   _styð, יאת_, _أعلي_,
  { {0x7ae766cb,0xed58000d,0x6d9d228a,0x00000000}},	//   tajt, тоў_, néai,
  { {0x69c300ea,0x2d8251e4,0xceb80078,0x00000000}},	//   _ének, anke_, udęs_,
  { {0xe9190086,0x2d54017d,0xda78042c,0x00000000}},	//   нові_, _cães_, вят_,
  { {0x38690994,0x3f9e5be1,0x7ae766cc,0x00000000}},	//   tzar_, lltu_, sajt,
  { {0x39491a8a,0x9715290b,0x7ae7085a,0x00000000}},	// [dbd0] rjas_, лмац, pajt,
  { {0x3869076d,0x3949004b,0xf7700593,0x00000000}},	//   rzar_, sjas_, يال_,
  { {0x38690051,0x3f9e0014,0x645604aa,0x00000000}},	//   szar_, iltu_, øyin,
  { {0xe0df0013,0x6d5d1dd3,0xa8a70085,0x00000000}},	//   ưòi_, nksa, _аргк,
  { {0x7ae50004,0x24890016,0x69c50035,0x00000000}},	//   _keht, çam_, _huhe,
  { {0xb4640086,0x42094ba8,0x59da0053,0x00000000}},	//   шкіл, енко_, यीकर,
  { {0x69c50019,0x96f8005e,0x6d5d04aa,0x00000000}},	//   _juhe, _јест_, kksa,
  { {0x3216007e,0x6232005e,0x3abc0063,0x00000000}},	//   اييد_, сећу, ומונ,
  { {0x6d9d0025,0xd00e0044,0xbd04011b,0x00000000}},	//   céai, كلي_, nkéř,
  { {0x200d66cd,0xd25b14b4,0x6d5d66ce,0x00000000}},	//   rtei_, _оце_, eksa,
  { {0x200d0529,0x1d0a005a,0xf204000d,0x00000000}},	//   stei_, нени_, _вячо,
  { {0x200d003b,0x925804d6,0x6abe0042,0x00000000}},	//   ptei_, _шахт_, ्ड्र,
  { {0xff53007e,0x60db1848,0x3af60505,0x00000000}},	//   _پخش_, mbum, лявс,
  { {0xdfcf006a,0x6d5d5389,0x60db66cf,0x00000000}},	//   _هيچ_, ërar, lbum,
  { {0x6459002b,0xd93a01ce,0x00000000,0x00000000}},	//   hywi, нчаш_,   ,
  { {0x98a90024,0x98a0007d,0x6d5d66d0,0x00000000}},	//   adač_, ndić_, cksa,
  { {0x999e00ea,0xe73a007b,0x59c00042,0x00000000}},	// [dbe0] ítő_, неа_, _शंकर,
  { {0x64590051,0xab2a005e,0x9b460044,0x00000000}},	//   dywi, _џона_, _إندو,
  { {0x9bb70063,0x75d30021,0xceb2009d,0x00000000}},	//   _תהיה_, ميلا, ֖יב_,
  { {0x6459001f,0x4a7b069a,0xd9460867,0x00000000}},	//   fywi, _טריב, _семи,
  { {0x4d7b00b5,0xbebc001c,0xdcef003b,0x00000000}},	//   ערנע, ldīt, lică,
  { {0x533404f2,0x61e100a3,0xf8b3009a,0x00000000}},	//   рект, _bwll, _לשר_,
  { {0x3d050053,0xa79b0063,0xed610114,0x00000000}},	//   _वाले_, _נשלח, ážky_,
  { {0xbcfb0164,0xbebc001c,0x9f4d0072,0x00000000}},	//   thém, idīt, hreä_,
  { {0xa3cb0053,0xdb0e017d,0x7984002b,0x00000000}},	//   _रूप_, ambé, iniw,
  { {0x66e40053,0x141b07e9,0x30170021,0x00000000}},	//   गरिक_, _אומב, اتية_,
  { {0x3eb8142c,0x7ae50050,0x59b40082,0x00000000}},	//   ärt_, _reht, ंगार,
  { {0x69c500bd,0x6d5d00a4,0x44260051,0x00000000}},	//   _ruhe, uksa, owo_,
  { {0x5c07000d,0x6d5d66d1,0x55770047,0x00000000}},	//   ыяна, rksa, רעכן_,
  { {0xdcef0529,0x69c5024a,0x07030042,0x00000000}},	//   fică, _puhe, _लाइव_,
  { {0xab5b017d,0x64590051,0x8e37007e,0x00000000}},	//   nqüi, zywi, _مسير_,
  { {0x44260035,0x78d50062,0x58d53f5d,0x00000000}},	//   kwo_, ржах, роат,
  { {0x7ae50aba,0xb606007d,0xed580063,0x00000000}},	// [dbf0] _teht, _lišć, _תבחר_,
  { {0xf7730021,0xe8740593,0x98a00022,0x00000000}},	//   حار_, حافظ, ndię_,
  { {0x57a40376,0x9f4b013d,0x44260022,0x00000000}},	//   сшта, écé_, ewo_,
  { {0x60c266d2,0xb9350002,0xbebc008f,0x00000000}},	//   _ngom, _темј, ldīs,
  { {0xbcfb0003,0x0d160047,0x61e1002b,0x00000000}},	//   ckée, יקײט_, _swll,
  { {0x645966d3,0xc886004d,0x61e1002b,0x00000000}},	//   rywi, üßen_, _pwll,
  { {0x66180066,0x45d40121,0xe8d90013,0x00000000}},	//   čaká, _госс, ghệ_,
  { {0x8505005d,0xdb1c013d,0xfa78009a,0x00000000}},	//   _خورن, _özön, טעות_,
  { {0x8467011c,0xbfc20121,0x60db66d4,0x00000000}},	//   _съве, обык, rbum,
  { {0x2f5500d7,0x889c0047,0xee39079b,0x00000000}},	//   ртис, עבזי, вно_,
  { {0xc2c4006a,0x2fc6001f,0x7984001f,0x00000000}},	//   _ايمي, _euog_, yniw,
  { {0xa3a90042,0xbebc008f,0x318c004c,0x00000000}},	//   _गीत_, edīs, těze_,
  { {0xe50d0042,0x6ea10042,0xa3cb0042,0x00000000}},	//   _हानि_, _ऑरकु, _रूम_,
  { {0x98a20051,0x60c2003b,0x68e666d5,0x00000000}},	//   _jaką_, _zgom, _sekd,
  { {0x09e61099,0xb976000a,0xbebc001c,0x00000000}},	//   робн, аѓањ, udīt,
  { {0xdcef003b,0xdb07009c,0x442666d6,0x00000000}},	//   rică, rmjá, ywo_,

  { {0x7c950085,0xa6e602fa,0x00000000,0x00000000}},	// [dc00] _грэц, ижал,   ,
  { {0x7c29005b,0xdb24005d,0xfc5b009a,0x00000000}},	//   çere, _اودی, _סכימ,
  { {0x5afb00b5,0xbcfb04aa,0x59a70042,0x00000000}},	//   _בליצ, skée, _कीवर,
  { {0xe45a0055,0x44260045,0x61fc1781,0x00000000}},	//   кже_, two_, _årli,
  { {0xa533000d,0x60c201f4,0x394266d7,0x00000000}},	//   ўніч, _rgom, _inks_,
  { {0x60c20290,0x442666d8,0x21f40044,0x00000000}},	//   _sgom, rwo_, مكتس,
  { {0x661c017f,0x25bf000c,0x63030021,0x00000000}},	//   _uprk, _fiul_, زويل,
  { {0xbcfb01d1,0x98a70022,0x25d7009a,0x00000000}},	//   chéh, śną_, _כולן_,
  { {0x7f9d0164,0xa4fb0063,0x34fb009a,0x00000000}},	//   hèqu, _שלמט, _שהמד,
  { {0x200b0268,0x38170063,0x3f130054,0x00000000}},	//   àcia_, סקים_, одьс,
  { {0xb7370047,0x0737089e,0x6e9444d5,0x00000000}},	//   בריװ_, באים_, сину,
  { {0xc27b009a,0x6143377f,0xc2550044,0x00000000}},	//   _ברבי, _меха, _اخْت,
  { {0xd007011c,0xff4f005d,0x7173005d,0x00000000}},	//   _вече_, سخی_, _بهنا,
  { {0x27170080,0x2004167e,0xbebc008f,0x00000000}},	//   _mění_, mumi_, udīs,
  { {0x200466d9,0xa9240066,0xaa54007b,0x00000000}},	//   lumi_, _žľaz, оврш,
  { {0x644d0072,0xb8d7005d,0x4dd30044,0x00000000}},	//   äaik, شترش, _بتوس,
  { {0x2d9966da,0xb6c76358,0x200466db,0x00000000}},	// [dc10] mose_, асей, numi_,
  { {0x7c2d0fe5,0x2d9966dc,0x3ce90168,0x00000000}},	//   _isar, lose_, _heav_,
  { {0x20040035,0xcf9300ff,0xc7b80121,0x00000000}},	//   humi_, קטע_, рёт_,
  { {0x200425fc,0x394d017d,0x2d9966dd,0x00000000}},	//   kumi_, _ões_, nose_,
  { {0x2004003d,0x48ab000a,0xb8dd0053,0x00000000}},	//   jumi_, _штом_, ेख_,
  { {0x68ed66de,0xc5fb0021,0x2717004c,0x00000000}},	//   laad, _لعرض_, _dění_,
  { {0x7d0d100f,0x926b0062,0x6d9d0003,0x00000000}},	//   _ocas, ърда_, néas,
  { {0x2d990006,0x7c2d09c9,0xbcfb0025,0x00000000}},	//   jose_, _osar, bhéi,
  { {0xf94a00b5,0x2d9966df,0x656b0025,0x00000000}},	//   רעפֿ, dose_, mhgh,
  { {0x442d5569,0x1f6507a1,0x7d0d66e0,0x00000000}},	//   _ise_, ском, _acas,
  { {0x68ed0019,0x66050089,0x7c2d66e1,0x00000000}},	//   kaad, nuhk, _asar,
  { {0x2d990006,0x01340021,0x63660014,0x00000000}},	//   gose_, _وعند, _iðna,
  { {0x68ed0019,0x6725069f,0x29f3007d,0x00000000}},	//   daad, kehj, eća_,
  { {0x66050397,0xb47a0047,0x1dcf0053,0x00000000}},	//   kuhk, אָלי, _संपत,
  { {0xdf74007e,0xa96a0062,0x2d994399,0x00000000}},	//   _بدنب, гива_, bose_,
  { {0x75c50006,0x442d66e2,0x2d9966e3,0x00000000}},	//   _jėzu, _ose_, cose_,
  { {0xdb1e0027,0x6d4466e4,0x6d9d0003,0x00000000}},	// [dc20] _lipé, _inia, réat,
  { {0x672500b9,0xa088009d,0x00000000,0x00000000}},	//   gehj, בְעִ,   ,
  { {0x6d56005b,0x66050397,0x442d66e5,0x00000000}},	//   _koya, guhk, _ase_,
  { {0xbcfb0025,0xe4e30086,0x6d5602ee,0x00000000}},	//   théi, пішн, _joya,
  { {0x69dc66e6,0x6d5666e7,0x59831a78,0x00000000}},	//   lpre, _moya, _хляб,
  { {0x66050228,0x27f210c4,0x69dc66e8,0x00000000}},	//   buhk, msyn_, opre,
  { {0x442d048e,0x27f243eb,0x69dc5d05,0x00000000}},	//   _ese_, lsyn_, npre,
  { {0xf126148d,0x6d560003,0x6d9d0025,0x00000000}},	//   сько, _noya, héar,
  { {0xa494006a,0x27f202ea,0x7054007e,0x00000000}},	//   _بیشت, nsyn_, زندا,
  { {0x543b00b5,0x6d4413d5,0x200466e9,0x00000000}},	//   _געמא, _ania, rumi_,
  { {0x2d990006,0xeb9f0205,0x69dc0599,0x00000000}},	//   tose_, ktør_, jpre,
  { {0x2d990006,0x27f200fe,0x5d6761a5,0x00000000}},	//   uose_, ksyn_, стоз,
  { {0x68ed0019,0x2d9966ea,0x6d440051,0x00000000}},	//   vaad, rose_, _dnia,
  { {0x2d990006,0x7aee004d,0x69dc004d,0x00000000}},	//   sose_, gabt, fpre,
  { {0x2d990399,0x69dc01bb,0x68ed66eb,0x00000000}},	//   pose_, gpre, taad,
  { {0x6d9d0027,0x984b0062,0x6d5666ec,0x00000000}},	//   réas, ляза_, _goya,
  { {0xb8d10161,0x69dc082a,0x7c2d3735,0x00000000}},	// [dc30] _ओर_, apre, _usar,
  { {0x660506c2,0x68ed0e39,0x7bdd0526,0x00000000}},	//   tuhk, saad, mpsu,
  { {0x69c80066,0x656b0139,0x672504aa,0x00000000}},	//   ídet, thgh, rehj,
  { {0x66051472,0x7bdd547f,0x442d66ed,0x00000000}},	//   ruhk, opsu, _pse_,
  { {0xe3b10049,0x6605004b,0x4375012c,0x00000000}},	//   ورت_, suhk, жуйт,
  { {0x442d0198,0x66050019,0x889a0063,0x00000000}},	//   _vse_, puhk, _כברי,
  { {0xa4d50085,0x94d5012c,0x93940044,0x00000000}},	//   _мові, _мовц, أجنا,
  { {0x34950785,0xf4870131,0x4a7c009a,0x00000000}},	//   _дабр, _лузн, טרוב,
  { {0x442d0860,0x6d5604bc,0xe454000d,0x00000000}},	//   _use_, _roya, _екты,
  { {0x2d8b000f,0x6d56005b,0x225c004c,0x00000000}},	//   ében_, _soya, ízká_,
  { {0x2f540054,0xd12e005d,0x9ea931d7,0x00000000}},	//   їтьс, رمی_, рвна_,
  { {0x69dc0198,0x75350047,0x35d00053,0x00000000}},	//   vpre, קאָד_, _तूफ़,
  { {0x9f350086,0x6d561cac,0x316d00ea,0x00000000}},	//   _меді, _voya, mhez_,
  { {0x316d00ea,0x3b0a005e,0x69dc66ee,0x00000000}},	//   lhez_, јево_, tpre,
  { {0xa3cb0053,0xbcfb00ea,0x6569017e,0x00000000}},	//   _रूस_, mkén, _oleh,
  { {0xdce40ae1,0x316d00ea,0x69dc1a9a,0x00000000}},	//   _klič, nhez_, rpre,
  { {0x69dc66ef,0x06ea0001,0x3ff90047,0x00000000}},	// [dc40] spre, имак_, יפּע,
  { {0xbf87001b,0xbcfb000f,0x27f266f0,0x00000000}},	//   _điện_, nkén, rsyn_,
  { {0x20180529,0xdd8f006a,0x316d000f,0x00000000}},	//   ării_, _سوی_, khez_,
  { {0x394f0137,0x6b9c02c0,0x6562004b,0x00000000}},	//   ögst_, lorg, ukoh,
  { {0x6b9c0179,0xeb9f05b9,0x200b01a8,0x00000000}},	//   oorg, brød_, àcil_,
  { {0x47c3011c,0x69c30164,0x6562037e,0x00000000}},	//   _обяв, _éner, skoh,
  { {0x416a0001,0xe1ef0021,0x29e8095a,0x00000000}},	//   ијим_, نسي_, nşa_,
  { {0xdced007d,0x316d66f1,0xa50709c8,0x00000000}},	//   _imać, ghez_, _меса_,
  { {0x6b9c00c7,0x7f4a0086,0xe5a30713,0x00000000}},	//   korg, аїна_, _цити,
  { {0x25a6001f,0xbcfb013d,0xdce400a8,0x00000000}},	//   llol_, gkén, _dlič,
  { {0xe8a70053,0x52860021,0x6b9c337d,0x00000000}},	//   _खर्च, _بلاك, dorg,
  { {0xd130007e,0x316d3380,0x3d270086,0x00000000}},	//   _سمت_, chez_, цьов,
  { {0x0cab08b0,0x5c74030b,0x6b9c66f2,0x00000000}},	//   ртни_, длят, forg,
  { {0xa3b00053,0x99d70021,0x7bdd008f,0x00000000}},	//   _टीम_, قترا, rpsu,
  { {0x0eba000d,0xda340183,0x49bb02da,0x00000000}},	//   _туды_, меры, لارد_,
  { {0x65a30019,0x9bf50062,0x26c70066,0x00000000}},	//   põhi, _езич, ľnom_,
  { {0x6b9c66f3,0x26c70ffb,0x69c800ed,0x00000000}},	// [dc50] borg, žnom_, íder,
  { {0x5a470088,0x6b9c0290,0xb9020053,0x00000000}},	//   _дэма, corg, _न्_,
  { {0xcb120063,0x61e8002b,0x8f9b009a,0x00000000}},	//   _אלי_, _nwdl, סיבי,
  { {0x8aa4000d,0xbcfb4ed9,0x057401fb,0x00000000}},	//   _юрыд, chét, واند,
  { {0x7bc53287,0xb4270021,0x2d8b66f4,0x00000000}},	//   _kihu, تعاو, ince_,
  { {0xdb0e0139,0xd8ba0063,0xc5db0021,0x00000000}},	//   ombá, _לצרכ, _نظرا_,
  { {0xdce41181,0x316d00ea,0x7afa0014,0x00000000}},	//   _slič, thez_, ótti,
  { {0x657b0035,0x6b9c66f5,0x7bc50526,0x00000000}},	//   _umuh, zorg, _lihu,
  { {0x443966f6,0xbcfb00ea,0x7ff50021,0x00000000}},	//   _és_, tkén, أسبا,
  { {0x316d000f,0x39592d54,0x2d8b04bc,0x00000000}},	//   shez_, _loss_, ence_,
  { {0x6b9c0b64,0xada60062,0xbcfb013d,0x00000000}},	//   vorg, занл, rkén,
  { {0xbcfb66f7,0x443f66f8,0xb6ab000d,0x00000000}},	//   skén, _kru_, ымiн,
  { {0x98a70080,0x212a007e,0x7bcd258b,0x00000000}},	//   ěně_, _دينی_, _cuau,
  { {0xd00e0032,0x26c7017f,0x00560063,0x00000000}},	//   _صلى_, žnoj_, _משנת_,
  { {0x7bc5053b,0x0a390076,0xbcfb0003,0x00000000}},	//   _dihu, очты_, thét,
  { {0x3946048e,0x7d1b004b,0x6b9c66f9,0x00000000}},	//   ños_, õust, sorg,
  { {0x2d8266fa,0x3b0a02d8,0x2bd8007e,0x00000000}},	// [dc60] mike_, _лепо_, _بابک_,
  { {0x2d8266fb,0x7c2400be,0xe6c60021,0x00000000}},	//   like_, _ipir, ستطي,
  { {0x443f0019,0xbcfb0003,0x38600150,0x00000000}},	//   _aru_, phét, syir_,
  { {0x994a0021,0x2d8266fc,0xe6930593,0x00000000}},	//   _الحل_, nike_, رلند,
  { {0x27ee02f4,0xdce6003d,0xe8030053,0x00000000}},	//   álně_, dokļ, _लिया_,
  { {0x27e00e53,0xfbd30063,0x2d8266fd,0x00000000}},	//   mpin_, עתו_, hike_,
  { {0x443f0ac6,0x26ca66fe,0x2d82004b,0x00000000}},	//   _eru_, _igbo_, kike_,
  { {0xdc3f003b,0xb3ca0121,0x68e4006f,0x00000000}},	//   nţăr, _глаз_, nbid,
  { {0x68e408be,0x636f06a5,0xb466000d,0x00000000}},	//   ibid, _bønd, _экал,
  { {0x9df8000a,0x69c666ff,0x138a0021,0x00000000}},	//   онот_, _like, _اخرى_,
  { {0x69c6024a,0x7bcd0006,0xdd95000d,0x00000000}},	//   _oike, _suau, даны,
  { {0x160d0161,0x44240089,0x27e008f2,0x00000000}},	//   ांतर_, _kpm_, kpin_,
  { {0x7bc50019,0x44241aff,0x395925cb,0x00000000}},	//   _pihu, _jpm_, _ross_,
  { {0xddda000f,0x7fb8007e,0x68e4006d,0x00000000}},	//   sztő, _بهتر_, ebid,
  { {0x44240089,0x98a90022,0x673508ed,0x00000000}},	//   _lpm_, odać_, _razj,
  { {0x6da4018e,0xfc4a0080,0x39a40002,0x00000000}},	//   _пија, _spíš_, ешув,
  { {0x69c608f0,0xa2bc0161,0x636f069f,0x00000000}},	// [dc70] _dike, षेत्, _høne,
  { {0x3f8c0026,0x69c60821,0x3f9e6700,0x00000000}},	//   nndu_, _eike, notu_,
  { {0xda670242,0x44246701,0x6d4011f5,0x00000000}},	//   _رادي, _apm_, ômag,
  { {0x443f00e3,0x3f9e0cff,0x984b0094,0x00000000}},	//   _pru_, hotu_, _ляга_,
  { {0x98ab0469,0x2409019d,0x3f9e001c,0x00000000}},	//   _dacă_, інки_, kotu_,
  { {0x2d823730,0x8c1c07e9,0x443f00dd,0x00000000}},	//   zike_, צווי, _vru_,
  { {0x98ab000c,0x3f9e001c,0x64406702,0x00000000}},	//   _facă_, dotu_, _ermi,
  { {0x443f6703,0xd1790088,0x636f05dd,0x00000000}},	//   _tru_, ўскі_, _sønd,
  { {0x7c2901f7,0x798d002c,0x3f8c0014,0x00000000}},	//   çerl, inaw, fndu_,
  { {0x3f9e001c,0x752b013d,0xd00e005d,0x00000000}},	//   gotu_, legz, گلی_,
  { {0x442f0185,0x20041fd6,0x7d1d004d,0x00000000}},	//   lwg_, armi_, ffss,
  { {0x27e000fe,0xd00e007e,0xf8bf0042,0x00000000}},	//   ypin_, دلی_, ्शाय,
  { {0xbcfb6704,0x2d826705,0x636f05b9,0x00000000}},	//   thér, rike_, _tønd,
  { {0x69c6000f,0x798d1ba5,0x2018003b,0x00000000}},	//   _sike, enaw, ărit_,
  { {0xc332014e,0x69c6112c,0x68e400a4,0x00000000}},	//   כום_, _pike, tbid,
  { {0x140d0161,0x2d950088,0x57ea005a,0x00000000}},	//   _समूह_, _прыс, ждам_,
  { {0x2fc76706,0xbcfb0003,0x3ea7002b,0x00000000}},	// [dc80] _king_, phér, _hynt_,
  { {0x798d00a4,0x442445b3,0x752b005f,0x00000000}},	//   anaw, _rpm_, eegz,
  { {0x44246707,0x2fc71220,0x69c6322e,0x00000000}},	//   _spm_, _ming_, _tike,
  { {0x27e06708,0x34aa005e,0x2fc76709,0x00000000}},	//   ppin_, овео_, _ling_,
  { {0xd24f006a,0x3f8c007a,0xf487007e,0x00000000}},	//   ینه_, yndu_, واهی,
  { {0x2fc724ed,0x3394000d,0x2377005d,0x00000000}},	//   _ning_, эалё, ومند_,
  { {0x2eee00d1,0x3f9e670a,0x98ab00dd,0x00000000}},	//   _reff_, votu_, _tacă_,
  { {0x442400e3,0x60f8005a,0xc03400e1,0x00000000}},	//   _tpm_, чния_, ениј,
  { {0x3f9e5d6a,0x44241fdc,0xe58f0139,0x00000000}},	//   totu_, _upm_, _úsáí,
  { {0x2d800003,0x798d0051,0x6d41001c,0x00000000}},	//   _amie_, znaw, ēlam,
  { {0x3ea7001f,0x2fc7670b,0x3f9e0b5b,0x00000000}},	//   _cynt_, _ding_, rotu_,
  { {0x28de016a,0xbcfb013d,0x2fc70046,0x00000000}},	//   _फ्लि, mkék, _eing_,
  { {0xb87b000f,0x2fc7004d,0x3f9e670c,0x00000000}},	//   _leír, _fing_, potu_,
  { {0x2fc728e7,0x0a6b0af0,0x798d0022,0x00000000}},	//   _ging_, орби_, wnaw,
  { {0x8fa30001,0x3ea7670d,0x61f800ca,0x00000000}},	//   _шаље, _gynt_, nsvl,
  { {0x69da0027,0x798400a4,0x798d2f1b,0x00000000}},	//   ítea, giiw, unaw,
  { {0x798d0c02,0xdce60078,0x57b50b4a,0x00000000}},	// [dc90] rnaw, eikė, ебат,
  { {0xb87b00ea,0x798400a4,0x2ca9670e,0x00000000}},	//   _beír, aiiw, _iyad_,
  { {0xfc3f0871,0x7af5013d,0x4a750044,0x00000000}},	//   lví_, mazt, _أُجر,
  { {0xa4d5019d,0x61f800f5,0xceb300ff,0x00000000}},	//   ході, dsvl, דיע_,
  { {0x2458000d,0xd0060242,0xd6db0caa,0x00000000}},	//   маць_, _حل_, _мтв_,
  { {0x442f001f,0xa5f9005e,0x35fb005d,0x00000000}},	//   rwg_, _негу_, _ورزد_,
  { {0x9171008b,0x2fc73067,0x7c3a001c,0x00000000}},	//   _nợ_, _ring_, ātri,
  { {0x2fc71683,0x20550f63,0xfc3f011b,0x00000000}},	//   _sing_, етор, kví_,
  { {0xbcfb004c,0x2fc7670f,0x4419009a,0x00000000}},	//   akék, _ping_, _מוּס,
  { {0xbcfb004c,0xf7720041,0x2d80456c,0x00000000}},	//   lkéh, ָקט_, _smie_,
  { {0x29c7002b,0x2fc70990,0x0ea901a4,0x00000000}},	//   _rŵan_, _ving_, якой_,
  { {0x2fc70034,0x20020006,0xc692009f,0x00000000}},	//   _wing_, škia_, ראט_,
  { {0xf5390024,0x2fc76710,0x3ea7002b,0x00000000}},	//   _mať_, _ting_, _wynt_,
  { {0x212d0089,0x3ea704aa,0x547a009d,0x00000000}},	//   leeh_, _tynt_, לטרו,
  { {0x3f8500f3,0xda6601fb,0x00000000,0x00000000}},	//   milu_, راسي,   ,
  { {0x8e740002,0x394b0013,0xe9a30085,0x00000000}},	//   _јушч, _cncs_, гасп,
  { {0xcc360032,0xa3cb0053,0x3207011b,0x00000000}},	// [dca0] _أربع, _रंग_, hrny_,
  { {0xdce60006,0x8c1b009a,0xdc37009d,0x00000000}},	//   tikė, _צויי, _טאפט_,
  { {0x69de0829,0x07150062,0x9b17009a,0x00000000}},	//   _utpe, ъфтя, _אחיה_,
  { {0x66031d6b,0xd910007e,0x3f85008f,0x00000000}},	//   ánka, _خیر_, hilu_,
  { {0xf5390024,0xd467447a,0xdce60078,0x00000000}},	//   _dať_, нице_, sikė,
  { {0x68f6005b,0x61f80104,0xd25a0601,0x00000000}},	//   layd, tsvl, зци_,
  { {0x3f8500c3,0xf41f00fe,0x31c60065,0x00000000}},	//   dilu_, _ään_, нсив,
  { {0x46a30001,0xbcfb0114,0x91710013,0x00000000}},	//   _сасв, ckéh, _rợ_,
  { {0x59d20161,0x200d017d,0x91710013,0x00000000}},	//   _दूसर, guei_, _sợ_,
  { {0x29070078,0x32070022,0x987b0063,0x00000000}},	//   ėnai_, brny_, פריק,
  { {0x4e8a0121,0xce940062,0x6e940141,0x00000000}},	//   ящим_, танъ, тину,
  { {0xfc3f02f4,0x9f5f0026,0xeb9f00b9,0x00000000}},	//   tví_, stuð_, grøn_,
  { {0x69da00ea,0x5b270085,0x68f60058,0x00000000}},	//   íten, ньва, dayd,
  { {0xfc3f5f9c,0xdb1e013d,0xbcfb011b,0x00000000}},	//   rví_, _pipá, zkéh,
  { {0x7ed50086,0xe9190054,0xf993005d,0x00000000}},	//   _річч, мові_, هبر_,
  { {0x6c850021,0xad270044,0x9db900de,0x00000000}},	//   _للعم, _أرثو, _تهبط_,
  { {0xa8980138,0x6d4d34a1,0x7ce80063,0x00000000}},	// [dcb0] екту_, _inaa, _אַתֶ,
  { {0x81bc001c,0x76410014,0x29070075,0x00000000}},	//   _spēl, _ályk, şna_,
  { {0x6d4d6711,0xa6150121,0xbcfb0124,0x00000000}},	//   _knaa, тмеч, tkéh,
  { {0x3f8502f7,0x32070445,0x96b8005d,0x00000000}},	//   zilu_, vrny_, رالز_,
  { {0x5887000d,0xf5390066,0x79a20022,0x00000000}},	//   _чына, _vať_, ływó,
  { {0x9f5f021a,0xbcfb0114,0xa3bd0053,0x00000000}},	//   truí_, skéh, ीआइ_,
  { {0xe2960189,0x3f854116,0x6d4d0229,0x00000000}},	//   каш_, vilu_, _onaa,
  { {0x7fd90002,0x00000000,0x00000000,0x00000000}},	//   мфот_,   ,   ,
  { {0x637400cd,0xa3d50086,0x26c70066,0x00000000}},	//   _bànd, _розч, ľnou_,
  { {0x200308ea,0xfe450062,0x637400cd,0x00000000}},	//   čji_, вноо, _cànd,
  { {0x4dd40088,0xc7b20063,0x753b01c2,0x00000000}},	//   ліяф, שבי_, _kauz,
  { {0x3135005e,0x63a34791,0x3f854a14,0x00000000}},	//   _једр, lonn, silu_,
  { {0x753b0035,0x200d1997,0xeb9f04aa,0x00000000}},	//   _mauz, quei_, rrøn_,
  { {0x69d60235,0x63a328da,0x3b0a0121,0x00000000}},	//   _मंदी, nonn, ьего_,
  { {0x60db2550,0xfaa6090f,0xbb4302d8,0x00000000}},	//   ocum, таво, јеск,
  { {0xb9030121,0x63a36712,0x1c466713,0x00000000}},	//   изск, honn, _аним,
  { {0x6b87006f,0x63a36714,0x4c36000d,0x00000000}},	// [dcc0] bijg, konn, _рэйт,
  { {0xeb9f00d1,0x66e60363,0x68f60058,0x00000000}},	//   ktøy_, тожа, sayd,
  { {0xa3bd0053,0x63a36715,0x8b570041,0x00000000}},	//   ीआई_, donn, _סיטס_,
  { {0x753b0529,0x73e6000d,0x56930086,0x00000000}},	//   _cauz, водз, шаєт,
  { {0xf487007e,0x63a36716,0x07fa0044,0x00000000}},	//   پانی, fonn, _ترجع_,
  { {0x7c29005b,0x66e3000d,0x63a36717,0x00000000}},	//   çeri, _вора, gonn,
  { {0x753b0089,0xbcfb00ea,0xc7b3009a,0x00000000}},	//   _fauz, mkév, _כבש_,
  { {0xf1260086,0x673c217a,0xd6272303,0x00000000}},	//   тько, _harj, _шосе_,
  { {0xb4250067,0x65600025,0x63a31782,0x00000000}},	//   _معلو, _iomh, bonn,
  { {0x63a3236f,0x753b017f,0x20020078,0x00000000}},	//   conn, _zauz, škio_,
  { {0x69da0080,0x3eaa00b9,0x43750086,0x00000000}},	//   ítel, æbt_, _сутт,
  { {0x201900cd,0x6b8700ca,0x60db3183,0x00000000}},	//   àsic_, wijg, ccum,
  { {0x64426718,0x6b87006f,0x7c844968,0x00000000}},	//   nvoi, tijg, ауре,
  { {0x636f07e6,0x673c007d,0xfb870085,0x00000000}},	//   _lønn, _narj, тымн,
  { {0x5fb7014e,0x6b870122,0xffb70063,0x00000000}},	//   _שהוא_, rijg, _שלוש_,
  { {0x6d4d0035,0x261c006d,0x81bc001c,0x00000000}},	//   _unaa, dío_, _spēj,
  { {0x69d83525,0x63a36719,0x3eb90051,0x00000000}},	// [dcd0] _éven, yonn, ęste_,
  { {0x261c006d,0x63a30003,0x6603108e,0x00000000}},	//   fío_, xonn, ánko,
  { {0x6442003b,0x9f5900ea,0x673c30a7,0x00000000}},	//   evoi, ésé_, _darj,
  { {0x6560018d,0x660300c2,0x63a3671a,0x00000000}},	//   _comh, šnko, wonn,
  { {0x65600027,0x44290813,0x63a3671b,0x00000000}},	//   _domh, ïa_, tonn,
  { {0x63a300fe,0xd4040062,0xef180023,0x00000000}},	//   uonn, ряци, biļi_,
  { {0x261c02dd,0x38690443,0x64420f38,0x00000000}},	//   cío_, lyar_, avoi,
  { {0x63a31e9d,0xf2df001b,0xeb9f00d1,0x00000000}},	//   sonn, _đâu_, rtøy_,
  { {0xeb9f1262,0x3869671c,0x2054000d,0x00000000}},	//   støy_, nyar_, атэр,
  { {0x60db0f84,0x8fa50002,0x00000000,0x00000000}},	//   scum, ѓане,   ,
  { {0xa3d90042,0xfe71043e,0x2f540085,0x00000000}},	//   _ठंड_, صدد_, ртыс,
  { {0x64580051,0x2b46003b,0x8d561213,0x00000000}},	//   ścił, _şoc_, уточ,
  { {0x644f00f8,0x9f4f0137,0xdcef0023,0x00000000}},	//   _ácid, _avgå_, eicē,
  { {0x50b8006a,0xdcef003d,0xdee20af0,0x00000000}},	//   _شدند_, ficē, _лоши,
  { {0x201f671d,0xfb850085,0x69960094,0x00000000}},	//   ltui_, рыўн, грах,
  { {0xb88602f4,0x261c02dd,0x80d50047,0x00000000}},	//   hlíž, vío_, רוּװ_,
  { {0x8d85006a,0x81bc001c,0x65600025,0x00000000}},	// [dce0] _خشون, _spēk, _romh,
  { {0x636f02ab,0x261c0331,0xcc570041,0x00000000}},	//   _sønn, tío_, _עסיק_,
  { {0x673c10b5,0x201f00fe,0x3869017e,0x00000000}},	//   _varj, htui_, ayar_,
  { {0x261c006d,0x14c8007e,0xb5a50086,0x00000000}},	//   río_, نهای_, арій,
  { {0x673c671e,0x6442671f,0xd4030121,0x00000000}},	//   _tarj, uvoi, бящи,
  { {0x64426720,0xd3b70054,0x39406721,0x00000000}},	//   rvoi, глії_, ldis_,
  { {0x644200fe,0x65600dcc,0x39403716,0x00000000}},	//   svoi, _tomh, odis_,
  { {0xdced6722,0x200202e2,0xe5a60098,0x00000000}},	//   _plač, škim_, _сиби,
  { {0x1f7400a0,0x637400cd,0xb8860114,0x00000000}},	//   илия, _cànc, blíž,
  { {0x7e6800ac,0xeb9f01f2,0x7ccc008f,0x00000000}},	//   tydp, trøm_, _mērī,
  { {0x798600ca,0x57570041,0x9df70085,0x00000000}},	//   _omkw, אביע_, лнэт_,
  { {0xdced0114,0x7bd66723,0x25a6004e,0x00000000}},	//   _tlač, _buyu, nool_,
  { {0x7d040185,0xdc870001,0x6018066c,0x00000000}},	//   _ddis, ућно, _роля_,
  { {0x200b034d,0x25a66724,0x7d0407fa,0x00000000}},	//   ácie_, hool_, _edis,
  { {0xb87b017d,0x25a61b35,0xda350121,0x00000000}},	//   _ofíc, kool_, шевы,
  { {0x79a71bc9,0x7d000046,0x53d40042,0x00000000}},	//   урге, ómst, ददाश,
  { {0x56f5000a,0x2d8b6725,0x5bb91406,0x00000000}},	// [dcf0] ипаѓ, mice_, _илия_,
  { {0x2d8b6726,0x6d5d3254,0x7c2d6727,0x00000000}},	//   lice_, ljsa, _ipar,
  { {0x6dbc0045,0x07080044,0xf64705ac,0x00000000}},	//   _właś, طيني_, ыхан,
  { {0x6d5d00c7,0x2d8b6728,0xe6040021,0x00000000}},	//   njsa, nice_, إِنَ,
  { {0x78fa009a,0xbcfb00ea,0x3eae0137,0x00000000}},	//   _בפרו, lkés, _lyft_,
  { {0xd46605c5,0x27e95ef7,0x2d8b0a37,0x00000000}},	//   рише_, mpan_, hice_,
  { {0x27e96729,0xe4e701dd,0xe0d10021,0x00000000}},	//   lpan_, _бізн, يزة_,
  { {0x7c2d0051,0x201f1798,0x2d8b068a,0x00000000}},	//   _opar, ttui_, jice_,
  { {0x646301f7,0x68ed0035,0x201f00fe,0x00000000}},	//   çtiğ, ibad, utui_,
  { {0x5f050d34,0x69cf193b,0x7e750021,0x00000000}},	//   јзна, _lice, لاجئ,
  { {0x64490026,0x2d8b406a,0x201f672a,0x00000000}},	//   _hrei, fice_, stui_,
  { {0x6da6019d,0x2d8b000c,0x27e900a4,0x00000000}},	//   рима, gice_, kpan_,
  { {0x69d7672b,0x50d4005d,0xe0ce014b,0x00000000}},	//   _auxe, _ازمر, _фв_,
  { {0x69cf0025,0x68ed5f38,0x25a60089,0x00000000}},	//   _aice, ebad, zool_,
  { {0x7529672c,0x27e90089,0x7d0401f4,0x00000000}},	//   _obez, epan_, _tdis,
  { {0x442d672d,0x64490164,0xf1c60026,0x00000000}},	//   _ope_, _orei, _þátt_,
  { {0x6d41001c,0x77863d57,0x69cf672e,0x00000000}},	// [dd00] ēlat, алаз, _dice,
  { {0x4bfb0047,0x68ed672f,0x69cf006f,0x00000000}},	//   _שליס, abad, _eice,
  { {0x68ed0137,0xe73703d1,0x64492793,0x00000000}},	//   bbad, рех_, _arei,
  { {0x53e6000d,0xbcfb00ea,0x39400089,0x00000000}},	//   ацка, lkér, qdis_,
  { {0x25a60019,0x7afc000c,0x64496730,0x00000000}},	//   rool_, oart, _crei,
  { {0xaaba0161,0x69c45939,0x2d8b0420,0x00000000}},	//   _इराक, lmie, zice_,
  { {0xcad7014e,0x64496731,0x200d6732,0x00000000}},	//   בוצת_, _erei, erei_,
  { {0x64496733,0x7afc6734,0x65b80080,0x00000000}},	//   _frei, hart, bíha,
  { {0x64496735,0x7afc6736,0x2d8b2b76,0x00000000}},	//   _grei, kart, vice_,
  { {0x29dc006d,0x69c46497,0x2d8b0976,0x00000000}},	//   _oía_, hmie, wice_,
  { {0x3eb81e79,0x7c2d0924,0x2d8b6737,0x00000000}},	//   årt_, _spar, tice_,
  { {0x200d6738,0xa0a6000a,0x7af76739,0x00000000}},	//   brei_, _каед, _sext,
  { {0x69cf104f,0x69c40b33,0x7afc673a,0x00000000}},	//   _rice, dmie, fart,
  { {0x69cf00c3,0xc90f0161,0x7afc673b,0x00000000}},	//   _sice, िल्म_, gart,
  { {0xd90f007e,0x61ea004d,0x27e9002b,0x00000000}},	//   وید_, npfl, wpan_,
  { {0x29dc048e,0x7c2901f7,0x69d700c7,0x00000000}},	//   _día_, çers, _vuxe,
  { {0xc8d80086,0x7afc673c,0x7af7673d,0x00000000}},	// [dd10] рмує_, bart, _text,
  { {0x69cf12cc,0x27e9673e,0x8ca00053,0x00000000}},	//   _wice, rpan_, _गुटो,
  { {0x69cf0185,0xeb9f0146,0x20021312,0x00000000}},	//   _tice, esøg_, ških_,
  { {0x45180086,0x1959000d,0x6449673f,0x00000000}},	//   иція_, _самы_, _prei,
  { {0xf9560063,0x7dc60078,0x9474005d,0x00000000}},	//   _הסרת_, _iųst, يدها,
  { {0x798d0089,0x200d1fb2,0x083a0047,0x00000000}},	//   liaw, vrei_, _געשל,
  { {0x6449001f,0xbb780041,0x00000000,0x00000000}},	//   _wrei, שעוו_,   ,
  { {0x3f8c001c,0x200d5322,0x798d6740,0x00000000}},	//   eidu_, trei_, niaw,
  { {0x44990088,0x6449004d,0x6009005e,0x00000000}},	//   _сваю_, _urei, ћном_,
  { {0x200d6741,0x69c427f1,0xdb240058,0x00000000}},	//   rrei_, zmie, ürüt,
  { {0x798d0052,0x7afc5b46,0x69c424ce,0x00000000}},	//   kiaw, vart, ymie,
  { {0xd656014e,0x200d56db,0x29dc006d,0x00000000}},	//   צירת_, prei_, _ría_,
  { {0x29dc0026,0x859a0047,0xddc90078,0x00000000}},	//   _sía_, רשרו, bzdž,
  { {0x69d800ea,0x7afc0d59,0x79960022,0x00000000}},	//   _évek, uart, wnyw,
  { {0xf2d20047,0x7afc6742,0x798d001f,0x00000000}},	//   לעם_, rart, fiaw,
  { {0x29dc02dd,0xe8030053,0x7afc6743,0x00000000}},	//   _vía_, _लिखा_, sart,
  { {0xab9a007e,0x7afc54bd,0x7996002b,0x00000000}},	// [dd20] _مخدر_, part, rnyw,
  { {0x29dc6744,0x7c3b0003,0xbcfb013d,0x00000000}},	//   _tía_, çure, lkép,
  { {0xc86900b5,0x29dc006d,0x69c4008f,0x00000000}},	//   ען_, _uía_, pmie,
  { {0xbcfb00ea,0x61fc06a5,0x8936002a,0x00000000}},	//   nkép, _ærli, _اعدا,
  { {0x23650198,0xddc90006,0x25bf0025,0x00000000}},	//   _bolj_, yzdž, _dhul_,
  { {0xeb9f0146,0x37e3005e,0xd467005e,0x00000000}},	//   rsøg_, _хорг, сиље_,
  { {0x39420019,0x3f8c1506,0x7a436745,0x00000000}},	//   _kaks_, vidu_, mítá,
  { {0x7a4303e8,0xf5960032,0x61ea00bd,0x00000000}},	//   lítá, _الرج, rpfl,
  { {0x61ea004d,0xe58b0063,0x2cb2004b,0x00000000}},	//   spfl, _עָלָ, _nyyd_,
  { {0x200b17f9,0x200a00c2,0x7a43013d,0x00000000}},	//   ácia_, čbi_, nítá,
  { {0x39a10078,0x4d990054,0x2d991358,0x00000000}},	//   lėse_, икою_, éreo_,
  { {0x63aa002b,0xa1c6342a,0x3f8c6746,0x00000000}},	//   lofn, _убед, sidu_,
  { {0x39a10006,0x7a4300ea,0x3f8c25e8,0x00000000}},	//   nėse_, kítá, pidu_,
  { {0x7a43013d,0xab842b2b,0xa0070044,0x00000000}},	//   jítá, пуск, _اقول_,
  { {0x42db00b5,0x7a4300ea,0x798d0150,0x00000000}},	//   רקלע, dítá, tiaw,
  { {0x98750076,0xbcfb013d,0xc171009a,0x00000000}},	//   олбц, ckép, ֵ֗ן_,
  { {0x6b8e00a4,0x798d176c,0xc6f90499,0x00000000}},	// [dd30] bibg, riaw, инах_,
  { {0xfb15007e,0x798d0150,0x2d9900a4,0x00000000}},	//   _بودج, siaw, lnse_,
  { {0xf7700021,0x798d0150,0xdb0e0139,0x00000000}},	//   راك_, piaw, ambó,
  { {0x6aba01f7,0xa5f8005e,0x44b511f7,0x00000000}},	//   ütfe, сецу_, обес,
  { {0x2d990025,0x236500c2,0x637400cd,0x00000000}},	//   inse_, _polj_, _càno,
  { {0x63aa0185,0xc5fb0049,0x78bd0023,0x00000000}},	//   gofn, _معرض_, _izsv,
  { {0xd5bb0094,0xe3b00044,0x00000000,0x00000000}},	//   _бса_, رره_,   ,
  { {0x212b2536,0xe87c01f7,0x2d990122,0x00000000}},	//   ých_, nüşü, jnse_,
  { {0x3dc0002b,0xf09f01a8,0x44390005,0x00000000}},	//   _rhiw_, çà_, _ès_,
  { {0x443f0397,0x2d996747,0x93970242,0x00000000}},	//   _isu_, ense_, _اجرا,
  { {0x3eb90051,0xbcfb013d,0xed5a0893,0x00000000}},	//   ęsto_, tkép, аон_,
  { {0x7a4300ea,0x443f0089,0x69d84ed9,0x00000000}},	//   zítá, _ksu_, _évei,
  { {0xbcfb00ea,0x7600004c,0x07190042,0x00000000}},	//   rkép, _kázá, दलाव_,
  { {0x2d990173,0xbcfb00ea,0x9fc70e82,0x00000000}},	//   anse_, skép, _ущел,
  { {0x7a4300ea,0x5a550062,0x09e306b4,0x00000000}},	//   vítá, пъту, досн,
  { {0xdb070072,0xa96a06da,0xa9260085,0x00000000}},	//   eljä, шиба_, ўдал,
  { {0x39423230,0x6d5600ac,0xa7661137,0x00000000}},	// [dd40] _vaks_, _inya, окад,
  { {0x47c30086,0xeab20021,0xa6b6047e,0x00000000}},	//   дбув, _يعد_, осещ,
  { {0x7f4302a7,0x7c266748,0x95861314,0x00000000}},	//   _manq, ltkr, олже,
  { {0x7a43000f,0x7c26006f,0x39a10006,0x00000000}},	//   sítá, otkr, tėse_,
  { {0x63aa0026,0x7a4300ea,0x6d446749,0x00000000}},	//   tofn, pítá, _maia,
  { {0x6d440019,0x2900674a,0x39a10078,0x00000000}},	//   _laia, laia_, rėse_,
  { {0xeb9f00b9,0x2d9900ac,0x26d800c2,0x00000000}},	//   prøv_, ynse_, _igro_,
  { {0x39a10006,0x2900235d,0x68e41e4c,0x00000000}},	//   pėse_, naia_, ncid,
  { {0x7f432652,0x98b9003b,0x81bc008f,0x00000000}},	//   _banq, _iasă_, _spēs,
  { {0x543b00b5,0x6d56674b,0x6d460024,0x00000000}},	//   _דעמא, _anya, edka,
  { {0x44262f83,0x6d46006f,0x6d44674c,0x00000000}},	//   lto_, fdka, _baia,
  { {0x2d990290,0x656200fe,0xc0ca005e,0x00000000}},	//   unse_, njoh, _куле_,
  { {0x98b9000c,0x4426674d,0x2d992bcc,0x00000000}},	//   _masă_, nto_, rnse_,
  { {0x98b9000c,0x4426674e,0x6d460b9d,0x00000000}},	//   _lasă_, ito_, adka,
  { {0x44265891,0x6d4400be,0x298b005e,0x00000000}},	//   hto_, _faia, асао_,
  { {0x2d9200ea,0x4426674f,0x26d86750,0x00000000}},	//   ézet_, kto_, _agro_,
  { {0x44260024,0xe87c005b,0xac95005e,0x00000000}},	// [dd50] jto_, rüşü, _хапш,
  { {0xcb680001,0x7d1d05dd,0x68e4006d,0x00000000}},	//   _мање_, lgss, acid,
  { {0x69da000f,0xbb3a0063,0x77b00137,0x00000000}},	//   ítet, _העתי, växt,
  { {0x98b9000c,0x2004001c,0x637d0003,0x00000000}},	//   _casă_, ksmi_, _mène,
  { {0x764e0185,0x43750076,0xeb9f00d1,0x00000000}},	//   _erby, зуйт, brøt_,
  { {0x83880086,0x93420c0b,0xdb1c0014,0x00000000}},	//   обів_, енше, amræ,
  { {0x44266751,0x20046752,0x7600004c,0x00000000}},	//   ato_, esmi_, _vázá,
  { {0x200b444c,0xf6520063,0x443f59dd,0x00000000}},	//   ácio_, _אצל_, _tsu_,
  { {0x44260b2b,0x443f0019,0xf8b90053,0x00000000}},	//   cto_, _usu_, _आरोप,
  { {0x7d1d004d,0x6d444fec,0x68fd006c,0x00000000}},	//   egss, _saia, _lesd,
  { {0x2f54019d,0x7f4300e5,0x65696753,0x00000000}},	//   єтьс, _vanq, _koeh,
  { {0xb2ba01f9,0xd00e006a,0x7d1d0829,0x00000000}},	//   _המער, خلی_, ggss,
  { {0xe6b80053,0x6d461b2e,0x7f4366a5,0x00000000}},	//   _अर्ज, rdka, _tanq,
  { {0x4b550062,0x8cc20042,0xdce80075,0x00000000}},	//   мъст, रेगो, ğmıy,
  { {0xa3d40235,0x637d1b84,0xa3cc0053,0x00000000}},	//   _संघ_, _gène, रगत_,
  { {0xb87b0871,0xd7f20021,0x44266754,0x00000000}},	//   _efím, فكر_, yto_,
  { {0x68fd0fca,0x38c8006a,0x44266755,0x00000000}},	// [dd60] _desd, زاری_, xto_,
  { {0x46a6005a,0x68e46756,0x6f0161b8,0x00000000}},	//   пазв, scid, nalc,
  { {0xada50024,0x29000290,0x98b9003b,0x00000000}},	//   spĺň, paia_, _pasă_,
  { {0xe45a0086,0x0566005a,0x4426055b,0x00000000}},	//   йже_, явен, tto_,
  { {0x6f0100c3,0x657b0080,0x69de0ab2,0x00000000}},	//   kalc, _dluh, _hupe,
  { {0x6f0100c3,0x69de0b7e,0x656200fe,0x00000000}},	//   jalc, _kupe, sjoh,
  { {0x877b00b5,0x44263cc7,0x644b0829,0x00000000}},	//   _פאלי, sto_, avgi,
  { {0x15430001,0x44260283,0x7afe6757,0x00000000}},	//   _песм, pto_, _lept,
  { {0x60f70088,0x637d01a8,0x64404bba,0x00000000}},	//   чныя_, _sène, _usmi,
  { {0x43860067,0x386001a8,0x6f016758,0x00000000}},	//   _علاق, ixir_, galc,
  { {0x62830045,0x69de005f,0xdb1e013d,0x00000000}},	//   czno, _nupe, _lipó,
  { {0x06970063,0x2d9f004b,0x637d4b27,0x00000000}},	//   לדים_, õue_, _vène,
  { {0x0cab011c,0xc0d30021,0x7d1d080f,0x00000000}},	//   стни_, _كيمب, rgss,
  { {0x68fd00ac,0x7afe09aa,0x6f016759,0x00000000}},	//   _sesd, _cept, calc,
  { {0x27e6018d,0x69de675a,0x7afe675b,0x00000000}},	//   íonn_, _cupe, _dept,
  { {0x3197000c,0x3da4000d,0x69de1276,0x00000000}},	//   tăzi_, _прыб, _dupe,
  { {0x69da0e7c,0x7d0d004e,0x2bbc0042,0x00000000}},	// [dd70] íter, _idas, ोगशा,
  { {0x656900f3,0x3197003b,0xf0930047,0x00000000}},	//   _soeh, răzi_, ײנע_,
  { {0x636f00b9,0xcb120063,0x637d00cd,0x00000000}},	//   _mønt, _בלי_, _lènc,
  { {0x7bdf00ac,0x6f0100c2,0x7afe6110,0x00000000}},	//   _kuqu, zalc, _zept,
  { {0x69de0051,0x442b013c,0x7dde008f,0x00000000}},	//   _zupe, сцем_, _bīsk,
  { {0xdb1e00cd,0x8c1c0063,0x7bdf006c,0x00000000}},	//   _hipò, מודי, _muqu,
  { {0x6f010198,0x3949675c,0x7bdf0331,0x00000000}},	//   valc, odas_, _luqu,
  { {0x3949675d,0xc692009f,0x6f010022,0x00000000}},	//   ndas_, _סאן_, walc,
  { {0x62830758,0x7bdf0003,0xef190054,0x00000000}},	//   szno, _nuqu, омп_,
  { {0x43940001,0xdb1c02ea,0x6f010290,0x00000000}},	//   _заус, områ, ualc,
  { {0x7bdf0164,0x6f01655e,0xd1310021,0x00000000}},	//   _auqu, ralc, _لما_,
  { {0xcb0901d8,0x8234006a,0x7bdf006d,0x00000000}},	//   _כל_, _سرما, _buqu,
  { {0xa0690002,0x3949675e,0xb95b008d,0x00000000}},	//   _фала_, ddas_, _phìn,
  { {0x7d0d0004,0x3949675f,0x637400cd,0x00000000}},	//   _edas, edas_, _rànk,
  { {0xab270062,0x8cc20082,0x00000000,0x00000000}},	//   ьора_, रेजो,   ,
  { {0x636f00b9,0xfe7000de,0x3dfa009d,0x00000000}},	//   _køns, _حده_, _ולקד,
  { {0xdb1e0268,0x00000000,0x00000000,0x00000000}},	// [dd80] _dipò,   ,   ,
  { {0xdced0117,0x636f0205,0x394904a6,0x00000000}},	//   _plać, _møns, adas_,
  { {0xeb9f00d1,0x636f01e1,0xa5260054,0x00000000}},	//   prør_, _løns, дмед,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0xd467005e,0xe8f702fe,0xe4a30131,0x00000000}},	//   мице_, _юля_, кршо,
  { {0x661a01e3,0x68f60146,0x5333041d,0x00000000}},	//   _åtko, lbyd, вешт,
  { {0xe355000d,0x69d8013d,0x636f05a5,0x00000000}},	//   этцэ, _éves, _rønt,
  { {0x3d180053,0x7c366760,0x5273005e,0x00000000}},	//   थलों_, _opyr, ђују,
  { {0x0326007b,0x20030044,0x48a9009d,0x00000000}},	//   _одан, نِيِ, ּיתְ,
  { {0x3e4c0080,0x39490006,0x637d00cd,0x00000000}},	//   _pět_, zdas_, _vènc,
  { {0x4e8a0076,0xbcfb013d,0x39490078,0x00000000}},	//   ющим_, mkéz, ydas_,
  { {0xdb07004c,0xe8d9008d,0x3e4c004c,0x00000000}},	//   rojí, thử_, _vět_,
  { {0x68f60146,0x3da40088,0x321c027d,0x00000000}},	//   dbyd, трэб, luvy_,
  { {0x69c60072,0x30330121,0xdb0701d1,0x00000000}},	//   _ahke, _решё, pojí,
  { {0x7e860080,0x3f9e00ac,0x0bd40131,0x00000000}},	//   úspě, mntu_, торџ,
  { {0xbda70021,0x39494b38,0xf770007e,0x00000000}},	//   _تحتو, udas_, یال_,
  { {0x39491f47,0xe8940055,0xcda8007e,0x00000000}},	// [dd90] rdas_, вать, _تهيه_,
  { {0x3f9e0026,0x6bd70021,0xbc38002a,0x00000000}},	//   nntu_, _تتعر, _آسيا_,
  { {0xb607008b,0x261a0042,0xfb000023,0x00000000}},	//   _giớ, मूली_, ļūtu_,
  { {0xcdd900b5,0x2a760063,0x95cb17e2,0x00000000}},	//   פֿער, _נערך_, цуза_,
  { {0xc9160063,0x69cd0d02,0x3eb90006,0x00000000}},	//   _אחרת_, mmae, ęsti_,
  { {0xcc780165,0x69da013d,0x69cd0072,0x00000000}},	//   ועדה_, _óceá, lmae,
  { {0xd66900f2,0x60c2013d,0xf5274273,0x00000000}},	//   _عمرو_, _azom, _офан,
  { {0x3f9e3a85,0x7dde001c,0x69cd002b,0x00000000}},	//   entu_, _mūsd, nmae,
  { {0x6b95008f,0x4f956761,0xd00e0044,0x00000000}},	//   kizg, ерну, ملي_,
  { {0x00820086,0xd3d80049,0x0e656762,0x00000000}},	//   ульо, _قبلا_, екон,
  { {0x68f6001f,0xc7b20063,0x7c366763,0x00000000}},	//   ybyd, רבי_, _spyr,
  { {0xf2df00aa,0x636f00d1,0xf67a0047,0x00000000}},	//   _đây_, _tøns, פארמ,
  { {0x61e10d9b,0x636f0205,0xec770062,0x00000000}},	//   _hull, _uøns, епя_,
  { {0x61e104ab,0xbea538b7,0xd00e0043,0x00000000}},	//   _kull, _палк, _الو_,
  { {0x61e157eb,0xfaa3000d,0xfbc303e5,0x00000000}},	//   _jull, гаро, убро,
  { {0x61e16764,0xbd030124,0xe9d70cd6,0x00000000}},	//   _mull, žérs, екс_,
  { {0x7d064a4d,0x2d80003b,0x68f66765,0x00000000}},	// [dda0] maks, _ilie_, rbyd,
  { {0x4a460086,0x7d063e3a,0xee490013,0x00000000}},	//   _знов, laks, _kẽ_,
  { {0x3eb90022,0x461a0085,0x61e16766,0x00000000}},	//   ęstw_, яцаў_, _null,
  { {0xee49008b,0x84e60454,0x69c6078c,0x00000000}},	//   _mẽ_, ходж, _uhke,
  { {0xee49008b,0x61e10331,0xf8db009a,0x00000000}},	//   _lẽ_, _aull, _מחכמ,
  { {0x7d060ff2,0x61e1357b,0xa2940500,0x00000000}},	//   haks, _bull, калі,
  { {0xdbc70019,0x60c200ea,0x2d802943,0x00000000}},	//   _tööj, _szom, _olie_,
  { {0xb0340001,0xc0340001,0x7d0628c6,0x00000000}},	//   вниш, вниј, jaks,
  { {0x7d062dc7,0xe123005e,0x41c30021,0x00000000}},	//   daks, умњи, دقيق,
  { {0x7522000f,0xbed4000a,0x3f9e017f,0x00000000}},	//   lgoz, копј, untu_,
  { {0xe0da000a,0x3eb82709,0x798400ac,0x00000000}},	//   _еве_, ært_, khiw,
  { {0x75220009,0x29026767,0xc27b0063,0x00000000}},	//   ngoz, _neka_, _מרבי,
  { {0x79840009,0x61e10122,0xdcbb005a,0x00000000}},	//   dhiw, _zull, ящо_,
  { {0x661e6768,0x7d060cb0,0x2d802a5a,0x00000000}},	//   kupk, aaks, _elie_,
  { {0x7dde00eb,0x6d96003d,0xf9c7042c,0x00000000}},	//   _būse, mšan, ещан,
  { {0xf773006a,0x7d06005b,0xdd91007e,0x00000000}},	//   گار_, caks, _خوب_,
  { {0x69cd6769,0xc7d9005e,0x76580066,0x00000000}},	// [ddb0] rmae, дмах_, ťvyl,
  { {0x200b0024,0xf7730242,0x752201f4,0x00000000}},	//   ácii_, دار_, egoz,
  { {0xcf9300b5,0x57a4018e,0xee490013,0x00000000}},	//   נטע_, ушта, _xẽ_,
  { {0x79840051,0x61e10d7d,0x765a011b,0x00000000}},	//   chiw, _rull, _štyc,
  { {0x04450c91,0x6d96003d,0x61e1676a,0x00000000}},	//   телн, kšan, _sull,
  { {0x6d9600c3,0x61e13de1,0xf62b0086,0x00000000}},	//   jšan, _pull, _ніби_,
  { {0x7d060d52,0xc6d70021,0x85bb0049,0x00000000}},	//   yaks, _ستست, _فارس_,
  { {0x61e14d14,0xee49008b,0x2127007e,0x00000000}},	//   _vull, _rẽ_, ريخی_,
  { {0xee4900aa,0x7d060659,0x7f19013c,0x00000000}},	//   _sẽ_, vaks, міну_,
  { {0x76550051,0x6d96001c,0x394b676b,0x00000000}},	//   _krzy, gšan, _lacs_,
  { {0x7d061fc9,0x4ed40086,0xbea5197b,0x00000000}},	//   taks, люют, танк,
  { {0xed5724f8,0xdb070240,0xee49008b,0x00000000}},	//   вою_, vojá, _vẽ_,
  { {0x7d060418,0x2902676c,0xfebb005d,0x00000000}},	//   raks, _reka_, _کاشت_,
  { {0x7bce0360,0xdee20054,0x7d060f2b,0x00000000}},	//   umbu, _коши, saks,
  { {0x7984001f,0x7d06676d,0x29022733,0x00000000}},	//   thiw, paks, _peka_,
  { {0x6f030034,0x2d9901e0,0xdb07052b,0x00000000}},	//   _henc, éret_, rojá,
  { {0x6f03003e,0x2902074f,0xc1720063,0x00000000}},	// [ddc0] _kenc, _veka_, בחן_,
  { {0x29020009,0x77830086,0x661e676e,0x00000000}},	//   _weka_, алуз, tupk,
  { {0xf7430619,0x6f030d75,0x394b0025,0x00000000}},	//   рехо, _menc, _facs_,
  { {0x6f03676f,0x00000000,0x00000000,0x00000000}},	//   _lenc,   ,   ,
  { {0x7d046770,0xd7ca0044,0xd90d0043,0x00000000}},	//   _meis, _يوجه_, _ریل_,
  { {0x93b30088,0x3940415a,0x66e600e1,0x00000000}},	//   абіц, leis_, _јова,
  { {0xcb130063,0x76550051,0xa3e20042,0x00000000}},	//   בלו_, _grzy, _नूर_,
  { {0x3253005a,0x3ce000b9,0xd259000d,0x00000000}},	//   рвър, _ngiv_, эці_,
  { {0xf9930132,0x637d00cd,0x30a60062,0x00000000}},	//   ירה_, _gèno, ъркв,
  { {0xd378017f,0x39400150,0x6d96001c,0x00000000}},	//   _biće_, heis_, ušan,
  { {0x7d040199,0x8266006a,0x471b0047,0x00000000}},	//   _beis, _جهان, וויג,
  { {0x61460138,0xac191b79,0x7d0408ab,0x00000000}},	//   _једа, ному_, _ceis,
  { {0x6f036771,0x7d0413d5,0x39406772,0x00000000}},	//   _fenc, _deis, deis_,
  { {0x7e540021,0x6f036773,0x3f850066,0x00000000}},	//   _منتص, _genc, chlu_,
  { {0x9e340055,0x2e4a005a,0x6d96017f,0x00000000}},	//   _сейч, _цяло_, ošal,
  { {0x7d046774,0x6f030058,0x00000000,0x00000000}},	//   _geis, _zenc,   ,
  { {0x2d991fc9,0x085508a6,0x7793005d,0x00000000}},	// [ddd0] mise_, ываю, لیحا,
  { {0x76551112,0x2d996775,0x9f4d017d,0x00000000}},	//   _przy, lise_, mpeã_,
  { {0x3940017d,0x6d4f6776,0x6d96007d,0x00000000}},	//   beis_, odca, kšal,
  { {0xeb9f0031,0x39400016,0xa9790047,0x00000000}},	//   ksøk_, ceis_, _נאָכ,
  { {0x6d4d0273,0x5887000d,0x6d960078,0x00000000}},	//   _maaa, _рына, dšal,
  { {0x76550051,0x69dd6777,0xeb9f00d1,0x00000000}},	//   _trzy, _hise, dsøk_,
  { {0xeb9f0031,0xdb070026,0x6f03362c,0x00000000}},	//   esøk_, lljó, _renc,
  { {0x6d4d002c,0x6f036778,0x68ed6779,0x00000000}},	//   _naaa, _senc, ncad,
  { {0x3f85001f,0xeb9f00d1,0x6f033ab5,0x00000000}},	//   thlu_, gsøk_, _penc,
  { {0x6d960006,0x69dd677a,0x7d04677b,0x00000000}},	//   ašal, _lise, _seis,
  { {0x69dd0164,0x6f0300c5,0xdb070014,0x00000000}},	//   _oise, _venc, hljó,
  { {0x69dd00c3,0x63ad0025,0xeb9f00d1,0x00000000}},	//   _nise, éanf, bsøk_,
  { {0x394003d9,0xd4790047,0x3f990003,0x00000000}},	//   veis_, גאָל, ésus_,
  { {0x200b034d,0x7d0404da,0x394000bd,0x00000000}},	//   áciu_, _weis, weis_,
  { {0x7d04677c,0x69dd027e,0x3940677d,0x00000000}},	//   _teis, _bise, teis_,
  { {0xd24f000d,0x5c960021,0x2d9959d7,0x00000000}},	//   сцi_, _مؤخر, cise_,
  { {0xd7f90086,0x3940677e,0x69dd677f,0x00000000}},	// [dde0] вує_, reis_, _dise,
  { {0x39406780,0x69dd6781,0x68ed5275,0x00000000}},	//   seis_, _eise, acad,
  { {0x4b7b0047,0x64490072,0x06560085,0x00000000}},	//   _נאטו, _asei, ытаў,
  { {0xc4860076,0x1a9b0047,0x68ed6782,0x00000000}},	//   ллек, _טייע, ccad,
  { {0x7bde6783,0x6e21004d,0x64a3005e,0x00000000}},	//   _kipu, hulb, баца,
  { {0x987b0047,0xdced005b,0xd3700021,0x00000000}},	//   _טאכט, _olağ, تهت_,
  { {0x6d96001c,0x637400cd,0x200f00d1,0x00000000}},	//   ešam, _sàns, _avgi_,
  { {0x7bde6784,0xeb9f00d1,0x628a0244,0x00000000}},	//   _lipu, tsøk_, rzfo,
  { {0x65600025,0xcf9a0141,0x9f5f0014,0x00000000}},	//   _inmh, ејн_, truð_,
  { {0xeb9f0031,0x2d990034,0x1e34000d,0x00000000}},	//   rsøk_, wise_, аноў,
  { {0x2d990004,0xeb9f00d1,0xb2290021,0x00000000}},	//   tise_, ssøk_, _لأنك_,
  { {0xeb9f00d1,0xd83f0078,0x41aa0094,0x00000000}},	//   psøk_, ščiu_, _явен_,
  { {0x69dd6785,0xdb0e003b,0xe8ff006c,0x00000000}},	//   _rise, dobâ, _moût_,
  { {0x69dd0004,0x09bf0161,0x7bde00f3,0x00000000}},	//   _sise, ्ष्य, _cipu,
  { {0x7bde168b,0xead50121,0x8e23005e,0x00000000}},	//   _dipu, ровь, иjе_,
  { {0xd8f5005e,0x2e13005d,0x9da700de,0x00000000}},	//   рзањ, _ابوح, _حصته,
  { {0x69dd02ab,0x68ed57f8,0xdb070072,0x00000000}},	// [ddf0] _vise, rcad, tojä,
  { {0xe8ff0164,0x6d9600c2,0x78bd004a,0x00000000}},	//   _août_, jšaj, _vysv,
  { {0xdced007d,0xe7ea0042,0x8f1b009a,0x00000000}},	//   _hlađ, _झूठा_, תובת,
  { {0xe8ff0164,0x39a10078,0x6449008f,0x00000000}},	//   _coût_, kėsi_, _psei,
  { {0x2458000d,0x88990047,0x2807004c,0x00000000}},	//   лаць_, _סבֿי, átně_,
  { {0xdced017f,0x22150256,0xe2990b69,0x00000000}},	//   _mlađ, афир, кал_,
  { {0x45d50121,0x00000000,0x00000000,0x00000000}},	//   _вовс,   ,   ,
  { {0xe8ff0164,0x200d0019,0x7de1001c,0x00000000}},	//   _goût_, tsei_, _mēst,
  { {0x6449024a,0x38690268,0xa1560001,0x00000000}},	//   _usei, nxar_, рању_,
  { {0x7f410003,0x200d3ecf,0xa295000d,0x00000000}},	//   uelq, rsei_, _казі,
  { {0x7bde6786,0x200d6787,0x02a7032d,0x00000000}},	//   _ripu, ssei_, _срам,
  { {0xdb0e1994,0x200d003b,0x7bde2c60,0x00000000}},	//   robí, psei_, _sipu,
  { {0x0c231087,0x6e2100a4,0x317a0041,0x00000000}},	//   омян, sulb, _שאנד,
  { {0xc33200b5,0x7df3000c,0x6e21004b,0x00000000}},	//   ֿון_, _răsf, pulb,
  { {0xa928004c,0x499605bd,0xaa460121,0x00000000}},	//   _nežá, ашат, шевл,
  { {0xfaa30054,0x7c961636,0x00000000,0x00000000}},	//   іато, _вроц,   ,
  { {0x7bde6788,0x8c460619,0xdcfd0078,0x00000000}},	// [de00] _tipu, _тепе, eisė,
  { {0x6abe0934,0x46f61224,0x7d160072,0x00000000}},	//   _typf, рчат, _hdys,
  { {0xdd8f006a,0xe9df0405,0x7d16004c,0x00000000}},	//   _روی_, _fiú_, _kdys,
  { {0x63740268,0x2bb40053,0x14c8007e,0x00000000}},	//   _rànq, ंकवा, ههای_,
  { {0xd4030ac5,0x93460cbb,0x2480013d,0x00000000}},	//   оящи, инде, áim_,
  { {0xd3b70086,0xd378007d,0xd336000d,0x00000000}},	//   алії_, _bića_, рэды,
  { {0x6d96007d,0x2480407b,0x6b9c004b,0x00000000}},	//   ršaj, šim_, iirg,
  { {0x7e7e004d,0x39a10078,0x39526789,0x00000000}},	//   _üppi, tėsi_, ndys_,
  { {0x1fa60142,0x6d9600a8,0x251b009a,0x00000000}},	//   ирог, pšaj, _שומא,
  { {0x1be10235,0x39520072,0x39a10078,0x00000000}},	//   _गूगल_, hdys_, rėsi_,
  { {0x4f67000d,0x63b83fb1,0x6b9c678a,0x00000000}},	//   ршым_, movn, dirg,
  { {0x25a60185,0x63b8678b,0xbf66005d,0x00000000}},	//   nnol_, lovn, ادکو,
  { {0x7d160185,0xcff40062,0x39520616,0x00000000}},	//   _ddys, _уплъ, ddys_,
  { {0x63b8065f,0x49bb007e,0x207b016e,0x00000000}},	//   novn, چارد_, _באדא,
  { {0xb3450016,0xda78005a,0xe9190086,0x00000000}},	//   leçã, аят_, лові_,
  { {0x7de1003d,0x386901a8,0x6edb0063,0x00000000}},	//   _vēst, txar_, _בחופ,
  { {0x63b806bb,0x6b9c00bd,0x26c508c4,0x00000000}},	// [de10] kovn, birg, _šlo_,
  { {0x386900cd,0x25a6001f,0x63b801d1,0x00000000}},	//   rxar_, enol_, jovn,
  { {0xd6db011c,0x63b8678c,0x39520078,0x00000000}},	//   тта_, dovn, bdys_,
  { {0xfe37014e,0x25a60164,0xe945007e,0x00000000}},	//   שראי_, gnol_, _اردی,
  { {0xb345017d,0xe5700044,0xdb0e678d,0x00000000}},	//   jeçã, بطل_, lobá,
  { {0x63b800c3,0xd378007d,0x25a6002b,0x00000000}},	//   govn, _pića_, anol_,
  { {0x6567005e,0x0b18009a,0x00000000,0x00000000}},	//   _књаж, שַׂר_,   ,
  { {0x01650079,0xf3ff0016,0x61e8678e,0x00000000}},	//   скио, _ção_, _dudl,
  { {0xdb0e00ea,0x68fb004b,0x7df300dd,0x00000000}},	//   őkés, _õudu, _măse,
  { {0x23740032,0x63b80a63,0x39520006,0x00000000}},	//   _والح, covn, zdys_,
  { {0x1d0a0da9,0xfce60e82,0x645e008f,0x00000000}},	//   лени_, йоно, āpie,
  { {0x443f00f3,0x645b0162,0xf77f00be,0x00000000}},	//   _kpu_, _krui, _ouço_,
  { {0xb3450016,0xf00b000d,0x443f0150,0x00000000}},	//   ceçã, _рэек_, _jpu_,
  { {0x443f0150,0x69d8013d,0x005603c3,0x00000000}},	//   _mpu_, _évez, _לשנת_,
  { {0x25a60185,0x7df3000c,0x753b007d,0x00000000}},	//   ynol_, _băse, _obuz,
  { {0x69cf0471,0x63b8218f,0xfaa31a6b,0x00000000}},	//   _chce, zovn, часо,
  { {0xed590024,0x8d76007e,0xe8ca005e,0x00000000}},	// [de20] ôže_, _ناکا, угал_,
  { {0x4b260726,0x753b000c,0x25a6001f,0x00000000}},	//   _умов, _abuz, wnol_,
  { {0xe7370076,0xd946101a,0x6d4664b3,0x00000000}},	//   сех_, _лени, oeka,
  { {0x7df3000c,0x7c260080,0x645b678f,0x00000000}},	//   _găse, oukr, _brui,
  { {0x63b86790,0x645b057a,0xe4e50086,0x00000000}},	//   tovn, _crui, цієн,
  { {0x53e50086,0x443f0150,0x290023a8,0x00000000}},	//   іціа, _dpu_, lbia_,
  { {0x645b006f,0x7c260035,0x6d5a001c,0x00000000}},	//   _erui, hukr, ētaj,
  { {0xb3450016,0x6d46017f,0xa91b0026,0x00000000}},	//   teçã, jeka, _alþj,
  { {0x6d466791,0x63ad0003,0xc9530063,0x00000000}},	//   deka, éanc, למה_,
  { {0x69c40199,0xb3450016,0x44266792,0x00000000}},	//   hlie, reçã, muo_,
  { {0xdceb082a,0x69c46793,0xc10601fb,0x00000000}},	//   žičn, klie, _هواي,
  { {0x6d466794,0xdcfd0023,0xade3012c,0x00000000}},	//   geka, misī, яцьк,
  { {0x637d00cd,0x69c46795,0x44266796,0x00000000}},	//   _sèni, dlie, nuo_,
  { {0x44260006,0x3e57003b,0x3f82008f,0x00000000}},	//   iuo_, _făt_, īkus_,
  { {0x44260035,0x69c40206,0x6d463ff4,0x00000000}},	//   huo_, flie, beka,
  { {0x69c46797,0xada4018e,0x3f9e6798,0x00000000}},	//   glie, _најл, litu_,
  { {0xdcfd0078,0x779912b9,0x3f9e0656,0x00000000}},	// [de30] nksč, акар_, oitu_,
  { {0x44260aca,0x7d0f013d,0x69c42429,0x00000000}},	//   duo_, lacs, alie,
  { {0x2900051e,0x69c46799,0x6440001c,0x00000000}},	//   bbia_, blie, _apmi,
  { {0x645b016d,0x44260035,0xd6d8679a,0x00000000}},	//   _prui, fuo_, сту_,
  { {0x4426679b,0xd469018e,0x5c5c0047,0x00000000}},	//   guo_, риле_, ָדוק,
  { {0x6d463a39,0xcec30080,0xe81e0053,0x00000000}},	//   zeka, _jiří_, _पिता_,
  { {0x2d820205,0xf1b9001c,0x4b7c679c,0x00000000}},	//   ykke_, toš_, רטוג,
  { {0x4426002c,0x91e2005a,0x60c205b9,0x00000000}},	//   buo_, моще, _byom,
  { {0x61e2679d,0x6d46679e,0x44260ac0,0x00000000}},	//   _diol, veka, cuo_,
  { {0x764e0185,0x3f9e014f,0x7df3000c,0x00000000}},	//   _ysby, gitu_, _născ,
  { {0x27e302b0,0x798d00f3,0xa1190049,0x00000000}},	//   _mijn_, khaw, _نقاط_,
  { {0x27e30122,0x68e200eb,0x3f9e053b,0x00000000}},	//   _lijn_, žodi, aitu_,
  { {0x69c45104,0x6d46679f,0xef0e1b06,0x00000000}},	//   vlie, reka, _ом_,
  { {0x291900a4,0x6d9600c2,0xcff5005d,0x00000000}},	//   _adsa_, jšav, _هيچک,
  { {0xb9760002,0x6d463e35,0x25bf005b,0x00000000}},	//   оѓањ, peka, _okul_,
  { {0xddc30432,0x290b67a0,0x798d173c,0x00000000}},	//   _общи, _ceca_, ghaw,
  { {0x290067a1,0x290b22cd,0x91fc008f,0x00000000}},	// [de40] rbia_, _deca_, _grāf,
  { {0x798d00e3,0xb6a60e6b,0x69c467a2,0x00000000}},	//   ahaw, оизл, slie,
  { {0x69c467a3,0x7c43007d,0x464a0131,0x00000000}},	//   plie, čvrš, рзен_,
  { {0x442667a4,0x2e3a0047,0xe45a2c9e,0x00000000}},	//   tuo_, יגענ, иже_,
  { {0x27e3006f,0x2019004a,0x61e267a5,0x00000000}},	//   _fijn_, ásil_, _riol,
  { {0x61e20025,0x7d0f013d,0xd3d70044,0x00000000}},	//   _siol, zacs, يبوا_,
  { {0x63ad0027,0x61e267a6,0x3f9e2904,0x00000000}},	//   éana, _piol, vitu_,
  { {0x27e30b7d,0xeb9f0031,0x60f80062,0x00000000}},	//   _zijn_, nsør_, щния_,
  { {0x442667a7,0x232a2046,0x3f9e4e28,0x00000000}},	//   quo_, _вози_, titu_,
  { {0x60c20009,0x61ee0003,0x7e7c00d1,0x00000000}},	//   _vyom, _éblo, ørpo,
  { {0x0dcb000a,0x3f9e67a8,0x7df3003b,0x00000000}},	//   иуми_, ritu_, _răsc,
  { {0x3f9e1848,0xc05a013c,0x20060022,0x00000000}},	//   situ_, _вік_, _twoi_,
  { {0x290b0290,0x83fd00ea,0xff4f007e,0x00000000}},	//   _reca_, _erőf, رخی_,
  { {0x33f00268,0x290b0e57,0xc2140063,0x00000000}},	//   _màx_, _seca_, ּהּ_,
  { {0xd378017f,0x27e3158f,0x7ac402a1,0x00000000}},	//   _moć_, _rijn_, дсте,
  { {0x27e3006f,0x57f50094,0x00000000,0x00000000}},	//   _sijn_, зпат,   ,
  { {0x27e3006f,0x3ce9004b,0x798d451d,0x00000000}},	// [de50] _pijn_, _igav_, rhaw,
  { {0xd378017f,0x25bf0150,0x7d0d004b,0x00000000}},	//   _noć_, _skul_, _heas,
  { {0x6e280198,0x6da4017f,0x7d0d017e,0x00000000}},	//   nudb, rđav, _keas,
  { {0x27e3006f,0x85e80054,0x7bc767a9,0x00000000}},	//   _wijn_, ідів_, llju,
  { {0x7d0d057a,0xdb150080,0x7af50051,0x00000000}},	//   _meas, hozí, oczt,
  { {0xa87a014e,0x7df3000c,0x7d0d057a,0x00000000}},	//   _האשר, _lăsa, _leas,
  { {0x7c3a003b,0x7e7c04aa,0xa91b0014,0x00000000}},	//   ătri, ørpl, _alþi,
  { {0xdb1c0014,0x7d0d0fc4,0x394967aa,0x00000000}},	//   ilrá, _neas, neas_,
  { {0x7bc706bb,0x3dd2001f,0x61fa004d,0x00000000}},	//   klju, _rhyw_, _ettl,
  { {0x39490027,0x637d0268,0x7bc7085a,0x00000000}},	//   heas_, _cènt, jlju,
  { {0x7d0d06b8,0x6d96007d,0x22580121,0x00000000}},	//   _beas, kšat, _мифы_,
  { {0x523a00b5,0x7d0d67ab,0x6d9600c2,0x00000000}},	//   _לײענ, _ceas, jšat,
  { {0xd1b8006a,0x7d0d19d5,0x394967ac,0x00000000}},	//   _بالا_, _deas, deas_,
  { {0xff51007e,0x70520021,0x98a00078,0x00000000}},	//   _سخت_, _أنوا, ngią_,
  { {0xa96a05fb,0x91fc001c,0x7d0d67ad,0x00000000}},	//   бива_, _grād, _feas,
  { {0x6d960006,0x7d0d67ae,0xdb0e00d1,0x00000000}},	//   tšau, _geas, dobå,
  { {0xa2a20161,0x7bc708ed,0x3f850058,0x00000000}},	// [de60] _केन्, blju, oklu_,
  { {0x6d5653f4,0xeb9f00d1,0x79840051,0x00000000}},	//   _haya, ssør_, skiw,
  { {0x6b81005b,0x6d561683,0xf6230ae8,0x00000000}},	//   ölge, _kaya, едхо,
  { {0x63ad0025,0x39490e7c,0x6d5632ac,0x00000000}},	//   éann, ceas_, _jaya,
  { {0x29121394,0x6d561fff,0xe4e3013c,0x00000000}},	//   maya_, _maya, нішн,
  { {0x6d5606a7,0xcc3b0047,0x2d990153,0x00000000}},	//   _laya, מענט, érez_,
  { {0x3c3600b9,0xe1d8000d,0xed61004c,0x00000000}},	//   hæv_, одкі_, ížky_,
  { {0x7de80080,0x291267af,0x6e280137,0x00000000}},	//   _měst, naya_, vudb,
  { {0x291200f3,0x7d0d0898,0x7df3003b,0x00000000}},	//   iaya_, _reas, _răsa,
  { {0x2912053b,0x7d0d057a,0x6e2800b9,0x00000000}},	//   haya_, _seas, tudb,
  { {0x7bc70117,0x6d56367c,0x7d0d010e,0x00000000}},	//   vlju, _baya, _peas,
  { {0x6e280146,0x29120397,0xadbd046e,0x00000000}},	//   rudb, jaya_, рамi,
  { {0x2912014f,0xdb1c0026,0x6e2826c6,0x00000000}},	//   daya_, ilræ, sudb,
  { {0xdb150066,0x629c0014,0x7d000058,0x00000000}},	//   pozí, _þros, ımsa,
  { {0xdcfd001c,0x2912005b,0x39491230,0x00000000}},	//   aksā, faya_, teas_,
  { {0x291267b0,0x6d5667b1,0x7bc70137,0x00000000}},	//   gaya_, _gaya, slju,
  { {0x5779000d,0x7bc7007d,0x394967b2,0x00000000}},	// [de70] обаў_, plju, reas_,
  { {0x394967b3,0xc66b0121,0x6f1c0139,0x00000000}},	//   seas_, йшее_, órch,
  { {0x3949006d,0x4b7c0063,0x6d561324,0x00000000}},	//   peas_, _לאזו, _yaya,
  { {0x210000c2,0x7ddf2b27,0x2019013d,0x00000000}},	//   nčič_, _būsi, ásik_,
  { {0x63ad3a7d,0x87070085,0xc9520063,0x00000000}},	//   éano, _няве, _סמך_,
  { {0x43420085,0xcc58009a,0x00000000,0x00000000}},	//   вешв, פסוק_,   ,
  { {0x91fc008f,0x2b8f0058,0x98a00022,0x00000000}},	//   _arāb, _güce_, rgią_,
  { {0x806504e3,0x21f1017c,0xb5a415ce,0x00000000}},	//   движ, _váh_, _зруй,
  { {0x6d56027b,0x7ddf008f,0x34945e1e,0x00000000}},	//   _raya, _gūsi, _затр,
  { {0x6d5667b4,0x0ea9007f,0x2b8f0058,0x00000000}},	//   _saya, жкой_, _yüce_,
  { {0x291204d2,0x6d560465,0x63a367b5,0x00000000}},	//   yaya_, _paya, minn,
  { {0x63a316f5,0xb2ba0063,0xdb070022,0x00000000}},	//   linn, _ומער, kojó,
  { {0x6d56006d,0x63a30025,0xd1b80021,0x00000000}},	//   _vaya, oinn, _عاما_,
  { {0xa3cd0161,0xa3bf0161,0x6d562323,0x00000000}},	//   रति_, ीति_, _waya,
  { {0x6d562f71,0xdb1c0003,0x2912132d,0x00000000}},	//   _taya, noré, taya_,
  { {0x6da4007d,0x656908a9,0x63a367b6,0x00000000}},	//   ađar, _nneh, hinn,
  { {0x6283001f,0xa3cd0053,0x63a367b7,0x00000000}},	// [de80] hyno, रता_, kinn,
  { {0x62830024,0x291267b8,0x6569017e,0x00000000}},	//   kyno, saya_, _aneh,
  { {0x6f1c017d,0x63a367b9,0x98c3001c,0x00000000}},	//   órci, dinn, īvāk_,
  { {0xf8bf00cd,0xdb15013d,0xa2b10042,0x00000000}},	//   _ccés_, mozá, _अख़्,
  { {0x63a33a97,0xdb15013d,0xe2f80085,0x00000000}},	//   finn, lozá, пелі_,
  { {0xf62602a9,0x6283002b,0x63a302ce,0x00000000}},	//   _одго, fyno, ginn,
  { {0x7c26004d,0xd3b90054,0x628318c0,0x00000000}},	//   hrkr, чуці_, gyno,
  { {0x63a300f3,0xdb1c00c7,0xdce4017c,0x00000000}},	//   ainn, llrä, _anič,
  { {0xdb15000f,0x63a367ba,0x65370047,0x00000000}},	//   hozá, binn, _קאמף_,
  { {0xdb15000f,0x442667bb,0xdb1c4ed9,0x00000000}},	//   kozá, mro_, boré,
  { {0xd12f0675,0xdb1c0003,0x7c2624f5,0x00000000}},	//   _их_, coré, erkr,
  { {0x44260c9f,0xdb1c004d,0xdb1510c9,0x00000000}},	//   oro_, hlrä, dozá,
  { {0x5c740376,0x210000c2,0x3ced00a8,0x00000000}},	//   влят, rčič_, ževo_,
  { {0x442603d9,0xcf26007e,0xdfa601fb,0x00000000}},	//   iro_, _آرشي, _تحصي,
  { {0x4426001f,0xdb15013d,0x2c09005d,0x00000000}},	//   hro_, gozá, _کعبی_,
  { {0xceb30149,0x442667bc,0xea000013,0x00000000}},	//   _שיק_, kro_, _giật_,
  { {0x62830051,0x657b011b,0xeb0712c2,0x00000000}},	// [de90] zyno, _rouh, _очно,
  { {0x657b3d9c,0x442667bd,0x27e72071,0x00000000}},	//   _souh, dro_, önn_,
  { {0x442667be,0x657b0080,0x44392b27,0x00000000}},	//   ero_, _pouh, _ūs_,
  { {0x63a31c2f,0x4426606b,0xdb1c006c,0x00000000}},	//   winn, fro_, voré,
  { {0x44260402,0x62830731,0x63a367bf,0x00000000}},	//   gro_, wyno, tinn,
  { {0x63a30025,0x39594a33,0xdb1c2db1,0x00000000}},	//   uinn, _hass_, toré,
  { {0x442667c0,0xdb0e270a,0x7dd60066,0x00000000}},	//   aro_, tobú, láse,
  { {0x63a367c1,0x63a40139,0x3cf90042,0x00000000}},	//   sinn, éinr, ंडों_,
  { {0x2019000f,0x395967c2,0x80a90156,0x00000000}},	//   ési_, _mass_, явив_,
  { {0xeafb0053,0x82f8007e,0xdb0e01bb,0x00000000}},	//   ्रोत_, _قرمز_, llbö,
  { {0xd1310032,0x398e0026,0x1ee7007e,0x00000000}},	//   _مما_, _lýsa_, بودی_,
  { {0x3f8e0035,0xf2d20047,0xdb0a004a,0x00000000}},	//   _elfu_, _געב_, čník,
  { {0xe5360041,0x7c280022,0xa0692530,0x00000000}},	//   עטשט_, ądro, _хала_,
  { {0xdce400c3,0x207a0047,0xdb1500ea,0x00000000}},	//   _unič, _מאנא, tozá,
  { {0xfb850088,0x6b810026,0x39590a66,0x00000000}},	//   тыўн, ölga, _bass_,
  { {0x79a50001,0x4426639b,0xdb154e8b,0x00000000}},	//   врђе, yro_, rozá,
  { {0x39590cd4,0xfc320021,0x777c01a8,0x00000000}},	// [dea0] _dass_, _صحة_, _porx,
  { {0x44260016,0x26de0114,0xdc3b0063,0x00000000}},	//   vro_, _útok_, _צעיר,
  { {0x3959004d,0x44261780,0xa5260591,0x00000000}},	//   _fass_, wro_, емед,
  { {0x44263fd8,0x395900d1,0x7dd6013d,0x00000000}},	//   tro_, _gass_, lásb,
  { {0x69c601f2,0x44260dc4,0xdb05008d,0x00000000}},	//   _ikke, uro_, _tkhô,
  { {0xb607008b,0x7791007e,0x442667c3,0x00000000}},	//   _khớ, _پیما, rro_,
  { {0x599a0063,0x6d4467c4,0x4426005f,0x00000000}},	//   ּשִׁ, _obia, sro_,
  { {0xd2590088,0x442667c5,0x6626008f,0x00000000}},	//   ьці_, pro_, īskā,
  { {0xf9930063,0xdfa60699,0xcfa612ab,0x00000000}},	//   טרה_, ејно, ешни,
  { {0x25a667c6,0x386018fb,0x8fa30092,0x00000000}},	//   liol_, ivir_, лање,
  { {0xdd950088,0x17970063,0x6d440290,0x00000000}},	//   ваны, גדיל_, _bbia,
  { {0x2e380026,0x25a60e2f,0x38600734,0x00000000}},	//   réf_, niol_, kvir_,
  { {0xdb1c001f,0x40340062,0x21750054,0x00000000}},	//   gorï, _релс, _шуфр,
  { {0x25a6001f,0x69c667c7,0x6298147d,0x00000000}},	//   hiol_, _akke, ozvo,
  { {0x2d9903b2,0xeef70063,0x7ddf0078,0x00000000}},	//   ères_, _אמור_, _būst,
  { {0x6298055e,0xb8860066,0x7dd61270,0x00000000}},	//   izvo, zníž, táse,
  { {0x25a60185,0xe8940156,0x6d4f67c8,0x00000000}},	// [deb0] diol_, гать, meca,
  { {0x69c60026,0x6e2829e0,0x6d4f67c9,0x00000000}},	//   _ekke, ordb, leca,
  { {0x765a0024,0x9f4f0137,0x7c2f67ca,0x00000000}},	//   _štyr, _utgå_, lucr,
  { {0x2d8b0080,0x6d5d67cb,0x7ddf008f,0x00000000}},	//   nkce_, ndsa, _gūst,
  { {0x76550045,0x29090009,0x6d4f000c,0x00000000}},	//   _wszy, mbaa_, ieca,
  { {0x7c3d004d,0x1707005d,0xd466167b,0x00000000}},	//   itsr, _سفری_, тише_,
  { {0xa9240080,0x69cd001f,0x6d4f1472,0x00000000}},	//   ůžet, olae, keca,
  { {0x6d4f017f,0xe2a80032,0x6d5d67cc,0x00000000}},	//   jeca, عاون_, jdsa,
  { {0x6d4f4a32,0x629808ed,0x4f950141,0x00000000}},	//   deca, azvo, врну,
  { {0x6d5d67cd,0x9f85019c,0x91fc008f,0x00000000}},	//   edsa, тгод, _irān,
  { {0x9f470080,0x9f4f0003,0x290900f5,0x00000000}},	//   _jiné_, _jugé_, kbaa_,
  { {0x91fc008f,0xd1b80044,0x7c3d5d64,0x00000000}},	//   _krān, _كانا_, ftsr,
  { {0x69cd0185,0x557600b5,0x442f00bd,0x00000000}},	//   dlae, דערן_, nug_,
  { {0xb607008d,0x69cd0a27,0x61eb0046,0x00000000}},	//   _phớ, elae, _higl,
  { {0xc33201f9,0x442f0139,0x7c3d0b06,0x00000000}},	//   יום_, hug_, atsr,
  { {0x3a25007a,0x6d4f45f7,0xdb1c2321,0x00000000}},	//   álpa_, ceca, morí,
  { {0x61eb02f6,0x394059af,0xdb1c0118,0x00000000}},	// [dec0] _migl, rfis_, lorí,
  { {0x386067ce,0x25a6001f,0x442f6192,0x00000000}},	//   rvir_, wiol_, dug_,
  { {0xe9da0138,0x60cb0006,0xdb1c09aa,0x00000000}},	//   _око_, _lygm, norí,
  { {0x2d800164,0x8ab70063,0x75890086,0x00000000}},	//   _joie_, _יהיו_, нсів_,
  { {0x25a6001f,0x99980080,0xdb1c00dd,0x00000000}},	//   riol_, ltrů_, morâ,
  { {0xd703005a,0x61eb0003,0xb87b006d,0x00000000}},	//   _взри, _aigl, _egís,
  { {0x61eb67cf,0x7bce0d19,0xdb1c0331,0x00000000}},	//   _bigl, ilbu, jorí,
  { {0x6d4f00cd,0xdb1c67d0,0x442f67d1,0x00000000}},	//   xeca, norâ, bug_,
  { {0xbcfb0003,0x6d4f007d,0x443d0022,0x00000000}},	//   ndée, veca, ctw_,
  { {0xd346007e,0x836a0049,0x236a00de,0x00000000}},	//   _شیعه_, _تصرف_, _تحري_,
  { {0x61eb02f6,0xdb1c67d2,0xf8bf0164,0x00000000}},	//   _figl, gorí, _idée_,
  { {0xa183093e,0x6026000d,0x61eb2c61,0x00000000}},	//   _вышл, _адда, _gigl,
  { {0x201902f4,0xada4000d,0x2d80431b,0x00000000}},	//   ásit_, раўл, _doie_,
  { {0x8fa30c07,0x7c3d2752,0x6d4f67d3,0x00000000}},	//   _каче, rtsr, seca,
  { {0x7c2f0871,0x442f67d4,0x6d4f62a7,0x00000000}},	//   sucr, zug_, peca,
  { {0x7996001f,0xa806005b,0xe9b40054,0x00000000}},	//   ghyw, ktığ, абсь,
  { {0x3dc900bb,0xcd340021,0x69cd21ef,0x00000000}},	// [ded0] _ikaw_, _ضريب, rlae,
  { {0x7f8400cd,0x69cd67d5,0x7dd6336c,0x00000000}},	//   _tòqu, slae, mása,
  { {0xcf9300b5,0xd006007e,0x644967d6,0x00000000}},	//   סטע_, _گل_, _spei,
  { {0x35b50076,0xceb3089e,0x442f0f49,0x00000000}},	//   ыбер, ביע_, tug_,
  { {0x24580088,0xef18001c,0x61eb12fd,0x00000000}},	//   каць_, kaļ_, _rigl,
  { {0xdb1c02dd,0xa856014e,0x61eb67d7,0x00000000}},	//   yorí, _גישה_, _sigl,
  { {0x05bb006a,0x61eb2ae4,0x443d0051,0x00000000}},	//   _قدرت_, _pigl, stw_,
  { {0xdb1c0024,0x9f460014,0x61fe004c,0x00000000}},	//   vorí, _stoð_, ípla,
  { {0x51840141,0x69da00ca,0x11d60044,0x00000000}},	//   руја, ïtei, دوية_,
  { {0x2d9902b0,0xaf050076,0x2f550086,0x00000000}},	//   ëren_, ыпол, утис,
  { {0x225b0044,0x22290043,0x5595009a,0x00000000}},	//   _تجذب_, _سزای_, ָדָע_,
  { {0xed570086,0x20b90121,0xc8840058,0x00000000}},	//   гою_, _пыль_, _yağı_,
  { {0x711a014e,0x2d8067d8,0xdb1c053c,0x00000000}},	//   _נוספ, _voie_, vorâ,
  { {0x7bce00dd,0xdb1c013d,0x798d0022,0x00000000}},	//   ulbu, porí, ekaw,
  { {0x69c40a2c,0xdb1c00be,0x6eca0082,0x00000000}},	//   toie, torâ, _सुपु,
  { {0x798d00a4,0x7dd6013d,0x6d4e0061,0x00000000}},	//   gkaw, bása, íhač,
  { {0x38660025,0x7996001f,0x9998004c,0x00000000}},	// [dee0] íor_, rhyw, strů_,
  { {0x386f00c7,0xbcfb0003,0x69c40003,0x00000000}},	//   ågra_, rdée, soie,
  { {0x452a01f6,0x76410050,0x7d1667d9,0x00000000}},	//   ежен_, _älyl, _keys,
  { {0x2956005a,0xa806005b,0x399504c7,0x00000000}},	//   _съор, ttığ, _påse_,
  { {0xd91b0063,0x7d162894,0xdb1c017d,0x00000000}},	//   _אוכל, _meys, corã,
  { {0x9326006a,0x7d160026,0xea00008b,0x00000000}},	//   ارشن, _leys, _ngẫu_,
  { {0xe2460021,0x7dd600ea,0x2fc500c2,0x00000000}},	//   اختي, zása, dolg_,
  { {0x7df30529,0xa806005b,0x75d60021,0x00000000}},	//   _găsi, ptığ, _إيرا,
  { {0x2fc500bd,0x212b0139,0xf8b40042,0x00000000}},	//   folg_, ócha_, ंपिय,
  { {0xa857014e,0x2002008f,0x39520d90,0x00000000}},	//   נייה_, īki_, heys_,
  { {0x20190026,0xa2060062,0x39525f4f,0x00000000}},	//   ásir_, _спед, keys_,
  { {0x7dd6000f,0xb8860066,0xab620058,0x00000000}},	//   tása, _zvíť, çünc,
  { {0xfc3f004c,0x5b270d80,0x71d7009a,0x00000000}},	//   utí_, льва, _עודד_,
  { {0xbe86007e,0xfc3f2194,0xdb0e0022,0x00000000}},	//   _مجبو, rtí_, dobó,
  { {0xe9190086,0x0ef9000d,0xfc3f612b,0x00000000}},	//   кові_, _рэчы_, stí_,
  { {0x798d00a4,0x1958000d,0x7dd667da,0x00000000}},	//   ukaw, ласы_, lásn,
  { {0x2d990025,0x798d1735,0x6e2e013d,0x00000000}},	// [def0] mhse_, rkaw, ábbf,
  { {0x994e004c,0x798d67db,0x6f1a67dc,0x00000000}},	//   _výš_, skaw, natc,
  { {0xb8cc0053,0xb87b04a5,0x44d4008d,0x00000000}},	//   _के_, _egíp, _à_,
  { {0xceb30047,0x7bc767dd,0x628a002b,0x00000000}},	//   זיע_, loju, dyfo,
  { {0x6d5f0fd1,0x399e004c,0xd91a009a,0x00000000}},	//   _maqa, růst_, _שושל,
  { {0x7bc713ed,0xe2850a91,0xd7950062,0x00000000}},	//   noju, илли, _тигъ,
  { {0x2fc504c6,0xa80601f7,0x6f1a017f,0x00000000}},	//   volg_, rtış, datc,
  { {0x91fc001c,0xf9920047,0x6d5f0059,0x00000000}},	//   _grām, ַרי_, _naqa,
  { {0x9f470290,0x7bc767de,0xa4d40054,0x00000000}},	//   _finì_, koju, _готі,
  { {0x2054011c,0xff25000a,0x4fa50002,0x00000000}},	//   стър, јмно, риов,
  { {0x6d5f0089,0x41550071,0x7bc713ed,0x00000000}},	//   _baqa, _ввес, doju,
  { {0xdb07004d,0xfce667df,0xc27a009a,0x00000000}},	//   hnjä, ионо, _ברעי,
  { {0x395200fe,0x7d1b0014,0x7bc7004e,0x00000000}},	//   veys_, ðusa, foju,
  { {0x7bc70a10,0x7d160244,0xdee51d11,0x00000000}},	//   goju, _weys, _коли,
  { {0x395200fe,0xbea232f0,0x9f47004c,0x00000000}},	//   teys_, _машк, _jiní_,
  { {0x2d9900bd,0x7dd600ea,0xdc35027d,0x00000000}},	//   chse_, máso, _zúčt,
  { {0x7dd600ea,0x7bc7001c,0xdb1c00cd,0x00000000}},	// [df00] láso, boju, porà,
  { {0x753b000c,0x27ee0026,0x7bc7001c,0x00000000}},	//   _acuz, öfn_, coju,
  { {0xdb0e0051,0x645b0072,0x850601fb,0x00000000}},	//   sobó, _asui, لوان,
  { {0x7dd600ea,0x3abb0063,0x4eac0041,0x00000000}},	//   zásn, _ימינ, עבאַ,
  { {0x63aa014f,0x66090080,0xf3e60121,0x00000000}},	//   tifn, _čeke, аждо,
  { {0xbcfb0025,0x7dd600ea,0x4420008d,0x00000000}},	//   idéa, káso, ĩi_,
  { {0x2b4701f7,0x7ddd00ea,0xd2500021,0x00000000}},	//   _önce_, lése, سنة_,
  { {0x29001513,0x7dd600ea,0x7bc70035,0x00000000}},	//   ncia_, dáso, zoju,
  { {0x7df30529,0x7ddd000f,0xd007000a,0x00000000}},	//   _măsu, nése, аење_,
  { {0x63ad0d23,0x65600139,0x9f4f01a8,0x00000000}},	//   éant, _hamh, _fugí_,
  { {0xa3e30235,0x29000024,0x7dd667e0,0x00000000}},	//   नगर_, kcia_, gáso,
  { {0x65600035,0xdb1c017d,0x65620035,0x00000000}},	//   _jamh, vorá, ndoh,
  { {0x644267e1,0x7bc767e2,0x31ba008f,0x00000000}},	//   ntoi, toju, cīza_,
  { {0x764e0146,0x7ddd00ea,0xc0a90049,0x00000000}},	//   _opby, dése, _حامل_,
  { {0xdced017f,0x7bc7003d,0x644200fe,0x00000000}},	//   _inač, roju, htoi,
  { {0x7df3000c,0x7dd6004c,0x6da40141,0x00000000}},	//   _căsu, násl, _мија,
  { {0xed590024,0x7d1d67e3,0x7ddd013d,0x00000000}},	// [df10] ôžu_, mass, gése,
  { {0x290002dd,0xe71901a7,0x753b000c,0x00000000}},	//   acia_, ايات_, _scuz,
  { {0x6f1801f7,0x64420072,0xc6a405f1,0x00000000}},	//   _mevc, etoi, орци,
  { {0x290002f6,0x09e4000a,0x7d1d67e4,0x00000000}},	//   ccia_, _моќн, nass,
  { {0x7dd6000f,0x65605ad4,0xc8790075,0x00000000}},	//   záso, _damh, _çş_,
  { {0xb3c801dd,0x7c2f00e5,0x98a90022,0x00000000}},	//   аліз_, ircr, egać_,
  { {0xe6950032,0x644267e5,0xcb140063,0x00000000}},	//   _الأد, atoi, קלק_,
  { {0x78b8007d,0x645b0139,0x6fdd0003,0x00000000}},	//   šavš, _tsui, ièce,
  { {0x64420164,0x29191ab1,0x91690013,0x00000000}},	//   ctoi, _mesa_, _cứu_,
  { {0x7dd603e8,0xc0c80001,0x3f830026,0x00000000}},	//   táso, јуће_, ðju_,
  { {0x7d1d0199,0x7ddd3ae8,0x201f0016,0x00000000}},	//   fass, zése, ssui_,
  { {0x7d1d000f,0xdced00c3,0x7dd600ea,0x00000000}},	//   gass, _enač, ráso,
  { {0x2d9e0006,0x6d46120a,0x7c2900c2,0x00000000}},	//   ėte_, rfka, šern,
  { {0x3b950d34,0xef190002,0x7d1d01cf,0x00000000}},	//   ојст, _смк_, aass,
  { {0x29000066,0xdcfd0058,0x699616e0,0x00000000}},	//   tcia_, ansı, брах,
  { {0x7ddd03e8,0xe9df001b,0xcc8a0032,0x00000000}},	//   tése, _chú_, _منبه_,
  { {0xa96718cc,0x291967e6,0x9876005e,0x00000000}},	// [df20] щита_, _desa_, љубљ,
  { {0x2900277d,0xc8b50088,0x7ddd572a,0x00000000}},	//   scia_, істы, rése,
  { {0x7ddd000f,0x2e230058,0xdb1c01e1,0x00000000}},	//   sése, nıf_, toræ,
  { {0x7ddd000f,0x29190397,0x66030080,0x00000000}},	//   pése, _gesa_, ínka,
  { {0xf3f1001b,0xdb1c00cd,0xfe67007e,0x00000000}},	//   _bị_, gorç, _کد_,
  { {0x64422b79,0x2e230058,0x2327005e,0x00000000}},	//   rtoi, kıf_, бољи_,
  { {0x7d040b88,0x644267e7,0x20060022,0x00000000}},	//   _ofis, stoi, _stoi_,
  { {0x60f8005a,0x7ddd00ea,0x7c245080,0x00000000}},	//   шния_, zésb, _ovir,
  { {0xdb1c00cd,0x6f1800c2,0x7d1d67e8,0x00000000}},	//   corç, _pevc, vass,
  { {0x63a40173,0x8ff70021,0x7d04455f,0x00000000}},	//   ëind, حرير_, _afis,
  { {0x7ddd00ea,0x7c24109c,0x8266005d,0x00000000}},	//   vésb, _avir, _دهان,
  { {0xc6930047,0x7df3003b,0x68e20078,0x00000000}},	//   פאר_, _răst, žody,
  { {0x3ced0019,0x7ddd00ea,0x7d1d61fc,0x00000000}},	//   äev_, tésb, rass,
  { {0x7df3000c,0x7d04014f,0xce94005a,0x00000000}},	//   _păst, _efis, _малъ,
  { {0x2919090c,0xe9df008b,0xb9270062,0x00000000}},	//   _pesa_, _phú_, йфай,
  { {0x442f0026,0xa8150062,0x7ddd00ea,0x00000000}},	//   yrg_, ждаш, sésb,
  { {0x9169008b,0x7ddd00ea,0xf8bf0331,0x00000000}},	// [df30] _hữu_, pésb, _edén_,
  { {0x6fdd0164,0xba5500e1,0x29190035,0x00000000}},	//   pèce, _двој, _wesa_,
  { {0x9f470080,0xe9df67e9,0x291901f4,0x00000000}},	//   _jiná_, _thú_, _tesa_,
  { {0x7bd500bd,0x2e3b0047,0xa4d5005e,0x00000000}},	//   llzu, רגאנ, ожељ,
  { {0x29d7017d,0x442f2d49,0x64460b49,0x00000000}},	//   nçam_, urg_, _äkil,
  { {0x9cd80063,0x4209197a,0x61fa67ea,0x00000000}},	//   צוגה_, анко_, _butl,
  { {0xf3f1001b,0x386967eb,0x798600ac,0x00000000}},	//   _vị_, lvar_, _yokw,
  { {0xdb1c017d,0x394967ec,0x7dd6013d,0x00000000}},	//   porç, nfas_, tásm,
  { {0x38692ecd,0xf3f1008d,0xd49b0094,0x00000000}},	//   nvar_, _tị_, _срв_,
  { {0xd00e007e,0x38694fec,0x6fa9005e,0x00000000}},	//   کلی_, ivar_, рвог_,
  { {0x7645001f,0x7c2467ed,0x31ba0023,0x00000000}},	//   nthy, _svir, cīzo_,
  { {0xe2940047,0x7645002b,0x763a0041,0x00000000}},	//   _צװײ_, ithy, סערג,
  { {0x5d670076,0xf1d50042,0xac930085,0x00000000}},	//   циям_, _डीएन, даўш,
  { {0x7ddd000f,0x9f4300fe,0x6d4d004b,0x00000000}},	//   tésc, öjä_, _ebaa,
  { {0x29d70555,0x3869001c,0x39490504,0x00000000}},	//   açam_, evar_, ffas_,
  { {0x39460088,0x7c240006,0x7ddd017d,0x00000000}},	//   ўнаг, _tvir, résc,
  { {0x77860001,0x66091eb3,0x7645001f,0x00000000}},	// [df40] олаз, _čeka, ethy,
  { {0x2d82074f,0x3b0a0001,0xdaaa0121,0x00000000}},	//   ljke_, _њено_, _ввод_,
  { {0xd6260021,0x7dd6336c,0x4c05007e,0x00000000}},	//   تعذي, jásk, _وظیف,
  { {0xceb200ff,0x7dd6013d,0x44240072,0x00000000}},	//   ויב_, dásk, _pvm_,
  { {0x5c370041,0x19570063,0x53e6536d,0x00000000}},	//   ַרקן_, _ובכל_, оцка,
  { {0x366a000d,0xb6a6005e,0xbebc008f,0x00000000}},	//   _каго_, _дигл, rgīz,
  { {0xe2970138,0x1b7b0041,0xd6272184,0x00000000}},	//   жај_, יטסע, _море_,
  { {0x764300cd,0x6fd400cd,0x99f7009a,0x00000000}},	//   ànye, màci, חזקה_,
  { {0xb145005d,0x83fd013d,0x00000000,0x00000000}},	//   سیوم_, _csőd,   ,
  { {0xff980138,0x7dd600ea,0x75290022,0x00000000}},	//   ској_, lásh, _zdez,
  { {0x4106000d,0xb7db0047,0x61460454,0x00000000}},	//   _дзев, שקיי, _межа,
  { {0xdb070066,0xeda70054,0xbcfb006c,0x00000000}},	//   rijí, ішно, rdéo,
  { {0x7b6705d2,0xed58000d,0x3f8767ee,0x00000000}},	//   отве, цоў_, _fonu_,
  { {0x7645001f,0x60d70063,0x69d600ea,0x00000000}},	//   ythy, _וודא_, elye,
  { {0x61e236a1,0xdb0e00ea,0x69d604aa,0x00000000}},	//   _khol, ójáb, flye,
  { {0x3f872341,0x38693cc4,0x2bdb0082,0x00000000}},	//   _zonu_, tvar_, _मीरा,
  { {0x61e20025,0xbcfb3977,0x3f9e004b,0x00000000}},	// [df50] _mhol, ndém, ohtu_,
  { {0xe945007e,0x38691bb7,0x2b58003b,0x00000000}},	//   _کردی, rvar_, cerc_,
  { {0xd5750b62,0x38690d7d,0x7c2a008f,0x00000000}},	//   зуль, svar_, _āfri,
  { {0x76450185,0xea00008d,0xbc68005d,0x00000000}},	//   rthy, _hiết_, _امین_,
  { {0xa97a0063,0xea000013,0xd4690092,0x00000000}},	//   _הארכ, _kiết_, силе_,
  { {0x57f40076,0xd7fa0063,0x7dd600ea,0x00000000}},	//   _опят, _להשל, tásk,
  { {0x6fd400cd,0xdb1500ea,0x7f8d00cd,0x00000000}},	//   càci, lozó, _xúqu,
  { {0xd24e0067,0xe4e70086,0x3f8729c5,0x00000000}},	//   اني_, _дізн, _sonu_,
  { {0x25ad00c3,0x9627008f,0x6009005e,0x00000000}},	//   _imel_, saņē, љном_,
  { {0x7dd6017d,0x398e0014,0x25bf0196,0x00000000}},	//   mási, _hýst_, _hjul_,
  { {0x25bf06a5,0x61e20139,0x80dd0053,0x00000000}},	//   _kjul_, _fhol, _परवे,
  { {0x6e2e00ea,0x61e206f7,0xdb1500ea,0x00000000}},	//   ábba, _ghol, kozó,
  { {0xea00001b,0x61e90c23,0xdb0e0003,0x00000000}},	//   _biết_, mmel, libé,
  { {0x61e967ef,0xdb1c021a,0x398e0026,0x00000000}},	//   lmel, lorú, _lýst_,
  { {0xdb0e01a8,0x09e639ed,0x2b9400a5,0x00000000}},	//   nibé, зовн, _häck_,
  { {0x61e967f0,0xf2d20047,0x61fe00be,0x00000000}},	//   nmel, געל_, ípli,
  { {0x61e91383,0x61360058,0x7dd667f1,0x00000000}},	// [df60] imel, lülü, vásh,
  { {0x4a460001,0xea00008b,0x91fc001c,0x00000000}},	//   _енов, _giết_, _krāt,
  { {0x69c10164,0x7dd600ea,0x61e94c5c,0x00000000}},	//   élec, tásh, kmel,
  { {0x6fd400cd,0x6f1c0051,0x7c2600c2,0x00000000}},	//   ràci, órcz, oskr,
  { {0x17fa0021,0x9f5f017d,0x6fd400cd,0x00000000}},	//   _درجة_, rquê_, sàci,
  { {0x25ad0d87,0x53342f9e,0x61e967f2,0x00000000}},	//   _emel_, фект, emel,
  { {0x9f4700fe,0x7d1b0026,0x61e213d5,0x00000000}},	//   _minä_, ðusk, _phol,
  { {0xb6bb0063,0xdb1c00ea,0x78a40b59,0x00000000}},	//   _הצלי, gorú, oziv,
  { {0x7df40529,0x78a41871,0x7dd60516,0x00000000}},	//   _răsp, nziv, cási,
  { {0x61e20034,0x9f5f00cd,0x2b940137,0x00000000}},	//   _whol, nquè_, _däck_,
  { {0x7c26023a,0xdb1c00ea,0xdd210078,0x00000000}},	//   eskr, ború, rįžk,
  { {0x61e20035,0x442622bf,0x7c260026,0x00000000}},	//   _uhol, oso_, fskr,
  { {0x442667f3,0x7c2667f4,0x9be70054,0x00000000}},	//   nso_, gskr, зівк,
  { {0x442667f5,0x200b67f6,0x78a40066,0x00000000}},	//   iso_, ície_, dziv,
  { {0xea00001b,0xbef70021,0xda78042c,0x00000000}},	//   _viết_, _عروض_, пят_,
  { {0x7c2667f7,0x6e3a004d,0xceb30063,0x00000000}},	//   bskr, mutb, _ריק_,
  { {0x91fc003d,0xea00001b,0x6934000d,0x00000000}},	// [df70] _krās, _tiết_, энту,
  { {0x4c9c014e,0x307b0047,0x25ad00c2,0x00000000}},	//   _לבחו, זאמנ, _smel_,
  { {0x78a4007d,0x442667f8,0x6e3a00a5,0x00000000}},	//   aziv, eso_, nutb,
  { {0x3ea10019,0x7ddd013d,0x04d90141,0x00000000}},	//   _ühte_, zésn, омеј_,
  { {0xf8c10161,0xc8670121,0x61e922db,0x00000000}},	//   _एशिय, _этни, vmel,
  { {0x6e3a5805,0x7dd667f9,0xe4580054,0x00000000}},	//   kutb, rási, яжі_,
  { {0x7d060137,0x236500c2,0x44260419,0x00000000}},	//   ycks, _valj_, aso_,
  { {0xd9e30053,0x61e9003b,0xdb0e01a8,0x00000000}},	//   _कीमत_, umel, ribé,
  { {0x7ddd00ea,0xafe50002,0x61e967fa,0x00000000}},	//   tésn, моил, rmel,
  { {0x91fc001c,0xa8580063,0x61360058,0x00000000}},	//   _prāt, ליחה_, tülü,
  { {0xdb1c0024,0x9f5f0003,0x83fd013d,0x00000000}},	//   porú, nqué_, _erőt,
  { {0x9f4700fe,0x6136005b,0xdb0500cd,0x00000000}},	//   _sinä_, rülü, _amhà,
  { {0x4c83005a,0x7c2619fb,0x7bce67fb,0x00000000}},	//   вляв, uskr, tobu,
  { {0x6d4100ea,0x7c260246,0x7076005d,0x00000000}},	//   őlap, rskr, _آموز_,
  { {0x7bce67fc,0x7c2667fd,0xfa6720e5,0x00000000}},	//   robu, sskr, марк_,
  { {0xe9da0651,0x4426001f,0x7c2667fe,0x00000000}},	//   іка_, yso_, pskr,
  { {0x79840089,0x68460085,0xeafa0044,0x00000000}},	// [df80] rjiw, ьнаа, _وردت_,
  { {0x799600ac,0x386f0014,0x78a443c6,0x00000000}},	//   skyw, ægra_, rziv,
  { {0x9f5f0994,0x15460076,0x5b7b0063,0x00000000}},	//   rquè_, деем, _וריא,
  { {0x442611c5,0x6fd401a8,0xe57a0766,0x00000000}},	//   tso_, làct, юзе_,
  { {0x045a0021,0x442667ff,0x99830078,0x00000000}},	//   تجات_, uso_, aujų_,
  { {0x44262bbd,0xa3a80053,0x25bd002b,0x00000000}},	//   rso_, खों_, anwl_,
  { {0x44266800,0x6fdd00cd,0x31ba001c,0x00000000}},	//   sso_, tècn, līzi_,
  { {0x3253011c,0x61430138,0x39406801,0x00000000}},	//   твър, већа, ngis_,
  { {0x39404a1d,0x38600150,0xcfaa0021,0x00000000}},	//   igis_, nwir_, قادم_,
  { {0x83fd00ea,0xada40051,0x187b0063,0x00000000}},	//   _erős, óźni, קטיב,
  { {0x6fd400cd,0x07370063,0xd737009a,0x00000000}},	//   dàct, ואים_, וטית_,
  { {0x6e3a0137,0x7ddd0003,0x3217007e,0x00000000}},	//   rutb, réso, _آيند_,
  { {0xdb050027,0x50e20053,0x6023000d,0x00000000}},	//   _amhá, _परिष, _адча,
  { {0x21240025,0x3860002b,0x7dd6013d,0x00000000}},	//   lamh_, dwir_, dásu,
  { {0x6fdd0003,0x298b005e,0x8fa301ce,0x00000000}},	//   iècl, осао_, _јаје,
  { {0x21240027,0x752000ea,0x2d840137,0x00000000}},	//   namh_, _nemz, ömet_,
  { {0x6d5d6802,0x8b670021,0x98480062,0x00000000}},	// [df90] mesa, _قادم, дяха_,
  { {0x6d5d6803,0x399c0014,0x58380121,0x00000000}},	//   lesa, _vísa_, ьзуя_,
  { {0xa535000a,0xfbdf0016,0x7c3d078c,0x00000000}},	//   енеч, ntêm_, lusr,
  { {0x9f5f2500,0x2d99006f,0xfa960063,0x00000000}},	//   rqué_, nkse_, _נדרש_,
  { {0x31ba001c,0x6d5d001c,0x9f5f2425,0x00000000}},	//   cīzi_, iesa, squé_,
  { {0x6d5d0d69,0xd7c9007e,0x44290013,0x00000000}},	//   hesa, _روزه_, ĩa_,
  { {0x6d5d08a4,0x7ddd00ea,0xd5bb04d8,0x00000000}},	//   kesa, tésl, _дса_,
  { {0x2d990122,0x6d4f006f,0xdb0710f0,0x00000000}},	//   jkse_, jfca, lijä,
  { {0x6d5d6804,0x83fd009c,0x89ec009a,0x00000000}},	//   desa, _erőr, חַזֵ,
  { {0x2d990179,0x0ea90076,0x6d446805,0x00000000}},	//   ekse_, зкой_, _scia,
  { {0x443d09e9,0x6d5d124c,0xb1150085,0x00000000}},	//   luw_, fesa, _змеш,
  { {0xe20a0026,0x3860001f,0x443d006f,0x00000000}},	//   slóð_, ywir_, ouw_,
  { {0x644b00e8,0xdb0700fe,0x67250019,0x00000000}},	//   ntgi, kijä, kahj,
  { {0x2d990019,0x91fc001c,0x6d5d188a,0x00000000}},	//   akse_, _krāp, aesa,
  { {0x6fd40994,0x6d5d028d,0xc4dc0053,0x00000000}},	//   ràct, besa, _बर्ख,
  { {0x6d5d6806,0x7dd66807,0x7db50085,0x00000000}},	//   cesa, tásu, _асьц,
  { {0x26de0a0d,0x38c8006a,0x26d80d18,0x00000000}},	// [dfa0] _što_, ذاری_, _syro_,
  { {0x443d006f,0x46a6085e,0xd8770044,0x00000000}},	//   duw_, назв, عملت_,
  { {0x443d0122,0x394000d1,0xbb3b0047,0x00000000}},	//   euw_, pgis_, _צעטי,
  { {0x7ae10b35,0xb5a90021,0x26d80078,0x00000000}},	//   ülte, وانك_, _vyro_,
  { {0x7dd61584,0xdb0e0331,0xf71a0085,0x00000000}},	//   láss, hibí, _нівы_,
  { {0xdb15006d,0xd62a0074,0x6d5d6808,0x00000000}},	//   onzá, _ноге_, zesa,
  { {0x3afb0047,0x6d5d5552,0x26de0066,0x00000000}},	//   פּגע, yesa, _áto_,
  { {0xea00001b,0x24496809,0x7ddd013d,0x00000000}},	//   _nhật_, búm_, tésm,
  { {0x6d5d3853,0x82fa007e,0xdfda0094,0x00000000}},	//   vesa, _فراز_, зън_,
  { {0x29d700cd,0x200b680a,0x6e9836b6,0x00000000}},	//   lçat_, ícia_, двор_,
  { {0x7054006a,0x6d5d680b,0x7dd6013d,0x00000000}},	//   رنگا, tesa, jáss,
  { {0x29d70268,0xea000013,0x10a60062,0x00000000}},	//   nçat_, _chật_, _пиен,
  { {0x6d5d680c,0x2d990229,0xd00f005d,0x00000000}},	//   resa, rkse_, _هلن_,
  { {0x6d5d18c2,0x2d99004b,0x307b0041,0x00000000}},	//   sesa, skse_, _מאדנ,
  { {0xdb0700fe,0xdb0e0118,0x6d5d680d,0x00000000}},	//   vijä, cibí, pesa,
  { {0x59f80121,0x5c7502b3,0x9991013d,0x00000000}},	//   ееся_, _алит, tsző_,
  { {0xdb070656,0x7dd6680e,0x6569004e,0x00000000}},	// [dfb0] tijä, rást, _raeh,
  { {0x7dd6336c,0x7c2d680f,0xd75900de,0x00000000}},	//   sást, _ivar, ظلات_,
  { {0x7dd62bad,0xfc3f00be,0xc7c42ff5,0x00000000}},	//   pást, luí_, усти,
  { {0x7c2d6810,0x7dd600ea,0xdb0701cf,0x00000000}},	//   _kvar, lásr, sijä,
  { {0x644b380f,0x656b0139,0x6d5a013d,0x00000000}},	//   utgi, rdgh, őtag,
  { {0x7dd6013d,0xdb1c017c,0x8c1c009a,0x00000000}},	//   násr, korý, לודי,
  { {0xfc3f0139,0x92560141,0x24490014,0x00000000}},	//   huí_, вајт_, súm_,
  { {0x36d40121,0x96f806b4,0x7c2d3e5a,0x00000000}},	//   _соср, _чест_, _ovar,
  { {0xa1560001,0x29d7017d,0x7dd600ea,0x00000000}},	//   тању_, lças_, záss,
  { {0x7d0d6208,0xfc3f00cd,0xdced007d,0x00000000}},	//   _afas, duí_, _znać,
  { {0x29d703d9,0xd131006a,0x63a10034,0x00000000}},	//   nças_, _نما_, _illn,
  { {0xfbc90063,0xdb0e0331,0x8f03005e,0x00000000}},	//   _ות_, ribí, аjу_,
  { {0xb87b000f,0xfc3f6811,0x200f00d1,0x00000000}},	//   _szín, guí_, _utgi_,
  { {0x4fe80086,0x7dd600ea,0x7d0d0014,0x00000000}},	//   _змін_, táss, _efas,
  { {0xea00001b,0x7f560635,0x7d0d001f,0x00000000}},	//   _thật_, _рајс_, _ffas,
  { {0x7d1b007a,0x442d04cc,0x316d6812,0x00000000}},	//   ðust, _ove_, ndez_,
  { {0xa3e40161,0x3946001c,0x31ba001c,0x00000000}},	// [dfc0] नतम_, ļos_, cīzu_,
  { {0xeb9f069f,0x6ff20022,0x00000000,0x00000000}},	//   spør_, _płci,   ,
  { {0x7dd60331,0x7c2d00a8,0xb3310054,0x00000000}},	//   lásq, _zvar, _спiл,
  { {0x25a00025,0xf8bf00cd,0x08fa0044,0x00000000}},	//   óil_, _adéu_, _يرحب_,
  { {0x29d76470,0xd46701ce,0xa533014b,0x00000000}},	//   aças_, кице_, рніч,
  { {0x798f00ac,0x442d0648,0x7ddd013d,0x00000000}},	//   _zocw, _dve_, tésk,
  { {0x2480000c,0xdb1c0051,0x442d16d6,0x00000000}},	//   ţim_, loró, _eve_,
  { {0x7dd6000f,0x29d704a5,0x6fdd0003,0x00000000}},	//   zásr, lçar_, lèch,
  { {0x03260088,0x67470026,0x4fd40174,0x00000000}},	//   _адзн, _þrjá, лжит,
  { {0x29d70bd1,0xdb1c0024,0x1f73026c,0x00000000}},	//   nçar_, torý, алья,
  { {0xc7b30063,0x25a62b21,0x7ddd411f,0x00000000}},	//   שבת_, ohol_, lési,
  { {0x25a6409d,0x63b838da,0xfc3f03ea,0x00000000}},	//   nhol_, livn, tuí_,
  { {0x7dd600ea,0x4034065b,0x4fc66813,0x00000000}},	//   tásr, _селс, _иска,
  { {0x7ddd00ea,0x8fa3005e,0x39950246,0x00000000}},	//   zésh, _ваље, _låst_,
  { {0x75fa0080,0x7ddd0164,0x6fdd1ecf,0x00000000}},	//   _různ, hési, dèch,
  { {0x39a40f30,0x7c2d1dd9,0x7d0d0022,0x00000000}},	//   ашув, _tvar, _ufas,
  { {0xfc3f1c50,0xdb1c01a8,0x8b080022,0x00000000}},	// [dfd0] quí_, goró, _stęż,
  { {0x7ddd0b6d,0x0574005d,0x7dd6013d,0x00000000}},	//   dési, یاند, lásp,
  { {0x442d0117,0x7ddd00ea,0x37040086,0x00000000}},	//   _sve_, tésh, рчув,
  { {0x29d76814,0x4eb50047,0xceb30063,0x00000000}},	//   rças_, נהײב_, סיף_,
  { {0xdb0e240a,0x7ddd6815,0xc4f80044,0x00000000}},	//   libá, résh, نعها_,
  { {0xbcfb000f,0x63b84bc3,0x68d40001,0x00000000}},	//   ldés, givn, _ђорђ,
  { {0x7ddd00ea,0xeb92089e,0xfc3f017c,0x00000000}},	//   pésh, מָה_, dzím_,
  { {0x200b03d9,0x45d50432,0x22560021,0x00000000}},	//   ício_, _собс, اليد_,
  { {0x316d11f5,0x442d01f4,0x4439239e,0x00000000}},	//   rdez_, _uve_, _ís_,
  { {0x8fa5007e,0x9f850169,0xea00008d,0x00000000}},	//   امده, угод, _giặt_,
  { {0x6fdd00cd,0xd215005e,0x7bd5013d,0x00000000}},	//   nèci, _смећ, dozu,
  { {0xea000013,0x25d50063,0x6da6005e,0x00000000}},	//   _nhạt_, רוֹן_, уима,
  { {0xa3c70235,0xac9a0021,0x91f6009a,0x00000000}},	//   _उदा_, رنسا_, _עמנו_,
  { {0xd00e043b,0xf1b9350b,0xfc0300fd,0x00000000}},	//   _على_, liš_, спро,
  { {0x32050034,0x15f50161,0x31ba008f,0x00000000}},	//   _july_, ेदार_, cīzs_,
  { {0xdb1c0051,0x63b81ba3,0xf1b929c3,0x00000000}},	//   toró, zivn, niš_,
  { {0x88e60be6,0x2d8000a4,0x4ddb0041,0x00000000}},	// [dfe0] ужае, _inie_, _אַזױ,
  { {0x6d4605e7,0xab666816,0x00000000,0x00000000}},	//   lgka, _свол,   ,
  { {0x25a6001f,0x29d71997,0x7c220058,0x00000000}},	//   thol_, rçar_, _çorb,
  { {0x6d465299,0x6e2e00ea,0x236c01a8,0x00000000}},	//   ngka, ábbi, _sadj_,
  { {0x2d800045,0x200b12c7,0x63b82b91,0x00000000}},	//   _mnie_, ícil_, tivn,
  { {0x7ddd0164,0x62980078,0x69c46817,0x00000000}},	//   rési, tyvo, lnie,
  { {0x63b86818,0xbb3b0047,0x645b003b,0x00000000}},	//   rivn, געצי, _epui,
  { {0xc0340540,0xd01a130d,0x7dc80058,0x00000000}},	//   аниј, нфо_, yısa,
  { {0xf9930063,0x99980078,0x69c46819,0x00000000}},	//   מרה_, ltrų_, inie,
  { {0xbcfb00ea,0x6562004b,0x8f34005e,0x00000000}},	//   zdés, leoh, јенц,
  { {0x7bd50080,0x9d19000d,0xf1b929ef,0x00000000}},	//   vozu, конт_, biš_,
  { {0x69d60034,0xd00a0002,0x65621e3d,0x00000000}},	//   joye, _зеде_, neoh,
  { {0x69c4127a,0x2d800022,0x00000000,0x00000000}},	//   dnie, _dnie_,   ,
  { {0x6d4600bb,0xd2460242,0x7f960003,0x00000000}},	//   agka, ين_, _pâqu,
  { {0x9f470080,0xea00008b,0xcfb70063,0x00000000}},	//   _jiný_, _phạt_, _תלוי_,
  { {0x69c4681a,0x69d60e1a,0x64420072,0x00000000}},	//   gnie, goye, kuoi,
  { {0xbcfb000f,0xa3e40053,0x6562681b,0x00000000}},	// [dff0] rdés, नता_, deoh,
  { {0x69c4681c,0x2d800066,0x7c2f581c,0x00000000}},	//   anie, _znie_, mscr,
  { {0x69c43c80,0x7c2f188f,0xdd21004c,0x00000000}},	//   bnie, lscr, _můžo,
  { {0xdb1c007a,0x2419026c,0x69c40051,0x00000000}},	//   lorð, воды_, cnie,
  { {0x3f9e0026,0xd46906b6,0x7c2f5cc2,0x00000000}},	//   kktu_, тиле_, nscr,
  { {0x6fdd0268,0x4787000d,0x32350086,0x00000000}},	//   pèci, _сымб, ахис,
  { {0xfe09008b,0x798d0051,0xf1b9007d,0x00000000}},	//   _mắc_, ojaw, tiš_,
  { {0x798d0397,0x200601f4,0xdc340066,0x00000000}},	//   njaw, _buoi_, _súče,
  { {0x78ad01f4,0xf1b93741,0x7f190083,0x00000000}},	//   nzav, riš_, кіну_,
  { {0x7d1d00bd,0x81bc001c,0x69c41e57,0x00000000}},	//   ebss, _svēt, znie,
  { {0x7c2f1459,0x69c4681d,0x20020046,0x00000000}},	//   escr, ynie, íkir_,
  { {0x3f9e681e,0x81bc008f,0x6727013d,0x00000000}},	//   aktu_, _dvēs, _lejj,
  { {0x69d603b2,0xfe09001b,0x69c4001c,0x00000000}},	//   voye, _bắc_, vnie,
  { {0x69c40045,0xb92b0013,0x6727004c,0x00000000}},	//   wnie, _thuỷ_, _nejj,
  { {0x6f7a014e,0x69d60164,0x7f3a00b5,0x00000000}},	//   _יְהו, toye, _סעקו,
  { {0x7c2f0951,0x69c4681f,0x2d806820,0x00000000}},	//   bscr, unie, _unie_,

  { {0xdb1c0026,0x69d64696,0x7ddd00ea,0x00000000}},	// [e000] borð, roye, tésv,
  { {0x69c4003d,0x1783000a,0x998d085a,0x00000000}},	//   snie, огум, češ_,
  { {0x443d0051,0x69c46821,0xbb3b0063,0x00000000}},	//   erw_, pnie, _בעיי,
  { {0x1e560047,0x644201cf,0x998a0078,0x00000000}},	//   ישער_, tuoi, rubų_,
  { {0x9f4f006d,0x7ddd0b23,0x6fdd00cd,0x00000000}},	//   _jugó_, mést, lècu,
  { {0xd25a0571,0x93b32049,0x6562078c,0x00000000}},	//   вци_, обіц, seoh,
  { {0x200602f6,0xd6da007e,0x443d002b,0x00000000}},	//   _suoi_, _شورش_, arw_,
  { {0x200602f6,0x7d040150,0x7c3d0829,0x00000000}},	//   _puoi_, _ngis, yrsr,
  { {0x20060164,0x64a31fa5,0x7cf10014,0x00000000}},	//   _quoi_, _дата, iðré,
  { {0x200602f6,0x7d04292b,0xa8570063,0x00000000}},	//   _vuoi_, _agis, סייה_,
  { {0x3f9e0026,0x78ad2c61,0x21260089,0x00000000}},	//   rktu_, zzav, _teoh_,
  { {0x200602f6,0xfe09008b,0xc1070076,0x00000000}},	//   _tuoi_, _sắc_, _кэше_,
  { {0x7c3d006f,0x7c2f006d,0x29de002b,0x00000000}},	//   ursr, uscr, nïau_,
  { {0x69c8236b,0x7d046822,0x3d29005d,0x00000000}},	//   éden, _egis, ختگی_,
  { {0xdb1c0ac6,0xff170063,0xba08005a,0x00000000}},	//   rorð, _דקות_, ихте_,
  { {0x78ad00cd,0x442f001f,0xdce6005b,0x00000000}},	//   tzav, ysg_, akkı,
  { {0x7c240185,0xfe09001b,0xbda7007e,0x00000000}},	// [e010] _gwir, _tắc_, _محکو,
  { {0xfc3f0139,0x36d50121,0x7dc80058,0x00000000}},	//   mrí_, бозр, hısl,
  { {0x78ad000f,0x995c0080,0x17f80021,0x00000000}},	//   szav, _síť_, شركة_,
  { {0x7bc700c3,0x6fdd00cd,0xeef70063,0x00000000}},	//   lnju, lèct, במבר_,
  { {0x91fc003d,0x4424001f,0x7ddd00ea,0x00000000}},	//   _frāz, _cwm_, léss,
  { {0xfc3f0027,0xdb15000c,0x9cd80063,0x00000000}},	//   irí_, lizâ, בודה_,
  { {0x92640021,0x356b17e1,0xfbdf00be,0x00000000}},	//   قديم, _иран_, ltês_,
  { {0x39496823,0xe7eb0053,0xdb1500dd,0x00000000}},	//   ngas_, _जीता_, nizâ,
  { {0x386924af,0x4424002b,0x39496824,0x00000000}},	//   nwar_, _gwm_, igas_,
  { {0xf8b20063,0xfc3f00cd,0xdb15003b,0x00000000}},	//   פשי_, drí_, hizâ,
  { {0x9f470268,0x59c70053,0xfc3f6825,0x00000000}},	//   _sinó_, रचार, erí_,
  { {0xd1640062,0xd00e007e,0xea00008d,0x00000000}},	//   _мъчи, بلی_, _khất_,
  { {0xfc3f6826,0x39490ae2,0x7ddd011b,0x00000000}},	//   grí_, dgas_, vést,
  { {0x3869001f,0x69dd60b7,0x39496827,0x00000000}},	//   dwar_, _akse, egas_,
  { {0xfaa300d7,0x3a990086,0x7ddd10fd,0x00000000}},	//   паро, аттю_, tést,
  { {0x394914f5,0xf2d20047,0x99f60086,0x00000000}},	//   ggas_, פען_, сягі,
  { {0xea00001b,0xcc360021,0x25bd002b,0x00000000}},	// [e020] _nhất_, _اربع, diwl_,
  { {0x69dd02ab,0xb2260026,0x39490078,0x00000000}},	//   _ekse, nmæð, agas_,
  { {0xe3c8008b,0x4424001f,0xbebc008f,0x00000000}},	//   hực_, _swm_, rbīg,
  { {0x99860032,0x7ddd00ea,0xdb1500dd,0x00000000}},	//   _الحو, lésr, cizâ,
  { {0xea00001b,0x7529006f,0x43940121,0x00000000}},	//   _chất_, _deez, жалс,
  { {0x29de001f,0x69c10003,0x7ddd013d,0x00000000}},	//   rïau_, élev, nésr,
  { {0xdb150016,0x29de001f,0x52370021,0x00000000}},	//   lizã, sïau_, مسيح_,
  { {0x29de001f,0xdb156828,0x4424002b,0x00000000}},	//   pïau_, vizí, _twm_,
  { {0x7ddd00ea,0xd0070002,0xa98b0041,0x00000000}},	//   zéss, бење_, אָיִ,
  { {0x752900ca,0x39490078,0xe3a4005d,0x00000000}},	//   _zeez, zgas_, _بشری,
  { {0x11d60376,0x7a150051,0x39490078,0x00000000}},	//   _людя, _kąte, ygas_,
  { {0xc693014e,0xfc3f0024,0x69c800ea,0x00000000}},	//   לאת_, trí_, édel,
  { {0x9f340054,0xab870062,0x9f5f0046,0x00000000}},	//   _делі, бувк, ppuð_,
  { {0x7ddd00ea,0x7bc7017e,0xfc3f0331,0x00000000}},	//   téss, unju, rrí_,
  { {0x0f5701f9,0xfe090013,0x3d95422b,0x00000000}},	//   _היום_, _hắn_, _микр,
  { {0x39494e70,0x7bc700c2,0xf9190062,0x00000000}},	//   ugas_, snju, ржащ_,
  { {0x23ab00b9,0x75290089,0xa2da0053,0x00000000}},	// [e030] _høje_, _reez, _पुस्,
  { {0xdb0f00fe,0x9b590002,0xfe09008b,0x00000000}},	//   äjät, _тиот_, _mắn_,
  { {0xa6c80044,0x1995014b,0x8b88009a,0x00000000}},	//   موكل_, _даня, _הָרֶ,
  { {0xea00008d,0x69dd3822,0x78bb0078,0x00000000}},	//   _phất_, _ukse, _žuvu,
  { {0xf1c90013,0x15f40021,0x87e70062,0x00000000}},	//   hạc_, أسلح, _гюве,
  { {0x80dc0053,0xe2996829,0x37e40085,0x00000000}},	//   _पड़े, иал_, _ноўг,
  { {0xa1890076,0x23ab00b9,0x8b9c009a,0x00000000}},	//   ибка_, _nøje_, רבות,
  { {0x7ddd000f,0xd179000d,0x3f980026,0x00000000}},	//   zésr, рскі_, örun_,
  { {0x6009005e,0x6006000d,0xf9970013,0x00000000}},	//   јном_, оным_, _đậm_,
  { {0xa9280240,0xe3c8008b,0x53340818,0x00000000}},	//   ouží, rực_, _неут,
  { {0xcee9167b,0x236700a8,0xc2750699,0x00000000}},	//   рдне_, menj_, _флеј,
  { {0x7d090006,0x82d60047,0x6e3c00ea,0x00000000}},	//   žesn, _וועג_, árba,
  { {0x7ddd000f,0x2247000f,0x399c0080,0x00000000}},	//   tésr, lunk_, _míst_,
  { {0xbea5071a,0x23ab0146,0x98a2003d,0x00000000}},	//   _малк, _føje_, _nekā_,
  { {0xbb430002,0x7ddd013d,0x3af50121,0x00000000}},	//   ќеск, résr, зятс,
  { {0x7ddd00ea,0xdb0e0014,0xdce40130,0x00000000}},	//   sésr, nibú, _naić,
  { {0x7ddd00ea,0xe9d72049,0x48e35394,0x00000000}},	// [e040] pésr, іку_, дотв,
  { {0xe73a0086,0xaadb0053,0x236700c2,0x00000000}},	//   реж_, _मुवक, jenj_,
  { {0xa6ca0021,0x7dd600ea,0x236700c2,0x00000000}},	//   جوال_, dász, denj_,
  { {0xa2da0161,0x75d30032,0x224700ea,0x00000000}},	//   _पुष्, ويلا, dunk_,
  { {0xdb15682a,0xeafa007e,0xb87b00ea,0x00000000}},	//   lizá, _حرکت_, _szív,
  { {0xfe09008b,0x7a150051,0x245246db,0x00000000}},	//   _rắn_, _wąte, râm_,
  { {0x224700ea,0xfe090013,0xdb15682b,0x00000000}},	//   gunk_, _sắn_, nizá,
  { {0xf12615d4,0xba9b0041,0x7bdc682c,0x00000000}},	//   цько, יסצי, horu,
  { {0xa2da0235,0xd5b90088,0xc3560062,0x00000000}},	//   _पुर्, _усё_, _мъжъ,
  { {0x9182008b,0xfe09008d,0x321c00a5,0x00000000}},	//   iểu_, _vắn_, ppvy_,
  { {0xc2c6007e,0x7bdc682d,0xdb1c0244,0x00000000}},	//   _بياي, doru, inrä,
  { {0xd83f01d1,0xdb1c0244,0xdb15682e,0x00000000}},	//   íčku_, hnrä, dizá,
  { {0x7bdc331d,0xdd98014b,0xcce70044,0x00000000}},	//   foru, цшэ_, تسدي,
  { {0xbebc003d,0x64422300,0xa92801d1,0x00000000}},	//   rbīb, iroi, yuží,
  { {0xda78042c,0x7e2a0086,0xbae50021,0x00000000}},	//   оят_, _тіла_, سكري,
  { {0x7dd600ea,0x7bdc007d,0x3ea301e1,0x00000000}},	//   zász, aoru, øjte_,
  { {0x224700ea,0x613500ea,0x998a005f,0x00000000}},	// [e050] zunk_, lülí, erbų_,
  { {0x64423012,0x68310014,0x7bdc1bb1,0x00000000}},	//   droi, _aðdá, coru,
  { {0x69c100ea,0x7c360066,0x6dab004c,0x00000000}},	//   éles, _zvyr, dřaz,
  { {0x64420003,0x2247013d,0x06081cdf,0x00000000}},	//   froi, vunk_, інік_,
  { {0x638517e1,0x64421e3d,0x236700c2,0x00000000}},	//   згла, groi, tenj_,
  { {0x224700ea,0xe3b80086,0xdb1c0003,0x00000000}},	//   tunk_, обі_, tiré,
  { {0x3f89008b,0x64420072,0xdb0e0046,0x00000000}},	//   _đau_, aroi, tibú,
  { {0x9f5c2167,0x7bdc682f,0x237b0022,0x00000000}},	//   _diví_, zoru, _żyją_,
  { {0x7bdc01f7,0xdb0e0024,0x64421c5f,0x00000000}},	//   yoru, ribú, croi,
  { {0xdb1c0003,0xf2070062,0x22476830,0x00000000}},	//   piré, _дядо, punk_,
  { {0x7c360078,0x7bdc6831,0x69cf0022,0x00000000}},	//   _svyr, voru, _ojce,
  { {0xdb1500ea,0x26b6009a,0xc2c40044,0x00000000}},	//   vizá, פִים_, _تيمي,
  { {0x7bdc6832,0x20b80121,0x3cda0085,0x00000000}},	//   toru, _мышь_, сьню_,
  { {0x201f0035,0xe1f90006,0x200b0066,0x00000000}},	//   mpui_, lmų_, íciu_,
  { {0x753b017f,0x3f8701a8,0x7bdc6833,0x00000000}},	//   _oduz, _innu_, roru,
  { {0x7bdc000c,0xe1f90078,0x7d7601fb,0x00000000}},	//   soru, nmų_, _رابط,
  { {0x07a60002,0xfe090013,0x7bdc2dc2,0x00000000}},	// [e060] паан, _mắm_, poru,
  { {0x46f605fb,0xfe09008b,0x6442006c,0x00000000}},	//   пчет, _lắm_, vroi,
  { {0xd63a0086,0x8b9b0063,0xfc3f013d,0x00000000}},	//   сязі_, _הבית, szít_,
  { {0xfe09008b,0x320c6834,0xd5b90054,0x00000000}},	//   _nắm_, _rudy_, осі_,
  { {0x397b0063,0x845a005e,0x644252cb,0x00000000}},	//   _הטכנ, срет_, uroi,
  { {0x644246b5,0x7522006d,0x995c004c,0x00000000}},	//   rroi, sboz, _jíž_,
  { {0x27f70080,0x3f980026,0xcb570063,0x00000000}},	//   řené_, örum_, פסקה_,
  { {0xd657014e,0x7ae100bd,0x764300ea,0x00000000}},	//   _מילת_, ülti, ánye,
  { {0xd0070002,0xb4aa4ff3,0x04435432,0x00000000}},	//   пење_, _указ_, _петн,
  { {0x995c0080,0xe1f90006,0x3f980014,0x00000000}},	//   _níž_, amų_, ðru_,
  { {0x1df90076,0x26386835,0x1757009a,0x00000000}},	//   жены_, nčo_, הסיר_,
  { {0x7ae500fe,0x25a64d97,0xddab093d,0x00000000}},	//   _ryht, nkol_, стол_,
  { {0xed58000d,0x200b00cd,0xf1c90013,0x00000000}},	//   чоў_, ícit_, oạn_,
  { {0x661c008f,0x9b4500de,0x70fb009d,0x00000000}},	//   _otrk, بنسو, _ההדח,
  { {0x79a70088,0x1f5b0063,0xaf5b0063,0x00000000}},	//   прае, _הדוא, _הכוכ,
  { {0x1994005a,0xf773006a,0xbebc0023,0x00000000}},	//   нася, کار_, saīs,
  { {0xa2be0235,0x3f87002b,0x6d3c0063,0x00000000}},	// [e070] _वेस्, _ynnu_, _התחנ,
  { {0x97150054,0xe1f90078,0x6d5d6836,0x00000000}},	//   ємец, zmų_, lfsa,
  { {0xe1f900eb,0x36340021,0x61e20ff8,0x00000000}},	//   ymų_, فرنس, _okol,
  { {0x25a6002c,0xceb30063,0x6d4f2a5b,0x00000000}},	//   gkol_, עיף_, ngca,
  { {0x69cd453f,0xe44e0062,0xfe09008d,0x00000000}},	//   mnae, ъж_, _rắm_,
  { {0xfe090013,0x61e20050,0x00000000,0x00000000}},	//   _sắm_, _akol,   ,
  { {0xe2960062,0xe1f90078,0xa1f501ce,0x00000000}},	//   дащ_, tmų_, мџиј,
  { {0x6d5d006f,0x69cd6837,0xe1f9005f,0x00000000}},	//   jfsa, nnae, umų_,
  { {0xbf050161,0xe1f90006,0xbcfb0003,0x00000000}},	//   रश्न_, rmų_, nféd,
  { {0xdb1e0164,0x6d480006,0x644b5ebf,0x00000000}},	//   _empê, ėdam, mugi,
  { {0xdb0803b2,0x7645001f,0x51870002,0x00000000}},	//   _élém, nrhy, _нуда,
  { {0x9f450164,0x64590051,0x200b0139,0x00000000}},	//   illé_, otwi, ícis_,
  { {0x644b6838,0xa134007e,0x753600ff,0x00000000}},	//   nugi, _سرنش, וארד_,
  { {0x61e96839,0x68e600ac,0x61fb145f,0x00000000}},	//   llel, _rykd, lmul,
  { {0x644b007a,0xea00001b,0x68e600d1,0x00000000}},	//   hugi, _chết_, _sykd,
  { {0x61fb683a,0xf2d20041,0xd910005d,0x00000000}},	//   nmul, דעל_, طیس_,
  { {0x20070397,0x61fb4197,0x4806000d,0x00000000}},	// [e080] _kini_, imul, дпав,
  { {0x68e600eb,0x644b4493,0x25ad4675,0x00000000}},	//   _vykd, dugi, _alel_,
  { {0x20070246,0x463a05ac,0x61e925e4,0x00000000}},	//   _mini_, ючая_, klel,
  { {0x672e00e8,0xea00001b,0x25a600a4,0x00000000}},	//   _webj, _đặc_, ukol_,
  { {0x62814be2,0x61e9683b,0x61fb683c,0x00000000}},	//   _arlo, dlel, dmul,
  { {0x20070009,0x61fb0397,0x61e206a3,0x00000000}},	//   _nini_, emul, _skol,
  { {0x644b00eb,0x661c007d,0xf556005e,0x00000000}},	//   augi, _utrk, _отаџ,
  { {0x61e900fe,0x61fb683d,0xdb1c006d,0x00000000}},	//   glel, gmul, dirí,
  { {0xc05a019d,0xa0670856,0x64590022,0x00000000}},	//   цій_, дања_, ctwi,
  { {0x7e7c00d1,0x201900cd,0x200f0b59,0x00000000}},	//   ærpo, ísia_, _dugi_,
  { {0x61e90006,0x2007683e,0xe196000d,0x00000000}},	//   blel, _dini_, _ордэ,
  { {0x61e20117,0x56370047,0x200f0f84,0x00000000}},	//   _ukol, ואטע_, _fugi_,
  { {0x6d5d0026,0x200711ff,0xd90f007e,0x00000000}},	//   rfsa, _fini_, یید_,
  { {0xaed4005a,0x6d5d0035,0xdb1c05d5,0x00000000}},	//   _полш, sfsa, birí,
  { {0xdb1c006d,0x69cd007d,0x69c4006c,0x00000000}},	//   cirí, tnae, fiie,
  { {0xdb0700fe,0x82770047,0x200f33c6,0x00000000}},	//   kijö, ועלע_, _yugi_,
  { {0x7d0d683f,0x656b19d0,0xbcfb006c,0x00000000}},	// [e090] _igas, vegh, ffée,
  { {0x61e900ea,0x69cd440c,0xbc680043,0x00000000}},	//   zlel, snae, _کمین_,
  { {0x8704000d,0x61e03f3b,0xdd120058,0x00000000}},	//   вяце, koml, nüşm,
  { {0x7c2d539e,0x4efb0047,0xdb1e6840,0x00000000}},	//   _kwar, קלאג, _ampè,
  { {0x656b0290,0x61e06841,0xe3650b41,0x00000000}},	//   regh, doml, екли,
  { {0x3f9c0117,0xe66700a0,0x200f117f,0x00000000}},	//   _novu_, _отбо, _rugi_,
  { {0x06140088,0x644b00a4,0x20070150,0x00000000}},	//   _адсю, sugi, _rini_,
  { {0x20073ab5,0x61fb6842,0x27e1004d,0x00000000}},	//   _sini_, umul, lohn_,
  { {0x61e96843,0x200701f4,0x61fb6844,0x00000000}},	//   rlel, _pini_, rmul,
  { {0x442d0035,0xdb1c006d,0xa295000d,0x00000000}},	//   _iwe_, tirí, _пазі,
  { {0x660919d1,0x7c2d6845,0x20076846,0x00000000}},	//   _kiek, _awar, _vini_,
  { {0x1d0a005a,0xdb1c006d,0x799d001f,0x00000000}},	//   яеми_, rirí, _nosw,
  { {0x5e56007e,0x66096847,0x4c831dd6,0x00000000}},	//   ولیس_, _miek, гляв,
  { {0xdb1c017d,0x66096848,0xbebc008f,0x00000000}},	//   dirã, _liek, obīl,
  { {0xf1c90013,0x69c4004d,0x7bce4132,0x00000000}},	//   hạm_, tiie, rnbu,
  { {0x3f9c007d,0xa928004a,0x66096849,0x00000000}},	//   _zovu_, drží, _niek,
  { {0x186727ad,0x69c41555,0xf1b20047,0x00000000}},	// [e0a0] нати_, riie, אסן_,
  { {0xdb07684a,0x57e70002,0x5c5b009f,0x00000000}},	//   vijö, едум_, _צדיק,
  { {0x7c2d36f3,0xcb570063,0x442d00e5,0x00000000}},	//   _zwar, _אסיה_, _awe_,
  { {0x14c8006a,0x66090051,0x764300ea,0x00000000}},	//   وهای_, _ciek, ánya,
  { {0xb4aa0053,0x6609684b,0xe4e30085,0x00000000}},	//   खने_, _diek, лішн,
  { {0xd2500021,0x387200a3,0x87f90085,0x00000000}},	//   لنت_, mwyr_, _жэст_,
  { {0x38720185,0xdb0e60c9,0xf1a60083,0x00000000}},	//   lwyr_, dibü, ерпн,
  { {0xd1300021,0x3952001f,0xe0260054,0x00000000}},	//   جمة_, ngys_, ньоп,
  { {0x442d0185,0x3872001f,0x6b9e00ac,0x00000000}},	//   _gwe_, nwyr_, _oopg,
  { {0x66090122,0x3ea500d1,0x543b0041,0x00000000}},	//   _ziek, fylt_, _מעמא,
  { {0x38720185,0x7c2d6588,0x216a005e,0x00000000}},	//   hwyr_, _swar, _нижи_,
  { {0xdd12005b,0x717301fb,0x91ba005d,0x00000000}},	//   rüşm, _مهما, _عطار_,
  { {0x69c10003,0x8fa60160,0x799d684c,0x00000000}},	//   èlem, _паде, _rosw,
  { {0x38720185,0x9be4000d,0x7ddd013d,0x00000000}},	//   dwyr_, гіск, nész,
  { {0x6b9e00ac,0xead40121,0x998d004c,0x00000000}},	//   _dopg, горь, čež_,
  { {0x7c2d0051,0x3872001f,0xdb1c017d,0x00000000}},	//   _twar, fwyr_, tirã,
  { {0x7ddd000f,0x38720185,0xdd04000c,0x00000000}},	// [e0b0] kész, gwyr_, ărăt,
  { {0x660919d1,0x2cb3005b,0xdb0500ea,0x00000000}},	//   _siek, ındı_, _elhá,
  { {0x6609003d,0x442d0051,0x7ddd013d,0x00000000}},	//   _piek, _swe_, dész,
  { {0xdb070146,0x3872001f,0x7a880063,0x00000000}},	//   thjæ, bwyr_, _נָתַ,
  { {0x3872001f,0x66090050,0x43750200,0x00000000}},	//   cwyr_, _viek, вуйт,
  { {0x7ddd000f,0x66090051,0x63520001,0x00000000}},	//   gész, _wiek, ављу,
  { {0x6e3a006f,0x6609109f,0xdb1c006d,0x00000000}},	//   jstb, _tiek, nirá,
  { {0xceb80051,0x2019017d,0x442d1634,0x00000000}},	//   dzę_, ísio_, _twe_,
  { {0x3375005e,0x442d684d,0xf1bf0066,0x00000000}},	//   _игар, _uwe_, žšom_,
  { {0x645b684e,0x657b21a8,0xa283007e,0x00000000}},	//   _iqui, _hauh, _میتو,
  { {0x273c02f4,0x657b0072,0x539a0047,0x00000000}},	//   lání_, _kauh, _קיעו,
  { {0xdb1c006d,0x30850021,0xdb0e004b,0x00000000}},	//   dirá, _للصف, sibü,
  { {0x273c0080,0x6d410078,0x853a0063,0x00000000}},	//   nání_, ėlap, וגרי,
  { {0x8fa2093f,0xdb070137,0x245b0013,0x00000000}},	//   _ваше, khjä, iêm_,
  { {0x245b008b,0xdb1c006d,0x273c004c,0x00000000}},	//   hêm_, girá, hání_,
  { {0x273c02f4,0xdb070137,0xe9670002,0x00000000}},	//   kání_, dhjä, касл_,
  { {0x2d5a00c3,0x261704a5,0x3872002b,0x00000000}},	// [e0c0] _všeč_, _aço_, uwyr_,
  { {0x273c0080,0x38720185,0xdb1c006d,0x00000000}},	//   dání_, rwyr_, birá,
  { {0x1dc60161,0x3872001f,0x7ddd00ea,0x00000000}},	//   _लगात, swyr_, vész,
  { {0x3872001f,0xe9a601e2,0x8506009b,0x00000000}},	//   pwyr_, _рамп, نوان,
  { {0xbcfb00ea,0x7ddd013d,0xa5070330,0x00000000}},	//   leér, tész, веца_,
  { {0xa3f4000d,0x7c220058,0xe2f80083,0x00000000}},	//   ыплі, _çoru, нелі_,
  { {0x877b0047,0x03a30001,0x7ddd00ea,0x00000000}},	//   _קאלי, ријо, rész,
  { {0x28c70161,0x16770063,0x61f9002b,0x00000000}},	//   _रेडि, _בגלל_, _chwl,
  { {0xdfda0062,0x7eab0072,0xb465005d,0x00000000}},	//   дън_, yöpö, _مدله,
  { {0x4426684f,0xdce4007d,0x9406007e,0x00000000}},	//   mpo_, _naiđ, _شواه,
  { {0x03a30138,0x9f5c0a2e,0x777c6850,0x00000000}},	//   _њихо, _nivå_, _marx,
  { {0x75f80080,0x2369017f,0x44266851,0x00000000}},	//   bíze, đaje_, opo_,
  { {0xceb80045,0x7bc76852,0x7f860021,0x00000000}},	//   szę_, tiju, _للإن,
  { {0x4426048e,0xdb1c1e0a,0xdb070072,0x00000000}},	//   ipo_, tirá, yhjä,
  { {0x273c0080,0xcb34005a,0x7bc76853,0x00000000}},	//   zání_, ресъ, riju,
  { {0x7bc70812,0x1e97014e,0xdb1c006d,0x00000000}},	//   siju, _יכול_, rirá,
  { {0x7bc700eb,0x657b0963,0x777c01a8,0x00000000}},	// [e0d0] piju, _rauh, _barx,
  { {0x7d1d03e8,0x273c0080,0x2ca40137,0x00000000}},	//   lcss, vání_, ämde_,
  { {0x44260ab2,0x39580066,0x645b561d,0x00000000}},	//   epo_, _šesť_, _squi,
  { {0x273c0080,0x245b017d,0x7d09008f,0x00000000}},	//   tání_, têm_, _tīrī,
  { {0x4426002c,0xc7cb000d,0x798f002b,0x00000000}},	//   gpo_, _жыве_, _incw,
  { {0x273c0080,0xb444000d,0xfe0a008d,0x00000000}},	//   rání_, рэцк, _hắt_,
  { {0x82a40001,0x657b240d,0x44266854,0x00000000}},	//   ишће, _tauh, apo_,
  { {0xf1c9008b,0x31b10066,0x273c004c,0x00000000}},	//   oại_, _báza_, pání_,
  { {0xfe0a008b,0x60090156,0x4094000d,0x00000000}},	//   _mắt_, нним_, арэт,
  { {0x777c0994,0x53b70235,0xf2c70002,0x00000000}},	//   _xarx, _अतिश, _исен,
  { {0x6da615d3,0xdb1c0026,0xd13100f2,0x00000000}},	//   гина, gnrý, _هما_,
  { {0x63a100ea,0x31b10066,0x7db60021,0x00000000}},	//   _holn, _fáza_, اصدا,
  { {0x90450044,0xdf490094,0x63a16855,0x00000000}},	//   _إنته, _ззлд_, _koln,
  { {0xeb9a0002,0x8e85007e,0x644b6856,0x00000000}},	//   ѕив_, _ملته, irgi,
  { {0xfe0a001b,0xc3320063,0xa96a005e,0x00000000}},	//   _bắt_, מום_, нива_,
  { {0x443f0117,0xfe0a008b,0x317f1601,0x00000000}},	//   _ovu_, _cắt_, nduz_,
  { {0x2283005b,0xfe0a0013,0xf1c90013,0x00000000}},	// [e0e0] _lık_, _dắt_, gại_,
  { {0x7c24005b,0x66150575,0xe61a1224,0x00000000}},	//   _itir, _buzk, едж_,
  { {0x98ab008f,0x86c60021,0xd757005d,0x00000000}},	//   _vecā_, ديان, المت_,
  { {0x35e5019d,0x25a00026,0xfe0a0013,0x00000000}},	//   аців, ðil_, _gắt_,
  { {0x660300ac,0x44266857,0x69c6004d,0x00000000}},	//   ïnka, upo_, _imke,
  { {0x9cdb0047,0x44261070,0x63a1017c,0x00000000}},	//   ײַדז, rpo_, _coln,
  { {0x36780063,0x656200bd,0x38791c0d,0x00000000}},	//   _בְּע, pfoh, _zssr_,
  { {0x442602f6,0x6d440027,0x7c3d00c7,0x00000000}},	//   ppo_, _ndia, yssr,
  { {0x38604008,0xdb1c0139,0x62830734,0x00000000}},	//   ntir_, nnró, avno,
  { {0x6d446858,0xdb050072,0x9f5e006c,0x00000000}},	//   _adia, _ylhä, omté_,
  { {0x7c244a7e,0xbebc001c,0x69c6006f,0x00000000}},	//   _atir, icīg, _omke,
  { {0x38601a90,0x7a150051,0x6fb4007e,0x00000000}},	//   ktir_, _wątk, امگا,
  { {0x6d44001f,0xdb1e0e1f,0x91f7009a,0x00000000}},	//   _ddia, _empí, _עמדו_,
  { {0x69c80003,0xfe0a008b,0x6d440d39,0x00000000}},	//   èden, _sắt_, _edia,
  { {0x38791aa5,0xda350121,0x2b4c0022,0x00000000}},	//   _sssr_, ребы, ódca_,
  { {0x3860007a,0xbebc001c,0x8e470021,0x00000000}},	//   ftir_, ecīg, _إليك_,
  { {0x98170049,0xfe0a008d,0xe877005d,0x00000000}},	// [e0f0] ابرا, _vắt_, دازظ,
  { {0x62886859,0xfc3f0139,0x7bc50014,0x00000000}},	//   _ordo, msí_, _umhu,
  { {0xfe0a008b,0xb87b006d,0x443f017f,0x00000000}},	//   _tắt_, _oxíg, _svu_,
  { {0x200e0046,0x63a1685a,0x75d5056c,0x00000000}},	//   _lifi_, _soln, rązo,
  { {0xdb1c0019,0x2283005b,0xfc3f0025,0x00000000}},	//   birä, _sık_, nsí_,
  { {0x8c1c0047,0xfc3f0139,0xc7bb0121,0x00000000}},	//   עווי, isí_, _чём_,
  { {0x5b58014e,0xea00008b,0x63a119bc,0x00000000}},	//   אשון_, _chặt_, _voln,
  { {0x63a10051,0xe0450189,0x628310f5,0x00000000}},	//   _woln, ании, rvno,
  { {0xf9940063,0x2419007f,0x6288685b,0x00000000}},	//   מרק_, _розы_, _erdo,
  { {0xb0680032,0x9e6524ad,0xdee531ab,0x00000000}},	//   اصيل_, авод, иопи,
  { {0x7c2403a3,0xf7720063,0x75f80331,0x00000000}},	//   _stir, חקי_, líza,
  { {0x60d60006,0x38600026,0x3f980014,0x00000000}},	//   _žyme, ytir_, örur_,
  { {0xd1b8007e,0x55760047,0x8cc00042,0x00000000}},	//   _حالا_, בערן_, _लेखो,
  { {0xbcfb007a,0x61e40ff8,0x00ba009d,0x00000000}},	//   mfél, čile, _שמסמ,
  { {0xdb2500ea,0xfaa30002,0xad9b0014,0x00000000}},	//   ásár, оаро, mmún,
  { {0xe2060026,0xe9d741af,0x3860520f,0x00000000}},	//   _þótt_, акс_, ttir_,
  { {0x47c6000d,0xfbdf685c,0xbcfb00ea,0x00000000}},	// [e100] абав, guês_, nfél,
  { {0x44240228,0xf7720021,0xdb1c0139,0x00000000}},	//   _rtm_, غاء_, rnró,
  { {0x3860685d,0xf6d50054,0x2d80004e,0x00000000}},	//   stir_, біця, _kaie_,
  { {0x69c6004d,0x38604490,0x6602685e,0x00000000}},	//   _umke, ptir_, umok,
  { {0xdce401a6,0x6602685f,0x2d80004e,0x00000000}},	//   _obič, rmok, _maie_,
  { {0x026a0076,0x212d0066,0x442400ca,0x00000000}},	//   вший_, ebeh_, _vtm_,
  { {0x95960138,0x69d60009,0xa5960086,0x00000000}},	//   _краљ, onye, _кращ,
  { {0x2369017f,0x51860e87,0xa186000d,0x00000000}},	//   đaja_, рука, рыкл,
  { {0x90970062,0x44246860,0xdfa60021,0x00000000}},	//   ивът_, _utm_, لحدي,
  { {0x628800c2,0x8146007e,0xe2920044,0x00000000}},	//   _trdo, _چنان, _وذا_,
  { {0x2d806861,0x24860146,0xd3b90086,0x00000000}},	//   _baie_, lvom_, _суті_,
  { {0x2486007d,0x200e6862,0xd0860121,0x00000000}},	//   ovom_, _wifi_, _выки,
  { {0xa3ca0053,0xfc3f004a,0x2d85004c,0x00000000}},	//   _लगा_, usí_, ěle_,
  { {0xfd1f051e,0x69d66863,0x2d850051,0x00000000}},	//   scì_, enye, śle_,
  { {0xf9c7011c,0xfb840088,0x1995066c,0x00000000}},	//   ащан, цыян, бавя,
  { {0x2486017f,0x24890066,0x76430078,0x00000000}},	//   kvom_, ťami_, šnyk,
  { {0xcbc7006a,0x87270044,0x32040168,0x00000000}},	// [e110] _نزدي, لعام, immy_,
  { {0x3954004c,0x57190054,0x3b5512a5,0x00000000}},	//   _časů_, ужжя_, _укор,
  { {0x75150032,0xf1c9008b,0xd6180044,0x00000000}},	//   مواض, oạt_, لتنا_,
  { {0xb9950021,0x2419066e,0xc9950044,0x00000000}},	//   _الحب, годы_, _الحظ,
  { {0x2489017d,0x00000000,0x00000000,0x00000000}},	//   íam_,   ,   ,
  { {0x368b0001,0x69cd001f,0xfe0a008b,0x00000000}},	//   _исбн_, liae, _lắp_,
  { {0x0bb801f9,0xdd2c0006,0x3875005b,0x00000000}},	//   שלום_, _lėšo, şarı_,
  { {0x69cd0185,0x22490c61,0x65693a74,0x00000000}},	//   niae, čak_, _ubeh,
  { {0x78ad132b,0xf0a60062,0x2d806864,0x00000000}},	//   nyav, йкъл_, _raie_,
  { {0x67f0024a,0x2127007e,0xab640051,0x00000000}},	//   täji, ديکی_, ężki,
  { {0xbebc003d,0x92b40021,0xfe0a0013,0x00000000}},	//   ecīb, _وحما, _bắp_,
  { {0xea00008b,0xfe0a0013,0x3f9e007d,0x00000000}},	//   _đắc_, _cắp_, ajtu_,
  { {0x69cd001f,0x3f6902a2,0xa0260072,0x00000000}},	//   diae, _било_, rnöö,
  { {0xad9b013d,0xb4fa009a,0x00000000,0x00000000}},	//   lmúl, טפרי,   ,
  { {0x24860024,0x2d80003b,0x01f90041,0x00000000}},	//   zvom_, _taie_, ָפּל,
  { {0x2ef8004d,0x69cd6865,0xad26005d,0x00000000}},	//   ürfe_, giae, _ارغو,
  { {0x69d62e7f,0xb7160021,0x20050150,0x00000000}},	// [e120] rnye, مباش, omli_,
  { {0x63a5004d,0x59070141,0x9aa6005d,0x00000000}},	//   öhnl, сеум_, _همخو,
  { {0x7c36001f,0x61e9119d,0x6b7b009f,0x00000000}},	//   _hwyr, koel, _גרינ,
  { {0x84460021,0x24866866,0x7bce6867,0x00000000}},	//   مختل, tvom_, libu,
  { {0x61e90179,0xc448005d,0xc537012c,0x00000000}},	//   doel, شیان_, спіх_,
  { {0x6ac50026,0x9f58005b,0x75f80066,0x00000000}},	//   _útfæ, örü_, cízn,
  { {0x7d16001f,0xb2860475,0x9f4500fe,0x00000000}},	//   _ogys, сылк, illä_,
  { {0x75d604de,0x7bce0228,0x673e0b50,0x00000000}},	//   _ايرا, hibu, lapj,
  { {0xf484007e,0x7bce6868,0x7c36002b,0x00000000}},	//   _بازی, kibu, _nwyr,
  { {0xfe0a008b,0x487b0047,0x7bce1139,0x00000000}},	//   _sắp_, נטיס, jibu,
  { {0x7c36001f,0x61e90203,0xe2160021,0x00000000}},	//   _awyr, boel, _طباع,
  { {0x6442024a,0x8cb50053,0x9f4500fe,0x00000000}},	//   osoi, उनलो, ellä_,
  { {0x7984001f,0xa2650013,0x644247d9,0x00000000}},	//   ddiw, huộ, nsoi,
  { {0x69da236b,0x7c36001f,0x69cd001f,0x00000000}},	//   éten, _dwyr, wiae,
  { {0x7f3b00b7,0x75f80024,0x8fc5007e,0x00000000}},	//   _געוו, vízn, _بزنن,
  { {0x6442024a,0x23ab0146,0x38350097,0x00000000}},	//   ksoi, _højt_, жнар,
  { {0x69cd0185,0xbc68006a,0x7c36001f,0x00000000}},	// [e130] riae, _همين_, _gwyr,
  { {0x69cd0674,0x61e93048,0x161d0042,0x00000000}},	//   siae, zoel, _बंदर_,
  { {0xb8f00161,0x163b0021,0x61e90035,0x00000000}},	//   _वे_, اسطة_, yoel,
  { {0x7afa6869,0xdb15013d,0x89f40085,0x00000000}},	//   ütte, pizó, _няўц,
  { {0x61e90179,0x9f450164,0x3ce02337,0x00000000}},	//   voel, solé_, _xxiv_,
  { {0xd2a90001,0xc7b8000d,0xcc3c0041,0x00000000}},	//   икле_, _лёс_, רעגט,
  { {0x5155005e,0x61e9686a,0x81bc008f,0x00000000}},	//   отпу, toel, _ttēl,
  { {0xd9fb0161,0x60d60078,0xd9f90053,0x00000000}},	//   ्षित_, _žyma, ंतित_,
  { {0x9f4500fe,0x61e95be9,0xad9b0014,0x00000000}},	//   yllä_, roel, rmúl,
  { {0x3e7a003d,0x201100ea,0x248d686b,0x00000000}},	//   _būt_, özi_, _irem_,
  { {0x753b0122,0x61e9006f,0x41e70085,0x00000000}},	//   _keuz, poel, _ліда,
  { {0x1d0a1001,0xed5a0184,0x8c9601dd,0x00000000}},	//   иени_, шом_, оргі,
  { {0x645d0137,0xccfa15ce,0xbbea00de,0x00000000}},	//   _åsid, рхні_, لرسم_,
  { {0x798400a3,0xe3a701f3,0x7016009d,0x00000000}},	//   wdiw, ذر_, _וחסד_,
  { {0x3e7a001c,0xdb1d00ea,0x9c87027d,0x00000000}},	//   _gūt_, ózás, _počí,
  { {0x753b686c,0x75f80066,0x64420072,0x00000000}},	//   _neuz, vízo, ysoi,
  { {0x691e00c3,0x201f2a7f,0xa8870330,0x00000000}},	// [e140] všeč, nqui_, ойта_,
  { {0x46f608a7,0x3f850022,0x6fb90042,0x00000000}},	//   очет, ndlu_, इसिं,
  { {0xa96a0c09,0x869a0699,0x2c64686d,0x00000000}},	//   _кина_, штат_, löd_,
  { {0x213f003e,0x248d1848,0x673e013d,0x00000000}},	//   jauh_, _brem_, sapj,
  { {0x439407b0,0x64a3000d,0x3940686e,0x00000000}},	//   залс, маца, mais_,
  { {0xdb05662d,0x3940686f,0x644200c9,0x00000000}},	//   _bohè, lais_, rsoi,
  { {0x3f850185,0x96f9000d,0x96636870,0x00000000}},	//   ddlu_, _гэту_, _окре,
  { {0x248d02ab,0xe476000d,0x753b1767,0x00000000}},	//   _frem_, _музэ, _geuz,
  { {0x673c0e53,0x2c640137,0xfbdf006c,0x00000000}},	//   _kerj, jöd_, orêt_,
  { {0xd007000a,0x39406871,0x3faa005e,0x00000000}},	//   оење_, hais_, рњим_,
  { {0x673c6872,0x6e940002,0x39402b27,0x00000000}},	//   _merj, чину, kais_,
  { {0x69da000f,0x394020ae,0x63a80114,0x00000000}},	//   étel, jais_, _hodn,
  { {0x63a86873,0x39406874,0x628a05e7,0x00000000}},	//   _kodn, dais_, lvfo,
  { {0x10a30001,0x673c085a,0x0aeb0044,0x00000000}},	//   _циљн, _nerj, لرأي_,
  { {0x3940001f,0x1995000d,0x4ea60002,0x00000000}},	//   fais_, павя, _фрла,
  { {0x2d85001c,0x63a801c8,0x39406875,0x00000000}},	//   ēles_, _lodn, gais_,
  { {0x673c0397,0x290f03b0,0xc7470021,0x00000000}},	// [e150] _berj, äga_, قضاي,
  { {0xf7736876,0xc72b0086,0x65600139,0x00000000}},	//   بار_, ріал_, _acmh,
  { {0x39406877,0x673c004d,0xcb88009a,0x00000000}},	//   bais_, _derj, _וְרֹ,
  { {0x39406878,0xe6180086,0x46380021,0x00000000}},	//   cais_, іді_, تأكد_,
  { {0xc8640f1c,0x3f85002b,0x673c04aa,0x00000000}},	//   _отри, ydlu_, _ferj,
  { {0x248d003b,0xdb0704aa,0x53c80085,0x00000000}},	//   _vrem_, rkjæ, огім_,
  { {0x61e40198,0xdb07069f,0x661c6879,0x00000000}},	//   čiln, skjæ, _gurk,
  { {0xdb050003,0x248d687a,0x91fc008f,0x00000000}},	//   _cohé, _trem_, _spār,
  { {0x65790034,0xb367005a,0xdb1e00fe,0x00000000}},	//   mewh, _мъжк, _ympä,
  { {0x201f032a,0x63a80051,0x3940008f,0x00000000}},	//   rqui_, _godn, zais_,
  { {0x201f00cd,0x39400003,0xfe71013a,0x00000000}},	//   squi_, yais_, ردد_,
  { {0x3f83082a,0xdb1c0025,0x2c640137,0x00000000}},	//   žju_, mhré, töd_,
  { {0x7f950bf5,0x1c4301dd,0x3940687b,0x00000000}},	//   _надх, нням, vais_,
  { {0x6d5d002c,0xe81f0053,0x2c640137,0x00000000}},	//   agsa, _बढ़ा_, röd_,
  { {0x3af50076,0x6459006f,0x3940687c,0x00000000}},	//   дятс, huwi, tais_,
  { {0x645900e8,0x3940687d,0x31b1004c,0x00000000}},	//   kuwi, uais_, _bázi_,
  { {0x673c687e,0x3940687f,0x2e210014,0x00000000}},	// [e160] _perj, rais_, _hóf_,
  { {0x661c2f55,0x62810c19,0x39406880,0x00000000}},	//   _purk, _oslo, sais_,
  { {0x39406881,0x6459006f,0x673c6882,0x00000000}},	//   pais_, euwi, _verj,
  { {0x63a803f5,0x27190080,0x31b1004c,0x00000000}},	//   _sodn, třní_, _fázi_,
  { {0x673c6883,0xc9530063,0x4519000d,0x00000000}},	//   _terj, _אמר_, іцця_,
  { {0x60d60006,0x999f0066,0x661c1f4b,0x00000000}},	//   _žymo, čuť_, _turk,
  { {0x63a815df,0x66e36884,0x7f416885,0x00000000}},	//   _vodn, _зора, dalq,
  { {0xcb13014e,0x61e404e9,0x63a80051,0x00000000}},	//   עלה_, čilo, _wodn,
  { {0x62813784,0xa41c001c,0xdcef003b,0x00000000}},	//   _eslo, ādēļ_, iecă,
  { {0xbcfb0003,0x5f940062,0xdfd0007e,0x00000000}},	//   ngée, фиот, ئيد_,
  { {0xdb1c19fe,0xdd910593,0x20190046,0x00000000}},	//   chré, نود_, ísir_,
  { {0x6d5d0014,0x420a005e,0xa0a60e5e,0x00000000}},	//   ugsa, _унео_, _наед,
  { {0xdcef000c,0x5c074b3a,0xdb050066,0x00000000}},	//   decă, зява, _dlhý,
  { {0xea000013,0x628123c9,0x8fa30131,0x00000000}},	//   _đạc_, _yslo, _паче,
  { {0x2cb30080,0x6e94007e,0x2fa50044,0x00000000}},	//   _řadě_, _آلبا, _تصنّ,
  { {0x6edb009a,0xe9450043,0x00000000,0x00000000}},	//   _לחופ, برآی,   ,
  { {0x79860397,0x321e0022,0x99d400f2,0x00000000}},	// [e170] _dakw, _luty_, رتفا,
  { {0x7c2d0035,0xdc3c0063,0x37070699,0x00000000}},	//   _itar, _העזר, пчев,
  { {0x36d40002,0xdb070014,0xf77000f2,0x00000000}},	//   нофр, rhjó, طال_,
  { {0x25a9007a,0x6459002c,0xf6500067,0x00000000}},	//   ðal_, tuwi, ائل_,
  { {0xfc460080,0x15180021,0x00000000,0x00000000}},	//   říve_, أزمة_,   ,
  { {0x65790034,0x9f450268,0x9f470024,0x00000000}},	//   sewh, tolí_, _okná_,
  { {0x3869073d,0x6d4d013d,0x42090a29,0x00000000}},	//   ltar_, _odaa, онко_,
  { {0x321e0898,0xe1f1007e,0x38696886,0x00000000}},	//   _duty_, خست_, otar_,
  { {0x38696887,0x25b20058,0x9f4501a8,0x00000000}},	//   ntar_, öyle_, solí_,
  { {0x38696888,0x7f410460,0x24800058,0x00000000}},	//   itar_, ualq, çime_,
  { {0x386904ab,0x6281017f,0x90e7006a,0x00000000}},	//   htar_, _uslo, _کسان,
  { {0x64490026,0x38696889,0x201d00a4,0x00000000}},	//   _kvei, ktar_, _tuwi_,
  { {0xac930088,0xa158000d,0xdb1e01a8,0x00000000}},	//   ваўш, _хачу_, _impú,
  { {0x3869688a,0x6aa800a5,0xee390cf7,0x00000000}},	//   dtar_, ädfo, _днк_,
  { {0x3869000c,0xca75014c,0x75f8013d,0x00000000}},	//   etar_, нуты, bízh,
  { {0x38690397,0x442d688b,0x3f871566,0x00000000}},	//   ftar_, _ote_, _hanu_,
  { {0x38690027,0xe7aa0612,0x3f870a1a,0x00000000}},	// [e180] gtar_, овал_, _kanu_,
  { {0x09030138,0xdb2400fe,0x7a150051,0x00000000}},	//   тпун, ärät, _wątp,
  { {0xe1f90006,0xbcfb0003,0x79860ba1,0x00000000}},	//   klų_, rgée, _takw,
  { {0x893603eb,0xd8260141,0xd910005d,0x00000000}},	//   _تعدا, _одми, _میز_,
  { {0x38691bb7,0x397b009a,0xa5330e74,0x00000000}},	//   ctar_, _וטכנ, тніч,
  { {0x7529688c,0x64a3005e,0xa43d0085,0x00000000}},	//   _efez, таља, сьцi,
  { {0xe2970459,0x644926ad,0xfd650013,0x00000000}},	//   дај_, _evei, _chuố,
  { {0xd1300032,0xe1f90006,0x442d3a19,0x00000000}},	//   دمة_, glų_, _fte_,
  { {0x6723082a,0x30145ed9,0xb145005d,0x00000000}},	//   žnje, ндир, ریوم_,
  { {0x3f87001f,0xdb1e00cd,0xdefa000d,0x00000000}},	//   _canu_, _empú, жым_,
  { {0x3f87017f,0x1df9000d,0x32fc008b,0x00000000}},	//   _danu_, зены_, _ủy_,
  { {0x442d130e,0x25a61b9f,0xd1300044,0x00000000}},	//   _yte_, njol_, _صمت_,
  { {0x38690137,0xfc640062,0x3f87008f,0x00000000}},	//   xtar_, кърн, _fanu_,
  { {0xb3450016,0x3f87001f,0x00000000,0x00000000}},	//   maçã, _ganu_,   ,
  { {0xb34503d9,0xb87b017d,0xa0070021,0x00000000}},	//   laçã, _exíl, _تقول_,
  { {0x2369017f,0x39150001,0x3869688d,0x00000000}},	//   đaji_, ембр, ttar_,
  { {0xb3450016,0x28f80076,0x7c2d538e,0x00000000}},	// [e190] naçã, деть_, _utar,
  { {0x3869688e,0x7d0041f7,0x4ff8009d,0x00000000}},	//   rtar_, ümse, פִּנ,
  { {0x7bd500eb,0xfc460080,0x8ac7000d,0x00000000}},	//   mizu, říte_, _цёпл,
  { {0x386958be,0x442d26c5,0x28d00053,0x00000000}},	//   ptar_, _pte_, _सेवि,
  { {0x7bd5008d,0x2d89688f,0x23290320,0x00000000}},	//   oizu, _maae_, поли_,
  { {0x3a2100f3,0xb3450016,0x6265055d,0x00000000}},	//   _kuhp_, daçã, евка,
  { {0xb34500be,0x3f873bdc,0xdb1c41f7,0x00000000}},	//   eaçã, _ranu_, virü,
  { {0x64490627,0x32060222,0xb34500be,0x00000000}},	//   _tvei, _choy_, façã,
  { {0xd3750138,0xb34503d9,0xe0d9464a,0x00000000}},	//   _плаћ, gaçã, яви_,
  { {0x60061485,0xfd65008b,0x75f818a8,0x00000000}},	//   нным_, _thuố, vízi,
  { {0xf77200b5,0x645e0051,0x32550086,0x00000000}},	//   נקט_, ąpie, _чвер,
  { {0x9f4501a8,0xb34500be,0x6cc61224,0x00000000}},	//   solà_, baçã, ейма,
  { {0xb34503d9,0x5cf50088,0x61fb005b,0x00000000}},	//   caçã, вяру, mlul,
  { {0x61fb6890,0xdee5202f,0xbb750094,0x00000000}},	//   llul, _поли, кусъ,
  { {0x637301f7,0xbad5000d,0x61fb078c,0x00000000}},	//   mını, віты, olul,
  { {0x3eb80205,0x6373005b,0x61fb005b,0x00000000}},	//   ørte_, lını, nlul,
  { {0x6d4603f9,0x61fb0be3,0xa8063351,0x00000000}},	// [e1a0] maka, ilul, езал,
  { {0x637301f7,0x6d461193,0xa7630131,0x00000000}},	//   nını, laka, лкуд,
  { {0xb34503d9,0x6aa1004d,0x61fb0058,0x00000000}},	//   zaçã, älft, klul,
  { {0x6d462fbe,0x98a60854,0x63730075,0x00000000}},	//   naka, _зиме, hını,
  { {0xb3450016,0x25ad0179,0x6373005b,0x00000000}},	//   xaçã, _doel_, kını,
  { {0xb34503d9,0x69d601f7,0xf1b9001c,0x00000000}},	//   vaçã, liye, ekš_,
  { {0x6d4615c4,0xbcfb0164,0x6373005b,0x00000000}},	//   kaka, nfér, dını,
  { {0xb34503d9,0x7ec6000f,0x6d466891,0x00000000}},	//   taçã, _lépé, jaka,
  { {0x6d460e53,0x75d30021,0x6373005b,0x00000000}},	//   daka, _إيقا, fını,
  { {0xb34503d9,0x50b70021,0x2d8900b9,0x00000000}},	//   raçã, عديد_, _saae_,
  { {0x7bd53940,0xd3370063,0xb345017d,0x00000000}},	//   vizu, _נראה_, saçã,
  { {0xb3450016,0xd246006a,0x6d466863,0x00000000}},	//   paçã, ین_, gaka,
  { {0x637301f7,0x69d6005b,0x7bd56892,0x00000000}},	//   bını, diye, tizu,
  { {0xbcfb03b2,0x637301f7,0x7d040051,0x00000000}},	//   ffér, cını, _dzis,
  { {0xda7802e4,0xdb0700d1,0xdb2410ba,0x00000000}},	//   нят_, nkjø, órás,
  { {0x4efb0063,0x69c42f80,0x6d465b1c,0x00000000}},	//   _מהוו, ghie, caka,
  { {0xdc140058,0x25ad00ca,0xd7f1008d,0x00000000}},	// [e1b0] aşıy, _roel_, _ữ_,
  { {0x3f8c002b,0xf647030b,0xf6e74020,0x00000000}},	//   nddu_, ехдн, нцен,
  { {0x3f8c0014,0x394201e1,0x61fb0058,0x00000000}},	//   iddu_, _feks_, ylul,
  { {0x69c46893,0x6373005b,0x94790fce,0x00000000}},	//   chie, zını, дску_,
  { {0x25ad00e8,0xc8670086,0x6373005b,0x00000000}},	//   _voel_, _ятни, yını,
  { {0x69da013d,0xad9b0260,0xdb1c0046,0x00000000}},	//   étev, llúd, nirð,
  { {0x6d461320,0x02c20086,0x25ad004b,0x00000000}},	//   yaka, ийшо, _toel_,
  { {0xa224007e,0x798d6894,0xdb1c0014,0x00000000}},	//   دروه, ndaw, hirð,
  { {0x61fb6895,0x6373005b,0x6d462f2e,0x00000000}},	//   rlul, tını, vaka,
  { {0x6d462150,0x661b0072,0xdb1c0139,0x00000000}},	//   waka, _hiuk, thrí,
  { {0x637304ab,0x61fb01f7,0x661b0035,0x00000000}},	//   rını, plul, _kiuk,
  { {0x637301f7,0x2369017f,0x64595062,0x00000000}},	//   sını, đaju_, orwi,
  { {0x6d460397,0x69d6005b,0xdb1c0026,0x00000000}},	//   raka, viye, firð,
  { {0x6d4618d5,0x39424098,0x661b6269,0x00000000}},	//   saka, _seks_, _liuk,
  { {0x6d46375a,0x69d6005b,0x60c9005b,0x00000000}},	//   paka, tiye, lzem,
  { {0x60d60006,0xdc14005b,0xbcfb0003,0x00000000}},	//   _žymi, rşıy, rfér,
  { {0x69d6005b,0xa923005e,0xbcfb372e,0x00000000}},	// [e1c0] riye, рдул, sfér,
  { {0x61e400c3,0x78a400cd,0x644b2caa,0x00000000}},	//   čili, rxiv, dsgi,
  { {0x64596896,0x3942582e,0x15460002,0x00000000}},	//   erwi, _teks_, веем,
  { {0x7c240035,0xd5b90054,0xef18008f,0x00000000}},	//   _kuir, нсі_, neļa_,
  { {0x6d44017d,0x3f8c0762,0x661b0360,0x00000000}},	//   _meia, yddu_, _diuk,
  { {0x6d446897,0xa3cc0053,0xe2a3008b,0x00000000}},	//   _leia, शों_, _trữ_,
  { {0x38601088,0x926a0002,0xb2860121,0x00000000}},	//   luir_, фрла_, тылк,
  { {0xdb0700d1,0x2167005e,0x31b800ea,0x00000000}},	//   rkjø, вићи_, _kézi_,
  { {0x7c240d23,0xdb0700d1,0x38603784,0x00000000}},	//   _nuir, skjø, nuir_,
  { {0xdb0700d1,0x6e2301a8,0x798d0022,0x00000000}},	//   pkjø, _bunb, zdaw,
  { {0x3f8a0024,0xa75b0047,0x38600025,0x00000000}},	//   ľbu_, ודיר, huir_,
  { {0x9f4c00cd,0x7c2419fe,0xdb1c0014,0x00000000}},	//   modí_, _buir, virð,
  { {0x7c240027,0x442400f3,0x6d44002b,0x00000000}},	//   _cuir, _jum_, _deia,
  { {0x38600994,0xbcfb05d5,0xdb1c0014,0x00000000}},	//   duir_, bgén, tirð,
  { {0x9f4505ec,0x6e2300e5,0x49bb0593,0x00000000}},	//   alló_, _gunb, وارد_,
  { {0x201c0009,0x38600003,0xef18008f,0x00000000}},	//   _hivi_, fuir_, ceļa_,
  { {0x44246898,0x38601c30,0x7deb0078,0x00000000}},	// [e1d0] _num_, guir_, ręsd,
  { {0x62830051,0xf7700593,0x661b0a26,0x00000000}},	//   ywno, قام_, _siuk,
  { {0x65950141,0x2b5e0022,0x661b078c,0x00000000}},	//   лажу, ótce_, _piuk,
  { {0x644b0137,0x44242268,0x38603c46,0x00000000}},	//   tsgi, _bum_, buir_,
  { {0x44246899,0xdb1c0027,0x39494d97,0x00000000}},	//   _cum_, mhrá, maas_,
  { {0x60c900c3,0x394951a9,0x4424689a,0x00000000}},	//   vzem, laas_, _dum_,
  { {0xb364005a,0x661b0072,0x7bcb0078,0x00000000}},	//   ръчк, _tiuk, _įgul,
  { {0x60c90268,0x394900a4,0x4424689b,0x00000000}},	//   tzem, naas_, _fum_,
  { {0x6d440268,0x317f689c,0x6e23508f,0x00000000}},	//   _reia, reuz_, _sunb,
  { {0xe4e40086,0xee3943bd,0x2374005d,0x00000000}},	//   _тісн, нно_, _نامح,
  { {0x44240199,0xd175000d,0x201c001c,0x00000000}},	//   _zum_, _былы, _divi_,
  { {0xb2ba00b5,0x9b96007e,0x6455008f,0x00000000}},	//   _אמער, گلست, _āzij,
  { {0x7c240577,0x6d44017d,0xef18008f,0x00000000}},	//   _quir, _veia, reļa_,
  { {0x7052002a,0x8fa20da2,0x3f83004e,0x00000000}},	//   _انوا, _гаше, õjud_,
  { {0x2d840003,0xdb051089,0xad9b00be,0x00000000}},	//   ômes_, _pohá, rmúr,
  { {0x3b07000a,0x7c240025,0xf2d20047,0x00000000}},	//   ѓето_, _tuir, צען_,
  { {0x09f70021,0x98a304e3,0x475a0200,0x00000000}},	// [e1e0] افقة_, бите, ерея_,
  { {0x9d1b0063,0x4424689d,0x38600e57,0x00000000}},	//   _אופט, _rum_, ruir_,
  { {0x4fba0047,0x39490019,0x2d8200ac,0x00000000}},	//   עזעצ, baas_, oeke_,
  { {0x44245721,0x75890086,0x3935000d,0x00000000}},	//   _pum_, ксів_, _вэрс,
  { {0x7e611647,0xf993009a,0x99f7009a,0x00000000}},	//   hulp, _פרש_, _תזכה_,
  { {0x33730054,0x2d821013,0x7e61689e,0x00000000}},	//   йгір, heke_, kulp,
  { {0x201c00fe,0x03a3005e,0x69c3003b,0x00000000}},	//   _rivi_, сијо, _înec,
  { {0x2d82017f,0xe6170062,0xf484007e,0x00000000}},	//   jeke_, _бдс_, _پاری,
  { {0x44240089,0xc2070044,0x00000000,0x00000000}},	//   _uum_, دقين_,   ,
  { {0x8f860001,0x30770021,0x2ef40062,0x00000000}},	//   ућил, احية_, изпр,
  { {0x2002001c,0x201c4970,0xb7db0063,0x00000000}},	//   ēki_, _vivi_, תקיי,
  { {0x3e4e0022,0x60d60078,0xe2310043,0x00000000}},	//   ręt_, _žymu, _بکوب,
  { {0xdfda005a,0x5c740156,0x201c0013,0x00000000}},	//   _пък_, блят, _tivi_,
  { {0xd00f0021,0x93b50013,0x201c0003,0x00000000}},	//   _فلن_, _lĩn, _uivi_,
  { {0x394900bb,0x539b0063,0x2d82689f,0x00000000}},	//   taas_, עילו, beke_,
  { {0xf99f0013,0x99d40021,0x7afe3c7a,0x00000000}},	//   _thèm_, متقا, _dypt,
  { {0x394900f5,0x9fbd0022,0xd7d501ce,0x00000000}},	// [e1f0] raas_, _głów_, ажањ,
  { {0xb8cd0053,0x69da12a2,0x394900d1,0x00000000}},	//   _कप_, éter, saas_,
  { {0x37070676,0x6723007d,0x17f80044,0x00000000}},	//   учав, žnjo, ارقة_,
  { {0x645d0137,0x15a80062,0x04b50519,0x00000000}},	//   _åsik, лъчи_, исля,
  { {0xdcfd00eb,0xdd3c009a,0x64a568a0,0x00000000}},	//   kesč, תעדכ, рала,
  { {0x3438005d,0x42551e1b,0x321d056c,0x00000000}},	//   اسند_, атит, _siwy_,
  { {0xd346007e,0x02d80042,0xfbb8009a,0x00000000}},	//   شینه_, _भेदभ, רפות_,
  { {0x02050079,0x00000000,0x00000000,0x00000000}},	//   јзин,   ,   ,
  { {0x7dc60139,0x798f10b6,0x3d010042,0x00000000}},	//   _lósc, _macw, ोधों_,
  { {0xd0090001,0xd00e0021,0x7e612cde,0x00000000}},	//   ђене_, ولي_, tulp,
  { {0x9fbd0045,0xe233006a,0x2d8201a6,0x00000000}},	//   _słów_, _اکتب, teke_,
  { {0x41e4000d,0x60060014,0xd256009d,0x00000000}},	//   _ліча, rðma, _כשעה_,
  { {0x7e610a9f,0x2d8268a1,0x814c0047,0x00000000}},	//   sulp, reke_, _טעאַ,
  { {0x2d8268a2,0x6b6602f8,0x9516009a,0x00000000}},	//   seke_, јква, יקרא_,
  { {0xaa4643f9,0x7ff4014d,0x09d6000d,0x00000000}},	//   ребл, _اسنا, ацаў,
  { {0xdb1c68a3,0xd24f0085,0x7de40046,0x00000000}},	//   nkré, ццi_, iđsk,
  { {0xad9b0066,0xdc54005d,0x97360044,0x00000000}},	// [e200] slúc, _اربک, لعاص,
  { {0x7d1b0066,0x7dd6008f,0x7afe00a5,0x00000000}},	//   ľust, kšsk, _typt,
  { {0x39ea0088,0xbbe9007e,0x7bdc620f,0x00000000}},	//   _адно_, _حريم_, miru,
  { {0x7bdc68a4,0xdb1c04aa,0xc7a900ff,0x00000000}},	//   liru, thræ, וב_,
  { {0x93b5008b,0x69c668a5,0x645e0022,0x00000000}},	//   _vĩn, _ilke, ąpio,
  { {0x7bdc0822,0xbebc0023,0x0666005d,0x00000000}},	//   niru, ocīt, _پاسپ,
  { {0x31c60001,0x877b0063,0x7bdc078c,0x00000000}},	//   исив, _שאלי, iiru,
  { {0x3f8e0035,0x7bdc68a6,0x51f300de,0x00000000}},	//   _safu_, hiru, يسير,
  { {0x7bdc5552,0xdfa60095,0xcfa61a5c,0x00000000}},	//   kiru, ајно, ашни,
  { {0x7bdc0035,0x6d561db3,0x66021b09,0x00000000}},	//   jiru, _adya, llok,
  { {0x6e630b3f,0xd12f1743,0xadf50054,0x00000000}},	//   отяж, _мх_, йпош,
  { {0x660268a7,0x629a0072,0xad670044,0x00000000}},	//   nlok, _irto, جاده,
  { {0x99890051,0xdcfd0006,0xdce60078,0x00000000}},	//   ymał_, pesč, iekė,
  { {0x69da0003,0x69c668a8,0xb09b009a,0x00000000}},	//   èten, _alke, _שיגר,
  { {0x1ab400a0,0xf96b0d64,0x6602492d,0x00000000}},	//   обря, край_, klok,
  { {0x39a40472,0x660200ea,0x7bdc008f,0x00000000}},	//   ошув, jlok, airu,
  { {0x286b0062,0xdb5b0121,0x7bdc12a8,0x00000000}},	// [e210] ърво_, _июн_, biru,
  { {0x960f0161,0xc60f0053,0x69c668a9,0x00000000}},	//   िष्ट_, िष्य_, _elke,
  { {0xb8fe0053,0x6602252f,0x29e80058,0x00000000}},	//   _थे_, flok, oğal_,
  { {0xdb070014,0xdce6008f,0x78a201d1,0x00000000}},	//   skjó, žāņu_, ťova,
  { {0xa8790047,0x24f80895,0x629a68aa,0x00000000}},	//   _גאָר, анцы_, _arto,
  { {0x28d00053,0x83380062,0x66020072,0x00000000}},	//   _सेटि, ачът_, alok,
  { {0x9567005a,0xdb1c00bd,0xb5a7170a,0x00000000}},	//   _възд, chrä, _край,
  { {0x98a00022,0xc692009a,0x00000000,0x00000000}},	//   ecię_, _צאן_,   ,
  { {0x657b00a4,0x629a0983,0xa9380063,0x00000000}},	//   _ibuh, _erto, בטחה_,
  { {0x644d005f,0x9f540046,0xdb1c01d1,0x00000000}},	//   šais, æfða_, skré,
  { {0x7c360f4b,0x7bdc68ab,0x41e70085,0x00000000}},	//   _styr, viru, _кіда,
  { {0xb4f90047,0xd215005e,0x6b81004b,0x00000000}},	//   ָפֿי, _умећ, õlgn,
  { {0x248d0080,0x213f003e,0x7dc60025,0x00000000}},	//   _jsem_, mbuh_, _cósa,
  { {0x8cb50054,0x6602056c,0x96620085,0x00000000}},	//   ісяч, zlok, сiль_,
  { {0x657b017f,0xdd110240,0xde35007f,0x00000000}},	//   _obuh, _výšk, _уэль,
  { {0x7ae10025,0x3eb800bd,0x248d14d5,0x00000000}},	//   últa, ärte_, _osem_,
  { {0x69d800eb,0x7bdc68ac,0x3e7100ea,0x00000000}},	// [e220] _įved, piru, lát_,
  { {0xbb8601a7,0xab66042c,0x3e710013,0x00000000}},	//   _الدي, _увол, oát_,
  { {0x38721641,0x248d68ad,0xdce60078,0x00000000}},	//   styr_, _asem_, tekė,
  { {0x660200fe,0xcb130063,0x7afa004d,0x00000000}},	//   ulok, _מלת_, üttu,
  { {0x6ba5007a,0xdcf6027d,0x66023d34,0x00000000}},	//   _útgá, _obyč, rlok,
  { {0x3f8510ff,0x39400006,0x2d92006c,0x00000000}},	//   jelu_, lbis_, _laye_,
  { {0x3e71000f,0x660268ae,0x3f8568af,0x00000000}},	//   ját_, plok, delu_,
  { {0xc0340fe2,0x2d920035,0xb0340856,0x00000000}},	//   ониј, _naye_, ониш,
  { {0x39400025,0x04430062,0xd01a02d8,0x00000000}},	//   ibis_, _нетн, лфо_,
  { {0xb7fa0053,0x3f85001f,0x3e71013d,0x00000000}},	//   ्तिम_, gelu_, fát_,
  { {0x3e7100ea,0xd3370063,0x386053db,0x00000000}},	//   gát_, _הרבה_, hrir_,
  { {0x38600014,0x00000000,0x00000000,0x00000000}},	//   krir_,   ,   ,
  { {0x3f8567bb,0x5c743a82,0x50ba043e,0x00000000}},	//   belu_, плят, _حداد_,
  { {0x3e711954,0x3f85004c,0x38601d26,0x00000000}},	//   bát_, celu_, drir_,
  { {0x5e440021,0x3e71013d,0x386068b0,0x00000000}},	//   _بَعْ, cát_, erir_,
  { {0x7dc60139,0x386000e9,0xdb050066,0x00000000}},	//   _tósa, frir_, _kohú,
  { {0xbbeb006a,0x6d4f014f,0x3dc900a4,0x00000000}},	// [e230] _مردم_, maca, _ilaw_,
  { {0x6d4f554a,0x7d0d007d,0x29020137,0x00000000}},	//   laca, _izas, _dyka_,
  { {0x3ebe00d1,0x2d9200ac,0xa3ac0042,0x00000000}},	//   nytt_, _yaye_, गान_,
  { {0x6d4f01f7,0x3860073d,0x7bc10014,0x00000000}},	//   naca, brir_, öluf,
  { {0x998001f7,0x3e71013d,0xd8380766,0x00000000}},	//   lmiş_, zát_, _гэс_,
  { {0x248d00c3,0x3dc9001f,0xc484000d,0x00000000}},	//   _vsem_, _llaw_, ялік,
  { {0x998001f7,0x7de4013d,0x3f8568b1,0x00000000}},	//   nmiş_, lőse, velu_,
  { {0x213f00e3,0x20550bb3,0x3e71000f,0x00000000}},	//   ubuh_, отор, vát_,
  { {0x6e2a00bd,0x7dc6017d,0x6d4f0139,0x00000000}},	//   _aufb, _bósn, daca,
  { {0x3e7168b2,0x6d4f0139,0x99800058,0x00000000}},	//   tát_, eaca, kmiş_,
  { {0x59c90161,0x2d920003,0x7dea0054,0x00000000}},	//   रसार, _paye_, имог_,
  { {0x3860007a,0xf6520047,0x6da602d8,0x00000000}},	//   yrir_, וצט_, цима,
  { {0x7d0d0045,0x3e71608d,0x69da0003,0x00000000}},	//   _czas, sát_, ètem,
  { {0x38600164,0xcb6a0001,0x2480005b,0x00000000}},	//   vrir_, јаве_, çimi_,
  { {0xdde9006a,0xdcfd001c,0x61e939b2,0x00000000}},	//   _گروه_, resā, onel,
  { {0x3e55001c,0x3dc9001f,0x6d4f68b3,0x00000000}},	//   māt_, _glaw_, caca,
  { {0xa3ac016a,0x20c90161,0x3e55001c,0x00000000}},	// [e240] गाम_, िनिध, lāt_,
  { {0x61e968b4,0x61fb0034,0x6281037d,0x00000000}},	//   hnel, houl, _oplo,
  { {0x3e550418,0x61fb68b5,0x200568b6,0x00000000}},	//   nāt_, koul, illi_,
  { {0x386000be,0x7a05000d,0x98a61dd1,0x00000000}},	//   prir_, _няўж, _диме,
  { {0x61e9007d,0xd38a0054,0x6f0368b7,0x00000000}},	//   dnel, ийде_, _lync,
  { {0x3e55001c,0x9294047e,0x61e968b8,0x00000000}},	//   kāt_, закц, enel,
  { {0x6d4f01f7,0x3e55003d,0xbcfb0139,0x00000000}},	//   yaca, jāt_, rgéi,
  { {0x61e968b9,0x3e55003d,0x394b0268,0x00000000}},	//   gnel, dāt_, _xecs_,
  { {0xdb1e017d,0xbfaa27b5,0xdb1c0139,0x00000000}},	//   _impõ, атне_, ghrú,
  { {0x7bc0017d,0x61e968ba,0x6f03002b,0x00000000}},	//   êmul, anel, _bync,
  { {0x69c468bb,0xf0b7007e,0x6d4f68bc,0x00000000}},	//   kkie, مایش_, taca,
  { {0x61fb0003,0xd5a601fb,0x200568bd,0x00000000}},	//   coul, رف_, alli_,
  { {0x6e240089,0x69c40051,0x6d4f68be,0x00000000}},	//   _diib, dkie, raca,
  { {0x3e55003d,0x60cc005b,0x6723082a,0x00000000}},	//   bāt_, ılmı, žnji,
  { {0x2e4a005a,0x6281548a,0x6d4f1a8d,0x00000000}},	//   _тяло_, _xplo, paca,
  { {0x9980005b,0x7c3d0137,0x7de4013d,0x00000000}},	//   rmiş_, ppsr, tőse,
  { {0x69cd001f,0x60c001e9,0x247e008f,0x00000000}},	// [e250] rhae, nymm, nāmā_,
  { {0x7de400ea,0x69c40051,0xf8070085,0x00000000}},	//   rőse, akie, ічан,
  { {0x61fb0035,0x61e968bf,0xfc3f00cd,0x00000000}},	//   youl, ynel, lpí_,
  { {0xdcfd000c,0x69c45afc,0x60c017cb,0x00000000}},	//   cesă, ckie, kymm,
  { {0x62810198,0x183500b5,0x7c2d0397,0x00000000}},	//   _splo, _מאָל_, _juar,
  { {0xfc3f0027,0x7c2d3efd,0x61e0002b,0x00000000}},	//   ipí_, _muar, eiml,
  { {0x386968c0,0x7c2d68c1,0xf5e70054,0x00000000}},	//   luar_, _luar, _діам,
  { {0xdb1e0ec6,0x3e55001c,0xdb1c0139,0x00000000}},	//   _impô, vāt_, thrú,
  { {0x61fb05d7,0x38690764,0x7c2d0139,0x00000000}},	//   roul, nuar_, _nuar,
  { {0x3e55001c,0x6f03001f,0xa295000d,0x00000000}},	//   tāt_, _pync, _назі,
  { {0x69dd68c2,0x69c40051,0x6d4d00ac,0x00000000}},	//   _omse, ykie, _beaa,
  { {0x3eb800c7,0x442d0150,0x3e55001c,0x00000000}},	//   ärta_, _kue_, rāt_,
  { {0x7c2d018d,0x6e240019,0x3e55001c,0x00000000}},	//   _cuar, _viib, sāt_,
  { {0x442500f3,0x69dd0185,0x386900cd,0x00000000}},	//   _jil_, _amse, duar_,
  { {0x442d0f3b,0x44250577,0xfaa368c3,0x00000000}},	//   _lue_, _mil_, наро,
  { {0x7c2d0025,0x6d4d006f,0x316d0003,0x00000000}},	//   _fuar, _geaa, ngez_,
  { {0x44250969,0x442d0003,0x7c2d2996,0x00000000}},	// [e260] _oil_, _nue_, _guar,
  { {0x69c468c4,0xf7720021,0x61e0005b,0x00000000}},	//   skie, عاء_, ziml,
  { {0x3bbb014e,0x61e0005b,0x7c2d12ca,0x00000000}},	//   _המיד, yiml, _zuar,
  { {0x442568c5,0x14c8007e,0x442d68c6,0x00000000}},	//   _ail_, يهای_, _bue_,
  { {0x442568c7,0x386912c7,0x2a6a08a9,0x00000000}},	//   _bil_, cuar_, lubb_,
  { {0x442d68c8,0x395268c9,0x249f68ca,0x00000000}},	//   _due_, lays_, _drum_,
  { {0x4425005b,0x249f0026,0x61e0005b,0x00000000}},	//   _dil_, _erum_, timl,
  { {0x442d048e,0x3253005a,0x7c3b000c,0x00000000}},	//   _fue_, хвър, ţuri,
  { {0x64490185,0x442d00f3,0x61e001f7,0x00000000}},	//   _gwei, _gue_, riml,
  { {0x60c000c7,0x61e001f7,0xbfaa042c,0x00000000}},	//   rymm, siml, стие_,
  { {0x64490199,0x7c2d014f,0x6d4d0019,0x00000000}},	//   _zwei, _suar, _peaa,
  { {0x60060014,0x7c25007d,0x442d68cb,0x00000000}},	//   iðmi, _sihr, _yue_,
  { {0x310a0002,0x395268cc,0x63ba4684,0x00000000}},	//   _ундп_, days_, _kotn,
  { {0xe10b00b5,0x9202001c,0xbcfb0003,0x00000000}},	//   _פּאָ, žādo, dgét,
  { {0x7c2500fe,0x63ba00c2,0x9f7b0063,0x00000000}},	//   _vihr, _motn, _הנוח,
  { {0x63ba0051,0x38693784,0x2ca001bb,0x00000000}},	//   _lotn, tuar_, _frid_,
  { {0x290f00c7,0x2d8b62e8,0xe7b90002,0x00000000}},	// [e270] åga_, mece_, огаш_,
  { {0x442d1672,0x2907001c,0x6449004d,0x00000000}},	//   _rue_, āna_, _rwei,
  { {0xfe7800eb,0x26c70080,0x442d055b,0x00000000}},	//   ntį_, áno_, _sue_,
  { {0x28de0161,0x2d8b0297,0x2d9968cd,0x00000000}},	//   _नेवि, nece_, ndse_,
  { {0x26c701a6,0x674800ea,0x442d100f,0x00000000}},	//   šno_, érjü, _que_,
  { {0x442d0164,0x65780024,0x24840089,0x00000000}},	//   _vue_, _ľahš, _dpmm_,
  { {0x994d0024,0x442504b1,0xdd100024,0x00000000}},	//   _môžu_, _vil_, ižši,
  { {0x63a80c83,0x44251a20,0xbcfb000f,0x00000000}},	//   _endn, _wil_, ngés,
  { {0x2d8b01f7,0x442d0004,0x932703eb,0x00000000}},	//   dece_, _uue_, _فران,
  { {0x2d99006f,0xcee90076,0xd374005e,0x00000000}},	//   edse_, ждое_, _плућ,
  { {0xd1750085,0xaf090593,0x27780041,0x00000000}},	//   _жылы, تقدم_, לעזש_,
  { {0xfce60156,0x2ca0085a,0xfbc90063,0x00000000}},	//   домо, _prid_, _דת_,
  { {0x61fc0014,0xef18008f,0xfe780078,0x00000000}},	//   _írla, deļu_, atį_,
  { {0x39520037,0xe9df0025,0x9f451270,0x00000000}},	//   ways_, _amú_, roló_,
  { {0x8a060085,0xab270590,0x39520168,0x00000000}},	//   дзве, дора_, tays_,
  { {0x9f450290,0xbcfb00ea,0x00000000,0x00000000}},	//   colò_, ggés,   ,
  { {0x39522eaf,0x48e34890,0x6ec50042,0x00000000}},	// [e280] rays_, вотв, ानकु,
  { {0x2cad0146,0xbcfb17f8,0x2cbf004d,0x00000000}},	//   åede_, rgét, äude_,
  { {0x395201e1,0x63ba08a9,0xdcfd0078,0x00000000}},	//   pays_, _rotn, resą,
  { {0xe5c50086,0xdb1c0195,0xf50a0caa,0x00000000}},	//   нсіо, ckrá, онел_,
  { {0x6d460089,0x63ba00c2,0xc95300ff,0x00000000}},	//   ibka, _potn, _שמש_,
  { {0x2d8b003b,0x9cd70063,0x7deb0078,0x00000000}},	//   zece_, וונה_, tęsk,
  { {0x2d991b21,0x926a071f,0x03a3005e,0x00000000}},	//   ydse_, ірка_, тијо,
  { {0xa3ac0053,0xcb130063,0x7deb0078,0x00000000}},	//   गाह_, כלו_, ręsk,
  { {0x2d8b051e,0x00000000,0x00000000,0x00000000}},	//   vece_,   ,   ,
  { {0x9ed8000a,0xdfd00049,0x64422300,0x00000000}},	//   змот_, ايد_, mpoi,
  { {0x644200fe,0x6d400058,0xddc2004c,0x00000000}},	//   lpoi, ıman, oplň,
  { {0xfe780006,0x656f004d,0xfe24030b,0x00000000}},	//   rtį_, _öcht, кьян,
  { {0x5c07005a,0xfe780006,0x2d8b68ce,0x00000000}},	//   дява, stį_, rece_,
  { {0x7df2001c,0x2d8b00b2,0x0a950062,0x00000000}},	//   rāsa, sece_, нагю,
  { {0x7bc70026,0xbcfb0164,0x8ae40086,0x00000000}},	//   rkju, ggér, вітл,
  { {0x3e78000f,0x3f8c196d,0x7bc768cf,0x00000000}},	//   mét_, ledu_, skju,
  { {0xb8150138,0x3e7800ea,0x2aff0053,0x00000000}},	// [e290] едај, lét_, _शुरु_,
  { {0xdb1c007a,0xa8a40062,0x644200e5,0x00000000}},	//   skrá, ърск, dpoi,
  { {0xdb1c0146,0x6442017d,0x601400cd,0x00000000}},	//   ekræ, epoi, càme,
  { {0x25a902dd,0xdb1c0046,0x00000000,0x00000000}},	//   ñal_, fkræ,   ,
  { {0xa9280080,0x7e7a68d0,0x638568d1,0x00000000}},	//   _vyžá, http, егла,
  { {0x3e7800ea,0x3f8c007c,0xe29908a2,0x00000000}},	//   két_, jedu_, зак_,
  { {0x3e7800ea,0x45d50086,0x6933004c,0x00000000}},	//   jét_, _зовс, přeč,
  { {0x69da0003,0x41a90042,0x34950085,0x00000000}},	//   étex, काइस, _пабр,
  { {0x3f8c002b,0x60e90054,0x60254598,0x00000000}},	//   fedu_, ямим_, ндиа,
  { {0x443f014f,0xf2c72625,0x64591a62,0x00000000}},	//   _itu_, _осен, mswi,
  { {0x3e78000f,0xa3ac0053,0xc7b2009a,0x00000000}},	//   gét_, गार_, אבי_,
  { {0x6d46005f,0xadb70044,0xe29a009a,0x00000000}},	//   ubka, ّهَا_, _משער,
  { {0x2d9e02f4,0x707500b5,0x3f8c08c1,0x00000000}},	//   ěte_, _נײַע_, bedu_,
  { {0x443f0009,0x6aa804aa,0x2ba70042,0x00000000}},	//   _mtu_, ådfo, खागा,
  { {0xddc20061,0x5f050054,0x7bc10014,0x00000000}},	//   yplň, _язка, ölua,
  { {0x69260138,0x60140268,0xda650044,0x00000000}},	//   емба, ràme, ضافي,
  { {0x6459006f,0xdb05006d,0x95820022,0x00000000}},	// [e2a0] jswi, _bohó, łąka,
  { {0x317f00e3,0x64591a99,0x46f60263,0x00000000}},	//   hfuz_, dswi, нчет,
  { {0x645909fe,0xd910007e,0x644200e5,0x00000000}},	//   eswi, _چیز_, wpoi,
  { {0xd910006a,0x6736001c,0x2e3a0047,0x00000000}},	//   _نیز_, _šajā, לגענ,
  { {0x3e7800ea,0xa3ac0053,0xdb0b013d,0x00000000}},	//   zét_, गाल_, önöz,
  { {0xddc20080,0x7deb0006,0x644268d2,0x00000000}},	//   splň, ręsi, rpoi,
  { {0x68290006,0xdb1c05b9,0x443f0072,0x00000000}},	//   _užda, skræ, _etu_,
  { {0x3e7800ea,0x7dc6006d,0x644268d3,0x00000000}},	//   vét_, _fósi, ppoi,
  { {0x63ab02f4,0x600f05a5,0xdb1c0354,0x00000000}},	//   ální, rømn, lkrä,
  { {0x3e78000f,0xd0070002,0x289b0047,0x00000000}},	//   tét_, нење_, ליפא,
  { {0x1df90076,0x3f8c68d4,0xe0cf007e,0x00000000}},	//   дены_, redu_, لزی_,
  { {0x3e7868d5,0x3f8c68d6,0x61560044,0x00000000}},	//   rét_, sedu_, _أنشئ,
  { {0x3e78000f,0x0ca8046a,0x61e21a60,0x00000000}},	//   sét_, нтри_, _imol,
  { {0x6fe60164,0x3e7800ea,0xb1130054,0x00000000}},	//   _décè, pét_, _сміш,
  { {0x39a7000d,0x660268d7,0xdb1c004d,0x00000000}},	//   ншав, kook, chrü,
  { {0x6440007d,0x6602004b,0x1994295f,0x00000000}},	//   _otmi, jook, лася,
  { {0xdb1c00c7,0xddc2013d,0x644d008f,0x00000000}},	// [e2b0] ekrä, cslő, šaiz,
  { {0x65600139,0x7dc60014,0x7e6800ca,0x00000000}},	//   _admh, _rósi, ordp,
  { {0x64440529,0x201e0006,0x659568d8,0x00000000}},	//   ţiil, imti_, кажу,
  { {0x3704000a,0xcb1201f9,0x6459030c,0x00000000}},	//   учув, _כלי_, tswi,
  { {0x62880006,0xdb1c0025,0x394968d9,0x00000000}},	//   _apdo, bhró, mbas_,
  { {0x386968da,0x394968db,0x6459316f,0x00000000}},	//   mrar_, lbas_, rswi,
  { {0x660268dc,0xe296005a,0x64402d12,0x00000000}},	//   book, ващ_, _etmi,
  { {0x56941705,0x201e0023,0xd24e00de,0x00000000}},	//   _щаст, emti_, آني_,
  { {0x386968dd,0x05840062,0xa5f8005e,0x00000000}},	//   nrar_, _щурм, _чету_,
  { {0x22910006,0x3f830014,0x3869125f,0x00000000}},	//   _tšk_, ýju_, irar_,
  { {0x7e7e0137,0x39490137,0x9d46032d,0x00000000}},	//   _äppl, kbas_, кенд,
  { {0x386901f7,0x9f5e0072,0x200c0014,0x00000000}},	//   krar_, eltä_, aldi_,
  { {0x7e68006f,0x4b560062,0x7de400ea,0x00000000}},	//   ardp, къвт, sőso,
  { {0x394902dd,0x3869626a,0x320d68de,0x00000000}},	//   ebas_, drar_, lley_,
  { {0x3b0768df,0x6dfa0002,0x3869233e,0x00000000}},	//   веро_, _охис_, erar_,
  { {0x25bf000c,0xb2220026,0x320d1823,0x00000000}},	//   _noul_, _þætt, nley_,
  { {0x7e7d000c,0xdb1c0139,0xdd1f004c,0x00000000}},	// [e2c0] ăspu, thró, píšo,
  { {0x46a65f40,0x7bd500bd,0xdb1c00bd,0x00000000}},	//   казв, chzu, tkrä,
  { {0xe57a0597,0x38694760,0x320d68e0,0x00000000}},	//   дзе_, arar_, kley_,
  { {0x600f0831,0x9182008b,0x3869073d,0x00000000}},	//   dømm, iệu_, brar_,
  { {0x200c0014,0xdb1c68e1,0x320d0305,0x00000000}},	//   yldi_, phró, dley_,
  { {0x3dd2002b,0x25ad68e2,0x764544ad,0x00000000}},	//   _llyw_, _enel_, bphy,
  { {0x37e30928,0x600f06a5,0x62630141,0x00000000}},	//   _торг, røml, авја,
  { {0x2b580027,0x31c30076,0x30a641af,0x00000000}},	//   harc_, исыв, вров,
  { {0xa06702a9,0x2eca0053,0xd1b70044,0x00000000}},	//   вања_, ान्त, ضايا_,
  { {0xfc3f006d,0x0eea0499,0xd9bf0042,0x00000000}},	//   nvíe_, дьми_, _एक्ट,
  { {0x39490078,0x320d1098,0x2b58009c,0x00000000}},	//   ybas_, bley_, darc_,
  { {0x442c0c8b,0x614646a5,0x386900a5,0x00000000}},	//   _hid_, _реда, yrar_,
  { {0x7d160051,0x257d013d,0x442c117e,0x00000000}},	//   _czys, láló_, _kid_,
  { {0x386968e3,0x7d080014,0x4ea63fdf,0x00000000}},	//   vrar_, _sérþ, _ариа,
  { {0x257d000f,0x1015000d,0x442c375e,0x00000000}},	//   náló_, _сьця, _mid_,
  { {0x442c68e4,0x38692b2e,0x320468e5,0x00000000}},	//   _lid_, trar_, nomy_,
  { {0x78a6017f,0x3946006d,0x3f9c68e6,0x00000000}},	// [e2d0] _crkv, ñosa_, _kavu_,
  { {0x442c0185,0x25ad4a36,0x6fcd0297,0x00000000}},	//   _nid_, _snel_, _núcl,
  { {0x25bf68e7,0x320d68e8,0xa7590023,0x00000000}},	//   _poul_, yley_, _āķīg,
  { {0x442c1d83,0x38693eb1,0x600f01f2,0x00000000}},	//   _aid_, prar_, vømm,
  { {0xd8380088,0x442c68e9,0x0564071f,0x00000000}},	//   _аэс_, _bid_, рвін,
  { {0x6e2d057a,0x69cd0072,0x320d68ea,0x00000000}},	//   _liab, lkae, wley_,
  { {0x442c0034,0x799d00a4,0x36d51314,0x00000000}},	//   _did_, _kasw, _совр,
  { {0x600f02ab,0x69cd032e,0x2c1a0053,0x00000000}},	//   rømm, nkae, _मीनू_,
  { {0xe4e7019d,0x799d0009,0x320d68eb,0x00000000}},	//   _рівн, _masw, rley_,
  { {0x7deb0051,0xe0d60121,0x320d4aaf,0x00000000}},	//   zęst, увь_, sley_,
  { {0xc7d60063,0x9f52004c,0x69d60072,0x00000000}},	//   רותי_, ádám_, yhye,
  { {0xe8e00013,0x442c68ec,0x8c460888,0x00000000}},	//   êịm_, _zid_, леме,
  { {0x407900b5,0x6e2d68ed,0x2b5801a8,0x00000000}},	//   _נאַװ, _diab, tarc_,
  { {0x61e9003d,0x7d00004c,0x6e2d004d,0x00000000}},	//   liel, _nárů, _eiab,
  { {0xd006005a,0x3f87003e,0x7deb0006,0x00000000}},	//   _щеше_, _ibnu_, tęst,
  { {0xf9d5000d,0x7dc60139,0x61e968ee,0x00000000}},	//   ацую, _cóst, niel,
  { {0x7d160045,0x60c9053b,0x7deb0006,0x00000000}},	// [e2e0] _uzys, nyem, ręst,
  { {0x60c9002c,0x61e905e4,0x2005001f,0x00000000}},	//   iyem, hiel, noli_,
  { {0x6d56003e,0x61e93079,0x60c90072,0x00000000}},	//   _keya, kiel, hyem,
  { {0xf1a30053,0x200568ef,0x257d00ea,0x00000000}},	//   _खोलन, holi_, váló_,
  { {0x6d56014f,0x200508c4,0x10030053,0x00000000}},	//   _meya, koli_, रकाश_,
  { {0xa3de0161,0x60db001c,0x2005251e,0x00000000}},	//   दों_, dzum, joli_,
  { {0x442c68f0,0x2005001f,0x320468f1,0x00000000}},	//   _vid_, doli_, tomy_,
  { {0x3f9c0418,0x61e90051,0xb3a40053,0x00000000}},	//   _savu_, giel, _गोरख,
  { {0x6e2d0290,0x442c1bbc,0xdcef001c,0x00000000}},	//   _riab, _tid_, recī,
  { {0x987b00b5,0x200568f2,0x61e93746,0x00000000}},	//   עריק, goli_, aiel,
  { {0x61e90102,0x6d56005b,0xb7db0047,0x00000000}},	//   biel, _beya, גקיי,
  { {0x01360032,0x60c900a4,0x629a6368,0x00000000}},	//   _إعاد, byem, _isto,
  { {0x00da007e,0x200568f3,0x3f9c3d6a,0x00000000}},	//   _ثبات_, boli_, _tavu_,
  { {0x200502f6,0x6b9e00cd,0x7e7d003b,0x00000000}},	//   coli_, _capg, ăspr,
  { {0x7dc668f4,0xe57f001c,0x1959000d,0x00000000}},	//   _póst, šķir_, кавы_,
  { {0x69da0a10,0x6e4304a0,0xbce70044,0x00000000}},	//   ūten, _انيم, _مأخو,
  { {0x7d0d0035,0x7c970021,0xf1c20013,0x00000000}},	// [e2f0] _uyas, _إشعا, _đỡ_,
  { {0x661b058c,0x61e90c65,0xf7700021,0x00000000}},	//   _shuk, ziel, كام_,
  { {0x799d0035,0xbb3a0063,0x56950612,0x00000000}},	//   _tasw, _בעתי, рает,
  { {0x7887001c,0xa3e70042,0x14750044,0x00000000}},	//   tīvā, मोन_, لاتج,
  { {0x61e93037,0x629a68f5,0x04670131,0x00000000}},	//   viel, _asto, утем,
  { {0x600f02ab,0x61e90051,0x629a00a8,0x00000000}},	//   rømk, wiel, _bsto,
  { {0x200568f6,0x61e968f7,0x661b0244,0x00000000}},	//   voli_, tiel, _thuk,
  { {0x60c900a4,0x20050051,0x629a00c2,0x00000000}},	//   tyem, woli_, _dsto,
  { {0x20053559,0x3f870150,0x61e968f8,0x00000000}},	//   toli_, _pbnu_, riel,
  { {0x61e968f9,0x0ea90076,0x09d20053,0x00000000}},	//   siel, вкой_, _सत्य,
  { {0x612b01f7,0x61e968fa,0x20053c80,0x00000000}},	//   _bölü, piel, roli_,
  { {0xb2ba0063,0xf2c40086,0x200568fb,0x00000000}},	//   _במער, _усун, soli_,
  { {0x200568fc,0x7df2003d,0x7c380c61,0x00000000}},	//   poli_, nāsi, _čvrs,
  { {0x629a0185,0x78a40290,0x765e0072,0x00000000}},	//   _ysto, vviv, yspy,
  { {0x3956000a,0x3946006d,0x993a0085,0x00000000}},	//   ињат, ñoso_, вязу_,
  { {0xf2d200b5,0x3946000d,0x3eaa00b9,0x00000000}},	//   קען_, рнаг, æbte_,
  { {0xe73a0095,0x7984002b,0x2ca968fd,0x00000000}},	// [e300] вез_, rfiw, _grad_,
  { {0x23a4016a,0x78a41e3e,0x7df2008f,0x00000000}},	//   _गोंद, rviv, dāsi,
  { {0x765e00fe,0x56930086,0xab2a02d8,0x00000000}},	//   uspy, жаєт, _јона_,
  { {0xa2a40161,0xfc3f006d,0x8699000d,0x00000000}},	//   किस्, lvía_, ытут_,
  { {0x9426005e,0x998c0078,0x00000000,0x00000000}},	//   амде, ūdų_,   ,
  { {0xfc3f006d,0x3860418c,0xb4b60042,0x00000000}},	//   nvía_, msir_, _छपी_,
  { {0xd2570088,0x4e060053,0x27ef12f7,0x00000000}},	//   ацы_, रवाई_, ègne_,
  { {0x39403889,0xdb2500ea,0x629a08c4,0x00000000}},	//   ncis_, ísér, _vsto,
  { {0xdfda005a,0x39400025,0x386068fe,0x00000000}},	//   вън_, icis_, nsir_,
  { {0x38600164,0x4ea6000d,0x4fc61406,0x00000000}},	//   isir_, арма, рсиа,
  { {0x6fcd0025,0xd7370063,0xd3b50121,0x00000000}},	//   _múch, יטית_, _усть,
  { {0x7de70086,0x386068ff,0xadd90121,0x00000000}},	//   ріод, ksir_, умму_,
  { {0xed580088,0x91a6008d,0xc0d30044,0x00000000}},	//   шоў_, _gió_, _ويمب,
  { {0xdb1e001f,0x7f581238,0x30db009a,0x00000000}},	//   _copï, _сакс_, _שַׁע,
  { {0x29e80058,0x9b5801f6,0x9a8701ce,0x00000000}},	//   aşam_, рист_, југл,
  { {0x3860014f,0x2ca96900,0x6829005f,0x00000000}},	//   fsir_, _trad_, _iždi,
  { {0x290f0026,0x6d5d58eb,0xe8380054,0x00000000}},	// [e310] æga_, masa, ипті_,
  { {0xcb990086,0xf7730242,0xdb1e001f,0x00000000}},	//   _свої_, تار_, _gopï,
  { {0x6fcd0025,0x29070051,0x38600089,0x00000000}},	//   _dúch, łna_, asir_,
  { {0x6d5d5162,0xdb050066,0x95670062,0x00000000}},	//   nasa, _dohô, ръжд,
  { {0x7bc50004,0x6d5d0228,0xdff80053,0x00000000}},	//   _kohu, iasa, ुवाद_,
  { {0xf677007e,0x33870062,0x6d5d6901,0x00000000}},	//   _پاسخ, рудв, hasa,
  { {0x6d5d00bb,0xc293007e,0x321d002b,0x00000000}},	//   kasa, تیاب, _phwy_,
  { {0x25d50047,0x84670062,0xd179000d,0x00000000}},	//   _פוּן_, _въже, ускі_,
  { {0x9f450290,0x6d5d0dbb,0x600905c5,0x00000000}},	//   bilì_, dasa, лним_,
  { {0x39590034,0x9f5e01a8,0x1fb50121,0x00000000}},	//   _less_, gotà_, ссир,
  { {0xd1310021,0x6d5d6902,0x3f85006c,0x00000000}},	//   _فما_, fasa, rflu_,
  { {0xfbc901d8,0xfc460080,0x63a14d6f,0x00000000}},	//   _את_, říme_, _haln,
  { {0x2281000f,0x6fcd039f,0xa0696903,0x00000000}},	//   lók_, _lúci, _сала_,
  { {0x8fa40021,0xad9b004c,0xa142008f,0x00000000}},	//   _ومنه, hoúh, _ēķin,
  { {0xc3320132,0x6d5d6904,0xfc3f006d,0x00000000}},	//   לום_, basa, rvía_,
  { {0x62830250,0x38600150,0x228100ea,0x00000000}},	//   itno, tsir_, iók_,
  { {0x395901e3,0x6c860021,0xdb050c38,0x00000000}},	// [e320] _dess_, _الخم, _anhä,
  { {0x6283218f,0x2281013d,0x98a20023,0x00000000}},	//   ktno, kók_, _iekļ_,
  { {0x3e63005b,0x394000cd,0xdb1e0240,0x00000000}},	//   nıt_, pcis_, _kopí,
  { {0x228100ea,0x250b007e,0x499a01a4,0x00000000}},	//   dók_, گرمی_, _стоя_,
  { {0x7794006a,0x63a168d9,0xdb0500a5,0x00000000}},	//   _ویرا, _baln, _enhä,
  { {0xd3700021,0x3e630058,0x69c639c4,0x00000000}},	//   ذهب_, kıt_, _hoke,
  { {0x69c6024a,0x6d440051,0xf6d50086,0x00000000}},	//   _koke, _ofia, _дітя,
  { {0x66f70063,0x69c63d8d,0x36f7009a,0x00000000}},	//   _המלא_, _joke, _הצלם_,
  { {0x69c600eb,0x9f450025,0x62833288,0x00000000}},	//   _moke, ailí_, atno,
  { {0x2e4a005a,0x389b0063,0x22810026,0x00000000}},	//   лямо_, ניינ, bók_,
  { {0x9df9000a,0x9f5e0942,0xd36f0021,0x00000000}},	//   инот_, gotá_, _أهم_,
  { {0x7bc80019,0x6d5d6905,0x3f82004c,0x00000000}},	//   ödun, uasa, řku_,
  { {0x6d5d0397,0x63a101f7,0xdb1e0195,0x00000000}},	//   rasa, _yaln, _dopí,
  { {0x6d5d6906,0x3eb80b64,0xda350121,0x00000000}},	//   sasa, ärts_, жевы,
  { {0x69c602f0,0x68290006,0x7bc500c2,0x00000000}},	//   _boke, _uždi, _vohu,
  { {0x5c750076,0x8e470021,0x69c65713,0x00000000}},	//   _длит, _اليك_, _coke,
  { {0x228100ea,0x6fcd00be,0x7bc56907,0x00000000}},	// [e330] zók_, _súci, _tohu,
  { {0x62830080,0x7bdc2bcb,0x711b0041,0x00000000}},	//   ytno, chru, רומפ,
  { {0xa93501dd,0x569416fc,0x29e80075,0x00000000}},	//   _менш, захт, kşah_,
  { {0xfc3f006d,0xd56b0086,0x15150456,0x00000000}},	//   nvío_, рiал, одея,
  { {0xa5bd00eb,0xd7fb019d,0xa5090001,0x00000000}},	//   _siųs, _був_, јела_,
  { {0x2281000f,0x3e6301f7,0x224925ea,0x00000000}},	//   tók_, yıt_, апки_,
  { {0x657a0027,0x217505ce,0x69c618c8,0x00000000}},	//   úchá, оупр, _yoke,
  { {0x644b00c7,0x63a11d20,0x2281013d,0x00000000}},	//   ppgi, _waln, rók_,
  { {0x63a10026,0x9f450080,0x10a50062,0x00000000}},	//   _taln, silí_, ципн,
  { {0x660b0203,0x289c07e9,0x8fa5005d,0x00000000}},	//   logk, ריזא, آمده,
  { {0xdb1e027d,0xf7720063,0x7e610014,0x00000000}},	//   _popí, וקי_, uslp,
  { {0xee36000d,0xc1e6007e,0x3a3a00a5,0x00000000}},	//   ўня_, _وکيل_, _rupp_,
  { {0x7bdc0025,0xa069005e,0x3a3a55fc,0x00000000}},	//   thru, _ђака_, _supp_,
  { {0xe1f90078,0x69c66908,0x00000000,0x00000000}},	//   lnų_, _soke,   ,
  { {0xe95a0062,0x69c644f3,0x2fc700a4,0x00000000}},	//   иращ_, _poke, _iong_,
  { {0x69d800eb,0x656900b9,0x600f000e,0x00000000}},	//   _įves, _ndeh, rømu,
  { {0x2fc76909,0x9f450003,0xe1f90078,0x00000000}},	// [e340] _kong_, oilà_, inų_,
  { {0x2fc736ee,0xddc20078,0x95f40053,0x00000000}},	//   _jong_, kslū, ेक्ट_,
  { {0x2fc74bf2,0x9bb70063,0x6449690a,0x00000000}},	//   _mong_, _והיה_, _atei,
  { {0x2fc753cf,0x34aa005e,0x442700dd,0x00000000}},	//   _long_, ивео_, emn_,
  { {0x7de400ea,0x6569002b,0x24e70141,0x00000000}},	//   lőss, _ddeh, омци_,
  { {0x66e62956,0x64490025,0x395200d1,0x00000000}},	//   _дога, _dtei, lbys_,
  { {0x249f00cd,0xbb3b0041,0x6449690b,0x00000000}},	//   _esum_, בעצי, _etei,
  { {0x442700c7,0x06070062,0xe5770500,0x00000000}},	//   amn_, _днск_, _мзс_,
  { {0xdfd00032,0x601400cd,0x9f4c0003,0x00000000}},	//   فية_, làmi, lidé_,
  { {0x388e001c,0x2fc7690c,0x2486690d,0x00000000}},	//   mērā_, _cong_, mtom_,
  { {0x60140268,0x2fc7690e,0x25a6001f,0x00000000}},	//   nàmi, _dong_, odol_,
  { {0x25a6690f,0x2486114b,0x7125005d,0x00000000}},	//   ndol_, otom_, _کرمل,
  { {0x2fc731ef,0x24866910,0x8fa60a29,0x00000000}},	//   _fong_, ntom_, _маде,
  { {0x61ed0024,0x2fc74439,0xfc3f0331,0x00000000}},	//   ďale, _gong_, svío_,
  { {0x69d80006,0x600f05dd,0x6fcd006d,0x00000000}},	//   _įver, rømt, _cúcu,
  { {0x2fc71c79,0x248648e8,0x200c6911,0x00000000}},	//   _zong_, ktom_, lodi_,
  { {0x25a60185,0xdcfd001c,0x2d996912,0x00000000}},	// [e350] ddol_, resē, mese_,
  { {0x2fc7008b,0x200c171a,0x2d995682,0x00000000}},	//   _xong_, nodi_, lese_,
  { {0x64496913,0x96350085,0xe6070054,0x00000000}},	//   _stei, чнец, оїдн,
  { {0x1a9a0047,0x2d991568,0xa7140086,0x00000000}},	//   _פירע, nese_, ємці,
  { {0x2d9900bd,0x200c0035,0x660b00b9,0x00000000}},	//   iese_, kodi_, rogk,
  { {0xf1a30053,0x25a6001f,0x44270150,0x00000000}},	//   _खोजन, adol_, umn_,
  { {0x9f4c0164,0x2d9964b6,0x2fc76914,0x00000000}},	//   cidé_, kese_, _rong_,
  { {0x0165000a,0x2fc71898,0x2d992386,0x00000000}},	//   чкио, _song_, jese_,
  { {0x10150088,0x2fc70537,0x2d996915,0x00000000}},	//   зьня, _pong_, dese_,
  { {0xb4d70161,0x200c01b3,0x60e60121,0x00000000}},	//   ानी_, godi_, ямым_,
  { {0x68290006,0xf7720047,0x7bc80019,0x00000000}},	//   _uždu, עקט_, ödum,
  { {0x6d410051,0x2d996916,0x2fc76917,0x00000000}},	//   ślan, gese_, _wong_,
  { {0x61fb000c,0x659a0047,0x2fc76918,0x00000000}},	//   mnul, זירק, _tong_,
  { {0x2d990290,0x2fc700a4,0x600f01f2,0x00000000}},	//   aese_, _uong_, røms,
  { {0x25a60767,0x8b234250,0x61fb6919,0x00000000}},	//   ydol_, едре, onul,
  { {0x61fb691a,0x68460002,0x7de4013d,0x00000000}},	//   nnul, знаа, rőss,
  { {0x24860024,0x7d7b0063,0x61fb691b,0x00000000}},	// [e360] xtom_, _הנפו, inul,
  { {0x7bd500bd,0x7b0700ea,0x3952001f,0x00000000}},	//   ckzu, érté, sbys_,
  { {0x61fb0253,0x3a29006f,0xbb3b0063,0x00000000}},	//   knul, bmap_, _לעיי,
  { {0x601400cd,0x24861dc0,0x8e5607e9,0x00000000}},	//   ràmi, ttom_, פינג_,
  { {0x293700b5,0x69c4001c,0x9f4c691c,0x00000000}},	//   _מאכן_, mjie, sidé_,
  { {0x5497000d,0x9d1b0047,0xdb1e0066,0x00000000}},	//   явіў_, זונט, _zopá,
  { {0x200c0c61,0x2d99691d,0x2486691e,0x00000000}},	//   vodi_, yese_, stom_,
  { {0x61fb1f3c,0x24863741,0x68e4691f,0x00000000}},	//   gnul, ptom_, ozid,
  { {0xfc3f0080,0x2d990fea,0xa4f8007e,0x00000000}},	//   tvím_, vese_, _بکار_,
  { {0x2d9900e8,0x6d460137,0x69c40050,0x00000000}},	//   wese_, ecka, hjie,
  { {0x2d99189b,0x200c5953,0x7a05005f,0x00000000}},	//   tese_, rodi_, lėte,
  { {0x67e000c7,0x36f70063,0x200c6920,0x00000000}},	//   _höjd, לצים_, sodi_,
  { {0xa2a40161,0x200c0290,0x69c46921,0x00000000}},	//   किक्, podi_, djie,
  { {0x60b70063,0x2d996922,0x69c4008f,0x00000000}},	//   _מהדף_, sese_, ejie,
  { {0x2d990173,0x7d046923,0x68e46924,0x00000000}},	//   pese_, _exis, ezid,
  { {0x6e242dba,0x7d1601cf,0x656201cf,0x00000000}},	//   _ghib, _fyys, jaoh,
  { {0xe8940121,0x7bc10014,0x3835045b,0x00000000}},	// [e370] нать, ölus, днар,
  { {0x61430026,0xb814005e,0xba990054,0x00000000}},	//   _kíló, едуј, _двоє_,
  { {0xdb1e0024,0x61fb6712,0xda670044,0x00000000}},	//   _topá, ynul, _عادي,
  { {0x68f8000f,0xd6d80076,0xdb1e00b9,0x00000000}},	//   áadá, чту_, _bopæ,
  { {0xb4d70053,0xfc3f004c,0x67e000a5,0x00000000}},	//   ाने_, dvík_, _böjd,
  { {0xa3e70161,0x9c870114,0x7e7a00b8,0x00000000}},	//   मों_, _začí, kutp,
  { {0x78ad0019,0x6d4600c7,0x61fb007d,0x00000000}},	//   lvav, ycka, tnul,
  { {0x200300b2,0x20d50054,0x61fb6925,0x00000000}},	//   čjim_, діос, unul,
  { {0x61fb1052,0x6d410080,0x8f750454,0x00000000}},	//   rnul, ělal, муні,
  { {0x2628000c,0x798d001f,0xdb2400ea,0x00000000}},	//   _uşor_, hfaw, űrés,
  { {0x443f10ca,0x7d1600fe,0x69dd534e,0x00000000}},	//   _huu_, _syys, _olse,
  { {0x443f25b3,0x02440021,0x29e8003b,0x00000000}},	//   _kuu_, _أَنَ, nşat_,
  { {0x443f0009,0x67e00137,0xddc900a8,0x00000000}},	//   _juu_, _höje, urdš,
  { {0x443f047f,0xc0e20002,0x7dc6013d,0x00000000}},	//   _muu_, _јошк, _jósz,
  { {0xfebb006a,0x69c400e8,0x160d0161,0x00000000}},	//   _داشت_, tjie, िकार_,
  { {0x753b0035,0x69c42886,0x7deb0022,0x00000000}},	//   _nguz, ujie, zęsz,
  { {0x6b9300c7,0xf1c30078,0x656201cf,0x00000000}},	// [e380] ädgå, mušė_, vaoh,
  { {0x69c46926,0x46f6065b,0x69d605b9,0x00000000}},	//   sjie, мчет, skye,
  { {0x3a260138,0x67e00137,0x6b9c6927,0x00000000}},	//   _омог, _nöje, merg,
  { {0x93bc008b,0x443f6928,0x6b9c6929,0x00000000}},	//   _chăn, _buu_, lerg,
  { {0x249a03eb,0x65620168,0x240a5cef,0x00000000}},	//   تخاب_, raoh, онди_,
  { {0x443f00cd,0x6b9c692a,0x43930121,0x00000000}},	//   _duu_, nerg, вашс,
  { {0xdced0058,0x067501d5,0x61fe006c,0x00000000}},	//   _ocağ, _путя, éplo,
  { {0x68290006,0x6b9c004d,0x44253668,0x00000000}},	//   _uždr, herg, _ehl_,
  { {0x6b9c0224,0x60f8047e,0x60630044,0x00000000}},	//   kerg, яния_, نهيل,
  { {0x60f70088,0x7e7a00a4,0x6b9c00b9,0x00000000}},	//   ьныя_, tutp, jerg,
  { {0x6440692b,0xa186000d,0x179b0063,0x00000000}},	//   _humi, _жылл, חייב,
  { {0x2cb20185,0x6b9c0a53,0x64401e22,0x00000000}},	//   _bryd_, eerg, _kumi,
  { {0x64400b4f,0x7c84032d,0x628a12b7,0x00000000}},	//   _jumi, куре, ltfo,
  { {0x64400006,0x6b9c692c,0x7e7a00b9,0x00000000}},	//   _mumi, gerg, putp,
  { {0x628a692d,0x64403b42,0x63a8692e,0x00000000}},	//   ntfo, _lumi, _madn,
  { {0x7bde00ea,0x63a8692f,0x2cb2002b,0x00000000}},	//   _elpu, _ladn, _fryd_,
  { {0x6440000c,0x9be70086,0x63ba006f,0x00000000}},	// [e390] _numi, _жінк, _ontn,
  { {0x443f00f3,0xa7740079,0xf77004f6,0x00000000}},	//   _ruu_, клуч, لام_,
  { {0xe47d005b,0x78ad021e,0x443f6930,0x00000000}},	//   ştüğ, svav, _suu_,
  { {0x69dd0089,0x64404ab6,0x443f01a9,0x00000000}},	//   _ulse, _bumi, _puu_,
  { {0xf99212cd,0xe4580086,0xe5340054,0x00000000}},	//   _ערך_, джі_, вець,
  { {0x6440000c,0x628a1df5,0x51f5005d,0x00000000}},	//   _dumi, ftfo, کستر,
  { {0x93bc008b,0x765c002b,0x386906d5,0x00000000}},	//   _thăn, _gwry, lsar_,
  { {0x386900cd,0x443f0035,0x63ba665a,0x00000000}},	//   osar_, _tuu_, _entn,
  { {0x38696931,0xdff5000d,0x39494d02,0x00000000}},	//   nsar_, еянь, icas_,
  { {0x38696932,0x6b9c017d,0x8ee90200,0x00000000}},	//   isar_, xerg, змов_,
  { {0x644000bd,0x9f4c0857,0x6fd60003,0x00000000}},	//   _zumi, cidí_, _mâch,
  { {0xed57019d,0x2cb2001f,0x6fd60003,0x00000000}},	//   ною_, _pryd_, _lâch,
  { {0x38690137,0xd4790047,0x6b9c6933,0x00000000}},	//   jsar_, האָל, terg,
  { {0xdce6003d,0x3949001c,0xc058007e,0x00000000}},	//   mekļ, ecas_, _آشنا_,
  { {0x501a0047,0x38696934,0x3af50121,0x00000000}},	//   _צוצו, esar_, вятс,
  { {0xe9df0025,0x6b9c4299,0x4c860054,0x00000000}},	//   _clú_, serg, _злив,
  { {0x48e30189,0x6b9c32ac,0xdce6008f,0x00000000}},	// [e3a0] готв, perg, nekļ,
  { {0xdce6001c,0x64400e45,0x4c060044,0x00000000}},	//   iekļ, _rumi, _سِجل,
  { {0x200300c3,0x63a81aa5,0x38694a6b,0x00000000}},	//   čjih_, _radn, asar_,
  { {0x644000bb,0x9f4c0080,0x2d826935,0x00000000}},	//   _pumi, vidí_, ngke_,
  { {0x7c2e6936,0x6fd60003,0xfba40053,0x00000000}},	//   ombr, _fâch, _ओसाम,
  { {0x7a050006,0x628a2767,0x6fd6006c,0x00000000}},	//   mėta, ttfo, _gâch,
  { {0x628a0031,0x764e0ddc,0x63a81035,0x00000000}},	//   utfo, _utby, _vadn,
  { {0x644026b2,0x64a6000d,0x628a516a,0x00000000}},	//   _tumi, _паба, rtfo,
  { {0x7a050078,0x9f4c01a8,0x628a59ea,0x00000000}},	//   nėta, sidí_, stfo,
  { {0xddc90051,0x3949006d,0x4f6a0121,0x00000000}},	//   łożo, zcas_, чшим_,
  { {0x11d60086,0xb7db0063,0x02d70044,0x00000000}},	//   _підр, פקטי, _كوكب_,
  { {0x7a050006,0x7c2e6937,0xc0e609c2,0x00000000}},	//   kėta, embr, _поек,
  { {0x68fb0024,0x91a6008b,0x442e090d,0x00000000}},	//   _ľudo, _nhỏ_, omf_,
  { {0x7a050006,0x7ac70002,0x3a750062,0x00000000}},	//   dėta, нсбе, клгр,
  { {0x3f9e6938,0xbea3007b,0x9b44009b,0x00000000}},	//   metu_, _бајк, انفو,
  { {0xee83000d,0x3f9e3564,0xdcfd001c,0x00000000}},	//   _сышо, letu_, nesī,
  { {0x394906b2,0xa89801dd,0xdcfd008f,0x00000000}},	// [e3b0] rcas_, нкту_, iesī,
  { {0x394904a6,0xc9140001,0x38696939,0x00000000}},	//   scas_, удућ, rsar_,
  { {0x3869693a,0xf77001a7,0xddc90006,0x00000000}},	//   ssar_, صال_, iudž,
  { {0x3f9e004b,0x3869693b,0x7bc8004e,0x00000000}},	//   hetu_, psar_, öduv,
  { {0x6fd60164,0x3f9e2f3e,0x25a90066,0x00000000}},	//   _tâch, ketu_, ľal_,
  { {0x3f9e017f,0x72950076,0x25a95aee,0x00000000}},	//   jetu_, вших, žal_,
  { {0xdb1c0026,0x69cf1643,0xfbb800ff,0x00000000}},	//   skrö, _koce, תפות_,
  { {0xb147005d,0x32d40085,0xd179014b,0x00000000}},	//   ریتم_, ыціс, фскі_,
  { {0x3c2400c7,0x3f9e0130,0x743504dc,0x00000000}},	//   höva_, fetu_, _анаф,
  { {0xbcfb0003,0x69cf008f,0xd00e00f2,0x00000000}},	//   raél, _loce, يلي_,
  { {0x236700c3,0x99800066,0xdcfd008f,0x00000000}},	//   manj_, lmiť_, besī,
  { {0x11f9007e,0x8d660062,0x69cf693c,0x00000000}},	//   _کوچک_, ъвме, _noce,
  { {0x20100026,0xddc9001c,0xe0ce1259,0x00000000}},	//   ólið_, budž, _тв_,
  { {0xab2a000d,0xc34e008d,0x7c2e693d,0x00000000}},	//   дога_, hổng_, umbr,
  { {0x69cf5149,0x6a860062,0x7c2e693e,0x00000000}},	//   _boce, ълва, rmbr,
  { {0x69cf18fb,0xaea80044,0xa3b30042,0x00000000}},	//   _coce, _أطول_, _जोस_,
  { {0x236700c3,0x69cf03a4,0xdddb004c,0x00000000}},	// [e3c0] kanj_, _doce, jstř,
  { {0xd7f90086,0x236700c3,0xd764007e,0x00000000}},	//   нує_, janj_, انای,
  { {0x26dc0114,0x7bdc0e04,0x7a050078,0x00000000}},	//   ávo_, mkru, sėta,
  { {0x7a050078,0xe7290043,0xa95a0044,0x00000000}},	//   pėta, رسلو_, _تجدر_,
  { {0x04940021,0xb8f60044,0x3957009d,0x00000000}},	//   التح, _شكسب, _בשכם_,
  { {0xdb0e007a,0x9cd70063,0x23675080,0x00000000}},	//   _þjón, כונה_, ganj_,
  { {0xe2970d34,0x3263026c,0x3f9e0c7e,0x00000000}},	//   вај_, атыв, vetu_,
  { {0x79840035,0x7bdc004b,0x33290085,0x00000000}},	//   ngiw, hkru, хцін_,
  { {0x7bdc0026,0x69360080,0x3f9e693f,0x00000000}},	//   kkru, břež, tetu_,
  { {0x9f5e00c6,0xa3e60053,0xcec10022,0x00000000}},	//   onté_, _पति_, kręć_,
  { {0xddc91535,0xfe780006,0x68fb0066,0x00000000}},	//   rudž, urį_, _ľudm,
  { {0xe0da0138,0x660200fe,0xe1fa0121,0x00000000}},	//   _ове_, nnok, _юге_,
  { {0xa3e60161,0x5f94018e,0x69cf30ee,0x00000000}},	//   _पता_, _билт, _roce,
  { {0x3d12016a,0x7bdc00f5,0x69da0003,0x00000000}},	//   _धुळे_, gkru, êten,
  { {0x69cf0403,0x1af4079f,0xa3e70042,0x00000000}},	//   _poce, апря, मोट_,
  { {0xddc8000c,0x660200ea,0x1f370063,0x00000000}},	//   ălţi, jnok, _ברור_,
  { {0x7bdc00e8,0x69cf6940,0x201e0290,0x00000000}},	// [e3d0] bkru, _voce, olti_,
  { {0xb8cb0161,0x7e7a083f,0x629a47a2,0x00000000}},	//   _कई_, ortp, _opto,
  { {0x2367082a,0xd5750500,0x9599005e,0x00000000}},	//   vanj_, гуль, етлу_,
  { {0x7a050006,0x2ca90150,0x320600a5,0x00000000}},	//   mėto, _ksad_, _njoy_,
  { {0x15140086,0x2367085a,0x7a050078,0x00000000}},	//   адця, tanj_, lėto,
  { {0x67e000a5,0xa3b30042,0x2409030b,0x00000000}},	//   _höjn, _जोश_, энли_,
  { {0x7a050006,0xe2960062,0xe2996941,0x00000000}},	//   nėto, гащ_, хай_,
  { {0x42d40086,0x2ca96942,0xa3b30042,0x00000000}},	//   рішу, _osad_, _जोर_,
  { {0x601d00cd,0xe4a40d34,0x25bf2806,0x00000000}},	//   lèmi, _врхо, _inul_,
  { {0xbfc50076,0x7a050006,0x61e200ea,0x00000000}},	//   убок, kėto, _elol,
  { {0xdb050118,0x32550071,0xe3b0007e,0x00000000}},	//   _bahí, _свер, _برق_,
  { {0x8d760032,0x7de400ea,0x7a050078,0x00000000}},	//   دادا, lősz, dėto,
  { {0xe1f90006,0x7e7a006f,0x601d00cd,0x00000000}},	//   mių_, artp, hèmi,
  { {0xe1f900eb,0xf0a80086,0x8c430156,0x00000000}},	//   lių_, _шкіл_, сере,
  { {0x7bdc01ac,0x19960002,0x2ca90745,0x00000000}},	//   rkru, лјар, _esad_,
  { {0xe1f90812,0x601d0268,0x3eb80093,0x00000000}},	//   nių_, dèmi, ærte_,
  { {0x3f8500c2,0xa7640062,0xa9260cb9,0x00000000}},	// [e3e0] oglu_, ижаr, удал,
  { {0x25bf5d2c,0x3dd2001f,0x2365004b,0x00000000}},	//   _anul_, _hoyw_, _nelj_,
  { {0xe1f900eb,0x7de400ea,0xe57a202f,0x00000000}},	//   kių_, dősz, езе_,
  { {0x25ad0c70,0xda7b0aeb,0xdb23005d,0x00000000}},	//   _cael_, _אנטר, _دوپی,
  { {0x7c3e6943,0xe1f9005f,0x44f6005d,0x00000000}},	//   _kipr, dių_, دساز,
  { {0x22456944,0x66026945,0x6d400058,0x00000000}},	//   _bulk_, snok, ımay,
  { {0xe81d0053,0xe7270bd8,0x66e64259,0x00000000}},	//   _बीटा_, _борд_, _сова,
  { {0x85b50138,0x25ad0185,0xe1f90006,0x00000000}},	//   _кључ, _gael_, gių_,
  { {0xdfd00032,0xa067018e,0x5506000d,0x00000000}},	//   قية_, гања_, _спаб,
  { {0x749b00ff,0x7c3e00dd,0xd0970044,0x00000000}},	//   _אימפ, _nipr, ائيا_,
  { {0xe1f90006,0x38170063,0x3a206946,0x00000000}},	//   bių_, רקים_, klip_,
  { {0x1df90076,0x443e1aaf,0x61460e48,0x00000000}},	//   темы_, _hit_, _седа,
  { {0x2245006f,0x443e15e6,0x50a80042,0x00000000}},	//   _zulk_, _kit_, _कनिष,
  { {0x7c3e5158,0x442c004d,0x113b009a,0x00000000}},	//   _cipr, _jhd_, _נתגל,
  { {0x443e6947,0xda78011c,0x7c3e014f,0x00000000}},	//   _mit_, лят_, _dipr,
  { {0x99553f67,0xb9550062,0x2ddb0021,0x00000000}},	//   ркац, рващ, _سبعة_,
  { {0x6e2d00a4,0xc7f5005e,0x443e6948,0x00000000}},	// [e3f0] _ihab, азаћ, _oit_,
  { {0xe1f90006,0x443e6949,0x4af6005d,0x00000000}},	//   zių_, _nit_, اکید_,
  { {0x6e2d694a,0x6d4f0290,0xdb05001f,0x00000000}},	//   _khab, occa, _wahâ,
  { {0x3a20694b,0x95c80062,0x9479005e,0x00000000}},	//   clip_, луча_, вску_,
  { {0x442c00e3,0xe1f900eb,0xe3ae0086,0x00000000}},	//   _bhd_, vių_, об_,
  { {0x987a0047,0x7c3e00cd,0xd7e40086,0x00000000}},	//   _באשט, _xipr, _лісо,
  { {0x67e001e3,0x3cfc0161,0x443e655c,0x00000000}},	//   _möjl, _लेने_, _dit_,
  { {0x25bf0529,0x443e694c,0x69cd5738,0x00000000}},	//   _unul_, _eit_, njae,
  { {0xe1f900eb,0x68ed02dd,0x443e04bc,0x00000000}},	//   rių_, nzad, _fit_,
  { {0xe1f900eb,0x443e005b,0x6d4f0290,0x00000000}},	//   sių_, _git_, ecca,
  { {0x7c3e02f6,0xe1f900eb,0x63a3694d,0x00000000}},	//   _ripr, pių_, menn,
  { {0x443e0122,0x3f85001f,0x656b694e,0x00000000}},	//   _zit_, sglu_, nagh,
  { {0x4c83005a,0x63c400ea,0x6283694f,0x00000000}},	//   оляв, _átné, luno,
  { {0x61fb000c,0x6609007d,0x63a36950,0x00000000}},	//   liul, _ljek, nenn,
  { {0xa96a005a,0x62836951,0x63a36952,0x00000000}},	//   кива_, nuno, ienn,
  { {0x6e2d0025,0x61fb2662,0xdb080026,0x00000000}},	//   _ghab, niul, _ólík,

  { {0x67560021,0x60db3d28,0x63a36953,0x00000000}},	// [e400] لخار, nyum, kenn,
  { {0x60c90268,0x63a36954,0x47c30c0b,0x00000000}},	//   ixem, jenn, обув,
  { {0x5b7b0063,0x22b5001c,0x22a700ea,0x00000000}},	//   _בריא, _nāk_, _nők_,
  { {0xdcf6005b,0x62836955,0xe7290021,0x00000000}},	//   _hayı, duno, اسكو_,
  { {0x63a30185,0xdcf601f7,0x61fb000c,0x00000000}},	//   fenn, _kayı, diul,
  { {0x7bce00c7,0x63a36956,0x61e96957,0x00000000}},	//   njbu, genn, ehel,
  { {0x6283048e,0x98b201f7,0x68fb0024,0x00000000}},	//   guno, mayı_, _ľudi,
  { {0x98b2005b,0x61fb003b,0x61e94be6,0x00000000}},	//   layı_, giul, ghel,
  { {0x63a30185,0xb376006a,0x73c6007e,0x00000000}},	//   benn, _نداش, _پيام,
  { {0x443e102f,0x63a36958,0x61e9004b,0x00000000}},	//   _uit_, cenn, ahel,
  { {0x61fb00e3,0x6283000c,0x3eb800ea,0x00000000}},	//   biul, cuno, írt_,
  { {0x61fb000c,0x61e96051,0x51830d4c,0x00000000}},	//   ciul, chel, _душа,
  { {0x98b2005b,0x3eb9008f,0xdcf60058,0x00000000}},	//   kayı_, āsta_, _bayı,
  { {0x656b00ca,0x8fa33774,0x6fb3009b,0x00000000}},	//   zagh, _маче, _ومنا,
  { {0x6e2d4956,0xec340086,0xde660062,0x00000000}},	//   _thab, інсь, _тълп,
  { {0x68ed0994,0x827700b5,0x6e2d05b3,0x00000000}},	//   tzad, יעלע_, _uhab,
  { {0x7c950032,0x63a31db7,0x98b2005b,0x00000000}},	// [e410] _الخص, yenn, fayı_,
  { {0x66090031,0x207b0047,0x68ed6959,0x00000000}},	//   _sjek, כאמא, rzad,
  { {0xa3ea016a,0x63a3695a,0x56950076,0x00000000}},	//   मसन_, venn, сает,
  { {0x3618019d,0x261c02dd,0xdcf6005b,0x00000000}},	//   ацію_, díos_, _zayı,
  { {0xdcf601f7,0x656b695b,0x22b5001c,0x00000000}},	//   _yayı, ragh, _sāk_,
  { {0x261c006d,0xdb050114,0x63a301e1,0x00000000}},	//   fíos_, _zahá, uenn,
  { {0x6609695c,0x656b0a9f,0x63a3695d,0x00000000}},	//   _tjek, pagh, renn,
  { {0xc69200b5,0x661b00ac,0x244b069f,0x00000000}},	//   _מאל_, _ukuk, _tøm_,
  { {0x6283695e,0x61fb23d8,0x20d50726,0x00000000}},	//   suno, riul, сійс,
  { {0xe3b80002,0x62833ac7,0x0ea90121,0x00000000}},	//   _клуч_, puno, гкой_,
  { {0x261c048e,0x60db0150,0xee3a2f16,0x00000000}},	//   cíos_, syum, лно_,
  { {0xdcf601f7,0x68290080,0x6441695f,0x00000000}},	//   _sayı, _vždy, _hili,
  { {0x64413a57,0x98b20058,0xdcf60058,0x00000000}},	//   _kili, yayı_, _payı,
  { {0x644104f8,0xf1c40013,0x66190022,0x00000000}},	//   _jili, ươì_, howk,
  { {0x64411de1,0x499a0121,0x98b20058,0x00000000}},	//   _mili, лтая_, vayı_,
  { {0x644126b2,0x91a60013,0x7f3a0047,0x00000000}},	//   _lili, _khó_, _געצו,
  { {0xdce40006,0x64490006,0x64410025,0x00000000}},	// [e420] _keič, _nuei, _oili,
  { {0x69cb0c38,0x64415072,0x3b860d34,0x00000000}},	//   öger, _nili, _улог,
  { {0x98b201f7,0x3cfc0053,0x45460021,0x00000000}},	//   rayı_, _लेते_, مناق,
  { {0x261c006d,0x98b20058,0x75890054,0x00000000}},	//   víos_, sayı_, исів_,
  { {0x64412f70,0x999e0006,0x644911f5,0x00000000}},	//   _bili, ūtų_, _cuei,
  { {0x64416960,0xdc9b0047,0x261c0139,0x00000000}},	//   _cili, רױסש, tíos_,
  { {0x6441261e,0xd3790054,0xd2570766,0x00000000}},	//   _dili, рчі_, бцы_,
  { {0x261c006d,0x90540781,0x64416961,0x00000000}},	//   ríos_, овиц, _eili,
  { {0xc1b7026c,0x64412cf5,0x3872002b,0x00000000}},	//   слых_, _fili, nsyr_,
  { {0xad9b007a,0x25a6001f,0x644124d5,0x00000000}},	//   rnúm, leol_, _gili,
  { {0x200b0016,0xad9b0026,0xa3ad0053,0x00000000}},	//   écia_, snúm, _औसत_,
  { {0x64410009,0x68300137,0xddeb014d,0x00000000}},	//   _zili, lädd, ارده_,
  { {0x5ce4014b,0xa0a3014b,0x81430044,0x00000000}},	//   пюра, _нацд, _عنون,
  { {0x25a60025,0xad9b0066,0x7a050078,0x00000000}},	//   heol_, onúk, mėti,
  { {0x7a050078,0x9b5810f6,0x6df50044,0x00000000}},	//   lėti, сист_, _وكتا,
  { {0xd2570063,0x7de7007e,0x998500de,0x00000000}},	//   משלה_, _دستم, تلرو,
  { {0x4d780063,0x7a050078,0x6fdf006c,0x00000000}},	// [e430] _התחל_, nėti, _bêch,
  { {0xe9df0025,0x8af906f0,0xdd310051,0x00000000}},	//   _siúd_, _внос_, _mężc,
  { {0x81c8001c,0x64416962,0xdb1e0051,0x00000000}},	//   orēķ, _rili, _dopó,
  { {0x9567005a,0x7a050006,0x64416963,0x00000000}},	//   съжд, kėti, _sili,
  { {0x64490367,0x64416964,0xdb05005b,0x00000000}},	//   _quei, _pili, _bahç,
  { {0x7a050006,0x42550257,0x24180085,0x00000000}},	//   dėti, отит, бочы_,
  { {0xc7b20063,0x6441148a,0x321d6965,0x00000000}},	//   _קבל_, _vili, _pkwy_,
  { {0xef18008f,0x96f80062,0x64415f01,0x00000000}},	//   ngļu_, _уест_, _wili,
  { {0x644109ff,0x63c40080,0x9f5e017d,0x00000000}},	//   _tili, átní, mitê_,
  { {0xcf390086,0x64410025,0xdb1e005b,0x00000000}},	//   ичні_, _uili, _popü,
  { {0x23740066,0x63c4004c,0x6da60239,0x00000000}},	//   šajú_, štní, оина,
  { {0xcdf60088,0xfbc90063,0x24805005,0x00000000}},	//   ічны, _בת_, šime_,
  { {0x68300354,0x387e008f,0x7fd50085,0x00000000}},	//   läde, _ātro_, _мікі,
  { {0xdee56966,0x653a0047,0x853a069a,0x00000000}},	//   _моли, יערד, יגרי,
  { {0xed5a005a,0xe7ff0053,0xbb4353a7,0x00000000}},	//   _кой_, ोचना_, дерк,
  { {0x7bc5017d,0x7db50085,0x00000000,0x00000000}},	//   _enhu, _есьц,   ,
  { {0x6fdf0164,0x683000bd,0x25a6004b,0x00000000}},	// [e440] _pêch, häde, veol_,
  { {0xbb860021,0x387200d1,0x9f5e0139,0x00000000}},	//   _بلدي, rsyr_, ontá_,
  { {0xd9465432,0x056a0002,0x85460121,0x00000000}},	//   _мени, ајли_, оэле,
  { {0xa526005a,0x64a602fe,0xee49008d,0x00000000}},	//   омед, жада, _lẽo_,
  { {0xdb1e6967,0xad9b0139,0x69c66968,0x00000000}},	//   _topó, liúc, _inke,
  { {0xd3a30062,0x68300e77,0x81c80023,0x00000000}},	//   дръп, fäde, zrēķ,
  { {0x683000c7,0x5333005e,0x03a3005e,0x00000000}},	//   rädd, мешт, фијо,
  { {0xe617005a,0x672e017f,0x22420014,0x00000000}},	//   _ддс_, _izbj, ökk_,
  { {0xc05a0086,0x656253ba,0x7d000014,0x00000000}},	//   шій_, mboh, úmsl,
  { {0xceb80078,0x33d52049,0x7a050078,0x00000000}},	//   tvę_, _ніхт, rėti,
  { {0x2450008b,0x69c61e05,0xc16f0054,0x00000000}},	//   _hàm_, _onke, _ої_,
  { {0x29dc0331,0x7bda6969,0xf77701ce,0x00000000}},	//   _mías_, ötun, циjе_,
  { {0x8cf4000d,0x81c8001c,0xfd44000d,0x00000000}},	//   дзяц, rrēķ, дэрн,
  { {0x212b00bd,0x99800078,0x69c6696a,0x00000000}},	//   üche_, kmių_, _anke,
  { {0x245000aa,0xf96b005a,0x81c8001c,0x00000000}},	//   _làm_, ирай_, prēķ,
  { {0xdce6003d,0x3f8c0026,0x0855000d,0x00000000}},	//   sakā, lgdu_, зваю,
  { {0x68fb0024,0xe8940121,0xdce6008f,0x00000000}},	// [e450] _ľuds, мать, pakā,
  { {0xcb35005a,0x69c60421,0x3f8c0026,0x00000000}},	//   _непъ, _enke, ngdu_,
  { {0xf1b9004c,0x6d48004c,0xac380044,0x00000000}},	//   loše_, ědav, _بسيط_,
  { {0x29dc048e,0xdb1e00cd,0x683000a5,0x00000000}},	//   _días_, _topò, väde,
  { {0x24f8000d,0x8cbe0053,0xa4d4071f,0x00000000}},	//   онцы_, शियो, моці,
  { {0x68300137,0x493a0063,0xf8bf0331,0x00000000}},	//   täde, _לגרו, _iré_,
  { {0x9f5e00cd,0xad9b0139,0x212908ed,0x00000000}},	//   mitè_, anúi, _šah_,
  { {0x798d014f,0x68300502,0xf1b9007d,0x00000000}},	//   ngaw, räde, koše_,
  { {0x24580076,0xa156005e,0x200b00be,0x00000000}},	//   _мать_, чању_, écio_,
  { {0x7a050006,0xf1b9007d,0x68301013,0x00000000}},	//   mėtu, doše_, päde,
  { {0x7a0500eb,0x660b696b,0xa3b80593,0x00000000}},	//   lėtu, ongk, _باقر_,
  { {0xcfe9006a,0x4427087d,0x92b4005d,0x00000000}},	//   _گفته_, lln_, _زحما,
  { {0x660b3d20,0xf1b9007d,0x7a050078,0x00000000}},	//   ingk, goše_, nėtu,
  { {0x798d0360,0xeb9a005e,0x6283696c,0x00000000}},	//   egaw, љив_, orno,
  { {0xee49008d,0xab2a696d,0x00000000,0x00000000}},	//   _kẽm_, сова_,   ,
  { {0x798d002c,0xad9b0027,0x8b66007e,0x00000000}},	//   ggaw, riúc, _کاظم,
  { {0x62830080,0x98a30962,0x05bf0042,0x00000000}},	// [e460] hrno, ните, _एफ़ब,
  { {0x798d002c,0x7a050006,0x660b017e,0x00000000}},	//   agaw, dėtu, engk,
  { {0x2bf70063,0xc869009a,0x7bdb009a,0x00000000}},	//   _זמין_, רן_, _הקיו,
  { {0x29dc006d,0x69c603a7,0xe5980085,0x00000000}},	//   _vías_, _unke, іклі_,
  { {0xf8bf0003,0x6283696e,0x656226c5,0x00000000}},	//   _gré_, erno, rboh,
  { {0x386008f0,0xa5330726,0x645b0025,0x00000000}},	//   mpir_, хніч, _dtui,
  { {0xa6a90021,0x02a30085,0xad9b0046,0x00000000}},	//   _وافق_, ерым, snúi,
  { {0x2fc700a4,0x9f5e696f,0xd6eb089e,0x00000000}},	//   _anng_, mité_, _הַמָ,
  { {0x9f5e03b2,0x6283158e,0xb0342b4f,0x00000000}},	//   lité_, arno, мниш,
  { {0x66021668,0xb4d80053,0x7bda004b,0x00000000}},	//   liok, ाही_, ötul,
  { {0x9f5e6970,0x23890080,0xe0cf007e,0x00000000}},	//   nité_, ňují_, نزی_,
  { {0x63aa0026,0x3f820058,0x66026971,0x00000000}},	//   lefn, şku_, niok,
  { {0x62981841,0x628a6972,0xc5f3009a,0x00000000}},	//   ltvo, lufo, תדר_,
  { {0x62981df9,0x63aa0014,0xb033000d,0x00000000}},	//   otvo, nefn, _зніш,
  { {0x798d00e8,0x9f9b0063,0x62982cdc,0x00000000}},	//   tgaw, _הסופ, ntvo,
  { {0x9f5e0164,0xf8bf0732,0x62980179,0x00000000}},	//   dité_, _pré_, itvo,
  { {0x798d021f,0x2c270086,0x765c0051,0x00000000}},	// [e470] rgaw, _ньог, _atry,
  { {0x201e031c,0x78ad6973,0x9f470114,0x00000000}},	//   noti_, rwav, _plné_,
  { {0x200c00bb,0xd6db005a,0x63aa001f,0x00000000}},	//   indi_, щта_, defn,
  { {0xf8bf2946,0x660b0bbf,0x69da0003,0x00000000}},	//   _tré_, ungk, êtet,
  { {0x62830185,0x3e4c0080,0x201e3716,0x00000000}},	//   wrno, _děti_, koti_,
  { {0x7a0500eb,0x3a29004b,0x9f5e29be,0x00000000}},	//   rėtu, llap_, bité_,
  { {0x9f5e2226,0x201e1b74,0x4e1d0053,0x00000000}},	//   cité_, doti_, नवाई_,
  { {0x200c1f4a,0x3a2925bd,0x7d1a0022,0x00000000}},	//   endi_, nlap_, ętsz,
  { {0x6b9c001f,0xf347007e,0x00c90054,0x00000000}},	//   yfrg, _فضاپ, ілок_,
  { {0x201e0d93,0xff510021,0x200c0014,0x00000000}},	//   goti_, خخة_, gndi_,
  { {0x93940021,0xe7f50053,0x6830004b,0x00000000}},	//   _سجلا, _इतना_, näda,
  { {0xed570086,0x7bc0001c,0x200c6974,0x00000000}},	//   мою_, ēmum, andi_,
  { {0x4174007e,0x55760047,0xee370603,0x00000000}},	//   _سانس, וערן_, ьню_,
  { {0xa022004b,0x201e00dd,0x6602504f,0x00000000}},	//   öötu, coti_, ziok,
  { {0x9f5e0003,0x60080063,0x8c430cd6,0x00000000}},	//   xité_, _מִקְ, тере,
  { {0x9f5e6975,0xad9b0139,0x67e00137,0x00000000}},	//   vité_, liún, _löjt,
  { {0xd378017f,0x764e6976,0x765c6977,0x00000000}},	// [e480] _hoće_, _suby, _stry,
  { {0x62980240,0x9f5e11f5,0xba560062,0x00000000}},	//   ytvo, tité_, _отмъ,
  { {0x86c60021,0x3e4c0080,0x320d0caf,0x00000000}},	//   بيان, _pěti_, kney_,
  { {0x9f5e03b2,0x7d7b0047,0x38600014,0x00000000}},	//   rité_, ַנצו, ppir_,
  { {0x63aa0026,0x9f5e250d,0x320d22a4,0x00000000}},	//   tefn, sité_, dney_,
  { {0xd25a1259,0x684601dd,0x9f5e0003,0x00000000}},	//   оци_, _інва, pité_,
  { {0xe28f0032,0x765c01b9,0xdb0700ea,0x00000000}},	//   لذي_, _utry, tejé,
  { {0x63aa0026,0x62986978,0x628a6979,0x00000000}},	//   sefn, rtvo, rufo,
  { {0x68e400f3,0x62982968,0x201e13ed,0x00000000}},	//   nyid, stvo, toti_,
  { {0x24860031,0xff980001,0x201e0006,0x00000000}},	//   mrom_, чкој_, uoti_,
  { {0x3c2400c7,0xdef7000d,0x68e40089,0x00000000}},	//   hövs_, дыя_, hyid,
  { {0x6e360114,0x644800e5,0x00e61dd0,0x00000000}},	//   _chyb, _hidi, _ожен,
  { {0x64480035,0x201e697a,0x32040051,0x00000000}},	//   _kidi, poti_, mimy_,
  { {0x6e2401f7,0x7fb8006a,0x2d850058,0x00000000}},	//   _ekib, _رهبر_, şle_,
  { {0x7ed30021,0xf1b9007d,0x60c204a8,0x00000000}},	//   _لزيا, loša_, _hrom,
  { {0x2d8f0146,0x60c2697b,0xd2b70063,0x00000000}},	//   _øge_, _krom, וללת_,
  { {0x7b67042c,0x5a44000d,0xf1b91844,0x00000000}},	// [e490] _отне, тэра, noša_,
  { {0xc6170053,0x3a291cff,0x64480409,0x00000000}},	//   तव्य_, slap_, _nidi,
  { {0x9f4c006d,0x6c180021,0x9f450072,0x00000000}},	//   lidó_, _تتيح_, silö_,
  { {0x683000c7,0x6448697c,0x7ae800b9,0x00000000}},	//   räda, _aidi, ødte,
  { {0xb4e90235,0x6448090c,0xf1b9008f,0x00000000}},	//   मने_, _bidi, joša_,
  { {0x320d358b,0x69dd1538,0x68300244,0x00000000}},	//   wney_, _hose, päda,
  { {0x387e001c,0x69dd697d,0x6448697e,0x00000000}},	//   _ātri_, _kose, _didi,
  { {0x9e480024,0x6448002b,0x2486697f,0x00000000}},	//   _keďž, _eidi, brom_,
  { {0x6e36001f,0x320d4f8d,0x7bda0019,0x00000000}},	//   _rhyb, rney_, ötuk,
  { {0x6e246980,0x6448005b,0xf8b20063,0x00000000}},	//   _skib, _gidi, נשי_,
  { {0xad9b0025,0x32040022,0xddcd0075,0x00000000}},	//   riún, bimy_, ükşe,
  { {0xad9b0027,0xd378007d,0x68e40949,0x00000000}},	//   siún, _voće_, yyid,
  { {0x2e320026,0x3c3600b9,0xad9b4945,0x00000000}},	//   gáfa_, hæve_, miúl,
  { {0xad9b0139,0x4c350085,0x6e3d6981,0x00000000}},	//   liúl, вэст, amsb,
  { {0x20056982,0xf1d30053,0x69dd6983,0x00000000}},	//   mili_, थापन, _bose,
  { {0xf2d200b7,0x61e96984,0x69dd14c4,0x00000000}},	//   נען_, nkel, _cose,
  { {0x69dd2748,0xa84a0754,0x61e94872,0x00000000}},	// [e4a0] _dose, سلام_, ikel,
  { {0x68f60051,0xd7f90086,0xdc9b0047,0x00000000}},	//   rzyd, мує_, _צייל,
  { {0x644809ee,0x68e40150,0x61e95389,0x00000000}},	//   _ridi, syid, kkel,
  { {0x7ae1627f,0x20056985,0x61e9006f,0x00000000}},	//   älte, hili_, jkel,
  { {0x43944d63,0x64486986,0xad9b0139,0x00000000}},	//   валс, _pidi, diúl,
  { {0x20056987,0x24805a9f,0x61e96988,0x00000000}},	//   jili_, šimo_, ekel,
  { {0x64486989,0x248604aa,0x2005698a,0x00000000}},	//   _vidi, srom_, dili_,
  { {0x7bde024a,0x64480150,0xf1b9001c,0x00000000}},	//   _lopu, _widi, toša_,
  { {0x644801e3,0x31570032,0x20054984,0x00000000}},	//   _tidi, رجية_, fili_,
  { {0x32040045,0x20053cde,0x6448006f,0x00000000}},	//   simy_, gili_, _uidi,
  { {0x211a006a,0x3f9e0026,0x9f4c0290,0x00000000}},	//   _کتاب_, rftu_, fidò_,
  { {0x61e9698b,0xad9b0025,0x60c2698c,0x00000000}},	//   ckel, ciúl, _trom,
  { {0x9ccb000d,0x20055153,0xafe60f34,0x00000000}},	//   чына_, bili_, _подл,
  { {0x69dd698d,0x2005698e,0x6f0b013d,0x00000000}},	//   _sose, cili_, álcá,
  { {0x63ba0b3e,0x69dd698f,0x7bde034a,0x00000000}},	//   _matn, _pose, _dopu,
  { {0x8e830021,0x7e7a6494,0x63ba3dc6,0x00000000}},	//   _إليه, mstp, _latn,
  { {0xbddb0110,0x9f5e01a8,0x3e4c004c,0x00000000}},	// [e4b0] rmèd, hití_, _větu_,
  { {0x7c250089,0xd7c9007e,0x7e7a00ca,0x00000000}},	//   _ukhr, بوطه_, ostp,
  { {0x56950076,0x57a4000d,0x99800734,0x00000000}},	//   тает, ышта, sliš_,
  { {0x20053382,0xd6270044,0x14750044,0x00000000}},	//   zili_, رعاي, ناتج,
  { {0xe4580086,0x44250dde,0x63ba0014,0x00000000}},	//   ежі_, _pkl_, _batn,
  { {0xec720047,0xdb1e00be,0xe3b1009b,0x00000000}},	//   בֿה_, _topô, شرت_,
  { {0x61e9024a,0x63ba003d,0xb5a70304,0x00000000}},	//   tkel, _datn, _прай,
  { {0x6830004d,0xb5c9007e,0x2ca96990,0x00000000}},	//   hädl, _تورم_, _opad_,
  { {0xdb07004c,0x20056991,0x61e96992,0x00000000}},	//   dejí, tili_, rkel,
  { {0xe9df0027,0xad9b0025,0x61e96993,0x00000000}},	//   _siúl_, siúl, skel,
  { {0x61ec00ea,0x8e850062,0x20051055,0x00000000}},	//   álló, ъгне, rili_,
  { {0x249d001f,0x20051fdf,0x7a0c003b,0x00000000}},	//   otwm_, sili_, oşte,
  { {0x7bde6917,0x20056994,0x249d00a3,0x00000000}},	//   _popu, pili_, ntwm_,
  { {0xafe20076,0x00000000,0x00000000,0x00000000}},	//   _вошл,   ,   ,
  { {0xab270e48,0xf1b9008f,0xadfa0044,0x00000000}},	//   вора_, nošo_, _يربط_,
  { {0x2a36000d,0x00000000,0x00000000,0x00000000}},	//   тэгр,   ,   ,
  { {0x25bd0185,0x3946000d,0x2bba0021,0x00000000}},	// [e4c0] ddwl_, тнаг, _قادة_,
  { {0xf1b9001c,0xbcfb006c,0x8c460505,0x00000000}},	//   košo_, zbék, _шепе,
  { {0xc815019d,0x63ba6995,0xf1b9001c,0x00000000}},	//   уєть, _ratn, jošo_,
  { {0xd5d5000d,0x63ba007d,0xdb0e0137,0x00000000}},	//   лючы, _satn, rdbä,
  { {0x2b060053,0x63ba395b,0xe76a0021,0x00000000}},	//   _हेतु_, _patn, _يحسن_,
  { {0x82a60076,0xdb070080,0x7e7a04aa,0x00000000}},	//   вшие, zejí, ystp,
  { {0x63ba0627,0xfba40053,0x2ba40053,0x00000000}},	//   _vatn, ख्यम, ख्या,
  { {0xcb1312cd,0xdce60078,0xa021004b,0x00000000}},	//   ילו_, sakę, öönd,
  { {0x2737005f,0xa446197b,0x64a601ce,0x00000000}},	//   ažnį_, _анад, _јаза,
  { {0x9ed8000a,0xef1f0058,0x00000000,0x00000000}},	//   емот_, ğün_,   ,
  { {0xf1b9001c,0xd36f007e,0xef1f0058,0x00000000}},	//   cošo_, _ذهن_, şün_,
  { {0x067b0047,0x7e7a6996,0x867b0063,0x00000000}},	//   ונטל, rstp, ורטו,
  { {0x5c07011c,0x6fb60021,0xdb070331,0x00000000}},	//   вява, _لمشا, rejí,
  { {0xdb0702f4,0xce940062,0xa0770041,0x00000000}},	//   sejí, _бакъ, _יעדנ_,
  { {0x9f5e051e,0x20190164,0x200b00cd,0x00000000}},	//   mità_, ésie_, ècie_,
  { {0x9f5e02f6,0x628a6997,0x394f01e1,0x00000000}},	//   lità_, irfo, øgs_,
  { {0xdb0700ea,0x6d5d00ea,0xa8150a91,0x00000000}},	// [e4d0] ldjü, mcsa, гдаш,
  { {0x9f5e02f6,0xd9440001,0x109b0063,0x00000000}},	//   nità_, ређи, ובמב,
  { {0x628a00b9,0xa3b60053,0xf77000f2,0x00000000}},	//   jrfo, ज़न_, زال_,
  { {0x442e6998,0x249d002b,0x6d5d013d,0x00000000}},	//   elf_, ttwm_, ncsa,
  { {0x45840086,0x6594257e,0x69cf6999,0x00000000}},	//   ргів, рачу, _ince,
  { {0xf1b9001c,0x59d10053,0x8235005d,0x00000000}},	//   tošo_, हावर, گرتا,
  { {0x9f5e051e,0x36d40076,0xa2c00053,0x00000000}},	//   dità_, _корр, विष्,
  { {0x442e57c4,0xd378007d,0xf1b9008f,0x00000000}},	//   alf_, _voća_, rošo_,
  { {0x628a0003,0xbcfb0153,0xf1b9008f,0x00000000}},	//   arfo, ncéd, sošo_,
  { {0x9f5e01f4,0x9f450139,0x76550022,0x00000000}},	//   gità_, mhlú_, _kuzy,
  { {0xdb05004c,0x69cf3700,0x5f050b69,0x00000000}},	//   _pahý, _once, узна,
  { {0x76550051,0x2459008b,0x26b60063,0x00000000}},	//   _muzy, _kèm_, נִים_,
  { {0x2d9e0051,0xe0ce699a,0x7c990094,0x00000000}},	//   ęte_, _ув_, кърс_,
  { {0x9f5e02f6,0x2d9e0080,0xb2260026,0x00000000}},	//   cità_, řte_, phæð,
  { {0xcf24007e,0xf8bf013d,0x99800066,0x00000000}},	//   _پروي, _szép_, hliť_,
  { {0x7ae10137,0xdb1c0b6c,0x5cd60054,0x00000000}},	//   älta, ndré, _біох,
  { {0x5975000d,0xdb0e0014,0x6e26013d,0x00000000}},	// [e4e0] рысу, ndbú, mokb,
  { {0x69cf3a4e,0x46f60062,0x67f20014,0x00000000}},	//   _ence, лчет, _bæja,
  { {0x99800066,0x7aec00dd,0xdb9b009a,0x00000000}},	//   eliť_, ântă, _אסיר,
  { {0xd5b9013c,0x99890022,0xd49a080a,0x00000000}},	//   ксі_, anał_, ерк_,
  { {0xbcfb0164,0xa4d40086,0xdb07013d,0x00000000}},	//   ccéd, ролі, zdjü,
  { {0xdb07013d,0x6d5d013d,0xd7f20044,0x00000000}},	//   lejá, zcsa, _اكس_,
  { {0x9f5e02f6,0x2bd50053,0xdced0058,0x00000000}},	//   vità_, दाता, _odağ,
  { {0xbcfb0025,0x2ba40082,0x00000000,0x00000000}},	//   sbéi, ख्ता,   ,
  { {0x9f5e051e,0x463b00b5,0xe45f005b,0x00000000}},	//   tità_, _טעלע, _çöp_,
  { {0xbcfb0164,0xad9b0025,0xd0070699,0x00000000}},	//   ncée, miúi, лење_,
  { {0x9f5e5706,0x8f341b8b,0x29dc2589,0x00000000}},	//   rità_, ренц, _díaz_,
  { {0x9f5e051e,0x867b0063,0x99890051,0x00000000}},	//   sità_, ערכו, znał_,
  { {0x9f5e00cd,0xad9b0025,0xcd071b8b,0x00000000}},	//   pità_, niúi, учни,
  { {0xab9520cf,0x61e20004,0x30830021,0x00000000}},	//   јављ, _hool, _الوف,
  { {0x61e2010e,0xf1b80053,0xad9b0139,0x00000000}},	//   _kool, _आसान, hiúi,
  { {0x7655004c,0x61e2004e,0x391501ce,0x00000000}},	//   _ruzy, _jool, амбр,
  { {0x9da80062,0xe895000d,0xa775005e,0x00000000}},	// [e4f0] _съща_, разь, илач,
  { {0xad9b0025,0x7bda004b,0xbcfb006c,0x00000000}},	//   diúi, ötut, rcéd,
  { {0x26c75d66,0x9f45004c,0xbb76009a,0x00000000}},	//   íno_, yklí_, _דעתו_,
  { {0xe60e019d,0x69cf0034,0x99800066,0x00000000}},	//   ід_, _unce, tliť_,
  { {0xad9b0025,0xa97a0063,0xf1e70042,0x00000000}},	//   giúi, _בארכ, टॉफ़_,
  { {0x3869699b,0x62650a72,0x67f20046,0x00000000}},	//   mpar_, авка, _tæja,
  { {0x61e2699c,0x3869699d,0xbcfb013d,0x00000000}},	//   _bool, lpar_, ncéb,
  { {0x11e50055,0x7a0c003b,0x61e2255c,0x00000000}},	//   ржим, oşta, _cool,
  { {0xe5340086,0xad9b0025,0x660b004d,0x00000000}},	//   _геть, ciúi, migk,
  { {0xef1f01f7,0x93940021,0x25bf035a,0x00000000}},	//   şüm_, _هجما, _haul_,
  { {0x61e20034,0x6e2600ea,0xc7b20063,0x00000000}},	//   _fool, tokb, חבי_,
  { {0x3f8b003b,0xc105007e,0x64430137,0x00000000}},	//   şcu_, _پوتي, lmni,
  { {0x7ae100bd,0x200b0164,0x4427699e,0x00000000}},	//   ältn, écis_, oon_,
  { {0x660b00bd,0x6e2600ea,0x64430025,0x00000000}},	//   higk, sokb, nmni,
  { {0x6443008f,0x6e2600ea,0xab2a3f45,0x00000000}},	//   imni, pokb, това_,
  { {0x4427699f,0xc9660062,0x248063f3,0x00000000}},	//   hon_, рвай, šimi_,
  { {0x97560138,0x7bda0019,0x660b00bd,0x00000000}},	// [e500] атељ, ötus, digk,
  { {0x442769a0,0x64430045,0xbc7b0063,0x00000000}},	//   jon_, jmni, _שנית,
  { {0x660b00bd,0xbcfb0003,0xb6070013,0x00000000}},	//   figk, rcée, _trờ,
  { {0xad9b0027,0x660b00bd,0x4427001f,0x00000000}},	//   tiúi, gigk, eon_,
  { {0x683000bd,0x24800025,0x044605fb,0x00000000}},	//   hädi, éim_, аедн,
  { {0xad9b0025,0x68220066,0x60c40139,0x00000000}},	//   riúi, hôdz, _áimi,
  { {0x61e2010e,0xad9b0025,0x66e61518,0x00000000}},	//   _pool, siúi, _това,
  { {0x2489001c,0x442700a4,0x644369a1,0x00000000}},	//   šama_, aon_, amni,
  { {0xdfd00032,0x442769a2,0x61e20019,0x00000000}},	//   كية_, bon_, _vool,
  { {0x61e228c5,0x442769a3,0x2378009a,0x00000000}},	//   _wool, con_, _תָּמ,
  { {0x20190268,0x200b0268,0x3fc8007e,0x00000000}},	//   ésia_, ècia_, ندگی_,
  { {0xb6d90047,0xc2c4007e,0xe1f90078,0x00000000}},	//   אַשט, _پيچي, chų_,
  { {0x2cad00ac,0x5cb80085,0x00d70043,0x00000000}},	//   ïed_, аляў_, _نبوت_,
  { {0x8fa3005e,0x99890022,0x9ce40054,0x00000000}},	//   _даље, znań_, іцял,
  { {0xaae80086,0x443e00b9,0x7ac41518,0x00000000}},	//   аєте_, _mht_, осте,
  { {0x200c097c,0x7bda0019,0x442769a4,0x00000000}},	//   lidi_, ötur, zon_,
  { {0x44270273,0xa3b60161,0x26ca69a5,0x00000000}},	// [e510] yon_, ज़ा_, _arbo_,
  { {0xc7f80086,0x200c614a,0x66c7005e,0x00000000}},	//   анує_, nidi_, иљеж,
  { {0x660b00bd,0x44390006,0xe945007e,0x00000000}},	//   tigk, _ės_, _گردی,
  { {0x2d99021f,0x386950d3,0x200c0035,0x00000000}},	//   ngse_, ppar_, hidi_,
  { {0x660b00bd,0x200c1643,0xd49b0336,0x00000000}},	//   rigk, kidi_, тре_,
  { {0x660b00bd,0x84280086,0x6443546f,0x00000000}},	//   sigk, ажів_, umni,
  { {0x68ed1362,0x442769a6,0x9f5e00fe,0x00000000}},	//   lyad, ron_, iitä_,
  { {0xef1f005b,0x442714ac,0xdb07004b,0x00000000}},	//   şük_, son_, mejä,
  { {0x66090035,0x91fc001c,0x442769a7,0x00000000}},	//   _imek, _itāl, pon_,
  { {0x753b017f,0x41020076,0x200c01f4,0x00000000}},	//   _izuz, языв, gidi_,
  { {0x539a0063,0xdb070050,0xa3c40082,0x00000000}},	//   _תיעו, nejä, एयर_,
  { {0x200c0d74,0xc69200b5,0xdce6008f,0x00000000}},	//   aidi_, האט_, ebkā,
  { {0x200c0035,0x661b00c7,0x9f4c00fe,0x00000000}},	//   bidi_, _mjuk, ehdä_,
  { {0x3c190088,0x200c69a8,0x6b6311ec,0x00000000}},	//   аўся_, cidi_, зкра,
  { {0x6e95043b,0x254b0006,0xa3a90053,0x00000000}},	//   _العا, lėlį_, ग्य_,
  { {0x61b50082,0x9e6414d7,0x00000000,0x00000000}},	//   _अघोष, _باون,   ,
  { {0xed620006,0x6d5600a4,0x26ca00a8,0x00000000}},	// [e520] ąžą_, _igya, _srbo_,
  { {0x660935fc,0xdb1c2ee1,0x661b1848,0x00000000}},	//   _amek, ldrí, _ajuk,
  { {0x61fb00ac,0xdb1c09aa,0x5b570149,0x00000000}},	//   khul, odrí, _לייב_,
  { {0xdb1c02dd,0x200c0035,0x765a0003,0x00000000}},	//   ndrí, zidi_, _étym,
  { {0xceb80051,0xd378007d,0x25a6002b,0x00000000}},	//   zwę_, _peć_, rfol_,
  { {0x69c4356b,0x25a600ac,0x61fb0104,0x00000000}},	//   ldie, sfol_, ehul,
  { {0xd3780117,0x200c69a9,0xbcfb0025,0x00000000}},	//   _već_, vidi_, icéa,
  { {0x61fb0009,0xda7b0047,0x200c0035,0x00000000}},	//   ghul, אנקר, widi_,
  { {0x290069aa,0x78a469ab,0x200c01f4,0x00000000}},	//   nzia_, ntiv, tidi_,
  { {0x6e2d010a,0x61fb69ac,0x290000be,0x00000000}},	//   _skab, ahul, izia_,
  { {0x9f5e024a,0x78a42c84,0x69c469ad,0x00000000}},	//   vitä_, htiv, kdie,
  { {0xd7370063,0x61fb0c84,0x200c14d1,0x00000000}},	//   מטית_, chul, sidi_,
  { {0x200c69ae,0x69c40ca8,0x013600f2,0x00000000}},	//   pidi_, ddie, _اعاد,
  { {0x69c45d6a,0x290027f1,0x31740022,0x00000000}},	//   edie, dzia_, ńczą_,
  { {0xec34019d,0xcfa9006a,0x9f5e00fe,0x00000000}},	//   їнсь, _خانم_, ritä_,
  { {0xf1b9001c,0x6e2d05b3,0x69c40229,0x00000000}},	//   toši_, _ukab, gdie,
  { {0x7c970049,0x661b00a5,0x89340044,0x00000000}},	// [e530] _اشعا, _rjuk, كعكا,
  { {0x661b02eb,0x660900c7,0x68ed0cc6,0x00000000}},	//   _sjuk, _smek, ryad,
  { {0x68ed1395,0x69c4001c,0x290069af,0x00000000}},	//   syad, bdie, azia_,
  { {0x999900eb,0xd246006a,0x3f8a0051,0x00000000}},	//   _visų_, _زن_, óbuj_,
  { {0x0395008f,0xdb07004b,0xc4840085,0x00000000}},	//   žīmā_, sejä, злік,
  { {0xd7f10013,0x254b0078,0x248969b0,0x00000000}},	//   _ỗ_, vėlį_, šamo_,
  { {0xdb1e017d,0xe945007e,0x7a33005b,0x00000000}},	//   _papé, _درگی, eçti,
  { {0x66090035,0x254b0078,0x52a60085,0x00000000}},	//   _umek, tėlį_, івым_,
  { {0x61fb405c,0x201900be,0xcfb50121,0x00000000}},	//   rhul, ésio_, ощны,
  { {0x69c40024,0x60092c9e,0x61fb1c42,0x00000000}},	//   zdie, рном_, shul,
  { {0x61fb00e8,0x20f4001b,0x60c40006,0x00000000}},	//   phul, ài_, _šimt,
  { {0x9f450114,0xf8bf0003,0x20d500de,0x00000000}},	//   chlý_, _osé_, _وقاس,
  { {0x628310b8,0x290f0014,0xc0e508b0,0x00000000}},	//   lsno, úgal_, _фолк,
  { {0xda660021,0x317f013d,0xcfe9005d,0x00000000}},	//   قاري, lauz_, _خفته_,
  { {0x60c907d2,0x1ea8005d,0xad9b0195,0x00000000}},	//   lvem, _هايي_, tiút,
  { {0x78a469b1,0xbcfb69b2,0x69c42174,0x00000000}},	//   ttiv, scéa, udie,
  { {0x69c469b3,0xad9b017d,0x98a31410,0x00000000}},	// [e540] rdie, aiús, мите,
  { {0x29000024,0x9cb3007e,0x78a408c9,0x00000000}},	//   rzia_, _کمیت, rtiv,
  { {0x56930086,0x78a409e2,0xbb460062,0x00000000}},	//   даєт, stiv, _фенк,
  { {0xdb1c0016,0x64410222,0x645b00a4,0x00000000}},	//   adrã, _ahli, _buui,
  { {0x64410027,0x21f800ea,0x58d3000d,0x00000000}},	//   _bhli, _néha_, _жоўт,
  { {0x20190003,0x2caf0137,0x644169b4,0x00000000}},	//   ésil_, _ägde_, _chli,
  { {0xfc3f02dd,0xdb1c00cd,0xa3a90053,0x00000000}},	//   ntía_, ndrà, ग्ध_,
  { {0xd378017f,0x317f693e,0x64410075,0x00000000}},	//   _moći_, gauz_, _ehli,
  { {0xef18001c,0xf1b9001c,0x62832211,0x00000000}},	//   daļa_, jošu_, asno,
  { {0xdb0e0026,0xb4d60053,0x765c69b5,0x00000000}},	//   ndbó, िमी_, _kury,
  { {0xd378017f,0x765c2134,0x63b800c2,0x00000000}},	//   _noći_, _jury, mevn,
  { {0x1687009d,0x00000000,0x00000000,0x00000000}},	//   חֲךָ_,   ,   ,
  { {0xdb1500ea,0xe6110063,0x20290014,0x00000000}},	//   mezé, תִי_, ótið_,
  { {0x63b820ee,0x62980003,0xdb1500ea,0x00000000}},	//   nevn, ouvo, lezé,
  { {0xc1ee0161,0xa2c00042,0x99d701f3,0x00000000}},	//   _जवाब_, विट्, يترا,
  { {0xd378017f,0xee0800d7,0xbd6b005e,0x00000000}},	//   _doći_, _мејл_, _трке_,
  { {0x2e320026,0xf1b90023,0x7c6704a0,0x00000000}},	// [e550] gáfu_, cošu_, _بابل,
  { {0x63b8082a,0x62830072,0xf7700049,0x00000000}},	//   jevn, ysno, نام_,
  { {0xdb15000f,0xd6db69b6,0x35b51e15,0x00000000}},	//   kezé, шта_, збер,
  { {0xdb15000f,0x9f470066,0x64410d17,0x00000000}},	//   jezé, _plnú_, _shli,
  { {0x7bc5002c,0x683000bd,0xdb1500ea,0x00000000}},	//   _kahu, tädt, dezé,
  { {0x7bc5004b,0xdb1c1476,0x69c00014,0x00000000}},	//   _jahu, ldrá, _ómer,
  { {0x7bc569b7,0xdb1c0331,0x4bfc0041,0x00000000}},	//   _mahu, odrá, שלוס,
  { {0xdb1c69b8,0x7bc50019,0x62835718,0x00000000}},	//   ndrá, _lahu, rsno,
  { {0x60090086,0xe0d6000d,0x765c056c,0x00000000}},	//   йним_, звы_, _zury,
  { {0xaf05011c,0x7bc569b9,0x64410061,0x00000000}},	//   зпол, _nahu, _uhli,
  { {0x7bc70838,0xed5a08e5,0x5f75005d,0x00000000}},	//   ddju, йон_, ياگر,
  { {0xd1310032,0xf1b9001c,0x24920078,0x00000000}},	//   _كما_, tošu_, šyme_,
  { {0x62080021,0x7bc53457,0xef18008f,0x00000000}},	//   _بْنِ_, _bahu, raļa_,
  { {0x7bc70137,0xd378007d,0xf1b9008f,0x00000000}},	//   gdju, _poći_, rošu_,
  { {0x7bc50397,0xf1b9008f,0x34b80042,0x00000000}},	//   _dahu, sošu_, _इन्द,
  { {0xfc3f006d,0x786607da,0x7bd7017d,0x00000000}},	//   rtía_, зказ, _enxu,
  { {0x765c00f3,0xfc3f02dd,0x2d8269ba,0x00000000}},	// [e560] _sury, stía_, make_,
  { {0x2d8269bb,0x765c0022,0xdb1c013d,0x00000000}},	//   lake_, _pury, adrá,
  { {0x7c2e0da5,0xdb1e0014,0xf1b93187,0x00000000}},	//   mobr, _kapí, nošs_,
  { {0x2d8202e2,0xfc3f5abe,0x15460002,0x00000000}},	//   nake_, ntín_, пеем,
  { {0xdb1500ea,0x63b80114,0x7bc50fe3,0x00000000}},	//   vezé, tevn, _yahu,
  { {0x69c6024a,0x629800eb,0x765c0051,0x00000000}},	//   _hake, tuvo, _tury,
  { {0x69c61fa9,0xdb1500ea,0xf1b9008f,0x00000000}},	//   _kake, tezé, jošs_,
  { {0x0566005a,0xdb1e01d9,0x60f80062,0x00000000}},	//   _хван, _napí, жния_,
  { {0x69c60625,0xbcfb00ea,0x32f7008b,0x00000000}},	//   _make, gcél, ãy_,
  { {0xe9df008b,0x7c2e0051,0x99800078,0x00000000}},	//   _khúc_, jobr, olių_,
  { {0x7bc50004,0x7c2e1ba3,0x7bc70137,0x00000000}},	//   _rahu, dobr, vdju,
  { {0x38a60024,0x71a6000d,0xdb1e2b2e,0x00000000}},	//   kôr_, _хадз, _capí,
  { {0xdb0e00d1,0xdb1c0026,0x1154000d,0x00000000}},	//   nebæ, ndræ, _ўклю,
  { {0x99800006,0xf1da0053,0x7c2e69bc,0x00000000}},	//   klių_, भावन, gobr,
  { {0x2d820031,0x7bc5004b,0x7bc769bd,0x00000000}},	//   bake_, _vahu, rdju,
  { {0x21f80080,0x7bc700c7,0xa7fb006d,0x00000000}},	//   _mého_, sdju, _muñe,
  { {0x7bc5014f,0xd378007d,0x442e69be,0x00000000}},	// [e570] _tahu, _hoću_, kof_,
  { {0xdb0e00b9,0x60c20035,0xdb1e01d9,0x00000000}},	//   debæ, _msom, _zapí,
  { {0xe9df008b,0x3e610013,0x99890066,0x00000000}},	//   _chúc_, _xót_, elať_,
  { {0xe9df001b,0x36180054,0x2bcb0042,0x00000000}},	//   _giúp_, пцію_, ायवा,
  { {0x8cd00161,0x99800006,0xf1b91333,0x00000000}},	//   दियो, alių_, veš_,
  { {0x69c60122,0x2d82006f,0x442e002b,0x00000000}},	//   _zake, zake_, gof_,
  { {0xea00001b,0xddcd0045,0x60c2006d,0x00000000}},	//   _hoạt_, _miał, _asom,
  { {0x3f9e001c,0x7c2e2fb7,0x644a00ca,0x00000000}},	//   egtu_, zobr, amfi,
  { {0x64a4000a,0x60c200ea,0x3e61604b,0x00000000}},	//   _паѓа, _csom, _sót_,
  { {0xdb1e0016,0x2d820035,0xf1b9001c,0x00000000}},	//   _japã, wake_, tošs_,
  { {0x9f5e00fe,0xea00008b,0xdb1e19bc,0x00000000}},	//   yntö_, _loạt_, _papí,
  { {0xf1b9008f,0x7c2e0ee2,0xa3a90042,0x00000000}},	//   rošs_, wobr, ग्र_,
  { {0xddcd0045,0xfc3f69bf,0x522a0047,0x00000000}},	//   _biał, rtín_, _ווײַ,
  { {0xddcd0051,0xfc3f09b1,0x26d101f4,0x00000000}},	//   _ciał, stín_, _orzo_,
  { {0x69c64b77,0x2d8269c0,0xfaa31499,0x00000000}},	//   _pake, pake_, каро,
  { {0xc9aa000d,0x7c2e69c1,0xe8fa2b4f,0x00000000}},	//   ўвае_, sobr, олб_,
  { {0x61eb69c2,0x2fc718ab,0x69c61161,0x00000000}},	// [e580] _mogl, _kang_, _vake,
  { {0x26d10755,0xe9df008b,0xdce4001c,0x00000000}},	//   _brzo_, _phúc_, _ediģ,
  { {0x69c60706,0x2fc769c3,0x99800006,0x00000000}},	//   _take, _mang_, ulių_,
  { {0x61eb010a,0x2fc769c4,0x24861c40,0x00000000}},	//   _nogl, _lang_, tsom_,
  { {0x2d800004,0x442e2602,0x99800078,0x00000000}},	//   _meie_, tof_, slių_,
  { {0x2fc7099b,0x24861e79,0xe9df001b,0x00000000}},	//   _nang_, rsom_, _thúc_,
  { {0x9989034d,0x61eb0146,0x442e2a80,0x00000000}},	//   slať_, _bogl, rof_,
  { {0x61eb0290,0x2fc769c5,0x442e5254,0x00000000}},	//   _cogl, _aang_, sof_,
  { {0x61eb614f,0x2fc769c6,0xd0d40062,0x00000000}},	//   _dogl, _bang_, хопъ,
  { {0x2fc7008d,0x00000000,0x00000000,0x00000000}},	//   _cang_,   ,   ,
  { {0x61eb4133,0xdb0e00c7,0xbcfb0003,0x00000000}},	//   _fogl, nebä, rcém,
  { {0x61eb0185,0x99890051,0x2fc70123,0x00000000}},	//   _gogl, ział_, _eang_,
  { {0x60c20035,0x2bbb0021,0x9fe60021,0x00000000}},	//   _usom, ياسة_, _يسته,
  { {0x2fc70cc8,0xa08b2177,0x6fb40044,0x00000000}},	//   _gang_, _וְהִ, _أمثا,
  { {0x6602172b,0x62a20114,0x22460013,0x00000000}},	//   khok, _útoč, _khok_,
  { {0x2fc7006f,0x20140051,0x99890051,0x00000000}},	//   _zang_, ścić_, wiał_,
  { {0x2fc7014f,0xe9df008b,0x201e697a,0x00000000}},	// [e590] _yang_, _chúa_, onti_,
  { {0x660200fe,0x1ddd0053,0x201e0014,0x00000000}},	//   ehok, यावत, nnti_,
  { {0x201e024a,0xa3e20053,0xdb0e004d,0x00000000}},	//   inti_, धान_, gebä,
  { {0x99890051,0x66020150,0xff17009a,0x00000000}},	//   siał_, ghok, וקבת_,
  { {0x99890022,0x2e240075,0xc976009a,0x00000000}},	//   piał_, nıfa_, _רגשי_,
  { {0x61eb69c7,0xf3f1008d,0x3cf20042,0x00000000}},	//   _sogl, _bịa_, ुनते_,
  { {0x6b7c014e,0x61eb1bc3,0xa3b80021,0x00000000}},	//   חרונ, _pogl, ظاهر_,
  { {0xdb1c03d9,0x66020035,0x201e69c8,0x00000000}},	//   ferê, chok, enti_,
  { {0x2fc700bb,0x61eb051e,0xfa0d001b,0x00000000}},	//   _pang_, _vogl, _đấu_,
  { {0x2d80454b,0xe3b0007e,0xdb1e013d,0x00000000}},	//   _seie_, _نرم_, _lapá,
  { {0x6da61001,0x61eb69c9,0x2fc769ca,0x00000000}},	//   нина, _togl, _vang_,
  { {0x2fc768dc,0x91fc001c,0x201e69cb,0x00000000}},	//   _wang_, _stāv, anti_,
  { {0xdb0e69cc,0xfc3f004c,0x2d8004aa,0x00000000}},	//   ndbö, atím_, _veie_,
  { {0x2fc700f3,0x3ced0019,0x224d3998,0x00000000}},	//   _uang_, äeva_, lmek_,
  { {0x2d800004,0x3f8569cd,0x8c430062,0x00000000}},	//   _teie_, malu_, уере,
  { {0x3f8506a7,0x224d01f7,0xe1f90006,0x00000000}},	//   lalu_, nmek_, nkų_,
  { {0xdb0500bd,0x63ad017f,0x87ba0076,0x00000000}},	// [e5a0] _abhä, đanj, зует_,
  { {0xfd47093e,0x3f85382b,0x08c30085,0x00000000}},	//   _язык_, nalu_, ыбун,
  { {0x869a005a,0x224d005b,0x7ae10072,0x00000000}},	//   ятат_, kmek_, ältt,
  { {0xf5390024,0x14ca0076,0xdb1c0832,0x00000000}},	//   _byť_, зыки_, rdrä,
  { {0xc9550088,0x201e00fe,0x6e240035,0x00000000}},	//   _атры, ynti_, _mjib,
  { {0xdce60006,0xc049008b,0x2e390014,0x00000000}},	//   sakė, _vườn_, réfi_,
  { {0x53330002,0x3f8558dd,0x85b602d8,0x00000000}},	//   лешт, dalu_, _пљач,
  { {0xdb1c431b,0x68e469ce,0xe297005e,0x00000000}},	//   terê, oxid, хаћ_,
  { {0xdfd0043b,0xbddb0164,0xcfa6005a,0x00000000}},	//   لية_, llèg, ншни,
  { {0x201e0009,0x68e400cd,0xa2e6342a,0x00000000}},	//   unti_, ixid, _позд,
  { {0x3a2000ac,0x6d441a50,0x645a0072,0x00000000}},	//   knip_, _azia, _iiti,
  { {0x645a69cf,0x68f60072,0x628a321d,0x00000000}},	//   _hiti, kyyd, msfo,
  { {0x2c66001f,0x628a02c0,0x3f8569d0,0x00000000}},	//   _côd_, lsfo, balu_,
  { {0x6d440045,0x645a0035,0x6298006f,0x00000000}},	//   _dzia, _jiti, orvo,
  { {0x03d70063,0xe9df0139,0x645a1777,0x00000000}},	//   עולם_, _dhún_, _miti,
  { {0x645a69d1,0x79a70085,0x62982a5a,0x00000000}},	//   _liti, эрге, irvo,
  { {0xb955005a,0xdb1c00cd,0xe8940121,0x00000000}},	// [e5b0] тващ, herè, лать,
  { {0x6e3d1ed3,0x224d005b,0x628a14e3,0x00000000}},	//   llsb, zmek_, ksfo,
  { {0x9f5e006d,0xa7fb006d,0xdb15004d,0x00000000}},	//   litó_, _cuña, ndzü,
  { {0x7afa07e6,0x443c02ab,0x628a060b,0x00000000}},	//   øtte, elv_, dsfo,
  { {0x69dd69d2,0x645a005b,0x628a008d,0x00000000}},	//   _inse, _biti, esfo,
  { {0xdb1c0994,0x645a69d3,0x7415002a,0x00000000}},	//   ferè, _citi, ضوعا,
  { {0x645a003e,0x224d005b,0x9f4d005b,0x00000000}},	//   _diti, tmek_, ünün_,
  { {0xe4e70086,0xe1f90006,0x645a1d43,0x00000000}},	//   _пізн, ukų_, _eiti,
  { {0x224d01f7,0x8f99005a,0x62980466,0x00000000}},	//   rmek_, мънт_, arvo,
  { {0x2455006a,0x78ad4711,0xe1f90078,0x00000000}},	//   _شناس, itav, skų_,
  { {0x248d02ab,0x78ad003a,0x69dd69d4,0x00000000}},	//   _hvem_, htav, _onse,
  { {0xc115018e,0x645a00bd,0x3f85004b,0x00000000}},	//   _имеј, _ziti, salu_,
  { {0xf65200b5,0x6448024a,0x645a0058,0x00000000}},	//   יצט_, _yhdi, _yiti,
  { {0x69dd69d5,0xf99f00cd,0x61fb69d6,0x00000000}},	//   _anse, _omès_, lkul,
  { {0xbddb01a8,0x3e86004c,0x61e90072,0x00000000}},	//   tmèt, _vítá_, ojel,
  { {0x61e969d7,0x3eaa01c2,0x248d00c2,0x00000000}},	//   njel, žití_, _ovem_,
  { {0x753b0035,0x9f5e2c5d,0x61fb69d8,0x00000000}},	// [e5c0] _nyuz, citó_, ikul,
  { {0x4803000a,0x61e969d9,0x69cd001f,0x00000000}},	//   апув, hjel, adae,
  { {0x61e90031,0x248d000c,0x645a69da,0x00000000}},	//   kjel, _avem_, _riti,
  { {0x645a048e,0xa2d50161,0xceb20063,0x00000000}},	//   _siti, भिन्, שיא_,
  { {0x08360088,0x61e90117,0xdb050164,0x00000000}},	//   _ахвя, djel, _achè,
  { {0xdb1c0268,0x61e9000f,0xdb1e0268,0x00000000}},	//   terè, ejel, _capç,
  { {0xdb1c006d,0x61e90093,0x6298006f,0x00000000}},	//   feré, fjel, urvo,
  { {0x61e903e8,0x442500b9,0x61fb4735,0x00000000}},	//   gjel, _ejl_, gkul,
  { {0x91fc001c,0x645a69db,0x9f5e01f4,0x00000000}},	//   _stās, _titi, ditò_,
  { {0x645a006f,0x9f5e006d,0x61e93d38,0x00000000}},	//   _uiti, vitó_, ajel,
  { {0xfc3f0066,0xdb1c013d,0xdfd0005d,0x00000000}},	//   stík_, beré, ليک_,
  { {0xe9df0139,0x20050066,0xad9b0139,0x00000000}},	//   _chúl_, ahli_, chúl,
  { {0xa3e60053,0x6e3d63d1,0x21670320,0x00000000}},	//   _बचा_, rlsb, _ричи_,
  { {0x3ed40021,0xac240152,0x614302b3,0x00000000}},	//   _مقتر, афск, _теча,
  { {0x9f5e006d,0xdb1e0066,0xaf33007e,0x00000000}},	//   sitó_, _napä, _پروت,
  { {0x78ad69dc,0x0f570063,0x8f450086,0x00000000}},	//   ttav, _ביום_, _схід,
  { {0xc984006e,0x69dd004d,0x57b5193d,0x00000000}},	// [e5d0] руси, _vnse, лбат,
  { {0x673c0627,0xdb1c013d,0x78ad69dd,0x00000000}},	//   _byrj, zeré, rtav,
  { {0xa3d60235,0xd8380088,0xcf9300b5,0x00000000}},	//   ियन_, тэт_, שטע_,
  { {0x78ad007a,0x69dd04da,0xa3b00053,0x00000000}},	//   ptav, _unse, ट्स_,
  { {0xe9df0024,0x61e9017f,0x98e40062,0x00000000}},	//   _inú_, vjel, _кюрд,
  { {0xdb0511f5,0xee3f0260,0x80d60042,0x00000000}},	//   _aché, hlý_, बिने,
  { {0xfbb8014e,0x3f830026,0xdb1c69de,0x00000000}},	//   דפות_, ðjum_, teré,
  { {0x7ae8004d,0x61fb69df,0x00c90142,0x00000000}},	//   ädti, ukul, елик_,
  { {0x7a0c003b,0x61e969e0,0x9f5e01f4,0x00000000}},	//   oştr, rjel, vitò_,
  { {0x2489003d,0xa7fb0118,0xdb050003,0x00000000}},	//   šams_, _muño, _tchè,
  { {0x61e9017f,0x7c355ab1,0x61fb69e1,0x00000000}},	//   pjel, dozr, pkul,
  { {0xf3f1001b,0x2d84017d,0xfbc90063,0x00000000}},	//   _họ_, úme_, _מת_,
  { {0x3e680164,0xed570156,0x6fd50054,0x00000000}},	//   _eût_, лою_, _бійц,
  { {0x3e680164,0x75160047,0x40920021,0x00000000}},	//   _fût_, אַלע_, _الور,
  { {0x9f5e0290,0xbddb0003,0xab272279,0x00000000}},	//   pitò_, rmèr, гора_,
  { {0x316d67d8,0x38cb005d,0x8a430044,0x00000000}},	//   ncez_, کافی_, مَّن,
  { {0x48e3005a,0x673c0072,0xa3d60053,0x00000000}},	// [e5e0] ботв, _syrj, ियम_,
  { {0x7bde00e5,0xe9df0331,0xdb070046,0x00000000}},	//   _unpu, _enú_, sfjá,
  { {0x9f45011b,0x00000000,0x00000000,0x00000000}},	//   yklý_,   ,   ,
  { {0x09e62758,0x94aa58c7,0x1f360047,0x00000000}},	//   _сомн, етка_, ארער_,
  { {0x4e3700b5,0xdb1c05b9,0x64b300de,0x00000000}},	//   אָגן_, edrø, محور,
  { {0x798600ca,0xf3f1008d,0xdb0559d3,0x00000000}},	//   _hekw, _cọ_, _sché,
  { {0x79860089,0xd3790054,0xd25a202f,0x00000000}},	//   _kekw, тчі_, нци_,
  { {0x66190051,0x98a70051,0xe7371948,0x00000000}},	//   ciwk, łną_, _сес_,
  { {0xbfaa019b,0x4a5b0063,0x3e68006c,0x00000000}},	//   нтне_, עדפו, _sût_,
  { {0x3e680003,0x5f940141,0xdfd0005d,0x00000000}},	//   _pût_, јинт, آيد_,
  { {0x7986006f,0xdb050003,0x6d40005b,0x00000000}},	//   _oekw, _tché, üman,
  { {0xa3b00161,0x21670001,0x9f474e86,0x00000000}},	//   ट्र_, _бици_, _donà_,
  { {0xbddb01a8,0x3a3900ca,0xd01a0094,0x00000000}},	//   elèc, _rksp_, _пфк_,
  { {0xee3f0061,0xe9df0046,0x3a750094,0x00000000}},	//   slý_, _snú_, илгр,
  { {0x3ffb00b5,0x79860983,0xfc3f14ab,0x00000000}},	//   _אפגע, _bekw, ktív_,
  { {0xb9250021,0xa7fb0331,0xfe780078,0x00000000}},	//   لفزي, _puño, mpį_,
  { {0xb8150001,0x27f10260,0x4815046e,0x00000000}},	// [e5f0] адај, _pozn_, амас,
  { {0x7b150121,0x64460078,0xf795000d,0x00000000}},	//   _вдох, _ūkin, ражэ,
  { {0xf77004f6,0x9f4701c8,0x2575005d,0x00000000}},	//   سال_, _koná_, لهاس,
  { {0x79860179,0x2d8b69e2,0x8f370047,0x00000000}},	//   _gekw, nace_, נטאג_,
  { {0x26d803d9,0xa2bd0053,0xb5c20086,0x00000000}},	//   _erro_, _वैज्, ійшл,
  { {0x69cf048e,0x38af0058,0xfc3f28be,0x00000000}},	//   _hace, mür_, atív_,
  { {0x2d8b02f4,0x38af005b,0x2bf80063,0x00000000}},	//   kace_, lür_, רמון_,
  { {0x0165000a,0xc2450259,0xdb0e05e7,0x00000000}},	//   шкио, јник, rebø,
  { {0x38af005b,0x316d3d50,0x2d8b69e3,0x00000000}},	//   nür_, rcez_, dace_,
  { {0x69cf52f9,0x2d8b3623,0x41a70042,0x00000000}},	//   _lace, eace_, _गावस,
  { {0xa3e20053,0xee260a29,0x5de60789,0x00000000}},	//   धार_, имоп, ажна,
  { {0x2d8b0080,0x2480000c,0x69cf69e4,0x00000000}},	//   gace_, ţime_, _nace,
  { {0xef18003d,0x8c46005a,0x7986056c,0x00000000}},	//   daļu_, иеме, _rekw,
  { {0xef67005a,0x38af005b,0xab2a0349,0x00000000}},	//   _съдо, dür_, вога_,
  { {0x25a6001f,0x78bd2b27,0x8a160002,0x00000000}},	//   ygol_, _apsv, аќач,
  { {0x38af00bd,0x2d8b69e5,0x69cf2737,0x00000000}},	//   für_, cace_, _cace,
  { {0x77860001,0x38c8007e,0xdb1c69e6,0x00000000}},	// [e600] илаз, دازی_, merí,
  { {0xdb1c258a,0xb8ee0042,0x8b96354e,0x00000000}},	//   lerí, _शन_, _трич,
  { {0xa3e90161,0x69cf1e27,0x056669e7,0x00000000}},	//   यान_, _face, авен,
  { {0xe61a005a,0xdb1c006d,0x69cf69e8,0x00000000}},	//   ъде_, nerí, _gace,
  { {0x656400c2,0x8cd90053,0x69c4251d,0x00000000}},	//   žiho, मियो, meie,
  { {0x2d8b02f4,0x25a60185,0xdb1c001f,0x00000000}},	//   zace_, sgol_, merâ,
  { {0x03a30001,0x4420017f,0xdb1c29c7,0x00000000}},	//   цијо, đi_, lerâ,
  { {0xdb1c006d,0xe5a30336,0x1a9b0047,0x00000000}},	//   jerí, _миси, דיקע,
  { {0x2d8b549e,0xdb1c3ba5,0x03a60d0a,0x00000000}},	//   vace_, derí, _визо,
  { {0x6abe076c,0x250b007e,0xf8b30063,0x00000000}},	//   _oppf, _شرقی_, קשת_,
  { {0x2d8b0080,0x3f87001f,0xdb1c0e7c,0x00000000}},	//   tace_, _denu_, ferí,
  { {0xfe780006,0xdb1c006d,0xf1a9005d,0x00000000}},	//   rpį_, gerí, _ماهه_,
  { {0x61e202f6,0xfd470088,0x61430189,0x00000000}},	//   _inol, рэнн, _деца,
  { {0x69cf69e9,0x2d8b1eb2,0xdb1c1653,0x00000000}},	//   _sace, sace_, derâ,
  { {0x6e940032,0xdb1c67d2,0x5e940021,0x00000000}},	//   _البا, berí, _البط,
  { {0xdb1c69ea,0x38af0b91,0x1f5b0063,0x00000000}},	//   cerí, tür_, _בדוא,
  { {0xa3d60235,0x78a40290,0x478b03d6,0x00000000}},	// [e610] िया_, guiv, всем_,
  { {0x38af005b,0xb5fd007d,0xad9b0139,0x00000000}},	//   rür_, _miše, dhúi,
  { {0x69cf69eb,0x61e2007d,0xf1b9007d,0x00000000}},	//   _tace, _onol, liše_,
  { {0x249d001f,0xd6d808a2,0x78a401f4,0x00000000}},	//   trwm_, шту_, buiv,
  { {0xf1b9017f,0xd9440699,0x3f8c69ec,0x00000000}},	//   niše_, _меџи, kadu_,
  { {0x66fc001c,0x3f8c007d,0x61e200f1,0x00000000}},	//   _sākš, jadu_, _anol,
  { {0x7642005b,0x569417e6,0xdb1c0331,0x00000000}},	//   bloy, _март, yerí,
  { {0x16340376,0xdb1e0331,0x0085182b,0x00000000}},	//   _деся, _papú, блио,
  { {0x03c70076,0x66fc008f,0x3f8c002b,0x00000000}},	//   _всем, _vākš, fadu_,
  { {0x63ad017f,0x61e21232,0xf1b9007d,0x00000000}},	//   đans, _enol, diše_,
  { {0xdb1c42d4,0x3f870164,0x78a400ca,0x00000000}},	//   terí, _venu_, zuiv,
  { {0x644301e3,0xa3cf016a,0x2d9e00bd,0x00000000}},	//   llni, षयक_, ßte_,
  { {0xa3ae0161,0x3f870164,0x69c469ed,0x00000000}},	//   _काम_, _tenu_, veie,
  { {0x2d9e5a5c,0xdb1c1919,0x69c42670,0x00000000}},	//   şte_, serí, weie,
  { {0xdb1c0016,0x69c400bd,0x442769ee,0x00000000}},	//   derã, teie, inn_,
  { {0x89661499,0xbcfb0003,0xc3320a7a,0x00000000}},	//   скаж, rcér, פון_,
  { {0xc044008b,0x69c469ef,0xdb1c004d,0x00000000}},	// [e620] _đoạt_, reie, ldrü,
  { {0x25ad000c,0x69c469f0,0x6443007d,0x00000000}},	//   _acel_, seie, jlni,
  { {0x3ea55ac6,0x6abe69f1,0xdb1c004d,0x00000000}},	//   nult_, _uppf, ndrü,
  { {0x442700bd,0xad9b0025,0x644369f2,0x00000000}},	//   enn_, thúi, elni,
  { {0x78a403d9,0xdb1c1997,0x04460f55,0x00000000}},	//   quiv, berã, бедн,
  { {0x3ea55ac6,0x6aa1007a,0xdb1c0016,0x00000000}},	//   kult_, álfg, cerã,
  { {0x3ea502ab,0xd25000b3,0x764204bc,0x00000000}},	//   jult_, ونت_, ploy,
  { {0x90980076,0xb5fd082a,0xa07403d6,0x00000000}},	//   авит_, _piše, огич,
  { {0xa0670092,0xdb1c0022,0xc05a071f,0x00000000}},	//   бања_, odró, ліо_,
  { {0xf1b9017f,0xb5fd017f,0x66021715,0x00000000}},	//   više_, _više, lkok,
  { {0x50d6006a,0x28cf0161,0xdc190051,0x00000000}},	//   _گزار, _सैनि, _głęb,
  { {0xf1b9007d,0xb66202fe,0x660269f3,0x00000000}},	//   tiše_, омiк, nkok,
  { {0x7c29006c,0xdddb2401,0x3f8c69f4,0x00000000}},	//   éero, lptū, padu_,
  { {0xf1b9074f,0x798d00a4,0x7bd800ed,0x00000000}},	//   riše_, waaw, _óvul,
  { {0xa3e90235,0x3ea50034,0xfc3f006d,0x00000000}},	//   यात_, cult_, guía_,
  { {0xf1b9082a,0x201e69f5,0xddc40051,0x00000000}},	//   piše_, liti_, _chiń,
  { {0x443e69f6,0xe66f0014,0x66020891,0x00000000}},	// [e630] _okt_, ðaþý, dkok,
  { {0x201e69f7,0x5f780063,0xfc3f19f1,0x00000000}},	//   niti_, שָּׂ, rtís_,
  { {0xb87b0876,0xd6db014c,0xfc3f01a8,0x00000000}},	//   _oríg, ыта_, stís_,
  { {0xa9c7007e,0x7bd5004d,0x66024d97,0x00000000}},	//   _ازدو, ldzu, gkok,
  { {0x7ae0001c,0xd49b0184,0x201e0ebe,0x00000000}},	//   āmte, уре_, kiti_,
  { {0x8707000d,0xc7c70905,0x3a2900ea,0x00000000}},	//   _лябе, _усми, lnap_,
  { {0xdb070019,0x201e69f8,0x443e0150,0x00000000}},	//   pejõ, diti_, _dkt_,
  { {0x201e0dff,0x1dd90042,0x5095005e,0x00000000}},	//   eiti_, _बोलत, орођ,
  { {0x201e0009,0x7bc70089,0x600400cd,0x00000000}},	//   fiti_, keju, _còmo,
  { {0x3ea51212,0x66090026,0x201e69f9,0x00000000}},	//   tult_, _hlek, giti_,
  { {0x3a2900b9,0xb87b0fb8,0xa3d60042,0x00000000}},	//   knap_, _fríg, ियर_,
  { {0xb87b0024,0xdb1c00bd,0xed5a0336,0x00000000}},	//   _kríd, rdrü, ион_,
  { {0xdb1c69fa,0x201e69fb,0x3ea569fc,0x00000000}},	//   sdrü, biti_, sult_,
  { {0xbddb0164,0xdb1c00cd,0x201e69fd,0x00000000}},	//   llèl, terà, citi_,
  { {0x66090004,0x8c431b8b,0xdb1c00ea,0x00000000}},	//   _olek, фере, ferá,
  { {0x4a46000d,0x3a29013d,0xf2d2089e,0x00000000}},	//   інав, gnap_, ועל_,
  { {0x2bb20053,0x7afa00a5,0xeb9a0129,0x00000000}},	// [e640] _जापा, ättb, _кип_,
  { {0x7f8c0047,0x39420078,0xdb1c01a8,0x00000000}},	//   ָנאַ, _vyks_, perà,
  { {0xfc3f006d,0x660200fe,0xdb1c69fe,0x00000000}},	//   quía_, tkok, berá,
  { {0xdb1c02dd,0x201e01b3,0x7c3c05ab,0x00000000}},	//   cerá, ziti_, lorr,
  { {0xf53f0205,0x443e0022,0x7c3c00ca,0x00000000}},	//   _øål_, _pkt_, oorr,
  { {0x38b40502,0x660969ff,0x290004aa,0x00000000}},	//   mär_, _elek, myia_,
  { {0x38b40502,0x6609022f,0x201e6a00,0x00000000}},	//   lär_, _flek, viti_,
  { {0x7e640019,0xa186000d,0x11ea0021,0x00000000}},	//   _niip, цыкл, شعبي_,
  { {0x201e055e,0x60f70088,0x29006a01,0x00000000}},	//   titi_, жныя_, nyia_,
  { {0xdb1c0512,0x6e2d0122,0xdfd00593,0x00000000}},	//   zerá, _sjab, ريج_,
  { {0x443c14d5,0xf7730063,0x201e6a02,0x00000000}},	//   mov_, וקת_, riti_,
  { {0x78b600eb,0x200c0089,0x443c6a03,0x00000000}},	//   ktyv, shdi_, lov_,
  { {0x98b3001c,0xdb1c029c,0x61f30066,0x00000000}},	//   ādīs_, verá, želá,
  { {0x443c6a04,0x7c3c6a05,0xc046002a,0x00000000}},	//   nov_, gorr, _بخصو,
  { {0x298b0001,0x7bd531aa,0xf1b9007d,0x00000000}},	//   исао_, rdzu, liša_,
  { {0x38b400c7,0x443c6a06,0x7bc76a07,0x00000000}},	//   fär_, hov_, seju,
  { {0x7c3c0994,0x27f80034,0x38b400c7,0x00000000}},	// [e650] borr, _born_, gär_,
  { {0x443c0024,0x69d6002c,0x66096a08,0x00000000}},	//   jov_, adye, _slek,
  { {0x3c3b0080,0x6609166f,0xa3ae0053,0x00000000}},	//   rávě_, _plek, कलन_,
  { {0x38b400c7,0xb87b0024,0x60c208ea,0x00000000}},	//   bär_, _príd, _opom,
  { {0xd1260021,0x600d006d,0x27f84a1e,0x00000000}},	//   _أم_, _húme, _forn_,
  { {0x443c11d7,0x97c70021,0x78fa009a,0x00000000}},	//   gov_, _بتحم, _הפשו,
  { {0xa3bc0053,0xad9b0014,0xe62b005e,0x00000000}},	//   ेज़_, nhús, _кôд_,
  { {0xddc4000c,0x7ae10072,0x27f8254c,0x00000000}},	//   _munţ, älty, _zorn_,
  { {0x7e6400fe,0x443c6a09,0xd24e00f2,0x00000000}},	//   _riip, bov_, دني_,
  { {0x443c329b,0x60090184,0x7e640072,0x00000000}},	//   cov_, сном_, _siip,
  { {0x26150024,0xdb1c00cd,0x600d0b16,0x00000000}},	//   sťou_, merç, _núme,
  { {0xbddb03b2,0xd12e006a,0x78b600fe,0x00000000}},	//   blèm, ئمی_, ytyv,
  { {0xeb040053,0x7e646a0a,0x7c3c6a0b,0x00000000}},	//   रन्त_, _viip, torr,
  { {0x60db00ac,0x38b40137,0xc104007e,0x00000000}},	//   mvum, vär_, _توهي,
  { {0x09e6019d,0x63bc01f7,0x60c20080,0x00000000}},	//   повн, _örne, _zpom,
  { {0x78b6024a,0x443c14d5,0xe9da0001,0x00000000}},	//   ttyv, zov_, љка_,
  { {0x7c3c2929,0x64416a0c,0x27f86a0d,0x00000000}},	// [e660] porr, _okli, _porn_,
  { {0x64416a0e,0x78b60072,0x3a20004b,0x00000000}},	//   _nkli, rtyv, siip_,
  { {0x443c0dec,0xe9df008b,0x78b600fe,0x00000000}},	//   vov_, _phút_, styv,
  { {0x27f80034,0x61f96a0f,0xf8660062,0x00000000}},	//   _worn_, _nowl, _нвмо,
  { {0x443c6a10,0xd4e30076,0x6f01002b,0x00000000}},	//   tov_, еющи, hylc,
  { {0x74690086,0xa7fb0331,0x6458584a,0x00000000}},	//   ірів_, _buñu, umvi,
  { {0x05bb0053,0x443c280a,0x60c2064f,0x00000000}},	//   ोजशब, rov_, _spom,
  { {0x443c14d5,0xb5fd00c2,0x20056a11,0x00000000}},	//   sov_, _hišn, ekli_,
  { {0x443c14d5,0xb5fd007d,0xa0670092,0x00000000}},	//   pov_, _kišn, пања_,
  { {0xdb1e02dd,0xdcef001c,0x24520003,0x00000000}},	//   _japó, sacī, fâme_,
  { {0x6f010185,0xa3e90053,0x6288006f,0x00000000}},	//   gylc, यार_, _uwdo,
  { {0x4c950121,0x3f830014,0x64413187,0x00000000}},	//   мимс, ðjur_, _zkli,
  { {0x6e3d00ea,0x78a400ca,0xc05a0085,0x00000000}},	//   rosb, jriv, _лік_,
  { {0x3ce043eb,0x78a412f5,0x515b0063,0x00000000}},	//   _driv_, driv, _הכדו,
  { {0x6e3d00ac,0x7659001f,0x78a46a12,0x00000000}},	//   posb, ymwy, eriv,
  { {0x7afa00c7,0x25a00025,0x78a46a13,0x00000000}},	//   ätta, óill_, friv,
  { {0xb87b0025,0x394f0137,0x69340f0a,0x00000000}},	// [e670] _sríb, ågs_, енту,
  { {0xb87b0024,0x6d41005b,0x3947001c,0x00000000}},	//   _príb, ğlad, āns_,
  { {0x59f9005a,0x6d41005b,0xdb1c00bd,0x00000000}},	//   _деня_, şlad, gerä,
  { {0x60db00eb,0x64416a14,0xab280699,0x00000000}},	//   yvum, _skli, _хоџа_,
  { {0x99f60063,0x7659001f,0x61f96a15,0x00000000}},	//   _חזרה_, rmwy, _rowl,
  { {0x03a50001,0xb4ad0053,0xdb1c0137,0x00000000}},	//   фико, _कमी_, berä,
  { {0x626300ea,0xa3ae0053,0x52b20021,0x00000000}},	//   _főol, _कार_, نموذ,
  { {0xdb1c017d,0x35d40076,0x35f5000d,0x00000000}},	//   serç, _посё, _ўпар,
  { {0x9f5e0025,0xdb1c0003,0xceb83164,0x00000000}},	//   chtú_, perç, etę_,
  { {0x20190021,0x9f4e00ed,0x20050078,0x00000000}},	//   تتبع_, _sofá_, ukli_,
  { {0x60c4001c,0xada62e2f,0x60db004b,0x00000000}},	//   _ģime, манл, svum,
  { {0x20056a16,0x9f64004c,0x333a009d,0x00000000}},	//   skli_, ítám_, _ותעמ,
  { {0x6ff50021,0xdb0e0137,0xceb80022,0x00000000}},	//   _يستط, nebö, atę_,
  { {0xdff50054,0x515a009d,0x00000000,0x00000000}},	//   _іяль, _וכנו,   ,
  { {0x3f85000c,0xbb430098,0x798f00a3,0x00000000}},	//   mblu_, верк, _becw,
  { {0x78a40529,0xa3e90161,0xc332014e,0x00000000}},	//   triv, याँ_, דול_,
  { {0x7c95000d,0x78a4004b,0xa3ae0053,0x00000000}},	// [e680] _прэц, uriv, _काल_,
  { {0x07a30055,0x1c430121,0x78a46a17,0x00000000}},	//   каун, _иным, rriv,
  { {0xf986000a,0x78a401b2,0xb87b0066,0x00000000}},	//   _огно, sriv, _príc,
  { {0xeef60047,0x68e9004c,0x78a46a18,0x00000000}},	//   ומער_, _šede, priv,
  { {0xa3e90053,0xceb80022,0xd78a0044,0x00000000}},	//   यां_, ztę_, _ونحو_,
  { {0xdb1c024a,0xcc3b0047,0xceb822b4,0x00000000}},	//   perä, ֿעקט, ytę_,
  { {0x3f8e0035,0xb87b6a19,0x07a300e1,0x00000000}},	//   _refu_, _tríc, _јасн,
  { {0xfc3f006d,0x7c2e004d,0x60f80062,0x00000000}},	//   iría_, hnbr, зния_,
  { {0xb5fd074f,0xfa1c0013,0x96550062,0x00000000}},	//   _mišl, _đất_, _чърч,
  { {0xf9570063,0x33f6000d,0x34fb0063,0x00000000}},	//   וספת_, _ўчас, _והמד,
  { {0xad9b0066,0xe2970e74,0x80d30042,0x00000000}},	//   skúm, _жах_, _बैठे,
  { {0xfc3f048e,0xceb81265,0x7c2e00ca,0x00000000}},	//   dría_, rtę_, enbr,
  { {0x7afa01e3,0xfc3f006d,0xceb81748,0x00000000}},	//   ättn, ería_, stę_,
  { {0xce94005a,0xfc3f006d,0x2f180121,0x00000000}},	//   _закъ, fría_, _ноль_,
  { {0x62984241,0xfc3f006d,0xaa590001,0x00000000}},	//   nsvo, gría_, зиву_,
  { {0x7c2e0229,0x992b0121,0x629800ca,0x00000000}},	//   anbr, оюза_, isvo,
  { {0xa3ae0235,0xdb0500bd,0xfc3f006d,0x00000000}},	// [e690] कला_, _schä, aría_,
  { {0xfc3f02dd,0x644a0146,0x3eac006f,0x00000000}},	//   bría_, jlfi, oudt_,
  { {0x23d90161,0x600400cd,0x1995000d,0x00000000}},	//   _योगद, _còmi, _паня,
  { {0x78a22f42,0x49740062,0x62980872,0x00000000}},	//   šova, _илюс, dsvo,
  { {0x629a0198,0x09e4000d,0x43750086,0x00000000}},	//   _avto, _роўн, нуйт,
  { {0xdb1c6a1a,0xb4640086,0x3eac01e1,0x00000000}},	//   rdrö, вкіл, kudt_,
  { {0x4429017f,0x78ad00fe,0x62986a1b,0x00000000}},	//   đa_, luav, gsvo,
  { {0xa4d50054,0x64460078,0x69cd004b,0x00000000}},	//   _побі, _ūkit, neae,
  { {0x9f470025,0x84350086,0xb246007e,0x00000000}},	//   _inné_, _знає, ریهٔ_,
  { {0x69cd0019,0x764b002b,0x629801e1,0x00000000}},	//   heae, llgy, bsvo,
  { {0x99800024,0x2c740137,0xdb15004d,0x00000000}},	//   lniť_, _säd_, gezü,
  { {0x6619005b,0x200e6a1c,0x78ad004b,0x00000000}},	//   _çakı, _elfi_, kuav,
  { {0x61eb03e1,0x764b002b,0x69cd004b,0x00000000}},	//   _ingl, ilgy, deae,
  { {0xfc3f006d,0x6b9500ea,0x9f5c017d,0x00000000}},	//   tría_, gazg, _movê_,
  { {0xca560001,0xde88005d,0x7c2e5320,0x00000000}},	//   етањ, _قضيه_, rnbr,
  { {0xfc3f006d,0x69cd0019,0x76580078,0x00000000}},	//   rría_, geae, įvyk,
  { {0x99800024,0x656d0066,0x3f81004b,0x00000000}},	// [e6a0] jniť_, ľahl, _õhus_,
  { {0x7d06024a,0x99800066,0xe73a0416,0x00000000}},	//   myks, dniť_, пез_,
  { {0x39ea071a,0x61eb56b1,0xa3e90053,0x00000000}},	//   _едно_, _ongl, याई_,
  { {0x186a0499,0xceb2009f,0x7bce1538,0x00000000}},	//   _нами_, ריא_, lebu,
  { {0x7bdc0b59,0xb87b3473,0xa5070062,0x00000000}},	//   odru, _tría, неца_,
  { {0x7bdc00eb,0x6e2602b0,0x99890051,0x00000000}},	//   ndru, hikb, chał_,
  { {0x53340076,0x7d0600fe,0x6e2600ac,0x00000000}},	//   ъект, hyks, kikb,
  { {0x7bce00bd,0x20bd0053,0x629805e9,0x00000000}},	//   hebu, ्बंध, rsvo,
  { {0x7bce47c0,0xe3b2007e,0x7bdc00ca,0x00000000}},	//   kebu, _مرا_, kdru,
  { {0x61eb31e2,0xd91b016e,0x7d060050,0x00000000}},	//   _engl, פויל, dyks,
  { {0x60c7003b,0x6e261034,0x7bce6a1d,0x00000000}},	//   ăjma, fikb, debu,
  { {0x3eac00b9,0xfc3f18fb,0x7bdc50ab,0x00000000}},	//   rudt_, grín_, edru,
  { {0xdb1c0024,0x7bdc0b94,0x5c74030b,0x00000000}},	//   zdrô, fdru, ллят,
  { {0x7bce00bd,0x41530085,0x7b6701ce,0x00000000}},	//   gebu, _свіс, етбе,
  { {0xc9870001,0x99800024,0x6b956a1e,0x00000000}},	//   еузи, zniť_, razg,
  { {0x7bdc6a1f,0x78ad0858,0x7bce004b,0x00000000}},	//   adru, tuav, aebu,
  { {0x9c39005a,0x97a70086,0x7bce0006,0x00000000}},	// [e6b0] _опит_, ерел, bebu,
  { {0x7bce0f16,0xc02e0013,0xdb07013d,0x00000000}},	//   cebu, _điệu_, agjá,
  { {0xcf9300b5,0x2d920035,0x224600ea,0x00000000}},	//   רטע_, _yeye_, _okok_,
  { {0x99800024,0xa647007e,0xdb070014,0x00000000}},	//   tniť_, رخان, sfjó,
  { {0x78ad01f4,0x33d50054,0x00000000,0x00000000}},	//   quav, війт,   ,
  { {0x99800024,0xb5fd0078,0x24180085,0x00000000}},	//   rniť_, _kišk, ночы_,
  { {0x99800066,0x6283004c,0x52a90054,0x00000000}},	//   sniť_, upno, євим_,
  { {0x99800024,0x7bce0051,0x7c270089,0x00000000}},	//   pniť_, zebu, hijr,
  { {0x2721016a,0x7bce017e,0x682b0022,0x00000000}},	//   _मधुर_, yebu, ażde,
  { {0xa2a90053,0x7d060006,0x95540021,0x00000000}},	//   _टिप्, vyks, _إخفا,
  { {0x44276a20,0xc2c403eb,0xdcfd001c,0x00000000}},	//   min_, _ميلي, kasē,
  { {0x7d06024a,0x61eb6a21,0x628108f2,0x00000000}},	//   tyks, _ungl, _itlo,
  { {0x64430004,0xed57019d,0x51840088,0x00000000}},	//   ooni, кою_, _суха,
  { {0x64436a22,0x44276a23,0xb87b6a24,0x00000000}},	//   noni, nin_, _prín,
  { {0xb5fd00c3,0x7d0600fe,0xae1f0053,0x00000000}},	//   _višj, syks, मोहन_,
  { {0x44276a25,0x7bce0397,0x7bdc00bd,0x00000000}},	//   hin_, sebu, sdru,
  { {0x87ba0121,0xc9660062,0x6e2400ac,0x00000000}},	// [e6c0] дует_, твай, _imib,
  { {0xb87b6a26,0x6b68013d,0x44274569,0x00000000}},	//   _trín, _cégü, jin_,
  { {0xb87b006d,0x64436a27,0x44276a28,0x00000000}},	//   _frío, doni, din_,
  { {0x225f0089,0x44276a29,0xb87b0139,0x00000000}},	//   jmuk_, ein_, _grío,
  { {0xcd770047,0x44276a2a,0x64434746,0x00000000}},	//   דענק_, fin_, foni,
  { {0x9d1b014e,0xe1f90006,0x2a600019,0x00000000}},	//   וונט, ejų_, lmib_,
  { {0xd25a058f,0xd7f90085,0xb4170044,0x00000000}},	//   мци_, _чуў_, ضغوط_,
  { {0x44276a2b,0xc4c60044,0x75d60044,0x00000000}},	//   ain_, _لتطو, _جيرا,
  { {0xdfd00032,0xe3ba12ad,0x64436a2c,0x00000000}},	//   مية_, _оба_, boni,
  { {0xbddb0003,0x44276a2d,0x6e24013d,0x00000000}},	//   hlèt, cin_, _amib,
  { {0xdef70088,0x6448003d,0x645a01f7,0x00000000}},	//   выя_, _ikdi, _ihti,
  { {0xa2060002,0xd378007d,0x600401a8,0x00000000}},	//   _шпед, _daće_, _ròmu,
  { {0xf1b30063,0x624501a8,0x1e340085,0x00000000}},	//   _כסף_, póor, рняў,
  { {0xb5fd00c3,0x69c6004d,0x2bc80002,0x00000000}},	//   _pišk, _abke, кусо_,
  { {0xb87b0027,0xdb2301f7,0xbddb0003,0x00000000}},	//   _prío, _ürün, flèt,
  { {0x442701f7,0x9f5c016b,0xb5fd0734,0x00000000}},	//   zin_, _nové_, _višk,
  { {0x44274067,0x99555c3b,0xb955005a,0x00000000}},	// [e6d0] yin_, укац, уващ,
  { {0x44276a2e,0x2d990f2c,0x1b4b0021,0x00000000}},	//   xin_, lase_, _يؤدي_,
  { {0x6b6800ea,0xb87b0025,0x2d99003b,0x00000000}},	//   _végü, _trío, oase_,
  { {0x44276a2f,0x645a6a30,0xe3b80058,0x00000000}},	//   win_, _ahti, _acı_,
  { {0x2bc00053,0xd49b005e,0x44276a31,0x00000000}},	//   श्वा, фре_, tin_,
  { {0x44270f3b,0xbddb00cd,0xb5fd6a32,0x00000000}},	//   uin_, olès, _miši,
  { {0x44276a33,0x64436a34,0x2d996a35,0x00000000}},	//   rin_, roni, kase_,
  { {0x4427507d,0x64436a36,0x645a01cf,0x00000000}},	//   sin_, soni, _ehti,
  { {0xa5350076,0x7bc8004b,0x44276a37,0x00000000}},	//   _снач, õduk, pin_,
  { {0xbf0e0053,0x224d37ff,0x69dd6a38,0x00000000}},	//   ानून_, slek_, _lase,
  { {0x224d00e8,0x765b001b,0xa3470088,0x00000000}},	//   plek_, _khuy, _рэал,
  { {0x6d4101f7,0xb87b0024,0x69dd6a39,0x00000000}},	//   ğlan, _príl, _nase,
  { {0x6d4101f7,0x645a00fe,0x249d001f,0x00000000}},	//   şlan, _yhti, nswm_,
  { {0x9ad60088,0xb87b006d,0x9f4701f4,0x00000000}},	//   любі, _crím, _donò_,
  { {0x2d996a3a,0x9980003b,0xea5a0002,0x00000000}},	//   base_, ghiş_, ерај_,
  { {0xceb2014e,0x7e6d051e,0x61fb007a,0x00000000}},	//   _היה_, _giap, njul,
  { {0x69dd0a67,0x62220041,0xfce60fc3,0x00000000}},	// [e6e0] _dase, גנאָר, _сопо,
  { {0x93bc000c,0x9d1b0047,0xd7f90054,0x00000000}},	//   _amăn, _נויט, кує_,
  { {0x2ca000b9,0x55e60794,0x07b70021,0x00000000}},	//   _hvid_, ложб, اهمة_,
  { {0x765b00aa,0x4425001f,0xbddb0003,0x00000000}},	//   _chuy, _aml_, llèr,
  { {0x98a7003b,0x320d04fa,0x7bc30075,0x00000000}},	//   ănă_, dkey_, _önuc,
  { {0x69dd164c,0x2d996a3b,0x98160044,0x00000000}},	//   _zase, zase_, _إبحا,
  { {0x68e46a3c,0x7afa0137,0x7bde6a3d,0x00000000}},	//   lvid, ätth, _mapu,
  { {0x68e46a3e,0x69c441b0,0x320d3f9c,0x00000000}},	//   ovid, nfie, gkey_,
  { {0x7e6d0290,0x13b6007e,0x69c400ac,0x00000000}},	//   _riap, _مصاح, ifie,
  { {0x6aa1007a,0x7e6d014f,0x7bde6a3f,0x00000000}},	//   álfk, _siap, _napu,
  { {0x68e4271c,0x2ca06a40,0x630600f2,0x00000000}},	//   hvid, _avid_, _حوال,
  { {0xb5fd08ea,0x90e603eb,0x320d0399,0x00000000}},	//   _piši, _مستن, ckey_,
  { {0x69dd6a41,0x7bde001f,0x2d9936f6,0x00000000}},	//   _rase, _bapu, rase_,
  { {0xb5fd082a,0x68e46a42,0x8f760086,0x00000000}},	//   _viši, dvid, _суді,
  { {0x3a29014f,0x7bde0397,0x6016017d,0x00000000}},	//   tiap_, _dapu, _câme,
  { {0x8e830021,0xb5fd12bf,0xfb340085,0x00000000}},	//   _اليه, _tiši, ёнтэ,
  { {0x37ab0189,0x245b0003,0x69dd6a43,0x00000000}},	// [e6f0] етен_, lême_, _vase,
  { {0x3eac02b0,0x69dd0035,0xf1b902e2,0x00000000}},	//   ordt_, _wase, riši_,
  { {0x69dd1f11,0x96e824f4,0x76b901f6,0x00000000}},	//   _tase, льца_, тлер_,
  { {0x7bde1228,0x3ce90d7d,0xc64b0021,0x00000000}},	//   _zapu, _krav_, رجال_,
  { {0x798d38c4,0xe5780086,0x245b0003,0x00000000}},	//   mbaw, узі_, hême_,
  { {0x23290690,0xf3e50156,0xad9b0066,0x00000000}},	//   коли_, ржко, okús,
  { {0x765b001b,0xfc3f6a44,0x41b50021,0x00000000}},	//   _thuy, luís_, لمغر,
  { {0x212b017d,0x0205137a,0x7afa0ec4,0x00000000}},	//   úcho_, рзин, ätti,
  { {0x320d0034,0x798d017e,0x4425008f,0x00000000}},	//   rkey_, ibaw, _tml_,
  { {0xb87b0024,0x60090175,0x8fa50002,0x00000000}},	//   _príj, тном_, јане,
  { {0x68e4085a,0x26c105b3,0x7bde18d5,0x00000000}},	//   zvid, ntho_, _rapu,
  { {0x6016017d,0x78ad0666,0x39a2013d,0x00000000}},	//   _câmb, krav, _késő_,
  { {0x7bde6a45,0x3eac0717,0x6016003b,0x00000000}},	//   _papu, ardt_, _dâmb,
  { {0x68e40290,0xa1360047,0xfc3f01a8,0x00000000}},	//   vvid, _דאנק_, duís_,
  { {0x6996005a,0x19960095,0xb87b0014,0x00000000}},	//   ирах, ијар, _frík,
  { {0xdb1c6a46,0x798d002c,0x68e40730,0x00000000}},	//   cerý, gbaw, tvid,
  { {0x48e30076,0x7bde6a47,0x2ca0007d,0x00000000}},	// [e700] оотв, _tapu, _uvid_,
  { {0x69c40be9,0x68e43e1d,0x798d2f40,0x00000000}},	//   sfie, rvid, abaw,
  { {0xcb6a0002,0x69c4004d,0xf1b9007d,0x00000000}},	//   _јане_, pfie, lišu_,
  { {0x78ad6a48,0x3eb90051,0x6b9c171d,0x00000000}},	//   brav, ństw_, larg,
  { {0x78ad0016,0xf1b9007d,0x5d7b0041,0x00000000}},	//   crav, nišu_, דאנק,
  { {0x66e6011c,0xdb1c000f,0xdb070026,0x00000000}},	//   _кога, kerü, rfjö,
  { {0xdb070026,0xc7a306b4,0xdb1c0022,0x00000000}},	//   sfjö, _фиск, meró,
  { {0x6b9c059b,0x6aa10014,0xbebc008f,0x00000000}},	//   harg, álfi, lzīg,
  { {0x6b9c0bc1,0xc05a071f,0x33d60085,0x00000000}},	//   karg, кіо_, _віет,
  { {0x23890080,0x6016003b,0xdb1c0051,0x00000000}},	//   čují_, _sâmb, neró,
  { {0xb87b0024,0x6d4101f7,0x08570063,0x00000000}},	//   _prík, ğlam, שבים_,
  { {0x3ce90198,0x6d4101f7,0x245b0003,0x00000000}},	//   _prav_, şlam, rême_,
  { {0x6b9c0031,0xfbd300f2,0x0cab0062,0x00000000}},	//   farg, يتس_, ътни_,
  { {0x26c10185,0xab940086,0x7f840021,0x00000000}},	//   ytho_, жирі, _الغن,
  { {0xda78011c,0xbebc003d,0xdb1c6a49,0x00000000}},	//   ият_, dzīg, deró,
  { {0x9dab005a,0x78ad5675,0x4a550085,0x00000000}},	//   _ръка_, trav, ёкас,
  { {0x6b9c048e,0x394f00b9,0x32d8008b,0x00000000}},	// [e710] barg, ægs_, _lũy_,
  { {0x6b9c0942,0xb5fd2f42,0x798d0150,0x00000000}},	//   carg, _lišt, sbaw,
  { {0x8ae4019d,0xdc3c0063,0x7bd524d1,0x00000000}},	//   _діял, _בעזר, mezu,
  { {0xb5fd017f,0x78ad403f,0x9f5c01d1,0x00000000}},	//   _ništ, prav, _noví_,
  { {0x8b67007e,0xdb1c00ea,0x98ab008f,0x00000000}},	//   _حاکم, zerü, īmēt_,
  { {0x7bd50402,0xb87b0331,0xe3b80054,0x00000000}},	//   nezu, _asíg, ибі_,
  { {0xd298000d,0x07340505,0xc3d40085,0x00000000}},	//   атыі_, _дерю, іўшы,
  { {0x2019001c,0x91d5000d,0x7bd545ca,0x00000000}},	//   īsim_, сцкі, hezu,
  { {0x600d04a5,0x7bca0014,0x6b9c0058,0x00000000}},	//   _húmi, _öfug, yarg,
  { {0x20030026,0xaffe0013,0x04590021,0x00000000}},	//   ðji_, _phướ, _صلاة_,
  { {0x5f450032,0x2eb60042,0x6b9c6a4a,0x00000000}},	//   إنجل, _अमृत, varg,
  { {0x6b9c0dde,0xe9df0013,0x78a26a4b,0x00000000}},	//   warg, _thúy_, šovi,
  { {0x30850032,0x6b9c6a4c,0xafe50071,0x00000000}},	//   _التف, targ, _голл,
  { {0x1c390076,0x3f790047,0xaffe008b,0x00000000}},	//   аясь_, _גאַס, _thướ,
  { {0x600d00be,0x2ef8004d,0x6b9c6a4d,0x00000000}},	//   _númi, ärft_, rarg,
  { {0x6b9c6a4e,0xb87b0114,0x4d160062,0x00000000}},	//   sarg, _osíd, _гьот,
  { {0xdb1c6a4f,0xe9d7005e,0x7bd50a87,0x00000000}},	// [e720] teró, љку_, bezu,
  { {0xca290047,0x3cfb0063,0x46f60062,0x00000000}},	//   ײם_, _עלינ, йчет,
  { {0x20560047,0x3b0a5a0f,0x8f9a009a,0x00000000}},	//   ציעל_, _сено_, ריעי,
  { {0xceb200b5,0x7c2e4ea9,0xe5a30962,0x00000000}},	//   ליב_, libr, зици,
  { {0x6aa1007a,0x69d601f7,0xad9b021a,0x00000000}},	//   álfv, meye, ljúc,
  { {0xa5070138,0x69d601f7,0x04430500,0x00000000}},	//   сеља_, leye, печн,
  { {0x3f980026,0xb5fd0392,0x5273005e,0x00000000}},	//   ðrum_, _pišt, пуњу,
  { {0x69d65d02,0x2d8200ca,0x832e008d,0x00000000}},	//   neye, jcke_, _càvạ,
  { {0xdb0500bd,0x99800078,0x24f6005e,0x00000000}},	//   _schü, lnių_, _учвр,
  { {0xa208005b,0x3f981600,0x628a0829,0x00000000}},	//   ılış_, úru_, ppfo,
  { {0xdb1c007a,0x60160016,0x7bd51312,0x00000000}},	//   lfræ, _câma, vezu,
  { {0x442e499c,0x99800078,0x6d5a0022,0x00000000}},	//   lif_, inių_, ętan,
  { {0x644a00ac,0x7bd511ad,0x69d6092a,0x00000000}},	//   oofi, tezu, deye,
  { {0x4e93006a,0xdcfd003d,0x442e0360,0x00000000}},	//   _کشور, lasī, nif_,
  { {0x3f9e6a50,0xb5fd0078,0xdb0704aa,0x00000000}},	//   matu_, _mišr, ngjø,
  { {0x3f9e017f,0x442e001f,0x20c20014,0x00000000}},	//   latu_, hif_, oði_,
  { {0x61e20025,0x77994273,0x644a6a51,0x00000000}},	// [e730] _maol, икар_, kofi,
  { {0x20c20026,0x99890066,0x61e21423,0x00000000}},	//   iði_, dnať_, _laol,
  { {0xaa590091,0x7ac7202f,0x442e6a52,0x00000000}},	//   _вину_, _успе, dif_,
  { {0x6aa10026,0xdebb07e9,0xdb1c0014,0x00000000}},	//   álfu, רמאל, ffræ,
  { {0x3f9e5174,0x84c70001,0xdb1c0026,0x00000000}},	//   katu_, сљед, gfræ,
  { {0xdb050164,0xd7fb6a53,0x644a001f,0x00000000}},	//   _adhé, _сум_, gofi,
  { {0xdc3800b5,0xdb07069f,0x2d820137,0x00000000}},	//   זאגט_, ggjø, ycke_,
  { {0x20c20026,0x80a96a54,0x61e200dd,0x00000000}},	//   fði_, авив_, _caol,
  { {0x20c2007a,0x3494088e,0x644a2f10,0x00000000}},	//   gði_, _натр, bofi,
  { {0xbebc003d,0xb87b0516,0x3f9e194f,0x00000000}},	//   dzīb, _frív, gatu_,
  { {0xc7b20063,0x02d9007e,0xee3a29c2,0x00000000}},	//   ובי_, _خواب_, ино_,
  { {0x61e20027,0x92b4007e,0xdce6008f,0x00000000}},	//   _gaol, _رحما, pakļ,
  { {0x8fa56a55,0x9e3d01d1,0x2d820244,0x00000000}},	//   _дале, vrďt, rcke_,
  { {0xdb1c007a,0x27e300c2,0x99800078,0x00000000}},	//   ferð, _najn_, ynių_,
  { {0xdb1c007a,0x69d6005b,0x99890024,0x00000000}},	//   gerð, teye, znať_,
  { {0xe9da00e1,0x442e2d6f,0x01f90047,0x00000000}},	//   јка_, zif_, ספּל,
  { {0xd910007e,0x7c2e0078,0xf9c50121,0x00000000}},	// [e740] ریس_, pibr, ящён,
  { {0x99890024,0x7afa0137,0x3b830065,0x00000000}},	//   vnať_, ätts, _ольг,
  { {0x764b001f,0x20076a56,0xe57a143c,0x00000000}},	//   fogy, _moni_, азе_,
  { {0xdb0700d1,0x99800078,0x200747bf,0x00000000}},	//   vgjø, rnių_, _loni_,
  { {0x99800006,0x644a07bc,0x442e0fe3,0x00000000}},	//   snių_, tofi, tif_,
  { {0xdb1c007a,0xdb0700d1,0x61e20139,0x00000000}},	//   rfræ, tgjø, _saol,
  { {0x61e20191,0xdb1c0014,0x644a6a57,0x00000000}},	//   _paol, sfræ, rofi,
  { {0xdb070031,0xdd140024,0x9f5c027d,0x00000000}},	//   rgjø, pĺňa, _nová_,
  { {0x3f9e6a58,0xdcfd008f,0xd0100021,0x00000000}},	//   tatu_, rasī, فلة_,
  { {0x20c2007a,0x3f9e014f,0x20180026,0x00000000}},	//   rði_, uatu_, óri_,
  { {0x20076a59,0x61e2112c,0xb77b0041,0x00000000}},	//   _doni_, _taol, יאיש,
  { {0x3f9e2207,0xdb1c0014,0x62650021,0x00000000}},	//   satu_, verð, _فانق,
  { {0x3f9e419f,0x9ccb000d,0xdce60058,0x00000000}},	//   patu_, шына_, fakı,
  { {0x68fb0268,0xa06702a1,0x752229ef,0x00000000}},	//   _àudi, _дача_, izoz,
  { {0x5fb7014e,0x764b0150,0x600d12e2,0x00000000}},	//   _והוא_, yogy, _cúmu,
  { {0x41d0016a,0x7bda0003,0x2007007d,0x00000000}},	//   _थॉमस, ôtur, _zoni_,
  { {0x7afa01e3,0xdd15007e,0x99890022,0x00000000}},	// [e750] ättr, _رودخ, tkał_,
  { {0x6aa10026,0xc7f80086,0x998f0022,0x00000000}},	//   álfs, онує_, ógł_,
  { {0x201e004b,0x78a46a5a,0x87280085,0x00000000}},	//   ihti_, asiv, оўца_,
  { {0x7afa2b4c,0x9479000d,0x78a40072,0x00000000}},	//   åtte, бску_, bsiv,
  { {0x25a0007a,0xb87b573f,0xc4db005e,0x00000000}},	//   ðila_, _crít, рђе_,
  { {0x2a690019,0x442c6a5b,0x942502d7,0x00000000}},	//   lmab_, _cmd_, ямле,
  { {0x65950088,0x8c1c00ff,0xb87b0046,0x00000000}},	//   _наву, שווי, _erít,
  { {0xb87b0014,0x20070130,0x41050062,0x00000000}},	//   _frít, _soni_, ззив,
  { {0x661b004b,0xdce60058,0x7522056c,0x00000000}},	//   _iluk, yakı, czoz,
  { {0x66092ac2,0x79840051,0x6e2d4851,0x00000000}},	//   _hoek, zciw, _amab,
  { {0x66090a5f,0x661b0026,0x8e850454,0x00000000}},	//   _koek, _kluk, ягне,
  { {0x78a40072,0x201e078c,0xdd850085,0x00000000}},	//   ysiv, ahti_, дыёп,
  { {0xe0ce0086,0xdd4a005e,0x317a0149,0x00000000}},	//   _яв_, стнa_, _האנד,
  { {0x20130013,0x600d0014,0x660955db,0x00000000}},	//   _ôxi_, _púmu, _loek,
  { {0xdb1c01e3,0x661b0004,0xdce6005b,0x00000000}},	//   kfrå, _oluk, rakı,
  { {0x78a40bc2,0x88863320,0x2d85004c,0x00000000}},	//   tsiv, злаж, ělec_,
  { {0x799d00bd,0xdb1c0137,0x6aa10014,0x00000000}},	// [e760] _desw, dfrå, álfr,
  { {0x9f470031,0x661b2a78,0x600d3502,0x00000000}},	//   _ennå_, _aluk, _túmu,
  { {0x66090ac8,0x6676007e,0x224d00ca,0x00000000}},	//   _boek, سدار, koek_,
  { {0xb87b0024,0x799d00ac,0x6b9e002b,0x00000000}},	//   _prít, _gesw, _hepg,
  { {0x7ded0047,0x6609006f,0xdb1c00a5,0x00000000}},	//   יקאַ, _doek, sfrä,
  { {0x661b0019,0x78a20061,0x2bc00042,0x00000000}},	//   _eluk, šovs, श्चा,
  { {0xe2970856,0x3f9c1a05,0x661b6a5c,0x00000000}},	//   пај_, _revu_, _fluk,
  { {0xb87b0014,0x661b6a5d,0x6d5a0022,0x00000000}},	//   _grís, _gluk, ętaj,
  { {0xdfd0043b,0x764300ea,0x60f7000d,0x00000000}},	//   نية_, énye, зныя_,
  { {0x66090b7d,0x29006a5e,0x251b069a,0x00000000}},	//   _zoek, ixia_, _הומא,
  { {0x224d0250,0x6d5600e5,0x6d446a5f,0x00000000}},	//   boek_, _ayya, _axia,
  { {0xf27b014e,0xa3cd0053,0x3f87002b,0x00000000}},	//   _הראש, ष्ठ_, _efnu_,
  { {0xfc3f006d,0x64586a60,0x799d001f,0x00000000}},	//   esía_, olvi, _resw,
  { {0x7bc8004b,0x9a870c46,0x2f1802fa,0x00000000}},	//   õdup, зуал, _моль_,
  { {0xdb1c0164,0xcb69005d,0x64586a61,0x00000000}},	//   ngrè, زمره_, ilvi,
  { {0x6e2d002c,0x79a7000d,0x0f570063,0x00000000}},	//   _umab, ярге, _מיום_,
  { {0xdb1c0137,0x660900ca,0x2c6400a5,0x00000000}},	// [e770] vfrå, _roek, född_,
  { {0x660910e9,0x224d0122,0x661b0d02,0x00000000}},	//   _soek, zoek_, _sluk,
  { {0x2ca9010a,0xb87b0024,0x99890022,0x00000000}},	//   _hvad_, _prís, tkań_,
  { {0x3a206a62,0x6e3d53d1,0x601f017d,0x00000000}},	//   chip_, nnsb, _iême,
  { {0xdb1c01e3,0x629a0e27,0x6e3d0244,0x00000000}},	//   rfrå, _awto, insb,
  { {0x69cd001f,0xdb1c6a63,0xd7e40054,0x00000000}},	//   lfae, sfrå, _пісо,
  { {0x660904c6,0x68ed16eb,0xdb1c004b,0x00000000}},	//   _toek, lvad, berõ,
  { {0x601f0164,0x661b004b,0x645835b8,0x00000000}},	//   _même, _uluk, alvi,
  { {0x682000c7,0x224d26ad,0xf1a8007e,0x00000000}},	//   _född, roek_, سايه_,
  { {0x224d021f,0x7e646a64,0xc87f00bd,0x00000000}},	//   soek_, _ship, _muß_,
  { {0xa3cd0235,0xa2940086,0x1f650086,0x00000000}},	//   ष्ण_, _захі, ьком,
  { {0xd12e006a,0x63a36a65,0xf2040085,0x00000000}},	//   امی_, lann, _пячо,
  { {0x61e90ca9,0x7659002b,0x7568009d,0x00000000}},	//   mdel, ilwy, ּ֣רְ,
  { {0xddcd000c,0x61e96a66,0x63a36a67,0x00000000}},	//   _piaţ, ldel, nann,
  { {0x60c96a68,0xc87f004d,0x68ed13ed,0x00000000}},	//   ltem, _auß_, evad,
  { {0xddcd000c,0xda650021,0xdb1c0803,0x00000000}},	//   _viaţ, فاقي, ngré,
  { {0x6b670164,0x98a30076,0x61e92c87,0x00000000}},	// [e780] tégé, ките, idel,
  { {0x3a200037,0xb87b6a69,0xc9630076,0x00000000}},	//   ship_, _prír, твуй,
  { {0x69c9016a,0x76590185,0x6d4101f7,0x00000000}},	//   _हॉकी, flwy, şlat,
  { {0x6b67000f,0x61e95923,0x7659001f,0x00000000}},	//   ségé, jdel, glwy,
  { {0xfc3f0025,0x63a36a6a,0x61e96a6b,0x00000000}},	//   isín_, fann, ddel,
  { {0x7bdc5406,0x9f980026,0x63a36a6c,0x00000000}},	//   neru, _náðu_, gann,
  { {0xe61a0002,0x61e91923,0x60c96a6d,0x00000000}},	//   _ддв_, fdel, etem,
  { {0xdb2500ea,0x7bdc00bd,0x68200137,0x00000000}},	//   ésér, heru, _döde,
  { {0x83c6005a,0x30142ab5,0x7bdc6a6e,0x00000000}},	//   _обаж, едпр, keru,
  { {0x7bdc0a1a,0x63a36a6f,0x68206a70,0x00000000}},	//   jeru, cann, _föde,
  { {0x7bdc6a71,0x61e932fa,0x78b6006f,0x00000000}},	//   deru, bdel, hryv,
  { {0xd378017f,0x7d090019,0x7bdc004b,0x00000000}},	//   _naći_, äeso, eeru,
  { {0x60c90164,0x9f980026,0x7bdc6a72,0x00000000}},	//   ctem, _fáðu_, feru,
  { {0x6abc001f,0x9f980014,0x7bdc6a73,0x00000000}},	//   furf, _gáðu_, geru,
  { {0x7659001f,0xcf260021,0x2019008f,0x00000000}},	//   ylwy, _ترشي, īsit_,
  { {0x25a00026,0x63a36a74,0xda700021,0x00000000}},	//   ðill_, zann, لُّ_,
  { {0x7d0000c7,0xee3f027d,0x7bdc6a75,0x00000000}},	// [e790] ämst, mný_, beru,
  { {0x9c380076,0x61e96a76,0x68ed2b2e,0x00000000}},	//   _опыт_, zdel, rvad,
  { {0x248d36f0,0x63a34387,0xc7c40062,0x00000000}},	//   _stem_, vann, ъсти,
  { {0xee3f0a63,0x94790001,0x38c3008f,0x00000000}},	//   nný_, пску_, tūrā_,
  { {0x682000c7,0x61e96a77,0xb87b0014,0x00000000}},	//   _söde, vdel, _gríp,
  { {0x5faf0053,0xee3f0066,0x02c502f9,0x00000000}},	//   _फ़ाइल, hný_, ейко,
  { {0x63a36a78,0x93bc003b,0x61e90a3f,0x00000000}},	//   rann, _rmăt, tdel,
  { {0x60c96a79,0x35fb007e,0x7ae505b3,0x00000000}},	//   ttem, _برسد_, _msht,
  { {0x61e92aad,0xee3f0114,0x4094000d,0x00000000}},	//   rdel, dný_, крэт,
  { {0x93bc000c,0x60c96a7a,0x61e90b19,0x00000000}},	//   _clăd, rtem, sdel,
  { {0x60c96a7b,0x2d85004c,0x61e913e5,0x00000000}},	//   stem, ělen_, pdel,
  { {0x7bc5001f,0x7bdc04aa,0x60c90d4d,0x00000000}},	//   _achu, weru, ptem,
  { {0x39590137,0x7bdc6a7c,0x62816a7d,0x00000000}},	//   _nyss_, teru, _hulo,
  { {0x7bdc00bd,0x62816a7e,0x6abc26f5,0x00000000}},	//   ueru, _kulo, turf,
  { {0x63a1001c,0xdbdd0026,0xee3f027d,0x00000000}},	//   _meln, ráðu, bný_,
  { {0xb87b0024,0x2caa005a,0x09e3270f,0x00000000}},	//   _príp, _екип_, лосн,
  { {0x6d4101f7,0x39466a7f,0xba170032,0x00000000}},	// [e7a0] şlar, ços_, ريكا_,
  { {0xdb1c00b9,0x999f001c,0xb6080066,0x00000000}},	//   kfrø, ārša_, _mešť,
  { {0x31ba005b,0x28ac0053,0x628123e7,0x00000000}},	//   nüzü_, _चिकि, _nulo,
  { {0x25a00027,0x5ab70047,0xb87b12c7,0x00000000}},	//   úil_, _אלטע_, _tríp,
  { {0xb97b0063,0x69c6018f,0xb60801d1,0x00000000}},	//   _מרכז, _icke, _nešť,
  { {0x628103f7,0xee3f01c2,0x93bc003b,0x00000000}},	//   _bulo, zný_, _amăr,
  { {0xc8430086,0x62816a80,0x63a126cd,0x00000000}},	//   _серй, _culo, _deln,
  { {0x63a10004,0x60f8005a,0x6281002c,0x00000000}},	//   _eeln, дния_, _dulo,
  { {0xc05a0088,0x63a100ea,0xee3f027d,0x00000000}},	//   зін_, _feln, vný_,
  { {0x20d30021,0xb608004c,0x63a1017c,0x00000000}},	//   اتيج, _dešť, _geln,
  { {0xee3f0512,0x93bc003b,0x3e7a005f,0x00000000}},	//   tný_, _vlăd, _būta_,
  { {0x7bc56a81,0xe29b0041,0xe7c70082,0x00000000}},	//   _schu, _זשאר, _लाभप,
  { {0x6016017d,0xee3f0114,0xdb150014,0x00000000}},	//   _lâmi, rný_, _íbúa,
  { {0x7a230019,0x25a6001f,0xee3f004a,0x00000000}},	//   _mõte, haol_, sný_,
  { {0x22ac0080,0xdb220026,0xbebc001c,0x00000000}},	//   něk_, ðuðu, ozīm,
  { {0x9b580086,0x7a3b0072,0x3ebe004e,0x00000000}},	//   хист_, dätä, mutt_,
  { {0x9f5c0024,0x3ebe3327,0x200e4c6f,0x00000000}},	// [e7b0] _novú_, lutt_, _kofi_,
  { {0x7bc50035,0x2907007d,0xc6a70065,0x00000000}},	//   _uchu, ćna_, ерди,
  { {0xf3ff00aa,0x3ebe0031,0x25a6002b,0x00000000}},	//   _đã_, nutt_, faol_,
  { {0xb495005e,0xbebc008f,0x36180054,0x00000000}},	//   видљ, jzīm, нцію_,
  { {0xe56e000a,0x63a1143b,0x93bc003b,0x00000000}},	//   рз_, _peln, _rmăr,
  { {0xe3b3006a,0x293600b5,0x62816a82,0x00000000}},	//   ارش_, _יארן_, _pulo,
  { {0x07350062,0x92e80021,0xd5bb0062,0x00000000}},	//   _ревю, فريق_, _нса_,
  { {0x75e7000d,0x25a6002b,0xceb80022,0x00000000}},	//   _яўге, caol_, drę_,
  { {0xe0d90086,0xfa0f008d,0xe3b300f2,0x00000000}},	//   єво_, _đậu_, _مرض_,
  { {0x62816a83,0x200e002b,0xbebc0023,0x00000000}},	//   _tulo, _cofi_, azīm,
  { {0x3e7b008f,0xa2b40082,0x779a009d,0x00000000}},	//   _sūta_, ैंण्, וֹכו,
  { {0x93bc003b,0x2c6400a5,0x2374013a,0x00000000}},	//   _umăr, döda_, _صالح,
  { {0xceb80022,0xf532009a,0x00000000,0x00000000}},	//   arę_, ֹ֥ר_,   ,
  { {0x3ebe0031,0x0c790076,0x1d070092,0x00000000}},	//   butt_, ессы_, њери_,
  { {0xe8050053,0x601f002b,0xfe462c7a,0x00000000}},	//   राना_, _gêma, _инко,
  { {0x4a430733,0x7db5014b,0x00000000,0x00000000}},	//   ансв, _йсьц,   ,
  { {0x61eb6a84,0x991502fe,0x27ea002b,0x00000000}},	// [e7c0] _magl, льфі, _pabn_,
  { {0xe3b8005b,0x61eb0504,0xbebc0417,0x00000000}},	//   _alın_, _lagl, dzīj,
  { {0xf719000d,0x25a6002b,0x37e30085,0x00000000}},	//   ніцы_, taol_, рохг,
  { {0x22ac0080,0x61eb6a85,0x682000c7,0x00000000}},	//   věk_, _nagl, _döda,
  { {0x7a3b00fe,0x9f470114,0xe4c30062,0x00000000}},	//   sätä, _dané_, ийци,
  { {0xa7da006a,0xa5070001,0x93bc003b,0x00000000}},	//   _توسط_, теља_, _slăb,
  { {0xb6a30086,0xbebc001c,0x96b90001,0x00000000}},	//   _висл, tzīm, _путу_,
  { {0xe3b2006a,0x61eb304b,0xcb130063,0x00000000}},	//   _چرا_, _cagl, שלה_,
  { {0x20540062,0xbebc008f,0xad9b0014,0x00000000}},	//   лкия, rzīm, sjúk,
  { {0x61eb057a,0x3ebe6a86,0xe8050053,0x00000000}},	//   _eagl, tutt_, राया_,
  { {0xd7bb0047,0x539b0063,0xa1c6000d,0x00000000}},	//   וציר, _חיבו, _абед,
  { {0x3ebe2579,0x61eb24b9,0x93bc003b,0x00000000}},	//   rutt_, _gagl, _flăc,
  { {0x224600e3,0x69c4006c,0x23c90042,0x00000000}},	//   _ijok_, dgie, _रामद,
  { {0x68e40034,0x61e001f7,0x61eb158e,0x00000000}},	//   dwid, leml, _zagl,
  { {0x60c000fe,0x68e4001f,0xdd03005b,0x00000000}},	//   lumm, ewid, ırıd,
  { {0x69c46a87,0xe18f008b,0x61e06a88,0x00000000}},	//   ggie, hẳng_, neml,
  { {0x60c00f4b,0xaa580a8f,0x61e00244,0x00000000}},	// [e7d0] numm, титу_, ieml,
  { {0x7d580063,0x61e06a89,0x7e81008f,0x00000000}},	//   _ביחד_, heml, _sēpi,
  { {0xdcef005b,0xa647005d,0x61e00058,0x00000000}},	//   macı, پخان, keml,
  { {0x61e000c3,0xfb1a0063,0x60c06a8a,0x00000000}},	//   jeml, _נורמ, kumm,
  { {0xa8a40079,0xe8df001b,0x61eb001f,0x00000000}},	//   _врск, _thực_, _ragl,
  { {0x61eb003d,0x2484004d,0xbebc0023,0x00000000}},	//   _sagl, _dumm_, rzīj,
  { {0x61eb00bb,0x78ad0006,0x2129017c,0x00000000}},	//   _pagl, lsav, _ťah_,
  { {0x93bc000c,0x61e041e4,0x60e90b41,0x00000000}},	//   _plăc, geml, емим_,
  { {0x26c100a4,0x61eb0290,0x78ad6a8b,0x00000000}},	//   luho_, _vagl, nsav,
  { {0x78ad0891,0x798d002b,0x6fd40054,0x00000000}},	//   isav, hcaw, ацює,
  { {0x2ba70053,0x61eb6a8c,0x54560047,0x00000000}},	//   _औज़ा, _tagl, _עסען_,
  { {0xa2d80161,0x60c024bb,0x68e40022,0x00000000}},	//   _महत्, bumm, ywid,
  { {0x25a00026,0x64436a8d,0x44271645,0x00000000}},	//   ðili_, onni, ohn_,
  { {0x78ad380f,0x613a0047,0x69cb00cd,0x00000000}},	//   dsav, _אײנס, ògen,
  { {0xe6d20161,0x69c43dc7,0x64436a8e,0x00000000}},	//   _सहेज, tgie, inni,
  { {0xfaa50055,0x6e920021,0x01f90047,0x00000000}},	//   ршён, _اليا, עפּל,
  { {0xc966005a,0x78ad0829,0x6d5a0051,0x00000000}},	// [e7e0] увай, gsav, ętas,
  { {0xebe60079,0x225f0150,0x61e06a8f,0x00000000}},	//   _сооп, hluk_, zeml,
  { {0x68e4004d,0x225f2b22,0xdb1c0805,0x00000000}},	//   swid, kluk_, sgrâ,
  { {0x64436a90,0x44270378,0x69d00042,0x00000000}},	//   enni, ehn_, ड्शी,
  { {0x2a600150,0x69ca00ea,0xe3b2007e,0x00000000}},	//   mlib_, őfes, مرغ_,
  { {0x6e240994,0x2a600019,0x26c100a4,0x00000000}},	//   _llib, llib_, buho_,
  { {0xd62a0001,0xd8230002,0xdb070014,0x00000000}},	//   _зове_, _удри, sgjö,
  { {0x7afa00fe,0x60c06a91,0x710a0121,0x00000000}},	//   ätty, tumm, ехов_,
  { {0x463b00b5,0x61e001a6,0xdcef005b,0x00000000}},	//   _נעמע, reml, yacı,
  { {0x44386a92,0x60c00b0c,0xb0340a8f,0x00000000}},	//   _ör_, rumm, рнош,
  { {0x08570063,0x60c06a93,0xdcef0058,0x00000000}},	//   רבים_, summ, vacı,
  { {0xfe55000d,0x629801b0,0x27e1004d,0x00000000}},	//   ркмэ, mpvo, zehn_,
  { {0x4096018e,0x5096005e,0x0e341224,0x00000000}},	//   _срет, _сређ, сняю,
  { {0x63aa0026,0x6e246a94,0x629800ca,0x00000000}},	//   nafn, _elib, opvo,
  { {0xdcef005b,0x501b0063,0xfe70007e,0x00000000}},	//   racı, _אוגו, تدی_,
  { {0x201e0078,0x78ad6a95,0x5eeb009a,0x00000000}},	//   lkti_, tsav, _רַגְ,
  { {0x200c00c2,0x64436a96,0xa91b0014,0x00000000}},	// [e7f0] ojdi_, ynni, _afþr,
  { {0x201e382d,0x78ad6a97,0x225f005b,0x00000000}},	//   nkti_, rsav, zluk_,
  { {0xd6db0088,0x201e143b,0xb87b0066,0x00000000}},	//   эта_, ikti_, _kríz,
  { {0x7afa0146,0x78ad003d,0x7bc70026,0x00000000}},	//   ætte, psav, lgju,
  { {0x442701db,0x7e6d002b,0x2bd20042,0x00000000}},	//   thn_, _mhap, द्वा,
  { {0x24960021,0x7bc76a98,0x63aa002b,0x00000000}},	//   جنود_, ngju, gafn,
  { {0xa349011c,0xdb1c42d7,0x786b0058,0x00000000}},	//   ъзка_, ográ, güve,
  { {0xe1ff006d,0x201e508e,0x15a80062,0x00000000}},	//   ñó_, ekti_, _бъфи_,
  { {0xdd140024,0x225f107b,0x9f4b004c,0x00000000}},	//   kúša, rluk_, ěcí_,
  { {0x225f2dd6,0x6e24290e,0xe8df0013,0x00000000}},	//   sluk_, _slib, _giục_,
  { {0x43840032,0xde060727,0x44256a99,0x00000000}},	//   _المق, апни, _ill_,
  { {0x200c00c2,0x7e6d6a9a,0x3eb8274e,0x00000000}},	//   ajdi_, _chap, árta_,
  { {0xd1670062,0x9c870066,0x7af5004c,0x00000000}},	//   _съжи, _rečí, evzt,
  { {0xbf35007e,0x7bc70026,0x55760047,0x00000000}},	//   _پرتغ, ggju, יערן_,
  { {0x765b005b,0xfaa60a6e,0x26c700cd,0x00000000}},	//   _okuy, рабо, ànol_,
  { {0x6e240035,0xceb80022,0xba236a9b,0x00000000}},	//   _ulib, rzęt_, одск,

  { {0xdb1c00cd,0x442546b8,0xe9d70092,0x00000000}},	// [e800] sgrà, _oll_, јку_,
  { {0x7a230019,0x3a290089,0x480309c2,0x00000000}},	//   _võta, ahap_, опув,
  { {0x3bbb014e,0xab2a37e9,0x98a00022,0x00000000}},	//   _במיד, _рона_, dzią_,
  { {0x3a296a9c,0x44252c95,0x9f5c0114,0x00000000}},	//   chap_, _all_, _nový_,
  { {0x201e0078,0x43943774,0x45b70083,0x00000000}},	//   ykti_, балс, ргію_,
  { {0x9473007e,0x741300f2,0x98a302f8,0x00000000}},	//   يدوا, يونا, _фире,
  { {0x44256a9d,0x7c3c00fe,0xe5a60086,0x00000000}},	//   _dll_, iirr, _виби,
  { {0x442533d4,0x63aa0026,0xe61701ce,0x00000000}},	//   _ell_, safn, _кдс_,
  { {0x9f470114,0xdfd40121,0x914a0062,0x00000000}},	//   _daní_, бопы, ъчка_,
  { {0x7e6d0034,0xdb1c00b9,0x201e143b,0x00000000}},	//   _shap, mgræ, ukti_,
  { {0x7c3c0026,0x7c2900ac,0x201e0006,0x00000000}},	//   dirr, ëerm, rkti_,
  { {0x7c3c0026,0x443c6a9e,0x64583667,0x00000000}},	//   eirr, liv_, lovi,
  { {0x40940032,0x64580019,0x3e4f0051,0x00000000}},	//   _التر, oovi, jęte_,
  { {0xbebc001c,0x62886a9f,0x7bd5004d,0x00000000}},	//   dzīv, _kudo, ufzu,
  { {0x63a800c3,0x1a5b0032,0x39a70a3d,0x00000000}},	//   _medn, نشرة_, ишав,
  { {0x62886aa0,0x7e6d017f,0xddcd001c,0x00000000}},	//   _mudo, _uhap, _skaņ,
  { {0xdb1c0026,0x6820004d,0x443c2e50,0x00000000}},	// [e810] rgrá, _tödl, kiv_,
  { {0x443c01b3,0x3a200058,0xfda70053,0x00000000}},	//   jiv_, akip_, _ख़ुफ,
  { {0x64586aa1,0x6288006d,0xdb1c00b9,0x00000000}},	//   dovi, _nudo, egræ,
  { {0x3f790047,0xdb0500ea,0xdb1c00b9,0x00000000}},	//   אָנע, _nehé, fgræ,
  { {0x6560001f,0x62880006,0x24e709da,0x00000000}},	//   _cymh, _audo, рцег,
  { {0x443c010a,0x64586aa2,0xe3b1007e,0x00000000}},	//   giv_, govi, سرت_,
  { {0xdb1c0026,0x9f470080,0x6e3d0014,0x00000000}},	//   agræ, _paní_, kisb,
  { {0x628809d4,0xdb1c01e1,0xddc400a8,0x00000000}},	//   _dudo, bgræ, _ohiš,
  { {0x76590051,0x6560001f,0x443c0ba5,0x00000000}},	//   mowy, _gymh, biv_,
  { {0x76590051,0x44256aa3,0x80f80062,0x00000000}},	//   lowy, _ull_, рхът_,
  { {0xc2c40032,0xdb0500ea,0x62880137,0x00000000}},	//   _ويكي, _fehé, _gudo,
  { {0x76590051,0x2d8400d1,0x3f9e017e,0x00000000}},	//   nowy, øme_, abtu_,
  { {0x6145005e,0x30750336,0x7c3c6aa4,0x00000000}},	//   _ћела, _лукс, tirr,
  { {0x6f950044,0x7659056c,0xfbfa00de,0x00000000}},	//   _الغض, howy, دّسة_,
  { {0xff53006a,0x76590051,0x7a230019,0x00000000}},	//   _بخش_, kowy, _võtn,
  { {0xbb430c07,0x443c055e,0x64580eb1,0x00000000}},	//   ческ, ziv_, zovi,
  { {0x76590051,0x7d090072,0x7c3c00be,0x00000000}},	// [e820] dowy, äest, pirr,
  { {0x3a206aa5,0xc8b50085,0x443c4a37,0x00000000}},	//   skip_, ўсты, xiv_,
  { {0x63a86aa6,0x9f4e4e86,0x64580dad,0x00000000}},	//   _redn, _cafè_, vovi,
  { {0xdb1c0146,0x452a1804,0x4eaa0047,0x00000000}},	//   tgræ, лжен_, רבײַ,
  { {0x98a00045,0x7a230019,0x443c6aa7,0x00000000}},	//   dzić_, _mõtl, tiv_,
  { {0x9cd7014e,0xdb1c0146,0x62883333,0x00000000}},	//   מונה_, rgræ, _pudo,
  { {0x63a80198,0xdb1c00b9,0xd706005e,0x00000000}},	//   _vedn, sgræ, _узви,
  { {0x443c6aa8,0x76590051,0x63a800e5,0x00000000}},	//   siv_, cowy, _wedn,
  { {0x63a800c3,0x361b0063,0x64580c19,0x00000000}},	//   _tedn, _עומד, povi,
  { {0x60160529,0x9ed80e5e,0x62886aa9,0x00000000}},	//   _câmp, амот_, _tudo,
  { {0xe0cf007e,0x6d400066,0xdb1c0ae2,0x00000000}},	//   وزی_, úman, ngrä,
  { {0x6e3d00e8,0x7d1d00fe,0x2bdb0053,0x00000000}},	//   uisb, tyss, म्ना,
  { {0x5c07005a,0x25d70047,0x6e3d4c33,0x00000000}},	//   бява, זוכן_, risb,
  { {0x76590022,0x7d1d6aaa,0xf3f1008d,0x00000000}},	//   zowy, ryss, _xạ_,
  { {0xa3cd0161,0x2fd8004b,0x7ff3005d,0x00000000}},	//   ष्ट_, õrgu_, _رسوا,
  { {0x6e440079,0xb9c50032,0x7d0900fe,0x00000000}},	//   _нејз, تقري, äess,
  { {0xb8150001,0xdb1c0137,0xb4e70053,0x00000000}},	// [e830] одај, egrä, _बने_,
  { {0x2cb40080,0x76590051,0x37070062,0x00000000}},	//   řadí_, wowy, йчев,
  { {0x76590045,0x57a4000d,0xf7480044,0x00000000}},	//   towy, яшта, ملكي_,
  { {0x3e7b00eb,0xe3b801f7,0x9f4e3a4e,0x00000000}},	//   _būti_, _adı_, _café_,
  { {0x76590051,0x9f4500ac,0x69dd462e,0x00000000}},	//   rowy, gelê_, _ibse,
  { {0x76590051,0x14190021,0x93bc003b,0x00000000}},	//   sowy, شيعة_, _flăm,
  { {0xe2990088,0x6d4101f7,0xdb070080,0x00000000}},	//   шай_, ğlay, kají,
  { {0x6d4101f7,0x20181471,0x7791005d,0x00000000}},	//   şlay, örin_, _ریچا,
  { {0xdb070080,0x41050086,0xa5070086,0x00000000}},	//   dají, ізов, _уявл,
  { {0xdb1c0137,0xc7ac009a,0x00000000,0x00000000}},	//   mfrö, ְׁכָ,   ,
  { {0x69dd318a,0xbebc008f,0x3f6904f2,0x00000000}},	//   _obse, dzīs, рино_,
  { {0xbe3a0086,0xbebc008f,0x0356009a,0x00000000}},	//   рчої_, ezīs, _ויעש_,
  { {0x3cf40053,0x6016003b,0x9f470061,0x00000000}},	//   इटें_, _tâmp, _daná_,
  { {0xbebc008f,0x69dd0136,0x25af05a5,0x00000000}},	//   tzīt, _abse, hagl_,
  { {0xdb1c0137,0x4e2a0456,0x92080023,0x00000000}},	//   xgrä, _войн_, brāķ,
  { {0xbebc008f,0xdb1c0137,0x2bdb0042,0x00000000}},	//   rzīt, vgrä, म्बा,
  { {0x3ea7001f,0xe79a0021,0xb17d0066,0x00000000}},	// [e840] _hwnt_, لخاص_, ieťo,
  { {0x69cf23a0,0xdb1c00c7,0x7d1b00bd,0x00000000}},	//   _ecce, tgrä, äuse,
  { {0xf9860076,0x46ea06b4,0x3e7b008f,0x00000000}},	//   _мгно, рден_, _sūti_,
  { {0x09060079,0xdb1c00c7,0xd5e9008b,0x00000000}},	//   _дпмн, rgrä, _chè,
  { {0xdb1c00c7,0xe8f721ac,0x6282006f,0x00000000}},	//   sgrä, _для_, _rioo,
  { {0xb6a60062,0xad9b0014,0xdb07004c,0x00000000}},	//   _мигл, hjúp, zají,
  { {0x78700137,0x00000000,0x00000000,0x00000000}},	//   rävd,   ,   ,
  { {0x92570021,0xb114218c,0xaae20082,0x00000000}},	//   يشير_, змиш, _पहनक,
  { {0xdb070080,0x3cf40053,0x6282006f,0x00000000}},	//   vají, इटों_, _vioo,
  { {0xd01a0b69,0xa2e6030b,0xf3ca04a0,0x00000000}},	//   рфи_, _мозд, _خبره_,
  { {0xddcd0066,0xdb07004c,0x49990121,0x00000000}},	//   _viaž, tají, ́тся_,
  { {0xddab0002,0xa3ba0042,0xab630075,0x00000000}},	//   штол_, _आएँ_, şüks,
  { {0x644a3e28,0x867b0063,0xbebc008f,0x00000000}},	//   onfi, ירטו, tzīs,
  { {0x7a230019,0x7c2e00e5,0x644a04aa,0x00000000}},	//   _võtm, ghbr, nnfi,
  { {0x644a0025,0xb0240013,0xb4e70042,0x00000000}},	//   infi, _giườ, _बन्_,
  { {0xe70b007e,0xddeb014d,0x2f130085,0x00000000}},	//   یتان_, _ضربه_, _ідыё,
  { {0x9cb5007e,0xfbd30042,0xa2ca0042,0x00000000}},	// [e850] _عمدت, _तापम, सूत्,
  { {0x629a6aab,0xe61600c2,0x7c2e087d,0x00000000}},	//   _otto, _čišč, chbr,
  { {0x98ac001c,0xfc3f00cd,0x9f4e013d,0x00000000}},	//   ālās_, ssís_, _infó_,
  { {0x69cf6aac,0x78700072,0xa6150085,0x00000000}},	//   _ucce, väve, ямеч,
  { {0x629a6aad,0xd5e9008b,0xa3e70053,0x00000000}},	//   _atto, _ché, यजल_,
  { {0x787000c7,0xdb0e00cd,0x3e72004a,0x00000000}},	//   täve, fabè, máte_,
  { {0x68ed0185,0x2009008b,0x3e4f0051,0x00000000}},	//   lwad, _đai_, zęta_,
  { {0x69cd65fd,0x787001bb,0x4209005e,0x00000000}},	//   ngae, räve, снио_,
  { {0xd5fb001b,0x629a0314,0x68ed001f,0x00000000}},	//   _giú, _etto, nwad,
  { {0xe8df001b,0x25ad5e26,0x44230066,0x00000000}},	//   _chức_, _heel_, _ôj_,
  { {0x961d001c,0x764b001f,0x25ad6aae,0x00000000}},	//   _ziņa, ongy, _keel_,
  { {0xfce6019d,0x3e720114,0xfe72013a,0x00000000}},	//   помо, káte_, عدد_,
  { {0xc1040021,0x61e9152e,0x7a2a0014,0x00000000}},	//   _يومي, meel, _nýta,
  { {0x68ed001f,0x3e72004a,0xa09a12cd,0x00000000}},	//   dwad, dáte_, _היסט,
  { {0xab270c4d,0x20076aaf,0x2291013d,0x00000000}},	//   пора_, _inni_, _ják_,
  { {0x3e7b003d,0x99890051,0x7d1b004d,0x00000000}},	//   _būtu_, ciaż_, äusc,
  { {0x60c93d50,0x9f45006c,0x48e31b08,0x00000000}},	// [e860] nuem, delé_, нотв,
  { {0x7e93003b,0x61e96ab0,0xdbca0086,0x00000000}},	//   _zăpa, heel, _угод_,
  { {0x61e9021e,0x7bdc06a5,0x644a00d1,0x00000000}},	//   keel, mfru, vnfi,
  { {0xd6cf006a,0xd5e9001b,0x682000c7,0x00000000}},	//   طقه_, _phé, _nödv,
  { {0x25ad0102,0x61e93f68,0xd5af00b3,0x00000000}},	//   _deel_, deel, افه_,
  { {0x764b002c,0x02a60245,0x7bdc000c,0x00000000}},	//   angy, прим, nfru,
  { {0x25ad0034,0x66e30c8d,0xdb0e00f8,0x00000000}},	//   _feel_, _пора, fabé,
  { {0x200702f6,0xc1ea0086,0xa6e20026,0x00000000}},	//   _anni_, ське_, öðum,
  { {0xe8df008b,0x24856ab1,0x78b60078,0x00000000}},	//   _phức_, _film_, nsyv,
  { {0xb0330076,0x20180026,0x7bdc006f,0x00000000}},	//   еньш, ðri_, jfru,
  { {0x61e903a8,0x442c2523,0x69cd002b,0x00000000}},	//   beel, _ild_, ygae,
  { {0x7a23004b,0x78b60072,0x7c3e1423,0x00000000}},	//   _võtk, ksyv, _ampr,
  { {0xdb0502dd,0xe8df001b,0x61fd0066,0x00000000}},	//   _vehí, _thức_, ôsle,
  { {0x3e720080,0x68fb0016,0x443e004b,0x00000000}},	//   váte_, _áudi, _jmt_,
  { {0x7e860080,0x3fdb0063,0x5fdb0063,0x00000000}},	//   íspě, _הקוב, _החוק,
  { {0x9f4700cd,0xda7b0086,0x7bce1207,0x00000000}},	//   _sanç_, сяг_, agbu,
  { {0x442c0034,0x6e2d00a4,0x2007001f,0x00000000}},	// [e870] _old_, _ilab, _ynni_,
  { {0x3e7201d9,0xb87b05ab,0x7a23004b,0x00000000}},	//   ráte_, _psíq, _mõti,
  { {0x9f4502f4,0x25ad6ab2,0x280800de,0x00000000}},	//   telé_, _peel_, ثْلَ_,
  { {0x8aa80063,0x443e6ab3,0x2485004b,0x00000000}},	//   _מֹשֶ, _amt_, _silm_,
  { {0x248d03d9,0x61e93b9a,0x25ad4a3f,0x00000000}},	//   _quem_, veel, _veel_,
  { {0xd7f50085,0x443e6ab4,0x9f450566,0x00000000}},	//   _ўзвы, _cmt_, selé_,
  { {0x6e2d01f7,0x35b5000a,0x9f450164,0x00000000}},	//   _olab, _обвр, pelé_,
  { {0x02dd0161,0x443e0019,0x754800ea,0x00000000}},	//   _महीन, _emt_, ászá,
  { {0x61e96ab5,0xdb0e6ab6,0x66096ab7,0x00000000}},	//   reel, rabé, _inek,
  { {0x6e2d1a8d,0x661b00fe,0x61e96ab8,0x00000000}},	//   _alab, _houk, seel,
  { {0x61e91986,0x2a6900a4,0x66090829,0x00000000}},	//   peel, klab_, _knek,
  { {0x661b024a,0x64436ab9,0x78b60072,0x00000000}},	//   _jouk, lini, ysyv,
  { {0x60c96aba,0x224d00ea,0x30150002,0x00000000}},	//   quem, mnek_, _оддр,
  { {0x3b0a0055,0x224d000f,0x6e2d564e,0x00000000}},	//   оего_, lnek_, _elab,
  { {0x66091964,0x70760021,0xa3df0053,0x00000000}},	//   _onek, _تموز_, ध्य_,
  { {0x224d000f,0xe9da0088,0xe1f90006,0x00000000}},	//   nnek_, ўка_, ndų_,
  { {0xb17a00b5,0xe1f90006,0x224d00ea,0x00000000}},	// [e880] ַטער, idų_, inek_,
  { {0xcb6a0001,0x66093dea,0xbddb00cd,0x00000000}},	//   _мапе_, _anek, nièn,
  { {0x224d000f,0x64436abb,0x76420072,0x00000000}},	//   knek_, dini, tioy,
  { {0x64436abc,0xdb1c04aa,0x443e148c,0x00000000}},	//   eini, dgrø, _smt_,
  { {0x224d00ea,0x64436abd,0x442c693e,0x00000000}},	//   dnek_, fini, _pld_,
  { {0x64436abe,0xe3b8005b,0x224d0051,0x00000000}},	//   gini, _alır_, enek_,
  { {0xbddb0268,0x2508007e,0x54330021,0x00000000}},	//   dièn, _کرزی_, ضرور,
  { {0x2000005b,0x644302b5,0x224d00ea,0x00000000}},	//   _şii_, aini, gnek_,
  { {0x961d003d,0x60f70088,0x3253005a,0x00000000}},	//   _ziņo, дныя_, ъвър,
  { {0x3f140c07,0x443e0089,0x7e64330d,0x00000000}},	//   едос, _umt_, _akip,
  { {0x3eb8000f,0x6d5a000c,0x25a6001f,0x00000000}},	//   ért_, ştal, obol_,
  { {0x26c7017f,0x60e70137,0x7e760003,0x00000000}},	//   šnog_, örmå, _chyp,
  { {0xe0d400b5,0x2c640137,0x2bd30042,0x00000000}},	//   _נײַ_, jöds_, _तादा,
  { {0x7a310031,0xbddb0268,0x7e640e20,0x00000000}},	//   _måte, cièn, _ekip,
  { {0x7a3101b9,0x2902005b,0x2a690168,0x00000000}},	//   _låte, _arka_, tlab_,
  { {0x3e56001c,0xbddb00cd,0x64436abf,0x00000000}},	//   tāte_, gnèt, zini,
  { {0xa9550001,0xb955005a,0x6443005b,0x00000000}},	// [e890] хваљ, хващ, yini,
  { {0xc9840138,0x661b0080,0xe1f90006,0x00000000}},	//   ђути, _souk, zdų_,
  { {0x61e2074f,0x27f8001f,0x64436ac0,0x00000000}},	//   _obol, _darn_, vini,
  { {0x78700137,0xdce40051,0x7a3100df,0x00000000}},	//   räva, _wzią, _båte,
  { {0x644318a2,0x27f8001f,0x2902007d,0x00000000}},	//   tini, _farn_, _grka_,
  { {0x201c0add,0x68200137,0x97c70021,0x00000000}},	//   _novi_, _döds, _تتحم,
  { {0x224d000f,0x64436ac1,0x661b00fe,0x00000000}},	//   tnek_, rini, _touk,
  { {0x6443093b,0x68200137,0xdb070bda,0x00000000}},	//   sini, _föds, majä,
  { {0x25bf00f3,0x6025005a,0xe1f90006,0x00000000}},	//   _idul_, едпа, rdų_,
  { {0x7e6463b3,0x224d00ea,0x644300ac,0x00000000}},	//   _skip, snek_, qini,
  { {0xbddb0268,0xfe4605f7,0x224d00ea,0x00000000}},	//   rièn, енно, pnek_,
  { {0x6ec00053,0xed5a6ac2,0xe5030082,0x00000000}},	//   _विरु, зом_, लिपि_,
  { {0x61fb0397,0xdb070019,0x683201e1,0x00000000}},	//   mdul, hajä, _hæde,
  { {0x61f9001f,0x683200b9,0x61e20384,0x00000000}},	//   _hawl, _kæde, _zbol,
  { {0x60db6ac3,0xdbd2004b,0x25bf00dd,0x00000000}},	//   ltum, müük, _odul_,
  { {0x7e640035,0x3a296ac4,0x2c640137,0x00000000}},	//   _ukip, gkap_, töds_,
  { {0x64416ac5,0x683201e1,0x321d0022,0x00000000}},	// [e8a0] _omli, _læde, _mowy_,
  { {0x3a290089,0x7d0468e5,0xace9005d,0x00000000}},	//   akap_, _iris, _آريل_,
  { {0xdb070019,0x290f00c7,0x60db037e,0x00000000}},	//   gajä, ägar_, htum,
  { {0x7d046ac6,0x321d0045,0x4a9b00b5,0x00000000}},	//   _kris, _nowy_, _מיטג,
  { {0x61fb002b,0x25a62281,0x27f86ac7,0x00000000}},	//   ddul, rbol_, _tarn_,
  { {0xb8e60161,0x61fb0104,0xbddb0003,0x00000000}},	//   ैं_, edul, nnèr,
  { {0x683201e1,0x60db68ae,0x46f42177,0x00000000}},	//   _vædd, etum, _בֶּן_,
  { {0x93bc000c,0x61fb00a4,0x78a40072,0x00000000}},	//   _alăt, gdul, opiv,
  { {0x290019c9,0x61f95adf,0x905402d8,0x00000000}},	//   nvia_, _dawl, квиц,
  { {0xa067005e,0xd5750636,0x53a60021,0x00000000}},	//   нања_, _русь, _أماك,
  { {0xde590086,0x61fb6ac8,0x6f03007d,0x00000000}},	//   дані_, bdul, _crnc,
  { {0xd13a02dc,0x7d0426f7,0x61e2056c,0x00000000}},	//   _нхл_, _bris, _ubol,
  { {0x7a230004,0x463b00b5,0x7e7d5eb7,0x00000000}},	//   _mõtt, לעטע, rmsp,
  { {0x00f70063,0x7d046ac9,0xbddb0003,0x00000000}},	//   _נמוך_, _dris, gnèr,
  { {0xdb580076,0x7d040ff2,0x2cea0053,0x00000000}},	//   еют_, _eris, टबॉल_,
  { {0xb5fd00c3,0x7d040d11,0xef110041,0x00000000}},	//   _akšn, _fris, _כּח_,
  { {0xd7950062,0x7d046aca,0xc8c80042,0x00000000}},	// [e8b0] визъ, _gris, िंगट,
  { {0x682000c7,0x3a296acb,0x3e56001c,0x00000000}},	//   _södr, skap_, māta_,
  { {0xdcfd01f7,0x29006acc,0xc5d501dd,0x00000000}},	//   ması, avia_, віль,
  { {0x69c30006,0xd6d8000d,0x2c7600b9,0x00000000}},	//   ėnes, эту_, ræde_,
  { {0x3e56003d,0x61f96acd,0x786b0019,0x00000000}},	//   nāta_, _rawl, hüvi,
  { {0xdcfd005b,0xd5c50054,0xf3f10044,0x00000000}},	//   nası, рiвн, شأت_,
  { {0xdce40045,0x42550189,0xa3d20042,0x00000000}},	//   _dzię, ктит, _वार_,
  { {0x00e50086,0x7afa0014,0x61fb6ace,0x00000000}},	//   вжин, ætti, udul,
  { {0x93bc0529,0xdcfd005b,0x60db623f,0x00000000}},	//   _plăt, kası, utum,
  { {0x601e0080,0x60db32ab,0x3e56001c,0x00000000}},	//   _námě, rtum, dāta_,
  { {0x34d10053,0x3ce900be,0xdcfd0058,0x00000000}},	//   _समुद, _apav_, dası,
  { {0x27010006,0x98a90051,0x7d041019,0x00000000}},	//   _mėn_, czać_, _pris,
  { {0xee370086,0xdcfd005b,0x3e56001c,0x00000000}},	//   тня_, fası, gāta_,
  { {0x29000290,0xa1360041,0xdca30263,0x00000000}},	//   vvia_, _באנק_, рари,
  { {0x0b59093e,0x7d0400e5,0x5b35000d,0x00000000}},	//   ерты_, _wris, гэту,
  { {0x3e56001c,0xc3320063,0x60c96acf,0x00000000}},	//   bāta_, בול_, orem,
  { {0xf1b200b5,0x60c96ad0,0x290000fe,0x00000000}},	// [e8c0] יסן_, nrem, uvia_,
  { {0x60c90ec6,0x290039f7,0xdb050e77,0x00000000}},	//   irem, rvia_, _behä,
  { {0x9999000f,0xbddb0003,0x98b3001c,0x00000000}},	//   _első_, zièm, ādās_,
  { {0x601e0080,0x64a65e8e,0xfc3f0331,0x00000000}},	//   _zámě, вада, mpía_,
  { {0x7a230004,0xbddb0164,0x34d10042,0x00000000}},	//   _võtt, xièm, _समृद,
  { {0x07a3011c,0xfc3f006d,0xbddb0003,0x00000000}},	//   _варн, opía_, vièm,
  { {0x7a230019,0xdb0500bd,0x60c96ad1,0x00000000}},	//   _tõtt, _gehä, erem,
  { {0x60f81cea,0xf5060793,0xbddb0003,0x00000000}},	//   ения_, _избо, tièm,
  { {0x628b0322,0xdb1c004d,0xdcfd0058,0x00000000}},	//   _digo, egrü, yası,
  { {0x98a90051,0x3e56008f,0x628b4949,0x00000000}},	//   szać_, vāta_, _eigo,
  { {0x7a310137,0x3fc8007e,0xdcfd0058,0x00000000}},	//   _låta, ودگی_, vası,
  { {0x71a6000d,0x81436ad2,0x60c96ad3,0x00000000}},	//   _радз, اپیم, brem,
  { {0xecc7005a,0xdcfd005b,0x60c939b8,0x00000000}},	//   ъщно, tası, crem,
  { {0x63b80205,0x229800ea,0x3e56008f,0x00000000}},	//   navn, _kék_, rāta_,
  { {0xdcfd01f7,0xdb070066,0x200e004e,0x00000000}},	//   rası, lajú, _infi_,
  { {0x79a40055,0x7a316ad4,0x39a4000a,0x00000000}},	//   ируе, _båta, ишув,
  { {0xdb070066,0x59670062,0x22983dc6,0x00000000}},	// [e8d0] najú, тъва, _lék_,
  { {0x63b80198,0xc6a70095,0x6ca40062,0x00000000}},	//   javn, врди, _тръж,
  { {0xdb0500c7,0x63b8027c,0xad27007e,0x00000000}},	//   _behå, davn, _سرکو,
  { {0xdb070024,0x7a230019,0xa5350121,0x00000000}},	//   kajú, _võts, лнеч,
  { {0x628b6328,0xc987007b,0xd4350044,0x00000000}},	//   _rigo, _јуни, ُعتب,
  { {0x60c96ad5,0xdb070024,0x442b6ad6,0x00000000}},	//   vrem, dajú, ьцем_,
  { {0x82a4005e,0xe1f10021,0x628b6ad7,0x00000000}},	//   ашње, مسة_, _pigo,
  { {0xc1b90021,0x60c90653,0x33271f48,0x00000000}},	//   رابط_, trem, rynx_,
  { {0x60c902a7,0x3114000d,0x63b8389e,0x00000000}},	//   urem, афэс, bavn,
  { {0xef194657,0xa2ca0053,0x0ea90121,0x00000000}},	//   емо_, संख्, нкой_,
  { {0xe7f60161,0xdce80058,0x5f450021,0x00000000}},	//   ीयता_, _ılım, انجل,
  { {0xe80a0053,0xdb1c004d,0x60c9622d,0x00000000}},	//   _होना_, rgrü, prem,
  { {0xb4f90047,0xdb1c004d,0xd6560063,0x00000000}},	//   עפֿי, sgrü, רירת_,
  { {0x55760047,0x9f0501fb,0x20180050,0x00000000}},	//   טערן_, _موتو, örit_,
  { {0xc016009d,0x5fda009d,0x00000000,0x00000000}},	//   _תקצו_, _נחקק,   ,
  { {0x63b800b2,0x7a310246,0xdb0e013d,0x00000000}},	//   zavn, _påta, gabá,
  { {0x090606c9,0x3cfa00de,0x09f700de,0x00000000}},	// [e8e0] ыпан, _أعبد_, دفقة_,
  { {0x27eb01da,0xe61f00c2,0x7a2a0445,0x00000000}},	//   _činí_, _čašč, _mýti,
  { {0xdb070024,0x3e56001c,0xf9890063,0x00000000}},	//   zajú, nāto_, פר_,
  { {0x7afa0026,0x7e93003b,0xf1b900b2,0x00000000}},	//   ættu, _căpi, jaš_,
  { {0xa3b40088,0x7a2a0014,0x63b8389e,0x00000000}},	//   аблі, _nýti, tavn,
  { {0xdb070024,0x7c2e00ca,0x3e560023,0x00000000}},	//   vajú, nkbr, kāto_,
  { {0x53340619,0x68f60185,0x63b806b9,0x00000000}},	//   рейт, lwyd, ravn,
  { {0xf7530242,0xddcf003b,0x3e56008f,0x00000000}},	//   _انفج, docş, dāto_,
  { {0xc0340095,0x69d600ea,0x68f6001f,0x00000000}},	//   иниј, igye, nwyd,
  { {0xdb0e0090,0xdb070066,0x7bc800f8,0x00000000}},	//   zabá, rajú, ódul,
  { {0x33930032,0x74130021,0x9e1501dd,0x00000000}},	//   _المز, _دولا, адні,
  { {0x2cb2001f,0x7c2e006f,0xdd91009e,0x00000000}},	//   _bwyd_, ekbr, توح_,
  { {0xad9b017c,0x3d0f0082,0x00000000,0x00000000}},	//   edúc, ामें_,   ,
  { {0x961d001c,0x68f6001f,0x644a096f,0x00000000}},	//   _viņi, dwyd, nifi,
  { {0xf8bf0080,0x68f60185,0xddd0005b,0x00000000}},	//   _své_, ewyd, _çeşm,
  { {0x2cb2001f,0x644a002b,0x68f6002b,0x00000000}},	//   _fwyd_, hifi, fwyd,
  { {0x68f60185,0x7e93000c,0x39151862,0x00000000}},	// [e8f0] gwyd, _răpi, шмар,
  { {0x25fd016a,0x57b40086,0x683200b9,0x00000000}},	//   _रोजी_, йбут, _pæda,
  { {0xf1b900c3,0x644a07b9,0x26110053,0x00000000}},	//   ljše_, difi, णाली_,
  { {0xf8bf004c,0x6aa500a3,0xe4d50044,0x00000000}},	//   _tvé_, _ithf, لتتب,
  { {0xf1b96ad8,0xdb0e0026,0xe9d60047,0x00000000}},	//   njše_, gabæ, _דורכ_,
  { {0xf794000d,0x224601e1,0x39440014,0x00000000}},	//   _гарэ, _amok_, _ýmsa_,
  { {0xf1b912bf,0x07e4014b,0x1bfc009a,0x00000000}},	//   taš_, _уцям, גלוב,
  { {0x3e56001c,0xdb05013d,0xd25100f2,0x00000000}},	//   vāto_, _behú, تنع_,
  { {0x3d0f0161,0xf1b902f7,0x7a310137,0x00000000}},	//   ामों_, raš_, _låto,
  { {0x09b20161,0x99890024,0x8467005a,0x00000000}},	//   _ज़्य, chať_, _събе,
  { {0x8e760002,0x1ec90062,0x7a3104aa,0x00000000}},	//   иумч, ълни_, _råtn,
  { {0x764b002c,0x68f6001f,0xe5670593,0x00000000}},	//   nigy, ywyd, قط_,
  { {0x6aa50025,0x9f4c0290,0x0d76000d,0x00000000}},	//   _athf, ledì_, рыня,
  { {0x69cb05d5,0xdddd0051,0xb87b004c,0x00000000}},	//   ógen, gosł, _zpív,
  { {0x290f00c7,0xc9b60001,0x9f4c3dda,0x00000000}},	//   ågan_, исањ, nedì_,
  { {0x644a05ed,0xc3320063,0xb716005d,0x00000000}},	//   zifi, קון_, یباش,
  { {0x87ba0076,0xe8fa005a,0xada900f2,0x00000000}},	// [e900] вует_, ъла_, _صديق_,
  { {0x68f66ad9,0x6e240025,0x3e790066,0x00000000}},	//   rwyd, _hoib, méta_,
  { {0x103600b5,0x68f6001f,0x644a006c,0x00000000}},	//   סטעם_, swyd, vifi,
  { {0x644a002b,0x14ca0121,0xe4a6224c,0x00000000}},	//   wifi, выки_, арко,
  { {0xb9030088,0x25a902dd,0x3e790066,0x00000000}},	//   _дзяк, ñala_, néta_,
  { {0x04430001,0x0ec50053,0xdb05006d,0x00000000}},	//   жељн, _विंड, _rehú,
  { {0x764b00bb,0x644a5322,0xc5d60086,0x00000000}},	//   bigy, rifi, _візь,
  { {0xe80a0053,0xd627005e,0x644a6ada,0x00000000}},	//   _होता_, _косе_, sifi,
  { {0xd0100021,0x1da70053,0xbfaa0a8f,0x00000000}},	//   كلة_, _क्षत, ктне_,
  { {0x91a60161,0x44e00290,0x6600028d,0x00000000}},	//   _ट्रै, mò_, _hamk,
  { {0x44e00290,0x645a028d,0x44e2008b,0x00000000}},	//   lò_, _ijti, _hư_,
  { {0x3e720025,0x6e36001f,0x66020b1c,0x00000000}},	//   náth_, _clyb, ndok,
  { {0x44e0051e,0x66021147,0x40960f2e,0x00000000}},	//   nò_, idok, _трет,
  { {0x44e00290,0x78a9005b,0x9f4700cd,0x00000000}},	//   iò_, _çevi, _canó_,
  { {0xdddd0051,0x78a60026,0x600b0063,0x00000000}},	//   rosł, _atkv, _יִהְ,
  { {0xbdb50095,0x0dcb0376,0x6e36002b,0x00000000}},	//   _убиј, _руки_, _glyb,
  { {0x5fdd0161,0x6448314f,0x66026adb,0x00000000}},	// [e910] _मामल, _omdi, ddok,
  { {0x9f4702dd,0x44e00290,0xe8df0013,0x00000000}},	//   _ganó_, dò_, _nhục_,
  { {0x2bf60063,0x629e3d3e,0x6f1c12b8,0x00000000}},	//   _המתן_, ípol, ärch,
  { {0x60c2017f,0x9f4c0290,0x660209db,0x00000000}},	//   _ovom, vedì_, gdok,
  { {0x44e00290,0x44e2008b,0x03a50769,0x00000000}},	//   gò_, _cư_, било,
  { {0x7a380080,0xdb0505dd,0x44e2008b,0x00000000}},	//   _víte, _behø, _dư_,
  { {0x9725006a,0x66022523,0x7e6d6adc,0x00000000}},	//   _افزو, bdok, _okap,
  { {0x7e6d00a4,0x44e001f4,0x7a380331,0x00000000}},	//   _nkap, bò_, _títe,
  { {0x44e00290,0xe5340121,0xafe50062,0x00000000}},	//   cò_, _деть, бопл,
  { {0x7870024a,0x12e70086,0x60c214d5,0x00000000}},	//   tävi, _відг, _dvom,
  { {0x6fd8016a,0x6e240025,0xfeb9007e,0x00000000}},	//   _मारू, _poib, داخت_,
  { {0x51950032,0x201e00c2,0x44256add,0x00000000}},	//   _الإذ, ajti_, _hol_,
  { {0x442500eb,0xc2030053,0x7c2500e0,0x00000000}},	//   _kol_, _शोएब_, _bohr,
  { {0x224d6ade,0x9f450072,0x7e9300dd,0x00000000}},	//   liek_, telä_, _săpu,
  { {0x9f950019,0xbddb6adf,0x44256ae0,0x00000000}},	//   _müük_, vièv, _mol_,
  { {0x224d6ae1,0xb87b0066,0x3e790003,0x00000000}},	//   niek_, _opís, péta_,
  { {0x19b90088,0x66000051,0x44e001a8,0x00000000}},	// [e920] русь_, _ramk, xò_,
  { {0x80cf0235,0x44e0051e,0x6600007a,0x00000000}},	//   _दिने, vò_, _samk,
  { {0x44e2001b,0x4fba0047,0x290b174c,0x00000000}},	//   _sư_, רזעצ, _erca_,
  { {0x3f7a00b5,0x44e00290,0x05ba01a7,0x00000000}},	//   אָדע, tò_, ادات_,
  { {0x44250024,0x44e0051e,0xe8df001b,0x00000000}},	//   _bol_, uò_, _phục_,
  { {0x44e06ae2,0x44256ae3,0xa5c60051,0x00000000}},	//   rò_, _col_, dróż,
  { {0x44e00290,0x224d0162,0x02a3000d,0x00000000}},	//   sò_, fiek_, прым,
  { {0x44e2001b,0x644d0164,0x44250025,0x00000000}},	//   _tư_, éair, _eol_,
  { {0xdced007d,0xb1130121,0x9f4c0066,0x00000000}},	//   _izać, змыш, redí_,
  { {0x7e6d02eb,0xd491001b,0xe29a000d,0x00000000}},	//   _skap, _gì_, _баж_,
  { {0x68e40019,0x7c250206,0xb4e80053,0x00000000}},	//   htid, _rohr, _बहु_,
  { {0x90e6006a,0x68e40004,0xad9b0025,0x00000000}},	//   _هستن, ktid, adún,
  { {0x412a019d,0x7e93000c,0x442501f7,0x00000000}},	//   _щодо_, _săpt, _yol_,
  { {0x629a10ca,0x80a4006a,0x3940001c,0x00000000}},	//   _kuto, _همچن, dzis_,
  { {0x63ba01f7,0xf1b908ea,0x290b074f,0x00000000}},	//   _metn, ljša_, _srca_,
  { {0x31790051,0x0f570063,0x26c70066,0x00000000}},	//   ższe_, _ליום_, ánom_,
  { {0x68e402eb,0xf1b900c3,0xe9180086,0x00000000}},	// [e930] gtid, njša_, боті_,
  { {0x629a021f,0x224d0122,0x26c70ffb,0x00000000}},	//   _outo, ziek_, šnom_,
  { {0x2baf0235,0x44256ae4,0x629a0078,0x00000000}},	//   _ज्या, _rol_, _nuto,
  { {0x44254379,0x64580b43,0x6382013d,0x00000000}},	//   _sol_, envi, zíné,
  { {0x224d0024,0x442513a6,0x68e46ae5,0x00000000}},	//   viek_, _pol_, ctid,
  { {0xb87b0024,0xdb1c00bd,0x3e790024,0x00000000}},	//   _vpís, rgrö, kéto_,
  { {0xd491001b,0x16350076,0x3e720080,0x00000000}},	//   _vì_, _девя, sáti_,
  { {0x64581b84,0xa4d50086,0x4425050c,0x00000000}},	//   anvi, _мобі, _wol_,
  { {0x54550189,0x44256ae6,0x23690051,0x00000000}},	//   _дват, _tol_, łaj_,
  { {0x224d6ae7,0xe0450086,0xe81c0053,0x00000000}},	//   siek_, інни, नाया_,
  { {0x7d0d01f7,0x765900ac,0x629a00a4,0x00000000}},	//   _aras, onwy, _guto,
  { {0x76590185,0x1d0a005a,0x7d0d6652,0x00000000}},	//   nnwy, аеми_, _bras,
  { {0xbddb0268,0x1ddb0053,0x3e56001c,0x00000000}},	//   vièt, _भारत, nāti_,
  { {0x61e92bab,0x7d0d6ae8,0xf0640054,0x00000000}},	//   lfel, _dras, _екіп,
  { {0x78ad0006,0x26c7007d,0x7d0d4610,0x00000000}},	//   epav, šnoj_, _eras,
  { {0x3940090d,0x7d0d6325,0x6e3d087d,0x00000000}},	//   tzis_, _fras, chsb,
  { {0x60250080,0x61e900bd,0xe9d7000d,0x00000000}},	// [e940] _témě, ifel, ўку_,
  { {0x63660024,0x3940000c,0x68e46ae9,0x00000000}},	//   nčné, rzis_, rtid,
  { {0xbddb03b2,0x63ba191f,0x7659001f,0x00000000}},	//   mièr, _retn, fnwy,
  { {0xbddb03b2,0x63ba44bf,0x61e9006f,0x00000000}},	//   lièr, _setn, jfel,
  { {0x3e56001c,0xdb1533bf,0xdb0700ea,0x00000000}},	//   gāti_, mazá, mbjá,
  { {0xbddb0164,0x48f900b5,0x76591cbf,0x00000000}},	//   nièr, _פּרא, anwy,
  { {0xdb1c006c,0x61e93c36,0x75d60044,0x00000000}},	//   faré, ffel, _ويسا,
  { {0x61e9000f,0x20050b33,0x3e56001c,0x00000000}},	//   gfel, edli_, bāti_,
  { {0x32020024,0x3ea9001c,0x7bdc01d2,0x00000000}},	//   ľky_, _čata_, kgru,
  { {0x3202016b,0xdb1c0110,0x629a4c35,0x00000000}},	//   žky_, parè, _tuto,
  { {0x2ca9569a,0x7bdc6aea,0xbddb0003,0x00000000}},	//   _stad_, dgru, dièr,
  { {0x98b20045,0xde59000d,0xdb070022,0x00000000}},	//   czyć_, самі_, zajó,
  { {0x7bdc00bd,0x5c0711ec,0xbddb006c,0x00000000}},	//   fgru, оява, fièr,
  { {0x26c70024,0x212b0199,0x7bdc6aeb,0x00000000}},	//   ánok_, äche_, ggru,
  { {0x7659001f,0x0dcb0da9,0x2bdc0053,0x00000000}},	//   ynwy, _купи_, _बारा,
  { {0x7d0d6aec,0x9999005a,0x7bdc008f,0x00000000}},	//   _tras, скат_, agru,
  { {0x7afc001f,0x29090072,0x7bdc5c07,0x00000000}},	// [e950] awrt, uvaa_, bgru,
  { {0x290900fe,0x57f4000d,0xbddb0003,0x00000000}},	//   rvaa_, мпут, cièr,
  { {0x56950076,0x290900fe,0x7a310137,0x00000000}},	//   чает, svaa_, _låti,
  { {0x3e56003d,0xfad60063,0xcad60063,0x00000000}},	//   tāti_, _צורך_, _צורת_,
  { {0x0608000d,0x7a3100d1,0x7659002b,0x00000000}},	//   ўнік_, _nåti, rnwy,
  { {0x03a50b3f,0x3e720014,0xe29955b4,0x00000000}},	//   чико, látt_, бак_,
  { {0x68f9005b,0x61e96aed,0x3e56008f,0x00000000}},	//   şadı, tfel, sāti_,
  { {0xa3ab016a,0x6282171d,0xbddb109c,0x00000000}},	//   _क्र_, _choo, zièr,
  { {0x98b20045,0x9f4c0024,0xc3cb013a,0x00000000}},	//   rzyć_, vedá_, _نظام_,
  { {0x61e90018,0x98b20051,0x2d9e0080,0x00000000}},	//   sfel, szyć_, ětem_,
  { {0xbddb0164,0xfd4d001b,0xdb1c0164,0x00000000}},	//   vièr, _triệ, paré,
  { {0x2003082a,0x62820025,0x24490022,0x00000000}},	//   žji_, _ghoo, dźmi_,
  { {0xbddb03b2,0xc19a014e,0xf1b900c3,0x00000000}},	//   tièr, _השני, ljšo_,
  { {0xc0040086,0xb06800f2,0x7bdc62d1,0x00000000}},	//   _опік, _وصول_, ugru,
  { {0xbddb0164,0xf1b900c2,0x7bdc46aa,0x00000000}},	//   rièr, njšo_, rgru,
  { {0x3e726aee,0xee3f0240,0xbddb0003,0x00000000}},	//   gátt_, chý_, sièr,
  { {0x39460088,0xbddb0003,0x7bdc01bb,0x00000000}},	// [e960] чнаг, pièr, pgru,
  { {0x3e720a63,0xa80302f8,0xb7da0cac,0x00000000}},	//   rátu_, нзул, صوصا_,
  { {0xbf79008b,0x63822725,0x7c650049,0x00000000}},	//   _đuốc_, _míní, _تايل,
  { {0x6aa3006d,0x998900c2,0xc869089e,0x00000000}},	//   _énfa, skaš_, אן_,
  { {0x539801d5,0xa4d80083,0x95c300de,0x00000000}},	//   овля_, ідку_, ريوه,
  { {0x62820969,0xd4990086,0x443a29bb,0x00000000}},	//   _shoo, ірі_, óp_,
  { {0x78a901f7,0xb0240013,0xdb0e04aa,0x00000000}},	//   _çevr, _nhườ, gabø,
  { {0x85e7005a,0x71460062,0x7a38013d,0x00000000}},	//   _ндсв_, зхож, _míto,
  { {0x3e56003d,0x7a38011b,0xe8110042,0x00000000}},	//   nātu_, _líto, _डोडा_,
  { {0x73e30001,0xdefa06bc,0x320a0051,0x00000000}},	//   _поуз, бым_, śby_,
  { {0x62820139,0x1df90766,0x833a1fc6,0x00000000}},	//   _thoo, оены_, _учат_,
  { {0x29020019,0xee3f0080,0x31790051,0x00000000}},	//   _oska_, uhý_, ższa_,
  { {0xe24501fb,0xa06a0b69,0x00000000,0x00000000}},	//   _تخلي, _лада_,   ,
  { {0x3e56008f,0x2d800022,0x8aa76aef,0x00000000}},	//   dātu_, _dzie_, зрад,
  { {0x7a380025,0x290200a5,0x7b6402fa,0x00000000}},	//   _vítn, _aska_, етте,
  { {0x9b580131,0x1f5b009a,0xaf5b009a,0x00000000}},	//   чист_, _לדוא, _לכוכ,
  { {0xdb260003,0xd5fb0013,0x3e720014,0x00000000}},	// [e970] _épît, _nhú, rátt_,
  { {0xf9900593,0xed58009a,0x718b009a,0x00000000}},	//   طبق_, _מבחר_, זְבַ,
  { {0x26c70080,0xa3c20053,0x61e2003b,0x00000000}},	//   éno_, ्णन_, _ocol,
  { {0xcf930047,0x3e56001c,0xe9190054,0x00000000}},	//   גטע_, bātu_, _домі_,
  { {0xd5fb00aa,0xe5340086,0xac740043,0x00000000}},	//   _chú, нець, _زایش,
  { {0x3e48000f,0x61e26af0,0xdb0701e1,0x00000000}},	//   lőtt_, _acol, rbjæ,
  { {0xd5fb008b,0x9474007e,0x82f40085,0x00000000}},	//   _thù, ردها, ечыц,
  { {0x394d007a,0x80a902a1,0x9f4c0072,0x00000000}},	//   _þess_, овив_, iedä_,
  { {0xa4d40086,0x7fd50726,0x62890139,0x00000000}},	//   _поті, міні, rmeo,
  { {0x60250086,0xb0240013,0x2c7601e1,0x00000000}},	//   єдна, _phườ, pædi_,
  { {0x3f910066,0x73c401fb,0x200b004c,0x00000000}},	//   äzu_, _سينم, ěci_,
  { {0x200b1112,0x7bc10026,0x249f004b,0x00000000}},	//   ści_, ðlun, _kuum_,
  { {0x61fb0035,0x00000000,0x00000000,0x00000000}},	//   meul,   ,   ,
  { {0xb024001b,0x61fb0159,0x3c340072,0x00000000}},	//   _thườ, leul, _kävi_,
  { {0xfc03005a,0x09e60086,0x60db0072,0x00000000}},	//   ъпро, мовн, luum,
  { {0x20076af1,0xed5a3acd,0x3e56008f,0x00000000}},	//   _hani_, _мой_, tātu_,
  { {0xdb1c0118,0x20070da5,0x7bc800ea,0x00000000}},	// [e980] marí, _kani_, ódus,
  { {0x7a380994,0xdb1c05d5,0x3e56008f,0x00000000}},	//   _títo, larí, rātu_,
  { {0x8c1b00b7,0x49ba0067,0x2ca0006f,0x00000000}},	//   _וויי, _واحد_, _huid_,
  { {0x2ca00004,0xdb1c006d,0xd5fb008b,0x00000000}},	//   _kuid_, narí, _phú,
  { {0x69c40805,0x64a30500,0x6d46004d,0x00000000}},	//   maie, вача, nzka,
  { {0x69c46af2,0x2ca06af3,0xdb1e0003,0x00000000}},	//   laie, _muid_, _repê,
  { {0xae0e0161,0x3e56003d,0x38a40cbf,0x00000000}},	//   ियान_, nāts_, _hör_,
  { {0x69c40164,0x38a440a3,0xd5fb008b,0x00000000}},	//   naie, _kör_, _thú,
  { {0x20072653,0x26c70066,0x3d180042,0x00000000}},	//   _bani_, ánov_, दमों_,
  { {0x200709f5,0xa0670259,0x69c40003,0x00000000}},	//   _cani_, мања_, haie,
  { {0x7d046af4,0x99800006,0xdb1c0026,0x00000000}},	//   _asis, okių_, farí,
  { {0x998000eb,0xdb1c09aa,0x3e56001c,0x00000000}},	//   nkių_, garí, dāts_,
  { {0x2ca00027,0x6026000a,0xad9b0025,0x00000000}},	//   _cuid_, _одда, ndúi,
  { {0x20070009,0x20560086,0x7a310137,0x00000000}},	//   _gani_, _ютер, _lått,
  { {0x7d0402f6,0xc108008b,0x442c6af5,0x00000000}},	//   _esis, _hỗ_, _mod_,
  { {0x38a401e3,0x442c0203,0xdb1c05ab,0x00000000}},	//   _bör_, _lod_, carí,
  { {0x764200f3,0x2007005b,0x6d460022,0x00000000}},	// [e990] dhoy, _yani_, czka,
  { {0x25bf0164,0x38a40137,0x3e56001c,0x00000000}},	//   _seul_, _dör_, bāts_,
  { {0x2ca00122,0x4439001c,0xc108008b,0x00000000}},	//   _zuid_, _ēs_, _lỗ_,
  { {0x38a42ddc,0x443e6af6,0xb8820080,0x00000000}},	//   _för_, _alt_, řípa,
  { {0x442c0c70,0x38a401e3,0x443e07b7,0x00000000}},	//   _bod_, _gör_, _blt_,
  { {0xd3780045,0x683200b9,0x442c6af7,0x00000000}},	//   _być_, _sædv, _cod_,
  { {0xdb1c017d,0x442c6af8,0x61fb003b,0x00000000}},	//   marã, _dod_, teul,
  { {0xdb1e0268,0x443e4083,0x4105005e,0x00000000}},	//   _depè, _elt_, езив,
  { {0x442c0c70,0xdb1c006d,0xd49b0086,0x00000000}},	//   _fod_, varí, _єра_,
  { {0x60db0019,0x44e91077,0x26c70114,0x00000000}},	//   ruum, mú_, šnou_,
  { {0x2ca0021f,0x64430027,0xdb1c6af9,0x00000000}},	//   _suid_, mhni, tarí,
  { {0x20070089,0x6d46004d,0x6609004b,0x00000000}},	//   _wani_, tzka, _jaek,
  { {0x69c40164,0x44e910c3,0xa2940086,0x00000000}},	//   vaie, nú_, _раці,
  { {0x31560063,0x38a400c7,0xdb1c006d,0x00000000}},	//   _אינן_, _rör_, sarí,
  { {0x442702b0,0x6d460045,0x8b040080,0x00000000}},	//   ijn_, szka, ěřov,
  { {0xdb2600ea,0x60c90035,0x7d040006,0x00000000}},	//   _épít, osem, _tsis,
  { {0x44e90024,0x69c402a7,0x8c960086,0x00000000}},	// [e9a0] jú_, raie, _проі,
  { {0x69c40164,0x44e910c3,0x644300c2,0x00000000}},	//   saie, dú_, jhni,
  { {0x9f4501a8,0x69c46afa,0x7642002b,0x00000000}},	//   meló_, paie, thoy,
  { {0x6676007e,0x443e0150,0xdb1e0003,0x00000000}},	//   ردار, _slt_, _repè,
  { {0x65940001,0xdb1c017d,0x443e0150,0x00000000}},	//   њалу, barã, _plt_,
  { {0xdb1c017d,0xa3ab0053,0x64430139,0x00000000}},	//   carã, कुल_, ghni,
  { {0xf7460002,0x60c93570,0x442c6afb,0x00000000}},	//   _џебо, esem, _vod_,
  { {0x99890024,0xe297018e,0x64430066,0x00000000}},	//   skať_, нај_, ahni,
  { {0x60f70088,0x442c00bd,0xe2130021,0x00000000}},	//   еныя_, _tod_, طبيع,
  { {0x63b30240,0xc1080013,0x64436afc,0x00000000}},	//   čení, _vỗ_, chni,
  { {0x60c95bc0,0x08570063,0xa2e50021,0x00000000}},	//   asem, תבים_, _لأنن,
  { {0x11e90021,0xdb1c017d,0x10a6005e,0x00000000}},	//   _يعني_, zarã, _зидн,
  { {0xe0d40047,0x0cab0062,0x60c93264,0x00000000}},	//   _סײַ_, ятни_, csem,
  { {0xdb1c017d,0xb3e00053,0x205402d7,0x00000000}},	//   xarã, नलिख, _шкля,
  { {0xad9b017d,0xdb1c017d,0xfa87005e,0x00000000}},	//   teúd, varã, ећам,
  { {0xa8a70daf,0x0f7b0063,0x8f7b009a,0x00000000}},	//   ержк, _מאוב, _מנוק,
  { {0xdb1c017d,0xd7fb000d,0x660935d6,0x00000000}},	// [e9b0] tarã, зуе_, _raek,
  { {0x44e90024,0xdb1c00cd,0x200c001f,0x00000000}},	//   vú_, barà, nddi_,
  { {0xd6db6afd,0xdb1c017d,0x7bc73552,0x00000000}},	//   ята_, rarã, maju,
  { {0xdb051b58,0xdb1c017d,0x44e918a8,0x00000000}},	//   _behö, sarã, tú_,
  { {0xdb1e0003,0x7e7d6afe,0x2907008f,0x00000000}},	//   _repé, ilsp, ānas_,
  { {0x44e96aff,0x7bc76b00,0x60c9004b,0x00000000}},	//   rú_, naju, vsem,
  { {0xf1b900c3,0x68ed0747,0x2fc502ab,0x00000000}},	//   ljši_, ltad, valg_,
  { {0x60c9037e,0x44e900ea,0x200c001f,0x00000000}},	//   tsem, pú_, eddi_,
  { {0xdb050199,0x60c90164,0xf1b900c3,0x00000000}},	//   _gehö, usem, njši_,
  { {0x60c93876,0x68ed0569,0x7bc76b01,0x00000000}},	//   rsem, itad, jaju,
  { {0x7bc7017f,0x9f45006d,0x60c96b02,0x00000000}},	//   daju, veló_, ssem,
  { {0xdb1c0118,0x60c90019,0x2fc506a5,0x00000000}},	//   jará, psem, salg_,
  { {0xdb1c6b03,0xc0e50094,0x00000000,0x00000000}},	//   dará, _ролк,   ,
  { {0x407900b5,0x3949001c,0x30790047,0x00000000}},	//   _קאַװ, dzas_, _קאַנ,
  { {0xbad50088,0x8f32000a,0x629c0003,0x00000000}},	//   літы, _вејц, _érot,
  { {0x3b070079,0xdb1c05d5,0xf2d200ff,0x00000000}},	//   њето_, gará, יעל_,
  { {0x68ed00a4,0x07a6000d,0x3e4f0051,0x00000000}},	// [e9c0] gtad, вазн, jęty_,
  { {0xfd5f008b,0xd9430259,0x7a381814,0x00000000}},	//   huyể, јефи, _míti,
  { {0x7a380026,0x76a90086,0x290f0137,0x00000000}},	//   _líti, етів_, ågar_,
  { {0xdb1c0942,0x9473007e,0x68ed00cd,0x00000000}},	//   cará, یدوا, btad,
  { {0xd4e30055,0x200c0185,0x39490051,0x00000000}},	//   ающи, yddi_, czas_,
  { {0x07a60fe2,0x7d16002b,0x3e790046,0x00000000}},	//   _јавн, _mrys, létt_,
  { {0x683205b9,0xfbd30063,0x32663510,0x00000000}},	//   _fædr, בתו_, ктив,
  { {0x22810026,0x644104bf,0xd7e20053,0x00000000}},	//   sókn_, _elli, _पाँच,
  { {0x7a38027d,0x64a60e87,0xf50a0062,0x00000000}},	//   _cíti, _раза, _юнал_,
  { {0xdb1c6b04,0x9f450290,0xd575000d,0x00000000}},	//   zará, velò_, _сусь,
  { {0x200c001f,0x7bc720da,0x48150047,0x00000000}},	//   rddi_, vaju, אַרן_,
  { {0xf7730063,0x200a01b3,0xdb1c006d,0x00000000}},	//   יקת_, žbi_, xará,
  { {0x7d1605b6,0xe0460962,0x7bc76b05,0x00000000}},	//   _crys, _инди, taju,
  { {0x7d16001f,0xd00f0021,0x00f70063,0x00000000}},	//   _drys, _ولن_, _סמוך_,
  { {0x7bc72600,0xdb1c6b06,0x629c0003,0x00000000}},	//   raju, tará, _éros,
  { {0x7bc70529,0x68ed6b07,0x64586b08,0x00000000}},	//   saju, ttad, hivi,
  { {0xdb1c02dd,0x7d161cc2,0x3ea9008f,0x00000000}},	// [e9d0] rará, _grys, _čati_,
  { {0x394902dd,0x68ed63e8,0x57b40086,0x00000000}},	//   rzas_, rtad, ибут,
  { {0x95d90076,0x3dd2001f,0x64582090,0x00000000}},	//   едет_, _ydyw_, divi,
  { {0x7bc500ac,0xe7ff0053,0x68ed1117,0x00000000}},	//   _hehu, _उसका_, ptad,
  { {0x58d4011c,0x89da014e,0x7bc56b09,0x00000000}},	//   _коят, _אחרי, _kehu,
  { {0x645800c7,0x3e4f0022,0x79820022,0x00000000}},	//   givi, ręty_, żowc,
  { {0x6e3d0031,0x7a380016,0x7bc53a62,0x00000000}},	//   kksb, _síti, _mehu,
  { {0xad9b1997,0x96f80571,0x6e3d00ca,0x00000000}},	//   ndús, _шест_, jksb,
  { {0x64580019,0xd0590086,0x16340086,0x00000000}},	//   bivi, ерні_, _тетя,
  { {0x7a380016,0x64416b0a,0x76590a8d,0x00000000}},	//   _víti, _ulli, liwy,
  { {0x8eb2005d,0x339b00de,0x00000000,0x00000000}},	//   یمیش, _آخذة_,   ,
  { {0x7d166b0b,0x7659002b,0x00000000,0x00000000}},	//   _prys, niwy,   ,
  { {0x681b001c,0x463a00b5,0x7bc53d5e,0x00000000}},	//   _kādē, גערע, _behu,
  { {0xd00606cb,0x3b0a0076,0x7d1600e8,0x00000000}},	//   _беше_, него_, _vrys,
  { {0xdea1005d,0x6b662ef3,0x6008009a,0x00000000}},	//   _دیجی, уква, _יִקְ,
  { {0x6e3d6b0c,0x6458007d,0x7d166b0d,0x00000000}},	//   cksb, zivi, _trys,
  { {0x7afb000c,0x7659001f,0x3e790026,0x00000000}},	// [e9e0] ăuta, diwy, rétt_,
  { {0x7bc53c1c,0x60db1aff,0x64586b0e,0x00000000}},	//   _gehu, irum, xivi,
  { {0x64586b0f,0x2a790150,0x98c5001c,0x00000000}},	//   vivi, _fksb_, ātās_,
  { {0x442200ea,0x60db4e31,0x16a706da,0x00000000}},	//   _ők_, krum, увци_,
  { {0x3936000d,0x69c60066,0x4254005d,0x00000000}},	//   _сэнс, _ieke, ینتر,
  { {0x60db6b10,0x64580003,0x69c62949,0x00000000}},	//   drum, uivi, _heke,
  { {0x69c606a7,0x7659002b,0x2b0d0042,0x00000000}},	//   _keke, biwy, हिएँ_,
  { {0x60f8005a,0x80cf0053,0xdb0700d1,0x00000000}},	//   вния_, _दिखे, rbjø,
  { {0x64580659,0x19570047,0x9f5e01a8,0x00000000}},	//   pivi, ָביל_, meté_,
  { {0xddd60066,0x69c639e6,0x9f5e6b11,0x00000000}},	//   _chyž, _leke, leté_,
  { {0x69c6006f,0x7bc56729,0xe0cf007e,0x00000000}},	//   _oeke, _rehu, يزی_,
  { {0xde59000d,0x71a6000d,0x9f5e0003,0x00000000}},	//   тамі_, _садз, neté_,
  { {0xd24f0032,0xd6570063,0x6e3d6b12,0x00000000}},	//   _عنه_, ריכת_, rksb,
  { {0x9f5e0003,0x76590022,0x62806b13,0x00000000}},	//   heté_, ziwy, llmo,
  { {0xab956b14,0x69c66b15,0x7a380014,0x00000000}},	//   рављ, _beke, _lítu,
  { {0x200e0026,0x9f5e0003,0xceb83164,0x00000000}},	//   _hafi_, jeté_, mpę_,
  { {0x2bcb0001,0x62806b16,0x1855000d,0x00000000}},	// [e9f0] _пуно_, ilmo, аваў,
  { {0xee3f0080,0x98480062,0x67d5071f,0x00000000}},	//   lký_, ляха_, рожу,
  { {0xb8680001,0x69c600ea,0x4c9a0063,0x00000000}},	//   ујте_, _feke, _שבתו,
  { {0x79820051,0x69c60da0,0xee3f011b,0x00000000}},	//   żowa, _geke, nký_,
  { {0x7659001f,0x8e980041,0xa50938b3,0x00000000}},	//   riwy, אדאו_, тела_,
  { {0x69c602b0,0x200e00e3,0x32d55217,0x00000000}},	//   _zeke, _nafi_, ацис,
  { {0x7659002b,0xe8df008d,0x8c1c009a,0x00000000}},	//   piwy, _biệc_, תווי,
  { {0xd5f900b5,0x7a380014,0xa3e70042,0x00000000}},	//   _שפּר, _fítu, _भाव_,
  { {0x681b003d,0x60db005b,0x66040019,0x00000000}},	//   _tādē, urum, õike,
  { {0x60db6b17,0x60c20022,0xb97c0041,0x00000000}},	//   rrum, _dwom, ענזי,
  { {0x3f6906b4,0x9e6601f8,0x0e660ef3,0x00000000}},	//   тино_, ивод, икон,
  { {0x290b078d,0x6fa70053,0x60db6134,0x00000000}},	//   _osca_, _फ़्रू, prum,
  { {0x69c66b18,0x3ea9008f,0x200e0072,0x00000000}},	//   _reke, _čatu_, ömiä_,
  { {0x69c66b19,0x8b660021,0x1d07005e,0x00000000}},	//   _seke, لازم, јери_,
  { {0x3f790047,0x69c63035,0xca56005e,0x00000000}},	//   _באַס, _peke, атањ,
  { {0xee3f0512,0xc3320063,0x6b630085,0x00000000}},	//   cký_, חול_, ікта,
  { {0x3ea76b1a,0x2fc76b1b,0x61f60058,0x00000000}},	// [ea00] _hunt_, _keng_, _öyle,
  { {0x3ea70b7d,0x69c60122,0x49990121,0x00000000}},	//   _kunt_, _weke, утся_,
  { {0xdb050146,0x3ea70268,0x69c66b1c,0x00000000}},	//   _afhæ, _junt_, _teke,
  { {0x3ea7007a,0xeef60047,0x320f6b1d,0x00000000}},	//   _munt_, ימער_, _nagy_,
  { {0x9f5e0164,0x24e70001,0x07a60590,0x00000000}},	//   reté_, имци_, _вагн,
  { {0x2baf0161,0x3ea00019,0x6280006f,0x00000000}},	//   _ज्ञा, _liit_, wlmo,
  { {0x96ba0001,0x68e46b1e,0x02a305ac,0x00000000}},	//   _југу_, luid, орым,
  { {0x7a380747,0x91b70062,0xa6950092,0x00000000}},	//   _títu, агът_, _груј,
  { {0xe8df00aa,0x3ea70034,0x68e40460,0x00000000}},	//   _việc_, _aunt_, nuid,
  { {0x7afe0031,0x249e00e3,0x78700072,0x00000000}},	//   _oppt, _uitm_, tävy,
  { {0x2d800089,0xe8df0013,0x3ea0004b,0x00000000}},	//   _ayie_, _tiệc_, _biit_,
  { {0x68e42410,0x16190082,0x333b009a,0x00000000}},	//   kuid, नएयर_, _שתאמ,
  { {0x78700072,0x2fc76b1f,0x3e720195,0x00000000}},	//   sävy, _feng_, náty_,
  { {0x2fc700e3,0xcc89006a,0x68e46b20,0x00000000}},	//   _geng_, انسه_, duid,
  { {0x224629e0,0x442e006f,0xa3ab0042,0x00000000}},	//   _klok_, ijf_, कुट_,
  { {0x9f9b0063,0xc98709c8,0x291910f5,0x00000000}},	//   _בסופ, аузи, _prsa_,
  { {0x68e400c5,0x97a7219b,0xddc60075,0x00000000}},	// [ea10] guid, арел, likş,
  { {0x29d7001b,0x7d0d1a61,0x3e72004c,0x00000000}},	//   ủa_, _isas, dáty_,
  { {0x78ba0080,0x22460150,0xd7f8005e,0x00000000}},	//   _čtve, _olok_, јуу_,
  { {0x32040045,0x68e40297,0x99890022,0x00000000}},	//   jemy_, buid, okaż_,
  { {0x320424ec,0x69cd004b,0x38c9007e,0x00000000}},	//   demy_, maae, _حاجی_,
  { {0x2246002c,0xdb1e0e7c,0x1cb80063,0x00000000}},	//   _alok_, _hepá, סלול_,
  { {0x68330080,0x22466b21,0xdb150331,0x00000000}},	//   _výdě, _blok_, mazó,
  { {0x3ea700c7,0x2019001c,0x7d0d0213,0x00000000}},	//   _runt_, ēsim_, _osas,
  { {0x3ea70469,0x2fc70fd1,0xca2a0047,0x00000000}},	//   _sunt_, _peng_, רופֿ,
  { {0x3ea00019,0x3ea76b22,0xd0090001,0x00000000}},	//   _siit_, _punt_, ћене_,
  { {0x3ea9001c,0x224600b9,0xa3ac0053,0x00000000}},	//   _čats_, _flok_, _गलत_,
  { {0x29090035,0x32040051,0xce4a005e,0x00000000}},	//   kwaa_, cemy_, узме_,
  { {0xdb150051,0x2fc76b23,0x361a0063,0x00000000}},	//   kazó, _teng_, אורד,
  { {0x557600b5,0x61e96b24,0x69cb0014,0x00000000}},	//   מערן_, lgel, ðgen,
  { {0x61e96b25,0x3ea00019,0xdb1c3115,0x00000000}},	//   ogel, _tiit_, larú,
  { {0x68e40942,0x61e96b26,0x20050606,0x00000000}},	//   tuid, ngel, leli_,
  { {0x6e246b27,0x61e94a33,0xf8aa04a0,0x00000000}},	// [ea20] _inib, igel, ادره_,
  { {0x68e46b28,0x7a386b29,0x20056b2a,0x00000000}},	//   ruid, _cítr, neli_,
  { {0x17790088,0x7afe3eef,0xd63a0086,0x00000000}},	//   асць_, _uppt, ляді_,
  { {0x7bce0397,0x61e90122,0x80d80053,0x00000000}},	//   labu, jgel, _मिले,
  { {0xdb05008b,0x644a5670,0x4e7b0047,0x00000000}},	//   _nghê, thfi, נאנצ,
  { {0x200506bb,0xed590024,0x7bce2983,0x00000000}},	//   jeli_, úži_, nabu,
  { {0x386f00ea,0x20056b2b,0x6e24002b,0x00000000}},	//   égre_, deli_, _onib,
  { {0x764b001f,0x61e948b4,0x7a38004c,0x00000000}},	//   chgy, ggel, _zítr,
  { {0x7bce15c1,0x754602d8,0x32045a0b,0x00000000}},	//   kabu, _уназ, remy_,
  { {0x200569ae,0x6e246b2c,0xa0540054,0x00000000}},	//   geli_, _anib, івні,
  { {0x8f340138,0x43860032,0x487b0063,0x00000000}},	//   ценц, _الاق, רטיס,
  { {0x3f82001c,0x9cf50086,0x479b009d,0x00000000}},	//   āku_, озмі, טייס,
  { {0x91e30499,0x2ca91ae7,0x20056b2d,0x00000000}},	//   _хоче, _quad_, beli_,
  { {0x50960138,0x20054988,0x9f5e6b2e,0x00000000}},	//   _уређ, celi_, letí_,
  { {0x1013007e,0x69cd01e1,0x9f4c0331,0x00000000}},	//   _ربود, taae, redó_,
  { {0x7f830021,0x7bce004b,0xeda70054,0x00000000}},	//   _علين, aabu, _ушко,
  { {0xec79005e,0x7d0d6b2f,0x2dd80021,0x00000000}},	// [ea30] упâ_, _usas, _طبية_,
  { {0xb3de0085,0x7bce6b30,0x4fb8009d,0x00000000}},	//   _жнiў, cabu, שֶּׂ,
  { {0xdb15293b,0x69cd00fe,0x7e6d00d1,0x00000000}},	//   razó, paae, _kjap,
  { {0x9f5e0080,0xceb30047,0x22810051,0x00000000}},	//   jetí_, ליע_, póki_,
  { {0x7ae70512,0x25fa0053,0x20050058,0x00000000}},	//   lujt, ोज़ी_, yeli_,
  { {0x2005000c,0x42d90ac5,0x61b30053,0x00000000}},	//   xeli_, афия_, ीर्ष,
  { {0x20056b31,0x2c7b004c,0x61e96b32,0x00000000}},	//   veli_, mádě_, tgel,
  { {0x7bce01d9,0x2a690019,0x61e906aa,0x00000000}},	//   zabu, nnab_, ugel,
  { {0x61e96b33,0xdb1c0026,0x21490013,0x00000000}},	//   rgel, rbré, ̉thư_,
  { {0xe5880063,0x61e96b34,0x7e6d004b,0x00000000}},	//   _הָעָ, sgel, _ajap,
  { {0x64430051,0x61e90229,0x20056b35,0x00000000}},	//   mkni, pgel, reli_,
  { {0x8e560086,0x7ae76b36,0x7c25002b,0x00000000}},	//   ітні, dujt, _anhr,
  { {0x7af500bd,0x7bce0bab,0x64486b37,0x00000000}},	//   etzt, tabu, _yldi,
  { {0x64433385,0x459a0041,0x764900a3,0x00000000}},	//   nkni, יסרע, _lley,
  { {0xea5a00d7,0x7bce6b38,0xa3e70053,0x00000000}},	//   арај_, rabu, _भाई_,
  { {0x6e241cb4,0x3eb80066,0x225f1556,0x00000000}},	//   _unib, írte_, niuk_,
  { {0x7bce00bb,0x38cb005d,0xdb07009c,0x00000000}},	// [ea40] pabu, لالی_, rcjá,
  { {0x76490058,0x4425004b,0xb9020042,0x00000000}},	//   _aley, _nnl_, _धि_,
  { {0xdb05008b,0x870a0121,0xd70a007f,0x00000000}},	//   _nghè, реев_, рнее_,
  { {0x9f5e00cd,0x5efa0047,0xd5b00049,0x00000000}},	//   xetí_, יפעד, رفت_,
  { {0x37c60044,0x00000000,0x00000000,0x00000000}},	//   _ويحف,   ,   ,
  { {0x68f600ac,0xd372007e,0x2bbf0053,0x00000000}},	//   mtyd, وهش_, ्रया,
  { {0x68f600e8,0x76491c8b,0xdc9b0041,0x00000000}},	//   ltyd, _fley, ביסל,
  { {0x76490026,0xcad70063,0x44250019,0x00000000}},	//   _gley, קופת_, _enl_,
  { {0x661d0026,0x32180080,0x68f64725,0x00000000}},	//   _óska, ěry_, ntyd,
  { {0x644301e3,0x3faa005e,0xdced0058,0x00000000}},	//   ckni, шњим_, _ayağ,
  { {0xc7b3014e,0xa6e7008b,0x7ae70566,0x00000000}},	//   ובת_, _ngừ, xujt,
  { {0x68f600e8,0x7ae70240,0xdb250003,0x00000000}},	//   ktyd, vujt, _épée,
  { {0xa06a0138,0x2257007e,0x212b004d,0x00000000}},	//   _када_, _بلند_, ächt_,
  { {0x7ae7073c,0x2d85008f,0x2bb80044,0x00000000}},	//   tujt, āle_, قافة_,
  { {0x68f613e5,0x9ee80021,0xaa950094,0x00000000}},	//   etyd, _افعل_, зивч,
  { {0x42db00b5,0x7ae70240,0x49bb14d7,0x00000000}},	//   יקלע, rujt, شارد_,
  { {0xb955005a,0x37ab6b39,0x64436b3a,0x00000000}},	// [ea50] чващ, атен_, ykni,
  { {0x7e7d00fe,0x7ae7004a,0x6604004b,0x00000000}},	//   losp, pujt, õikn,
  { {0x68f6005f,0xcd34005d,0x98481cdf,0x00000000}},	//   atyd, _فریب, цята_,
  { {0xbddb0003,0x7e7d6b3b,0x4efb0041,0x00000000}},	//   chèt, nosp, שלאג,
  { {0x442502a4,0xe534013c,0xc9840258,0x00000000}},	//   _pnl_, мець, _жури,
  { {0x7e7d6b3c,0xe4580054,0xe3b10044,0x00000000}},	//   hosp, ожі_, ررت_,
  { {0x644328d7,0x03a206da,0xdb1e004d,0x00000000}},	//   rkni, нишо, _gepä,
  { {0x27e9003b,0x765b005b,0xdbd70072,0x00000000}},	//   şină_, _umuy, lääk,
  { {0xf4870001,0x225f0089,0xc6920047,0x00000000}},	//   _дужн, riuk_, _טאל_,
  { {0x8f750086,0xc4d2009a,0x00000000,0x00000000}},	//   зумі, _נגב_,   ,
  { {0xd4980054,0xcce90aeb,0x2019004c,0x00000000}},	//   _єру_, _תכ_, ěsi_,
  { {0x3ea40cbf,0x12fa0063,0x39520022,0x00000000}},	//   ömt_, _להעב, yzys_,
  { {0xe1670021,0xaf35005d,0x00000000,0x00000000}},	//   _بداي, زرگت,   ,
  { {0x9f5e00cd,0x61fb6b3d,0x1d070141,0x00000000}},	//   betà_, lful, џери_,
  { {0xd00e043b,0xbddb0003,0x3af50121,0x00000000}},	//   _إلى_, thèt, мятс,
  { {0x68f600ac,0x61fb1fd9,0x2bb7004c,0x00000000}},	//   ttyd, nful, těcí_,
  { {0xdb1c006d,0xf8a70094,0xfd120044,0x00000000}},	// [ea60] mbrí, звук_, _أجب_,
  { {0xa3e70161,0x2bbf0053,0x68f66b3e,0x00000000}},	//   _भाग_, ्रणा, rtyd,
  { {0x39462174,0x68f66b3f,0x290f0026,0x00000000}},	//   šos_, styd, ægar_,
  { {0x8b8b089e,0x3a390130,0xcb8b009a,0x00000000}},	//   _לָכֶ, _gosp_, _לְכֹ,
  { {0xdb1c6b40,0x1a9b0047,0x69c46b41,0x00000000}},	//   ibrí, _ליטע, mbie,
  { {0xf8bf007a,0x9423005e,0xdb1c002b,0x00000000}},	//   _bréf_, емље, mbrâ,
  { {0xd25a005a,0x6ada0042,0x69c46b42,0x00000000}},	//   йци_, _बटोर, obie,
  { {0x69c44d5c,0x68e430b7,0x7d040646,0x00000000}},	//   nbie, orid, _opis,
  { {0x68e400e5,0xc4c50044,0x00000000,0x00000000}},	//   nrid, _يتكو,   ,
  { {0x9ed8000a,0x645d0006,0x68e46b43,0x00000000}},	//   омот_, _įsig, irid,
  { {0x68e40025,0x6d4000d1,0x7d0421db,0x00000000}},	//   hrid, øman, _apis,
  { {0x648d0027,0x68e43588,0x33050044,0x00000000}},	//   núin, krid, _تذكّ,
  { {0x62822af2,0xed58000d,0x127b0047,0x00000000}},	//   _ikoo, зоў_, _פאדע,
  { {0xbddb0164,0xdb1c006d,0xb911008b,0x00000000}},	//   thès, abrí, _thoả_,
  { {0x3ffb0063,0x6ffb0165,0xdddd001c,0x00000000}},	//   _הפוע, _ההופ, nosū,
  { {0xaa5814c6,0x68e432be,0x69c4004d,0x00000000}},	//   пису_, frid, gbie,
  { {0xdbd700fe,0x2bbf0053,0xed58005e,0x00000000}},	// [ea70] tääk, ्रदा, _ноћ_,
  { {0xbddb0164,0x37ab02b1,0xb814005e,0x00000000}},	//   chèr, стан_, ндуј,
  { {0x212b001b,0x68e40019,0xdbd70019,0x00000000}},	//   ̣ch_, arid, rääk,
  { {0x68e46b44,0x68f8013d,0xd6d80083,0x00000000}},	//   brid, éadá, яту_,
  { {0x3eae0312,0xddcd00b2,0x26d800b2,0x00000000}},	//   _luft_, _okaž, _evro_,
  { {0x0574007e,0x7d1d04aa,0x61fb0411,0x00000000}},	//   راند, ivss, wful,
  { {0x69cf0974,0x645d0006,0xb8830080,0x00000000}},	//   _kece, _įsid, řísp,
  { {0x42540121,0x00000000,0x00000000,0x00000000}},	//   етьт,   ,   ,
  { {0x61fb36c1,0x660b013d,0xfbbf0042,0x00000000}},	//   rful, megk, ्राम,
  { {0x69c42b8f,0x3e790066,0x69cf0150,0x00000000}},	//   zbie, méty_, _lece,
  { {0x7d046b45,0x69c40051,0x2d8c0051,0x00000000}},	//   _spis, ybie, ędem_,
  { {0xdb1c0026,0xf38c0047,0x69dd01e1,0x00000000}},	//   tarþ, _פראָ, _ndse,
  { {0x3e790066,0x76ac0058,0x628905a5,0x00000000}},	//   néty_, _işye, mleo,
  { {0x7d0400c3,0x78a7006f,0xe8df0013,0x00000000}},	//   _vpis, _nijv, _chọc_,
  { {0x7d040045,0xddcb007d,0x78bd1bba,0x00000000}},	//   _wpis, žišn, _atsv,
  { {0x7ae1000f,0x62890ddd,0x69c46b46,0x00000000}},	//   álta, nleo, ubie,
  { {0x78a702b0,0x7d04017f,0x629b0290,0x00000000}},	// [ea80] _bijv, _upis, imuo,
  { {0xb8f60161,0x9f880026,0x29de0013,0x00000000}},	//   _सब_, _kóði_, ữa_,
  { {0x69cf0b27,0xe61a16b4,0x79860022,0x00000000}},	//   _fece, жде_, _wykw,
  { {0xa3d00053,0x69cf5237,0xceb20149,0x00000000}},	//   _वजह_, _gece, דיא_,
  { {0xe5a3049f,0xd49a2e56,0x15ff0042,0x00000000}},	//   вици, орк_, ोज़र_,
  { {0x62823339,0x22b5001c,0xdb070b68,0x00000000}},	//   _skoo, _sāka_, rbjö,
  { {0x62890185,0xdb05008b,0xdb1c6b47,0x00000000}},	//   fleo, _nghì, maró,
  { {0x6114000a,0x3263000d,0xc1140d34,0x00000000}},	//   едиу, ктыв, емиј,
  { {0x95830336,0x3e79017c,0x22b50023,0x00000000}},	//   _алте, céty_, _vāka_,
  { {0x80060062,0x629b1d61,0x653b009a,0x00000000}},	//   фчие, amuo, _ועמד,
  { {0x3fc8007e,0x2bbf0053,0x61480014,0x00000000}},	//   يدگی_, ्रसा, félö,
  { {0x752d0024,0xbddb0003,0xe2460044,0x00000000}},	//   ťaze, thèq, _تخطي,
  { {0xdc3a01f7,0x69cf2951,0x62806b48,0x00000000}},	//   _açıl, _rece, momo,
  { {0x7d1d00b9,0x69cf0bab,0x3f87002b,0x00000000}},	//   rvss, _sece, _fynu_,
  { {0x69cf6b49,0x200c6b4a,0x2019008f,0x00000000}},	//   _pece, medi_, ēsit_,
  { {0xdb120025,0x200c6b4b,0x62806b4c,0x00000000}},	//   ógái, ledi_, nomo,
  { {0x69cf02dd,0x386f0003,0xe8df008d,0x00000000}},	// [ea90] _vece, égro_, _thọc_,
  { {0x200c6b4d,0x9cd8089e,0x648d0046,0x00000000}},	//   nedi_, _חוזה_, gúil,
  { {0xd6db0905,0x3ea90150,0x78a7006f,0x00000000}},	//   юта_, _kiat_, _vijv,
  { {0xb9350079,0x69dd0146,0x2bbf0053,0x00000000}},	//   _земј, _udse, ्रवा,
  { {0x62806b4e,0x660b0618,0x2ab500b9,0x00000000}},	//   domo, regk, _håb_,
  { {0x200c017f,0x7bc700c7,0xf8bf0164,0x00000000}},	//   jedi_, nbju, _crée_,
  { {0xe7840138,0x2292006a,0x27f80a63,0x00000000}},	//   _ауто, گليس, žený_,
  { {0x3ea9053b,0x6b6e013d,0x62806b4f,0x00000000}},	//   _niat_, lőgé, gomo,
  { {0x9f5e024a,0x629b0006,0xdb1c00cd,0x00000000}},	//   hetä_, rmuo, narò,
  { {0x629b00fe,0x200c27ca,0xaec50094,0x00000000}},	//   smuo, gedi_, нбол,
  { {0x6289006d,0x6280414d,0x00000000,0x00000000}},	//   pleo, bomo,   ,
  { {0x531a0063,0x9f5e0072,0x76590058,0x00000000}},	//   _מועצ, detä_, _çayı,
  { {0x61d6014e,0xc6920047,0x22ae0022,0x00000000}},	//   _נוסף_, טאט_, _ręki_,
  { {0x200c6b50,0x26dc0066,0x68ed12c7,0x00000000}},	//   cedi_, ávok_, duad,
  { {0xf8bf03d9,0x3ea90408,0xa3c20053,0x00000000}},	//   _até_, _fiat_, ूरत_,
  { {0xc3320132,0x3ea90360,0xf2d20047,0x00000000}},	//   נון_, _giat_, טעל_,
  { {0x68ed6b51,0x4c86064b,0xdb1c0022,0x00000000}},	// [eaa0] guad, _плив, taró,
  { {0x7e6601ec,0xeb9a0002,0x7bd5003b,0x00000000}},	//   likp, _нип_, cazu,
  { {0x6d466b52,0x2bf70063,0xbebc008f,0x00000000}},	//   lyka, _אמין_, rvīg,
  { {0xc8690063,0xd5a40043,0xdeba009a,0x00000000}},	//   זן_, نلای, למעל,
  { {0x68ed0942,0x62801507,0x7c3e6b53,0x00000000}},	//   cuad, vomo, _kopr,
  { {0x7c3e003d,0x69d60c44,0x28b50053,0x00000000}},	//   _jopr, laye, _अंति,
  { {0x38b602ab,0x200c4aee,0x6fd60053,0x00000000}},	//   _hær_, vedi_, _मजबू,
  { {0x69d6005b,0xd2570454,0x62800078,0x00000000}},	//   naye, ець_, uomo,
  { {0x200c22c7,0x50666b54,0xc1b7005d,0x00000000}},	//   tedi_, етна, رايط_,
  { {0x752d0024,0x69d60058,0x14d70063,0x00000000}},	//   ťazc, haye, _נובל_,
  { {0x628024e9,0x442c6b55,0x38b602ab,0x00000000}},	//   pomo, _ind_, _lær_,
  { {0x200c08ea,0xddcd0022,0x443e5381,0x00000000}},	//   sedi_, _ukaż, _hot_,
  { {0x443e0fbf,0x5c07011c,0x7afc00c2,0x00000000}},	//   _kot_, нява, etrt,
  { {0x7ae1000f,0x315700b5,0x7c3e12c9,0x00000000}},	//   álto, _אידן_, _copr,
  { {0x7bc700c7,0x443e6b56,0x6d466b57,0x00000000}},	//   rbju, _mot_, ayka,
  { {0x68ed1117,0x7bd5004c,0x25a9143a,0x00000000}},	//   tuad, sazu, žali_,
  { {0x442c0c70,0x6e2d353f,0x07e7005e,0x00000000}},	// [eab0] _ond_, _inab, ецем,
  { {0x443e03e9,0x2bee0053,0x75eb013d,0x00000000}},	//   _not_, _जाएं_, közü,
  { {0x6e2d004d,0xbbbf0053,0x68ed14fa,0x00000000}},	//   _knab, ्रीक, suad,
  { {0x442c3fa5,0x38b60026,0x7c3e00c2,0x00000000}},	//   _and_, _fær_, _zopr,
  { {0x68ed2777,0x38b60014,0x94793320,0x00000000}},	//   quad, _gær_, мску_,
  { {0xdddd0051,0x443e693e,0xe7870be8,0x00000000}},	//   nisł, _cot_, _зубо,
  { {0x6d460051,0x35b50121,0x443e6b58,0x00000000}},	//   zyka, _аббр, _dot_,
  { {0x442c6b59,0xd36e0021,0xd2980085,0x00000000}},	//   _end_, تهى_, нтыі_,
  { {0x8415005a,0x03f90001,0x443e6b5a,0x00000000}},	//   _имах, _онај_, _fot_,
  { {0x443e0780,0x661b1668,0x6e2d035a,0x00000000}},	//   _got_, _hauk, _anab,
  { {0x44fb3346,0x7c3e6512,0xdb1c0014,0x00000000}},	//   lê_, _ropr, jarð,
  { {0x7c3e6b5b,0x2f540376,0x6d4613e4,0x00000000}},	//   _sopr, утьс, tyka,
  { {0x7c3e6b5c,0x614502d8,0x0d9905ac,0x00000000}},	//   _popr, _јела, етры_,
  { {0x6d460051,0xafe50062,0x661b66b5,0x00000000}},	//   ryka, _рокл, _lauk,
  { {0x7c3e0066,0x44fb0013,0xdb1c0014,0x00000000}},	//   _vopr, hê_, garð,
  { {0x661b6b5d,0x6d466285,0x3eb7008f,0x00000000}},	//   _nauk, pyka, ēgtā_,
  { {0x69d63bf1,0x7c3e005b,0x7aee003b,0x00000000}},	// [eac0] raye, _topr, subt,
  { {0x69d603b2,0x38b602ab,0x0b460fc7,0x00000000}},	//   saye, _vær_, _анон,
  { {0x443e6b5e,0xd5af0cba,0xf8bf0003,0x00000000}},	//   _rot_, ис_, _préc_,
  { {0x60db0019,0x4438002b,0x443e6b5f,0x00000000}},	//   ksum, _ŵr_, _sot_,
  { {0x442c0089,0x443e516f,0xdbcd0014,0x00000000}},	//   _pnd_, _pot_, _kóðu,
  { {0x8d5b014e,0x7d09005b,0x60db0324,0x00000000}},	//   וכני, çesi, dsum,
  { {0x442c0199,0xdbcd0014,0x443e6b60,0x00000000}},	//   _vnd_, _móðu, _vot_,
  { {0x661b16f6,0x3f980014,0xdddd0022,0x00000000}},	//   _gauk, ýrum_, zisł,
  { {0xd0100032,0x44fb017d,0x60db00a4,0x00000000}},	//   ملة_, cê_, gsum,
  { {0x442c0cd4,0x6e2d6b61,0x7054007e,0x00000000}},	//   _und_, _snab, اندا,
  { {0x764002ae,0x60db0ba5,0x1df90895,0x00000000}},	//   _komy, asum, нены_,
  { {0xe8020161,0xdb1c0026,0xdd0e0053,0x00000000}},	//   र्ता_, varð, िबंध_,
  { {0xb8840080,0x3f820051,0x61e26b62,0x00000000}},	//   _zvíř, łku_, _idol,
  { {0xfc670062,0xdb1c0014,0x6d400072,0x00000000}},	//   тъмн, tarð, ämaa,
  { {0x44fb00be,0x0ff70044,0x1bd438ba,0x00000000}},	//   zê_, _شعوب_, рося,
  { {0x201c00ea,0xbdf50002,0xba740021,0x00000000}},	//   _havi_, _спиј, لاقت,
  { {0x661d0014,0x2d840058,0x7c320014,0x00000000}},	// [ead0] _óski, ümet_, ókrý,
  { {0x44fb017d,0xdbcd0026,0xf8bf0003,0x00000000}},	//   vê_, _góðu, _créa_,
  { {0x201c005b,0x61e204c8,0xb87b0331,0x00000000}},	//   _mavi_, _odol, _nvíe,
  { {0x60c209fb,0x36180086,0x44fb017d,0x00000000}},	//   _otom, кцію_, tê_,
  { {0x76400051,0xda5a0063,0x44fb3636,0x00000000}},	//   _domy, _נכשל, uê_,
  { {0x201c051e,0x61e26b63,0xd7c9007e,0x00000000}},	//   _navi_, _adol, _سوره_,
  { {0x60c26b64,0x661b6b65,0x9f9a004b,0x00000000}},	//   _atom, _tauk, _jääk_,
  { {0xdb1e0066,0x60db6b66,0xe78401ce,0x00000000}},	//   _nepý, tsum, _ђуро,
  { {0x61e20185,0x3949002c,0x00850076,0x00000000}},	//   _ddol, nyas_, ллио,
  { {0x201c0290,0xbfc5000d,0x60db06ee,0x00000000}},	//   _cavi_, ыбок, rsum,
  { {0xe8140161,0x481600b5,0x764000ac,0x00000000}},	//   ड़ता_, אַכן_, _yomy,
  { {0x29196b67,0x644125c9,0xed5a005e,0x00000000}},	//   _ossa_, _holi, еом_,
  { {0x644149a8,0x9e630085,0xfd1200de,0x00000000}},	//   _koli, свяд, حجج_,
  { {0x39490a9f,0x61e2232d,0x64416163,0x00000000}},	//   dyas_, _zdol, _joli,
  { {0x64410117,0x09e66b68,0xda9a005e,0x00000000}},	//   _moli, ловн, еђај_,
  { {0x7e6400a4,0x224d00ea,0x64416b69,0x00000000}},	//   _umip, nkek_, _loli,
  { {0xa9260085,0x0e9b009a,0x7e9b009a,0x00000000}},	// [eae0] ыдал, _אשקל, _אסקו,
  { {0x69cb0026,0x764000ac,0x64411e11,0x00000000}},	//   ðger, _somy, _noli,
  { {0x224d000f,0x29196b6a,0x7bfb0047,0x00000000}},	//   kkek_, _essa_, _אפיצ,
  { {0x31790051,0x56930086,0xe9df0139,0x00000000}},	//   ższy_, баєт, _dlús_,
  { {0xe5340b3f,0x752d0066,0x64416b6b,0x00000000}},	//   рель, ťazn, _boli,
  { {0xd92b0063,0x64412e47,0x75223d08,0x00000000}},	//   _אֵלָ, _coli, rvoz,
  { {0x29006b6c,0x3d160053,0x201c6b6d,0x00000000}},	//   ltia_, _पैसे_, _ravi_,
  { {0x7791007e,0xe5a636a9,0x64411fb2,0x00000000}},	//   _بیما, _биби, _eoli,
  { {0x30140088,0xdb1c017d,0x29006b6e,0x00000000}},	//   адпр, marõ, ntia_,
  { {0x93b50013,0x64416b6f,0xa0670092,0x00000000}},	//   _hãn, _goli, лања_,
  { {0xde590086,0x290000fe,0x60c200a4,0x00000000}},	//   вані_, htia_, _wtom,
  { {0x29000072,0x7054005d,0xe731009d,0x00000000}},	//   ktia_, انگا, קֵי_,
  { {0x60c26b70,0x40340074,0x9be70054,0x00000000}},	//   _utom, _велс, лівк,
  { {0x93b5008b,0x29190813,0x64580093,0x00000000}},	//   _lãn, _rssa_, nhvi,
  { {0xce95005a,0x2d8400bd,0xdb1c0003,0x00000000}},	//   _какъ, ümer_, ncrè,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x52d10042,0x394f0046,0x19580183,0x00000000}},	// [eaf0] _सब्स, ágs_, гаты_,
  { {0x7d0d00bb,0x64580066,0xad1a009a,0x00000000}},	//   _ipas, jhvi, _סותר,
  { {0x35b50138,0xdb1e0b23,0x29006b71,0x00000000}},	//   абер, _depó, atia_,
  { {0x2bbf0161,0x644103e1,0x6d5d0061,0x00000000}},	//   ्रका, _soli, ozsa,
  { {0x64411852,0x29006b72,0xa3c10053,0x00000000}},	//   _poli, ctia_, ंडल_,
  { {0x752d0066,0x6d5d008f,0x6721007d,0x00000000}},	//   ťazo, izsa, _šlju,
  { {0x64416b73,0x42551527,0xdb1c00be,0x00000000}},	//   _voli, итит, barõ,
  { {0x645800fe,0xdb1e00ea,0x7bd76b74,0x00000000}},	//   ahvi, _repü, _lexu,
  { {0xe0d60475,0x7659001f,0x64413e23,0x00000000}},	//   авы_, mhwy, _toli,
  { {0xd0090001,0x3e6f00fe,0x68ed5478,0x00000000}},	//   њене_, yötä_, irad,
  { {0xd3710032,0x68ed0114,0x7d0d6b75,0x00000000}},	//   _بها_, hrad, _apas,
  { {0xd1310021,0x7659001f,0x3f8e002b,0x00000000}},	//   _وما_, nhwy, _dyfu_,
  { {0x463a0047,0x52840021,0x661d0014,0x00000000}},	//   דערע, _النك, _ósku,
  { {0x7529007d,0x68ed6b76,0x60c96b77,0x00000000}},	//   _mrez, drad, mpem,
  { {0xdb1e017d,0x60c900d1,0x7d0d001c,0x00000000}},	//   _repó, lpem, _epas,
  { {0x60c90035,0x68ed6b78,0x29001798,0x00000000}},	//   opem, frad, ttia_,
  { {0x68ed6b79,0xf866167b,0x78662125,0x00000000}},	// [eb00] grad, авао, аказ,
  { {0x60c93d3a,0x29006b7a,0x8cdb009a,0x00000000}},	//   ipem, rtia_, _שחית,
  { {0x48790076,0x75296b7b,0x68ed6b7c,0x00000000}},	//   устя_, _arez, arad,
  { {0x752948dc,0x68ed00c5,0x64450072,0x00000000}},	//   _brez, brad, öhin,
  { {0x68ed05ab,0x7529053c,0xbcfb0003,0x00000000}},	//   crad, _crez, rzég,
  { {0x2c6d017f,0x3ce90053,0x7bdc6b7d,0x00000000}},	//   ožda_, _जिसे_, naru,
  { {0x66e30e0d,0x7529235d,0x60c9017e,0x00000000}},	//   _мора, _erez, epem,
  { {0x7bdc06a7,0x76591ac6,0x7aee0078,0x00000000}},	//   haru, chwy, irbt,
  { {0xdb1c0003,0x7aee00c2,0x6d400072,0x00000000}},	//   scrè, hrbt, ämal,
  { {0x7bdc0035,0x50380054,0xcfa60da9,0x00000000}},	//   jaru, упою_, ишни,
  { {0x7d0d6b7e,0xb7db0047,0x75292259,0x00000000}},	//   _spas, כקיי, _zrez,
  { {0xe4db0080,0xdceb00a8,0x6e675cef,0x00000000}},	//   zšíř, šičn, ртож,
  { {0x224b004d,0x8cf40085,0x71a6014b,0x00000000}},	//   öcke_, озяц, _тадз,
  { {0x3f8e001f,0x68ed6b7f,0x7bdc2806,0x00000000}},	//   _tyfu_, vrad, garu,
  { {0xab95575d,0xaa672007,0xea6701ce,0x00000000}},	//   сиві, атак, ањан,
  { {0x0f570063,0x68ed3ea0,0x645d0006,0x00000000}},	//   _כיום_, trad, _įsim,
  { {0x7d0d02ab,0x7bdc6b80,0x68ed67fa,0x00000000}},	// [eb10] _upas, baru, urad,
  { {0x68ed6b81,0x6ab701db,0x7bdc0f9d,0x00000000}},	//   rrad, _tuxf, caru,
  { {0x76590185,0xd126006a,0xfbd20063,0x00000000}},	//   thwy, _کم_, _מתי_,
  { {0x56950076,0x68ed6b82,0x75293d93,0x00000000}},	//   щает, prad, _prez,
  { {0x24f80121,0x95090021,0xe5700049,0x00000000}},	//   инцы_, اقتك_, وطه_,
  { {0x75296b83,0x44640054,0x63c80044,0x00000000}},	//   _vrez, овів, لِهِ_,
  { {0x03a50076,0xcb140041,0x43450094,0x00000000}},	//   щико, ַלץ_, сейв,
  { {0x3e72082a,0xa1150021,0x660906a5,0x00000000}},	//   ošte_, موعت, _ubek,
  { {0x0fd901e8,0x60c90003,0x7529007d,0x00000000}},	//   льны_, upem, _urez,
  { {0xdb1c0b6d,0xddc6004c,0x60c9006c,0x00000000}},	//   scré, tiků, rpem,
  { {0x7bdc6b84,0x0eaa0121,0x20050058,0x00000000}},	//   varu, лкой_, rfli_,
  { {0x60c96b85,0x02440021,0xf7720063,0x00000000}},	//   ppem, _وَلَ, לקי_,
  { {0xd0090001,0x645d0078,0x51870699,0x00000000}},	//   _беле_, _įsij, _тужа,
  { {0x0c790121,0x9f5e004c,0xe1f90078,0x00000000}},	//   ассы_, letý_, lgų_,
  { {0x648d0139,0x7bdc6b86,0x4fd6009a,0x00000000}},	//   lúis, raru, _הוצב_,
  { {0xe1f900eb,0xc3320063,0x6ec40021,0x00000000}},	//   ngų_, הול_, _بتوق,
  { {0x7bdc6b87,0x61e6013d,0xb87b0046,0x00000000}},	// [eb20] paru, ókli, _svía,
  { {0x6aa4004b,0xe73a6b88,0x00000000,0x00000000}},	//   smif, лез_,   ,
  { {0x46ea026b,0x2b50003b,0x648d0139,0x00000000}},	//   уден_, âncă_, húis,
  { {0x54e60021,0x9f58009c,0x5693012c,0x00000000}},	//   مستق, üré_, паєт,
  { {0xd6250032,0x6fe2004c,0xa3b40083,0x00000000}},	//   تعلي, nící, облі,
  { {0x6846026b,0x533414db,0x61330075,0x00000000}},	//   _унга, жект, zılö,
  { {0xdc9b0047,0x6d400072,0xb7db0063,0x00000000}},	//   װיקל, ämaj, _תקלי,
  { {0x3ce90053,0xd257066e,0x34b60043,0x00000000}},	//   _जिले_, йцы_, _همرز,
  { {0x6fe202f4,0xdfd00032,0xe3b2007e,0x00000000}},	//   jící, وية_, _فرا_,
  { {0x50b70021,0x3ea0330d,0x661d0026,0x00000000}},	//   حديد_, _ahit_, _óskr,
  { {0xe2ca011c,0x20020045,0xbfaa0076,0x00000000}},	//   _след_, ęki_, ытие_,
  { {0x91ba0021,0x3e72004c,0x539b0063,0x00000000}},	//   _إطار_, yšte_, _גיבו,
  { {0xbd6b0a8f,0x216701ce,0xc5f3009a,0x00000000}},	//   урне_, _лици_, הדר_,
  { {0xe0fb0063,0x645d0006,0x224600e5,0x00000000}},	//   _עלול, _įsik, _hook_,
  { {0x600b009d,0x00000000,0x00000000,0x00000000}},	//   _תִדְ,   ,   ,
  { {0x78ba0080,0x44d60051,0x2246004b,0x00000000}},	//   _čtvr, kł_, _jook_,
  { {0xbcfb013d,0xddcf00dd,0xd8bb0044,0x00000000}},	// [eb30] széb, ancţ, ادرا_,
  { {0x22460037,0x44d60051,0x26130013,0x00000000}},	//   _look_, dł_, _ảo_,
  { {0x625c0164,0xb09b0063,0xe1f90006,0x00000000}},	//   _géog, ניבר, ygų_,
  { {0x3e72017f,0x9f5e6b89,0x386a0003,0x00000000}},	//   pšte_, letó_, _embr_,
  { {0x04450002,0x44d60051,0x26c72401,0x00000000}},	//   желн, gł_, ūno_,
  { {0xd83b007f,0xe3b1009e,0xa3490131,0x00000000}},	//   _сэм_, ورث_, изла_,
  { {0x44d60045,0x22466b8a,0xf7700044,0x00000000}},	//   ał_, _book_, _كاف_,
  { {0xe1f900eb,0x22466b8b,0x90c507bf,0x00000000}},	//   ugų_, _cook_, обие,
  { {0x80390086,0x212b6b8c,0x84670062,0x00000000}},	//   аїну_, ích_, _лъже,
  { {0x648d0025,0x22b5008f,0x6fe2004c,0x00000000}},	//   rúis, _sāku_, vící,
  { {0xe80b0053,0x5334047e,0x244b01f2,0x00000000}},	//   स्या_, _нефт, _dømt_,
  { {0xa6e20014,0x99920022,0x6fe2004c,0x00000000}},	//   æðil, gdyś_, tící,
  { {0xafe50076,0xdb0a0066,0xe1f90078,0x00000000}},	//   _долл, ľník, siųs_,
  { {0xb87b0014,0xf1b2009f,0x3ea06b8d,0x00000000}},	//   _svín, _חסד_, _whit_,
  { {0x625c0003,0x3ea00025,0x6fe20080,0x00000000}},	//   _féod, _thit_, sící,
  { {0x44d60051,0x61fb6b8e,0x3ced007d,0x00000000}},	//   ył_, ngul, ševa_,
  { {0xe8fa1406,0x8bb60044,0x68460085,0x00000000}},	// [eb40] рлз_, _وإدا, онаа,
  { {0xb79601ce,0x40e8009a,0x00000000,0x00000000}},	//   орећ, מַעֲ,   ,
  { {0x6e2400bb,0x2bd00235,0x9f5e01f4,0x00000000}},	//   _kaib, _त्या, letò_,
  { {0xb87b007a,0x452a07bf,0x00000000,0x00000000}},	//   _hvíl, ижен_,   ,
  { {0x6e24002c,0x224607f3,0xa4d40054,0x00000000}},	//   _maib, _rook_, чолі,
  { {0xd4d90088,0x68e412f5,0x44d60051,0x00000000}},	//   сьці_, msid, rł_,
  { {0x224600a4,0x68e417c6,0xd25a0793,0x00000000}},	//   _pook_, lsid, ици_,
  { {0xd3780117,0x61fb3303,0x69c4344e,0x00000000}},	//   _neće_, ggul, ncie,
  { {0x22b5001c,0x601f0006,0xdddd0066,0x00000000}},	//   _sākt_, kšmė, nosť,
  { {0xbfaa019b,0x6e3600e5,0x68e4004b,0x00000000}},	//   итне_, _anyb, isid,
  { {0x22460034,0x64485277,0x38170063,0x00000000}},	//   _took_, _iodi, חקים_,
  { {0x28db0161,0x64480114,0x69c40051,0x00000000}},	//   मीडि, _hodi, jcie,
  { {0x61e001f7,0x99990066,0x244b01e1,0x00000000}},	//   maml, _kosť_, _tømt_,
  { {0x61e06b8f,0xdddd0024,0x68e412f5,0x00000000}},	//   laml, dosť, dsid,
  { {0x6e240164,0x9f5e006d,0x644807b9,0x00000000}},	//   _faib, retó_, _modi,
  { {0xddc401f7,0x64486b90,0x61e00046,0x00000000}},	//   _iliş, _lodi, naml,
  { {0xed580001,0x68e46b91,0x79c80593,0x00000000}},	// [eb50] _моћ_, gsid, توقف_,
  { {0xf72b0076,0x64486b92,0x69c46b93,0x00000000}},	//   ицей_, _nodi, acie,
  { {0x87e40055,0xddc66b94,0x61fb005b,0x00000000}},	//   ьюте, likš, ygul,
  { {0x68e46b95,0xfb1a0063,0x3e720606,0x00000000}},	//   bsid, _פורמ, ošta_,
  { {0x672e00c7,0x6448330c,0x27f60080,0x00000000}},	//   _erbj, _bodi, ádné_,
  { {0x7c250199,0x64482bbd,0x32d5000a,0x00000000}},	//   _jahr, _codi, пцис,
  { {0xd6c3006a,0x69dd0397,0x99990024,0x00000000}},	//   _آمری, _kese, _dosť_,
  { {0x22b5001c,0xe0d90076,0x6b7c11b4,0x00000000}},	//   _sāks_, бви_, ירונ,
  { {0x6e240027,0xe80b0161,0x69dd46a6,0x00000000}},	//   _raib, स्था_, _mese,
  { {0x64480117,0x6e2433ef,0x7e6d6b96,0x00000000}},	//   _godi, _saib, _amap,
  { {0x6e2400a4,0x69c40051,0xa207005b,0x00000000}},	//   _paib, ycie, şmış_,
  { {0x4425014f,0x44270034,0xe80b0053,0x00000000}},	//   _hal_, ldn_, स्ता_,
  { {0xd378017f,0x7c255d47,0x128a007e,0x00000000}},	//   _veće_, _bahr, _امنی_,
  { {0x8b080080,0xb042008b,0x64430137,0x00000000}},	//   jdří, _thưở, njni,
  { {0x69dd6b97,0x765b005b,0x442700e5,0x00000000}},	//   _bese, _oluy, idn_,
  { {0x78b5003d,0x2ee72f6d,0xdddd0066,0x00000000}},	//   _aizv, _ivnf_, tosť,
  { {0x7c256b98,0x69dd57f8,0x68e40006,0x00000000}},	// [eb60] _fahr, _dese, usid,
  { {0x3979019d,0x68e46b99,0xc079008b,0x00000000}},	//   істю_, rsid, _điệp_,
  { {0x3bbb0063,0x69c46b9a,0xdb1c004d,0x00000000}},	//   _למיד, pcie, nbrü,
  { {0x64486b9b,0x44250717,0x69dd5f6c,0x00000000}},	//   _sodi, _aal_, _gese,
  { {0x7bde0e53,0x27e14fb8,0x61e00058,0x00000000}},	//   _kepu, bahn_, vaml,
  { {0x44250994,0x7bde00e3,0x6abe00bd,0x00000000}},	//   _cal_, _jepu, _kupf,
  { {0x44256b9c,0x212f0025,0x765b006d,0x00000000}},	//   _dal_, _argh_, _fluy,
  { {0xcb130063,0x6443238b,0x44251384,0x00000000}},	//   גלה_, ajni, _eal_,
  { {0x64486b9d,0x645d0078,0x39520072,0x00000000}},	//   _todi, _įsiv, nyys_,
  { {0x394000cd,0x61e06460,0x20c00013,0x00000000}},	//   ixis_, saml, _vòi_,
  { {0xdb1c0244,0xd9a90042,0x00000000,0x00000000}},	//   gbrü, _कण्ट,   ,
  { {0x44256b9e,0x78600137,0x7c256b9f,0x00000000}},	//   _zal_, _hövd, _sahr,
  { {0x7d1d006f,0x69dd6239,0x02430044,0x00000000}},	//   uwss, _rese, _سَوَ,
  { {0x69dd0397,0xddc60078,0x3e720078,0x00000000}},	//   _sese, rikš, ršta_,
  { {0x9f6200fe,0x5f9300d7,0x7bde6ba0,0x00000000}},	//   ävän_, _пишт, _depu,
  { {0x7c250199,0x58d903d1,0xba990054,0x00000000}},	//   _wahr, ждая_, іває_,
  { {0x69dd6ba1,0x27e100a4,0x7c256ba2,0x00000000}},	// [eb70] _vese, tahn_, _tahr,
  { {0x69dd07c7,0x7bde1b26,0x7af20058,0x00000000}},	//   _wese, _gepu, üktü,
  { {0x44250f20,0xc05307e9,0x69dd6ba3,0x00000000}},	//   _ral_, עזע_, _tese,
  { {0x442510e9,0x7e7d05f8,0xf1c20078,0x00000000}},	//   _sal_, nnsp, nešę_,
  { {0x7e7d3b00,0x442506d3,0x6abe0244,0x00000000}},	//   insp, _pal_, _zupf,
  { {0x87070085,0x7bc70022,0xe3b1005d,0x00000000}},	//   _нябе, ncju, پرت_,
  { {0x290900fe,0x64430137,0xd5fb0013,0x00000000}},	//   ltaa_, rjni, _chụ,
  { {0x3a290052,0x44256ba4,0xe2910044,0x00000000}},	//   ndap_, _wal_, خذت_,
  { {0x2909024a,0x44256ba5,0x0019000d,0x00000000}},	//   ntaa_, _tal_, оўны_,
  { {0x8ee9137a,0x78600058,0xaec55610,0x00000000}},	//   омов_, _gövd, мбол,
  { {0x290900fe,0x7bde6ba6,0xf484045b,0x00000000}},	//   htaa_, _repu, _чутн,
  { {0x22420026,0x7bde168b,0x7e7d0838,0x00000000}},	//   ökkt_, _sepu, gnsp,
  { {0x2d84005b,0xdb1c004d,0xbcfb013d,0x00000000}},	//   çme_, sbrü, szén,
  { {0x786003e8,0x39520072,0x7e7d6ba7,0x00000000}},	//   _köve, vyys_, ansp,
  { {0x786000ea,0xab27006e,0x6e460021,0x00000000}},	//   _jöve, мора_, _ينتم,
  { {0xe80b0053,0x3e720078,0xceb8005f,0x00000000}},	//   स्सा_, mšto_, avęs_,
  { {0x7bde0397,0x7ae700ac,0x78601942,0x00000000}},	// [eb80] _tepu, asjt, _löve,
  { {0x3e72082a,0x786000a5,0x60cd0058,0x00000000}},	//   ošto_, _oöve, _çamu,
  { {0x7860000f,0xc6060088,0x395200fe,0x00000000}},	//   _növe, дзей, syys_,
  { {0xf8bf006d,0x7afc6ba8,0xe8020042,0x00000000}},	//   _fué_, murt, र्जा_,
  { {0xf8bf006c,0x94aa07a3,0x051a0044,0x00000000}},	//   _gué_, отка_, تزاع_,
  { {0xd5fb008b,0x62840006,0x3e720078,0x00000000}},	//   _phụ, čiom, kšto_,
  { {0x645d00eb,0x320d37b7,0xa294045b,0x00000000}},	//   _įsit, ffey_, накі,
  { {0x7217005a,0xc7a303d6,0xee3f0066,0x00000000}},	//   джър_, _риск, tmým_,
  { {0xf503011c,0x3e72007d,0x7afc05e7,0x00000000}},	//   _изто, ešto_, hurt,
  { {0x7afc00eb,0xc0570086,0x68f6002b,0x00000000}},	//   kurt, дію_, iryd,
  { {0xddc4007d,0x68f6002b,0xb87b0014,0x00000000}},	//   _smiš, hryd, _svík,
  { {0x68f60146,0x7afc6ba9,0xc7b30063,0x00000000}},	//   kryd, durt, כבת_,
  { {0xed580088,0x3e722e6a,0x5c070062,0x00000000}},	//   доў_, ašto_, мява,
  { {0xe571009f,0xd6df0022,0x40eb0063,0x00000000}},	//   אַל_, ółka_, _וַהֲ,
  { {0x6ffb0165,0x9e67005d,0x645836b7,0x00000000}},	//   _והופ, _يابن, ikvi,
  { {0x290909ff,0x68f6001f,0xda7b0054,0x00000000}},	//   ttaa_, fryd, іяв_,
  { {0xf8bf048e,0x645800d1,0xa3cf0053,0x00000000}},	// [eb90] _qué_, kkvi, वुड_,
  { {0x290900fe,0x7afc6baa,0x98a00078,0x00000000}},	//   rtaa_, burt, yvią_,
  { {0x2909024a,0x8bd6014e,0x628400eb,0x00000000}},	//   staa_, _אותו_, čioj,
  { {0xf8bf0164,0xfe10008b,0x68f66bab,0x00000000}},	//   _tué_, _lắng_, bryd,
  { {0xceb40063,0x6aad4d45,0xf1b9099e,0x00000000}},	//   דיף_, mmaf, neše_,
  { {0x3cfc0047,0xfe100013,0x645d0078,0x00000000}},	//   קלונ, _nắng_, _įsis,
  { {0x26070121,0xf7730c0a,0x00000000,0x00000000}},	//   _очаг, _شاس_,   ,
  { {0xfbb80063,0x64586bac,0x659537c4,0x00000000}},	//   ופות_, akvi, _забу,
  { {0xd378017f,0xf1b9007d,0xafe50a2f,0x00000000}},	//   _veća_, ješe_, нопл,
  { {0x60090175,0x752d0066,0x64586bad,0x00000000}},	//   чном_, ťazs, ckvi,
  { {0xbcfb000f,0x7d1600e8,0x4f790062,0x00000000}},	//   szél, _spys, ящия_,
  { {0x371600b5,0x3f99001c,0x2d960121,0x00000000}},	//   ײַטל_, āsu_, ергс,
  { {0x916c001b,0xee372127,0xd656009a,0x00000000}},	//   _gồm_, хня_, גירת_,
  { {0x629b0185,0xe0060053,0xfe10008b,0x00000000}},	//   lluo, _शायद_, _gắng_,
  { {0x6a86005a,0x6fd50042,0x629b0130,0x00000000}},	//   елва, _म्यू, oluo,
  { {0x7afc00bd,0x68f66bae,0x625c4fd1,0x00000000}},	//   rurt, tryd, _léon,
  { {0x69d62caa,0x6a830713,0x7afc3ced,0x00000000}},	// [eba0] rbye, улта, surt,
  { {0xb882027d,0x69d601f2,0x68f6002b,0x00000000}},	//   _čísl, sbye, rryd,
  { {0x629b0078,0xe61a23d6,0x7bdb009d,0x00000000}},	//   kluo, зде_, _מקיו,
  { {0xd9460854,0xcf920047,0x55066baf,0x00000000}},	//   _земи, נטא_, ечка,
  { {0x645d0078,0xceb30041,0xb26a01ce,0x00000000}},	//   _įsir, איא_, _наjв,
  { {0xdceb007d,0xd4670ae8,0x04432360,0x00000000}},	//   šićn, ниче_, лечн,
  { {0xc7950088,0x2795000d,0xfbd30063,0x00000000}},	//   _арты, _аштр, נתה_,
  { {0x2d9e0051,0x179b0149,0x64581679,0x00000000}},	//   ętej_, _זילב, skvi,
  { {0xe0cf007e,0x320a0022,0xc4860299,0x00000000}},	//   یزی_, ęby_, _злак,
  { {0x6602013d,0x649600dd,0xbf34012c,0x00000000}},	//   lgok, tâiu, внощ,
  { {0xfe100013,0x1df90895,0x3f980014,0x00000000}},	//   _vắng_, мены_, æru_,
  { {0x877b0149,0x66022762,0xde590085,0x00000000}},	//   לטיז, ngok, фамі_,
  { {0xfe6e006a,0x7c870081,0xc05a15ce,0x00000000}},	//   تگو_, еуве, _нік_,
  { {0x61e213d5,0xac2401ce,0xd12f0044,0x00000000}},	//   _heol, лфск, _دمه_,
  { {0xab951736,0x60c24bb8,0x6d400137,0x00000000}},	//   тављ, _huom, ämar,
  { {0x66e70080,0x26c70066,0x60c26bb0,0x00000000}},	//   _léká, ínom_, _kuom,
  { {0x6aad6bb1,0x60c20072,0xe918012c,0x00000000}},	// [ebb0] rmaf, _juom, ноті_,
  { {0x61e2001f,0x201e6bb2,0x75220022,0x00000000}},	//   _leol, neti_, dwoz,
  { {0x60c2024a,0x3ea90089,0xf8bf1090,0x00000000}},	//   _luom, _khat_, _prés_,
  { {0x201e000f,0xcad60063,0xa4d50054,0x00000000}},	//   heti_, _שורת_, воді,
  { {0x60c20006,0x5a34015a,0x201e6bb3,0x00000000}},	//   _nuom, _снят, keti_,
  { {0x201e0add,0x61e20168,0x6602013d,0x00000000}},	//   jeti_, _aeol, agok,
  { {0xe784005a,0x201e5efe,0x5c380063,0x00000000}},	//   _буто, deti_, תרון_,
  { {0x61e20025,0x3ea9008d,0xc105009e,0x00000000}},	//   _ceol, _nhat_, نوبي,
  { {0x74f80121,0xd24e0021,0x61e2155f,0x00000000}},	//   _петр_, تني_, _deol,
  { {0x60c200eb,0x3ea900a4,0x628033e4,0x00000000}},	//   _duom, _ahat_, anmo,
  { {0x200b0051,0xd4360047,0xf1d20053,0x00000000}},	//   ęci_, _שרעק_, _ध्वन,
  { {0x3255018e,0x74d80042,0x3ea96bb4,0x00000000}},	//   _швер, नीकृ, _chat_,
  { {0x26c3006d,0xd0090001,0x7ebe143b,0x00000000}},	//   _lujo_, _желе_, _rūpe,
  { {0xb4fa014e,0x61e26bb5,0x201e6bb6,0x00000000}},	//   ופשי, _zeol, ceti_,
  { {0xfe0a0161,0x3af50121,0x09e60f55,0x00000000}},	//   _वापस_, лятс, ковн,
  { {0xc0b90080,0x625c0003,0xad9b004c,0x00000000}},	//   řádá, _néol, rfúr,
  { {0x0d860002,0xbebc008f,0x661d0014,0x00000000}},	// [ebc0] _шлин, svīt, _ósky,
  { {0xbc6a007e,0x7d5707e9,0xed570063,0x00000000}},	//   _آمدن_, _סייד_, _סביר_,
  { {0x26c30016,0x4aaa0076,0x645d0006,0x00000000}},	//   _cujo_, _окон_, _įsip,
  { {0x66020078,0x7c2e6bb7,0x201e6bb8,0x00000000}},	//   ugok, ldbr, zeti_,
  { {0x2d8f0146,0x201e005b,0x61e2001f,0x00000000}},	//   _øget_, yeti_, _reol,
  { {0x29000009,0x61e26bb9,0x7c2e0b82,0x00000000}},	//   muia_, _seol, ndbr,
  { {0x60c26bba,0x65c601d5,0x29006bbb,0x00000000}},	//   _suom, _абба, luia_,
  { {0x625c0003,0x78bc6bbc,0x3ced0130,0x00000000}},	//   _géol, _hirv, ševi_,
  { {0x201e6bbd,0x290000dd,0x1a9b0041,0x00000000}},	//   teti_, nuia_, ויקע,
  { {0xb425007e,0xb0330121,0xa0670092,0x00000000}},	//   _معمو, аньш, кања_,
  { {0x442c0027,0x201e6bbe,0x61e26bbf,0x00000000}},	//   _iad_, reti_, _teol,
  { {0x442c0706,0xb87b0026,0x60c20c97,0x00000000}},	//   _had_, _hvít, _tuom,
  { {0x442c3740,0x4ea4000d,0xc6930063,0x00000000}},	//   _kad_, ррэа, שאר_,
  { {0x3ea90034,0xd366007e,0xd0100067,0x00000000}},	//   _what_, مه_, _طلب_,
  { {0x3ea903e9,0x1fa3005a,0x3b84000d,0x00000000}},	//   _that_, _кръг, алёг,
  { {0x442c41f4,0xfe0a0053,0xaa640062,0x00000000}},	//   _lad_, _वायस_, атук,
  { {0x443e03b2,0x2d8f0164,0x8d74006a,0x00000000}},	// [ebd0] _ont_, _âge_, _پايا,
  { {0xf1b90df9,0x442c6bc0,0x6e2d6bc1,0x00000000}},	//   neša_, _nad_, _haab,
  { {0xcc3a00b5,0x442e001f,0x6e2d6bc2,0x00000000}},	//   _װערט, ddf_, _kaab,
  { {0x443e1d56,0x2d8f00b9,0x2900000c,0x00000000}},	//   _ant_, _øges_, buia_,
  { {0x6e2d1040,0x442c6bc3,0x2900003b,0x00000000}},	//   _maab, _bad_, cuia_,
  { {0x442c0027,0x25a0017d,0x443e6bc4,0x00000000}},	//   _cad_, üila_, _cnt_,
  { {0x442c04bf,0x68ed1493,0xc5fb0021,0x00000000}},	//   _dad_, lsad, _يعرض_,
  { {0x6e2d0012,0x78bc005b,0x68ed6bc5,0x00000000}},	//   _naab, _zirv, osad,
  { {0x442c0027,0x64b501f7,0x3e620025,0x00000000}},	//   _fad_, eğiş, _nóta_,
  { {0x68ed6bc6,0x442c6bc7,0xb87b0046,0x00000000}},	//   isad, _gad_, _tvíu,
  { {0x5f050088,0x29000035,0x8ff9007e,0x00000000}},	//   ызна, zuia_, ورگر_,
  { {0x3e726bc8,0x43760047,0xb87b004c,0x00000000}},	//   ošti_, _גײען_, _zvít,
  { {0x61e96bc9,0x9294000d,0x2725002b,0x00000000}},	//   mael, _тацц, _lŷn_,
  { {0x68ed0146,0x6abd0139,0xbf650021,0x00000000}},	//   dsad, _aisf, _مدعو,
  { {0x6eca0161,0x7c2e6bca,0x68ed6bcb,0x00000000}},	//   _संयु, rdbr, esad,
  { {0xddcf000c,0x78bc6bcc,0x2900003b,0x00000000}},	//   ricţ, _sirv, tuia_,
  { {0x799d0185,0x7e641040,0x2d85005b,0x00000000}},	// [ebe0] _cysw, _ilip, şler_,
  { {0x2900000c,0x20c90013,0x7c3e6bcd,0x00000000}},	//   ruia_, _múi_, _unpr,
  { {0x2d8f0146,0x7e6443b1,0x20050290,0x00000000}},	//   _øger_, _klip, igli_,
  { {0x99800024,0x442c03bd,0x61e90d69,0x00000000}},	//   ediť_, _sad_, jael,
  { {0x20c9008b,0x68ed00ea,0x29000283,0x00000000}},	//   _núi_, csad, quia_,
  { {0x7bdc01a2,0xe2f80085,0x6f016bce,0x00000000}},	//   nbru, векі_, kulc,
  { {0x442c6bcf,0x7bdc00ac,0x443e00ac,0x00000000}},	//   _vad_, ibru, _vnt_,
  { {0x2005051e,0x82a60076,0xe297018e,0x00000000}},	//   egli_, ышле, лај_,
  { {0x7bdc0829,0x442c6bd0,0x6e2d4562,0x00000000}},	//   kbru, _tad_, _raab,
  { {0x6e2d0019,0xdefa03e6,0x1f14000d,0x00000000}},	//   _saab, ным_, амоў,
  { {0x7bdc02ea,0x61e9013d,0x68ed056c,0x00000000}},	//   dbru, bael, zsad,
  { {0x6e95019d,0x7bdc0102,0x20053834,0x00000000}},	//   риму, ebru, agli_,
  { {0x22930032,0x7bdc1b3c,0xcd070121,0x00000000}},	//   _النس, fbru, ычни,
  { {0x3e620025,0x6f010080,0x6e2d0035,0x00000000}},	//   _vóta_, bulc, _waab,
  { {0x7e640a61,0x309b0063,0x2aab005e,0x00000000}},	//   _flip, _רשומ, етао_,
  { {0x5bb80076,0x7e6441f5,0x68ed6bd1,0x00000000}},	//   улся_, _glip, tsad,
  { {0x9f4501c2,0x28f80121,0x7bdc323f,0x00000000}},	// [ebf0] valé_, леть_, bbru,
  { {0x2c661937,0xdb1f00ea,0x68ed6bd2,0x00000000}},	//   _pôde_, ívój, rsad,
  { {0x68ed6bd3,0x57a70002,0x7e640072,0x00000000}},	//   ssad, ушаа, _ylip,
  { {0xa5350002,0xaa59018b,0x56950121,0x00000000}},	//   инеч, _риму_, шает,
  { {0xd126014d,0x58870895,0x61e963f2,0x00000000}},	//   _بم_, _быва, vael,
  { {0xc4840097,0x200a00cd,0x82f5005e,0x00000000}},	//   блік, òbil_, ачиц,
  { {0x99800024,0x61e96bd4,0x9f51005b,0x00000000}},	//   rdiť_, tael, üzü_,
  { {0xb87b0014,0xe7840002,0x311509c2,0x00000000}},	//   _tvís, _ѓуро, афос,
  { {0x7bdc2f86,0x61e96bd5,0xf06514cd,0x00000000}},	//   ybru, rael, икип,
  { {0x20050290,0x3949017d,0x2a690222,0x00000000}},	//   ugli_, ixas_, hhab_,
  { {0xfe460055,0x2005051e,0x7bdc02f0,0x00000000}},	//   анно, rgli_, vbru,
  { {0xed5a6bd6,0x20c90013,0xd1cb0330,0x00000000}},	//   вом_, _túi_, _чужд_,
  { {0xc0e51d7c,0x7bdc328f,0x6284005f,0x00000000}},	//   _толк, tbru, čiot,
  { {0x224d00c3,0xdde5001c,0xddc40078,0x00000000}},	//   ljek_, āpša, _kliū,
  { {0xddcd01f7,0x7bdc410a,0xeb9a3510,0x00000000}},	//   _ulaş, rbru, тив_,
  { {0x3b07000a,0x7e640035,0x7bdc331d,0x00000000}},	//   јето_, _ulip, sbru,

  { {0x64416bd7,0x7bdc0031,0xf1b9008f,0x00000000}},	// [ec00] _onli, pbru, iešo_,
  { {0xddcd007d,0xb87b011b,0x6d3b009d,0x00000000}},	//   _imaš, _svír, _יתפנ,
  { {0x75e66bd8,0xbb460095,0x3949017d,0x00000000}},	//   аўле, _тенк, axas_,
  { {0xeabf0290,0x25a0017d,0x644106a3,0x00000000}},	//   _giù_, üilo_, _anli,
  { {0x96330088,0xe5340446,0xa5070062,0x00000000}},	//   ўніц, сель, иеца_,
  { {0xb6020080,0x5497000d,0x18a3130d,0x00000000}},	//   _řádk, авіў_, _маям,
  { {0x2480007d,0xdc370047,0xc3270044,0x00000000}},	//   đim_, שאצט_, لكون_,
  { {0xd2570055,0x64410924,0x3e72059d,0x00000000}},	//   ицы_, _enli, oštu_,
  { {0x26da00fe,0x26c70124,0x1098005e,0x00000000}},	//   lppo_, ínov_, лкић_,
  { {0x32ca001b,0x2a690089,0x200a004b,0x00000000}},	//   _tùy_, zhab_, übi_,
  { {0x50b70032,0xf8370063,0xb80b0053,0x00000000}},	//   جديد_, בנית_, स्टम_,
  { {0x62840006,0x3e720078,0xe37b009a,0x00000000}},	//   čios, kštu_, _ברבר,
  { {0x56b70041,0xeda701ce,0x0e34014b,0x00000000}},	//   יפטן_, ршно, цняю,
  { {0x515b0063,0xa067005e,0x2a60004b,0x00000000}},	//   _בכדו, _ваља_, ekib_,
  { {0xeabf02f6,0xee870055,0xdb580055,0x00000000}},	//   _più_, _выпо, ают_,
  { {0x59f80076,0x7afa0026,0x8f9b0063,0x00000000}},	//   иеся_, átta, _שיהי,
  { {0x7e7d699e,0x27c70121,0xfce4005e,0x00000000}},	// [ec10] misp, ащег, _доњо,
  { {0x7e7d6bd9,0xe9180054,0x1c390085,0x00000000}},	//   lisp, рофі_, _ёзны_,
  { {0xc5d50726,0x3e720078,0x6d5d6bda,0x00000000}},	//   біль, aštu_, lysa,
  { {0x7e7d6bdb,0x87080054,0xee32009a,0x00000000}},	//   nisp, реїв_, ּֽא_,
  { {0x224d017f,0xbcfb00ea,0x7ebf0078,0x00000000}},	//   vjek_, mzés, _lūpo,
  { {0x7e7d35dc,0xbcfb00ea,0x240902a1,0x00000000}},	//   hisp, lzés, унки_,
  { {0x7ebf001c,0xf8b200ff,0x7e7d0072,0x00000000}},	//   _rūpn, _משך_, kisp,
  { {0x5694126b,0xc2450e0d,0x41b40042,0x00000000}},	//   _даст, сник, ुशंस,
  { {0x224d00ac,0xa1120021,0x661b1acc,0x00000000}},	//   rjek_, كويت, _ibuk,
  { {0x442303e8,0x64410034,0x316d0045,0x00000000}},	//   _új_, _unli, rzez_,
  { {0x2054005a,0x5434007e,0xbcfb10fd,0x00000000}},	//   ютър, _برقر, zzét,
  { {0x6ed3000c,0x63bc013d,0x867a0041,0x00000000}},	//   _răbd, _úrna, ָרשו,
  { {0xd378017f,0x9f456bdc,0xd148005d,0x00000000}},	//   _reći_, malí_, _نشون_,
  { {0x7e7d0025,0xc0b2008b,0xc57a0041,0x00000000}},	//   aisp, _mười_, אָלט,
  { {0xcaa60021,0x661b007d,0x7e7d6bdd,0x00000000}},	//   مصري, _obuk, bisp,
  { {0xbcfb00ea,0x60db008f,0xe78a004c,0x00000000}},	//   gzés, opum, tíží,
  { {0xd378017f,0x39460016,0x2f1100ea,0x00000000}},	// [ec20] _veći_, ãos_, lág_,
  { {0x7d06024a,0x6e2600ea,0x2a606bde,0x00000000}},	//   muks, lekb, skib_,
  { {0x7cfe007a,0x9956001c,0x7d066bdf,0x00000000}},	//   _færð, _kļūt_, luks,
  { {0x69da000c,0x4ecc0047,0x66d40066,0x00000000}},	//   _ştef, דזאַ, eľký,
  { {0x753b6be0,0xc0b2008b,0x7d066be1,0x00000000}},	//   _cruz, _cười_, nuks,
  { {0x6aa4007a,0x7d060050,0x753b6be2,0x00000000}},	//   llif, iuks, _druz,
  { {0x753b0290,0x7d06004b,0xf487005d,0x00000000}},	//   _eruz, huks, حانی,
  { {0x60f80c07,0x29006be3,0x32540086,0x00000000}},	//   ания_, oria_, івпр,
  { {0x26ca2cd5,0x31340189,0xc05a013c,0x00000000}},	//   _hubo_, цепр, гін_,
  { {0x7d066be4,0x6aa4004d,0x29006be5,0x00000000}},	//   duks, hlif, iria_,
  { {0x6aa43cde,0x6d5d002b,0x9f450331,0x00000000}},	//   klif, wysa, balí_,
  { {0x6e67005a,0x6d5d00fe,0x6e26013d,0x00000000}},	//   стож, tysa, gekb,
  { {0xbcfb00ea,0x7e7d6be6,0x26ca0022,0x00000000}},	//   ezér, risp, _lubo_,
  { {0x26d86be7,0x29000268,0x7e7d21dc,0x00000000}},	//   _otro_, dria_, sisp,
  { {0xf3f1008b,0xbcfb00cd,0x290034a3,0x00000000}},	//   _học_, tzés, eria_,
  { {0x2bd90161,0x7d065ed4,0x290036bc,0x00000000}},	//   _ब्रा, buks, fria_,
  { {0xbcfb000f,0x29006be8,0xdd91007e,0x00000000}},	// [ec30] rzés, gria_, _زود_,
  { {0x26ca6be9,0xbcfb013d,0xd8770044,0x00000000}},	//   _bubo_, szés, حارب,
  { {0xf3f1008b,0x628501d9,0x29003dcd,0x00000000}},	//   _lọc_, éhok, aria_,
  { {0x7c2700b9,0x29001c6c,0x753b4812,0x00000000}},	//   lejr, bria_, _pruz,
  { {0x2f11000f,0x672e01e1,0x201c01a8,0x00000000}},	//   zág_, _esbj, _obvi_,
  { {0x26c76bea,0xf7730593,0x6e26013d,0x00000000}},	//   ínos_, _فاز_, zekb,
  { {0x8505005d,0x69db004e,0x4dfb0042,0x00000000}},	//   _ژورن, _õues, ्लाई_,
  { {0x6b7c0063,0x661b00a4,0xd378007d,0x00000000}},	//   טרונ, _ubuk, _neću_,
  { {0x7e8b0051,0xb1450054,0x6e26013d,0x00000000}},	//   tępn, інол, vekb,
  { {0xef190c45,0x63a10051,0x7d060072,0x00000000}},	//   амо_, _tyln, vuks,
  { {0x660b00d1,0x6e2600ea,0x7c270051,0x00000000}},	//   oggk, tekb, dejr,
  { {0x7d0609ff,0x6da60b3f,0x60db10f0,0x00000000}},	//   tuks, жима, ppum,
  { {0x2f11000f,0x9f470003,0x4427566d,0x00000000}},	//   ság_, _mené_, oen_,
  { {0x6e2600ea,0x7d066beb,0x6aa4002b,0x00000000}},	//   sekb, ruks, wlif,
  { {0xa09a0047,0x60cb0026,0x7bc80078,0x00000000}},	//   _דיסט, _hugm, žduo,
  { {0x62890027,0x44276bec,0x61eb00bd,0x00000000}},	//   nneo, hen_, _jegl,
  { {0x44271f3b,0xbcfb00ea,0x57ea2b4f,0x00000000}},	// [ec40] ken_, szér, идам_,
  { {0x44276bed,0x29001289,0x62890139,0x00000000}},	//   jen_, rria_, hneo,
  { {0xbc6a006a,0x60cb00ac,0xd6cf0021,0x00000000}},	//   _ممکن_, _lugm, نقل_,
  { {0x29006bee,0x61eb055b,0x249e0150,0x00000000}},	//   pria_, _negl, _sktm_,
  { {0x44276bef,0x6fc90042,0x28c30042,0x00000000}},	//   fen_, रशां, _वंचि,
  { {0x66e6455b,0x61eb0019,0x26ca0bec,0x00000000}},	//   _мога, _aegl, _tubo_,
  { {0x61eb00bd,0x60cb0da1,0x07a332e5,0x00000000}},	//   _begl, _augm, _жарн,
  { {0x62893331,0x60c30025,0x7c270051,0x00000000}},	//   gneo, _ainm, zejr,
  { {0x61eb02f6,0xfe7f00cd,0x44276bf0,0x00000000}},	//   _degl, viï_, ben_,
  { {0x60cb017f,0x44276bf1,0x3ea06bf2,0x00000000}},	//   _dugm, cen_, _akit_,
  { {0x26c40035,0x625c1f44,0x60c36bf3,0x00000000}},	//   _kimo_, _séou, _dinm,
  { {0x60c300bd,0x62890027,0x61eb2670,0x00000000}},	//   _einm, cneo, _gegl,
  { {0xd378017f,0xf3f10013,0x60c304aa,0x00000000}},	//   _veću_, _họa_, _finm,
  { {0x27170080,0x62806bf4,0x403409c8,0x00000000}},	//   něná_, limo, _хекс,
  { {0xcb340062,0x9f4501a8,0x60cb004d,0x00000000}},	//   меръ, calà_, _zugm,
  { {0x8cf5005a,0x7c2700b9,0x63a705b9,0x00000000}},	//   _езиц, sejr, _øjne,
  { {0x9f476bf5,0x3eb9004d,0x44276bf6,0x00000000}},	// [ec50] _rené_, mmst_, yen_,
  { {0x17fb0032,0x44276bf7,0x29880054,0x00000000}},	//   شرطة_, xen_, істо_,
  { {0x44276bf8,0xc5d50086,0x2717004c,0x00000000}},	//   ven_, піль, děná_,
  { {0x44276bf9,0x35b5005e,0x62801283,0x00000000}},	//   wen_, пбер, jimo,
  { {0x62806bfa,0x61eb6bfb,0x628901f2,0x00000000}},	//   dimo, _regl, vneo,
  { {0x61eb6bfc,0x44276bfd,0x25ad00c2,0x00000000}},	//   _segl, uen_, _vzel_,
  { {0x290900fe,0x44276bfe,0x96f8005e,0x00000000}},	//   luaa_, ren_, _мерт_,
  { {0x786000ea,0x7af500ea,0x6280193b,0x00000000}},	//   _rövi, iszt, gimo,
  { {0x44276bff,0x61eb0290,0x62896c00,0x00000000}},	//   pen_, _vegl, rneo,
  { {0xe5c415d4,0xd0090001,0x9f456c01,0x00000000}},	//   _істо, љене_, talà_,
  { {0x62806c02,0xf1b9008f,0x60c304aa,0x00000000}},	//   bimo, ieši_, _vinm,
  { {0x60cb002c,0x62806c03,0x200c00a4,0x00000000}},	//   _tugm, cimo, agdi_,
  { {0x60cb00a4,0x0d9a0121,0x7af50758,0x00000000}},	//   _uugm, стны_, eszt,
  { {0xc172014e,0x3e62007a,0x6ab40053,0x00000000}},	//   _אחד_, _móti_, ंग्र,
  { {0xe9df0026,0x09e62977,0xbb43200c,0x00000000}},	//   _snúa_, зобн, нерк,
  { {0x32d1001b,0x9f4505d5,0x5efa0063,0x00000000}},	//   _máy_, calá_, _הפקד,
  { {0x7af513d9,0x0906046e,0x09290044,0x00000000}},	// [ec60] aszt, япан, يسكي_,
  { {0x44e90045,0x62806c04,0xe8f70085,0x00000000}},	//   dź_, zimo, ялу_,
  { {0x25a4001f,0x6e36005b,0x3ec50058,0x00000000}},	//   _syml_, _kayb, _üstü_,
  { {0x62806c05,0x69b40042,0xfb250043,0x00000000}},	//   ximo, _आरपी, _کریپ,
  { {0x38b4004b,0x7546000d,0x2717004c,0x00000000}},	//   järg_, яндз, těná_,
  { {0x1c1f0042,0x9d1b009a,0x00000000,0x00000000}},	//   म्पल_, מונט,   ,
  { {0x6611024a,0x9f58005b,0x62806c06,0x00000000}},	//   ähkö, ürü_, timo,
  { {0xe6170076,0x38b40137,0x46a36c07,0x00000000}},	//   _ндс_, färg_, _засв,
  { {0x62806c08,0x9f4501d1,0xc5d50085,0x00000000}},	//   rimo, valá_, _цісь,
  { {0xc4c50021,0xf3f10013,0xee3f002b,0x00000000}},	//   _قتلو, _họn_, glýn_,
  { {0x6e362e10,0x64485682,0x9f45039f,0x00000000}},	//   _bayb, _indi, talá_,
  { {0x20020058,0x2c6f004d,0x645a6c09,0x00000000}},	//   şki_, _müde_, _hoti,
  { {0xfd470088,0x645a0659,0x99890066,0x00000000}},	//   чэнн, _koti, odať_,
  { {0x91bb014e,0xd3660021,0x625c0003,0x00000000}},	//   _המדי, نه_, _géor,
  { {0x7af5013d,0x645a6c0a,0xb17d017c,0x00000000}},	//   uszt, _moti, saťt,
  { {0x645a6c0b,0x7af5119b,0xbf650044,0x00000000}},	//   _loti, rszt, _تدهو,
  { {0xa3cc0053,0x64486c0c,0x986f008f,0x00000000}},	// [ec70] रखा_, _ondi, eļā_,
  { {0x7e6d085a,0x645a6c0d,0x7d28013d,0x00000000}},	//   _hlap, _noti, őssé,
  { {0xe6c7005d,0x9b95157f,0xab950054,0x00000000}},	//   ستاي, _цинц, _цині,
  { {0x644835c6,0x56940062,0x68f60022,0x00000000}},	//   _andi, нахт, bsyd,
  { {0x645a2275,0xd7e7000d,0x38b40137,0x00000000}},	//   _boti, _ніво, färd_,
  { {0x38b400c7,0xdfc60021,0x645a6c0e,0x00000000}},	//   gärd_, _لي_, _coti,
  { {0xf794000d,0x625c0003,0x87040121,0x00000000}},	//   _зарэ, _réor, _пяте,
  { {0x99890024,0xf3f10013,0xe0d90336,0x00000000}},	//   adať_, _gọn_, ови_,
  { {0x320d6c0f,0x31140085,0x03c70094,0x00000000}},	//   rgey_, нфэс, _есем,
  { {0x7e6d2846,0x7e84013d,0x645a6c10,0x00000000}},	//   _alap, dőpa, _goti,
  { {0x6fa90021,0x6808013d,0xf3670145,0x00000000}},	//   تهدف_, léjü, _этан,
  { {0x68f6001f,0x38b4004d,0xd1b8005d,0x00000000}},	//   ysyd, märe_, _کاما_,
  { {0x20180268,0x38b400bd,0xe1f00021,0x00000000}},	//   òric_, läre_, _إسم_,
  { {0x24890025,0x4e0a0053,0x60c4006c,0x00000000}},	//   éamh_, _वाकई_, _éimp,
  { {0x38b400bd,0xfaa6000d,0x9626008f,0x00000000}},	//   näre_, даво, _huņņ,
  { {0x1e95000d,0x786000a5,0x4e960044,0x00000000}},	//   _прыр, _lövt, _تشتر,
  { {0x38b400bd,0x9f470024,0xfaa33052,0x00000000}},	// [ec80] häre_, _mení_, тато,
  { {0x65620035,0x7ebf143b,0x625c6c11,0x00000000}},	//   vyoh, _rūpi, _léop,
  { {0xdb2400fe,0x38b401e9,0x645a6c12,0x00000000}},	//   äräs, värd_, _roti,
  { {0x9f470080,0x645a00fe,0x26dc001c,0x00000000}},	//   _není_, _soti, īvo_,
  { {0x6aa3017d,0x645a6c13,0x28af0042,0x00000000}},	//   _ênfa, _poti, _जीवि,
  { {0xd467100b,0x7d0663d1,0xf1b92886,0x00000000}},	//   миче_, irks, nešu_,
  { {0x645a6c14,0xb87b0014,0x9982004c,0x00000000}},	//   _voti, _stíg, _jakž_,
  { {0x32b70032,0xd2500021,0xd134005e,0x00000000}},	//   ودية_, انة_, енић,
  { {0x645a6c15,0x902a4222,0xd0100021,0x00000000}},	//   _toti, оцна_, هلة_,
  { {0x7e6d00eb,0x6448447f,0x15f80053,0x00000000}},	//   _slap, _undi, ुलकर_,
  { {0xd9ee0053,0xa0670002,0xc4c50021,0x00000000}},	//   जरात_, фаќа_, _ستكو,
  { {0x787200b9,0x625c0003,0x39421a62,0x00000000}},	//   _hævd, _géop, _orks_,
  { {0xb17d0066,0x3e620046,0x6eca0042,0x00000000}},	//   saťr, _nótu_, _संकु,
  { {0x212600e3,0x60dd2fcd,0xdddd004c,0x00000000}},	//   _ipoh_, ísme, pisů,
  { {0x69da000c,0x7d066c16,0x260f0053,0x00000000}},	//   _ştea, arks, _डाली_,
  { {0x2d9e003b,0xda7b000d,0x4efb0165,0x00000000}},	//   ştea_, цяг_, _ולהג,
  { {0xf770007e,0x63a80838,0xe77c004c,0x00000000}},	// [ec90] یام_, _lydn, výší,
  { {0x37ab0189,0x48ab046e,0xd117009a,0x00000000}},	//   отен_, ітам_, וקמה_,
  { {0xee3f011b,0x96fb00de,0x07f800de,0x00000000}},	//   hlým_, تعذر_, برقع_,
  { {0x645e6c17,0xd7df0053,0xddc4003b,0x00000000}},	//   öpin, _प्रच, _uliţ,
  { {0x2a690150,0x286b018e,0x5887000d,0x00000000}},	//   mkab_, _дрво_, _жыва,
  { {0x9475006a,0x344b047e,0x38b4004d,0x00000000}},	//   رگذا, ючен_, täre_,
  { {0x63a8001f,0x03a20054,0x3a39005f,0x00000000}},	//   _cydn, лишо, _kasp_,
  { {0x682e0051,0xda0f0053,0x98a00022,0x00000000}},	//   ródł, िलित_, twić_,
  { {0x10150088,0x3495183e,0xca1a009a,0x00000000}},	//   ньня, _заар, הֵיכ,
  { {0x2a69004e,0x00000000,0x00000000,0x00000000}},	//   hkab_,   ,   ,
  { {0x20180994,0x2a690019,0x1fa90062,0x00000000}},	//   òria_, kkab_, якои_,
  { {0x3e620014,0xc175089a,0x3619009a,0x00000000}},	//   _nótt_, _плещ, הוֹד,
  { {0x787200b9,0x8c96071f,0xf1ad0082,0x00000000}},	//   _hæve, ерві, फ़ेशन,
  { {0x7dfb0042,0x2f18013d,0x9999056c,0x00000000}},	//   ्लॉग_, bég_, _obsł_,
  { {0xd00e0032,0xf1b9001c,0xfe720021,0x00000000}},	//   _الى_, rešu_, _مدة_,
  { {0xba1a0044,0x9f7a009a,0xddc4011b,0x00000000}},	//   ثيرا_, _מנצח, _eliš,
  { {0x6e240537,0xc8ca0c0a,0x00000000,0x00000000}},	// [eca0] _ibib, سوان_,   ,
  { {0x9f4c0114,0x6d446c18,0xad1b009d,0x00000000}},	//   zadí_, _iria, _צויר,
  { {0x6d440066,0xdbc7004b,0x9f4c00be,0x00000000}},	//   _hria, _söök, madã_,
  { {0x63a805b9,0x7e8b0022,0x6d440078,0x00000000}},	//   _rydn, tępi, _kria,
  { {0xe5340b0f,0x63a822a4,0x9f4c01c8,0x00000000}},	//   тель, _sydn, vadí_,
  { {0x68e41127,0xf71a000d,0x7c2e0e57,0x00000000}},	//   mpid, _нібы_, nebr,
  { {0x39400611,0x68e46c19,0xf7430062,0x00000000}},	//   lvis_, lpid, _йеро,
  { {0xdbc70004,0x6d44001f,0x62d3007e,0x00000000}},	//   _töök, _oria, دآور,
  { {0x39400994,0x68e400fe,0x9f4c01d9,0x00000000}},	//   nvis_, npid, radí_,
  { {0x7c2e00b9,0xd250007e,0x945d0022,0x00000000}},	//   jebr, انک_, _duńs,
  { {0xdef70597,0x6d441afb,0x39400019,0x00000000}},	//   ныя_, _aria, hvis_,
  { {0x63a401f7,0xddc400c3,0x7c2e004b,0x00000000}},	//   ğind, _sliš, eebr,
  { {0x6d4403d9,0x2f18000f,0x442e00f5,0x00000000}},	//   _cria, ség_, oef_,
  { {0x3e620026,0xf1b9007d,0x39400f8c,0x00000000}},	//   _sótt_, rešt_, dvis_,
  { {0x6d440019,0xa6e7008b,0x2a69004b,0x00000000}},	//   _eria, _chứ, tkab_,
  { {0xb87b03ea,0x673b008f,0x442e6c1a,0x00000000}},	//   _otíc, _ņujo, hef_,
  { {0x39400307,0x99d40021,0x9f4c00cd,0x00000000}},	// [ecb0] gvis_, اتفا, ladà_,
  { {0x2a690425,0x6f08006f,0xa9c4015a,0x00000000}},	//   skab_, ordc, усск,
  { {0x442e01f7,0x9f4c0268,0x6d440066,0x00000000}},	//   def_, nadà_, _zria,
  { {0x442e0122,0xc8f50062,0x787200b9,0x00000000}},	//   eef_, _измъ, _ræve,
  { {0x6e3d0438,0xddec00b5,0x9f470024,0x00000000}},	//   idsb, פֿאָ, _mená_,
  { {0x7d1d00bd,0x26d10035,0x6aad6c1b,0x00000000}},	//   itss, _tuzo_, llaf,
  { {0xe2994c10,0x13090054,0x7d1d0244,0x00000000}},	//   мак_, єний_, htss,
  { {0x38b400c7,0x31250062,0x6e3d01af,0x00000000}},	//   mära_, вдиг, jdsb,
  { {0xd1790088,0x6e3d0031,0x38b400c7,0x00000000}},	//   ьскі_, ddsb, lära_,
  { {0x6aad00bd,0xf0650141,0xa4d40054,0x00000000}},	//   hlaf, ткоп, _софі,
  { {0x5f05005a,0x38b400c7,0x7d1d3c0e,0x00000000}},	//   ъзна, nära_, etss,
  { {0x6d440024,0xd6e80063,0x7d1d6c1c,0x00000000}},	//   _pria, עַתָ, ftss,
  { {0x7d1d00b9,0x61e9076b,0x7c2e6c1d,0x00000000}},	//   gtss, mbel, tebr,
  { {0x69dd6c1e,0xa6e70013,0x63a4003b,0x00000000}},	//   _afse, _phứ, şine,
  { {0xaed20002,0x7c2e0bea,0x2c740137,0x00000000}},	//   _којш, rebr, _rädd_,
  { {0xf2d20047,0x6d4431d1,0x61e96c1f,0x00000000}},	//   שען_, _tria, nbel,
  { {0x61e90ebe,0x6d446c20,0xba23005e,0x00000000}},	// [ecc0] ibel, _uria, јдук,
  { {0xa6e7008b,0x9f4c0024,0x68e46c21,0x00000000}},	//   _thứ, ladá_, rpid,
  { {0x38b400c7,0x68e4641c,0xd6d90086,0x00000000}},	//   gära_, spid, еті_,
  { {0x9f4c06b2,0x442e001f,0x68e40763,0x00000000}},	//   nadá_, wef_, ppid,
  { {0x7bdc0025,0x442e6c22,0x61e96c23,0x00000000}},	//   ocru, tef_, dbel,
  { {0x62824d4b,0x38b40137,0x61e953ea,0x00000000}},	//   _smoo, bära_, ebel,
  { {0x442e5c20,0x2327005e,0x7c23013d,0x00000000}},	//   ref_, воји_, _önre,
  { {0x32630076,0xddcd0080,0xe2970141,0x00000000}},	//   итыв, _smaž, кај_,
  { {0x28d80053,0xbebd0023,0x361b009a,0x00000000}},	//   _भूमि, ltīg, _קומד,
  { {0x9f4c00cd,0xdefa014c,0x244a0021,0x00000000}},	//   tadà_, мым_, _تجري_,
  { {0x61e96c24,0xbebd008f,0x2f140085,0x00000000}},	//   bbel, ntīg, ыднё,
  { {0x83fc007d,0x6e3d0104,0x7d1d6c25,0x00000000}},	//   _dođe, udsb, ttss,
  { {0xcd070062,0x6e3d6c26,0x9da80062,0x00000000}},	//   ъчни, rdsb, въра_,
  { {0xbebd001c,0x6d34005e,0xd2d10053,0x00000000}},	//   ktīg, јерф, _ढूँढ़,
  { {0x7b6402a1,0x7d1d0014,0x61e4004e,0x00000000}},	//   атте, stss, _õils,
  { {0x7e8b0051,0x63bc0025,0x6a780014,0x00000000}},	//   tępu, _úrnu, _líff,
  { {0xadf80032,0xd759006a,0x98b9000a,0x00000000}},	// [ecd0] _شريط_, کلات_, елат_,
  { {0x38b40137,0xc6e70086,0xb5fd6c27,0x00000000}},	//   tära_, відп, _moše,
  { {0x75296c28,0xb5fd007d,0x61e96ac8,0x00000000}},	//   _spez, _loše, ybel,
  { {0xb9e40086,0x38b40137,0x6908005b,0x00000000}},	//   _віри, rära_, ürdü,
  { {0xfd1f0290,0x7bc80006,0x15140054,0x00000000}},	//   ntì_, ždut, идця,
  { {0x38b4004b,0x83390121,0x00000000,0x00000000}},	//   pära_, ечит_,   ,
  { {0x82f40088,0x9f4500cd,0xc7c40086,0x00000000}},	//   ачыц, salú_, _всти,
  { {0x83fc0117,0xf3f1008b,0x6d41001c,0x00000000}},	//   _rođe, _mọi_, ālaj,
  { {0x90d5007e,0x61e96c29,0xdff51f89,0x00000000}},	//   دآبا, rbel, лянь,
  { {0x61e601f7,0x61e96c2a,0xd5b809c2,0x00000000}},	//   ıkla, sbel, _рсс_,
  { {0x63a4005b,0x8215009e,0x20540085,0x00000000}},	//   ğinc, _مواص, ртыр,
  { {0x83fc017f,0x2d9e003b,0x63a40058,0x00000000}},	//   _vođe, ştem_, şinc,
  { {0x78a5004b,0xd009019c,0x910529c2,0x00000000}},	//   kohv, _зеле_, _спле,
  { {0xddcb003b,0x7bdc003b,0x6abe0042,0x00000000}},	//   ţişa, ucru, ्द्र,
  { {0x9f4c01c2,0x78a50130,0x5a9631ab,0x00000000}},	//   padá_, dohv, граф,
  { {0x6289006f,0x6a7102fd,0x7bdc6280,0x00000000}},	//   nieo, _påfa, scru,
  { {0x39466c2b,0x2ba40042,0xcec0056c,0x00000000}},	// [ece0] íos_, _खुरा, łęsy_,
  { {0x7b09005b,0x2c66017c,0xbb760094,0x00000000}},	//   üstü, _pôdu_, _бумъ,
  { {0xf3f1008b,0x6aa40035,0x5c370aeb,0x00000000}},	//   _gọi_, poif, _גרין_,
  { {0xbebd001c,0xc8690063,0xceb3009a,0x00000000}},	//   rtīg, הן_, ֖יא_,
  { {0x24180121,0x7c3e6c2c,0xbebd008f,0x00000000}},	//   волы_, _kapr, stīg,
  { {0x9f47005b,0x64a30500,0x29120058,0x00000000}},	//   _genç_, бача, muya_,
  { {0x7c3e3881,0x29126c2d,0x7eb6004a,0x00000000}},	//   _mapr, luya_, zápa,
  { {0x7c3e00ea,0x26cd0013,0xb5fd6c2e,0x00000000}},	//   _lapr, _gieo_, _poše,
  { {0x92370001,0x291229ed,0x201a004e,0x00000000}},	//   учју_, nuya_, _öpik_,
  { {0x3ea96c2f,0x2018004b,0x7c3e407b,0x00000000}},	//   _skat_, üri_, _napr,
  { {0xa2e60edd,0x08570063,0x2912008d,0x00000000}},	//   _соед, אבים_, huya_,
  { {0x443e0359,0x7c3e00a4,0xd3370063,0x00000000}},	//   _hat_, _aapr, _תראה_,
  { {0x5c075898,0xa06a107a,0x5118000d,0x00000000}},	//   лява, _пада_, _ролю_,
  { {0xdfcf0032,0xfd1f0290,0x7c3e6c30,0x00000000}},	//   _فيه_, rtì_, _capr,
  { {0x8cd50053,0xfd1f0290,0x443e6c31,0x00000000}},	//   _यूरो, stì_, _mat_,
  { {0x5a35000a,0x443e6c32,0x25a90022,0x00000000}},	//   јнат, _lat_, żali_,
  { {0x57f5018e,0x3da40085,0x7c870896,0x00000000}},	// [ecf0] ипат, _грэб, _буне,
  { {0x290706bb,0x443e6c33,0x95ff0053,0x00000000}},	//   čna_, _nat_, ॉल्ट_,
  { {0x7fd70041,0xa5d5030b,0x0747014b,0x00000000}},	//   אובס_, ажеш, ыхам,
  { {0x29126c34,0x443e6c35,0x7c3e6b5c,0x00000000}},	//   buya_, _aat_, _zapr,
  { {0x26cd0035,0x59670062,0x2c74004b,0x00000000}},	//   _vieo_, _съна, _häda_,
  { {0x443e5c6b,0x78722a6d,0x0445013f,0x00000000}},	//   _cat_, _hævn, рекн,
  { {0xc3040021,0x62891ba8,0x443e2052,0x00000000}},	//   مبيو, tieo, _dat_,
  { {0x41050138,0x443e0034,0x78720146,0x00000000}},	//   азив, _eat_, _jævn,
  { {0x5455000d,0x443e2f77,0xbebd0023,0x00000000}},	//   _кват, _fat_, ktīb,
  { {0x443e6c36,0x63a4003b,0x0444005e,0x00000000}},	//   _gat_, şina, _леђн,
  { {0x6a78017d,0x00000000,0x00000000,0x00000000}},	//   _hífe,   ,   ,
  { {0x78720146,0x7c3e3fba,0x443e6c37,0x00000000}},	//   _nævn, _sapr, _zat_,
  { {0x7c3e00eb,0xa075000d,0x7ae50139,0x00000000}},	//   _papr, _выйш, _atht,
  { {0x443e0268,0xd0090184,0xa0664ae0,0x00000000}},	//   _xat_, _реке_, _ваша_,
  { {0x645e004b,0x6800004c,0x9ad60054,0x00000000}},	//   öpii, hájí, рюгі,
  { {0x7c3e00f3,0x99e60086,0x8f9a0063,0x00000000}},	//   _wapr, ржад, _ביצי,
  { {0x61fb0078,0x88860fce,0xe8fa0a7d,0x00000000}},	// [ed00] iaul, алаж, тлз_,
  { {0xb87b0139,0x61fb6c38,0x29126c39,0x00000000}},	//   _dtío, haul, ruya_,
  { {0x443e45f5,0xb87b12c7,0x29124bf9,0x00000000}},	//   _rat_, _etío, suya_,
  { {0x0bb7014e,0x89d50054,0x2912006c,0x00000000}},	//   _כלים_, _гірш, puya_,
  { {0x443e031c,0x61fb053b,0xceb30063,0x00000000}},	//   _pat_, daul, קיד_,
  { {0xddc40022,0xdddd004c,0x84380044,0x00000000}},	//   _bliź, misť, اكثر_,
  { {0xd4670138,0x443e0166,0x6d41001c,0x00000000}},	//   рије_, _vat_, ālai,
  { {0x443e6b18,0x44200080,0x61fb18a1,0x00000000}},	//   _wat_, ři_, gaul,
  { {0xb273019d,0x60f70088,0xb5aa0032,0x00000000}},	//   ільш, аныя_, _شارك_,
  { {0x2900024a,0x27f80205,0xe1ff006f,0x00000000}},	//   isia_, _jern_, óór_,
  { {0x752203e8,0x290000e3,0x7206006a,0x00000000}},	//   ltoz, hsia_, _نوام,
  { {0x290009ff,0x7ebd00ea,0xb5fd027c,0x00000000}},	//   ksia_, képe, _koša,
  { {0x752200ea,0x76401154,0xa1830121,0x00000000}},	//   ntoz, _mamy, _мышл,
  { {0x26d80016,0x7ebd0164,0x017b0063,0x00000000}},	//   _ouro_, dépe, _שָׁל,
  { {0xbebd003d,0x7e7603b1,0x6d460c7f,0x00000000}},	//   rtīb, _flyp, avka,
  { {0xbebd001c,0xadf50001,0x98a90051,0x00000000}},	//   stīb, _упиш, ować_,
  { {0xdebc014e,0x7ebd00ea,0x87e70021,0x00000000}},	// [ed10] _במהל, gépe, لثال,
  { {0x08540086,0x68e20139,0x9c3911da,0x00000000}},	//   овую, íoda, _спот_,
  { {0xec36014e,0xddcd000c,0x26d8002b,0x00000000}},	//   _האתר_, _flaţ, _curo_,
  { {0x36180086,0x83fc007d,0x26d86c3a,0x00000000}},	//   ицію_, _rođa, _duro_,
  { {0x61fb2f80,0x27f803a7,0x26d86c3b,0x00000000}},	//   vaul, _fern_, _euro_,
  { {0xb5fd017f,0xe81e0053,0x27f800bd,0x00000000}},	//   _doša, _पाया_, _gern_,
  { {0x96f80c09,0xf794000d,0x61fb6c3c,0x00000000}},	//   _вест_, _дарэ, taul,
  { {0x2d9e003b,0x76404fe8,0xeb980063,0x00000000}},	//   ştei_, _gamy, ידור_,
  { {0x61fb0c3f,0x753b011b,0x7158014b,0x00000000}},	//   raul, _usuz, арэс_,
  { {0xcea900b5,0xd3a71c9d,0x76400470,0x00000000}},	//   _װי_, _креп, _zamy,
  { {0x61e20185,0x5058000d,0x61fb6c3d,0x00000000}},	//   _ffol, ршыя_, paul,
  { {0x29006c3e,0x394b6c3f,0x64433588,0x00000000}},	//   ysia_, _orcs_, ldni,
  { {0x627b0051,0x3f8b0051,0x64416c40,0x00000000}},	//   głoś, ńcu_, _kali,
  { {0x225f000f,0x9f470b14,0x64436c41,0x00000000}},	//   ljuk_, _menú_, ndni,
  { {0x64416c42,0x394b6532,0x627b0022,0x00000000}},	//   _mali, _arcs_, ałoś,
  { {0x225f0397,0x2d84017d,0x316d0003,0x00000000}},	//   njuk_, úmes_, oyez_,
  { {0x29006c43,0xbebd008f,0x5e770063,0x00000000}},	// [ed20] usia_, stīc, _לתקן_,
  { {0xbddb0268,0x76400051,0x64416c44,0x00000000}},	//   ndèn, _samy, _nali,
  { {0x644300c7,0x27f82060,0x98a90022,0x00000000}},	//   ddni, _vern_, zwać_,
  { {0xb5fd0117,0x61f90034,0x6441002c,0x00000000}},	//   _poša, _newl, _aali,
  { {0x225f000f,0x64416c45,0x9f45027d,0x00000000}},	//   djuk_, _bali, valý_,
  { {0x7522000f,0x26d800a4,0x64a3000d,0x00000000}},	//   rtoz, _turo_, пача,
  { {0x64416c46,0x08770047,0x7eb6013d,0x00000000}},	//   _dali, _פעלט_, tápl,
  { {0x7d04017f,0x225f00ea,0x44270026,0x00000000}},	//   _ovis, gjuk_, afn_,
  { {0x315a0032,0x61fd0026,0xb5fd0b59,0x00000000}},	//   اجعة_, ðsla, _košn,
  { {0x225f00e3,0x64410498,0x0eea0086,0x00000000}},	//   ajuk_, _gali, льми_,
  { {0x7d046c47,0x6fb4007e,0x42ea01ce,0x00000000}},	//   _avis, تمدا, _смео_,
  { {0xc3b70047,0x64416c48,0x7e92008f,0x00000000}},	//   _פלאץ_, _zali, kāpu,
  { {0x64410009,0x2d9f0003,0x02430044,0x00000000}},	//   _yali, çue_, _رَوَ,
  { {0xb5fd0734,0x63ad004d,0x7d0434fb,0x00000000}},	//   _nošn, ßang, _dvis,
  { {0x2d84007a,0xeabf008b,0x5f9300e1,0x00000000}},	//   úmer_, _phù_, _ништ,
  { {0x7d0400b9,0x64435d1d,0xb9250021,0x00000000}},	//   _fvis, zdni, يفزي,
  { {0x6e2d00bb,0x7e7d0025,0xb5fd074f,0x00000000}},	// [ed30] _ibab, mhsp, _bošn,
  { {0x2a600397,0x27c70121,0xddcd02f7,0x00000000}},	//   ajib_, бщег, _glaš,
  { {0xeabf008b,0x7d040066,0x95d90121,0x00000000}},	//   _thù_, _zvis, адет_,
  { {0x64416c49,0xe8150053,0x442c6c4a,0x00000000}},	//   _sali, _ढाका_, _abd_,
  { {0x64416c4b,0xa3cb0053,0xc984005e,0x00000000}},	//   _pali, रेन_, _еури,
  { {0x83fc007d,0x68ed6c4c,0xd49b0121,0x00000000}},	//   _dođo, mpad, ыре_,
  { {0x225f000f,0x64414278,0x442c0150,0x00000000}},	//   tjuk_, _vali, _dbd_,
  { {0x64413f96,0x39492ae3,0x62650054,0x00000000}},	//   _wali, ovas_, івпа,
  { {0xe0d60088,0x225f00ea,0x39492238,0x00000000}},	//   овы_, rjuk_, nvas_,
  { {0xd0090001,0x6e2d6c4d,0x64416c4e,0x00000000}},	//   јене_, _abab, _uali,
  { {0x39490019,0x225f00ea,0x66090114,0x00000000}},	//   hvas_, pjuk_, _kdek,
  { {0x63ad0058,0x6d4d6c4f,0x68ed00ca,0x00000000}},	//   ğand, _braa, kpad,
  { {0xddcd003d,0x763a00b5,0x63ad005b,0x00000000}},	//   _plaš, בערג, şand,
  { {0xdfdb005a,0x7d046a13,0x6d4d6113,0x00000000}},	//   _съд_, _vvis, _draa,
  { {0x68ed0974,0xbb430088,0xbddb0003,0x00000000}},	//   epad, мерк, odèl,
  { {0x7e7d00bd,0x66096c50,0x394900a5,0x00000000}},	//   chsp, _ndek, fvas_,
  { {0x68ed00bb,0x6d4d0462,0x78660a1f,0x00000000}},	// [ed40] gpad, _graa, оказ,
  { {0xbebd008f,0xdd0f0058,0x66096c51,0x00000000}},	//   ntīn, lışv, _adek,
  { {0x3949001c,0xe73a0f64,0x68ed3ac7,0x00000000}},	//   avas_, рее_, apad,
  { {0xd62a14cf,0x8f9a0063,0xcf920063,0x00000000}},	//   роде_, ביעי, וטב_,
  { {0x44f30088,0x14f3000d,0x68ed008f,0x00000000}},	//   дпіс, дзіў, cpad,
  { {0x628b001f,0x86ea0021,0x83fc007d,0x00000000}},	//   _amgo, _نعرف_, _vođo,
  { {0xa6960092,0x969611da,0x6615013d,0x00000000}},	//   _драј, _драш, ágké,
  { {0xfbd3014e,0x60f80062,0xf484005d,0x00000000}},	//   ותו_, бния_, _کاری,
  { {0xa2da0235,0x93bc000c,0xc05a000d,0x00000000}},	//   _पूर्, _scăd, аін_,
  { {0xddc418c4,0x2d820066,0x39570063,0x00000000}},	//   _bliž, dzke_, קשים_,
  { {0x3ce93af5,0xf2060062,0xe7db0063,0x00000000}},	//   _stav_, _дяло, יקיש,
  { {0x6d4d166f,0x39490006,0xe292007e,0x00000000}},	//   _praa, yvas_, _غذا_,
  { {0x6ab66c52,0xe0180042,0xa3cb0042,0x00000000}},	//   dlyf, _दाऊद_, रेठ_,
  { {0x6d4d0173,0x68ed00a8,0x69b40042,0x00000000}},	//   _vraa, vpad, _आरजी,
  { {0x6d4d006f,0x628b002b,0xaa670fcc,0x00000000}},	//   _wraa, _ymgo, отак,
  { {0x6d4d406c,0x68ed007d,0x6ab66c53,0x00000000}},	//   _traa, tpad, glyf,
  { {0xdd91007e,0x3ce91310,0xb5fd073c,0x00000000}},	// [ed50] _سود_, _utav_, _došl,
  { {0xa3cb0235,0x68ed014f,0xdb0500fe,0x00000000}},	//   रेड_, rpad, _pyhä,
  { {0xc6a727c8,0x68ed6c54,0x2912017e,0x00000000}},	//   орди, spad, arya_,
  { {0x68ed1ed3,0xcb120047,0xc9870074,0x00000000}},	//   ppad, _אלט_, _дуги,
  { {0x73e5011c,0xd1260032,0x4a5a0063,0x00000000}},	//   полз, _ثم_, _הדרו,
  { {0x82f50062,0xb5fd011b,0x448816f2,0x00000000}},	//   пчиц, _tošo, обін_,
  { {0xbc7c009a,0xe61300de,0x00000000,0x00000000}},	//   שנות, _يشر_,   ,
  { {0xb87b0114,0x38b40072,0xb2220062,0x00000000}},	//   _stíh, väri_, емъл,
  { {0xe1f1005d,0xa63415ce,0x00000000,0x00000000}},	//   وسک_, _інфі,   ,
  { {0x38b4004b,0x50590062,0x6aad01d1,0x00000000}},	//   täri_, сшия_, hoaf,
  { {0x0eaa0121,0xbebd0023,0x8caf0042,0x00000000}},	//   йкой_, rtīn, ंकनो,
  { {0x6da61321,0xbebd008f,0x00000000,0x00000000}},	//   зима, stīn,   ,
  { {0xee3721b9,0x31580021,0x1c200042,0x00000000}},	//   чня_, _وجهة_, _बादल_,
  { {0x38b400fe,0x7ebd0003,0x629b3b8b,0x00000000}},	//   päri_, répa, lnuo,
  { {0xb5fd6417,0x7ebd0003,0x629b0078,0x00000000}},	//   _pošl, sépa, onuo,
  { {0x7ebd00ea,0x6d400026,0xe9da0571,0x00000000}},	//   lépn, æmas, ска_,
  { {0xfc320021,0x6ab6002b,0x6ec50021,0x00000000}},	// [ed60] _كحد_, rlyf, _تتوق,
  { {0x49990086,0x07a61dfd,0x65640050,0x00000000}},	//   іття_, пазн, äihm,
  { {0x25bf06b2,0x7d060f8c,0xa6ca005d,0x00000000}},	//   _azul_, lsks, موئل_,
  { {0x56930086,0xbddb006c,0x38b4004b,0x00000000}},	//   наєт, ydèm, järv_,
  { {0x48e319bb,0x27ef004c,0x60c3004d,0x00000000}},	//   _появ, ílné_, _ohnm,
  { {0xd8380061,0x629b5c1b,0xa9bb009a,0x00000000}},	//   _úč_, enuo, _לזכר,
  { {0x4367018e,0x987b0041,0xeb92009a,0x00000000}},	//   зајн_, _פאלט, ךָ֗_,
  { {0x629b0290,0xddc40051,0xd6273320,0x00000000}},	//   gnuo, _bliż, _носе_,
  { {0x798400ac,0x93bc00dd,0xdfda0062,0x00000000}},	//   nziw, _abăt, йън_,
  { {0x2fd80d02,0x44e20026,0x44386c55,0x00000000}},	//   ørg_, _ið_, _úr_,
  { {0xdfd00049,0xd9b90082,0x09b90082,0x00000000}},	//   ضيح_, _आर्ट, _आर्य,
  { {0x66020035,0x59be0053,0xde59000d,0x00000000}},	//   naok, ्धार, цамі_,
  { {0xc0ca005e,0x91ba0044,0x00000000,0x00000000}},	//   _луке_, _اطار_,   ,
  { {0x6ab50161,0x79840051,0xdcb10013,0x00000000}},	//   ंत्र, dziw, ổ_,
  { {0x39420034,0x6d400026,0xb87b0066,0x00000000}},	//   _asks_, æmar, _ktív,
  { {0x69da0529,0x201e0006,0xd3570047,0x00000000}},	//   _şter, lgti_, הילי_,
  { {0xf993007e,0x19580085,0x7ebd006c,0x00000000}},	// [ed70] ربر_, паты_, lépo,
  { {0x201e00eb,0xd83e00c2,0x3eb96c56,0x00000000}},	//   ngti_, ščne_, llst_,
  { {0x44e26c57,0x629b0051,0xb87b017d,0x00000000}},	//   _að_, ynuo, _ruíd,
  { {0x6b9a0014,0x78730058,0x19590183,0x00000000}},	//   útge, _sıvı, _дамы_,
  { {0x04450189,0xa509000d,0xd4693119,0x00000000}},	//   делн, цела_, жиле_,
  { {0x629e0164,0x7eb63c09,0x6a780014,0x00000000}},	//   épon, rápi, _lífl,
  { {0x44e20026,0xe6950121,0x49190042,0x00000000}},	//   _eð_, _живы, यूरो_,
  { {0xb5fd00c3,0x201e276c,0x386a0061,0x00000000}},	//   _mošk, egti_, _zobr_,
  { {0xb5fd00c2,0x25bf003b,0x629b005f,0x00000000}},	//   _lošk, _uzul_, rnuo,
  { {0x20890054,0xbebd008f,0x62806c58,0x00000000}},	//   ійни_, stīl, ahmo,
  { {0xbea6000d,0x38b40137,0x0fc50054,0x00000000}},	//   данк, märt_, ьйон,
  { {0x38b4092e,0x62806c59,0xbebd008f,0x00000000}},	//   lärt_, chmo, ltīj,
  { {0x61451499,0xd0092c9e,0x7d06004b,0x00000000}},	//   _цела, _деле_, usks,
  { {0x38b40137,0x7d0604aa,0xb5fd007d,0x00000000}},	//   närt_, rsks, _bošk,
  { {0x20180024,0xbebd001c,0x09e66c5a,0x00000000}},	//   órie_, itīj, добн,
  { {0xc3320063,0x25b20051,0x9f476c5b,0x00000000}},	//   כול_, żyli_, _menü_,
  { {0x63a404ab,0x9f5e5f9c,0xddcd01d1,0x00000000}},	// [ed80] ğini, vaté_, _plať,
  { {0x63a46c5c,0x6d4425e5,0x38b40137,0x00000000}},	//   şini, _isia, järt_,
  { {0x9f5e0164,0x7c3c1df5,0x7883004c,0x00000000}},	//   taté_, merr, důvě,
  { {0x386a001f,0x7c2e536a,0x3ce0004b,0x00000000}},	//   _wobr_, lfbr, _kuiv_,
  { {0xa3cb0161,0x3935000d,0x66026c5d,0x00000000}},	//   रेस_, _пэрс, raok,
  { {0x38b400c7,0xe8e0008d,0x7c3c63d2,0x00000000}},	//   gärt_, _quỵt_, nerr,
  { {0x62806777,0xf7430121,0x7c3c6c5e,0x00000000}},	//   thmo, _иеро, ierr,
  { {0xda7b0047,0x7c3c3363,0x60f80062,0x00000000}},	//   ַניר, herr, пния_,
  { {0xa2da0053,0x14260002,0x7c3c6c5f,0x00000000}},	//   _पंक्, _одам, kerr,
  { {0x63ad005b,0x7c3c6c60,0x66000137,0x00000000}},	//   şana, jerr, _hemk,
  { {0x7c3c547e,0x6d440bcf,0xdef7000d,0x00000000}},	//   derr, _asia, мыя_,
  { {0x64480357,0x443c6c61,0x442e2659,0x00000000}},	//   _hadi, lev_, lff_,
  { {0x8d870001,0x6448076b,0x7c3c50a7,0x00000000}},	//   фунд, _kadi, ferr,
  { {0x443c6c62,0x91bb0063,0x6448131e,0x00000000}},	//   nev_, _ומדי, _jadi,
  { {0xe2070051,0x3940001f,0x442e001f,0x00000000}},	//   spół_, ewis_, iff_,
  { {0x443c6c63,0x83fc007d,0x6e450021,0x00000000}},	//   hev_, _dođi, _أنظم,
  { {0x645a0dd1,0x443c0266,0xceb40041,0x00000000}},	// [ed90] _onti, kev_, _ביק_,
  { {0x7c3c0b23,0x443c208b,0x64486c64,0x00000000}},	//   cerr, jev_, _nadi,
  { {0xd148008b,0x38b40137,0x443c6c65,0x00000000}},	//   _lễ_, värt_, dev_,
  { {0x9f4c00ea,0x7d1d6c66,0xb5fd6c67,0x00000000}},	//   ladó_, ouss, _koši,
  { {0x64486c68,0xe3b8005b,0x38b40137,0x00000000}},	//   _badi, _ayı_, gärs_,
  { {0xdfc6006a,0x443c0ba5,0x644841b0,0x00000000}},	//   _مي_, gev_, _cadi,
  { {0xd4040086,0x7d1d004d,0x38b40137,0x00000000}},	//   тячи, huss, rärt_,
  { {0x7e6d6c69,0xbebd001c,0x645a078f,0x00000000}},	//   _noap, stīj, _enti,
  { {0x7c251ad3,0x765b0877,0x64481852,0x00000000}},	//   _ochr, _inuy, _fadi,
  { {0x443c00c3,0xd148001b,0xf94a0047,0x00000000}},	//   cev_, _dễ_, לעפֿ,
  { {0x7c3c6c6a,0x3ce00003,0xaf990054,0x00000000}},	//   verr, _suiv_, ятих_,
  { {0x290900fe,0x32040051,0x6e3d051c,0x00000000}},	//   ksaa_, camy_, gesb,
  { {0x7d1d1b35,0x61e96c6b,0x7c3c1d7a,0x00000000}},	//   guss, mcel, terr,
  { {0x9f4c00ea,0x65640072,0x61e96c6c,0x00000000}},	//   gadó_, äihi, lcel,
  { {0xdd990024,0x20056c6d,0x6d440022,0x00000000}},	//   ĺňa_, mali_, _wsia,
  { {0x443c0080,0x61e96c6e,0x394000ac,0x00000000}},	//   zev_, ncel, twis_,
  { {0xf2d20047,0xc9a70002,0x7d1d6c6f,0x00000000}},	// [eda0] רען_, евте_, cuss,
  { {0x20056c70,0x61e90066,0x68460021,0x00000000}},	//   nali_, hcel, عَال,
  { {0x660000f3,0x66e50006,0xf7720021,0x00000000}},	//   _pemk, _dėko, داء_,
  { {0x2005047d,0x38b4004d,0x64486c71,0x00000000}},	//   hali_, tärs_, _sadi,
  { {0x443c0fbf,0x644800eb,0x66da0080,0x00000000}},	//   tev_, _padi, _důka,
  { {0x200518c4,0x2c660066,0xd1480013,0x00000000}},	//   jali_, _pôdy_, _rễ_,
  { {0x442e23c6,0x32040051,0x64486c72,0x00000000}},	//   rff_, tamy_, _vadi,
  { {0x9f580025,0x97570063,0x21660893,0x00000000}},	//   úrí_, _אילו_, етог,
  { {0x644869f5,0x32040051,0x91b70062,0x00000000}},	//   _tadi, ramy_, нгът_,
  { {0x645a1269,0x7d1d021e,0x20056c73,0x00000000}},	//   _unti, vuss, gali_,
  { {0x6e3d0146,0x7d1d0321,0xe41a0066,0x00000000}},	//   tesb, wuss, kľúč,
  { {0xb5fd1312,0x91e3000a,0x7bde00a4,0x00000000}},	//   _poši, _боце, _agpu,
  { {0x20056c74,0x6e3d1203,0x9ccb0121,0x00000000}},	//   bali_, resb, зыва_,
  { {0x20051646,0x7d1d6c75,0x9f5e6c76,0x00000000}},	//   cali_, russ, latí_,
  { {0x9f4c00ea,0x0ac70062,0x2ac7005e,0x00000000}},	//   radó_, ещам, ељав,
  { {0x7d1d6c77,0x66e50078,0x290904f9,0x00000000}},	//   puss, _dėkl, tsaa_,
  { {0x38b400c7,0x26c30078,0x61fd0046,0x00000000}},	// [edb0] värr_, _ėjo_, ðsli,
  { {0x7d1b00cd,0xd6d90051,0x61e94faf,0x00000000}},	//   àusu, _sił_, zcel,
  { {0x61e9002b,0x290901cf,0xd6d90022,0x00000000}},	//   ycel, ssaa_, _pił_,
  { {0x9f5e0024,0x81c2008f,0x20056c78,0x00000000}},	//   jatí_, ģējo, zali_,
  { {0x44250b98,0x49741a78,0x2005107b,0x00000000}},	//   _pcl_, _бляс, yali_,
  { {0x61e900ca,0xc87f004d,0xe3b92e56,0x00000000}},	//   wcel, _buße_, мбл_,
  { {0xa3cb0053,0xb87b006d,0x61e9001c,0x00000000}},	//   रें_, _guía, tcel,
  { {0xa562007e,0x20056c79,0x2a696c7a,0x00000000}},	//   _چگون, wali_, njab_,
  { {0x41020055,0xe9df0e7c,0x61e90725,0x00000000}},	//   азыв, _raúl_, rcel,
  { {0x20050290,0x7ebd3525,0x61e96c7b,0x00000000}},	//   uali_, léph, scel,
  { {0x20183c4b,0x20056c7c,0x7d0d6c7d,0x00000000}},	//   ória_, rali_, _avas,
  { {0x20054032,0x2c74004d,0xdb24013d,0x00000000}},	//   sali_, _lädt_, érít,
  { {0xfd1f0290,0x20056c7e,0x5d670121,0x00000000}},	//   guì_, pali_, виям_,
  { {0xe1f90006,0x7d0d0006,0x8c46005e,0x00000000}},	//   lbų_, _dvas, њеве,
  { {0x3ab60001,0x2b15046f,0xd83e00c2,0x00000000}},	//   вљат, льтр, ščke_,
  { {0xfd1f0290,0x6a7100b9,0x224d579d,0x00000000}},	//   buì_, _såfr, ndek_,
  { {0x2d95000d,0x290c001c,0x212d0089,0x00000000}},	// [edc0] _брэс, _ādas_, nteh_,
  { {0x7bde00a4,0x2a69004b,0x88830054,0x00000000}},	//   _ugpu, ajab_, алуж,
  { {0x7d090743,0xc5fe001c,0x66040014,0x00000000}},	//   šest, ņēma_, ðiko,
  { {0x63ad0058,0xa3d40042,0x00000000,0x00000000}},	//   ğanl, सेफ_,   ,
  { {0x63ad005b,0xe8f70062,0xa613071f,0x00000000}},	//   şanl, _иля_, рміч,
  { {0x44b3000d,0x9423005e,0x20c20014,0x00000000}},	//   абіс, амље, eðin_,
  { {0xe7b6005d,0xdc9b0041,0x2c200042,0x00000000}},	//   _شمرد, ויסל, _बाईं_,
  { {0xc7a30413,0x7ebd0003,0x224d00ca,0x00000000}},	//   _тиск, céph, gdek_,
  { {0x5273005e,0x2163000d,0x63ba0022,0x00000000}},	//   рују, атэг, _wytn,
  { {0x224d119b,0x844501f3,0xc057045b,0x00000000}},	//   adek_, _مخمل, вію_,
  { {0x9f5e004c,0x50d30593,0x6d566c7f,0x00000000}},	//   patí_, جزير, _arya,
  { {0xc7b30132,0xfd1f0290,0xddd60080,0x00000000}},	//   יבת_, tuì_, _slyš,
  { {0xbebd003d,0xddc400c3,0xddd64e31,0x00000000}},	//   ktīv, _poiš, _plyš,
  { {0x66e500eb,0x8f5400b3,0xfd1f0290,0x00000000}},	//   _sėkm, _منتش, ruì_,
  { {0xdee30138,0xb5fd017f,0x628215ed,0x00000000}},	//   _који, _košt, _kloo,
  { {0x9f5c004c,0xb87b1358,0x4da70044,0x00000000}},	//   _jeví_, _atíp, _لإخف,
  { {0xf807019d,0xb5fd08ea,0xead40156,0x00000000}},	// [edd0] вчен, _mošt, роть,
  { {0xf8b90021,0x7e7d63d8,0x4ac30082,0x00000000}},	//   رهاب_, lksp, _वीरव,
  { {0x9715000d,0xe1f90078,0x5ba40094,0x00000000}},	//   умец, ybų_, _вряз,
  { {0x9f5c004c,0xf7700049,0x7e7d2cc4,0x00000000}},	//   _neví_, غال_, nksp,
  { {0x7ae500fe,0x7e7d00ac,0xa825007e,0x00000000}},	//   _huht, iksp, _مکان,
  { {0xd7f40076,0x63ad0058,0x9475007e,0x00000000}},	//   _взры, şanm, دگرا,
  { {0x7ae50004,0x224d0250,0xf8b20063,0x00000000}},	//   _juht, tdek_, _השם_,
  { {0x2369017f,0x7ae55444,0x7e7d006f,0x00000000}},	//   ćaj_, _muht, jksp,
  { {0x20c2007a,0xe1f90006,0x98a00022,0x00000000}},	//   rðin_, rbų_, stią_,
  { {0x442300b9,0x25a00025,0x7e7d6c80,0x00000000}},	//   _øj_, úile_, eksp,
  { {0x62820034,0xa2f5005a,0xb87b0139,0x00000000}},	//   _floo, _спеч, _luío,
  { {0xf38c0041,0x62826c81,0xddcd01c8,0x00000000}},	//   _קראָ, _gloo, _dlaž,
  { {0x61fd007a,0xb87b017d,0x61fb67b4,0x00000000}},	//   ðslu, _ruín, mbul,
  { {0xb87b00be,0x61fb6c82,0xfce30768,0x00000000}},	//   _suín, lbul, соро,
  { {0x30da00b5,0x61fb0078,0x69c6013d,0x00000000}},	//   _אַהע, obul, _szke,
  { {0xb87b6c83,0x7e7d6c84,0x61fb6758,0x00000000}},	//   _buío, cksp, nbul,
  { {0xa81a007e,0x88ca0121,0x66da004c,0x00000000}},	// [ede0] فتار_, елав_, _důkl,
  { {0xa84a0049,0x00000000,0x00000000,0x00000000}},	//   علام_,   ,   ,
  { {0x61fb2d6f,0xeb9a1dd1,0x907a0041,0x00000000}},	//   kbul, _чин_, עטעי,
  { {0x84e60086,0x80ca0042,0xd6d90054,0x00000000}},	//   годж, _सीने, вті_,
  { {0x6aa45a9e,0xe5a30794,0x229a0023,0x00000000}},	//   mnif, бици, jūka_,
  { {0x62822493,0xbebd008f,0x399b0041,0x00000000}},	//   _sloo, ltīt, _װילד,
  { {0x6aa40019,0x78ab00ea,0xbddb0003,0x00000000}},	//   onif, égve, ndèr,
  { {0x9f5e01d9,0x75d60067,0xc2740141,0x00000000}},	//   jatá_, _ميزا, рлиј,
  { {0xddcd017f,0x20180016,0xbebd003d,0x00000000}},	//   _slaž, ório_, itīt,
  { {0xe4d7007e,0x83fc007d,0x290f00ea,0x00000000}},	//   _موقت_, _vođs, ágai_,
  { {0x2fd800c7,0x6aa4337e,0xe4750085,0x00000000}},	//   ärg_, knif, _тутэ,
  { {0x91e60055,0xddcd6c85,0x877b0041,0x00000000}},	//   _соде, _vlaž, גאטי,
  { {0x7ae5047f,0x7e7d6c86,0x729b0041,0x00000000}},	//   _suht, rksp, _אסאס,
  { {0x7ae5021e,0xdfd40121,0x10a305ef,0x00000000}},	//   _puht, _колы, _личн,
  { {0xb87b0027,0xc8790529,0xddcd007d,0x00000000}},	//   _suío, _îşi_, _ulaž,
  { {0xdb0c004c,0x6e95005d,0x6aa46b44,0x00000000}},	//   íhán, _خلبا, gnif,
  { {0x3ea90089,0x76420058,0xe9180054,0x00000000}},	// [edf0] _ijat_, deoy, лоті_,
  { {0x6aa46c87,0x61fb6c88,0x37ab06b4,0x00000000}},	//   anif, zbul, нтен_,
  { {0x501b0063,0x00000000,0x00000000,0x00000000}},	//   תובו,   ,   ,
  { {0x635c000c,0x16350062,0x61e23950,0x00000000}},	//   _mănă, редя, _ngol,
  { {0x85e80054,0xe44e0054,0x00000000,0x00000000}},	//   удів_, ож_,   ,
  { {0x65790034,0x4d7c0047,0x00000000,0x00000000}},	//   rywh, ערגע,   ,
  { {0xf4840001,0xbebd001c,0x95c5007e,0x00000000}},	//   ључн, ntīs, _چيزه,
  { {0xbb3c0047,0xbebd001c,0xa3cb0042,0x00000000}},	//   געהי, itīs, रेग_,
  { {0xb4270049,0xd538013a,0x6a780046,0x00000000}},	//   _معاو, _مثلا_, _gífu,
  { {0x61e20290,0x78a504aa,0x635c00dd,0x00000000}},	//   _egol, nnhv, _bănă,
  { {0x61e60006,0x78a50026,0x2054014c,0x00000000}},	//   žkla, inhv, стыр,
  { {0x660b002c,0x1e960076,0x44eb05dd,0x00000000}},	//   nagk, ррор, _kø_,
  { {0x6cc60086,0x644300ac,0x66e50078,0x00000000}},	//   ийма, oeni, _dėki,
  { {0x629b00eb,0xceb90045,0x61e200c2,0x00000000}},	//   liuo, stęp_, _zgol,
  { {0x44276c89,0x68e600a4,0x44eb06a5,0x00000000}},	//   ign_, _sukd, _lø_,
  { {0x629b0006,0xbddb0003,0xab270141,0x00000000}},	//   niuo, rdèr, јота_,
  { {0x64436c8a,0x673c007d,0x44eb01f2,0x00000000}},	// [ee00] keni, _sprj, _nø_,
  { {0xbebd003d,0x97560001,0x64436c8b,0x00000000}},	//   stīt, итељ, jeni,
  { {0x629b0006,0x64436c8c,0x26cd0139,0x00000000}},	//   kiuo, deni, _bheo_,
  { {0xc86900b7,0x1f3600b5,0x26cd0035,0x00000000}},	//   ון_, ירער_, _cheo_,
  { {0x2cb80250,0x64436c8d,0xd62704dc,0x00000000}},	//   oord_, feni, роче_,
  { {0x2cb802eb,0x7d040009,0xd7f20021,0x00000000}},	//   nord_, _mwis, _ذكر_,
  { {0xd4090021,0x07a314b4,0x07ba0044,0x00000000}},	//   اتهم_, _дарн, _شهرة_,
  { {0xd2570597,0x66e3000d,0x4427395c,0x00000000}},	//   аць_, _фота, agn_,
  { {0x30a6184a,0x044a0001,0x635c000c,0x00000000}},	//   иров, _ипак_, _sănă,
  { {0x2007082a,0x64436c8e,0x3e530013,0x00000000}},	//   _ceni_, ceni, _ệt_,
  { {0x9ed9000a,0x200714b5,0x62890139,0x00000000}},	//   лмот_, _deni_, bheo,
  { {0x61e201f4,0xefcc0058,0x62896c8f,0x00000000}},	//   _ugol, _ışığ, cheo,
  { {0x10a600d7,0xb87b0025,0x2cb814e1,0x00000000}},	//   _кидн, _suím, ford_,
  { {0x20076c90,0xbebd008f,0x2cb86c91,0x00000000}},	//   _geni_, ttīs, gord_,
  { {0xb87b1bb7,0x200c6c92,0x7d0424bf,0x00000000}},	//   _quím, madi_, _ewis,
  { {0xa3cb0235,0xeaf8007e,0x442c26c5,0x00000000}},	//   रेट_, شرفت_, _lcd_,
  { {0x200701f7,0x3eb90037,0x7d04001f,0x00000000}},	// [ee10] _yeni_, most_, _gwis,
  { {0x6d4d6c93,0x3946017d,0x3eb90ffc,0x00000000}},	//   _isaa, çosa_, lost_,
  { {0x7d040199,0x44eb05dd,0x64436c94,0x00000000}},	//   _zwis, _sø_, veni,
  { {0x200c0150,0x7ebd006d,0x4fd90047,0x00000000}},	//   hadi_, cépt, אַנד,
  { {0x200c1964,0x39596c95,0x442c6c96,0x00000000}},	//   kadi_, _urss_, _bcd_,
  { {0x6d4d0009,0x200c003e,0x3eb96c97,0x00000000}},	//   _msaa, jadi_, host_,
  { {0x26cd00aa,0x660b00bb,0x62896c98,0x00000000}},	//   _theo_, pagk, theo,
  { {0x3a296906,0x20076c99,0x6d4d10f0,0x00000000}},	//   ngap_, _seni_, _osaa,
  { {0x629b00eb,0x3a290089,0x39496c9a,0x00000000}},	//   riuo, igap_, nwas_,
  { {0x14740021,0x6e2d515e,0x62890025,0x00000000}},	//   _والج, _acab, sheo,
  { {0x629b00eb,0x2007000c,0x66090150,0x00000000}},	//   piuo, _veni_, _keek,
  { {0x2cb86c9b,0xfd1f0290,0x3eb900b2,0x00000000}},	//   word_, frì_, gost_,
  { {0x200c053b,0x0d9902dc,0xc692069a,0x00000000}},	//   badi_, атры_, לאט_,
  { {0xab2a6c9c,0x00f60063,0x644e00be,0x00000000}},	//   лога_, _המסך_, _óbit,
  { {0x9ef50032,0x3eb90185,0x2cb816af,0x00000000}},	//   _استش, bost_, rord_,
  { {0x4f1600b7,0x7d0419dd,0x3a292150,0x00000000}},	//   _פֿון_, _twis, ggap_,
  { {0x7e640150,0x2cb800b9,0xc4b90053,0x00000000}},	// [ee20] _inip, pord_, ेताओ,
  { {0xb80a0021,0xe9d73f8e,0x7a31013d,0x00000000}},	//   ايام_, ску_, tótó,
  { {0x7e646c9d,0x6609224f,0x442c6c9e,0x00000000}},	//   _knip, _beek, _rcd_,
  { {0x6b810205,0x5fba00b5,0x7a315607,0x00000000}},	//   ølge, אצענ, rótó,
  { {0x200c0cc6,0x15130054,0x4a57009a,0x00000000}},	//   yadi_, здія, _השכל_,
  { {0x442c6c9f,0x7aed013d,0x6d480022,0x00000000}},	//   _qcd_, _öltö, łdaw,
  { {0x33170032,0xd4670001,0x442c053b,0x00000000}},	//   مزيد_, сије_, _vcd_,
  { {0x3253005a,0x969502a9,0x200c02ae,0x00000000}},	//   звър, _друш, wadi_,
  { {0x2912002c,0x200c2223,0x60f7000d,0x00000000}},	//   nsya_, tadi_, бныя_,
  { {0x6609006f,0xdefa066e,0x26dc004c,0x00000000}},	//   _zeek, лым_, ůvod_,
  { {0x200c69fb,0x3eb95ba9,0x93f70063,0x00000000}},	//   radi_, tost_, _הצבא_,
  { {0x7afc00c3,0xddc4001c,0xb7db0047,0x00000000}},	//   dprt, _maiņ, טקיי,
  { {0xa133007e,0xc05a0054,0x200c6ca0,0x00000000}},	//   _فروش, _бій_, padi_,
  { {0x66c3004b,0x7ebd013d,0xad9b0046,0x00000000}},	//   tõkk, gépr, daút,
  { {0x3eb96ca1,0x309b0063,0xbebd0023,0x00000000}},	//   post_, _תשומ, trīd,
  { {0xfd1f0290,0x139b0047,0x9f5e0051,0x00000000}},	//   prì_, אבלע, śród_,
  { {0x66090173,0xaa580076,0x66e50078,0x00000000}},	// [ee30] _reek, щиту_, _lėkt,
  { {0x07e7000d,0x4af9007e,0x66096ca2,0x00000000}},	//   сцам, _نکرد_, _seek,
  { {0x291200a4,0x6609016c,0x77990896,0x00000000}},	//   asya_, _peek, јкер_,
  { {0x672547d4,0xaa59005e,0x66ca0061,0x00000000}},	//   ruhj, _тиму_, týka,
  { {0xd1260032,0x66090019,0x0608000d,0x00000000}},	//   _تم_, _veek, снік_,
  { {0x22ac0080,0x6609412e,0xf795000d,0x00000000}},	//   věka_, _week, _дагэ,
  { {0x66096ca3,0x96f80141,0x0ec90042,0x00000000}},	//   _teek, _гест_, रताड,
  { {0xc7b20063,0x23080021,0x7ebd013d,0x00000000}},	//   _חבל_, حتوي_, zépr,
  { {0xc42b002a,0x5ba60042,0x60e605ac,0x00000000}},	//   _مثال_, _ऐश्व, омым_,
  { {0x08760047,0x7e641f7a,0x60093f17,0x00000000}},	//   ַערט_, _snip, шном_,
  { {0xbebd001c,0xfe462f9e,0x0eaa03d1,0x00000000}},	//   drīb, онно, икой_,
  { {0x3f8b0051,0x13b6009a,0x00000000,0x00000000}},	//   ącu_, _והעל_,   ,
  { {0x2d84004a,0x3f8300c2,0xbc850013,0x00000000}},	//   áme_, šju_, ưỡn,
  { {0x83b50047,0x6b660076,0x030d0082,0x00000000}},	//   ַפּע_, окга, _सबाह_,
  { {0x4a9a000d,0x7ebd0003,0xda9a005e,0x00000000}},	//   атаў_, répr, ађај_,
  { {0x394600be,0x7e646ca4,0xada6089a,0x00000000}},	//   çoso_, _unip, _майл,
  { {0x29120058,0xdc760085,0xfaa30131,0x00000000}},	// [ee40] usya_, _дынь, фато,
  { {0x07a60094,0x00000000,0x00000000,0x00000000}},	//   оазн,   ,   ,
  { {0x20180024,0x75e6000d,0x3ce30082,0x00000000}},	//   órii_, оўле, _टूटे_,
  { {0x56930086,0x46a3075f,0xcb13009a,0x00000000}},	//   маєт, махв, _קלר_,
  { {0x83f802d8,0xa924011b,0x00000000,0x00000000}},	//   белс_, ěžst,   ,
  { {0x54970085,0x04580044,0x00000000,0x00000000}},	//   овіў_, صلبة_,   ,
  { {0x442001f7,0x7ebd00ea,0xad9b0046,0x00000000}},	//   ği_, képp, naúr,
  { {0x44201c93,0x32b70021,0x6733004c,0x00000000}},	//   şi_, يدية_, žejí,
  { {0xdcea0080,0x61430699,0x66026ca5,0x00000000}},	//   čněj, дења, mbok,
  { {0xdfda0062,0x442a01e1,0xb034005e,0x00000000}},	//   иън_, _øb_, чнош,
  { {0x44f0001b,0xf1c60080,0xde59071f,0x00000000}},	//   _hà_, _řádu_, бані_,
  { {0x66023073,0xd250007e,0x66d108a9,0x00000000}},	//   nbok, _سنت_, råkg,
  { {0x61a50161,0xd12f0021,0xbebd008f,0x00000000}},	//   खपृष, _لمن_, trīb,
  { {0x44f000aa,0x387800c7,0xbf14007e,0x00000000}},	//   _mà_, _norr_, _فوتب,
  { {0x44f06ca6,0x660200b0,0xee3f0114,0x00000000}},	//   _là_, kbok, lným_,
  { {0x9a680002,0x00000000,0x00000000,0x00000000}},	//   ојуз_,   ,   ,
  { {0xee3f0240,0x66020b19,0x3eb2013d,0x00000000}},	// [ee50] nným_, dbok, ézte_,
  { {0x27e70031,0xa787007e,0xee3f004c,0x00000000}},	//   ønn_, يشاو, iným_,
  { {0x387c0137,0x7522097a,0x17f80044,0x00000000}},	//   övra_, eroz, ترقة_,
  { {0x44f0001b,0x6602105a,0x8bd60063,0x00000000}},	//   _bà_, gbok, _מותו_,
  { {0x94790088,0x44f0008b,0xee3f0114,0x00000000}},	//   йску_, _cà_, jným_,
  { {0x44f06ca7,0xb97a0063,0xee3f027d,0x00000000}},	//   _dà_, _הנשי, dným_,
  { {0x7522004c,0x443e04f9,0xf62b0054,0x00000000}},	//   aroz, _dbt_, _візи_,
  { {0x44f001f4,0x75226ca8,0xc7b2009d,0x00000000}},	//   _fà_, broz, _נבן_,
  { {0x44f0008b,0x66d100b8,0x7522008d,0x00000000}},	//   _gà_, råkd, croz,
  { {0x320b056c,0x00000000,0x00000000,0x00000000}},	//   źcy_,   ,   ,
  { {0x7bc56ca9,0xd43400de,0xe8d8009d,0x00000000}},	//   _nyhu, _تعقب, חוזר_,
  { {0xe3b200b5,0xee3f0061,0x62d9014b,0x00000000}},	//   _אױב_, bným_, _умеў_,
  { {0x8234007e,0x44f00013,0x0d83037b,0x00000000}},	//   _آرما, _xà_, елян,
  { {0xf1b90023,0x515a009a,0x00000000,0x00000000}},	//   ugšu_, _לכנו,   ,
  { {0x7bc5001f,0x9f5e013d,0x75226caa,0x00000000}},	//   _cyhu, zatú_, zroz,
  { {0x6486007a,0x2a79002b,0x66ca0195,0x00000000}},	//   _aðil, _cosb_, výko,
  { {0xad9b0026,0xaec30062,0x38780137,0x00000000}},	// [ee60] lbún, _ябъл, _porr_,
  { {0x44f00013,0x628b002b,0x3ea26cab,0x00000000}},	//   _rà_, _llgo, likt_,
  { {0xb8f30394,0x2d82021f,0xe73a0001,0x00000000}},	//   _ही_, lyke_, сее_,
  { {0xe7b3007e,0x2a79001f,0x443e017d,0x00000000}},	//   رمند, _gosb_, _sbt_,
  { {0x443e00e3,0x66024dfd,0x38786be9,0x00000000}},	//   _pbt_, rbok, _torr_,
  { {0x44f000aa,0x29006cac,0x3ea20122,0x00000000}},	//   _và_, mpia_, hikt_,
  { {0x6ac7017d,0x29000fb8,0x7522004c,0x00000000}},	//   _órfã, lpia_, sroz,
  { {0x60f803d6,0xdb230003,0x69c600fe,0x00000000}},	//   ония_, érée, _kyke,
  { {0x7ae601f7,0xf1a3000d,0x78be00f5,0x00000000}},	//   _mikt, ерэн, oopv,
  { {0x66d102f0,0x6723074f,0xf8be0053,0x00000000}},	//   råke, šnje, ्तिय,
  { {0xad9b0026,0x11e60612,0x644a0441,0x00000000}},	//   gbún, _ежем, mefi,
  { {0x2720003b,0x7ae60f1f,0x64586cad,0x00000000}},	//   mănă_, _nikt, ldvi,
  { {0xc6930063,0x644a6cae,0x60181afc,0x00000000}},	//   תאר_, oefi, _доля_,
  { {0x644a2b63,0x64586bfb,0x9ce4085e,0x00000000}},	//   nefi, ndvi, ецсл,
  { {0x20180024,0x64580137,0x29006caf,0x00000000}},	//   óriu_, idvi, epia_,
  { {0x273500c7,0x644a001f,0x200e0014,0x00000000}},	//   vån_, hefi, _hefi_,
  { {0x7ae66cb0,0x644a6cb1,0xacb5005e,0x00000000}},	// [ee70] _dikt, kefi, _обиљ,
  { {0xed600006,0x69c61233,0x644a0130,0x00000000}},	//   įžti_, _dyke, jefi,
  { {0x644a6cb2,0xf3f10013,0x6d5d6cb3,0x00000000}},	//   defi, _lạc_, lvsa,
  { {0x273501e3,0x395200fe,0x2eee285d,0x00000000}},	//   rån_, änsä_, _muff_,
  { {0x273500a5,0x69cf008f,0x4a5a009a,0x00000000}},	//   sån_, _uzce, _ודרו,
  { {0x27350137,0x644a13a7,0x85480054,0x00000000}},	//   pån_, gefi, язів_,
  { {0xe299000d,0xe7380121,0x66d100df,0x00000000}},	//   жай_, _неё_, råkb,
  { {0x6e3d006f,0xf3f10013,0x51650054,0x00000000}},	//   jfsb, _bạc_, двиб,
  { {0x2eee00bd,0xd12e0021,0x6aad05b3,0x00000000}},	//   _auff_, لمي_, inaf,
  { {0x765921bf,0x644a161c,0x764b6cb4,0x00000000}},	//   ldwy, cefi, legy,
  { {0x6d44051e,0x2d8200ac,0x752b004d,0x00000000}},	//   _spia, wyke_, lugz,
  { {0xada60088,0x68e7006f,0x76592229,0x00000000}},	//   дамл, _lijd, ndwy,
  { {0x7ae62330,0x66ec005b,0x3ea250ab,0x00000000}},	//   _rikt, _işke, rikt_,
  { {0x3ea202f0,0x2d8200ac,0x7ae600df,0x00000000}},	//   sikt_, ryke_, _sikt,
  { {0x7ae60006,0x64410025,0xb87b017d,0x00000000}},	//   _pikt, _mbli, _luís,
  { {0x764b00ea,0x6d400058,0x4ea5005e,0x00000000}},	//   jegy, çmas, _прња,
  { {0x76590185,0x68e70122,0x7ae631c8,0x00000000}},	// [ee80] ddwy, _bijd, _vikt,
  { {0xcce60021,0x2fc700e5,0x7659002b,0x00000000}},	//   _تسعي, _kyng_, edwy,
  { {0x78be1031,0x7ae60df9,0xe7370a74,0x00000000}},	//   ropv, _tikt, дех_,
  { {0x29006cb5,0x98a90051,0xe1e7007e,0x00000000}},	//   ppia_, ytać_, _لس_,
  { {0x20c20026,0x644a6cb6,0xbcfb6cb7,0x00000000}},	//   iðir_, tefi, rvég,
  { {0xe1ff0118,0x61eb6cb8,0x645801e1,0x00000000}},	//   ñón_, _aggl, udvi,
  { {0x17790055,0x764b0205,0x6458212c,0x00000000}},	//   _есть_, begy, rdvi,
  { {0x68e70122,0x644a6cb9,0x73490054,0x00000000}},	//   _zijd, sefi, ячів_,
  { {0x321d001f,0x248c0089,0xb97b0047,0x00000000}},	//   _ddwy_, _tldm_, ַנטי,
  { {0x3ea0000f,0x94234fc2,0x2eee12a9,0x00000000}},	//   _amit_, _амфе, _puff_,
  { {0x98a90045,0x93460086,0x20c20014,0x00000000}},	//   stać_, _інде, fðir_,
  { {0x2ca30122,0x644114e2,0x20c20014,0x00000000}},	//   wijd_, _zbli, gðir_,
  { {0x2ca302b0,0x7dc4000d,0x6aad0066,0x00000000}},	//   tijd_, вёрд, vnaf,
  { {0x2eee1233,0x20c2590f,0x3ea00af9,0x00000000}},	//   _tuff_, rðis_, _emit_,
  { {0x2ca30122,0x68e70122,0x9f5c0093,0x00000000}},	//   rijd_, _rijd, _nevø_,
  { {0xbcfb00ea,0xc9871122,0xad9b0046,0x00000000}},	//   tvéd, музи, lbúm,
  { {0x6aad6cba,0x127b0041,0x99990094,0x00000000}},	// [ee90] rnaf, קאמע, чкат_,
  { {0x7d0d002c,0xd795005a,0x98a40001,0x00000000}},	//   _iwas, низъ, виђе,
  { {0x64450019,0x229a001c,0x764b002b,0x00000000}},	//   õhim, lūku_, tegy,
  { {0x68e7006f,0x7d0d14ce,0x35b501fe,0x00000000}},	//   _wijd, _kwas, нбер,
  { {0x68e702b0,0x79960051,0x765921bf,0x00000000}},	//   _tijd, czyw, rdwy,
  { {0x752b006f,0x7d0d0035,0xd259008f,0x00000000}},	//   rugz, _mwas, doņa_,
  { {0x56950499,0x66f40141,0x28be0053,0x00000000}},	//   _завт, _апсу, ्तरि,
  { {0xe3b0007e,0xd24e0021,0x2fc700a3,0x00000000}},	//   جره_, منى_, _ryng_,
  { {0x644101a8,0xbebd008f,0xd2590023,0x00000000}},	//   _tbli, trīn, goņa_,
  { {0x3ea0311d,0x64416cbb,0xc952009a,0x00000000}},	//   _smit_, _ubli, נמי_,
  { {0x3dc9002c,0x7d0d0222,0x200500cf,0x00000000}},	//   _ayaw_, _awas, rbli_,
  { {0xdd1e0529,0x20180014,0x61eb0b6e,0x00000000}},	//   _câşt, órir_, _uggl,
  { {0x20c2007a,0x6114000d,0xb80f0042,0x00000000}},	//   rðir_, _адчу, िराम_,
  { {0x7afe00e3,0xc4d20047,0x224d056f,0x00000000}},	//   _ptpt, ָגל_, leek_,
  { {0x6286004b,0xcb670142,0x2d8f0244,0x00000000}},	//   ökog, наре_, _ügen_,
  { {0x3af504aa,0x9f5e0061,0x3f85002b,0x00000000}},	//   _dåp_, natý_, mylu_,
  { {0x7d0d0185,0x6aa40526,0x61fd0014,0x00000000}},	// [eea0] _gwas, riif, ðsly,
  { {0x224d0122,0x6d5623c1,0xbcfb0003,0x00000000}},	//   heek_, _isya, uvée,
  { {0xbcfb0003,0x3f856cbc,0x224d00ca,0x00000000}},	//   rvée, nylu_, keek_,
  { {0x60c16cbd,0x040f0013,0x9f5e0195,0x00000000}},	//   holm, _đêị_, jatý_,
  { {0xe89b005b,0x64a602e1,0xdbca004b,0x00000000}},	//   _çağı, нада, rõõm,
  { {0x672301b3,0x66d11310,0x3952002b,0x00000000}},	//   šnja, råka, mwys_,
  { {0x3952001f,0x851c0053,0xcc3b0041,0x00000000}},	//   lwys_, _निकट_, פעקט,
  { {0x66e30d34,0x3952002b,0x6d560058,0x00000000}},	//   _боса, owys_, _osya,
  { {0x3952001f,0xc05a0e74,0xa19416f2,0x00000000}},	//   nwys_, пін_, тапч,
  { {0xf3f1001b,0x89370047,0x03960062,0x00000000}},	//   _hạn_, עריע_, _прея,
  { {0x7d0d08f8,0xbfaa0612,0x6d566cbe,0x00000000}},	//   _swas, ятие_, _asya,
  { {0x60c10025,0xe3c7006d,0x645a1642,0x00000000}},	//   aolm, áñez_, _hati,
  { {0x645a10ca,0x22510080,0x251b0041,0x00000000}},	//   _kati, ánků_, ּולא,
  { {0x645a028d,0x61430856,0x91e30612,0x00000000}},	//   _jati, _сеља, _соче,
  { {0x395200ac,0x5b243eea,0xc87f004d,0x00000000}},	//   ewys_, льта, _mußt_,
  { {0x7d0d0035,0x645a6cbf,0x9ee90021,0x00000000}},	//   _twas, _lati, _تفعل_,
  { {0x7d0d0035,0x7ebd00ea,0x7e6d6cc0,0x00000000}},	// [eeb0] _uwas, képz, _inap,
  { {0x7e6d007a,0x6f0d0051,0x645a632b,0x00000000}},	//   _hnap, _łaci, _nati,
  { {0xf3f100aa,0x78a5017f,0x7e6d4b34,0x00000000}},	//   _bạn_, rihv, _knap,
  { {0x6f1a0025,0xf3f10013,0x9f5e0331,0x00000000}},	//   istc, _cạn_, lató_,
  { {0xddc40529,0x645a184f,0x0c74007e,0x00000000}},	//   _iniţ, _bati, _شدید,
  { {0x0445018e,0x6f1a006f,0x645a6cc1,0x00000000}},	//   текн, kstc, _cati,
  { {0x224d3339,0x60c1203d,0x6289004b,0x00000000}},	//   teek_, volm, tkeo,
  { {0x645a0034,0x9f5e000f,0x7e6d6510,0x00000000}},	//   _eati, ható_, _nnap,
  { {0x224d0250,0xb3eb00b3,0x62896cc2,0x00000000}},	//   reek_, _فعال_, rkeo,
  { {0x7e6d64c9,0x645a6cc3,0x20110066,0x00000000}},	//   _anap, _gati, úzi_,
  { {0x9327007e,0xb4cd0053,0x64940013,0x00000000}},	//   _سران, रती_, _sàig,
  { {0x645a04c9,0xdc0a0053,0xc880003b,0x00000000}},	//   _zati, वर्ड_, ăşit_,
  { {0xe1f00067,0x645a0397,0x69cb00bd,0x00000000}},	//   _اسم_, _yati, ügel,
  { {0x2365007d,0x9f5e00ea,0xf3f10013,0x00000000}},	//   _krlj_, gató_, _mạo_,
  { {0xaac603eb,0x80ca0053,0x61fb6cc4,0x00000000}},	//   نترن, _सीटे, ocul,
  { {0x61fb6cc5,0x6e460141,0xba2300fd,0x00000000}},	//   ncul, _реиз, идск,
  { {0x3eb900ea,0xc2120063,0x66d80080,0x00000000}},	// [eec0] érte_, יהן_, níke,
  { {0x7c8502a9,0x39521cbf,0xf3f10013,0x00000000}},	//   _буџе, rwys_, _sạn_,
  { {0xe3b80058,0x645a6a5f,0xc8b50183,0x00000000}},	//   _adın_, _rati, усты,
  { {0x68ed0812,0x9bb7014e,0xf3f1008d,0x00000000}},	//   _žodž, _יהיה_, _bạo_,
  { {0x645a0498,0x95530cac,0x00000000,0x00000000}},	//   _pati, لخوا,   ,
  { {0xe8e1008d,0xf7460121,0x66d8004c,0x00000000}},	//   _đệp_, _иего, díke,
  { {0x0396005a,0xd4670001,0x07a6422b,0x00000000}},	//   ърдя, тије_, _равн,
  { {0xcb130063,0x645a0222,0xbebd008f,0x00000000}},	//   בלה_, _wati, arīj,
  { {0x645a148a,0xdb1e0072,0x273c6cc6,0x00000000}},	//   _tati, _hypä, lín_,
  { {0x61fb42c0,0x7e6d6cc7,0xdb1e0050,0x00000000}},	//   acul, _snap, _kypä,
  { {0x273c1c4b,0xd4970063,0x61fb2283,0x00000000}},	//   nín_, _שכבת_, bcul,
  { {0xad9b0026,0x61fb1014,0xb28306c9,0x00000000}},	//   lbúi, ccul, _вышк,
  { {0x9f5e000f,0x7e6d00c3,0x273c3115,0x00000000}},	//   tató_, _vnap, hín_,
  { {0x273c006d,0xac24030b,0x2d99009c,0x00000000}},	//   kín_, ифск, rzse_,
  { {0x273c0024,0x290200fe,0x2ac7005e,0x00000000}},	//   jín_, _atka_, вљав,
  { {0x31660117,0x7e6d3253,0x9ab4000d,0x00000000}},	//   _kroz_, _unap, айсц,
  { {0x49bb007e,0xaa640002,0xc8d90054,0x00000000}},	// [eed0] ذارد_, јтск, емає_,
  { {0x7d1b0297,0xb60200ea,0x20b40053,0x00000000}},	//   áusu, őáll, ुविध,
  { {0x27e700c7,0x22460051,0xb8fa0053,0x00000000}},	//   änn_, _obok_, _डी_,
  { {0xbebd003d,0x6723017f,0x66d104aa,0x00000000}},	//   drīk, šnjo, råko,
  { {0x961d003d,0x45450021,0x0608000d,0x00000000}},	//   _noņe, انتق, тнік_,
  { {0xb4cd0053,0x2611008b,0x85b80021,0x00000000}},	//   रते_, ạo_, خامس_,
  { {0xbebd001c,0x4429005b,0x273c6cc8,0x00000000}},	//   grīk, ğa_, cín_,
  { {0xf3f1001b,0x4429183b,0x31666cc9,0x00000000}},	//   _tạo_, şa_, _broz_,
  { {0x21740121,0xddc60051,0x10150500,0x00000000}},	//   ауэр, zekł, льня,
  { {0x2055226b,0x61fb1ea0,0x26cf002b,0x00000000}},	//   утир, scul, llgo_,
  { {0x7c3800c7,0x44f9008b,0x26cf00a8,0x00000000}},	//   _övri, _hè_, olgo_,
  { {0xe28e0002,0x44f9008d,0x02a402d8,0x00000000}},	//   _ѓа_, _kè_, _крчм,
  { {0xf3f1008b,0x2d840003,0x721a0063,0x00000000}},	//   _lạm_, âme_, _נוסח,
  { {0x25d60047,0x225f0058,0x225d6cca,0x00000000}},	//   טורן_, lduk_, _hawk_,
  { {0xeb9a2328,0x6619056c,0x00000000,0x00000000}},	//   хив_, kawk,   ,
  { {0x225f053b,0xcb670001,0x273c1994,0x00000000}},	//   nduk_, ћате_, vín_,
  { {0x213f053b,0x44f93dda,0x66d10829,0x00000000}},	// [eee0] ntuh_, _nè_, råkl,
  { {0x273c6ccb,0x78250021,0xc8ca01fb,0x00000000}},	//   tín_, لعمل, روان_,
  { {0xa6e9001b,0xbcfb0003,0x6b8c00dd,0x00000000}},	//   _thự, nvén, ângă,
  { {0x44f9001b,0x273c6ccc,0x6722008f,0x00000000}},	//   _bè_, rín_, ņojo,
  { {0x273c1230,0xa61301dd,0x997506b4,0x00000000}},	//   sín_, сміч, _курш,
  { {0xb8f80235,0x273c0024,0x2a600019,0x00000000}},	//   ात_, pín_, ldib_,
  { {0x4394000d,0x9f5c01f4,0xad9b0014,0x00000000}},	//   райс, _levò_, rbúi,
  { {0x6b810031,0xc7a30062,0x213f0150,0x00000000}},	//   ølgi, _уиск, ftuh_,
  { {0x39406ccd,0x41c6000d,0xbcfb013d,0x00000000}},	//   ntis_, ыёка, evén,
  { {0x39570063,0x39400006,0x6e246cce,0x00000000}},	//   נשים_, itis_, _adib,
  { {0xdfd0006a,0x39400019,0xdef7000d,0x00000000}},	//   تيد_, htis_, лыя_,
  { {0x394011ab,0x6445004b,0x93960058,0x00000000}},	//   ktis_, õhiv, ışır,
  { {0xb5fd3aa1,0x6e24001f,0xeda74345,0x00000000}},	//   _inšt, _ddib, ушно,
  { {0x31370132,0x6e2400e5,0x656f008d,0x00000000}},	//   _ערוך_, _edib, _áche,
  { {0x40eb0063,0x7d040d1a,0x77776ccf,0x00000000}},	//   _אַהֲ, _etis, xxxx,
  { {0x5a34295f,0xaa58005e,0x4a5502d8,0x00000000}},	//   йнст, лису_, јкас,
  { {0x39400078,0x9f640014,0xf8070121,0x00000000}},	// [eef0] gtis_, ðtæk_, гчен,
  { {0x6d4d00bb,0xddc4017f,0xe3b8005b,0x00000000}},	//   _ipaa, _uniš, _adım_,
  { {0x44f90290,0x68ee00a4,0x2a6000a4,0x00000000}},	//   _sè_, _dibd, bdib_,
  { {0xfd1f0290,0x44f900cd,0x64486cd0,0x00000000}},	//   osì_, _pè_, _abdi,
  { {0xfd1f0290,0x39406cd1,0xc9871657,0x00000000}},	//   nsì_, ctis_, _суни,
  { {0x63850055,0x3cfc00b5,0x656d0024,0x00000000}},	//   игла, עלונ, ťaho,
  { {0x290900fe,0xe1f10021,0x64435495,0x00000000}},	//   lpaa_, يسة_, rfni,
  { {0x44f93dda,0x225f017e,0x3125130d,0x00000000}},	//   _tè_, uduk_, адиг,
  { {0x44f900cd,0x225f005b,0x45d40074,0x00000000}},	//   _uè_, rduk_, _готс,
  { {0xe8e0001b,0xa3570021,0xe8e1008d,0x00000000}},	//   _địa_, _مخصص, _đớp_,
  { {0x6d4d002c,0x3255015a,0x7d04115b,0x00000000}},	//   _apaa, _ввер, _stis,
  { {0xd37a0047,0xbcfb00ea,0x21290066,0x00000000}},	//   _ברעט, rvén, _ťahu_,
  { {0x764905b3,0x46560041,0x4dd6071f,0x00000000}},	//   _mbey, בױרן_, рінф,
  { {0xafe50076,0xc19a0063,0x7d0400a2,0x00000000}},	//   _колл, _בשני, _vtis,
  { {0x93bc000c,0x764900e5,0x6a864259,0x00000000}},	//   _scăz, _obey, алва,
  { {0x44255004,0xeab7623c,0x39406cd2,0x00000000}},	//   _ldl_, айс_, ttis_,
  { {0xdc0c0006,0x7d046cd3,0x7aef2308,0x00000000}},	// [ef00] lėči, _utis, _dict,
  { {0xd82600a0,0xed4f007e,0x39406cd4,0x00000000}},	//   рджи, _کپی_, rtis_,
  { {0x39406cd5,0x7aef1823,0x29090072,0x00000000}},	//   stis_, _fict, apaa_,
  { {0x5506032d,0x65692b21,0xd62a173e,0x00000000}},	//   ачка, _breh, тоде_,
  { {0x7ae4326b,0xa5330085,0x00000000,0x00000000}},	//   mmit, жніч,   ,
  { {0x656900bd,0x7ae45c71,0x32190014,0x00000000}},	//   _dreh, lmit, ðsyn_,
  { {0x83fc017f,0x2348007e,0x2d8b03a4,0x00000000}},	//   _nađe, استی_, zyce_,
  { {0x6b8300cd,0xc2740856,0x71466cd6,0x00000000}},	//   _ànge, слиј, ахож,
  { {0x7ae46cd7,0x22910026,0xe0860021,0x00000000}},	//   imit, _tákn_, لجدي,
  { {0x4034005e,0x7ae46cd8,0xceb90078,0x00000000}},	//   љенс, hmit, yręs_,
  { {0xa3e20235,0x6d4d0162,0x10730054,0x00000000}},	//   नेश_, _spaa, ілюю,
  { {0x61460088,0x7ae403f5,0x2d8b0051,0x00000000}},	//   _веда, jmit, tyce_,
  { {0xfd470088,0x3eab6cd9,0x7ae4275e,0x00000000}},	//   шэнн, rict_, dmit,
  { {0x69cf0051,0x2d8b0051,0x90970054,0x00000000}},	//   _ryce, ryce_, _квіт_,
  { {0x207b0047,0x7aef1304,0x7ce00026,0x00000000}},	//   _באגא, _pict, körf,
  { {0xbea400e1,0x66d100cf,0x7e2b0054,0x00000000}},	//   _мајк, råkk, _ріка_,
  { {0xdd9100b3,0x6b5c0a2e,0x3ea9007d,0x00000000}},	// [ef10] _رود_, _pågå, _imat_,
  { {0x7ae40012,0x2909000e,0xa3d70053,0x00000000}},	//   amit, rpaa_, _सरल_,
  { {0x7ae40034,0x7ce000c7,0xe787000a,0x00000000}},	//   bmit, förf, јузо,
  { {0xd246043b,0x65696cda,0xb87b017d,0x00000000}},	//   _عن_, _preh, _juíz,
  { {0x2a76014e,0xbebd001c,0xf3f10013,0x00000000}},	//   _הערך_, brīv, _hại_,
  { {0x58d4005a,0x66d8243a,0xbebd008f,0x00000000}},	//   _моят, ríka, nsīb,
  { {0xd7950032,0x3ea900fe,0x98a00006,0x00000000}},	//   _الأخ, _omat_, urią_,
  { {0xfbb80063,0xf3f1008b,0xda170053,0x00000000}},	//   יפות_, _mại_, तरित_,
  { {0xf3f1001b,0x659402a9,0x44250150,0x00000000}},	//   _lại_, _дату, _tdl_,
  { {0x3ea90974,0xf1b9017f,0xbcfb0026,0x00000000}},	//   _amat_, jaše_, rvél,
  { {0x3f911994,0xf1b9007d,0xaec61111,0x00000000}},	//   ázu_, daše_, йбол,
  { {0xbebd001c,0xdc0c0006,0x290501b3,0x00000000}},	//   esīb, rėči, _član_,
  { {0x24850019,0x9f8d004b,0x3afc0013,0x00000000}},	//   _kolm_, _rõõm_, _síp_,
  { {0xfc036cdb,0xdce40195,0xf1b90130,0x00000000}},	//   зпро, _trič, gaše_,
  { {0xdca341b8,0x7ae400e0,0x98a9007d,0x00000000}},	//   чари, tmit, grač_,
  { {0x7ae46cdc,0x629b0072,0x6d41003b,0x00000000}},	//   umit, nhuo, ălar,
  { {0x7c96006a,0x7ae418f5,0xe9da1dd0,0x00000000}},	// [ef20] _هشدا, rmit, ука_,
  { {0xaa7b0024,0xc6100053,0x7ae46cdd,0x00000000}},	//   _chýb, ार्य_, smit,
  { {0xf9890ca4,0x91c90053,0xe7e30082,0x00000000}},	//   ער_, _हुसै, केला_,
  { {0x26df0035,0x798d00a4,0x66e30094,0x00000000}},	//   _chuo_, byaw, поха,
  { {0xceb30063,0xa3f4045b,0xd6cf043e,0x00000000}},	//   היא_, оплі, رقه_,
  { {0xb8960032,0x98a0007d,0x24850d17,0x00000000}},	//   _السع, drić_, _colm_,
  { {0xa3e20161,0xa2780076,0x60c80066,0x00000000}},	//   नें_, ибку_, vodm,
  { {0xf1b9007d,0x66d854d8,0xe81c0042,0x00000000}},	//   zaše_, míko, _पड़ता_,
  { {0xd0100032,0xb5fd2029,0x7ce000ca,0x00000000}},	//   ولة_, _inšp, oörd,
  { {0x443806a5,0x212b0139,0x30a30054,0x00000000}},	//   _ør_, ácha_, зрюв,
  { {0x443e132e,0xbebd001c,0x752200bd,0x00000000}},	//   _ict_, krīt, lsoz,
  { {0xa2f7014e,0x7d160185,0x7ce00832,0x00000000}},	//   _המאה_, _bwys, hörd,
  { {0x3f9e0051,0xf1b9007d,0xdceb0066,0x00000000}},	//   sztu_, taše_, žičo,
  { {0x66d10c4a,0xfaf30021,0x6723027c,0x00000000}},	//   råki, كثر_, šnji,
  { {0xf1b900fc,0x6280159a,0xda4b0363,0x00000000}},	//   raše_, ojmo, лчал_,
  { {0x3ea9014f,0x201a004b,0x66d80195,0x00000000}},	//   _umat_, _õpib_, díko,
  { {0x7ce02063,0xfe700021,0x443e6cde,0x00000000}},	// [ef30] förd, _أدى_, _oct_,
  { {0x798d003e,0x7ce000ea,0x201e6cdf,0x00000000}},	//   ryaw, görd, nati_,
  { {0x69c10045,0x23a70161,0xf3f1001b,0x00000000}},	//   _śled, _केंद, _tại_,
  { {0x201e6ce0,0x3eb913f3,0x443e6ce1,0x00000000}},	//   hati_, nnst_, _act_,
  { {0x3eb90037,0x2a3a0047,0x201e6ce2,0x00000000}},	//   inst_, _דערמ, kati_,
  { {0x201e1179,0x69dd6ce3,0xbcfb00ea,0x00000000}},	//   jati_, _izse, evék,
  { {0xd6db005a,0x201e69f8,0xa5c30051,0x00000000}},	//   _бта_, dati_, _łódz,
  { {0x65860014,0x4105210d,0x7ce000a5,0x00000000}},	//   ðuhó, озив, möre,
  { {0x2ee0001f,0x201e0387,0x05bb0044,0x00000000}},	//   _rhif_, fati_, _صدرت_,
  { {0x201e6ce4,0x3eb90c84,0x7d16001f,0x00000000}},	//   gati_, enst_, _rwys,
  { {0x56b50047,0x661b006f,0x7ce00137,0x00000000}},	//   ַפֿן_, _keuk, nöre,
  { {0x7d160185,0x7af800ea,0x25f00042,0x00000000}},	//   _pwys, _évti, ुँची_,
  { {0x7ce000bd,0x201e6ce5,0xb2240054,0x00000000}},	//   höre, bati_, _хміл,
  { {0x201e5146,0x6722001c,0xb87b00cd,0x00000000}},	//   cati_, ņoji, _guíx,
  { {0xe5190053,0xbebd0023,0x8fa50145,0x00000000}},	//   नीति_, trīt, _файе,
  { {0x83fc017f,0x29d6005d,0x4a460085,0x00000000}},	//   _mađa, قيزس, ўнав,
  { {0x7e7600a4,0xd9431b9c,0x7ce03420,0x00000000}},	// [ef40] _inyp, мети, törd,
  { {0x7ce000c7,0x7e640035,0x7c9602b3,0x00000000}},	//   före, _haip, _фриц,
  { {0xc8150086,0x160a0021,0x7ce03420,0x00000000}},	//   яєть, لياً_, rörd,
  { {0x7bde00c3,0xc8690063,0x201e6ce6,0x00000000}},	//   _izpu, כן_, zati_,
  { {0x7e6400bb,0x201e1d29,0x38636ce7,0x00000000}},	//   _maip, yati_, _fajr_,
  { {0x6c7a00b5,0x6d466ce8,0x7e646ce9,0x00000000}},	//   שאַפ, itka, _laip,
  { {0x201e6cea,0x6d46004b,0x7522004d,0x00000000}},	//   vati_, htka, ssoz,
  { {0x09de0235,0x7e646ceb,0x201e076b,0x00000000}},	//   _मराठ, _naip, wati_,
  { {0x60f7000d,0x66d80066,0x201e6cec,0x00000000}},	//   оныя_, níkm, tati_,
  { {0xdb1e0164,0x9179008b,0xf487005d,0x00000000}},	//   _expé, uất_, _والی,
  { {0x02060088,0x57fb0063,0x201e6ced,0x00000000}},	//   _дзен, יליו, rati_,
  { {0xeeab270f,0x201e6cee,0x7e6400be,0x00000000}},	//   рток_, sati_, _caip,
  { {0x6fca016a,0x201e3b36,0x6d4601e1,0x00000000}},	//   _सुरू, pati_, gtka,
  { {0xcce70021,0x64580f4f,0x9ccb082d,0x00000000}},	//   تسجي, nevi, рыма_,
  { {0x7ce000c7,0x6458001c,0x386d005b,0x00000000}},	//   förb, ievi, _ğer_,
  { {0xf1b900a8,0x386d0058,0xd2590023,0x00000000}},	//   laša_, _şer_, boņu_,
  { {0x66d80024,0xb5fd017f,0x661b0104,0x00000000}},	// [ef50] ríkl, _naša, _reuk,
  { {0x7ce00502,0xf1b908ea,0xa3cd0053,0x00000000}},	//   töre, naša_, रथम_,
  { {0x64586cef,0x96750085,0x661b0050,0x00000000}},	//   devi, зылі, _peuk,
  { {0x201c6cf0,0x7ce02502,0x83fc007d,0x00000000}},	//   _levi_, röre, _rađa,
  { {0xa4d50086,0x260a0053,0xf1b90130,0x00000000}},	//   поді, ाड़ी_, kaša_,
  { {0x64586cf1,0xf3f1008d,0xf1b90130,0x00000000}},	//   gevi, _oạt_, jaša_,
  { {0xe2910021,0x68fd0a3f,0xa357005d,0x00000000}},	//   فذة_, _husd, تیاط_,
  { {0x3bbc0063,0x7d0001c8,0x00000000,0x00000000}},	//   ימוד, ímsk,   ,
  { {0xdb0a0a63,0x64582494,0x20d50603,0x00000000}},	//   čnéh, bevi, зінс,
  { {0x64586cf2,0x7659001f,0x66d100d1,0x00000000}},	//   cevi, lewy, råku,
  { {0x201c051e,0x5f05000d,0x68f50075,0x00000000}},	//   _devi_, язна, _mizd,
  { {0x7659001f,0xc3320ee1,0x290b0066,0x00000000}},	//   newy, _טוב_, _otca_,
  { {0x0d76000d,0x6d4604aa,0xdd92002a,0x00000000}},	//   чыня, utka, روس_,
  { {0xe0d80086,0x649d01a8,0x672501e1,0x00000000}},	//   _дві_, _fèie, kshj,
  { {0x68fd00bd,0x7d0f000f,0x6d4b0137,0x00000000}},	//   _ausd, apcs, _ägan,
  { {0x244f005b,0x68f50df9,0xdb0f00ea,0x00000000}},	//   lımı_, _aizd, ójár,
  { {0x68f5005b,0x76591150,0x2caa0062,0x00000000}},	// [ef60] _bizd, dewy, _гкпп_,
  { {0x244f005b,0x68fd006f,0x64416cf3,0x00000000}},	//   nımı_, _dusd, _ncli,
  { {0x3b0a0001,0x6458069f,0xb5fd001c,0x00000000}},	//   _ћемо_, vevi, _saša,
  { {0xb5fd1b74,0x765900e8,0x61f9001f,0x00000000}},	//   _paša, gewy, _ngwl,
  { {0x64586cf4,0x244f005b,0x200746c0,0x00000000}},	//   tevi, kımı_, _ofni_,
  { {0xb5fd08b7,0x644a6cf5,0xa3d4012f,0x00000000}},	//   _vaša, uffi, молч,
  { {0x644a001f,0xd4d9000d,0x289b07e9,0x00000000}},	//   rffi, цьці_, _פילא,
  { {0x64586cf6,0x77bb0063,0x6441055b,0x00000000}},	//   sevi, _המלח, _ecli,
  { {0x7afe000c,0x41530121,0xb5fd12bf,0x00000000}},	//   _lupt, евыс, _kašn,
  { {0x6722003d,0x2f010051,0x64410139,0x00000000}},	//   ņoju, _bóg_, _gcli,
  { {0xf1b900b2,0x93bc00dd,0x7afe1806,0x00000000}},	//   raša_, _odăi, _nupt,
  { {0x2007007a,0x321d00ac,0xbfa70121,0x00000000}},	//   _efni_, _gewy_, ятые_,
  { {0x244f005b,0x6d5d006f,0xd12f0021,0x00000000}},	//   bımı_, uwsa, _ممن_,
  { {0xe7be0053,0x68fd017e,0xcfb40062,0x00000000}},	//   ्थाप, _rusd, _облъ,
  { {0x66d80026,0x7afe003b,0x2cb1013d,0x00000000}},	//   ríkj, _cupt, rizd_,
  { {0x68f5005b,0x62860ff2,0xf8b1005d,0x00000000}},	//   _sizd, ökoh, چکس_,
  { {0xa9540086,0x442c6cf7,0x83fc007d,0x00000000}},	// [ef70] нкті, _odd_, _nađo,
  { {0x7d0d2e69,0xd7950062,0xd7fb1224,0x00000000}},	//   _itas, мизъ, суа_,
  { {0x59f90055,0xf09300b5,0x765900ac,0x00000000}},	//   _меня_, ענע_, tewy,
  { {0xddcd00c3,0x442c6cf8,0x6441003b,0x00000000}},	//   _znaš, _add_, _scli,
  { {0x290b00ea,0x244f0058,0x83fc0130,0x00000000}},	//   _utca_, yımı_, _vađn,
  { {0x2a690004,0xe3b0007e,0x39496cf9,0x00000000}},	//   ldab_, گره_, mtas_,
  { {0x6e2d0117,0x42e90121,0x39490c79,0x00000000}},	//   _odab, омко_, ltas_,
  { {0x2a690004,0x66d100df,0x39496cfa,0x00000000}},	//   ndab_, råks, otas_,
  { {0x7ce000c7,0xa1560001,0x244f005b,0x00000000}},	//   höra, дању_, tımı_,
  { {0x26cf6cfb,0x39496cfc,0xaf050505,0x00000000}},	//   logo_, itas_, мпол,
  { {0x244f005b,0xd2510021,0x7d0d6ccd,0x00000000}},	//   rımı_, _لنا_, _atas,
  { {0x656d0024,0x66d80026,0x39496cfd,0x00000000}},	//   ťahu, víkk, ktas_,
  { {0x5045000a,0x442c002b,0x244f0058,0x00000000}},	//   _желб, _ydd_, pımı_,
  { {0x7ce000c7,0x2f010025,0x39496cfe,0x00000000}},	//   föra, _tóg_, dtas_,
  { {0x316d61ee,0x9f4300fe,0xcee9006a,0x00000000}},	//   lvez_, äjä_, ترین_,
  { {0xa3e20161,0x3b07000a,0x752900a8,0x00000000}},	//   नेट_, ќето_, _ovez,
  { {0x628b0198,0x39460088,0x26cf0035,0x00000000}},	// [ef80] _mogo, ьнаг, dogo_,
  { {0xddc401d9,0x660913d7,0xe73a0054,0x00000000}},	//   _kniž, _afek, жеж_,
  { {0x628b1986,0x26cf6cff,0x39496d00,0x00000000}},	//   _oogo, fogo_, atas_,
  { {0x628b01b3,0x00000000,0x00000000,0x00000000}},	//   _nogo,   ,   ,
  { {0x39490942,0xdb1e0022,0x6fcf0042,0x00000000}},	//   ctas_, _typó, _सुसं,
  { {0xe2f8000d,0x430a1406,0x66096d01,0x00000000}},	//   пекі_, охим_, _efek,
  { {0xbcfb000f,0x628b6802,0xf6260d34,0x00000000}},	//   lvét, _bogo, _одво,
  { {0xa6860088,0x29122e10,0x2242004b,0x00000000}},	//   _ўлад, opya_, ükk_,
  { {0x628b331a,0x5273005e,0x50f405ce,0x00000000}},	//   _dogo, тују, нзит,
  { {0x29120035,0x497b0047,0x74130021,0x00000000}},	//   ipya_, קטיװ, _لوكا,
  { {0x75291312,0xf837014e,0xdeb50076,0x00000000}},	//   _zvez, ונית_, ебны,
  { {0x39490006,0xe7e60053,0xb5fd068a,0x00000000}},	//   ytas_, _करना_, _našl,
  { {0xa06a0001,0x41e20053,0x30340121,0x00000000}},	//   _мада_, _परिस, _зелё,
  { {0x7ce00b6e,0x212b006c,0x61e26d02,0x00000000}},	//   töra, âche_, _izol,
  { {0xdfd00032,0xbcfb00ea,0x46ce0042,0x00000000}},	//   _حيث_, evét, ़वाह,
  { {0x39490ddc,0xb5fd0006,0xdb0e00ea,0x00000000}},	//   ttas_, _rašo, ájáb,
  { {0xddc414d5,0x2a69004b,0x7d0d6d03,0x00000000}},	// [ef90] _zniž, rdab_, _utas,
  { {0xf84b0085,0x7bc00058,0x394941a2,0x00000000}},	//   ўчай_, ğmur, rtas_,
  { {0x87040086,0x29120035,0x752969fd,0x00000000}},	//   вяче, apya_, _svez,
  { {0xb5fd6d04,0x26cf0290,0x39496d05,0x00000000}},	//   _vašo, uogo_, ptas_,
  { {0x27ff005b,0x26cf32d5,0x7aed6d06,0x00000000}},	//   _şunu_, rogo_, mmat,
  { {0x7aed0d47,0xb5fd6271,0x7ce0092e,0x00000000}},	//   lmat, _zašl, hörn,
  { {0x628b1c6b,0xe29959f7,0x82f50a55,0x00000000}},	//   _pogo, зай_, нчиц,
  { {0x7ce00026,0x7aed6d07,0xc2450962,0x00000000}},	//   jörn, nmat, хник,
  { {0xf1b90006,0x224d00ac,0x316d0003,0x00000000}},	//   rašo_, rfek_, uvez_,
  { {0x93bc0529,0xdced08c1,0x7aed0520,0x00000000}},	//   _adău, _brač, hmat,
  { {0xbcfb00ea,0x7aed6d08,0xc0a8014d,0x00000000}},	//   zvét, kmat, بايل_,
  { {0xf7720047,0x7aed0249,0xed5a5fa0,0x00000000}},	//   אקט_, jmat, пом_,
  { {0xdb0a0080,0x7aed57b6,0x6fcf0042,0x00000000}},	//   čníh, dmat, _सुरं,
  { {0x66d80026,0x7aed457a,0xbcfb013d,0x00000000}},	//   ríki, emat, evés,
  { {0xb5fd001c,0xdced007d,0xa09a0aeb,0x00000000}},	//   _pašl, _grač, _מיסט,
  { {0xbcfb013d,0xba170044,0x7aed6d09,0x00000000}},	//   tvét, فيفا_, gmat,
  { {0x6e2600bb,0x510c0047,0xdced02e2,0x00000000}},	// [efa0] makb, ַהאַ, _zrač,
  { {0xe9df0268,0x38a40026,0x7aed6d0a,0x00000000}},	//   _abús_, _mörg_, amat,
  { {0x6f0b0529,0x3ea001e1,0x7aed5a64,0x00000000}},	//   _încă, _klit_, bmat,
  { {0xd7ef0032,0x98c00058,0xf3f10013,0x00000000}},	//   حكم_, ırıp_, _rạp_,
  { {0xbcfb006c,0x54fa0082,0xf9fb009a,0x00000000}},	//   lvér, एआइए_, _מהכמ,
  { {0x3ea000cd,0xf36604c3,0xd4e30e82,0x00000000}},	//   _llit_, етин, лющи,
  { {0x61e2000f,0x37e30086,0xcc3b0047,0x00000000}},	//   _szol, _борг, לעסט,
  { {0x754900ea,0x29023928,0xc27402f8,0x00000000}},	//   öszö, _kuka_, тлиј,
  { {0x6e260150,0x7ce00014,0x5bbd0042,0x00000000}},	//   dakb, vörn, _ईश्व,
  { {0x29020c64,0x7aed6d0b,0xf3f10013,0x00000000}},	//   _muka_, zmat, _tạp_,
  { {0x29026d0c,0x7aed1451,0x7ce02957,0x00000000}},	//   _luka_, ymat, törn,
  { {0xdced1253,0x71a6000d,0x6562004d,0x00000000}},	//   _vrač, _паез, owoh,
  { {0xf8bf0080,0x656200bd,0x7aed6d0d,0x00000000}},	//   _svém_, nwoh, vmat,
  { {0xe04a007e,0xbddb0003,0x7aed09fe,0x00000000}},	//   _رشته_, ffèr, wmat,
  { {0x29020627,0x75f6005b,0x7aed6d0e,0x00000000}},	//   _auka_, _yüzü, tmat,
  { {0x2902053b,0x28d90053,0x7aed6d0f,0x00000000}},	//   _buka_, _बीजि, umat,
  { {0x200b0045,0x1958026c,0x7aed2e2d,0x00000000}},	// [efb0] ście_, наты_, rmat,
  { {0x290f001c,0x29026d10,0x58d80121,0x00000000}},	//   īga_, _duka_, едуя_,
  { {0x6562004d,0x7aed6d11,0x00000000,0x00000000}},	//   ewoh, pmat,   ,
  { {0x6aa46d12,0x7ce00e77,0xd7c8043e,0x00000000}},	//   chif, hörl, رونه_,
  { {0xb5fd017f,0xd469007b,0x38a400a5,0x00000000}},	//   _hašk, диле_, _börd_,
  { {0x22980026,0x6e2600ea,0x5fb20053,0x00000000}},	//   _fékk_, zakb, ुपाल,
  { {0x64a2047e,0x98a90051,0x753c008f,0x00000000}},	//   раща, erać_, _ārze,
  { {0xe7e60161,0x67d40121,0x6562004d,0x00000000}},	//   _करता_, _сосу, bwoh,
  { {0x7ce04715,0xb5fd6d13,0x6e26013d,0x00000000}},	//   förl, _lašk, vakb,
  { {0x2ebc0161,0x3075005e,0x3ea012a9,0x00000000}},	//   ोक्त, туис, _slit_,
  { {0x6e2600bb,0x44274430,0x75f60058,0x00000000}},	//   takb, man_, _tüzü,
  { {0x98a90045,0x64434cba,0x44272fb9,0x00000000}},	//   brać_, lgni, lan_,
  { {0x7ce00137,0x61450f55,0x38a4004d,0x00000000}},	//   börl, _рела, _höre_,
  { {0x7f850021,0x29026d14,0x44270859,0x00000000}},	//   _للتن, _ruka_, nan_,
  { {0x2902053b,0x44271f1f,0x6e260150,0x00000000}},	//   _suka_, ian_, pakb,
  { {0x62896d15,0x3ea0002c,0x44276d16,0x00000000}},	//   njeo, _ulit_, han_,
  { {0x44270cec,0xbddb00cd,0x3cca0062,0x00000000}},	// [efc0] kan_, sfèr, _олио_,
  { {0x6f03003e,0xb7960001,0x6e24001f,0x00000000}},	//   _kunc, крећ, _heib,
  { {0x7d041799,0x9182008b,0x6f031b85,0x00000000}},	//   _huis, iết_, _junc,
  { {0x6f036d17,0x7d041668,0x44274b97,0x00000000}},	//   _munc, _kuis, ean_,
  { {0x7d040122,0x442710c1,0xb5fd0240,0x00000000}},	//   _juis, fan_, _zašk,
  { {0x644301e3,0x7d04024a,0x44271add,0x00000000}},	//   ggni, _muis, gan_,
  { {0x6f031118,0x394026ad,0x7d046d18,0x00000000}},	//   _nunc, luis_, _luis,
  { {0x68fc03e8,0x2cb800e5,0x6443210b,0x00000000}},	//   _hird, hird_, agni,
  { {0x60f8005a,0x44272349,0x7ce046bb,0x00000000}},	//   нния_, ban_, törl,
  { {0x38a400c7,0x66d80026,0x44276d19,0x00000000}},	//   _före_, ríku, can_,
  { {0x38a401f7,0x39400179,0x883b0063,0x00000000}},	//   _göre_, huis_, ותיו,
  { {0x7ce0005b,0x83fc007d,0x52760021,0x00000000}},	//   sörl, _nađi, _جائز,
  { {0x7d041cac,0x6143000d,0x68fc0139,0x00000000}},	//   _cuis, _веча, _oird,
  { {0xd197014e,0x7d041203,0x6abd0053,0x00000000}},	//   _בכדי_, _duis, ्क्र,
  { {0xeb040076,0xcf8f0001,0xda35093e,0x00000000}},	//   ичто, _тј_, левы,
  { {0x44276d1a,0x68fc0770,0xb5fd0ed9,0x00000000}},	//   zan_, _aird, _vašk,
  { {0x3eb91fc9,0x44276d1b,0x4975000d,0x00000000}},	// [efd0] mist_, yan_, ылас,
  { {0xb5fd2365,0x48140086,0x44276d1c,0x00000000}},	//   _tašk, имус, xan_,
  { {0x3eb90025,0x7e6d1e4d,0x44276d1d,0x00000000}},	//   oist_, _kaap, van_,
  { {0x44272fbe,0x7e6d0a26,0x394000ca,0x00000000}},	//   wan_, _jaap, buis_,
  { {0x442703f9,0x7c250b64,0x9182008b,0x00000000}},	//   tan_, _kehr, yết_,
  { {0xdfc60032,0x68fc1a8d,0xbddb0003,0x00000000}},	//   _هي_, _gird, ygèn,
  { {0x7c250199,0x3eb94083,0x44271506,0x00000000}},	//   _mehr, kist_, ran_,
  { {0x69dd024a,0x7afd0080,0x6f036d1e,0x00000000}},	//   _kyse, _jist, _runc,
  { {0x6f03017f,0x44275299,0x3eb9010e,0x00000000}},	//   _sunc, pan_, dist_,
  { {0xf992014e,0x69dd04ff,0x6f036d1f,0x00000000}},	//   צרי_, _myse, _punc,
  { {0x7ce000c7,0x3eb90026,0x7afd00fe,0x00000000}},	//   börj, fist_, _oist,
  { {0xbddb00cd,0x7d046d20,0x7afd64d5,0x00000000}},	//   rgèn, _puis, _nist,
  { {0x6e240031,0x7d040b23,0x386100bd,0x00000000}},	//   _veib, _quis, kehr_,
  { {0x7afd0027,0x3ebe000f,0x6e2400bd,0x00000000}},	//   _aist, őtt_, _weib,
  { {0x7afd0add,0xc0520063,0xfaa6000d,0x00000000}},	//   _bist, _הזו_, гаво,
  { {0x7d046d21,0xaf02005a,0x69dd001f,0x00000000}},	//   _tuis, _упъл, _byse,
  { {0x3edb0047,0x6d4f006f,0xb5fd0392,0x00000000}},	// [efe0] _אַזא, ctca, _faši,
  { {0x4425104f,0x7afd264c,0x39400229,0x00000000}},	//   _nel_, _eist, ruis_,
  { {0x96ba0001,0x9fa20026,0x6ac6002a,0x00000000}},	//   нуду_, níða_, _مقدم,
  { {0x394003b2,0x7afd6d22,0xfbd30063,0x00000000}},	//   puis_, _gist, _לתת_,
  { {0x68fc001c,0x93bc003b,0x44256d23,0x00000000}},	//   _tird, _adăp, _bel_,
  { {0x7afd0024,0x44256d24,0x3eb96d25,0x00000000}},	//   _zist, _cel_, zist_,
  { {0x44252d58,0x07d8007e,0xd4910013,0x00000000}},	//   _del_, _شهرک_, _dò_,
  { {0x7ce00137,0x7afd6d26,0xd134005e,0x00000000}},	//   förk, _xist, анић,
  { {0xe6930032,0x3eb90b40,0x44256d27,0x00000000}},	//   _القد, vist_, _fel_,
  { {0x2e24001b,0x7e6d00fe,0x3eb92493,0x00000000}},	//   _đườn, _saap, wist_,
  { {0x2d9900e8,0xb5fd610a,0xd8d70149,0x00000000}},	//   wyse_, _raši, רויט_,
  { {0x2d990006,0x3eb91986,0x7c256110,0x00000000}},	//   tyse_, uist_, _sehr,
  { {0xa2d3007e,0x44250370,0x9cb50021,0x00000000}},	//   _اينت, _yel_, لمحت,
  { {0x30760001,0x3eb9010e,0xdbdf0014,0x00000000}},	//   _људс, sist_, _bíði,
  { {0xab840086,0x709b0047,0x447b0047,0x00000000}},	//   бутк, _אױגו, ענלע,
  { {0x7c254ae6,0x38612087,0xc987006e,0x00000000}},	//   _wehr, wehr_, лузи,
  { {0x7afd6d28,0xf1b900b2,0x7c256d29,0x00000000}},	// [eff0] _vist, taši_, _tehr,
  { {0x9c470086,0x7afd1c79,0x69dd011b,0x00000000}},	//   _схил, _wist, _vyse,
  { {0x7afd0198,0xa9240078,0x69dd1c6e,0x00000000}},	//   _tist, _įžei, _wyse,
  { {0x7afd1401,0xaa670713,0x44254ce6,0x00000000}},	//   _uist, _сток, _sel_,
  { {0x44250994,0x7ce00137,0x9425000d,0x00000000}},	//   _pel_, förh, амле,
  { {0xd491001b,0xb9ba0063,0xa4d40054,0x00000000}},	//   _tìm_, _יצרת, бочі,
  { {0x98a00006,0x44256d2a,0xddc40078,0x00000000}},	//   usią_, _vel_, _maiš,
  { {0xddc40812,0x44256b92,0xd6c3007e,0x00000000}},	//   _laiš, _wel_, _امری,
  { {0x844703eb,0x38a40137,0x44256d2b,0x00000000}},	//   _مخال, _höra_, _tel_,
  { {0x40950076,0x38a400c7,0xddc4007d,0x00000000}},	//   ррит, _köra_, _naiš,
  { {0x9216016a,0xaec60076,0x8e863515,0x00000000}},	//   _ध्वज_, ибол, агне,
  { {0x6da60021,0x3f650003,0x9fa20014,0x00000000}},	//   لمجم, _vœu_, ríða_,
  { {0x9fa20026,0xee370065,0x7ce0004b,0x00000000}},	//   síða_, шня_, löri,
  { {0x61e601f7,0x659a0047,0x8c4601ce,0x00000000}},	//   ükle, דישק, јеве,
  { {0x8a0607b3,0x00ba009a,0xdee601e2,0x00000000}},	//   изве, _במסמ, _коки,
  { {0x6f0d0066,0x7bde0114,0x00000000,0x00000000}},	//   _čach, _vypu,   ,

  { {0x7ce02063,0x7bde0022,0xdd150066,0x00000000}},	// [f000] höri, _wypu, _zúžt,
  { {0xdbdf0014,0xe8830002,0x7bde16f8,0x00000000}},	//   _tíði, огуп, _typu,
  { {0x6e360080,0x4c3b0063,0xdc3b009a,0x00000000}},	//   _kdyb, _בתיב, _בעיר,
  { {0xe7370cd6,0xcf56009d,0xee09009d,0x00000000}},	//   рец_, יבעת_, ְמוֹ_,
  { {0x25a0018d,0xa8060076,0x68eb00ea,0x00000000}},	//   áil_, _взгл, üldé,
  { {0x7ce000c7,0xb5fd0006,0x38a40137,0x00000000}},	//   föri, _našu, _föra_,
  { {0x38a401e3,0xb7da007e,0x7ce000a5,0x00000000}},	//   _göra_, _شورا_, göri,
  { {0xcb130063,0x3952005f,0x93770094,0x00000000}},	//   חלה_, otys_, рбът_,
  { {0x395200eb,0xe5a30086,0x04460a74,0x00000000}},	//   ntys_, _дити, _везн,
  { {0xc9530063,0x39520078,0xb5fd34fb,0x00000000}},	//   קמת_, itys_, _pašv,
  { {0x4fc60088,0xbebd001c,0x645a0150,0x00000000}},	//   рспа, ksīt, _ibti,
  { {0xddc4001c,0x39520078,0x7de10046,0x00000000}},	//   _saiš, ktys_, jású,
  { {0x6dcb0085,0x6e36002b,0xddc4005f,0x00000000}},	//   тынг_, _ddyb, _paiš,
  { {0x20d30044,0x9d182df7,0x6b9c00a3,0x00000000}},	//   _وتوج, рорт_, fyrg,
  { {0x6282006f,0xddc4005f,0x501b009a,0x00000000}},	//   _knoo, _vaiš, _יוגו,
  { {0xb3450016,0x6e360051,0x201e0006,0x00000000}},	//   luçã, _gdyb, lbti_,
  { {0x645a6d2c,0xf8071533,0xb5fd017c,0x00000000}},	// [f010] _obti, ачен, _jašt,
  { {0x645e0019,0xb0650019,0x2bd20053,0x00000000}},	//   õpil, mmää, _दुका,
  { {0x7ea60026,0xb06500fe,0x39520078,0x00000000}},	//   _hópa, lmää, atys_,
  { {0x02f00058,0xd6180593,0xcb12009a,0x00000000}},	//   üçlü_, لتها_, _מלט_,
  { {0xb06500fe,0xb5fd1d14,0x2bdb0053,0x00000000}},	//   nmää, _našt, _मुता,
  { {0x38a40137,0x26c60072,0x8365005d,0x00000000}},	//   _hörn_, anoo_, مدعل,
  { {0xb34503d9,0xb06500fe,0xddc4000c,0x00000000}},	//   duçã, hmää, _obiş,
  { {0x224b00bd,0x86c5007e,0x36d40f8d,0x00000000}},	//   ück_, _ايرن, _доср,
  { {0x2003085a,0x04670002,0xb5fd3187,0x00000000}},	//   žjim_, _втем, _pašu,
  { {0xa069005e,0x10a50988,0xf739009d,0x00000000}},	//   ћана_, сион, ְעָם,
  { {0x4e2a030b,0x1fb50183,0x00000000,0x00000000}},	//   лонн_, сспр,   ,
  { {0x39520072,0x975a0063,0xa2f5005e,0x00000000}},	//   ytys_, נדרט, _упеч,
  { {0xc108008b,0xee3f0061,0x6b9c002b,0x00000000}},	//   _hỗn_, chým_, wyrg,
  { {0x98a70080,0xb3450016,0x61eb152f,0x00000000}},	//   čně_, cuçã, _izgl,
  { {0xb5fd0117,0xf1b90006,0x38a40014,0x00000000}},	//   _zašt, rašu_, _börn_,
  { {0xad9b017d,0x8f9a0063,0xbebd008f,0x00000000}},	//   rcúr, _תיקי, usīt,
  { {0x6d401084,0xf3f1008d,0x99160085,0x00000000}},	// [f020] ámad, _vạy_, сьбі,
  { {0x6d460c86,0x765b0150,0x673e007d,0x00000000}},	//   muka, _abuy, trpj,
  { {0x6d4b00c7,0xc8150086,0x36060021,0x00000000}},	//   _ägar, юєть, مواف,
  { {0x7c2e6d2d,0xd6d90086,0x657b00a8,0x00000000}},	//   labr, аті_, _bruh,
  { {0x6d460b45,0x3f51008d,0x3edb0041,0x00000000}},	//   nuka, háu_, אַגא,
  { {0x657b016b,0xb5fd0a1c,0x7ae46d2e,0x00000000}},	//   _druh, _rašt, llit,
  { {0x3e7f00fe,0x6d466c99,0x7ae46d2f,0x00000000}},	//   _jätä_, huka, olit,
  { {0xb5fd0812,0xc1140fe2,0x6b8302dd,0x00000000}},	//   _pašt, омиј, _ánge,
  { {0x6d461cf4,0xba9b07e9,0x1a9b0047,0x00000000}},	//   juka, טסקי, טיקע,
  { {0x307a0032,0x39400025,0x6d460231,0x00000000}},	//   احظة_, iris_, duka,
  { {0xb345017d,0x201e0006,0x7ae46d30,0x00000000}},	//   ruçã, rbti_, klit,
  { {0xdced017f,0x64585e95,0xb5fd007d,0x00000000}},	//   _krać, lfvi, _tašt,
  { {0xf1940055,0x644a00b9,0x6d466d31,0x00000000}},	//   _филь, ogfi, guka,
  { {0x442e1be5,0x7ae46d32,0xb065112c,0x00000000}},	//   naf_, elit, rmää,
  { {0xb0650213,0x442e001f,0x39406d33,0x00000000}},	//   smää, iaf_, eris_,
  { {0x6d4600bb,0x394000ac,0xfa190001,0x00000000}},	//   buka, fris_, ржај_,
  { {0x442e6d34,0x26c717a6,0x60da004b,0x00000000}},	// [f030] kaf_, énom_, ootm,
  { {0x37ab00d7,0x442e6d35,0x7c2e6d36,0x00000000}},	//   лтен_, jaf_, cabr,
  { {0x39406d37,0x442e002b,0x6aa3003b,0x00000000}},	//   aris_, daf_, _înfo,
  { {0xdced14d8,0xc519000d,0x39406d38,0x00000000}},	//   _brać, аўкі_, bris_,
  { {0x4efc0047,0x39403fe3,0xdddd0022,0x00000000}},	//   אלאג, cris_, lesł,
  { {0x644a3144,0x83390076,0x6aad00bd,0x00000000}},	//   ggfi, ачит_, lhaf,
  { {0x3ea2007a,0x6d460051,0xa316005e,0x00000000}},	//   ykkt_, zuka, ожју_,
  { {0x290302dd,0x3f770529,0x7c2e0253,0x00000000}},	//   _hija_, _rău_, zabr,
  { {0x3f77000c,0xd9fb0053,0x290b3ecf,0x00000000}},	//   _său_, ्शित_, _juca_,
  { {0x3f51001f,0x442e001f,0x3ea96d39,0x00000000}},	//   táu_, caf_, _alat_,
  { {0x61eb0045,0x7ae400fe,0x3ea900cd,0x00000000}},	//   _wzgl, ylit, _blat_,
  { {0x60c80019,0x7ce000bd,0x29190019,0x00000000}},	//   andm, hört, _otsa_,
  { {0x7c2e0233,0x7e660104,0x60da0066,0x00000000}},	//   tabr, rekp, botm,
  { {0x3f77000c,0x2bdb0053,0x6d4624d3,0x00000000}},	//   _tău_, _मुहा, ruka,
  { {0x6d46238e,0x3ea96d3a,0x7c2e6d3b,0x00000000}},	//   suka, _flat_, rabr,
  { {0x7ce0007a,0x78be00e8,0x7d0a0071,0x00000000}},	//   vöru, wipv, _книг_,
  { {0x2903003d,0x442e0185,0x7ce0092e,0x00000000}},	// [f040] _bija_, yaf_, fört,
  { {0x3e7f024a,0x290b1fa6,0x7ce000bd,0x00000000}},	//   _tätä_, _duca_, töru,
  { {0x78be006f,0x6aad004d,0x7659002b,0x00000000}},	//   ripv, bhaf, ffwy,
  { {0xdced0117,0x6aad051d,0x2f5a00b5,0x00000000}},	//   _prać, chaf, ידענ,
  { {0x200702f6,0x2903006d,0x4ecb0047,0x00000000}},	//   _ogni_, _fija_, בזײַ,
  { {0xb5fd003d,0xdced017f,0xb4e40053,0x00000000}},	//   _pašr, _vrać, नते_,
  { {0xb6a60086,0x442e6d3c,0xe73721b9,0x00000000}},	//   _дивл, raf_, _мер_,
  { {0x442e0185,0xd257000d,0x7d1d0137,0x00000000}},	//   saf_, оць_, ypss,
  { {0xdddd0045,0x21040053,0x6aa41358,0x00000000}},	//   zesł, रदेश_, ikif,
  { {0x3f9e23a8,0x3ea96d3d,0x95970063,0x00000000}},	//   tytu_, _slat_, _וכמו_,
  { {0x6ec400ea,0x4fd3000d,0x3ea96d3e,0x00000000}},	//   zőbe, джэт, _plat_,
  { {0x442c3f9b,0x2007001f,0x7eb6008f,0x00000000}},	//   _hed_, _egni_, kšpu,
  { {0x2176000a,0x442c0066,0xcd070505,0x00000000}},	//   _фуер, _ked_, ючни,
  { {0x255e003d,0xa067005a,0x6ec400ea,0x00000000}},	//   mālā_, _мача_, vőbe,
  { {0x442c06a3,0x6f04003b,0x290b007d,0x00000000}},	//   _med_, _fiic, _suca_,
  { {0x3ea900bb,0x7ce02063,0x442c6d3f,0x00000000}},	//   _ulat_, förs, _led_,
  { {0x442c0185,0x7cf200b9,0x7eb6001c,0x00000000}},	// [f050] _oed_, færd, gšpu,
  { {0xfd1f0290,0xab870726,0x6aad6d40,0x00000000}},	//   mpì_, _думк, shaf,
  { {0x6aad0026,0xfd1f0290,0x6e2d0150,0x00000000}},	//   phaf, lpì_, _keab,
  { {0x7d0d0397,0x255e008f,0x442c01dc,0x00000000}},	//   _kuas, kālā_, _aed_,
  { {0x6e2d0025,0x442c212e,0x290300cd,0x00000000}},	//   _meab, _bed_, _tija_,
  { {0x6e2d0027,0x7d0d6d41,0xd5ae0021,0x00000000}},	//   _leab, _muas, طفى_,
  { {0x3949003e,0x9982001c,0x7d0d6d42,0x00000000}},	//   luas_, _iekš_, _luas,
  { {0x442c6d43,0xe3b0014d,0x6e2d4e31,0x00000000}},	//   _eed_, خره_, _neab,
  { {0x0577006a,0x7d0d0025,0x7cf2000e,0x00000000}},	//   _بازد, _nuas, lære,
  { {0xdce40045,0x75290035,0x7fd5000d,0x00000000}},	//   _ksią, _iwez, зімі,
  { {0x2bdb0053,0x7cf20093,0x6e2d004d,0x00000000}},	//   _मुला, nære, _beab,
  { {0x7d0d0302,0x752900ac,0x26dd0022,0x00000000}},	//   _buas, _kwez, nowo_,
  { {0x41290002,0x7cf2000e,0x7d0d0331,0x00000000}},	//   _ѓоко_, hære, _cuas,
  { {0xdce40051,0x75290035,0x711a0063,0x00000000}},	//   _osią, _mwez, _הוספ,
  { {0x7cf20d02,0x6e2d0027,0x60c10290,0x00000000}},	//   værd, _feab, milm,
  { {0x7ce001e3,0xdc3d003d,0x8f9a0063,0x00000000}},	//   törs, kšķu, _ליצי,
  { {0xf2d200b5,0x39490942,0x7d0d5833,0x00000000}},	// [f060] גען_, guas_, _guas,
  { {0x4d7b0047,0x6aa46d44,0x60c10868,0x00000000}},	//   _פריע, skif, nilm,
  { {0x75290035,0x442c5fea,0xd6cf13d3,0x00000000}},	//   _awez, _red_, ет_,
  { {0x62990051,0x6b8100b9,0x3949017d,0x00000000}},	//   _nowo, ælge, buas_,
  { {0x7cf200d1,0x4a7b0063,0xb3a9005b,0x00000000}},	//   mærb, _הרכב, çını,
  { {0x7cf202ab,0x38a406ea,0xd259008f,0x00000000}},	//   bære, _mörk_, viņa_,
  { {0x442c02ab,0x26dd04a4,0x60c1005b,0x00000000}},	//   _ved_, bowo_, dilm,
  { {0x3253005a,0xb909001b,0x442c6d45,0x00000000}},	//   евър, _nghị_, _wed_,
  { {0x62990045,0x15430002,0x6e2d18f5,0x00000000}},	//   _dowo, _петм, _reab,
  { {0xf484006a,0xd259001c,0x255e008f,0x00000000}},	//   _تاری, riņa_, rālā_,
  { {0x7d0d6d46,0x2d806d47,0x6e2d6d48,0x00000000}},	//   _suas, _arie_, _peab,
  { {0x7d0d053b,0x2d806d49,0x60c101a9,0x00000000}},	//   _puas, _brie_, ailm,
  { {0x2d80048c,0x60c16d4a,0xf27b0063,0x00000000}},	//   _crie_, bilm, _לראש,
  { {0x2d8003a8,0x60c16d4b,0x26dd0022,0x00000000}},	//   _drie_, cilm, zowo_,
  { {0x6e2d010e,0x905b0063,0x7ce00137,0x00000000}},	//   _teab, _הכות, törr,
  { {0x7cf201bc,0x39490460,0x2d8001f2,0x00000000}},	//   være, tuas_, _frie_,
  { {0x59390085,0x6e3c009a,0xdebc009d,0x00000000}},	// [f070] юзаў_, _התחד, _למהל,
  { {0x7cf206a5,0xd7fb000d,0x26dd0022,0x00000000}},	//   tære, буе_, wowo_,
  { {0x8d18006a,0xc7c8000d,0xc6e70054,0x00000000}},	//   _وزیر_, пыце_, підп,
  { {0x7cf201e1,0x60c10058,0x79a70601,0x00000000}},	//   rære, zilm, _ерге,
  { {0xb609003d,0x26dd0022,0xf650013a,0x00000000}},	//   višķ, rowo_, ائم_,
  { {0x629900bd,0x26dd0051,0x7b080139,0x00000000}},	//   _sowo, sowo_, _óstá,
  { {0x62990045,0xb609008f,0x26dd0022,0x00000000}},	//   _powo, tišķ, powo_,
  { {0x82f40085,0x00000000,0x00000000,0x00000000}},	//   нчыц,   ,   ,
  { {0x75290009,0x7ce000bd,0x60c12d12,0x00000000}},	//   _uwez, körp, tilm,
  { {0x62990009,0x4fa50481,0x00000000,0x00000000}},	//   _wowo, диов,   ,
  { {0x60c101f7,0x6e4600e1,0x7e766d4c,0x00000000}},	//   rilm, менз, _payp,
  { {0x2d8000eb,0xf6790047,0xed5a0141,0x00000000}},	//   _prie_, קאָמ, оом_,
  { {0xdc13005b,0x63a3002b,0x86360047,0x00000000}},	//   _ağım, lynn, וארג_,
  { {0x3b0a066f,0x51fa009a,0x00000000,0x00000000}},	//   жево_, _והנצ,   ,
  { {0x3bd50076,0x1ae60002,0x6fb20021,0x00000000}},	//   еютс, довм, _لموا,
  { {0x2d80006c,0x0aea045b,0x00000000,0x00000000}},	//   _trie_, ідай_,   ,
  { {0x63a3002b,0x2d8000dd,0xb90600fb,0x00000000}},	// [f080] hynn, _urie_, дзак,
  { {0xfc060076,0xbddb00cd,0x6d4600a4,0x00000000}},	//   _оппо, rgèt, mrka,
  { {0xb3a90058,0x373a16f2,0x076a00de,0x00000000}},	//   çılı, ючаю_, تماً_,
  { {0x9f96014e,0x56930054,0x63a30f8e,0x00000000}},	//   ודעה_, каєт, dynn,
  { {0xb3c30042,0x9553005d,0x00000000,0x00000000}},	//   _वेबख, نخوا,   ,
  { {0x63a3001f,0xf1e10042,0x6d466d4d,0x00000000}},	//   fynn, _पड़न, irka,
  { {0x63a3380f,0xbddb0164,0x38780025,0x00000000}},	//   gynn, ngèr, _iarr_,
  { {0xd13a0076,0xf1a60cbd,0xc1740c46,0x00000000}},	//   охо_, дрон, елищ,
  { {0x7c3e1622,0x760b0063,0xe29f0046,0x00000000}},	//   _odpr, _וּבַ, öða_,
  { {0x63a3001f,0x649400cd,0x4fc625dc,0x00000000}},	//   bynn, _nàix, дсма,
  { {0xc108001b,0x38783c8f,0x63a3001f,0x00000000}},	//   _mỗi_, _marr_, cynn,
  { {0xc108001b,0x6d480051,0xd12f005d,0x00000000}},	//   _lỗi_, ądan, _چمن_,
  { {0xc05a0086,0x6aa3000c,0x6ce70086,0x00000000}},	//   _дій_, _înfi, діве,
  { {0xdce40045,0xfc64005a,0x61fd0240,0x00000000}},	//   _księ, късн, ýsle,
  { {0xad9b0024,0xc108008b,0xbddb0003,0x00000000}},	//   ncúz, _nỗi_, ggèr,
  { {0x3fcb005d,0x539b009a,0x00000000,0x00000000}},	//   _بدهی_, חילו,   ,
  { {0x38780025,0x63a30051,0x75220755,0x00000000}},	// [f090] _barr_, zynn, jpoz,
  { {0x6d5a000c,0x63a300fe,0x29070db4,0x00000000}},	//   ătat, yynn, öna_,
  { {0xdb550121,0x75226d4e,0x2c140042,0x00000000}},	//   _явны, epoz, तुओं_,
  { {0x7cf204aa,0x99970022,0x19956d4f,0x00000000}},	//   mæra, ągły_, _замя,
  { {0x63a3001f,0x3f5800be,0x38780ac9,0x00000000}},	//   wynn, héu_, _farr_,
  { {0x443e6d50,0x63a36d51,0xc9b6069a,0x00000000}},	//   _cdt_, tynn, _טהרת_,
  { {0x25a903f5,0x443e6d52,0x9f4b3817,0x00000000}},	//   šal_, _ddt_, ülük_,
  { {0x6d4650d3,0x3f58017d,0x63a3002b,0x00000000}},	//   yrka, déu_, rynn,
  { {0x2a790150,0x4105032d,0x63a36d53,0x00000000}},	//   _masb_, нзив, synn,
  { {0x3f58017d,0x44f4000d,0xa81b009d,0x00000000}},	//   féu_, _апус, קֵ֖י,
  { {0x7ea60026,0xd2510021,0x26cf6d54,0x00000000}},	//   _hópi, _منا_, ongo_,
  { {0x7ea60024,0x82a4005e,0x0378005d,0x00000000}},	//   _kópi, _ишче, _زحمت_,
  { {0x628b206f,0x81a70021,0x0d8341ab,0x00000000}},	//   _ingo, _تحال, глян,
  { {0x7cf20026,0x6b9a004d,0xc19a00ff,0x00000000}},	//   færa, ätgo, _משני,
  { {0xfaf6015a,0xeb9a208c,0x75226d55,0x00000000}},	//   ечаю, чив_, zpoz,
  { {0x8a060540,0xbddb0003,0xc1080013,0x00000000}},	//   езбе, rgèr, _rỗi_,
  { {0x44270150,0x200b0051,0xd94317db,0x00000000}},	// [f0a0] kbn_, ściu_, лети,
  { {0xe73a000d,0x2bdb0053,0x7c3e01e1,0x00000000}},	//   зеж_, _मुका, _udpr,
  { {0x628b6d56,0xd70a0121,0xe6660781,0x00000000}},	//   _ongo, чнее_, етло,
  { {0xdce40006,0x6ef600ea,0x7c96007e,0x00000000}},	//   _priė, lább, _آشکا,
  { {0x1a9b00b5,0x7ea61088,0xf992007e,0x00000000}},	//   _זיכע, _cópi, _صبح_,
  { {0x6ecb0051,0x75224e6c,0x628b6d57,0x00000000}},	//   rębi, rpoz, _ango,
  { {0xd62a14c6,0x290a00a4,0x75226d58,0x00000000}},	//   _нове_, _iiba_, spoz,
  { {0x290a000f,0xf7000121,0xd3790054,0x00000000}},	//   _hiba_, ниeм_, ьчі_,
  { {0x60f80062,0x7ae30955,0x443e01a8,0x00000000}},	//   мния_, _ínte, _tdt_,
  { {0xdfda005a,0xe5060021,0x60f7000d,0x00000000}},	//   зъм_, _أبري, нныя_,
  { {0xf8b30063,0x6ecb004c,0x6909147d,0x00000000}},	//   רשת_, hřbe, _ožen,
  { {0x234b006a,0x9325005d,0x2bdb0042,0x00000000}},	//   _رسمی_, _شرمن, _मुगा,
  { {0xbcfb0003,0x31660066,0x25a6207d,0x00000000}},	//   ntég, _upoz_, nyol_,
  { {0x3f58017d,0xfe796d59,0x7053043e,0x00000000}},	//   péu_, žů_, _منها,
  { {0xdd91007e,0xee3f0080,0x207b0047,0x00000000}},	//   _چوب_, lkým_, _מאגא,
  { {0x290a0016,0x6d5a003b,0x9f470195,0x00000000}},	//   _aiba_, ătar, _uzná_,
  { {0x7cf200d1,0x7e7d004d,0x290a00be,0x00000000}},	// [f0b0] mærn, mdsp, _biba_,
  { {0x5b150c91,0x7e7d27a8,0x1868005e,0x00000000}},	//   _имот, ldsp, нађи_,
  { {0xe70b4d95,0x6d5d6d5a,0x5bc70044,0x00000000}},	//   ستان_, ltsa, _ستدف,
  { {0x26cf6d5b,0x7e7d242f,0x6d4f00be,0x00000000}},	//   ungo_, ndsp, ouca,
  { {0x3a290089,0x7e7d4280,0x6d5d6d5c,0x00000000}},	//   mbap_, idsp, ntsa,
  { {0x7aed5f8e,0x8458005a,0xd4660001,0x00000000}},	//   llat, ерът_, више_,
  { {0x6d5d0004,0x8c1c0063,0xbcfb0164,0x00000000}},	//   htsa, לוגי, atég,
  { {0x7ea66d5d,0x7e7d1244,0x6d4f007d,0x00000000}},	//   _tópi, jdsp, kuca,
  { {0x442700f3,0x7e7d0e41,0x39496d5e,0x00000000}},	//   pbn_, ddsp, nras_,
  { {0x39490016,0x6d4f4a93,0x9f850054,0x00000000}},	//   iras_, duca, вгод,
  { {0x6ef6000f,0x645e0268,0xaa7b0024,0x00000000}},	//   vább, òpie, _akým,
  { {0x39492f06,0x6d5d55dc,0xff05000d,0x00000000}},	//   kras_, ftsa, ляўн,
  { {0xdcb7008b,0xee3f004a,0x6d4f6d5f,0x00000000}},	//   ẳng_, ckým_, guca,
  { {0x39496d60,0xc05b0054,0x7aed6d61,0x00000000}},	//   dras_, _хід_, elat,
  { {0x6ef6000f,0x39496d62,0x6e960021,0x00000000}},	//   rább, eras_, _للغا,
  { {0x39491143,0x7aed6d63,0x6a860062,0x00000000}},	//   fras_, glat, ълба,
  { {0x39496d64,0x6e3b0014,0x6441143a,0x00000000}},	// [f0c0] gras_, ðube, _odli,
  { {0x7aed10dd,0x61e61013,0xfbd20044,0x00000000}},	//   alat, ükli, _نتج_,
  { {0xdced017f,0x3ea0004b,0x78a30072,0x00000000}},	//   _građ, _koit_, önva,
  { {0x39491e1a,0x76a9019d,0x7aed0110,0x00000000}},	//   bras_, нтів_, clat,
  { {0x7ae4024a,0x290a1687,0x2ab6004c,0x00000000}},	//   moit, _tiba_, ržbě_,
  { {0x7ae43ce0,0x54530086,0x3ea00072,0x00000000}},	//   loit, ивіт, _loit_,
  { {0x7ea60026,0x3ea00162,0x38a4005b,0x00000000}},	//   _hópu, _ooit_, _dört_,
  { {0xee3f0024,0xf7770132,0x38a40026,0x00000000}},	//   tkým_, _בעלי_, _vöru_,
  { {0xb6a3005a,0xbcfb0003,0x7cf200b9,0x00000000}},	//   _титл, ltée, værn,
  { {0xff980002,0x7ae437e0,0x69090734,0x00000000}},	//   екој_, hoit, _nžel,
  { {0xf837014e,0xbcfb0164,0x7ae400fe,0x00000000}},	//   כנית_, ntée, koit,
  { {0x7ae4024a,0x38a400c7,0xbcfb0003,0x00000000}},	//   joit, _körs_, itée,
  { {0x3ea003b2,0x7e7d04d3,0x7ae40ac2,0x00000000}},	//   _doit_, rdsp, doit,
  { {0x394903d9,0x6d5d02ea,0x6d4f6d65,0x00000000}},	//   vras_, rtsa, ruca,
  { {0x9f58024a,0xc3390080,0x3eb26d66,0x00000000}},	//   ärä_, žívá, _flyt_,
  { {0x39490e31,0x6ab6001f,0x7aed6d67,0x00000000}},	//   tras_, ghyf, ulat,
  { {0x7aed44ce,0x394913ed,0x89340021,0x00000000}},	// [f0d0] rlat, uras_, لعلا,
  { {0xd795005a,0x6ef600ea,0x39496d68,0x00000000}},	//   лизъ, mába, rras_,
  { {0x6ef6000f,0x645700cd,0xdced007d,0x00000000}},	//   lába, òxim, _urađ,
  { {0x60c81761,0xc6a70062,0x38a43a7c,0x00000000}},	//   hidm, ързи, _börs_,
  { {0x7cf200b9,0x6ef611ba,0xd1260049,0x00000000}},	//   kærl, nába, _دم_,
  { {0x7cf204aa,0x61eb0022,0x6ef6009c,0x00000000}},	//   jærl, _rygl, iába,
  { {0x2ca100e3,0xd5bf001c,0xf794000d,0x00000000}},	//   _mohd_, _šādu_, _карэ,
  { {0x6ef600ea,0x38a40137,0x60c8004b,0x00000000}},	//   kába, _förs_, eidm,
  { {0x6ef6000f,0x38a440a3,0x38b600b9,0x00000000}},	//   jába, _görs_, _færd_,
  { {0x3ea003b2,0x644100b9,0x7ae46d69,0x00000000}},	//   _soit_, _udli, zoit,
  { {0xb5fd00eb,0x1eca071a,0x61eb0051,0x00000000}},	//   _rašy, елни_, _wygl,
  { {0x60c80078,0x31352184,0x9f62011b,0x00000000}},	//   aidm, _бедр, áván_,
  { {0x7ae4024a,0x3ea06d6a,0x68e500fe,0x00000000}},	//   voit, _voit_, kohd,
  { {0x38b60146,0x3cd5000d,0x68e50072,0x00000000}},	//   _kære_, аўст, johd,
  { {0x2ca5007a,0x6f0d0b48,0x7ae401a9,0x00000000}},	//   ölda_, _fiac, toit,
  { {0x6f0d6d6b,0x2d960076,0xd838007d,0x00000000}},	//   _giac, _брос, _žč_,
  { {0x38b60831,0x7ae40f38,0x6b81000e,0x00000000}},	// [f0e0] _lære_, roit, ålgr,
  { {0x7ae4024a,0x4b260086,0x6aad0023,0x00000000}},	//   soit, _ймов, akaf,
  { {0xbcfb0003,0x6e363886,0x38b601f2,0x00000000}},	//   utée, _keyb, _nære_,
  { {0xbcfb0164,0x44380078,0xf6e50085,0x00000000}},	//   rtée, _žr_, ацін,
  { {0x8e5700b5,0x38a40137,0xbcfb0003,0x00000000}},	//   רינג_, _dörr_, stée,
  { {0x7cf200b9,0x6aa3000c,0xbcfb0003,0x00000000}},	//   kærm, _înfr, ptée,
  { {0x38b600b9,0x38a40137,0x7cf201e1,0x00000000}},	//   _værd_, _förr_, værl,
  { {0x57e70079,0x60c8004d,0x66e61594,0x00000000}},	//   _сдсм_, widm, _соба,
  { {0xd0100032,0x6f0d6d6c,0xc05a02fe,0x00000000}},	//   يلة_, _riac, нін_,
  { {0xbcfb00ea,0x6f0d002b,0x6ef61270,0x00000000}},	//   ztéb, _siac, vába,
  { {0x3f87007d,0x6f0d6d6d,0xc3260330,0x00000000}},	//   _crnu_, _piac, _смек,
  { {0xb5fd00c2,0x6ef66d6e,0x91860593,0x00000000}},	//   _obšl, tába, _مجتم,
  { {0x6f0d0024,0x6909007d,0xa2f70063,0x00000000}},	//   _viac, _džej, _עמדה_,
  { {0x91e3005e,0x31570063,0xb17b016e,0x00000000}},	//   _уоче, _עיון_, _נטור,
  { {0x6ef600ea,0x628000a8,0xa037009d,0x00000000}},	//   sába, odmo, _גאוה_,
  { {0x6ef600ea,0x6280358d,0x8aa461cb,0x00000000}},	//   pába, ndmo, бруд,
  { {0xbcfb0003,0x38350781,0x63aa002b,0x00000000}},	// [f0f0] rtéb, инар, hyfn,
  { {0x6aad0196,0x673e0014,0x6e360075,0x00000000}},	//   skaf, fspj, _zeyb,
  { {0x06150121,0xa61505ac,0xd2590023,0x00000000}},	//   адею, амеч, siņi_,
  { {0x17f80032,0xd5b10021,0x2b4c004c,0x00000000}},	//   اركة_, يفا_, ádce_,
  { {0xa5640021,0xd5480021,0xe6180054,0x00000000}},	//   مدون, هجوم_, уді_,
  { {0xd4690175,0xdb1e017d,0xddd60022,0x00000000}},	//   тике_, _expõ, _abyś,
  { {0x645e00cd,0x63aa002b,0x3e86013d,0x00000000}},	//   òpia, gyfn, lítő_,
  { {0x38b602ab,0xe8e0008b,0x6b882e58,0x00000000}},	//   _være_, _đứa_, ådgi,
  { {0x3e8600ea,0x3495000d,0xe0d9086c,0x00000000}},	//   nítő_, _каар, кви_,
  { {0x1f651b9c,0x05de0053,0xa069005e,0x00000000}},	//   аком, _फुटब, њана_,
  { {0xb4fa0041,0xaac60042,0xa856009a,0x00000000}},	//   _ספעי, रोडक, ביתה_,
  { {0xdee6354e,0xde060a30,0x9756009a,0x00000000}},	//   роми, ипни, סירו_,
  { {0xd0d50062,0xbce60044,0x9184009b,0x00000000}},	//   _кодъ, لأسو, _هجوم,
  { {0x7cf20c8e,0x6909007d,0xc4d20041,0x00000000}},	//   mærk, _džek, ַגן_,
  { {0xea5a0079,0x7cf204aa,0xbb430154,0x00000000}},	//   крај_, lærk, жеск,
  { {0x3eb90199,0xaa473df5,0x3a26231c,0x00000000}},	//   chst_, ипса_, рмаг,
  { {0x3b070189,0x213f0089,0xa96a0021,0x00000000}},	// [f100] рето_, nsuh_, ضمام_,
  { {0xd259008f,0xa2c50042,0xa9671fc6,0x00000000}},	//   miņu_, ़ोत्, рифа_,
  { {0x6287001c,0x7c3c6d6f,0x657b017e,0x00000000}},	//   ējoj, marr, _asuh,
  { {0x9f470080,0x7c2e004d,0x95ca1cab,0x00000000}},	//   _nyní_, lbbr, кула_,
  { {0x6ef600ea,0xbcfb0139,0xdb1e00be,0x00000000}},	//   hábo, ltéa, _expô,
  { {0x7c3c007a,0x7ce04167,0xa3b4000d,0x00000000}},	//   narr, töry, йблі,
  { {0xa696041d,0x6ef60026,0xc7a60002,0x00000000}},	//   _крај, jábo, _тивк,
  { {0xa3c70053,0x7c3c6d70,0x877b00ff,0x00000000}},	//   _उधर_, harr, _באלי,
  { {0xb1130076,0x7c3c2e4f,0x6efd013d,0x00000000}},	//   омыш, karr, nébe,
  { {0x39406d71,0x7c3c6d72,0x645a0195,0x00000000}},	//   isis_, jarr, _ucti,
  { {0x38170a7a,0x7c3c6d73,0x7246007e,0x00000000}},	//   יקים_, darr, _نپال,
  { {0x6efd000f,0xa18606bc,0x7c2e6d74,0x00000000}},	//   kébe, _выкл, ebbr,
  { {0x6efd00ea,0x65622733,0x7c3c6d75,0x00000000}},	//   jébe, ntoh, farr,
  { {0x2d89021f,0xba3b0003,0x7c3c0e57,0x00000000}},	//   _vrae_, _coïn, garr,
  { {0x0c84000d,0x0ac70062,0x60fb0063,0x00000000}},	//   цыям, ащам, _שהוק,
  { {0x656200a4,0x2d8913c2,0xddc4003b,0x00000000}},	//   ktoh, _trae_, _uciş,
  { {0x443c017f,0x39400006,0x6efd00ea,0x00000000}},	// [f110] kav_, gsis_, gébe,
  { {0xdca40001,0x1a65007e,0x443c14d5,0x00000000}},	//   _мањи, _گیری_, jav_,
  { {0x3e86000f,0x443c0019,0x2cac0137,0x00000000}},	//   sítő_, dav_, ödde_,
  { {0x3e8600ea,0x6d4f3473,0x98b30058,0x00000000}},	//   pítő_, orca, ğdır_,
  { {0x69d80058,0x394000a3,0x00000000,0x00000000}},	//   şver, csis_,   ,
  { {0x7cf20146,0xa9340002,0x6d4f00e5,0x00000000}},	//   værk, _ферш, irca,
  { {0x67d40086,0xd259001c,0x6380013d,0x00000000}},	//   _дору, ziņu_, váná,
  { {0x6b83006d,0x7cf2000e,0x4bfc0063,0x00000000}},	//   _ángu, tærk, כלוס,
  { {0x443c6d76,0x29190089,0x7659002b,0x00000000}},	//   bav_, _jusa_, mgwy,
  { {0x29193d81,0x23e7000d,0x649d01a8,0x00000000}},	//   _musa_, _кіев, _nèix,
  { {0x7c3c14dd,0x6d4f6d77,0x14d60063,0x00000000}},	//   varr, erca, _פועל_,
  { {0x7659001f,0xd259001c,0x39406d78,0x00000000}},	//   ngwy, tiņu_, ysis_,
  { {0x291900f3,0x38b60627,0x7659001f,0x00000000}},	//   _nusa_, _læra_, igwy,
  { {0x6efd00ea,0xd259008f,0x29116d79,0x00000000}},	//   vébe, riņu_, _niza_,
  { {0xe0d0007e,0x7cf201f2,0x7c3c6d7a,0x00000000}},	//   _غزه_, næri, rarr,
  { {0x7c3c6d7b,0x6b630088,0x443c3855,0x00000000}},	//   sarr, якса, zav_,
  { {0xbcfb0025,0x7c3c36e8,0xfaa30f85,0x00000000}},	// [f120] stéa, parr, чато,
  { {0xeb9a0138,0x6efd00ea,0x39406d7c,0x00000000}},	//   _био_, rébe, rsis_,
  { {0xbb860032,0x6efd00ea,0x39406d7d,0x00000000}},	//   _الجي, sébe, ssis_,
  { {0xb6c50086,0xef120047,0x65620072,0x00000000}},	//   осій, פּע_, ttoh,
  { {0x6b80003d,0x29110089,0x443c6d7e,0x00000000}},	//   āmgu, _fiza_, tav_,
  { {0x38b6007a,0x7cf20026,0x291116db,0x00000000}},	//   _færa_, færi, _giza_,
  { {0x961d003d,0xdb15000f,0xf6260062,0x00000000}},	//   _saņe, ozzá, _гдбо,
  { {0x443c6d7f,0x961d008f,0xcb13009f,0x00000000}},	//   sav_, _paņe, הלה_,
  { {0xb3a9005b,0x6d443543,0xd9fa0053,0x00000000}},	//   çırı, _nvia, ्धित_,
  { {0xf9930063,0x6aa6004d,0x76440014,0x00000000}},	//   פרת_, _lokf, ðiyf,
  { {0xb89b0047,0xd0100021,0x6d443bda,0x00000000}},	//   אביש, بلد_, _avia,
  { {0xa3d50042,0xde590085,0xb7db009a,0x00000000}},	//   सपर_, шамі_, רקטי,
  { {0x6d4f006f,0xed58000d,0x3a396d80,0x00000000}},	//   urca, боў_, _resp_,
  { {0x3f980019,0x9f340086,0x29196d81,0x00000000}},	//   ärus_, _декі, _rusa_,
  { {0xdddd000f,0xa0a30095,0x29194134,0x00000000}},	//   reső, _хајд, _susa_,
  { {0x29196d82,0xeafb007e,0x2b4c0066,0x00000000}},	//   _pusa_, ارست_, ádca_,
  { {0x644810c1,0x2911005f,0x6ce70083,0x00000000}},	// [f130] _oddi, _piza_, _гіне,
  { {0xf8070054,0x99d400de,0x00000000,0x00000000}},	//   бчен, أتفا,   ,
  { {0xb06500fe,0x29113f4c,0xbddb006c,0x00000000}},	//   llää, _viza_, saèd,
  { {0xdced0006,0x29190025,0x19950062,0x00000000}},	//   _praė, _tusa_, _дамя,
  { {0xb0650072,0x7659002b,0x64a56d83,0x00000000}},	//   nlää, rgwy, жала,
  { {0x76590185,0x9179008b,0xfbd0007e,0x00000000}},	//   sgwy, hật_, _آتی_,
  { {0x68fa0063,0x5c5c0047,0x04560044,0x00000000}},	//   _כלשה, אדוק, زلية_,
  { {0x6e3b0026,0x64486d84,0x52a91ed0,0x00000000}},	//   ðubl, _eddi, рвим_,
  { {0x7649002c,0xb5fd00c2,0x26cf30b7,0x00000000}},	//   _idey, _obši, migo_,
  { {0x26cf1f83,0x90c50054,0xd12e005d,0x00000000}},	//   ligo_, ібне, کمی_,
  { {0x6d446d85,0xf2e738ba,0xb4e50042,0x00000000}},	//   _svia, _людо, नवी_,
  { {0xdce4001c,0x9325007e,0x8d660121,0x00000000}},	//   _oriģ, _هرچن, овме,
  { {0xbcfb000f,0xe29f007a,0xa3c50053,0x00000000}},	//   rtén, öðu_, उज़र_,
  { {0x7e6d004b,0xc1050021,0x6aa6013d,0x00000000}},	//   _ebap, _بوتي, _sokf,
  { {0x25af002b,0xbea66d86,0x00000000,0x00000000}},	//   hygl_, _макк,   ,
  { {0x26cf00c3,0x6d40013d,0xeab70094,0x00000000}},	//   jigo_, ámas, ойс_,
  { {0x26cf6d87,0xaa7b017c,0x6d44017c,0x00000000}},	// [f140] digo_, _akýs, _uvia,
  { {0x44256d88,0x99820078,0x38c8005d,0x00000000}},	//   _nfl_, _sekų_, حاری_,
  { {0xf7720021,0xfaa66d89,0x929d0022,0x00000000}},	//   باء_, _дано, jmło,
  { {0x44256d8a,0x366a013f,0x00000000,0x00000000}},	//   _afl_, радо_,   ,
  { {0x3ea2006f,0xb603000d,0x7ae1013d,0x00000000}},	//   ijkt_, мяшк, élte,
  { {0x7af6024a,0x7ae900c3,0xddcf000c,0x00000000}},	//   llyt, čete, lecţ,
  { {0x26cf48e9,0x7af600ea,0xb4ca0053,0x00000000}},	//   bigo_, olyt, _लगी_,
  { {0xc2980675,0x6b83017d,0x71460363,0x00000000}},	//   ских_, _ânge, охож,
  { {0xd0d40062,0xddcf00dd,0x3abb0041,0x00000000}},	//   зопъ, iecţ, ימקנ,
  { {0x6448002b,0x7af6002b,0xd0aa01ce,0x00000000}},	//   _uddi, hlyt, ртид_,
  { {0x2d803d9c,0xb4d60053,0x7af60078,0x00000000}},	//   _asie_, ाची_, klyt,
  { {0x216a1b8b,0x91790013,0xddcf00dd,0x00000000}},	//   _види_, uật_, jecţ,
  { {0xf194030b,0xf5aa009a,0x00000000,0x00000000}},	//   _хиль, ׁבֹּ,   ,
  { {0x6ef60139,0xa067005e,0x7af6013d,0x00000000}},	//   hábh, _даља_, elyt,
  { {0x6d40007a,0xddcf003b,0x7af625c1,0x00000000}},	//   ámar, fecţ, flyt,
  { {0x6d480045,0xf1bf0066,0x00000000,0x00000000}},	//   ądar, žšej_,   ,
  { {0xb955005a,0x6909007d,0x26cf6d8b,0x00000000}},	// [f150] яващ, _ožet, vigo_,
  { {0x26ce00cd,0x7cf20014,0x478b0121,0x00000000}},	//   èfon_, færu, исем_,
  { {0x26cf03d9,0xa3c90161,0x39520006,0x00000000}},	//   tigo_, _लें_, arys_,
  { {0x4b7a00b5,0x9f61013d,0x8f9b0063,0x00000000}},	//   _פארו, épét_, ייבי,
  { {0xceb400b5,0x26cf1e4f,0x4425017d,0x00000000}},	//   ויף_, rigo_, _pfl_,
  { {0x7d7c00b5,0xf4840001,0x25af001f,0x00000000}},	//   ינדו, дућн, rygl_,
  { {0x5c380063,0x16351915,0x44251f51,0x00000000}},	//   חרון_, _невя, _vfl_,
  { {0xc24550bd,0x71591406,0x98a00022,0x00000000}},	//   чник, брос_, rpią_,
  { {0xddc40198,0xdced0006,0x8467005a,0x00000000}},	//   _obiš, _apač, _мъже,
  { {0xa9220026,0x25bd005b,0x645700f8,0x00000000}},	//   _óþek, ızlı_, óxid,
  { {0x3ea90034,0xf1a8007e,0x8eea0121,0x00000000}},	//   _boat_, مایه_, ймов_,
  { {0x3ea90034,0x23fa0063,0x395200a3,0x00000000}},	//   _coat_, _הפעמ, yrys_,
  { {0x2485085b,0x721a009a,0x25d5009d,0x00000000}},	//   _kalm_, _הונח, לוֹן_,
  { {0xdc13005b,0x6729007d,0xff250121,0x00000000}},	//   _aşım, _čejn, _емко,
  { {0xddcf000c,0x66160026,0xa09a0047,0x00000000}},	//   tecţ, þykk, _ליסט,
  { {0xaa7b007a,0x3952001f,0x3ea900e5,0x00000000}},	//   _skýr, trys_, _goat_,
  { {0x3e5b014e,0xddcf0529,0x394611f5,0x00000000}},	// [f160] _הדפס, recţ, éos_,
  { {0xb4ca0053,0xd910007e,0x395227f4,0x00000000}},	//   _लगे_, ئیس_, rrys_,
  { {0x7c3e003d,0x6d461c2d,0x63a5004d,0x00000000}},	//   _iepr, lska, ähnl,
  { {0xeafa007e,0x7c3e0072,0xcb9b0063,0x00000000}},	//   _درخت_, _hepr, _הסטט,
  { {0x6d46257d,0x7c3e003e,0x6ef60139,0x00000000}},	//   nska, _kepr, rábh,
  { {0xf74606cb,0x6d466d8c,0x6ef60139,0x00000000}},	//   _него, iska, sábh,
  { {0x2ca528ba,0x6c7b0041,0x99890130,0x00000000}},	//   öldi_, מאספ, mbaš_,
  { {0xb7db014e,0x6d465e9d,0x62660593,0x00000000}},	//   _הקלי, kska, سابق,
  { {0x69c46d8d,0x6d4657d9,0x21630085,0x00000000}},	//   nzie, jska, нтэг,
  { {0x6d4610e9,0x55bb0063,0x60da006f,0x00000000}},	//   dska, _הממו, untm,
  { {0x6d466d8e,0x443e6d8f,0x69c4004d,0x00000000}},	//   eska, _iet_, hzie,
  { {0x443e2a18,0x6f042c29,0x6e670121,0x00000000}},	//   _het_, _chic, чтож,
  { {0xf0b7006a,0x6287001c,0x50b7007e,0x00000000}},	//   زایش_, ējot, زدید_,
  { {0x69c40b5a,0x212b0025,0x443e3276,0x00000000}},	//   dzie, íche_, _jet_,
  { {0x443e2a18,0x7cf200b9,0x3f82001c,0x00000000}},	//   _met_, vært, ākus_,
  { {0x7cf2007a,0x6f04003b,0x443e6d90,0x00000000}},	//   færs, _ghic, _let_,
  { {0xdd9104de,0x443e0104,0x7cf20093,0x00000000}},	// [f170] _شود_, _oet_, tært,
  { {0x443e6d91,0x7c3e301a,0x27d90085,0x00000000}},	//   _net_, _gepr, одзь_,
  { {0x69c404e2,0x7aed003b,0x442b056c,0x00000000}},	//   azie, poat, _ęc_,
  { {0xae010161,0x443e25bb,0x24856d92,0x00000000}},	//   _ईरान_, _aet_, _salm_,
  { {0x443e6d93,0x248536e1,0x690931dd,0x00000000}},	//   _bet_, _palm_, _džer,
  { {0x443e6d94,0x69090006,0x6ef600be,0x00000000}},	//   _cet_, _ežer, rábi,
  { {0x443e31c8,0x6d46001c,0x68f8013d,0x00000000}},	//   _det_, zska, őadá,
  { {0x6d460045,0x41b50086,0x443e2792,0x00000000}},	//   yska, дсот, _eet_,
  { {0x443e6d95,0x746b0002,0xe162005d,0x00000000}},	//   _fet_, _грев_, نگوي,
  { {0x443e6d96,0x2ef200ac,0x6d465201,0x00000000}},	//   _get_, _skyf_, vska,
  { {0xdee601aa,0x6f040025,0x23b5014d,0x00000000}},	//   дони, _phic, _تماس,
  { {0x6d464ec7,0x443e0d0e,0x7c3e3305,0x00000000}},	//   tska, _zet_, _sepr,
  { {0x443e0034,0x62990179,0x6d466d97,0x00000000}},	//   _yet_, _inwo, uska,
  { {0x6f0403e9,0xfd5f008b,0x644306ce,0x00000000}},	//   _whic, _huyệ, nani,
  { {0x6f042843,0x6d466d98,0x64432712,0x00000000}},	//   _thic, sska, iani,
  { {0xdb1d000f,0x69c40c84,0xfaf50086,0x00000000}},	//   ázás, tzie, ечую,
  { {0x7c3e0080,0x69c43f42,0xf2d20149,0x00000000}},	// [f180] _tepr, uzie, דען_,
  { {0x7ae9017f,0xfd5f008b,0x69c46d99,0x00000000}},	//   četa, _luyệ, rzie,
  { {0x443e6d9a,0x64436d9b,0x387a0137,0x00000000}},	//   _ret_, dani, repr_,
  { {0xc8690ca4,0x443e28fa,0x1a5a0021,0x00000000}},	//   ין_, _set_, _بشدة_,
  { {0x9633000d,0x6289001f,0x6e3b0026,0x00000000}},	//   тніц, ddeo, ðubi,
  { {0x84380021,0x6299083f,0x2a60004b,0x00000000}},	//   أكثر_, _anwo, lgib_,
  { {0xd62a000d,0x443e6d9c,0xf487007e,0x00000000}},	//   _мове_, _vet_, بانی,
  { {0xa2e3000a,0x2a60004b,0x7abb0047,0x00000000}},	//   којд, ngib_, ַציו,
  { {0x29180e53,0xfd5f001b,0x64436d9d,0x00000000}},	//   _kira_, _duyệ, bani,
  { {0x6299001f,0x299b0132,0xbcfb1954,0x00000000}},	//   _enwo, קסימ, rték,
  { {0x085701f9,0xdfd0007e,0x5ed5183f,0x00000000}},	//   ובים_, ايج_, ежну,
  { {0x22930021,0x29186d9e,0x7206009b,0x00000000}},	//   _للمس, _lira_, _قوام,
  { {0x7cf200b9,0x56370047,0x2f1a008f,0x00000000}},	//   værr, ואכע_, _rīgu_,
  { {0x6f1c013d,0xd622045b,0x3cff0042,0x00000000}},	//   írcs, фiка, _शीशे_,
  { {0x5f94005a,0xbcfb0139,0x7cf20046,0x00000000}},	//   _чийт, ntéi, tærr,
  { {0x5f040fe2,0xe188001b,0x6ee70021,0x00000000}},	//   _изја, _kỳ_, _تستل,
  { {0x64430a49,0x7e7d6d9f,0x2d85008f,0x00000000}},	// [f190] yani, mesp, āles_,
  { {0x6d5d4026,0x9735007e,0x7e7d6da0,0x00000000}},	//   musa, فکرا, lesp,
  { {0x64430024,0x764005b9,0x6d5d0231,0x00000000}},	//   vani, _bemy, lusa,
  { {0x64431112,0xcf930047,0x29180762,0x00000000}},	//   wani, כטע_, _eira_,
  { {0x29186da1,0x6d5d6da2,0x64436da3,0x00000000}},	//   _fira_, nusa, tani,
  { {0xc4840088,0x29186da4,0x6443005f,0x00000000}},	//   клік, _gira_, uani,
  { {0x6d5d1eb1,0xa3c90053,0x64436da5,0x00000000}},	//   husa, _लेख_, rani,
  { {0x71590245,0x3eb9006f,0x2918005b,0x00000000}},	//   прос_, jkst_, _zira_,
  { {0x62896da6,0x39493a69,0x8235007e,0x00000000}},	//   rdeo, nsas_, ورکا,
  { {0x6d5d3845,0x39496da7,0xc1050021,0x00000000}},	//   dusa, isas_, عودي,
  { {0xfd5f008b,0x644142b2,0x04c80021,0x00000000}},	//   _tuyệ, _ieli, _تولي_,
  { {0x39492174,0x64416da8,0x6d5d6da9,0x00000000}},	//   ksas_, _heli, fusa,
  { {0x6d5d6daa,0x64416dab,0x4df5000d,0x00000000}},	//   gusa, _keli, вярт,
  { {0x2d9200e8,0x315600b5,0x38b600b9,0x00000000}},	//   _vrye_, _ניצן_, _værk_,
  { {0x6441014f,0x7ae921d5,0x7e7d6dac,0x00000000}},	//   _meli, četn, besp,
  { {0xfd4a005a,0x29180c05,0x6d5d6dad,0x00000000}},	//   _език_, _sira_, busa,
  { {0xb8560001,0x6d5d6dae,0x2a600019,0x00000000}},	// [f1a0] еђењ, cusa, rgib_,
  { {0x38b60014,0x64416daf,0xe8f7143c,0x00000000}},	//   _kæri_, _neli, елу_,
  { {0xf0b600b5,0x29186db0,0x39490331,0x00000000}},	//   עלער_, _vira_, asas_,
  { {0x29180089,0x7f3a0047,0xb7590054,0x00000000}},	//   _wira_, פענו, ьшує_,
  { {0x64416db1,0x29186db2,0x2508005d,0x00000000}},	//   _beli, _tira_, ورتی_,
  { {0x64416db3,0x35b30085,0xa3d40131,0x00000000}},	//   _celi, ыбір, колч,
  { {0xd4670001,0x6d5d004d,0x48e30121,0x00000000}},	//   хије_, zusa, _сорв,
  { {0x64410019,0x6d5d002c,0xbcfb017d,0x00000000}},	//   _eeli, yusa, rtéi,
  { {0x50660088,0xbcfb46c5,0x7e7d00be,0x00000000}},	//   нтна, stéi, vesp,
  { {0x6d5d0019,0x99800006,0x53a6000d,0x00000000}},	//   vusa, lbių_, _пазб,
  { {0xde590086,0x7e7d6db4,0xbcfb006c,0x00000000}},	//   мані_, tesp, nuée,
  { {0x8289019d,0x6d5d33b4,0x6441074f,0x00000000}},	//   _осіб_, tusa, _zeli,
  { {0x7e7d6db5,0x3f830046,0x3d1e0042,0x00000000}},	//   resp, æjur_, _यूआइ_,
  { {0x6d5d4928,0x38b60014,0x7e7d543c,0x00000000}},	//   rusa, _færi_, sesp,
  { {0x6d5d08a4,0xdb070072,0xdb23005d,0x00000000}},	//   susa, yyjä, اوری,
  { {0x6d5d228f,0x539b0063,0x7ae90077,0x00000000}},	//   pusa, הילו, četo,
  { {0x39490006,0x2ca500a5,0xdbf90022,0x00000000}},	// [f1b0] usas_, ölds_, _płóc,
  { {0x39492147,0x4c950330,0xd8790021,0x00000000}},	//   rsas_, _риос, ظمات_,
  { {0x39496db6,0x798600a4,0xf8bf0003,0x00000000}},	//   ssas_, _eskw, _nuée_,
  { {0xc5d5019d,0x64413b70,0x4615007e,0x00000000}},	//   кіль, _seli, نوار,
  { {0x64416db7,0xe5691326,0xd126005d,0x00000000}},	//   _peli, филд_, _خم_,
  { {0xbcfb0003,0x61f9002b,0x06080083,0x00000000}},	//   buée, _rywl, хнік_,
  { {0x64416db8,0x2d8c0023,0x8235005d,0x00000000}},	//   _veli, ādei_, پربا,
  { {0x6d4d18dc,0x64416db9,0x9f4b013d,0x00000000}},	//   _ovaa, _weli, _élén_,
  { {0xa1560001,0xc6920047,0x46f40121,0x00000000}},	//   вању_, _דאן_, _счёт,
  { {0xe0d6026c,0x40950f34,0xdb0e004c,0x00000000}},	//   квы_, трит, vybí,
  { {0x60090076,0x6d4d00fe,0x66280137,0x00000000}},	//   ьном_, _avaa, _åskå,
  { {0x38b60026,0xba3b0003,0x2f540121,0x00000000}},	//   _væri_, _moïs, ытьс,
  { {0xfe0c0161,0xee370062,0x0d99066e,0x00000000}},	//   सेंस_, ъня_, нтры_,
  { {0xa2040054,0xc1560063,0x628b6dba,0x00000000}},	//   _спід, _ישנו_, _hago,
  { {0x316d03b2,0x99800006,0xbb430002,0x00000000}},	//   ltez_, ybių_, иерк,
  { {0x316d006c,0x628b1a9f,0x7db61b41,0x00000000}},	//   otez_, _jago, _асоц,
  { {0x316d6dbb,0x68e212f7,0x628b6dbc,0x00000000}},	// [f1c0] ntez_, éodo, _mago,
  { {0x4b260001,0xe73a1001,0xbcfb0003,0x00000000}},	//   _имов, деж_, tuée,
  { {0x2a7500ea,0xbcfb013d,0x9a8a0044,0x00000000}},	//   íííí, ttév, _قَدْ_,
  { {0x628b6dbd,0xe7371159,0xd6cf0044,0x00000000}},	//   _nago, тец_, يقل_,
  { {0x91820013,0x99800078,0x64a62ada,0x00000000}},	//   iệt_, rbių_, када,
  { {0x44f3000d,0x545301ce,0x85550043,0x00000000}},	//   апіс, авшт, ایلر_,
  { {0x628b00bb,0xbcfb0164,0xf7430f8d,0x00000000}},	//   _bago, quée, _весо,
  { {0xbcfb000f,0x628b006c,0xd2500044,0x00000000}},	//   ltét, _cago, حنة_,
  { {0xf1a30088,0xc05a01dd,0xa6e20014,0x00000000}},	//   арэн, мін_, íðul,
  { {0xf8bf0003,0xbcfb3354,0x25c40058,0x00000000}},	//   _tuée_, ntét, ırlı_,
  { {0x628b6dbe,0x6d4d04aa,0xa0a30085,0x00000000}},	//   _fago, _svaa, ршыл,
  { {0xe3160044,0xe80a0042,0xe8070042,0x00000000}},	//   _شباب, _वरना_, वेटा_,
  { {0x1154005a,0x316d05d7,0x63b86dbf,0x00000000}},	//   _склю, ctez_, lyvn,
  { {0x628b05c9,0x62806dc0,0x00000000,0x00000000}},	//   _zago, lemo,   ,
  { {0xf5480013,0xce950062,0x6ef6013d,0x00000000}},	//   hụ_, _байъ, rábr,
  { {0x62806dc1,0x7f5c00cd,0x6b890022,0x00000000}},	//   nemo, àrqu, łego,
  { {0xbcfb006d,0x5a44000d,0x62806dc2,0x00000000}},	// [f1d0] ruéb, рэса, iemo,
  { {0x63b800d1,0xbcfb013d,0x62806dc3,0x00000000}},	//   kyvn, gtét, hemo,
  { {0x62800031,0x28680062,0x6ee80058,0x00000000}},	//   kemo, ърто_, lıba,
  { {0x62806dc4,0x96290044,0x00000000,0x00000000}},	//   jemo, ركتك_,   ,
  { {0x62803a4e,0x80c50042,0x628b6dc5,0x00000000}},	//   demo, िसमे, _rago,
  { {0x628b00bb,0xe73300f2,0xbcfb013d,0x00000000}},	//   _sago, _نصر_, mtés,
  { {0xbcfb000f,0x628b6dc6,0x9182001b,0x00000000}},	//   ltés, _pago, yệt_,
  { {0x316d0164,0x82a4005e,0x62806dc7,0x00000000}},	//   ttez_, ишње, gemo,
  { {0xbcfb03e8,0x316d0164,0xdb1500ea,0x00000000}},	//   ntés, utez_, gyzé,
  { {0x316d6dc8,0x628b6dc9,0x6fa9005e,0x00000000}},	//   rtez_, _wago, евог_,
  { {0x628b6dca,0x628004a6,0x316d05d7,0x00000000}},	//   _tago, bemo, stez_,
  { {0x628004a6,0x316d0164,0xed5a65f8,0x00000000}},	//   cemo, ptez_, ном_,
  { {0xbcfb00ea,0xddd5014b,0x00000000,0x00000000}},	//   jtés, аўрэ,   ,
  { {0xa069005a,0x40940094,0x00000000,0x00000000}},	//   _чака_, _врът,   ,
  { {0x4a9a0088,0x5ea60021,0x0f790041,0x00000000}},	//   нтаў_, _ممثل, _טאַב,
  { {0x38b617d3,0x20070058,0x9e660988,0x00000000}},	//   _lært_, _izni_, _свид,
  { {0xbcfb00ea,0x1a06023b,0xfe37009a,0x00000000}},	// [f1e0] ttét, упам, _גרפי_,
  { {0x291c00c7,0x38b60093,0x3ea00026,0x00000000}},	//   öva_, _nært_, _hnit_,
  { {0x27fc01e1,0x3ea000e5,0x00000000,0x00000000}},	//   ævn_, _knit_,   ,
  { {0xbbb20161,0xf7430699,0x056a0002,0x00000000}},	//   ीनीक, сецо, ејки_,
  { {0x62806dcb,0x7ae46dcc,0x4ecd0047,0x00000000}},	//   vemo, mnit, וזאַ,
  { {0x53340088,0x7ae43855,0xbcfb01ca,0x00000000}},	//   аект, lnit, ltér,
  { {0x27f70a63,0xbcfb243a,0x62806dcd,0x00000000}},	//   čené_, bréf, temo,
  { {0x7ae40aba,0x7d1e6dce,0xa2b40062,0x00000000}},	//   nnit, _lips, рбич,
  { {0x38b60026,0x6280095b,0x3325006c,0x00000000}},	//   _fært_, remo, _eulx_,
  { {0x7ae413fd,0x3d000053,0x62804937,0x00000000}},	//   hnit, ोगों_, semo,
  { {0x20180213,0x7ae45600,0x65620072,0x00000000}},	//   äri_, knit, luoh,
  { {0x7ae901b3,0x9e150054,0x7ae40066,0x00000000}},	//   četk, идні, jnit,
  { {0x7ae46cda,0x91b70044,0x00000000,0x00000000}},	//   dnit, _مطور_,   ,
  { {0x644a0096,0xd3660021,0x7ae46dcf,0x00000000}},	//   nafi, يه_, enit,
  { {0x60da003e,0x6d40017d,0x2bbb0021,0x00000000}},	//   mitm, âmar, راسة_,
  { {0xfebb006a,0xdb2400ea,0xbcfb013d,0x00000000}},	//   _ساعت_, árás, gtér,
  { {0x200b0045,0xdcb1008b,0xc27b0047,0x00000000}},	// [f1f0] ęcie_, ử_, ערמי,
  { {0xbcfb6dd0,0x6562004b,0x7ae46dd1,0x00000000}},	//   rtés, duoh, anit,
  { {0x64570fac,0x6d4f6dd2,0xf8070446,0x00000000}},	//   óxim, lsca, учан,
  { {0xaa950086,0xbcfb664e,0x8b3a0063,0x00000000}},	//   _тимч, ctér, _שתרצ,
  { {0xd469018e,0x6f0d2389,0x6d4f6dd3,0x00000000}},	//   виле_, _mhac, nsca,
  { {0x26c40787,0x2249007d,0x6d4f11ed,0x00000000}},	//   _elmo_, _žak_, isca,
  { {0x38b602ab,0x6d5d004d,0x60da01e1,0x00000000}},	//   _vært_, hrsa, ditm,
  { {0xa5350121,0x6f0d002b,0xe29907bf,0x00000000}},	//   _внач, _nhac, таи_,
  { {0x52a60076,0x91e56dd4,0x321900fe,0x00000000}},	//   рвым_, ропе, äsy_,
  { {0x764b002c,0x3ea000ac,0x7ae46dd5,0x00000000}},	//   lagy, _snit_, znit,
  { {0x6f0d0025,0x2901017d,0x6d5d322e,0x00000000}},	//   _bhac, ilha_, ersa,
  { {0xbcfb0003,0x6f0d6dd6,0x61d90121,0x00000000}},	//   xtér, _chac, _имея_,
  { {0x563a0047,0x8d630062,0x10a50bd8,0x00000000}},	//   כערײ, овяе, _вилн,
  { {0x764b6bf2,0x3fc7007e,0x8c4302a1,0x00000000}},	//   hagy, _مدعی_, жере,
  { {0xbcfb43cc,0x7ae404c9,0x6d4f6dd7,0x00000000}},	//   ttér, tnit, asca,
  { {0x6f0d0025,0x3ea06dd8,0xcb67005e,0x00000000}},	//   _ghac, _unit_, јате_,
  { {0x2d8c001c,0x20c90025,0x7ae46dd9,0x00000000}},	// [f200] ādes_, _cúig_, rnit,
  { {0xbcfb6dda,0x7ae40807,0xe8c70085,0x00000000}},	//   stér, snit, агул_,
  { {0x5c5b0063,0xd7ca007e,0x7ae4122a,0x00000000}},	//   _בדיק, خواه_, pnit,
  { {0x2901017d,0x6d440051,0x442e0089,0x00000000}},	//   alha_, _kwia, wcf_,
  { {0x66090051,0x644a6ddb,0x7bce6ddc,0x00000000}},	//   _czek, tafi, lzbu,
  { {0xc448007e,0xd843027d,0xbcfb01fa,0x00000000}},	//   ایان_, ručí_, créd,
  { {0x6609000f,0x644a6ddd,0x764b005f,0x00000000}},	//   _ezek, rafi, bagy,
  { {0x644a6dde,0x65620072,0xbcfb0003,0x00000000}},	//   safi, puoh, prég,
  { {0x60f8011c,0xe297005e,0x3cf8078c,0x00000000}},	//   лния_, рањ_, korv_,
  { {0xbcfb006c,0x6f0d6ddf,0x6d5d0130,0x00000000}},	//   orée, _shac, vrsa,
  { {0x6d4f00e5,0x3f980114,0xbcfb0003,0x00000000}},	//   wsca, íru_, nrée,
  { {0x6d4f4473,0x64486de0,0xdb150244,0x00000000}},	//   tsca, _hedi, uzzü,
  { {0x64483d81,0x6d4f05ab,0x6d5d6de1,0x00000000}},	//   _kedi, usca, ursa,
  { {0x91bb0063,0x6d440150,0x2a790150,0x00000000}},	//   _במדי, _dwia, _sbsb_,
  { {0xaa590690,0xcb350062,0x64481a9a,0x00000000}},	//   ливу_, себъ, _medi,
  { {0xbd88006a,0x1b19026c,0xaf330021,0x00000000}},	//   _چنين_, ужбы_, _بروت,
  { {0x6d440051,0x7c280078,0x7af40054,0x00000000}},	// [f210] _gwia, ždra, ізує,
  { {0x66090051,0xd70f0053,0x7bce007d,0x00000000}},	//   _rzek, िष्ठ_, bzbu,
  { {0xab950021,0xbcfb0003,0x6d440022,0x00000000}},	//   _الجغ, grée, _zwia,
  { {0x2b5e0080,0x9555009e,0xe7580054,0x00000000}},	//   átce_, مختا, риці_,
  { {0xd4d90088,0x644846b9,0x8e980063,0x00000000}},	//   лькі_, _bedi, ידאו_,
  { {0xdfc66de2,0x64481bae,0x2a69004b,0x00000000}},	//   _في_, _cedi, lgab_,
  { {0xbcfb03b2,0x93bc003b,0x6448157e,0x00000000}},	//   crée, _sfăr, _dedi,
  { {0x644800a4,0x2a6907b7,0x61e40077,0x00000000}},	//   _eedi, ngab_, _žila,
  { {0xeaaa00b5,0x99560075,0x00000000,0x00000000}},	//   רױפֿ, _müşt_,   ,
  { {0x644811a9,0x2377007e,0x7c25002b,0x00000000}},	//   _gedi, _ناصح, _nghr,
  { {0xc878005b,0x53340054,0xdce40066,0x00000000}},	//   _öğe_, _дехт, _priľ,
  { {0xd491008b,0xf6790047,0x64486de3,0x00000000}},	//   _hà_, נאָמ, _zedi,
  { {0xa2a40053,0x442501e1,0x75290331,0x00000000}},	//   कार्, _kgl_, _juez,
  { {0xa5da00b5,0x7db50086,0x7bce6de4,0x00000000}},	//   אַלי, ісяц, tzbu,
  { {0xd491001b,0x75212340,0xfaa60c46,0x00000000}},	//   _mà_, _milz, баво,
  { {0xd491001b,0x6e24085a,0xbcfb0003,0x00000000}},	//   _là_, _ugib, vrée,
  { {0x6d442f40,0xe8ea005e,0x67200130,0x00000000}},	// [f220] _uwia, гмад_, _rimj,
  { {0xbcfb0164,0x7afd0844,0x6c860021,0x00000000}},	//   trée, _ekst, _الدم,
  { {0x644806a3,0x78b538e6,0xbcfb006c,0x00000000}},	//   _redi, _dozv, urée,
  { {0x64480397,0x6efd236b,0xbcfb0003,0x00000000}},	//   _sedi, lébr, rrée,
  { {0x673b007d,0xa5f8005e,0x64486de5,0x00000000}},	//   _čuje, јелу_, _pedi,
  { {0x6fca0161,0x6efd0003,0xd4910013,0x00000000}},	//   ानमं, nébr, _cà_,
  { {0x644814d5,0x9d1b0041,0xe7373279,0x00000000}},	//   _vedi, נוצט, _гес_,
  { {0xdd2d0078,0x644824bf,0x926a4808,0x00000000}},	//   vėžy, _wedi, урка_,
  { {0xb6bb0063,0x39521780,0x75210244,0x00000000}},	//   _עצמי, nsys_, _filz,
  { {0x232a0062,0x9f540e82,0xf20d0042,0x00000000}},	//   _божи_, овоч, ाइज़_,
  { {0x2d8000eb,0xa5070ab1,0xd3e4005d,0x00000000}},	//   _apie_, _уефа_, _بقای,
  { {0x8143006a,0xeeab0156,0x2002008f,0x00000000}},	//   _کنون, уток_, āki_,
  { {0x200b0045,0xef92005d,0x00000000,0x00000000}},	//   ęcia_, زیکد,   ,
  { {0x39526de6,0x6efd50b1,0x1fa6344d,0x00000000}},	//   dsys_, gébr, _григ,
  { {0x2ac70001,0x78b5004a,0x200a004b,0x00000000}},	//   бљав, _rozv, übid_,
  { {0x7e6d053b,0xada60024,0x83370041,0x00000000}},	//   _ucap, _spúš, מאלס_,
  { {0x78270021,0x2a691548,0x78b56de7,0x00000000}},	// [f230] معال, rgab_, _pozv,
  { {0x764900ac,0x9c472ba3,0x2a690244,0x00000000}},	//   _seey, _ухил, sgab_,
  { {0x56950076,0xddcd0051,0xbcfb006c,0x00000000}},	//   жает, _udał, aréc,
  { {0x8f9b0063,0x30a6030b,0xef12009a,0x00000000}},	//   טיבי, ́рив, ֵּא_,
  { {0x98c5005b,0xbcfb017d,0x75210a67,0x00000000}},	//   ştır_, créc, _pilz,
  { {0x2d990019,0x84670062,0xe3b0007e,0x00000000}},	//   ivse_, съде, کره_,
  { {0xd49100aa,0x442500bd,0xe8df008d,0x00000000}},	//   _và_, _vgl_, _laịc_,
  { {0x6b83017d,0x7bdc0041,0xd2990085,0x00000000}},	//   _ângu, טקוו, рткі_,
  { {0x0595006a,0x3f9c0019,0x95cb0141,0x00000000}},	//   _بازگ, _arvu_, _сува_,
  { {0xe0d906be,0x44310075,0x147704a0,0x00000000}},	//   рво_, _üz_, _دارج,
  { {0x4f950002,0xe9df130c,0x2d8001f4,0x00000000}},	//   црпу, _seúl_, _spie_,
  { {0x6e290080,0x57fa0063,0x02440044,0x00000000}},	//   žebn, ילתו, _فَمَ,
  { {0x1d0a0854,0xa0c500de,0x20d500de,0x00000000}},	//   иеми_, _ويصو, _وتتج,
  { {0xa06602d7,0x00000000,0x00000000,0x00000000}},	//   _даша_,   ,   ,
  { {0x6efd0003,0x799d002b,0x2bf6000d,0x00000000}},	//   rébr, _arsw, іягр,
  { {0x3946000d,0x1ee8007e,0xbcfb006c,0x00000000}},	//   жнаг, _دوبی_, tréc,
  { {0xcee9007e,0x39520078,0xfee90044,0x00000000}},	// [f240] _درون_, usys_, _دعوى_,
  { {0xe9d7000d,0x3ead008f,0x39522688,0x00000000}},	//   цку_, ķete_, rsys_,
  { {0xd7ff000c,0x257200a3,0x562a49a0,0x00000000}},	//   _ţări_, wâl_, ажем_,
  { {0xbcfb0164,0x98af001c,0x39526de8,0x00000000}},	//   préc, īgā_, psys_,
  { {0xddcd0051,0x645e00be,0x94aa079b,0x00000000}},	//   _gdań, ópio, итка_,
  { {0xe71a007e,0x00000000,0x00000000,0x00000000}},	//   _چيست_,   ,   ,
  { {0xd4670138,0xe71a006a,0x03a3005e,0x00000000}},	//   ције_, _نيست_, дијо,
  { {0xfbe8001b,0x8c1b0063,0x2d8b056c,0x00000000}},	//   _đề_, סוקי, ywce_,
  { {0xcb130132,0x045a007e,0xbcfb0025,0x00000000}},	//   ולה_, _نجات_, hréa,
  { {0x3f9c017f,0x397b009f,0x7530008f,0x00000000}},	//   _prvu_, סטינ, ēdzā,
  { {0x65620244,0xe1ef005d,0x1fa6012c,0x00000000}},	//   lroh, فسی_, ірог,
  { {0x57fb009a,0x9e340085,0x673e1561,0x00000000}},	//   שלטו, меюч, ippj,
  { {0x171b00b5,0xf653014e,0x6562004d,0x00000000}},	//   יוטע, וצר_, nroh,
  { {0x61ed0078,0x6fb60021,0x25a00050,0x00000000}},	//   _žalg, _ومشا, äily_,
  { {0x80a3006a,0xbcfb14bd,0xab940054,0x00000000}},	//   _زمين, gréa, мирі,
  { {0x690b0994,0x20140022,0x69350085,0x00000000}},	//   güen, ącić_, знау,
  { {0x645a14d5,0x7e7b004b,0xa93d014b,0x00000000}},	// [f250] _odti, õupu, удзi,
  { {0x65624282,0x39140085,0xf8076de9,0x00000000}},	//   droh, дмур, очен,
  { {0x629c001c,0xbcfb46c5,0x602d013d,0x00000000}},	//   ēroj, créa, _hőmé,
  { {0x645a00e3,0x0f7b0063,0xabfa0063,0x00000000}},	//   _adti, שראל, _להתר,
  { {0x65626dea,0x7d070734,0xb6070085,0x00000000}},	//   groh, oljs, цяжк,
  { {0xab98006a,0x6fca0161,0xe5780054,0x00000000}},	//   _اخیر_, ानां, юзі_,
  { {0xc6e70086,0x0768000d,0xf8b2009f,0x00000000}},	//   _діап, _маёй_, _אשם_,
  { {0xd2a90055,0x2d84005b,0x52a90001,0x00000000}},	//   ские_, çmek_, свим_,
  { {0xa3db0042,0xddc6056c,0x00000000,0x00000000}},	//   _ढेर_, zakł,   ,
  { {0xa0690259,0x98bd0042,0xf8bd0082,0x00000000}},	//   љана_, ोसिए, ोसिय,
  { {0x64436deb,0x8fa56dec,0xcfe9043e,0x00000000}},	//   mbni, чане, صفحه_,
  { {0xe298019d,0x60ca0244,0x656f0244,0x00000000}},	//   _має_, _elfm, _ächs,
  { {0xe0ce019d,0xacea0044,0x3eab011b,0x00000000}},	//   _зв_, مرسل_, _šité_,
  { {0x40870dd5,0x213f003e,0x913a0063,0x00000000}},	//   _фудб, mpuh_, _העסק,
  { {0xfaa60085,0xeb9a04d6,0x00000000,0x00000000}},	//   паво, щив_,   ,
  { {0xbcfb0003,0x8b232f57,0xaf760047,0x00000000}},	//   rréa, едсе, _זעקס_,
  { {0x798d00a4,0xc9660ed2,0x25db0042,0x00000000}},	// [f260] gwaw, явай, _खेली_,
  { {0xedf6007e,0x0903005e,0x76426ded,0x00000000}},	//   _ويژگ, епун, wboy,
  { {0x798d00a4,0x66e60a29,0x1cbb009a,0x00000000}},	//   awaw, пожа, _המיע,
  { {0x690b13a3,0xd6d90086,0x6f360041,0x00000000}},	//   qüen, оті_, לװעב_,
  { {0x86230076,0xa50a0794,0xba9b0063,0x00000000}},	//   ньше, беда_, _הסכי,
  { {0x7afb00c2,0x65621165,0x39406dee,0x00000000}},	//   čute, rroh, mpis_,
  { {0x68fe00b9,0xe6460054,0x656202d2,0x00000000}},	//   mopd, _невп, sroh,
  { {0x994c0024,0xd3790086,0x3f980026,0x00000000}},	//   _môže_, ючі_, ærum_,
  { {0x64430137,0x35ca005e,0x00000000,0x00000000}},	//   bbni, _угао_,   ,
  { {0x2f1b008f,0xdb1c056c,0x653b009a,0x00000000}},	//   _lūgt_, ozró, _לעמד,
  { {0x7d0700a8,0xbcfb5883,0x389b0041,0x00000000}},	//   vljs, frén, זיינ,
  { {0x6b9c007d,0xbcfb0195,0xd2500044,0x00000000}},	//   dvrg, grén, _شنت_,
  { {0x68fe02b0,0xa0a622ce,0x7b130003,0x00000000}},	//   kopd, _надд, nçue,
  { {0x2ceb093e,0xb1130054,0xbcfb017c,0x00000000}},	//   сьмо_, _зміш, ltéz,
  { {0x307b0063,0x807b0063,0x26c60072,0x00000000}},	//   _האונ, _הנוצ, kkoo_,
  { {0x59de0235,0xbcfb45ef,0xa0070044,0x00000000}},	//   _नेहर, ntéz, _عقيل_,
  { {0x98b90002,0x644358c0,0x00000000,0x00000000}},	// [f270] олат_, ybni,   ,
  { {0x7e7d1647,0x798d6def,0x00000000,0x00000000}},	//   lfsp, rwaw,   ,
  { {0x39406df0,0x5b151849,0x28380044,0x00000000}},	//   apis_, _омот, سألة_,
  { {0xa634019d,0x2bd60053,0x291a6df1,0x00000000}},	//   енці, _डेटा, ampa_,
  { {0x8c19006a,0xa4d50086,0xc519000d,0x00000000}},	//   _ديگر_, моді, оўкі_,
  { {0x6443004d,0x8339093d,0x7aed6df2,0x00000000}},	//   ubni, очит_, lnat,
  { {0x20c90026,0x64436df3,0x7aed3d63,0x00000000}},	//   _búin_, rbni, onat,
  { {0x7e7d006f,0x2326047e,0x7aed256d,0x00000000}},	//   jfsp, мощи_, nnat,
  { {0xf487184a,0x7aed6df4,0x61ed017f,0x00000000}},	//   _нужн, inat, _žalb,
  { {0x629d0024,0x3ea900cd,0xdbcc0026,0x00000000}},	//   ôsob, _anat_, kóða,
  { {0xdbcc0026,0x3e8a02e4,0x3cf10042,0x00000000}},	//   jóða, ойно_, ँचने_,
  { {0x39400026,0x7aed00c2,0x656b00e5,0x00000000}},	//   ypis_, jnat, ough,
  { {0x291a0137,0x82d60063,0x7aed6df5,0x00000000}},	//   ympa_, _קונג_, dnat,
  { {0x7e7d01b0,0x7221008d,0x7aed6df6,0x00000000}},	//   afsp, _tửbạ, enat,
  { {0x656b0035,0xfc030054,0x1d0753a7,0x00000000}},	//   hugh, впро, фери_,
  { {0x3940017f,0x7aed6df7,0x21270013,0x00000000}},	//   tpis_, gnat, _hinh_,
  { {0x2127001b,0x672e6df8,0x673c00b2,0x00000000}},	// [f280] _kinh_, _subj, _strj,
  { {0xa3bf0235,0x39400006,0x7aed4197,0x00000000}},	//   ुना_, rpis_, anat,
  { {0x2127001b,0x93c4008b,0xdc8b0063,0x00000000}},	//   _minh_, _chẳ, _וְכָ,
  { {0x68fe5453,0x2127008b,0x656b0290,0x00000000}},	//   sopd, _linh_, fugh,
  { {0x20c90139,0x7ae401a9,0xa84a00de,0x00000000}},	//   _rúin_, miit, _ولحم_,
  { {0xb4e8016a,0x2127008b,0x7ae46df9,0x00000000}},	//   मचे_, _ninh_, liit,
  { {0x7e7d00ac,0x673c00c2,0x656b00e5,0x00000000}},	//   yfsp, _utrj, augh,
  { {0x236000c3,0x6b830137,0xdce60061,0x00000000}},	//   čij_, _änge, dukč,
  { {0x69c40268,0x2127008b,0x78bc0659,0x00000000}},	//   nyie, _binh_, _korv,
  { {0x7aed055e,0xd36f007e,0x7ae405cc,0x00000000}},	//   znat, _چهل_, hiit,
  { {0x442c017f,0x20c90025,0x21276dfa,0x00000000}},	//   _igd_, _iúil_, _dinh_,
  { {0xa1c62254,0x7e7d004d,0x6f165767,0x00000000}},	//   _обед, ufsp, _chyc,
  { {0x7ae40019,0x78bc00ac,0x3e040062,0x00000000}},	//   diit, _oorv, вярв,
  { {0x7c8402b6,0x78bc6dfb,0xa0c40044,0x00000000}},	//   кусе, _norv, _سيعو,
  { {0x7bd5004d,0x7ae40050,0x7e7d0244,0x00000000}},	//   uzzu, fiit, pfsp,
  { {0x7aed44fb,0x75280022,0x00000000,0x00000000}},	//   unat, _lidz,   ,
  { {0x2bff0053,0x9b240002,0xdcee008f,0x00000000}},	// [f290] _शुरू_, тфрл, žkār,
  { {0x79a4005a,0x75280301,0x67d50086,0x00000000}},	//   ърсе, _nidz, нозу,
  { {0x7aed0137,0x3cf80021,0x7b130058,0x00000000}},	//   pnat, _تعيد_, rçub,
  { {0x2d4d017f,0x9967005a,0x6d4d256a,0x00000000}},	//   ože_, _отгл, _kwaa,
  { {0x78bc31d4,0x2d4d0114,0xaa3a0063,0x00000000}},	//   _forv, nže_, _מתרח,
  { {0x6d4d0035,0xa8a40d34,0x93c40013,0x00000000}},	//   _mwaa, _ирск, _thẳ,
  { {0x69cb00b9,0x20c90025,0xf5060121,0x00000000}},	//   øgef, _dúil_, эншл_,
  { {0x2127001b,0x6595000d,0x26df00a4,0x00000000}},	//   _sinh_, _пабу, _umuo_,
  { {0xa3e4016a,0x20070014,0x75280072,0x00000000}},	//   _पेठ_, _syni_, _fidz,
  { {0x6f0401e3,0x03c70062,0x2d4d6dfc,0x00000000}},	//   _skic, _осем, dže_,
  { {0xf8b20063,0x2127008b,0xbcfb0003,0x00000000}},	//   אשי_, _vinh_, grém,
  { {0x61ea03e8,0x442c007d,0xe3360047,0x00000000}},	//   ámlá, _zgd_, _טרעפ_,
  { {0x67290045,0x29010019,0x2127001b,0x00000000}},	//   _miej, koha_, _tinh_,
  { {0x6d4d006f,0x6f1d00ca,0x67296dfd,0x00000000}},	//   _dwaa, amsc, _liej,
  { {0xdee60071,0xbcfb0003,0x69c4002b,0x00000000}},	//   _поки, crém, wyie,
  { {0x629b00eb,0x2d960086,0x6f040035,0x00000000}},	//   nduo, _зрос, _ukic,
  { {0x66090035,0xdca6012e,0x316d0003,0x00000000}},	// [f2a0] _nyek, _запи, nuez_,
  { {0x7ae40bda,0x4906005d,0xfd120044,0x00000000}},	//   siit, رواق, _حجب_,
  { {0x6d4d0122,0x75283bb3,0xb80a0021,0x00000000}},	//   _zwaa, _ridz, أيام_,
  { {0x20c90025,0x3866003b,0x68e50072,0x00000000}},	//   _súil_, şor_, aihd,
  { {0x672900bd,0xe5a31259,0x78bc6dfe,0x00000000}},	//   _diej, лици, _torv,
  { {0xd6270054,0xd6da005d,0xf993009d,0x00000000}},	//   хоче_, _کورش_, _גרש_,
  { {0x9294000d,0x232626b8,0x7528008f,0x00000000}},	//   вайц, нфиг, _vidz,
  { {0x75280045,0xd2500021,0x2d4d0066,0x00000000}},	//   _widz, جنة_, yže_,
  { {0x316d4352,0x52140062,0x45360054,0x00000000}},	//   guez_, ъдит, _їхат,
  { {0xf9770047,0x4438004d,0xbcfb6dff,0x00000000}},	//   עגיש_, _ür_, trém,
  { {0x6d4d00e8,0xddcd003b,0x62990022,0x00000000}},	//   _swaa, _ocaţ, _fawo,
  { {0x316d0003,0x6465008f,0x62994882,0x00000000}},	//   buez_, ēriņ, _gawo,
  { {0x66f50078,0x69100072,0x6f1d317c,0x00000000}},	//   nąka, väen, rmsc,
  { {0x62990051,0x62800983,0x10a3005e,0x00000000}},	//   _zawo, lfmo, _биљн,
  { {0x2f1200ea,0xdfcf0062,0x2ef50062,0x00000000}},	//   sága_, _съ_, _изкр,
  { {0x6d4d0179,0x929d0051,0xedd50044,0x00000000}},	//   _twaa, połe, _ليبد,
  { {0xe9f80086,0xbdf5005e,0x68e50058,0x00000000}},	// [f2b0] енті_, _шпиј, tihd,
  { {0x629b0006,0xed590066,0x672923a8,0x00000000}},	//   zduo, ážu_, _siej,
  { {0xec36014e,0xa2660006,0x66090150,0x00000000}},	//   _באתר_, dėžę_, _syek,
  { {0xb8c80053,0x36d40a71,0xcdd5009a,0x00000000}},	//   _खो_, лохр, ֣ךְ_,
  { {0x672902dd,0x9f5c024a,0x3eb90122,0x00000000}},	//   _viej, _hyvä_, ijst_,
  { {0x67290051,0xf5050062,0x7a40004c,0x00000000}},	//   _wiej, ъзло, rátů,
  { {0xf8f4000d,0xdc3c0047,0x6280004d,0x00000000}},	//   _спрэ, לעגר, ffmo,
  { {0xf99f006c,0xc2420094,0x00000000,0x00000000}},	//   _uzès_, анък,   ,
  { {0x36d40076,0x629b0006,0x6910004b,0x00000000}},	//   _сотр, rduo, käel,
  { {0x316d0003,0x7e76056c,0x2127005d,0x00000000}},	//   ruez_, _scyp, ژيکی_,
  { {0x644b007d,0x99560054,0x6e4601ce,0x00000000}},	//   čnič, дiли_, кенз,
  { {0xdee60b4c,0xed5a2373,0xfe720593,0x00000000}},	//   томи, мом_, جدد_,
  { {0x316d03b2,0x629c001c,0xf1d90053,0x00000000}},	//   quez_, ērot, _बेचन,
  { {0x8fe50044,0x2fd50044,0x71d6009a,0x00000000}},	//   _لأعم, _لتبح, _בונד_,
  { {0x6d400026,0x7afb00c2,0xac760043,0x00000000}},	//   ímab, čutn, _یادش,
  { {0xc3320a7a,0x8f74012c,0xda6614d7,0x00000000}},	//   שון_, _суші, ضاري,
  { {0x3b07026b,0xbcfb01a8,0xeabf0013,0x00000000}},	// [f2c0] тето_, gués, _giùm_,
  { {0x6b9b0051,0x07a6379e,0x684301ce,0x00000000}},	//   ługa, казн, инуа,
  { {0xc00f0013,0xaa4a01ce,0x186701ce,0x00000000}},	//   _đuối_, _опна_, ђаци_,
  { {0xdd110080,0x6d4601af,0x2bf70063,0x00000000}},	//   mýšl, opka, _ימין_,
  { {0x2918002b,0xfe37009a,0x659300de,0x00000000}},	//   _thra_, דרני_, لجور,
  { {0xf8bf0013,0x69cb01e1,0x00000000,0x00000000}},	//   _quét_, øgee,   ,
  { {0xe7370086,0x9cd7009a,0x889b009d,0x00000000}},	//   _аес_, כוסה_, _קבלי,
  { {0xc1740062,0x2bba0042,0xf1a60f9f,0x00000000}},	//   глищ, _उपना, врон,
  { {0x41530085,0xbcfb01d1,0x61430131,0x00000000}},	//   авыс, bréh, аења,
  { {0x30a6184a,0xc9530063,0xbcfb013d,0x00000000}},	//   трив, סמת_, mség,
  { {0x64580b4f,0x69100019,0x443e01e1,0x00000000}},	//   mavi, väel, _ift_,
  { {0x645800eb,0x7c3e0146,0xe2460067,0x00000000}},	//   lavi, _afpr, _شخصي,
  { {0xbcfb000f,0x20020051,0x40960021,0x00000000}},	//   nség, łki_, _للشر,
  { {0x31570047,0xbcfb017d,0x64586e00,0x00000000}},	//   _יידן_, oréi, navi,
  { {0x6d46014f,0xf0930063,0xfc460066,0x00000000}},	//   apka, _כנס_, _číta_,
  { {0xbcfb00ea,0x64586e01,0xdce6008f,0x00000000}},	//   kség, havi, rukā,
  { {0xbcfb5378,0x64586e02,0x443e495e,0x00000000}},	// [f2d0] hréi, kavi, _oft_,
  { {0x6d5d0f1b,0x64580648,0xf1b30047,0x00000000}},	//   mssa, javi, ױסע_,
  { {0x69cb00b9,0x6d5d04d1,0x05db0042,0x00000000}},	//   øgeb, lssa, _मेजब,
  { {0x4615007e,0x929d0051,0x6d5d6e03,0x00000000}},	//   هوار, koła, ossa,
  { {0xbcfb00ea,0x6d5d3929,0x443e008d,0x00000000}},	//   gség, nssa, _bft_,
  { {0xb97a014e,0x64580006,0x6d5d6e04,0x00000000}},	//   _אנשי, gavi, issa,
  { {0xfe7f00cd,0x1cbc0047,0xa3bb0044,0x00000000}},	//   viïn_, ומגע, باشر_,
  { {0xf8bf0003,0x64580072,0xbcfb013d,0x00000000}},	//   _tués_, aavi, bség,
  { {0xbcfb0003,0x443e6e05,0x64581b83,0x00000000}},	//   préh, _fft_, bavi,
  { {0x4095065b,0x6d5d018c,0x2ecc0053,0x00000000}},	//   урит, dssa, ास्त,
  { {0xd2510032,0x6d5d6e06,0xceea22c4,0x00000000}},	//   _هنا_, essa, едне_,
  { {0xc33201d8,0x6235000a,0x656b000c,0x00000000}},	//   _הוא_, _седу, orgh,
  { {0x7afb00c3,0xaed3000d,0xa0691850,0x00000000}},	//   čutl, соўш, _зала_,
  { {0x7659001f,0x515a0063,0xa3ca0053,0x00000000}},	//   hawy, _טכנו, रैक_,
  { {0x6b630086,0xbcfb00ea,0xbea66e07,0x00000000}},	//   йкра, zség, _байк,
  { {0xd00e0032,0x64581b99,0x3f51001c,0x00000000}},	//   _علي_, zavi, mšu_,
  { {0x200b0051,0x44200013,0x7659002b,0x00000000}},	// [f2e0] ęciu_, ̀i_, dawy,
  { {0xe849005d,0xa90a009b,0x3a23012c,0x00000000}},	//   نجمن_, ريال_, смуг,
  { {0x2f19000f,0x64580006,0x3f51001c,0x00000000}},	//   sége_, vavi, nšu_,
  { {0xbcfb6e08,0x3f510249,0xeb97030b,0x00000000}},	//   tség, išu_, _сию_,
  { {0x64586e09,0xbddb0003,0x9c8701d9,0x00000000}},	//   tavi, ccèd, _určí,
  { {0xbcfb1584,0x3f51001c,0xef19001c,0x00000000}},	//   tréi, kšu_, itļa_,
  { {0xbcfb000f,0x929d0051,0xa3e40053,0x00000000}},	//   sség, woła, _पेश_,
  { {0x7e640035,0xbcfb29c7,0xfbd30063,0x00000000}},	//   _ndip, rréi, מתו_,
  { {0x3f51001c,0x00ea0002,0x6b950022,0x00000000}},	//   ešu_, еќни_, zwzg,
  { {0xe97b0047,0xb6030240,0xf9930063,0x00000000}},	//   עניש, ýšen, צרת_,
  { {0x33f60076,0xbcfb0164,0x3f51001c,0x00000000}},	//   _счас, nsée, gšu_,
  { {0x7bdc00cd,0xbcfb0003,0x6d5d2523,0x00000000}},	//   dzru, isée, tssa,
  { {0x3f516e0a,0x7e64002b,0x6d5d6e0b,0x00000000}},	//   ašu_, _ddip, ussa,
  { {0x6d400026,0x7e645ead,0x7996001f,0x00000000}},	//   ímaa, _edip, dwyw,
  { {0xcb1b000a,0x2d8c003b,0xda350121,0x00000000}},	//   еќа_, ădea_, иевы,
  { {0x6b9b0051,0x5bb80121,0xe7fa0042,0x00000000}},	//   ługo, ылся_, ्थना_,
  { {0x08550376,0x1eea005d,0xa8550899,0x00000000}},	// [f2f0] иваю, _جويی_, икач,
  { {0xd7fb000d,0xe6c0007d,0x63a80f37,0x00000000}},	//   нуе_, _čišć, _ordn,
  { {0xec15007e,0x96356e0c,0x7d072a2b,0x00000000}},	//   _خودد, анец, mojs,
  { {0xbcfb0164,0xe70b01fb,0xb065004e,0x00000000}},	//   sséd, رتان_, onää,
  { {0x286b00e1,0x4a5a0063,0x32110022,0x00000000}},	//   _прво_, _בדרו, ęzyk_,
  { {0x98ab003b,0x39496e0d,0x67220440,0x00000000}},	//   _ducă_, mpas_, amoj,
  { {0xe29907f0,0x39496e0e,0x32d50cbb,0x00000000}},	//   вай_, lpas_, ицис,
  { {0x39496e0f,0xd2a90121,0xba3b0003,0x00000000}},	//   opas_, ткие_, _faïe,
  { {0x39490186,0x63a8004d,0x78b2009c,0x00000000}},	//   npas_, _erdn, _újvá,
  { {0x6ad20053,0x00820cba,0x6910004b,0x00000000}},	//   _सत्र, ольо, väek,
  { {0x200201f7,0x6d446e10,0xc2c5007e,0x00000000}},	//   şkin_, _stia, _پيشي,
  { {0x3f51001c,0x200e00a3,0x26cf6e11,0x00000000}},	//   ršu_, _dyfi_, nkgo_,
  { {0x20d5019d,0xe0ce005a,0x224d6e12,0x00000000}},	//   _війс, _дв_, mbek_,
  { {0xc5f2014e,0xa0696903,0x3f51008f,0x00000000}},	//   קדם_, _рака_, pšu_,
  { {0xca560001,0x6b830137,0xfbc31b5f,0x00000000}},	//   итањ, _ängl, обро,
  { {0x316d4cf4,0x38c8007e,0x4a462125,0x00000000}},	//   orez_, گاری_, рнав,
  { {0x3949002c,0x590a0002,0x61ed00b2,0x00000000}},	// [f300] gpas_, веам_, _žalj,
  { {0xebe6000a,0x38c8006a,0x69cb00b9,0x00000000}},	//   _вооп, داری_, øgea,
  { {0x8b96000a,0x39496e13,0x3eb200b9,0x00000000}},	//   _трпч, apas_, _knyt_,
  { {0xe5c61099,0x473315d4,0x4aca0053,0x00000000}},	//   исло, ініс, _रविव,
  { {0xbcfb0164,0x7ae100ac,0x67220b4f,0x00000000}},	//   ssée, ëlte, rmoj,
  { {0x5334005a,0x60c30509,0x6722001c,0x00000000}},	//   бект, _nonm, smoj,
  { {0xdb1c00fe,0xbcfb0003,0x316d6e14,0x00000000}},	//   pyrä, prév, erez_,
  { {0xdb1c0829,0x2489007d,0x316d0003,0x00000000}},	//   byrå, đama_, frez_,
  { {0x6441001f,0xbcfb0003,0x316d006c,0x00000000}},	//   _ffli, nséc, grez_,
  { {0x60c32cff,0xf484006a,0x63a800c3,0x00000000}},	//   _conm, _داری, _trdn,
  { {0x224d00ea,0xf8370063,0x6d400865,0x00000000}},	//   bbek_, ינית_, íman,
  { {0x3ea00139,0xbcfb0003,0x7afb00c2,0x00000000}},	//   _cait_, hrét, čutk,
  { {0xbd6b005a,0x60dd001c,0xba3b00f4,0x00000000}},	//   ърне_, ūsma, _laïc,
  { {0x7d020027,0x7bc10072,0x26c447c3,0x00000000}},	//   _íosl, äluo, _lomo_,
  { {0x3ea003b2,0xd0f50161,0x7d07007d,0x00000000}},	//   _fait_, ीकरण_, rojs,
  { {0xdee40001,0x5a350189,0x3ea000e5,0x00000000}},	//   _моји, снат, _gait_,
  { {0x7afa0026,0x7b130058,0x7c87093d,0x00000000}},	// [f310] étta, lçuk, _куне,
  { {0x58bb0021,0x39496e15,0x5ce40044,0x00000000}},	//   خارج_, rpas_, _وكيل,
  { {0x26c40198,0xfc460240,0x39496e16,0x00000000}},	//   _bomo_, číte_, spas_,
  { {0x26c46e17,0x394902f0,0x2d8f0003,0x00000000}},	//   _como_, ppas_, _âges_,
  { {0x644100bd,0x04450062,0x7aed6e18,0x00000000}},	//   _pfli, белн, miat,
  { {0x316d0164,0xbcfb236b,0x7aed6e19,0x00000000}},	//   vrez_, crét, liat,
  { {0x6f0d00b2,0xbcfb013d,0x7aed004b,0x00000000}},	//   _okac, lrés, oiat,
  { {0x316d03b2,0x2bf80063,0x236901b3,0x00000000}},	//   trez_, ימון_, čaj_,
  { {0x690b0016,0x316d0003,0x20020058,0x00000000}},	//   qües, urez_, şkil_,
  { {0x83870076,0x316d0164,0x147704f6,0x00000000}},	//   _выде, rrez_, _خارج,
  { {0x7aed6e1a,0x85040021,0x7af60072,0x00000000}},	//   kiat, _بولن, ynyt,
  { {0x66fc0195,0xe81f0042,0x60da004e,0x00000000}},	//   očka, _भरना_, ahtm,
  { {0x7aed3e9d,0x21690815,0x3ea01384,0x00000000}},	//   diat, _сили_, _vait_,
  { {0x3ea00034,0x2d82017f,0x60da05df,0x00000000}},	//   _wait_, rtke_, chtm,
  { {0x69cb0146,0x7af60137,0xfce309c2,0x00000000}},	//   øgen, tnyt, чоро,
  { {0x3ea00027,0x7f3a00b5,0x7aed238e,0x00000000}},	//   _uait_, _געקו, giat,
  { {0x5d860032,0x26c44ec0,0xc9aa000d,0x00000000}},	// [f320] _الخل, _romo_, ывае_,
  { {0x26c40035,0xbcfb0003,0xc212009a,0x00000000}},	//   _somo_, rséc, להן_,
  { {0xbcfb000b,0x7aed6e1b,0x6d56002b,0x00000000}},	//   rrét, biat, _hwya,
  { {0x66760021,0xf6e50086,0xbcfb0014,0x00000000}},	//   إدار, оцін, srét,
  { {0xdb230080,0x6aa4002b,0xbcfb0046,0x00000000}},	//   _írán, mdif, prét,
  { {0x6d560185,0x25a66e1c,0xc95303c3,0x00000000}},	//   _mwya, rvol_, _ממש_,
  { {0x25a60250,0x79846684,0x26c44058,0x00000000}},	//   svol_, ltiw, _tomo_,
  { {0x26c4051e,0x673800ea,0x6aa46e1d,0x00000000}},	//   _uomo_, ívju, ndif,
  { {0xc05a2049,0x7984002b,0x7bce63f6,0x00000000}},	//   лін_, ntiw, hybu,
  { {0x7aed033f,0x7afb00c2,0x935a3320,0x00000000}},	//   ziat, čuti, _брду_,
  { {0x645a001c,0x7f580141,0xf3f1008d,0x00000000}},	//   _ieti, јамс_, _hẹn_,
  { {0x798400e8,0x539b0063,0xb5fd00c2,0x00000000}},	//   ktiw, _תיאו, _odšl,
  { {0xd24f0032,0x645a0397,0x7aed6e1e,0x00000000}},	//   _أنه_, _keti, viat,
  { {0x7aed0051,0x261b0042,0xd197009a,0x00000000}},	//   wiat, _बरसी_, _לכדי_,
  { {0x645a01f7,0xd00f0021,0x2f1200ea,0x00000000}},	//   _meti, _كله_, zági_,
  { {0x69cb0146,0x6d56001f,0x61ed2e6a,0x00000000}},	//   øgeo, _fwya, _žali,
  { {0x1ef80021,0x7aed6e1f,0xf8b1005d,0x00000000}},	// [f330] _دعوة_, riat, وکس_,
  { {0x645a6e20,0x7aed5909,0xa3ab0042,0x00000000}},	//   _neti, siat, खिम_,
  { {0x661b0045,0x798400a4,0xbcfb013d,0x00000000}},	//   _szuk, atiw, srés,
  { {0xbcfb3ec9,0x1e3c0047,0xa615012f,0x00000000}},	//   prés, ָגגא, омеч,
  { {0x645a0c8e,0x356b0189,0x7afd006f,0x00000000}},	//   _beti, урен_, _ijst,
  { {0x2489007d,0x645a6e21,0x9475005d,0x00000000}},	//   đamo_, _ceti, تگرا,
  { {0x2f1200ea,0x36d50259,0x645a3570,0x00000000}},	//   sági_, _довр, _deti,
  { {0xa3de0080,0x645a0019,0x42c91849,0x00000000}},	//   běží_, _eeti, ргин_,
  { {0xe1ff01a8,0xd4b90054,0xe0d946a5,0x00000000}},	//   çó_, _клац_, иви_,
  { {0xa06900e1,0x645a6e22,0x20c90139,0x00000000}},	//   јана_, _geti, _rúis_,
  { {0xdbf20080,0x69100004,0x20c90014,0x00000000}},	//   _příp, päev, _búir_,
  { {0x753b0035,0x8234007e,0x2d9e0022,0x00000000}},	//   _kuuz, _فرها, łtem_,
  { {0x69cb0146,0x645a005b,0xef18008f,0x00000000}},	//   øgel, _yeti, ēļ_,
  { {0x7afd0077,0x225f005f,0x41b20043,0x00000000}},	//   _ajst, lauk_, _آمور,
  { {0xf3f1008b,0xea5a0d34,0x64430d17,0x00000000}},	//   _mẹo_, ирај_, icni,
  { {0x7bce0051,0xbddb0003,0xbcfb0139,0x00000000}},	//   rybu, rbèr, rséa,
  { {0x7bce00d1,0xc9a709c2,0x6aa46158,0x00000000}},	// [f340] sybu, овте_, rdif,
  { {0x186a5ccb,0x79845dac,0x6910004b,0x00000000}},	//   ражи_, rtiw, jäet,
  { {0x79846e23,0x645a1ecc,0xbb860044,0x00000000}},	//   stiw, _reti, _بلجي,
  { {0x645a014f,0x4b7b0047,0x64430290,0x00000000}},	//   _seti, _דאטו, ecni,
  { {0x65960032,0xba480006,0x645a6e24,0x00000000}},	//   تجار, grįž, _peti,
  { {0x65626e25,0xf3f1008d,0x4991005d,0x00000000}},	//   rsoh, _vẹn_, _سیمر,
  { {0x39400089,0xf487007e,0x6d4001d1,0x00000000}},	//   lqis_, تانی, ímaj,
  { {0xd1410051,0xc3270021,0x60c101e1,0x00000000}},	//   knąć_, يكون_, ejlm,
  { {0x11d80021,0x645a6e26,0x27ea0078,0x00000000}},	//   صودة_, _teti, žinė_,
  { {0x79b70063,0x6b9b0022,0x673c6e27,0x00000000}},	//   קליד_, ługi, _kurj,
  { {0x66fc00c2,0x320a0051,0x673c18d7,0x00000000}},	//   nčko, łby_, _jurj,
  { {0x7ee70086,0x539b0063,0xd1410022,0x00000000}},	//   іцне, _כיבו, fnąć_,
  { {0xc3330063,0x61ed005f,0xd1410022,0x00000000}},	//   _חוף_, _žalv, gnąć_,
  { {0xd12f0088,0x69cb00b9,0x559b0041,0x00000000}},	//   _іх_, øgem, ױסלײ,
  { {0x2ac70001,0xac19018b,0x7ac70121,0x00000000}},	//   ољав, сову_, осае,
  { {0x98850080,0xa3ab0053,0x7ee40021,0x00000000}},	//   _vůči_, खित_, _يكون,
  { {0x097501dd,0xe84b0044,0x49753fe2,0x00000000}},	// [f350] ягаю, لجان_, ялас,
  { {0x39460025,0x7e7d01f2,0xf84b000d,0x00000000}},	//   íosa_, lgsp, рчай_,
  { {0x872b000d,0x7e7d006f,0x6910004b,0x00000000}},	//   аўда_, ogsp, väet,
  { {0x6d4f006f,0x7e7d0246,0x41ca0053,0x00000000}},	//   opca, ngsp, िहास,
  { {0x2aba009a,0x2bc90082,0x7aba009a,0x00000000}},	//   _המרא, रहवा, _הצרו,
  { {0x04c80021,0x20110058,0x03a5079b,0x00000000}},	//   يوني_, üzik_, зико,
  { {0xccf4009a,0xfc58009a,0xc69700de,0x00000000}},	//   וכס_, חבוש_, _وشرع,
  { {0xd2990088,0xc7b2014e,0x4bfc0063,0x00000000}},	//   сткі_, _אבל_, ילוס,
  { {0xcb140063,0x225f0078,0xf4870500,0x00000000}},	//   ולק_, rauk_, _мужн,
  { {0x7e7d030c,0x225f0023,0xe0d92530,0x00000000}},	//   egsp, sauk_, сво_,
  { {0x9f58007a,0xd009005a,0xa4fa0047,0x00000000}},	//   ærð_, сене_, _פלעט,
  { {0x141a0063,0x61ed6e28,0xc7d60063,0x00000000}},	//   _הועב, _žalu, פורי_,
  { {0xd13b0259,0xbddb0110,0xf1a70818,0x00000000}},	//   _тхе_, scèn, _френ,
  { {0x38616e29,0x3cf60053,0xe4470021,0x00000000}},	//   jahr_, ँचें_, عض_,
  { {0xd1410022,0x60d6009a,0x00ba009d,0x00000000}},	//   snąć_, _מוסא_, _למסמ,
  { {0x39466e2a,0x00000000,0x00000000,0x00000000}},	//   знаг,   ,   ,
  { {0x386100bd,0x2a600bdb,0xcf250593,0x00000000}},	// [f360] fahr_, raib_, _تروي,
  { {0xe9d76e2b,0x673c01a9,0x69100656,0x00000000}},	//   чку_, _purj, väes,
  { {0x98aa000c,0x4c3b0063,0x3b0a06da,0x00000000}},	//   _aibă_, _לתיב, _гено_,
  { {0xeaf90053,0x69100072,0x66fc007d,0x00000000}},	//   ्कृत_, täes, rčko,
  { {0xa3e40053,0x6d400046,0x00000000,0x00000000}},	//   _पेज_, ímah,   ,
  { {0x7d0e1806,0x4394082d,0x13940094,0x00000000}},	//   nobs, дакс, дикю,
  { {0xd467005e,0xd36f0085,0xf433014b,0x00000000}},	//   чије_, эч_, нешэ,
  { {0x46a31fa0,0xe3af0cac,0x57fb009a,0x00000000}},	//   _пасв, ارو_, _הללו,
  { {0x3f67007d,0x5436014d,0x7d0e6e2c,0x00000000}},	//   eđu_, _فرار, kobs,
  { {0xc4830002,0x54670ace,0x46130021,0x00000000}},	//   _плук, _наум_, _أوكر,
  { {0x3f630076,0x9f58005b,0xf1f7007e,0x00000000}},	//   нтяб, _özür_, قعیت_,
  { {0x333b014e,0x69cb00b9,0x7b1300cd,0x00000000}},	//   _התאמ, øgek, nçut,
  { {0x6282006f,0x7e7d6e2d,0x316602f7,0x00000000}},	//   _icoo, rgsp, _uvoz_,
  { {0xdcef000c,0x6d4f00ca,0xef19008f,0x00000000}},	//   ducă, rpca, itļi_,
  { {0x6aa60c01,0xdb0f013d,0x80a3043e,0x00000000}},	//   _bakf, ődít, _سمين,
  { {0x68ee0268,0x6ffb014e,0x3861004d,0x00000000}},	//   _ambd, _להופ, wahr_,
  { {0xaf3401fb,0x44290013,0x7e6d004e,0x00000000}},	// [f370] _ثروت, ̀a_, _idap,
  { {0x6d4d6e2e,0x6f0f6e2f,0x66d30075,0x00000000}},	//   _itaa, locc, _içki,
  { {0xbcfb006c,0xf79901f3,0x00000000,0x00000000}},	//   nsém, تناب_,   ,
  { {0x6d490529,0x3986017d,0x6f0f206f,0x00000000}},	//   ţeau, bôs_, nocc,
  { {0x3e8800ea,0xe60e167b,0xa2c00042,0x00000000}},	//   lító_, тд_, वान्,
  { {0x0608000d,0x2481004b,0xba3b0003,0x00000000}},	//   чнік_, ühm_, _maïm,
  { {0xf8b2014e,0x6910004d,0xf7940085,0x00000000}},	//   _בשם_, päer, _парэ,
  { {0x6d4d006f,0x660d004b,0x11d50054,0x00000000}},	//   _otaa, üaks, діор,
  { {0x69cb01e1,0x30756e30,0xb5fd0a1e,0x00000000}},	//   øgeh, мунс, _odši,
  { {0xe0d10021,0xbddb0003,0x61ed0078,0x00000000}},	//   ئزة_, rcèl, _žals,
  { {0x5f0601dd,0x00000000,0x00000000,0x00000000}},	//   дзна,   ,   ,
  { {0x3e88013d,0x0378005d,0x00000000,0x00000000}},	//   dító_, _رحمت_,   ,
  { {0xc332009a,0xa0696e31,0x8628009d,0x00000000}},	//   _סוד_, _дала_, ּֽרֶ,
  { {0xee370088,0xddc4000c,0x78a70648,0x00000000}},	//   ьня_, _adiţ, _najv,
  { {0x6f0f0290,0x7d0e3d38,0x70921313,0x00000000}},	//   bocc, robs, _рајф,
  { {0x7b3c017f,0x629b001f,0x60080063,0x00000000}},	//   _očuv, neuo, _מִפְ,
  { {0xd7f8000c,0x6aa60058,0x29070124,0x00000000}},	// [f380] _ţă_, _vakf, čnan_,
  { {0xddc4000c,0xeb9a0001,0x629b002b,0x00000000}},	//   _ediţ, _дио_, heuo,
  { {0x7b3c007d,0x6aa66e32,0x78a700a8,0x00000000}},	//   _ačuv, _takf, _dajv,
  { {0x3986017d,0xe61a6e33,0x00000000,0x00000000}},	//   pôs_, оде_,   ,
  { {0xa2b10053,0x2ef9013d,0x629b00a3,0x00000000}},	//   _अफ़्, érfi_, deuo,
  { {0xa5330086,0x62826533,0x8b65007e,0x00000000}},	//   вніч, _scoo, _تایم,
  { {0x7791007e,0xb17d0024,0x47d6005d,0x00000000}},	//   _میلا, vzťa, _غيرر,
  { {0x416a0001,0x816a0054,0x629b00a3,0x00000000}},	//   ојом_, ороб_, geuo,
  { {0xdd140024,0xc4860001,0x05ba0021,0x00000000}},	//   dĺžn, _олак, _بدأت_,
  { {0x69cb00b9,0xa1270021,0x00000000,0x00000000}},	//   øgei, وكيل_,   ,
  { {0x6f0f0290,0x6d4d2790,0x5436005e,0x00000000}},	//   tocc, _staa, _цхау,
  { {0xfe7f00cd,0x3e88013d,0xa3db0082,0x00000000}},	//   viïs_, vító_, डनर_,
  { {0x6f0f6e34,0xbcfb0003,0x0cab019c,0x00000000}},	//   rocc, ssém, отви_,
  { {0x6f0f0290,0x45d90041,0x3e88013d,0x00000000}},	//   socc, פֿרא, tító_,
  { {0x1fa3000d,0x6d343121,0x6910004e,0x00000000}},	//   _арыг, терф, väep,
  { {0x62806e35,0x3e88013d,0x5fcb0042,0x00000000}},	//   ngmo, rító_, ाहरल,
  { {0x3e88000f,0xeabf008b,0x2727004b,0x00000000}},	// [f390] sító_, _chùa_, lõng_,
  { {0x3ea909fe,0x6d49003b,0x98740062,0x00000000}},	//   _haat_, ţeas, клуц,
  { {0x8c44000a,0x47580054,0x6d406e36,0x00000000}},	//   _шеќе, дрія_, ímav,
  { {0x36d4005e,0x98aa0078,0xb5fd0130,0x00000000}},	//   кохр, _ribą_, _leše,
  { {0x7bd50240,0xd5670121,0x78b20014,0x00000000}},	//   lyzu, фтеп, íkvó,
  { {0x3ea904c6,0xa3ab0235,0x6b830ae2,0x00000000}},	//   _laat_, खिल_, _ängs,
  { {0x84640062,0xb8d50042,0x83640044,0x00000000}},	//   тъче, ढ़ा_, نديل,
  { {0x9fae013d,0x5c38009a,0x339214d7,0x00000000}},	//   _főút_, ורון_, اليز,
  { {0x7afa007a,0x629b001f,0xddc408b7,0x00000000}},	//   étti, reuo, _odiš,
  { {0x629b0185,0xef190023,0x24550044,0x00000000}},	//   seuo, itļu_, _أناس,
  { {0x3ea9006f,0x325542ac,0x929d0051,0x00000000}},	//   _baat_, _звер, wołu,
  { {0xcfd20044,0x92670cac,0x00000000,0x00000000}},	//   ايَة, _آدام,   ,
  { {0x5d670076,0x9dba000d,0xd0d50456,0x00000000}},	//   ниям_, чыну_, _подъ,
  { {0xa0c50044,0x00000000,0x00000000,0x00000000}},	//   _سيبو,   ,   ,
  { {0x69cb092e,0x7a2a013d,0xab2a0c46,0x00000000}},	//   ägen, köté, зова_,
  { {0x3ea902b0,0x2fd805b9,0xfaa34a23,0x00000000}},	//   _gaat_, ørge_, ласо,
  { {0xc3320a7a,0x692624fe,0x3876005e,0x00000000}},	// [f3a0] רון_, емаа, ећет,
  { {0x7d57016e,0xd622014b,0x00000000,0x00000000}},	//   _רייד_, цiна,   ,
  { {0xe73a0121,0xdb0f013d,0x7b13006c,0x00000000}},	//   чее_, ődát, rçur,
  { {0xc8690063,0x66e3046e,0xb7160043,0x00000000}},	//   מן_, лоха, رباش,
  { {0xe5720044,0x00000000,0x00000000,0x00000000}},	//   اطؤ_,   ,   ,
  { {0xdb0500bd,0x2ee0002b,0x34940085,0x00000000}},	//   _erhä, _llif_, такр,
  { {0x96960079,0x2f1900ea,0xb5fd027c,0x00000000}},	//   _праш, ségi_, _reše,
  { {0x6b830137,0x68340078,0xb5fd004c,0x00000000}},	//   _ånge, gždž, _seše,
  { {0x1a9b00b5,0x7ae40d69,0x7e666e37,0x00000000}},	//   ליקע, ihit, dakp,
  { {0x3ea96e38,0x3b000089,0x2ee030a7,0x00000000}},	//   _saat_, hniq_, _alif_,
  { {0x20180026,0x32e4008b,0x1f740062,0x00000000}},	//   æri_, _đườ, ълня,
  { {0x7ae400c2,0x753a00e0,0xdb1d0058,0x00000000}},	//   jhit, _hitz, üyüm,
  { {0xed58000d,0xbcfb0139,0xc2e90021,0x00000000}},	//   ноў_, lséi, _تعلم_,
  { {0x7ae40213,0x91bb0063,0x63ad0022,0x00000000}},	//   ehit, _ממדי, łane,
  { {0x6fe60003,0x3ea90397,0x644a0025,0x00000000}},	//   _décé, _taat_, icfi,
  { {0x3f8b000c,0xdb0500d1,0x3da70726,0x00000000}},	//   ăcut_, _orhå, _зроб,
  { {0x5a350189,0x6d4054d8,0x0c740195,0x00000000}},	// [f3b0] тнат, ímat, ýýýý,
  { {0x6f1d20ed,0x394f001c,0xf8070d82,0x00000000}},	//   llsc, īgs_, нчен,
  { {0x6f1d0022,0x2eab009a,0x00000000,0x00000000}},	//   olsc, ּשְּ,   ,
  { {0x443e6e39,0xb5fd0d77,0x2727004b,0x00000000}},	//   _agt_, _odšt, kõne_,
  { {0x443e0150,0x6b8300a5,0xe5a507a1,0x00000000}},	//   _bgt_, _ångb, тили,
  { {0xdb1c007a,0x69cb00b9,0x6f1d004d,0x00000000}},	//   lyrð, øgeu, hlsc,
  { {0xdb0500c7,0x3942004b,0x94d20002,0x00000000}},	//   _erhå, _zuks_, ројц,
  { {0x6aad1e3a,0x443e0244,0x645d009c,0x00000000}},	//   ndaf, _egt_, _ősid,
  { {0x798d0509,0x64580137,0x30790021,0x00000000}},	//   ntaw, bbvi, وحدة_,
  { {0x7659001f,0x798d25e5,0xf992009a,0x00000000}},	//   lbwy, itaw, סרי_,
  { {0x29010016,0x22950021,0x798d0150,0x00000000}},	//   inha_, _للاس, htaw,
  { {0x92eb006a,0x798d20ea,0x4425007d,0x00000000}},	//   _عراق_, ktaw, _izl_,
  { {0x69cb01bb,0xdce4008f,0xeabf008d,0x00000000}},	//   ägel, _aviā, _phùn_,
  { {0xdb1c0014,0x7e66004b,0x1fb509c8,0x00000000}},	//   eyrð, sakp, _асир,
  { {0x5f06005a,0x2d9e0a63,0xdddd0051,0x00000000}},	//   _изка, ňte_, gasł,
  { {0x2901017d,0x673b0078,0x6d400014,0x00000000}},	//   enha_, _niuj, ímas,
  { {0x61e9051d,0x7ae44578,0x6e240035,0x00000000}},	// [f3c0] nzel, rhit, _uzib,
  { {0x7ae4075a,0x7d7b00ff,0x61e94c78,0x00000000}},	//   shit, _קריג, izel,
  { {0x7659001f,0xcc770063,0x61e90717,0x00000000}},	//   fbwy, _בעיה_, hzel,
  { {0x753a00bd,0xd6d90086,0x29016e3a,0x00000000}},	//   _sitz, нті_, anha_,
  { {0x61e9006f,0xa2c00053,0x673b0397,0x00000000}},	//   jzel, वास्, _diuj,
  { {0xe476000d,0xd6e20022,0xf993009f,0x00000000}},	//   тудэ, _siłę_, _דרש_,
  { {0x6458001c,0x61e94685,0x66096e3b,0x00000000}},	//   rbvi, ezel, _exek,
  { {0x7e640025,0xddcd003b,0x32530062,0x00000000}},	//   _neip, _neaş, авър,
  { {0x7f43048e,0x7ae3000c,0x36670142,0x00000000}},	//   _aunq, _înte, _шато_,
  { {0x753a0122,0x6f1d006f,0x443e6e3c,0x00000000}},	//   _uitz, wlsc, _ugt_,
  { {0x03a3019d,0x2378013d,0x287b0063,0x00000000}},	//   _вихо, _írj_, ונימ,
  { {0x7f43051e,0xc6940047,0xd2430121,0x00000000}},	//   _dunq, נאָ_, _кэши,
  { {0x7e64001f,0x61e90051,0x91e302b3,0x00000000}},	//   _deip, czel, _коце,
  { {0x40a8007e,0x69cb004b,0x71d70063,0x00000000}},	//   _سختی_, ägem, _בודד_,
  { {0xb5fd02f7,0x7659002b,0xa3ab0053,0x00000000}},	//   _meša, ybwy, खिए_,
  { {0x386300b9,0xaa7b0046,0x798d0b7c,0x00000000}},	//   _sejr_, _blýa, ttaw,
  { {0x6d440577,0xef1f0058,0x6aad06ee,0x00000000}},	// [f3d0] _guia, mlü_, rdaf,
  { {0x798d36d7,0xc0d40063,0x29f30058,0x00000000}},	//   rtaw, נֵּה_, _ağaç_,
  { {0x798d47ff,0x386300b9,0x661b014f,0x00000000}},	//   staw, _vejr_, _syuk,
  { {0xcf9300b5,0xe7580086,0x69cb00b9,0x00000000}},	//   יטע_, тиці_, øges,
  { {0xa4d50086,0x4974000d,0x7659002b,0x00000000}},	//   лоді, _кляс, rbwy,
  { {0xd0060032,0x61e900c3,0xd3890121,0x00000000}},	//   _هل_, vzel, ейке_,
  { {0xb5fd017f,0xef1f0058,0x57a402fe,0x00000000}},	//   _deša, klü_, _кшта,
  { {0x61e910ce,0xd18503d6,0x41590054,0x00000000}},	//   tzel, глий, ншою_,
  { {0x61e96e3d,0x249b0044,0xf57914d7,0x00000000}},	//   uzel, _يخطب_, _سماع_,
  { {0x9fc90002,0x61e96e3e,0x03b70044,0x00000000}},	//   егоа_, rzel, _لإصد,
  { {0x92590062,0xba3b0003,0xc2750141,0x00000000}},	//   _зает_, _taïw, _блеј,
  { {0x61e900ea,0xb1b504a0,0x2ede0082,0x00000000}},	//   pzel, _محتش, मसेत,
  { {0xd12e006a,0xcdf6026c,0xeabf0013,0x00000000}},	//   تمی_, учны, _chùm_,
  { {0x7172007e,0x64410244,0x4df5079f,0x00000000}},	//   _اهوا, _jgli, ряют,
  { {0x3bd50055,0x75ea00ea,0x6fb2007e,0x00000000}},	//   аютс, _közé, _هموا,
  { {0x7ce20066,0x224d013d,0xe7f90042,0x00000000}},	//   _dôra, ncek_, ्पना_,
  { {0x6b9b0529,0x316d2eac,0xf2d20047,0x00000000}},	// [f3e0] ăuga, nsez_, זען_,
  { {0x98b9000c,0x64410150,0xbd5b0063,0x00000000}},	//   _rusă_, _ngli, _רכיש,
  { {0x69cb0146,0x2d82017f,0xb5fd017f,0x00000000}},	//   øger, luke_, _reša,
  { {0x76a90086,0x98b9003b,0x5b7b0047,0x00000000}},	//   ктів_, _pusă_, _ארטא,
  { {0x2d821aec,0xb5fd0b59,0xbcfb0003,0x00000000}},	//   nuke_, _peša, rsév,
  { {0x291e00ea,0x7c3a0078,0x98b1003b,0x00000000}},	//   _óta_, žtru, _viză_,
  { {0xd377000d,0xef1f0058,0xaa7b004c,0x00000000}},	//   гчы_, ylü_, _mlýn,
  { {0x64411ca8,0x3ea26e3f,0x6b8101a8,0x00000000}},	//   _egli, jekt_, àlgi,
  { {0x3ea2006f,0x638a017d,0xf50a0121,0x00000000}},	//   dekt_, _bênç, _знал_,
  { {0x2d826e40,0x50f458c5,0xa0a649a0,0x00000000}},	//   duke_, рзот, ушил,
  { {0xba3b6e41,0xc9170063,0x66da006c,0x00000000}},	//   _haït, רחית_, _aïki,
  { {0x753d00ea,0x925a0044,0x3ec7005e,0x00000000}},	//   _észr, _أشار_, усоб,
  { {0xef1f005b,0x64410244,0xbed80054,0x00000000}},	//   rlü_, _ygli, удях_,
  { {0xd12f0021,0x3ead1aa5,0x3aff0072,0x00000000}},	//   _فمن_, žet_, käpä_,
  { {0x3ae7004b,0x25a6004d,0x2d822e5e,0x00000000}},	//   _lõpe_, hwol_, auke_,
  { {0x2d826e42,0x4a550541,0xaa55075f,0x00000000}},	//   buke_, ркас, рваш,
  { {0xe9750021,0xd1410022,0xadb904a0,0x00000000}},	// [f3f0] شهاد, ciąć_, _شهدا_,
  { {0x2907004b,0x270d0042,0x7afa0014,0x00000000}},	//   õna_, िक्र_, éttr,
  { {0xfcac0041,0x0a95046e,0x5d3a009a,0x00000000}},	//   _װיכּ, _каню, _שתתא,
  { {0x35b54107,0x8aa76e43,0xd6ab14d7,0x00000000}},	//   ибер, _срод, عدام_,
  { {0x298b02e4,0xe7300021,0xe3b80075,0x00000000}},	//   _ясно_, أصل_, _arı_,
  { {0xbcfb013d,0xa3c3004c,0x2ee20042,0x00000000}},	//   csét, _váží_, _पत्त,
  { {0xdce60023,0xa4d60131,0x398f0075,0x00000000}},	//   nskā, рдју_, lüs_,
  { {0x41b50021,0x2bf80063,0xc2451577,0x00000000}},	//   لمعر, טמון_, шник,
  { {0x3ea200d1,0x46f40121,0xa4870593,0x00000000}},	//   vekt_, _учёт, _مجان,
  { {0xe0d60076,0x3ea2006f,0x7fb5000d,0x00000000}},	//   ивы_, wekt_, аёмі,
  { {0x316d03b2,0xd0090676,0xef19001c,0x00000000}},	//   ssez_, тене_, guļo_,
  { {0x2d820019,0x61260026,0x799d00ac,0x00000000}},	//   tuke_, rðla, _opsw,
  { {0x3ea26e44,0xb5fd007d,0xa1580500,0x00000000}},	//   rekt_, _mešo, _бачу_,
  { {0x2d824095,0x3ea26e45,0xf9630047,0x00000000}},	//   ruke_, sekt_, עהיפּ,
  { {0x3ea26e46,0xfaf647b9,0x0af60085,0x00000000}},	//   pekt_, ачаю, ачаў,
  { {0x8a06075f,0x00000000,0x00000000,0x00000000}},	//   азбе,   ,   ,

  { {0x4432001b,0x4420008b,0x78662c47,0x00000000}},	// [f400] ̀y_, ́i_, иказ,
  { {0xbddb01a8,0xa7b6007b,0xa8560896,0x00000000}},	//   rcèt, исеј, ртај,
  { {0x62992082,0x07a66e47,0x68430085,0x00000000}},	//   _obwo, раен, інца,
  { {0x66fc00c2,0x25a6002b,0x398f0058,0x00000000}},	//   ečkr, twol_, büs_,
  { {0x7ceb00bd,0x7ae300dd,0x78af0050,0x00000000}},	//   _dürf, _înta, öivä,
  { {0x25a6002b,0x6aa46e48,0x03b60044,0x00000000}},	//   rwol_, leif, لإعد,
  { {0x27270019,0xbddb0164,0xe2f8071f,0x00000000}},	//   sõna_, ncèr, лекі_,
  { {0xbcfb0003,0xba3b006c,0xa3100042,0x00000000}},	//   nsér, _taït, ावेज_,
  { {0xe61a0054,0x9f4d004c,0xc05a0500,0x00000000}},	//   _рда_, ěným_, кін_,
  { {0x6b9e076c,0xba3b00ac,0x7bdc0078,0x00000000}},	//   _oppg, _kaïr, kyru,
  { {0xa2d6007e,0x67220058,0x3f150d3b,0x00000000}},	//   _پيشت, oloj, йдос,
  { {0x798400ac,0xdc2e0058,0x1dc20042,0x00000000}},	//   kuiw, _sığa, शमंत,
  { {0xfe6e007e,0x1154000d,0xf3f10013,0x00000000}},	//   ژگی_, _уклю, _hẹp_,
  { {0x22620051,0x7ceb004b,0x6f066e49,0x00000000}},	//   ńską_, _mürg, ankc,
  { {0x7f840032,0x67220006,0x212b0003,0x00000000}},	//   _العن, kloj, îche_,
  { {0x403b0063,0xbcfb10fd,0x539b0063,0x00000000}},	//   _בגוג, gsér, כילו,
  { {0x4b040088,0x8d950044,0xb9250044,0x00000000}},	// [f410] цярб, _الخش, مفري,
  { {0x261a0053,0xdced007d,0x63ba0137,0x00000000}},	//   _बड़ी_, _kvač, _ortn,
  { {0xba3b6e4a,0xf7730021,0xd1170063,0x00000000}},	//   _païs, تاذ_, סקבה_,
  { {0x7ceb00bd,0xbcfb013d,0x67226e4b,0x00000000}},	//   _bürg, csér, gloj,
  { {0x6ee6013d,0x63ba6e4c,0xb5a70121,0x00000000}},	//   _jóba, _artn, ррей,
  { {0x7ceb004d,0x84580062,0x64a56e4d,0x00000000}},	//   _würf, арът_, сака,
  { {0xbcfb0164,0xe3b3006a,0xe2991915,0x00000000}},	//   nséq, ترش_, гай_,
  { {0x7ceb004d,0x00000000,0x00000000,0x00000000}},	//   _hürd,   ,   ,
  { {0x7ceb0058,0xba3b006c,0x97420085,0x00000000}},	//   _kürd, _zaïr, цiць_,
  { {0x70c90001,0x25ad001f,0x15150085,0x00000000}},	//   угог_, _isel_, _удзя,
  { {0x8fa50062,0xd6a5012c,0x1ec60044,0x00000000}},	//   щане, рiчн, مقدّ,
  { {0x67170053,0xba3b0003,0x7ce20066,0x00000000}},	//   तविक_, _laïq, _pôro,
  { {0x6d4b03b2,0x225f0360,0xddd40066,0x00000000}},	//   _égal, mbuk_, ťažn,
  { {0xa069000a,0x62890019,0x6da30002,0x00000000}},	//   _сака_, lgeo, џира,
  { {0x60c30031,0x6aa400bd,0x60dc6e4e,0x00000000}},	//   _innm, teif, örme,
  { {0x4a460088,0x612f0831,0x0e6600e1,0x00000000}},	//   снав, følg, _укин,
  { {0xc332014e,0xab275b22,0x6aa46e4f,0x00000000}},	// [f420] לול_, сота_, reif,
  { {0xb4e60161,0x5e57007e,0xdb150024,0x00000000}},	//   _पते_, _پلیس_, ľbác,
  { {0x6b9e2b99,0x798400ac,0xe3b8005b,0x00000000}},	//   _uppg, suiw, _ayın_,
  { {0x612f000e,0x67220072,0x7ceb004b,0x00000000}},	//   bølg, uloj, _pürg,
  { {0x3f850397,0xa596005a,0x60c30025,0x00000000}},	//   hulu_, срещ, _onnm,
  { {0x3f856e50,0xdb070014,0x6722007d,0x00000000}},	//   kulu_, ðlög, sloj,
  { {0x25ad004d,0x533431b1,0xe3af0044,0x00000000}},	//   _esel_, оект, فري_,
  { {0xa3c90161,0x63ba085a,0x3f850114,0x00000000}},	//   _ऊपर_, _vrtn, dulu_,
  { {0x52730001,0x6d49003b,0x3f85002b,0x00000000}},	//   чују, ţeaz, eulu_,
  { {0xff980001,0x7ceb005b,0x6ee60139,0x00000000}},	//   акој_, _küre, _róba,
  { {0x64a30854,0x74160049,0x6289087d,0x00000000}},	//   _хаха, _اوضا, bgeo,
  { {0x216a0002,0x7ceb0058,0x291a00a5,0x00000000}},	//   _биди_, _müre, hopa_,
  { {0x317f196f,0xaa7b0014,0x291a6e51,0x00000000}},	//   cruz_, _flýj, kopa_,
  { {0xcc540062,0xa2d40053,0x6c540054,0x00000000}},	//   звръ, यॉर्, зкру,
  { {0xb0970063,0x23780063,0xdcfd0023,0x00000000}},	//   _הדוח_, יָּמ, gusā,
  { {0x7ceb005b,0x6ee60014,0x8f57009a,0x00000000}},	//   _sürd, _tóba, _פסחא_,
  { {0xeef8009d,0x00000000,0x00000000,0x00000000}},	// [f430] _למהר_,   ,   ,
  { {0x6e2d0117,0xfc470080,0x28c90053,0x00000000}},	//   _izab, číst_, राधि,
  { {0x7ae30529,0xead50086,0xf7700049,0x00000000}},	//   _înto, _донь, فان_,
  { {0x7ceb5804,0xdb1f00fe,0x6d5d001c,0x00000000}},	//   _würd, äväk, opsa,
  { {0xb5fd00eb,0x3f853900,0x7ceb005b,0x00000000}},	//   _iešk, zulu_, _türd,
  { {0x7aed000f,0xa5090001,0x7e6f0139,0x00000000}},	//   lhat, јека_, hacp,
  { {0x2ee90185,0x62890229,0xad1c0063,0x00000000}},	//   _olaf_, tgeo, אוגר,
  { {0x7aed5360,0x6e2d00c2,0x6289004d,0x00000000}},	//   nhat, _ozab, ugeo,
  { {0x225f66f8,0xe5c70571,0x62890136,0x00000000}},	//   rbuk_, _усво, rgeo,
  { {0x2ee90089,0x4102000d,0x98b90078,0x00000000}},	//   _alaf_, дзьв, _pusę_,
  { {0x6d5d09fe,0x225f00a4,0xdbc6004b,0x00000000}},	//   epsa, pbuk_, löög,
  { {0xf7720047,0x3f85005b,0xeef6000d,0x00000000}},	//   וקט_, rulu_, іянэ,
  { {0x7aed000f,0x7e55000d,0x3f8561bd,0x00000000}},	//   dhat, ятэц, sulu_,
  { {0x25a0005b,0x463a0047,0x612f05e7,0x00000000}},	//   çili_, יערע, føle,
  { {0x6d5d6e52,0x7fd50454,0x6e2d003b,0x00000000}},	//   apsa, _філі, _ezab,
  { {0x0d860076,0x7aed6e53,0x2ee9002b,0x00000000}},	//   _длин, ghat, _glaf_,
  { {0x7ceb01f7,0x291a01b3,0x394b01a8,0x00000000}},	// [f440] _süre, topa_, _cucs_,
  { {0xed590080,0xe8c7000d,0x394b0005,0x00000000}},	//   íže_, огул_, _ducs_,
  { {0xab2a019d,0x7d1c6e54,0x7aed00ea,0x00000000}},	//   _вона_, mors, bhat,
  { {0xe5c60076,0x7aed6e55,0x7d1c2033,0x00000000}},	//   жско, chat, lors,
  { {0x7d1c1038,0x7ae40006,0x27f6004c,0x00000000}},	//   oors, mkit, _ženě_,
  { {0xd37a098e,0x2d820093,0x7ceb6e56,0x00000000}},	//   ачи_, irke_, _türe,
  { {0x2480005b,0x7ae41dc1,0x0443005e,0x00000000}},	//   ğim_, okit, мељн,
  { {0x7ae46e57,0x248001f7,0x6843000d,0x00000000}},	//   nkit, şim_, _інта,
  { {0x60f8005a,0x2369017f,0x7ae40006,0x00000000}},	//   йния_, ćaja_, ikit,
  { {0x7aed000f,0x60f8000d,0x83fc007d,0x00000000}},	//   zhat, ёння_, _leđi,
  { {0x7ae400fe,0x6e2d1688,0x7d1c44f8,0x00000000}},	//   kkit, _szab, dors,
  { {0x79960045,0x399400fe,0x6286013d,0x00000000}},	//   ktyw, käs_, ókod,
  { {0x7d1c3960,0xb5fd007d,0x63a1004c,0x00000000}},	//   fors, _rešk, _zpln,
  { {0x6d5d0026,0x7ae46ae6,0xbcfb0003,0x00000000}},	//   rpsa, ekit, xpéd,
  { {0x7aed000f,0xddeb005d,0x1eea005d,0x00000000}},	//   that, _چرخه_, _گويی_,
  { {0xb606017f,0x7aed0019,0x20230024,0x00000000}},	//   _kršć, uhat, íriť_,
  { {0xb5fd0080,0x7aed5f6d,0x6f1d6e58,0x00000000}},	// [f450] _vešk, rhat, mosc,
  { {0x7d1c051e,0x7ae46906,0xa2a10053,0x00000000}},	//   cors, akit, _कॉन्,
  { {0xb5fd1ff8,0x7ceb0058,0x79960022,0x00000000}},	//   _tešk, _türb, atyw,
  { {0x6f1d6e59,0x394309fe,0x7ceb004d,0x00000000}},	//   nosc, _wijs_, _fürc,
  { {0x7cf000c7,0x63a1027d,0xb5fd007d,0x00000000}},	//   _därf, _spln, _keši,
  { {0x6d452933,0x6f1d0025,0xdfc60021,0x00000000}},	//   _jiha, hosc, _كي_,
  { {0xcc7c01f9,0xa2e50076,0x04426e5a,0x00000000}},	//   שְׂר, зойд, нешн,
  { {0x6d451a67,0x2d820205,0x29016e5b,0x00000000}},	//   _liha, yrke_, liha_,
  { {0x7d1c01f7,0xddc600c2,0x6f1d0e97,0x00000000}},	//   yors, kakš, dosc,
  { {0x1015000d,0x6d456e5c,0x60e9005e,0x00000000}},	//   зьмя, _niha, смом_,
  { {0x7ae400eb,0x80cd0161,0x7d1c6e5d,0x00000000}},	//   ykit, ताबे, vors,
  { {0x7e6d0025,0xd1380006,0x6f1d6e5e,0x00000000}},	//   _ceap, amą_, gosc,
  { {0x7cf00004,0x2229007e,0x6d456e5f,0x00000000}},	//   _järg, _ازای_, _biha,
  { {0x7cf00004,0x6351003d,0x7afd6e60,0x00000000}},	//   _märg, _jāno, _amst,
  { {0x6d450397,0xcc870076,0xb5fd0acf,0x00000000}},	//   _diha, ябре_, _deši,
  { {0x7d1c6e61,0x63be00d1,0x44252351,0x00000000}},	//   sors, åpni, _myl_,
  { {0x7ae46e62,0x7d1c6e63,0x929d0022,0x00000000}},	// [f460] rkit, pors, ciłe,
  { {0x7ae46e64,0x39940ef1,0x186a0854,0x00000000}},	//   skit, räs_, сажи_,
  { {0x2d8f00c7,0x69cb089f,0x7ae418a1,0x00000000}},	//   _äger_, äger, pkit,
  { {0xd94639ed,0xd1380c3b,0x7cf000a5,0x00000000}},	//   _неми, zmą_, _bärg,
  { {0xd13800eb,0xbb3b0047,0x6d450331,0x00000000}},	//   ymą_, _לעטי, _yiha,
  { {0x44250080,0xbcfb0003,0xddc4003b,0x00000000}},	//   _byl_, ppée, _zeiţ,
  { {0xdcb1008b,0x442558d6,0x929d0022,0x00000000}},	//   ổi_, _cyl_, ziłe,
  { {0x7cf0218d,0xbc0d0063,0x7ceb066b,0x00000000}},	//   _färg, יהוָ, _müra,
  { {0x6b9b003b,0x7cf0004b,0x7e6d095d,0x00000000}},	//   ăugi, _kärd, _reap,
  { {0x60f8019d,0x7e6d057a,0x5213000d,0x00000000}},	//   іння_, _seap, эдыт,
  { {0xb5fd082a,0xd1380c47,0x442a0139,0x00000000}},	//   _reši, rmą_, _áb_,
  { {0x6d450228,0x7cf00137,0xd1380078,0x00000000}},	//   _siha, _lärd, smą_,
  { {0x6d450397,0xd24f0032,0x3dc0001f,0x00000000}},	//   _piha, _إنه_, _criw_,
  { {0xd12f019d,0x7e6d0034,0xd23b0063,0x00000000}},	//   _їх_, _weap, _הגדל,
  { {0x78b506bb,0x309b0063,0x929d0022,0x00000000}},	//   _razv, _השומ, siłe,
  { {0x7c250240,0x2d9f0003,0x78b52341,0x00000000}},	//   _vyhr, çues_, _sazv,
  { {0xdb24000f,0xceb400b5,0x2901330d,0x00000000}},	// [f470] írás, _ניץ_, tiha_,
  { {0x63ad0045,0x3eab6e65,0x3eb90168,0x00000000}},	//   łani, lect_, ldst_,
  { {0x2d8b6e66,0x56950076,0x2d9900ea,0x00000000}},	//   luce_, дает, ltse_,
  { {0x3eb90146,0x7afd00bd,0xa6c90021,0x00000000}},	//   ndst_, _umst, توصل_,
  { {0x83fc0117,0x7cf000c7,0x3eab000c,0x00000000}},	//   _među, _färd, iect_,
  { {0x44250889,0x2d99152e,0x62870078,0x00000000}},	//   _pyl_, itse_, ėjom,
  { {0xe7840001,0xb5fd4e31,0xb6080260,0x00000000}},	//   _путо, _nešv, vyšš,
  { {0x3eab1400,0x2d99004b,0xdced0023,0x00000000}},	//   ject_, ktse_, _apaļ,
  { {0x91b00013,0x0595007e,0x2d99013d,0x00000000}},	//   _đãi_, _تازگ, jtse_,
  { {0xddc40006,0x2d8b095c,0x3eb901e1,0x00000000}},	//   _neiš, duce_, edst_,
  { {0x273501e3,0x7cf00004,0x3eab0625,0x00000000}},	//   gång_, _järe, fect_,
  { {0x141a0047,0xa2e40086,0x441a0047,0x00000000}},	//   _וועב, _поєд, _וועס,
  { {0x2d8b007d,0x6e290022,0x7ceb0075,0x00000000}},	//   guce_, żebn, _süra,
  { {0xc1720063,0x61e600d1,0xdb24004c,0x00000000}},	//   _יחד_, økle, ěsíc,
  { {0x2d9929bf,0xdfce00f2,0x9d4301f6,0x00000000}},	//   atse_, _نيو_, терд,
  { {0x2d8b0080,0xbebb00ac,0xee0a130d,0x00000000}},	//   buce_, toëe, _мейл_,
  { {0x394660e2,0x3b070cb2,0x28c90042,0x00000000}},	// [f480] днаг, фето_, रांि,
  { {0x49990076,0x7cf0051c,0xcc8a007e,0x00000000}},	//   ятся_, _bäre, _بنده_,
  { {0x7cf001e3,0xbcfb1560,0xca4a0044,0x00000000}},	//   _värd, spéc, _ولده_,
  { {0x7cf000c7,0xc6a302a9,0x562a03d1,0x00000000}},	//   _däre, врши, ожем_,
  { {0x7f3b0047,0x6593005d,0xee09009a,0x00000000}},	//   קענו, نجور, ּמוֹ_,
  { {0x2d54004b,0xcdf7009a,0xb446014b,0x00000000}},	//   _mäe_, ומני_, мэйк,
  { {0xb8f2016a,0x68e301f7,0x8696005e,0x00000000}},	//   वा_, önde, _ојач,
  { {0x27e702ab,0x07a3000d,0x41e60086,0x00000000}},	//   ønne_, _шасн, діоа,
  { {0x3f850397,0x2d54003a,0xd0860121,0x00000000}},	//   erlu_, _näe_, мыни,
  { {0x64360021,0x65620089,0x16040053,0x00000000}},	//   _قراء, mpoh, _शेयर_,
  { {0xddc40006,0x3eab0625,0xe29a000a,0x00000000}},	//   _reiš, tect_, _маж_,
  { {0x27350137,0x7cf00504,0xd57c0054,0x00000000}},	//   rång_, _närb, _вiдк,
  { {0x7bda00fe,0x7ae3000c,0x3eab2253,0x00000000}},	//   ätun, _înti, rect_,
  { {0x2d996e67,0x3eab3996,0x2d8b6e68,0x00000000}},	//   rtse_, sect_, ruce_,
  { {0x7cf000c7,0x01350047,0x5c0427b8,0x00000000}},	//   _bärb, _אָקט_, вята,
  { {0x4ea7005e,0xef19008f,0x9e350062,0x00000000}},	//   _црка, tuļu_, _пейч,
  { {0xb5fd0080,0x4429001b,0xadb4082d,0x00000000}},	// [f490] _ješt, ́a_, _абыш,
  { {0x39470137,0xb5fd274b,0x5a340da2,0x00000000}},	//   öns_, _mešt, тнут,
  { {0x3f8c017f,0x7cf0004d,0xb5fd017c,0x00000000}},	//   nudu_, _färb, _lešt,
  { {0x7cf000fe,0x645a0c5f,0xdc0301d1,0x00000000}},	//   _väre, _afti, nčím,
  { {0x7cf000bd,0xb5fd1b83,0x5a440085,0x00000000}},	//   _wäre, _nešt, _аэра,
  { {0x98c40076,0x798d05b3,0x6d4b0003,0x00000000}},	//   _иссл, muaw, _égau,
  { {0x273500c7,0xaa7b0026,0xb5fd00c2,0x00000000}},	//   tånd_, _flýt, _rešu,
  { {0x645a0ac6,0xdb050c38,0x5275005d,0x00000000}},	//   _efti, _erhö, رابز,
  { {0x317900ea,0x85050044,0xaa7b0046,0x00000000}},	//   ész_, _كورن, _hlýs,
  { {0xddc40529,0x7cf0004d,0xe0d10021,0x00000000}},	//   _afiş, _märc, ازة_,
  { {0x7cf0004d,0x5f064e4a,0x00000000,0x00000000}},	//   _lärc, езна,   ,
  { {0x32750047,0x7ceb6e69,0x6aad00a8,0x00000000}},	//   _װײַל_, _büro, jeaf,
  { {0x672b0031,0xe1ee0001,0xc33201f9,0x00000000}},	//   ilgj, _сг_, _עוד_,
  { {0x613400cd,0x3f8c004c,0x290f0003,0x00000000}},	//   tàle, budu_, égal_,
  { {0x3ae8006a,0x6351008f,0x3cf10042,0x00000000}},	//   وبری_, _sānj, ीफ़े_,
  { {0x27180d77,0x80cd0042,0x70bc0082,0x00000000}},	//   očne_, तावे, ्फ़ील,
  { {0x271800c3,0xbcfb0025,0x7cf0004b,0x00000000}},	// [f4a0] nčne_, spéa, _värb,
  { {0xee370088,0x3c660454,0xeb9a0062,0x00000000}},	//   _яны_, _яког, _еио_,
  { {0xb895005a,0x3ce500ea,0xdc18008f,0x00000000}},	//   ъртъ, ölve_, _jāļa,
  { {0x6aad6e6a,0x2f5a0041,0x6b7b009a,0x00000000}},	//   ceaf, לדענ, _צרכנ,
  { {0x86230071,0x09e30062,0xb602004c,0x00000000}},	//   льше, _боян, _čásk,
  { {0xb5fd0024,0xb4ea0042,0xd91a005d,0x00000000}},	//   _rešt, मसे_, _ريزش_,
  { {0xa3d4042c,0xb5fd00c2,0x65620072,0x00000000}},	//   тойч, _sešt, spoh,
  { {0x784e00ea,0xfbd30063,0x5c370041,0x00000000}},	//   bőví, רתה_, ערקן_,
  { {0x92570044,0x6f0601ff,0x690b056c,0x00000000}},	//   رشير_, dikc, użeg,
  { {0x55770047,0xb5fd0ecf,0x60f70121,0x00000000}},	//   _נעבן_, _vešt, енья_,
  { {0x612f000e,0x27186e6b,0x394a1c63,0x00000000}},	//   møll, ačne_, _mibs_,
  { {0x3f823667,0x7ceb004b,0xe29a01ce,0x00000000}},	//   čku_, _püro, _хад_,
  { {0xc0e60432,0x0dcb0001,0x3f8c007c,0x00000000}},	//   _подк, чуни_, sudu_,
  { {0x63a80089,0x81b70063,0x41170044,0x00000000}},	//   _kpdn, _נהוג_, _كينج_,
  { {0x672b0026,0xdcef003b,0x6e20004b,0x00000000}},	//   ylgj, escă, ümbr,
  { {0x9f970063,0x7f830021,0x5ae70044,0x00000000}},	//   _נדחה_, _إلين, رثأف,
  { {0xfeb8006a,0x6aad0034,0xdcf60024,0x00000000}},	// [f4b0] _سايت_, reaf, _zvyč,
  { {0xec6b0121,0x6aad0058,0x8a440044,0x00000000}},	//   _эрик_, seaf, ائِم,
  { {0x7d0701b3,0x6c5600ff,0xb0650bda,0x00000000}},	//   mijs, _ביתא_, lhää,
  { {0xb6020080,0x7d076e6c,0xdb050003,0x00000000}},	//   _čárk, lijs, _ophé,
  { {0x7cf00137,0xe44e0062,0xe7300021,0x00000000}},	//   _hära, иж_, حصل_,
  { {0x2a6900f3,0xf4840138,0xdb050003,0x00000000}},	//   lbab_, гућн, _sphè,
  { {0x9474007e,0x23b20021,0xd7f80062,0x00000000}},	//   ادها, لموس, _зут_,
  { {0x6351008f,0x7d07159a,0x7cf0004e,0x00000000}},	//   _jāni, hijs, _mära,
  { {0x7cf00137,0x7ae3003b,0x6b9c00a8,0x00000000}},	//   _lära, _întu, ztrg,
  { {0x27184dcb,0x42060054,0xa2a10053,0x00000000}},	//   rčne_, тньо_, _कॉर्,
  { {0x12e7019d,0x7d0701b3,0x27270019,0x00000000}},	//   _підг, dijs, sõnu_,
  { {0x2cba00ac,0xd3562177,0x929d0022,0x00000000}},	//   _sapd_, _סיני_, miło,
  { {0x7ceb005b,0xdce4007d,0x6f063d08,0x00000000}},	//   _türl, _sviđ, rikc,
  { {0x7d07082a,0x2a69014f,0x7cf00137,0x00000000}},	//   gijs, ebab_, _bära,
  { {0xfc0309b3,0xab2a6e6d,0x394a17e4,0x00000000}},	//   апро, дова_, _ribs_,
  { {0xbea6000a,0x7cf00137,0x613400cd,0x00000000}},	//   _раик, _dära, màla,
  { {0xee3a005a,0x6351008f,0x7d07394e,0x00000000}},	// [f4c0] _юни_, _dāni, bijs,
  { {0xb95b001b,0x7d0701a6,0x28d20053,0x00000000}},	//   _trìn, cijs, साधि,
  { {0xdce4007d,0x9cd70149,0x6f040022,0x00000000}},	//   _uviđ, _סוטה_, _kmic,
  { {0x6d4b0164,0xf62a0054,0x160a0044,0x00000000}},	//   _égar, міли_, وياً_,
  { {0x6b8300c7,0x2c060053,0x9596005e,0x00000000}},	//   _ångr, _हेतू_, трељ,
  { {0x26cd0009,0x752301f4,0x6722004b,0x00000000}},	//   _eneo_, gonz, sooj,
  { {0x6f040290,0xdb050003,0x3cfa0053,0x00000000}},	//   _omic, _sphé, _उतने_,
  { {0xdb0f00ea,0x7d073730,0x78bc6e6e,0x00000000}},	//   ődöt, zijs, _harv,
  { {0xe5720021,0x7ceb005b,0x2b4013cb,0x00000000}},	//   _خطأ_, _sürm, imic_,
  { {0x6f046e6f,0x30a30086,0x2b4000e5,0x00000000}},	//   _amic, арюв, hmic_,
  { {0x6ee60e7c,0x213e00e5,0x78bc6e70,0x00000000}},	//   _lóbu, rmth_, _marv,
  { {0x69c66e71,0x7d0704a1,0x78bc6e72,0x00000000}},	//   _orke, wijs, _larv,
  { {0x442c0185,0xf0b7006a,0x7d071253,0x00000000}},	//   _hyd_, رایش_, tijs,
  { {0x7cf00004,0x78bc6e73,0x7ceb004d,0x00000000}},	//   _pära, _narv, _türm,
  { {0x2b4b0089,0x7d076e74,0x69c61d13,0x00000000}},	//   _picc_, rijs, _arke,
  { {0x7bc5027c,0x442c001f,0x7cf0004b,0x00000000}},	//   _vrhu, _myd_, _vära,
  { {0x442c02ab,0x78bc08c4,0x7d090003,0x00000000}},	// [f4d0] _lyd_, _barv, éess,
  { {0x7cf00137,0x78bc30a8,0x690b0022,0x00000000}},	//   _härn, _carv, dżec,
  { {0x7cf06e75,0x612f01f2,0xec33007e,0x00000000}},	//   _kärn, følj, _خودگ,
  { {0x7cf000c7,0xd639000d,0x98b9001c,0x00000000}},	//   _järn, нялі_, _pusē_,
  { {0x78bc0146,0x7bd8003b,0x7aed6e76,0x00000000}},	//   _farv, ăbuş, mkat,
  { {0x442c0185,0x78bc6e77,0x2d8b0139,0x00000000}},	//   _byd_, _garv, irce_,
  { {0x442c001f,0x752313f4,0x67d40f2e,0x00000000}},	//   _cyd_, ronz, _кору,
  { {0x2489005b,0x5c380063,0x7aed6e78,0x00000000}},	//   şam_, כרון_, nkat,
  { {0xe0d1007e,0x3f9e0014,0x75236e79,0x00000000}},	//   مزد_, ettu_, ponz,
  { {0x442c001f,0x2ee00003,0xddcf003b,0x00000000}},	//   _fyd_, _soif_, zacţ,
  { {0x6e360045,0x442c0185,0x76490078,0x00000000}},	//   _szyb, _gyd_, ūlyč,
  { {0x52150086,0x6305005d,0x05c70082,0x00000000}},	//   _йдет, _حوصل, लिपब,
  { {0x271800c3,0x69cb00a5,0x2fd6005d,0x00000000}},	//   nčna_, ågel, نوید_,
  { {0x7aed164f,0x61e940c9,0x417a009a,0x00000000}},	//   ekat, myel, _טננב,
  { {0x0136014e,0xc0580086,0x3ae7004b,0x00000000}},	//   _גרסת_, _річ_, _lõpu_,
  { {0x7cf000c7,0x7aed18a5,0x3f8a017d,0x00000000}},	//   _gärn, gkat, ábue_,
  { {0x4a750088,0x61e908f0,0xddcf000c,0x00000000}},	// [f4e0] рыст, nyel, racţ,
  { {0x67290024,0x4a430f30,0xb5fd0024,0x00000000}},	//   _akej, снув, _rešp,
  { {0x60dc0bfc,0x7aed6e7a,0x7af6186d,0x00000000}},	//   örmi, bkat, phyt,
  { {0x673b0009,0x7aed00c7,0x6d560009,0x00000000}},	//   _chuj, ckat, _kuya,
  { {0x78bc0d68,0x628600ea,0x442c02c0,0x00000000}},	//   _tarv, ókom, _syd_,
  { {0x7ae30529,0x3f9e007a,0x7c29004d,0x00000000}},	//   _într, yttu_, ßerg,
  { {0x74690086,0x7cf00137,0x69c46e7b,0x00000000}},	//   трів_, _läro, lvie,
  { {0x6aa400ac,0x61fb004d,0x442c004c,0x00000000}},	//   nfif, fzul, _vyd_,
  { {0xdce40045,0x61e900ea,0x69c46e7c,0x00000000}},	//   _zwią, gyel, nvie,
  { {0x442c021f,0x43760076,0x69c46e7d,0x00000000}},	//   _tyd_, _будт, ivie,
  { {0x3f15000a,0x7cf06e7e,0x33660001,0x00000000}},	//   идос, _pärn, _свег,
  { {0x69c400eb,0x63ba0045,0x7ceb46e8,0x00000000}},	//   kvie, _istn, _türk,
  { {0x6d5604d0,0x91e60086,0x62870006,0x00000000}},	//   _cuya, _щоде, ėjot,
  { {0x6d56005b,0x69c46e7f,0x7cf00137,0x00000000}},	//   _duya, dvie, _däro,
  { {0x69c4001c,0x6abd0025,0xa9260078,0x00000000}},	//   evie, _pasf, _mažą,
  { {0x7cf000c7,0x6d560003,0xddcd003b,0x00000000}},	//   _härl, _fuya, _ceaţ,
  { {0x7aed0228,0x1995005a,0x7cf000c7,0x00000000}},	// [f4f0] rkat, разя, _kärl,
  { {0x7aed6e80,0x271800c2,0xb0cd0042,0x00000000}},	//   skat, včna_, ़ाएग,
  { {0x7c2900bd,0x7aed02f7,0x6abd0058,0x00000000}},	//   ßerd, pkat, _tasf,
  { {0x1995000d,0xb8ec0053,0x7c290058,0x00000000}},	//   _камя, _शो_, ğerd,
  { {0x69c4001b,0x2d800003,0x69cb00b9,0x00000000}},	//   cvie, _xvie_, æged,
  { {0x7cf00137,0x271800c2,0x61fb00a8,0x00000000}},	//   _närl, rčna_, vzul,
  { {0x3ea900f3,0x82f5005e,0x200a0066,0x00000000}},	//   _obat_, ичиц, úbil_,
  { {0xf3c8007e,0xa2e5406e,0x41a9030b,0x00000000}},	//   ابوه_, роид, ввин_,
  { {0xa2a10053,0x63ba6e81,0x20d5000d,0x00000000}},	//   क्ष्, _estn, аінс,
  { {0x3ea90803,0x60e60121,0x61fb6e82,0x00000000}},	//   _abat_, имым_, rzul,
  { {0x3dc90273,0x6d56258b,0x798d2268,0x00000000}},	//   _araw_, _suya, hraw,
  { {0x798d0dde,0xfe460376,0x69c40341,0x00000000}},	//   kraw, инно, yvie,
  { {0x2369017f,0xde36000d,0xddcd003b,0x00000000}},	//   ćaju_, рэнь, _reaţ,
  { {0x3dc904bf,0x69c40a02,0x317f005b,0x00000000}},	//   _draw_, vvie, msuz_,
  { {0x4a9a000d,0x798d0360,0x273c4945,0x00000000}},	//   ктаў_, eraw, líne_,
  { {0xf1a90053,0x6d5658e0,0x69c46e83,0x00000000}},	//   _कहान, _tuya, tvie,
  { {0x09060088,0x317f005b,0x7cf02430,0x00000000}},	// [f500] апан, nsuz_, _härm,
  { {0x69c46e84,0x7d7b009a,0x69c00078,0x00000000}},	//   rvie, _שניו, _šmes,
  { {0x798d2a43,0x628600ea,0x69c46e85,0x00000000}},	//   araw, ókok, svie,
  { {0x7c2900bd,0x69c4008f,0x798d6e86,0x00000000}},	//   ßere, pvie, braw,
  { {0x287608a6,0x798d6e87,0xd627005e,0x00000000}},	//   _выбр, craw, аоце_,
  { {0xed5901d9,0x7c290058,0x96330085,0x00000000}},	//   íži_, şere, цніц,
  { {0x7cf000c7,0xd377000d,0x2ca7005b,0x00000000}},	//   _närm, ачы_, _önde_,
  { {0xf1a60088,0x38780832,0x77bb0063,0x00000000}},	//   арон, _herr_, _במלח,
  { {0xb5a90021,0x271800c2,0x7cf00db3,0x00000000}},	//   _مالك_, lčno_, _pärl,
  { {0x4fc620cc,0x271802f7,0x859b009a,0x00000000}},	//   асма, očno_, _בשמו,
  { {0x27180198,0x7cf001e3,0x08570063,0x00000000}},	//   nčno_, _värl, יבים_,
  { {0x7cf000c7,0x3dc90051,0xd36f007e,0x00000000}},	//   _därm, _praw_, _آهن_,
  { {0xae010235,0x8f10005e,0xe1f76e88,0x00000000}},	//   _लेखन_, нaтa_, _кгц_,
  { {0x3e75008b,0x6143005e,0x7cf00db3,0x00000000}},	//   ất_, _деча, _härj,
  { {0xead50121,0x7cf001cf,0xdb5804ef,0x00000000}},	//   бовь, _kärj, иют_,
  { {0x3ea900e3,0x8e850032,0x7cf00d68,0x00000000}},	//   _ubat_, _الظه, _järj,
  { {0x4c95005a,0x7cf0004b,0x7e7d6e89,0x00000000}},	// [f510] _липс, _märj, masp,
  { {0x5cb9000d,0xd8790242,0x7cf00137,0x00000000}},	//   _слоў_, امات_, _lärj,
  { {0x25ad569a,0x273c28be,0x9735005d,0x00000000}},	//   _spel_, zíne_, مکرا,
  { {0x798d0045,0x8aa70092,0x00000000,0x00000000}},	//   praw, _трод,   ,
  { {0x929d0051,0xe56e000d,0xc9840a29,0x00000000}},	//   siłk, яз_, _мури,
  { {0x3f8300ea,0xdb070014,0x78806e8a,0x00000000}},	//   ájuk_, ðlæg, ráví,
  { {0x1368005e,0xf8b20063,0x7e7d6e8b,0x00000000}},	//   ашњи_, _משם_, kasp,
  { {0x4c3c0063,0x32b90021,0x2d84004c,0x00000000}},	//   כתוב, ادثة_, ámek_,
  { {0x224b0137,0x7e7d004b,0xc692009f,0x00000000}},	//   äck_, dasp, _מאן_,
  { {0x39590199,0x9f4e0080,0x273c0066,0x00000000}},	//   _muss_, ěním_, ríne_,
  { {0x7cf00137,0x63f40021,0x64b30042,0x00000000}},	//   _färj, _وأمر, ंजीश,
  { {0x1efa0032,0x613d0164,0x7cf000c7,0x00000000}},	//   اعدة_, dèle, _värm,
  { {0x01650138,0xdce40045,0xa256014e,0x00000000}},	//   _укло, _zwię, _הבנק_,
  { {0x463a0047,0x9d460121,0xed570098,0x00000000}},	//   טערע, сегд, сор_,
  { {0x7f850032,0x6f950021,0x7e7d00a5,0x00000000}},	//   _البن, _العض, basp,
  { {0x7cf00072,0x39596e8c,0x271800a8,0x00000000}},	//   _kärk, _buss_, včno_,
  { {0x7cf00659,0x44320013,0x9f462d7a,0x00000000}},	// [f520] _järk, ́y_, szló_,
  { {0x23b7016a,0xa8560001,0x98560001,0x00000000}},	//   _आनंद, стај, сташ,
  { {0x2d826e8d,0x38780014,0x00000000,0x00000000}},	//   lske_, _verr_,   ,
  { {0xf729019d,0x271800c2,0xf7431968,0x00000000}},	//   ацій_, rčno_, пехо,
  { {0x2d826e8e,0x7cf001e9,0xa2b80042,0x00000000}},	//   nske_, _närk, ्यस्,
  { {0x26c06e8f,0x2d826e90,0xb8f60021,0x00000000}},	//   žio_, iske_, _اكسب,
  { {0x7ae66e91,0x7cf0165b,0x9764012c,0x00000000}},	//   _kokt, _pärj, цiєю_,
  { {0x2d8227e8,0xfbd30063,0x00000000,0x00000000}},	//   kske_, לתו_,   ,
  { {0x2d82065f,0x60f8042c,0xe452007e,0x00000000}},	//   jske_, иния_, _فضا_,
  { {0x7e7d00f3,0x3ae70019,0x2d82027c,0x00000000}},	//   wasp, _lõpp_, dske_,
  { {0xe4d7006a,0xdeb5014c,0xd8db0047,0x00000000}},	//   _دولت_, обны, אקיר,
  { {0x7ae6005b,0x690b0051,0xf8370063,0x00000000}},	//   _nokt, eżel, מנית_,
  { {0x2d8200b9,0x290a0035,0x7e7d6e92,0x00000000}},	//   gske_, _omba_, rasp,
  { {0x2a790089,0xc19b0063,0x7e7d6e93,0x00000000}},	//   _sesb_, _עשוי, sasp,
  { {0x7ae608a9,0x7e7d241c,0x2d826e94,0x00000000}},	//   _bokt, pasp, aske_,
  { {0x2d826e95,0x7bc76e96,0x2f970063,0x00000000}},	//   bske_, rvju, _הכהן_,
  { {0x7ae61d9c,0x49bb007e,0x2d82013d,0x00000000}},	// [f530] _dokt, دازد_, cske_,
  { {0x7cf000c7,0xfe7f0003,0x4ddc0063,0x00000000}},	//   _närh, laï_, _תחזו,
  { {0xf7b90141,0xddc60022,0x7ceb0058,0x00000000}},	//   ргеј_, zakż, _dürt,
  { {0x6f0f01f4,0xfe7f1a05,0x963525ef,0x00000000}},	//   nicc, naï_, онец,
  { {0x85a70001,0x1a9a0047,0x23a10051,0x00000000}},	//   сјед, _דירע, wój_,
  { {0x7ceb004d,0x9a290013,0x690b0022,0x00000000}},	//   _gürt, _gươm_, ożem,
  { {0x7ae6005b,0xdcfd001c,0xf794000d,0x00000000}},	//   _yokt, lusē, _нарэ,
  { {0x65950086,0xddc4001c,0x2d82000e,0x00000000}},	//   _мабу, _reiž, yske_,
  { {0x44290045,0x6f0f234b,0xc175005d,0x00000000}},	//   ła_, dicc, زگشت,
  { {0x2d8201b3,0x273c0066,0x7507005e,0x00000000}},	//   vske_, mína_, _уџбе,
  { {0xef1a0e81,0x273c6e97,0x00000000,0x00000000}},	//   имо_, lína_,   ,
  { {0x7cf0024a,0x2d826e98,0xdcfd001c,0x00000000}},	//   _tärk, tske_, kusē,
  { {0x2d846e99,0x2385001c,0x7cf00137,0x00000000}},	//   éme_, lēj_, _häri,
  { {0xc0cb0001,0xdbc70026,0x2d823435,0x00000000}},	//   _људе_, töðv, rske_,
  { {0xf0b8006a,0x60c30072,0x7d0e6e9a,0x00000000}},	//   _دانش_, _ianm, ribs,
  { {0xed5a15d3,0x2d8207b4,0x60080063,0x00000000}},	//   _кои_, pske_, _לִפְ,
  { {0xdb050146,0x7ae600d1,0x6ab60014,0x00000000}},	// [f540] _ophæ, _vokt, reyf,
  { {0xfc320044,0xcb0a0043,0xf93616f2,0x00000000}},	//   _يحد_, _چيدن_, іхаю,
  { {0x7cf010b9,0x25bf6e9b,0x68e722b6,0x00000000}},	//   _näri, _asul_, _dojd,
  { {0x27e701e3,0x7ceb4f4f,0x7c96007e,0x00000000}},	//   änna_, _fürs, _اشکا,
  { {0xe737000d,0xf5b60242,0x273c00be,0x00000000}},	//   цец_, تصاد, gína_,
  { {0x75d30021,0x628f0051,0x7ceb0058,0x00000000}},	//   بيها, ócon, _hürr,
  { {0xbcfb0164,0xdb1c01e1,0x4394014b,0x00000000}},	//   mpét, rvræ, чайс,
  { {0x60c30a53,0x7cf000c7,0x1af70047,0x00000000}},	//   _aanm, _däri, ַמיל_,
  { {0x2cb8006f,0x7984001f,0x26c401f4,0x00000000}},	//   kerd_, nsiw, _iamo_,
  { {0x60c3001f,0xfe7f00a1,0x7984002b,0x00000000}},	//   _canm, waï_, isiw,
  { {0xb4b60161,0x2cb80250,0x3cde0053,0x00000000}},	//   ज़ी_, derd_, खाने_,
  { {0x26c60035,0x2cb8006f,0x74130049,0x00000000}},	//   ndoo_, eerd_, _توما,
  { {0x2cb81841,0x6f0f39b8,0xdced007d,0x00000000}},	//   ferd_, ricc, _svađ,
  { {0x2cb82e30,0x6f0f0b27,0x60c3002b,0x00000000}},	//   gerd_, sicc, _ganm,
  { {0x6f0f17c2,0x26110042,0x798400a3,0x00000000}},	//   picc, _देनी_, esiw,
  { {0x62806892,0x26c40078,0x2f180121,0x00000000}},	//   namo, _namo_, _мощь_,
  { {0x68e700c3,0x3eb937d4,0x7ceb004d,0x00000000}},	// [f550] _pojd, mest_, _dürr,
  { {0x2d990004,0x8b080080,0xa2cc0053,0x00000000}},	//   muse_, _pořá, _दोस्,
  { {0x65690199,0x2d990004,0x798400a4,0x00000000}},	//   _steh, luse_, asiw,
  { {0x2d990034,0x95d90076,0x62806e9c,0x00000000}},	//   ouse_, йдет_, jamo,
  { {0x2d990004,0x443e000f,0xb06500fe,0x00000000}},	//   nuse_, _azt_, nkää,
  { {0x7cf00004,0x3eb9010e,0xe4c203d1,0x00000000}},	//   _päri, hest_, ейши,
  { {0x59c90053,0x613400cd,0xad1c0063,0x00000000}},	//   रिवर, càli, בוגר,
  { {0x66b40076,0x7cf000fe,0x3eb96e9d,0x00000000}},	//   _обсу, _väri, jest_,
  { {0x443e000f,0x3eb9010e,0x25bf6e9e,0x00000000}},	//   _ezt_, dest_, _usul_,
  { {0x2d995e69,0x6f0d6e9f,0xf5aa0080,0x00000000}},	//   duse_, _amac, ížeč_,
  { {0x2cb80122,0x62800942,0x60c3017f,0x00000000}},	//   verd_, bamo, _vanm,
  { {0xdce400c3,0x2d9904bc,0x69cf23b6,0x00000000}},	//   _vtič, fuse_, _orce,
  { {0x2d990004,0x60c30268,0x2cb80122,0x00000000}},	//   guse_, _tanm, terd_,
  { {0x3ea00089,0xb6060114,0x60c301e1,0x00000000}},	//   _wcit_, _ukáž, _uanm,
  { {0xdce4017f,0xa021004b,0x69cf5b36,0x00000000}},	//   _utič, ööde, _arce,
  { {0x7cf01511,0x61340268,0x3eb909ee,0x00000000}},	//   _närv, vàli, cest_,
  { {0xc3320063,0x2cb800ac,0x26c40ac0,0x00000000}},	// [f560] תון_, perd_, _ramo_,
  { {0x49990055,0x79840185,0x26c41bc3,0x00000000}},	//   ются_, rsiw, _samo_,
  { {0x628b065f,0x62806ea0,0x69cf6ea1,0x00000000}},	//   _odgo, yamo, _erce,
  { {0xe73a0055,0xe5c60076,0x613400cd,0x00000000}},	//   щее_, зско, ràli,
  { {0x27180198,0xbcfb0ec6,0x62801088,0x00000000}},	//   nčni_, mpér, vamo,
  { {0x7ae46ea2,0x3f8500cc,0x2718007d,0x00000000}},	//   ljit, kslu_, ični_,
  { {0x26c4017f,0x660200ea,0x62806ea3,0x00000000}},	//   _tamo_, szok, tamo,
  { {0x7af600eb,0x7ae4017f,0xc2980121,0x00000000}},	//   nkyt, njit, цких_,
  { {0xc0ca005e,0x7af60078,0x6280124c,0x00000000}},	//   буне_, ikyt, ramo,
  { {0x2d990004,0x62806ea4,0x3eb90b02,0x00000000}},	//   vuse_, samo, west_,
  { {0x6f1d02dd,0x645a0146,0xdb1e18b3,0x00000000}},	//   érco, _igti, _espé,
  { {0x2d991fc9,0xb06500fe,0x7f443b2f,0x00000000}},	//   tuse_, tkää, _chiq,
  { {0x3eb96ea5,0x7ae4007d,0xe2970131,0x00000000}},	//   rest_, djit, _хач_,
  { {0x3eb91fc9,0x613d00cd,0x91bb0063,0x00000000}},	//   sest_, pèla, _למדי,
  { {0x6e2403d9,0x8fa30138,0x2d990004,0x00000000}},	//   _exib, _заје, suse_,
  { {0x2d995233,0x80370063,0x6f0d0022,0x00000000}},	//   puse_, _מנוע_, _umac,
  { {0xb955005a,0xa2a10042,0x2b496ea6,0x00000000}},	// [f570] дващ, क्ट्, rmac_,
  { {0xa3cf016a,0x98b80078,0xdb05004d,0x00000000}},	//   शिम_, _mirė_, _sphä,
  { {0x6f1d48c0,0xd138005f,0xaa590044,0x00000000}},	//   onsc, ilą_, _ولدا_,
  { {0x6f1d00bd,0x69cb0137,0x7cf00137,0x00000000}},	//   nnsc, åges, _däru,
  { {0xd1380006,0x6f1d050c,0x7cf0461c,0x00000000}},	//   klą_, insc, _värv,
  { {0xe5700021,0x6f1d004d,0x3f856ea7,0x00000000}},	//   اطن_, hnsc, yslu_,
  { {0x69cd00b9,0x6aad0035,0x68e337ce,0x00000000}},	//   lvae, ofaf, öndu,
  { {0xe2990062,0x7cf0051c,0x6f1d00ca,0x00000000}},	//   цаи_, _härt, jnsc,
  { {0x659420cc,0xb1450363,0x69cd0050,0x00000000}},	//   _пату, мнил, nvae,
  { {0x271800c2,0x6f1d6ea8,0x26c2013d,0x00000000}},	//   včni_, ensc, _ókor_,
  { {0x7cf00004,0x26110053,0x7c29004d,0x00000000}},	//   _märt, _देती_, ßerl,
  { {0x3f85007a,0x7c2901f7,0xbcfb0003,0x00000000}},	//   rslu_, ğerl, xpér,
  { {0xbd360062,0x69cb01e1,0xfaf80023,0x00000000}},	//   дхвъ, ægel, _ēī_,
  { {0x3e7c001b,0x271800c2,0x6f1d6ea9,0x00000000}},	//   ật_, rčni_, ansc,
  { {0xe3a70044,0x6aad6eaa,0xfaa60085,0x00000000}},	//   خر_, ffaf, маво,
  { {0x765b001b,0xff260086,0x291300cd,0x00000000}},	//   _nguy, _імпо, eixa_,
  { {0x7af60b4f,0xe8ea0054,0x6d576eab,0x00000000}},	// [f580] rkyt, омад_, _fixa,
  { {0xbcfb0164,0x7af619e4,0x4a4309c2,0x00000000}},	//   spér, skyt, тнув,
  { {0xf989014e,0x7cf00137,0x8f7a0047,0x00000000}},	//   שר_, _därt, ַנסק,
  { {0x29130858,0xf8a90063,0x273c017c,0x00000000}},	//   aixa_, יש_, ríno_,
  { {0xe4e60086,0x64410089,0x4ead0047,0x00000000}},	//   дійн, _azli, מבאַ,
  { {0x7cf0004d,0x7996002b,0x236a005e,0x00000000}},	//   _gärt, mryw, ојио_,
  { {0x7cf000c7,0xec360047,0x98a30095,0x00000000}},	//   _härs, ואַר_, _шире,
  { {0x7cf052ea,0x5afb0047,0x8afb0041,0x00000000}},	//   _kärs, ַליצ, ַליז,
  { {0x7cf0004b,0x7996002b,0x6ea50053,0x00000000}},	//   _järs, nryw, _काबु,
  { {0x799600a3,0x60c80046,0x13b600de,0x00000000}},	//   iryw, uddm, _يصاح,
  { {0x656000a4,0x2497007e,0xd01000f2,0x00000000}},	//   _humh, _زنند_, الج_,
  { {0x6b9c007a,0x799665c6,0x6f1d2087,0x00000000}},	//   durg, kryw, unsc,
  { {0x6b9c00ac,0x6f1d087d,0x7cf00137,0x00000000}},	//   eurg, rnsc, _närs,
  { {0xa2b80161,0x718b0063,0x799608b3,0x00000000}},	//   ्यक्, _וְהַ, dryw,
  { {0x44250d52,0x961d008f,0x63670058,0x00000000}},	//   _xxl_, _ieņe, _kına,
  { {0xa3cf0161,0xc27b00b5,0xaf080021,0x00000000}},	//   शित_, ַרבי, _يقوم_,
  { {0x6aad00ac,0x79960051,0xdb0700ea,0x00000000}},	// [f590] rfaf, gryw, ntjé,
  { {0x7b670245,0x3eb20051,0xf1c80013,0x00000000}},	//   _отме, _zbyt_, _mỡ_,
  { {0xf1c80013,0x6b9c6eac,0x3ce50014,0x00000000}},	//   _lỡ_, curg, ölvu_,
  { {0x7cf06ead,0x7afd6eae,0x690b056c,0x00000000}},	//   _färs, _ulst, yżew,
  { {0xe5780088,0x6560404d,0xd469007b,0x00000000}},	//   дзі_, _cumh, пиле_,
  { {0xa3c30080,0x7cf003b0,0x04450062,0x00000000}},	//   _září_, _härr, нелн,
  { {0xe3b103eb,0x29110058,0x7cf01fdb,0x00000000}},	//   ارت_, _imza_, _kärr,
  { {0x7cf00137,0x64410066,0xe7840141,0x00000000}},	//   _järr, _vzli, _јуро,
  { {0x9f5202f4,0xf1c8008b,0xa6340054,0x00000000}},	//   ází_, _cỡ_, _анті,
  { {0xf1c80013,0x3fe51501,0x6009173e,0x00000000}},	//   _dỡ_, ежов, зном_,
  { {0xd6d90051,0x79960051,0xb4bd0053,0x00000000}},	//   _siły_, zryw, ेयी_,
  { {0x7b030019,0x2018021a,0x59df0042,0x00000000}},	//   _jõud, úria_, नमार,
  { {0xf1c8008b,0x20050051,0x76fa0047,0x00000000}},	//   _gỡ_, szli_, פּטצ,
  { {0x6b9c6eaf,0x00000000,0x00000000,0x00000000}},	//   turg,   ,   ,
  { {0x7cf000c7,0x1c390086,0xf0920063,0x00000000}},	//   _särs, дять_, _ענה_,
  { {0x7b030004,0x6b9c6eb0,0x7cf001cd,0x00000000}},	//   _nõud, rurg, _pärs,
  { {0x2b596eb1,0x69cb0137,0x3946000d,0x00000000}},	// [f5a0] _disc_, ågep, енаг,
  { {0x7cf010c8,0xe4f40053,0x6b9c6eb2,0x00000000}},	//   _värs, _अवधि_, purg,
  { {0x7cf000c7,0x395813ed,0x6d4e004d,0x00000000}},	//   _färr, _virs_, mmba,
  { {0x7b03004e,0x46ea0094,0xab2a212b,0x00000000}},	//   _rõug, яден_, _хома_,
  { {0x39586eb3,0x6d4e6eb4,0xfa36005d,0x00000000}},	//   _tirs_, omba, _سرحد,
  { {0x6367005b,0x98a40078,0xf1c80013,0x00000000}},	//   _sına, _ėmė_, _rỡ_,
  { {0xccf30063,0x6d4e3986,0x03a3005e,0x00000000}},	//   רכו_, imba, гијо,
  { {0xdbcf0026,0xc7d70063,0x6d4e004d,0x00000000}},	//   nþág, _אולי_, hmba,
  { {0xc0ca005e,0xc1b70183,0xa1a7014b,0x00000000}},	//   пуне_, елых_, нтэз_,
  { {0xf1c8008b,0x7b03004b,0xdb07013d,0x00000000}},	//   _vỡ_, _tõug, rtjé,
  { {0x7d1500ea,0xdcf6004c,0x00000000,0x00000000}},	//   vizs, žbět,   ,
  { {0x6d4e08f0,0x03260062,0xa021004e,0x00000000}},	//   emba, _яден, ööae,
  { {0x9df8005a,0xbea4000d,0x2b596eb5,0x00000000}},	//   енят_, ышэй, _risc_,
  { {0x9ccb000d,0x2ca5013d,0xef1f0058,0x00000000}},	//   чыма_, üld_, snü_,
  { {0xdb1e1118,0x69c65547,0x7d156eb6,0x00000000}},	//   _espí, _aske, rizs,
  { {0x6d4e1642,0x3f9e6eb7,0x403b009a,0x00000000}},	//   amba, mutu_, _מגוג,
  { {0x7b030004,0x0f5800b5,0x3f9e6eb8,0x00000000}},	// [f5b0] _nõue, _איהם_, lutu_,
  { {0xa3e00053,0x58d9000d,0x2b5904f9,0x00000000}},	//   दमा_, ьдзя_, _wisc_,
  { {0x690b0051,0xdb0500b9,0x7bc56eb9,0x00000000}},	//   dżet, _ophø, _ushu,
  { {0x645e0078,0xb7150062,0x238c004c,0x00000000}},	//   žpil, ъдещ, děj_,
  { {0x3f9e004b,0x7cf06eba,0x64a53fe2,0x00000000}},	//   hutu_, _kärp, вала,
  { {0x2d996ebb,0x26c9017f,0x273c008b,0x00000000}},	//   irse_, žao_, hính_,
  { {0x62820179,0x7c2900bd,0x26110042,0x00000000}},	//   _beoo, ßerh, _देरी_,
  { {0x00000000,0x00000000,0x00000000,0x00000000}},	//     ,   ,   ,
  { {0x2d8b0045,0x7aef6ebc,0xa2a20053,0x00000000}},	//   jsce_, _moct, _गार्,
  { {0x3f9e0035,0xd12e0593,0xf0650094,0x00000000}},	//   futu_, يمي_, ъкоп,
  { {0x52b50021,0xddc4000c,0x2d990abc,0x00000000}},	//   _لماذ, _ofiţ, erse_,
  { {0x690b0051,0x62826ebd,0x7aef56ba,0x00000000}},	//   ożes, _geoo, _noct,
  { {0x929d0022,0x78b501c8,0x3f9e005f,0x00000000}},	//   chła, _obzv, autu_,
  { {0xed576ebe,0x3f9e6ebf,0xdfa9014d,0x00000000}},	//   коя_, butu_, _قطعه_,
  { {0x7cf00137,0x2d996ec0,0x70920002,0x00000000}},	//   _därp, arse_, _тајф,
  { {0x38c8006a,0x7aef6ec1,0x00000000,0x00000000}},	//   کاری_, _coct,   ,
  { {0x690b0051,0xfd120021,0x7aef2308,0x00000000}},	// [f5c0] jżes, _نجد_, _doct,
  { {0xd884005d,0xd6a50085,0xe81a00de,0x00000000}},	//   اهای, сiўн, وزات_,
  { {0xc8b5000d,0x8b260085,0x068634d0,0x00000000}},	//   ысты, _адне, вген,
  { {0xa3d50042,0x02bd0082,0x00000000,0x00000000}},	//   िटन_, ्योन,   ,
  { {0x6f1d06b2,0x84e60054,0x3f9e0022,0x00000000}},	//   érci, кодж, zutu_,
  { {0x3f9e005b,0x68460336,0xa53302fe,0x00000000}},	//   yutu_, _анга, аніч,
  { {0x69c40051,0xd4f5000d,0xf1ca0026,0x00000000}},	//   lwie, ыяцы, kráð_,
  { {0x69c40051,0x4420003b,0x7c29004d,0x00000000}},	//   owie, ăi_, ßeri,
  { {0x44320045,0xcb130132,0x7c29005b,0x00000000}},	//   ły_, ילה_, ğeri,
  { {0xa3cf0161,0x2018017d,0x67220078,0x00000000}},	//   शिश_, úrio_, lnoj,
  { {0x69c400bd,0x2d800089,0x62820019,0x00000000}},	//   hwie, _awie_, _teoo,
  { {0x69c4006f,0x3f9e6ec2,0x753d008f,0x00000000}},	//   kwie, rutu_, _īszi,
  { {0x2d994d4b,0x6aa405b9,0xf1940376,0x00000000}},	//   urse_, dgif, _силь,
  { {0x2d800051,0x69c40051,0xf6530063,0x00000000}},	//   _dwie_, dwie, יצר_,
  { {0x7ceb00bd,0xd259001c,0x6aa401b0,0x00000000}},	//   _kürz, meņa_, fgif,
  { {0x99800045,0x2cad0080,0x90570063,0x00000000}},	//   dził_, řed_, _בסוף_,
  { {0x690b0051,0x79a70062,0x3a840085,0x00000000}},	// [f5d0] dżer, ърве, рысв,
  { {0x6722109f,0xce380063,0x9874012c,0x00000000}},	//   enoj, _באחת_, илуц,
  { {0x69c40051,0xccf20063,0xe78702fa,0x00000000}},	//   awie, _הכי_, тузо,
  { {0x07a4148d,0xf794000d,0x47580054,0x00000000}},	//   раїн, рацэ, врія_,
  { {0x5a9a0063,0xa63415d4,0x1a9a0063,0x00000000}},	//   _אשרא, анці, _אירע,
  { {0x67220072,0xf7730044,0xdb1e009c,0x00000000}},	//   anoj, _نار_, _ispá,
  { {0x224600ea,0xd259008f,0x273c013d,0x00000000}},	//   _azok_, deņa_, zíni_,
  { {0x32d40085,0x72c50854,0xd1c91fc6,0x00000000}},	//   ацьс, убиз, елие_,
  { {0x798d160b,0x95d90062,0xdced007d,0x00000000}},	//   nsaw, _ядат_, _atač,
  { {0xc1050044,0xe3d700de,0x5996009d,0x00000000}},	//   اودي, _لتصع, נכתב_,
  { {0x69c40051,0xd37501ce,0x53a400de,0x00000000}},	//   zwie, _слећ, _نملك,
  { {0x213e6ec3,0x69c40022,0x24854b57,0x00000000}},	//   alth_, ywie, _helm_,
  { {0xe0ce011c,0x6aa40a2e,0x29036225,0x00000000}},	//   _лв_, vgif, _olja_,
  { {0x621a0149,0x62050058,0xb886004c,0x00000000}},	//   _אונק, ıtlı, otíž,
  { {0x798d6ec4,0x22590066,0xbc190054,0x00000000}},	//   esaw, ľsku_, віті_,
  { {0x69c40045,0xdce4007d,0x2fd800b9,0x00000000}},	//   twie, _otić, ærge_,
  { {0x09e36ec5,0xf389008b,0x6f046ec6,0x00000000}},	// [f5e0] ботн, hả_, _ilic,
  { {0x395c0137,0xb609001c,0x69c44dd0,0x00000000}},	//   övs_, iešķ, rwie,
  { {0x6aa401e3,0x6f046ec7,0x69c46ec8,0x00000000}},	//   pgif, _klic, swie,
  { {0xbc1b0047,0xeafa0021,0x6722008f,0x00000000}},	//   _טויש, _أردت_, unoj,
  { {0x6d5e6ec9,0xbf370041,0x60c16eca,0x00000000}},	//   _kipa, נאנץ_, kelm,
  { {0x60c1024a,0x6f040268,0xa3f40086,0x00000000}},	//   jelm, _llic, иплі,
  { {0x6d5e0035,0x60c12f8d,0xe3af0021,0x00000000}},	//   _mipa, delm, كري_,
  { {0xaa7b0024,0x6d5e03f7,0x3bbb0063,0x00000000}},	//   _inýc, _lipa, תמקד,
  { {0x171b00b5,0x7b030019,0xdced6ecb,0x00000000}},	//   _נומע, _jõua, _stač,
  { {0x291a0089,0x60c16ecc,0x6d5e0089,0x00000000}},	//   nipa_, gelm, _nipa,
  { {0x2b4000c3,0x6f040832,0x289b0047,0x00000000}},	//   klic_, _blic, עיטא,
  { {0x291a0529,0x6f046ecd,0x9f350086,0x00000000}},	//   hipa_, _clic, ремі,
  { {0x7b030019,0x291a6ece,0xada4000d,0x00000000}},	//   _nõua, kipa_, баўл,
  { {0x656f0164,0x6f046ecf,0x6d5e6ed0,0x00000000}},	//   _éche, _elic, _cipa,
  { {0x6d5e014f,0x6f040924,0x273c3dc6,0x00000000}},	//   _dipa, _flic, línu_,
  { {0x443e00e3,0xadf51001,0x543b0047,0x00000000}},	//   _myt_, _впиш, געלא,
  { {0x443e2d2c,0x7d1b0003,0xb886011b,0x00000000}},	// [f5f0] _lyt_, éuss, ztíž,
  { {0x798d0150,0x6fa80053,0x613d01a8,0x00000000}},	//   rsaw, _कमां, tèli,
  { {0xf7700032,0x443e6ed1,0x2b406ed2,0x00000000}},	//   كان_, _nyt_, blic_,
  { {0x1b7a0047,0x6d5e0035,0x7c2900bd,0x00000000}},	//   _שטרע, _zipa, ßeru,
  { {0xa684019d,0xd5e506da,0x60c100ea,0x00000000}},	//   слід, ржли, yelm,
  { {0x7aed6ed3,0x291a3af2,0x443e6ed4,0x00000000}},	//   ljat, cipa_, _byt_,
  { {0x60c10016,0xf389008b,0xa5060062,0x00000000}},	//   velm, uả_, реща_,
  { {0xe610007e,0xf389008b,0x7aed36e5,0x00000000}},	//   _کشف_, rả_, njat,
  { {0x62890185,0xb8830024,0x60c16ed5,0x00000000}},	//   raeo, príč, telm,
  { {0x6f0403bd,0x6f166ed6,0xa2d50053,0x00000000}},	//   _slic, _smyc, _मोर्,
  { {0x6d5e6ed7,0x4f260ae8,0x60c11d2b,0x00000000}},	//   _ripa, идоб, relm,
  { {0x7f4d03b2,0x6d5e27da,0x56b50047,0x00000000}},	//   _chaq, _sipa, ױפֿן_,
  { {0xfaff00ac,0x63a34ded,0x60c16ed8,0x00000000}},	//   _kiëf_, lunn, pelm,
  { {0xdca6041d,0x7aed017e,0x4e96007e,0x00000000}},	//   јави, ejat, دشگر,
  { {0x6d5e0ffe,0x70390041,0x95a00058,0x00000000}},	//   _vipa, _בײַצ, ışiş,
  { {0x7c3e0240,0x2b4000e5,0x6f046ed9,0x00000000}},	//   _vypr, ulic_, _ulic,
  { {0xdb07007a,0x61fb028d,0x7c3e0051,0x00000000}},	// [f600] ðmát, nyul, _wypr,
  { {0x63a30a08,0x68464cad,0x61e96eda,0x00000000}},	//   kunn, анза, ixel,
  { {0x485a000d,0x7c29004d,0xdc9b3759,0x00000000}},	//   траў_, ßert, _בסיכ,
  { {0x7d1c04ab,0x6fda0047,0x61fb0c55,0x00000000}},	//   lirs, כקעס, kyul,
  { {0xed590080,0x62860026,0xfb370047,0x00000000}},	//   ůže_, ðkom, _כאטש_,
  { {0x186a00d7,0x63a36edb,0x7d1c6edc,0x00000000}},	//   _јави_, funn, nirs,
  { {0xdb0700ea,0x64a3005e,0xd467005e,0x00000000}},	//   ltjá, цаја, шије_,
  { {0x64480024,0x7b030019,0xdddd0066,0x00000000}},	//   _vzdi, _lõun, lasť,
  { {0xdb0700ea,0x443e001f,0x32530062,0x00000000}},	//   ntjá, _wyt_, овър,
  { {0x7b030019,0x63a336a1,0x891e0047,0x00000000}},	//   _nõun, bunn, אָס_,
  { {0xd8d70047,0x6448007d,0x3f650003,0x00000000}},	//   בויט_, _uzdi, _nœud_,
  { {0xdb230058,0x7e2b0085,0xee840085,0x00000000}},	//   ürüc, віга_, жыро,
  { {0x7e470071,0x7e2b0086,0x57570041,0x00000000}},	//   рхне, тіна_, יבטע_,
  { {0x6fb4007e,0x7e646edd,0x7d1c6ede,0x00000000}},	//   _همتا, _egip, girs,
  { {0x9b6800e1,0x7aed6edf,0x8fa3005e,0x00000000}},	//   ишта_, tjat, _даје,
  { {0x5f73007e,0x905b0063,0x7aed2401,0x00000000}},	//   _باور, _בכות, ujat,
  { {0x6f1d1d07,0x9f530051,0x7d1c6ee0,0x00000000}},	// [f610] misc, ńców_, birs,
  { {0x7c2900bd,0x7d1c6ee1,0x6f1d6ee2,0x00000000}},	//   ßers, cirs, lisc,
  { {0x8e38007e,0x9675000d,0x3ebe00ea,0x00000000}},	//   _مسیر_, былі, őtte_,
  { {0xb8fe0161,0xec36014e,0x6f1d6ee2,0x00000000}},	//   _दो_, _לאתר_, nisc,
  { {0x58870088,0x7640001f,0xb465007e,0x00000000}},	//   _выба, _cymy, مگاه,
  { {0xa5f60138,0x63a30d9e,0x6f1d05e4,0x00000000}},	//   сељу_, tunn, hisc,
  { {0x6f1d00bd,0x63a300fe,0xc9520063,0x00000000}},	//   kisc, uunn, _ממך_,
  { {0x63a36ee3,0x9725005d,0xe78414db,0x00000000}},	//   runn, _افرو, _фуро,
  { {0x6f1d6ee4,0x7640001f,0x753800c2,0x00000000}},	//   disc, _gymy, bovz,
  { {0x69da0047,0x7e64002b,0x25bf003b,0x00000000}},	//   אַטו, _sgip, _ipul_,
  { {0x6f1d28e7,0x1015000d,0x7d1c6ee5,0x00000000}},	//   fisc, сьпя, virs,
  { {0x7c3802ab,0x6f1d1d07,0x33980044,0x00000000}},	//   _øvri, gisc, _ضخمة_,
  { {0x2d8403b2,0x2f55019d,0xa3cf0235,0x00000000}},	//   ème_, ютьс, शिक_,
  { {0x6f1d0025,0xa3ab0053,0xd37e007d,0x00000000}},	//   aisc, कंप_, šćen_,
  { {0x656103d9,0x7d1c6ee6,0x6f1d6ee7,0x00000000}},	//   _milh, rirs, bisc,
  { {0x8bc50088,0x6e960021,0x2d840003,0x00000000}},	//   ўсёд, _الظا, âmes_,
  { {0xe9da0475,0xf2d20047,0x7cf0004d,0x00000000}},	// [f620] ыка_, הען_, _märz,
  { {0xdb0700ea,0xb4e60053,0xe8f73320,0x00000000}},	//   rtjá, _बचे_, блу_,
  { {0x644106a3,0x7c290058,0x7640002b,0x00000000}},	//   _nyli, şerr, _symy,
  { {0x7b030019,0xdd8f007e,0x76a90086,0x00000000}},	//   _jõul, _توی_, итів_,
  { {0x65616ee8,0xd627000d,0x99d60021,0x00000000}},	//   _bilh, боце_, _اتجا,
  { {0x68f500c3,0x9633000d,0x186724cc,0x00000000}},	//   _gozd, чніц, _гари_,
  { {0x753800c2,0xd4990054,0x76400022,0x00000000}},	//   rovz, ррі_, _wymy,
  { {0x64410cc7,0x05666ee9,0x929d0022,0x00000000}},	//   _dyli, _гван, ykłe,
  { {0x65616eea,0xe29f007a,0x3202027d,0x00000000}},	//   _filh, óða_, áky_,
  { {0x656f0164,0x6f1d00bd,0x20ca005e,0x00000000}},	//   _écha, wisc, ућио_,
  { {0x6f1d27a0,0x3202004a,0x61e40078,0x00000000}},	//   tisc, šky_, _šild,
  { {0x71a6000d,0xadd90121,0xce590062,0x00000000}},	//   _гадз, амму_, ианц_,
  { {0x644100bd,0x6f1d6eeb,0x78bc0c7e,0x00000000}},	//   _zyli, risc, _obrv,
  { {0xd1300021,0x6f1d6eec,0x3ead0051,0x00000000}},	//   _تمت_, sisc, żet_,
  { {0x798600e5,0x6f1d6ee7,0xb4fb0149,0x00000000}},	//   _awkw, pisc, נפלי,
  { {0xae9b0021,0x802501f3,0x9aa50044,0x00000000}},	//   _إضغط_, _برهم, تمرو,
  { {0x68f56eed,0x98e50021,0xdce60058,0x00000000}},	// [f630] _pozd, يكرو, arkı,
  { {0xb8820024,0xc8670076,0x290100a4,0x00000000}},	//   _šírk, стаи, ukha_,
  { {0xf84b042c,0x29015ae1,0x25a600a3,0x00000000}},	//   учай_, rkha_, euol_,
  { {0x17f80021,0xd7580021,0x8c44003b,0x00000000}},	//   حركة_, مجنا_, ăşti,
  { {0x6561017d,0x644144a1,0x65690331,0x00000000}},	//   _pilh, _syli, _queh,
  { {0x73990002,0x64410078,0x69cf6eee,0x00000000}},	//   атис_, _pyli, _isce,
  { {0x65616eef,0x8cbb0042,0x3cfc009a,0x00000000}},	//   _vilh, श्यो, רפוב,
  { {0x8c1c0149,0x65616ef0,0x64410195,0x00000000}},	//   טווי, _wilh, _vyli,
  { {0x2d9e0051,0x65616682,0x64410a8d,0x00000000}},	//   ątek_, _tilh, _wyli,
  { {0xdb070137,0xdcf6008f,0x161f0042,0x00000000}},	//   ltjä, īcīb, _मेयर_,
  { {0xceea1259,0xd8d80041,0x78ba013d,0x00000000}},	//   адне_, מוזט_, _ötve,
  { {0x69dd001f,0xc7d60063,0x69cf2437,0x00000000}},	//   _orse, קורי_, _osce,
  { {0x200300c3,0xee370454,0x9dba0085,0x00000000}},	//   šji_, жня_, шыну_,
  { {0x3eb90014,0x9e630085,0x865a009a,0x00000000}},	//   afst_, ьвяд, ידרי,
  { {0xdb0700c7,0x69dd011f,0x69cf1eb4,0x00000000}},	//   ktjä, _arse, _asce,
  { {0x28ac0053,0x1a2a065b,0x0b4601dd,0x00000000}},	//   _चाहि, ажби_, інан,
  { {0x628b000f,0x3b070189,0xad9b00ea,0x00000000}},	// [f640] _mego, цето_, szúr,
  { {0xbca60021,0x69dd00a8,0x98a32046,0x00000000}},	//   _بمدي, _drse, дифе,
  { {0x69dd00bd,0x69cf0876,0x62990051,0x00000000}},	//   _erse, _esce, _odwo,
  { {0xe73a0076,0xb5aa0021,0xbebb006f,0x00000000}},	//   шее_, لاتك_, piëe,
  { {0x64450004,0x7ae600ca,0x186a0054,0x00000000}},	//   ühin, _inkt, _ваги_,
  { {0xb6030066,0x33980021,0x62996ef1,0x00000000}},	//   úšan, منتج_, _adwo,
  { {0x628b2da1,0x261a0053,0xdb1e0003,0x00000000}},	//   _bego, _मेरी_, _appé,
  { {0xc3d5000d,0x628b00be,0x6367013d,0x00000000}},	//   яўчы, _cego, _bűnb,
  { {0xc0c60001,0xe5770002,0x628b19f1,0x00000000}},	//   ољни, _мзт_, _dego,
  { {0x30146ef2,0xe452005d,0xe506043e,0x00000000}},	//   здор, _قضا_, _ببري,
  { {0x436a0cb2,0xf1f7005d,0xa2d50082,0x00000000}},	//   _таен_, معیت_, _मोक्,
  { {0x628b1203,0x51860cf7,0x00000000,0x00000000}},	//   _gego, _дука,   ,
  { {0xc6930a7a,0xe0cf007e,0x3eb906aa,0x00000000}},	//   ואר_, رزی_, rfst_,
  { {0x224b050c,0x387f0130,0x9f6a012c,0x00000000}},	//   ücke_, _đuro_, _криз_,
  { {0xcb1b000a,0xb603004c,0x0b5b0044,0x00000000}},	//   аќа_, _zmáč, لشرب_,
  { {0xb8820024,0x929d0051,0x539b0aeb,0x00000000}},	//   _šípk, okła, יסלא,
  { {0x5d840021,0x44290013,0x2eaa0041,0x00000000}},	// [f650] _قليل, ̃a_, _השפּ,
  { {0xaa7b0024,0xc87b005e,0x7ae6005f,0x00000000}},	//   _iným, рџа_, _enkt,
  { {0x6d4701a6,0xd7fb000a,0x7b03004b,0x00000000}},	//   mlja, јуз_, _jõuk,
  { {0x290a3fe1,0x87280085,0xae020042,0x00000000}},	//   _elba_, оўча_, रैकन_,
  { {0x628b02f6,0x69cf0290,0xdb070354,0x00000000}},	//   _rego, _usce, rtjä,
  { {0x628b0994,0xdb0700c7,0x33f51501,0x00000000}},	//   _sego, stjä, зчис,
  { {0x7b030004,0x8458005a,0x628b017d,0x00000000}},	//   _nõuk, орът_, _pego,
  { {0x656f0164,0x6aad6ef3,0x16160053,0x00000000}},	//   _écho, ngaf, _देकर_,
  { {0x257000cd,0x91b0008b,0x6d4708ed,0x00000000}},	//   _gàl_, _đại_, klja,
  { {0xd37e007d,0xa3bb0049,0x6d47013d,0x00000000}},	//   šćan_, _ناصر_, jlja,
  { {0x78fc0047,0x929d0051,0x69cd002b,0x00000000}},	//   יפזו, akła, hwae,
  { {0x672b2c24,0x6d476ef4,0x91f70021,0x00000000}},	//   nngj, elja, _وأشا,
  { {0x91e53ea5,0xed5a180c,0x28ac0042,0x00000000}},	//   _холе, йом_, _चालि,
  { {0x2d9e14c0,0x91f60063,0x25ee0042,0x00000000}},	//   čte_, _ממנו_, _आपसी_,
  { {0x3eb100fe,0xe8df0013,0x207a0041,0x00000000}},	//   ältö_, _ngực_, _פאקא,
  { {0x63ae0146,0xe9df0025,0x7e9a0021,0x00000000}},	//   _åbne, _brú_, _انظر_,
  { {0x6d4701a6,0x63a3027d,0x7c3b0058,0x00000000}},	// [f660] blja, hrnn, ğura,
  { {0x7c3b003b,0x672b0f49,0x3c94005d,0x00000000}},	//   şura, engj, _زیرز,
  { {0x78a30026,0x672b0014,0x929d0051,0x00000000}},	//   ónva, fngj, zkła,
  { {0x248c0080,0x60c80051,0x929d0051,0x00000000}},	//   _sedm_, zedm, ykła,
  { {0xa4d40086,0x94d40094,0x00000000,0x00000000}},	//   долі, долц,   ,
  { {0xb4d60161,0x672b2033,0xe38a030b,0x00000000}},	//   िये_, angj, бщил_,
  { {0xf2140053,0x60c801f2,0x99890051,0x00000000}},	//   _तेज़_, vedm, czał_,
  { {0x33970044,0xf1a6180c,0x717401f3,0x00000000}},	//   أخوة_, прон, وهبا,
  { {0x67220006,0xd528008b,0x79960051,0x00000000}},	//   mioj, _cộn, nsyw,
  { {0x672227f2,0xdce4007d,0xd5280013,0x00000000}},	//   lioj, _otiđ, _dộn,
  { {0x6d4706bb,0xe1ef007e,0xc4d30063,0x00000000}},	//   vlja, نسی_, _רגע_,
  { {0xd0170088,0x7d1e0159,0x67220078,0x00000000}},	//   яфы_, _amps, nioj,
  { {0x660200e3,0x6ce70086,0x6d4708ed,0x00000000}},	//   nyok, піве, tlja,
  { {0xeb050053,0x41530086,0xed590078,0x00000000}},	//   रस्त_, _звіс, įžo_,
  { {0xcc54005a,0x00bb0063,0x6d47007d,0x00000000}},	//   евръ, _המומ, rlja,
  { {0x67220035,0x5bb80076,0x395a0110,0x00000000}},	//   jioj, ялся_, emps_,
  { {0x6d47027c,0x5ed4005d,0xaa580505,0x00000000}},	// [f670] plja, _ستيز, зиту_,
  { {0xb4d60161,0x98b3003b,0x90d50013,0x00000000}},	//   ियो_, doxă_, hòn,
  { {0x6f0d66f5,0xf6d50086,0x06990021,0x00000000}},	//   _klac, діля, قناة_,
  { {0xd491001b,0xe9df241b,0x99890051,0x00000000}},	//   _còn_, _trú_, rzał_,
  { {0x99890022,0xe9df0139,0xd5bb0a7d,0x00000000}},	//   szał_, _urú_, ссе_,
  { {0xd528008b,0x04450002,0x2b490294,0x00000000}},	//   _rộn, мелн, llac_,
  { {0x6f0d01f7,0xcc78009a,0xdc9c009a,0x00000000}},	//   _olac, הגות_, זיול,
  { {0xd2a90121,0x25a01871,0x61e4237b,0x00000000}},	//   цкие_, šila_, _šila,
  { {0x44b50074,0x59e00042,0x63aa0244,0x00000000}},	//   _обас, नियर, aufn,
  { {0x6f0d6ef5,0x2ee96ef6,0xa2bd0042,0x00000000}},	//   _alac, _anaf_, _वॉर्,
  { {0x6f0d2f77,0x1eca0ae8,0x7548013d,0x00000000}},	//   _blac, олни_, őszá,
  { {0xe1f10021,0x6f0d6ef7,0xe607005d,0x00000000}},	//   _لست_, _clac, نش_,
  { {0x6f0d0051,0x8e550054,0xbe3a0054,0x00000000}},	//   _dlac, етрі, ючої_,
  { {0x60250259,0xcb6a0d62,0x333f1662,0x00000000}},	//   _одла, жаве_, loux_,
  { {0x6f0d6ef8,0x7fd50086,0xdc67018e,0x00000000}},	//   _flac, _цілі, дард_,
  { {0xbebb00ac,0x333f0003,0x6f0d6ef9,0x00000000}},	//   liën, noux_, _glac,
  { {0x2d95000d,0x8d560086,0xb8b6005e,0x00000000}},	// [f680] _прэс, _оточ, дсећ,
  { {0x660205b3,0x7c390003,0xbd46005d,0x00000000}},	//   vyok, ébré, _زنجي,
  { {0xc66a02d8,0x2ee9002b,0xd2590023,0x00000000}},	//   ошле_, _ynaf_, meņu_,
  { {0x464a0189,0x333f0003,0x869a0054,0x00000000}},	//   озен_, joux_, ітет_,
  { {0x67220006,0x38710025,0x6d5c08a5,0x00000000}},	//   rioj, íorú_, omra,
  { {0xd37a2c47,0x67224949,0x2d820077,0x00000000}},	//   очи_, sioj, ipke_,
  { {0xbebb006f,0x68fc6efa,0x22460089,0x00000000}},	//   diën, _iord, _syok_,
  { {0xc2980001,0xdb080072,0x68fc6efb,0x00000000}},	//   чких_, _äläk, _hord,
  { {0x68fc6efc,0xb0650050,0xc4c60044,0x00000000}},	//   _kord, yjää, _يتطو,
  { {0xbebb006f,0x6f0d20a0,0x752301f4,0x00000000}},	//   giën, _slac, cinz,
  { {0x68fc6efd,0x3f980240,0x6f0d6efe,0x00000000}},	//   _mord, éru_, _plac,
  { {0x9f500026,0x6d5c6eff,0x3f640121,0x00000000}},	//   ðaða_, emra, ктяб,
  { {0x68fc18c7,0x2f020026,0xe0da0121,0x00000000}},	//   _oord, _nógu_, _мвд_,
  { {0xbebb0122,0x68fc092f,0x2ee900a3,0x00000000}},	//   ciën, _nord, _wnaf_,
  { {0x6f0d1994,0xb0650ff2,0x69c60078,0x00000000}},	//   _tlac, rjää, _apke,
  { {0xc9870001,0xb0650bda,0xdb1e006c,0x00000000}},	//   дужи, sjää, _appâ,
  { {0x5a35005a,0x7e6d0019,0x65680139,0x00000000}},	// [f690] хнат, _igap, _oidh,
  { {0xba540001,0x64450019,0x25a6001f,0x00000000}},	//   твуј, ühik, drol_,
  { {0xf77008aa,0x752300bd,0x18a40086,0x00000000}},	//   لان_, vinz, таєм,
  { {0x25a6001f,0x61e241a9,0x65680139,0x00000000}},	//   frol_, _orol, _aidh,
  { {0x65680035,0x68fc6f00,0x1ae4000d,0x00000000}},	//   _bidh, _ford, _роўм,
  { {0x19b601f9,0x2d992a69,0x7afd2e91,0x00000000}},	//   _אפשר_, isse_, _host,
  { {0x61e20185,0x7afd6f01,0xd466005e,0x00000000}},	//   _arol, _kost, нише_,
  { {0x64480006,0x7afd00fe,0x25a64c3c,0x00000000}},	//   _dydi, _jost, brol_,
  { {0xbebb006f,0x61e24fe4,0x6d5c001f,0x00000000}},	//   tiën, _crol, ymra,
  { {0x2b40317f,0x7e6d6f02,0x7afd1817,0x00000000}},	//   zoic_, _agap, _lost,
  { {0x7afd0173,0x2d996f03,0xbebb0229,0x00000000}},	//   _oost, esse_, riën,
  { {0xbebb00e8,0x7afd6f04,0xd4910013,0x00000000}},	//   siën, _nost, _hè_,
  { {0xa3ab016a,0xbd36005a,0x7c3b0075,0x00000000}},	//   कूर_, ехвъ, şurl,
  { {0x7afd6f05,0x60d801e1,0x53990063,0x00000000}},	//   _aost, _gavm, ּיּו,
  { {0x7afd330c,0x9f52013d,0x2d995b87,0x00000000}},	//   _bost, ázó_, asse_,
  { {0x7afd3e9d,0x20050078,0x68fc6f06,0x00000000}},	//   _cost, myli_, _sord,
  { {0x2b401098,0x4a75000d,0x68fc6f07,0x00000000}},	// [f6a0] roic_, тыст, _pord,
  { {0x290e0026,0x38c8007e,0xc796007f,0x00000000}},	//   ófa_, باری_, ерды,
  { {0xcd020051,0x65680052,0x68fc46aa,0x00000000}},	//   ęść_, _ridh, _vord,
  { {0x68fc0625,0x65681101,0x25a63eab,0x00000000}},	//   _word, _sidh, trol_,
  { {0x6f1d0268,0x45d4006e,0xd491008b,0x00000000}},	//   èrci, толс, _bè_,
  { {0x7afd06ce,0x9f590025,0x25a614fa,0x00000000}},	//   _zost, árú_, rrol_,
  { {0xa3ab0053,0x3d080042,0xc8c60042,0x00000000}},	//   कूल_, _सकने_, _रॉयट,
  { {0x64940006,0x18670086,0x61e24d87,0x00000000}},	//   džių, _часи_, _prol,
  { {0xcb130063,0xe73722c4,0x6367013d,0x00000000}},	//   טלה_, _чет_, _tűnn,
  { {0x64486f08,0x61e2006f,0x60f80086,0x00000000}},	//   _tydi, _vrol, єння_,
  { {0xb3e90021,0x2d800089,0x7b03004b,0x00000000}},	//   _يعمل_, _atie_, _kõut,
  { {0xbebb0122,0x61e22bd1,0x7b03004b,0x00000000}},	//   ciël, _trol, _jõut,
  { {0x2d996f09,0x7afd2d1f,0xc333089e,0x00000000}},	//   usse_, _rost, _גוף_,
  { {0xd24f0032,0x3ea00592,0x7afd6f0a,0x00000000}},	//   _انه_, _edit_, _sost,
  { {0x2d996f0b,0x7afd6f0c,0x8ae7071f,0x00000000}},	//   ssse_, _post, ніал,
  { {0xa3e10161,0x7b030019,0xdb500021,0x00000000}},	//   दित_, _nõut, مَّ_,
  { {0x7afd6f0d,0xe29f0026,0x9f5f00ea,0x00000000}},	// [f6b0] _vost, óði_, sztó_,
  { {0x7c38017d,0x6d4505b3,0x656f0003,0x00000000}},	//   çarã, _ukha, _échi,
  { {0x56950055,0x2815006a,0x7afd69e9,0x00000000}},	//   вает, خواس, _tost,
  { {0x7afd1840,0xc747005d,0x5d84005d,0x00000000}},	//   _uost, رضاي, _جلیل,
  { {0x5e9c00b5,0x20050051,0xdb07004c,0x00000000}},	//   לבאק, zyli_, nují,
  { {0xfaff00e8,0xf9920132,0x7c34005b,0x00000000}},	//   _hoë_, _דרך_, _çerç,
  { {0xdb070080,0xdce500c3,0xbebb006f,0x00000000}},	//   hují, _nihč, tiël,
  { {0xdb07004c,0x67d40054,0xc3d40085,0x00000000}},	//   kují, _щосу, уўшы,
  { {0x26cf0051,0xbebb0983,0x61e40139,0x00000000}},	//   mego_, riël, _áill,
  { {0xdb0702f4,0x600912ad,0x41020076,0x00000000}},	//   dují, дном_, изыв,
  { {0x7b030004,0xc9520063,0x61ed4e31,0x00000000}},	//   _jõus, שמי_, _šald,
  { {0xe290043b,0x26cf0045,0x27e700fe,0x00000000}},	//   _هذه_, nego_, änny_,
  { {0xc332014e,0xe0ce6f0e,0xce690121,0x00000000}},	//   _דוא_, _кв_, ерёд_,
  { {0xa3b50161,0x98ba001c,0x00000000,0x00000000}},	//   _जमा_, kopā_,   ,
  { {0x7b030004,0xdb070124,0x8c460263,0x00000000}},	//   _nõus, aují, теве,
  { {0x3f850529,0x26cf0045,0x29111ba2,0x00000000}},	//   mplu_, jego_, _alza_,
  { {0x26cf0051,0xdb07004c,0x2896005e,0x00000000}},	// [f6c0] dego_, cují, вјес,
  { {0x3f850058,0xfb82005d,0x00000000,0x00000000}},	//   oplu_, _نگری,   ,
  { {0x26cf017d,0xdde9005d,0xf71a0085,0x00000000}},	//   fego_, _قریه_, міды_,
  { {0x6d4e02f0,0xd7ef0021,0xdb1e00cd,0x00000000}},	//   llba, تكم_, _espò,
  { {0xdb1e0045,0xe76900f2,0x6d4e6f0f,0x00000000}},	//   _wspó, رحمن_, olba,
  { {0xdb0e0244,0x24581cdf,0x00000000,0x00000000}},	//   stbä, наль_,   ,
  { {0x6731000f,0x94230001,0x25ee0053,0x00000000}},	//   ókjá, имље, _आपकी_,
  { {0x26cf0045,0x61d803d6,0x6d4e004d,0x00000000}},	//   cego_, емия_, hlba,
  { {0x527301ce,0x05663207,0x00000000,0x00000000}},	//   шују, _аван,   ,
  { {0xdb070080,0xf9930063,0xdb1c0022,0x00000000}},	//   vují, סרת_, owró,
  { {0xd00701aa,0x6d4e01e1,0xd1410022,0x00000000}},	//   веќе_, dlba, djąć_,
  { {0xb2260076,0x6d4e1b64,0x25a908ea,0x00000000}},	//   _имел, elba, šale_,
  { {0x9196005e,0x5bcb0042,0xf044005d,0x00000000}},	//   _рјеш, ाब्व, ضعگی,
  { {0xed580088,0x26cf0051,0xdb07004c,0x00000000}},	//   коў_, zego_, rují,
  { {0x212b0164,0x26cf20ea,0xac19018b,0x00000000}},	//   èche_, yego_, хову_,
  { {0xdb070080,0xdb1c4da0,0x6d4e6f10,0x00000000}},	//   pují, ntrè, alba,
  { {0xaa55000a,0xba5500d7,0x61e4007d,0x00000000}},	// [f6d0] уваш, увај, _šilj,
  { {0x26cf0045,0xf8070062,0x2bab0053,0x00000000}},	//   wego_, кчен, _छिपा,
  { {0x26cf0045,0x3d080053,0xdb070026,0x00000000}},	//   tego_, _सकते_, ðmót,
  { {0x59f9005a,0x26cf006d,0xdb0700ea,0x00000000}},	//   _земя_, uego_, ntjü,
  { {0xdb1e007a,0x3f5200ea,0xe947000d,0x00000000}},	//   _uppá, dául_, _ахво,
  { {0x7b030019,0xe795007e,0x75440454,0x00000000}},	//   _tõus, _مارک, аніз,
  { {0xe78702a9,0xf8b20063,0x0394000d,0x00000000}},	//   _југо, _לשם_, арыя,
  { {0xf1b70042,0x7879013d,0xfc58009a,0x00000000}},	//   _आमदन, _fúvó, כבוש_,
  { {0x628906aa,0xd4c70044,0x63aa0046,0x00000000}},	//   rbeo, _لغاي, arfn,
  { {0x6604004b,0x28c60042,0xe00e0042,0x00000000}},	//   äike, र्पि, ानंद_,
  { {0xb447000d,0x28ab0053,0x7aef0003,0x00000000}},	//   _рэак, _चयनि, _onct,
  { {0x7b0a01d1,0x00000000,0x00000000,0x00000000}},	//   _výuk,   ,   ,
  { {0xa0c5007e,0x21a50239,0xe29f0014,0x00000000}},	//   _ميشو, _силм, óðu_,
  { {0x9d5603eb,0xdb1c0022,0x64580022,0x00000000}},	//   انست, ywró, ściń,
  { {0xc0c80001,0xdb1c0003,0xf0920063,0x00000000}},	//   _јуче_, ltré, _פנה_,
  { {0x28c60042,0x00000000,0x00000000,0x00000000}},	//   र्नि,   ,   ,
  { {0xdb1c51ce,0x6aab0025,0x7f3b0047,0x00000000}},	// [f6e0] ntré, ógfa, _רעפו,
  { {0x61e604c7,0xe9d7066e,0x61e4005f,0x00000000}},	//   åkli, ыку_, _šilk,
  { {0x66e66f11,0x7c95000d,0xa686012d,0x00000000}},	//   ложа, _трыц, глед,
  { {0xd6d90086,0x257900cd,0x3f77003b,0x00000000}},	//   кті_, _bèl_, _răul_,
  { {0x257900cd,0x6a9b089e,0xf7170044,0x00000000}},	//   _cèl_, _אשכנ, دينغ_,
  { {0x6ab6002b,0xb4ae0042,0xa927017c,0x00000000}},	//   lgyf, कले_, _poľš,
  { {0x9f4b013d,0xc7d8009a,0xe3c30044,0x00000000}},	//   őjét_, _בַּכ, مْوَ,
  { {0x6ab6001f,0x3f520014,0x7b03004b,0x00000000}},	//   ngyf, fáum_, _jõup,
  { {0xc4ca0062,0xc114007b,0x61140f9f,0x00000000}},	//   _плаж_, имиј, идиу,
  { {0x7c3b003b,0x6ab6002b,0x7ddb00a5,0x00000000}},	//   şuri, hgyf, _läså,
  { {0x61e7001c,0x58f70047,0x8cbf0042,0x00000000}},	//   ājla, אמיע_, _लॉगो,
  { {0xa3e10053,0x7b03004b,0xe4570041,0x00000000}},	//   दिर_, _nõup, _גיבט_,
  { {0xe29b0047,0x3fc8005d,0xddcd0022,0x00000000}},	//   _טשאר, ردگی_, _szał,
  { {0x61db0063,0x3076018e,0x28c60053,0x00000000}},	//   _נקוד, _судс, र्मि,
  { {0xdc190022,0x6367009c,0xab9501ce,0x00000000}},	//   _ołąc, _bűnh, рабљ,
  { {0xd5d4016a,0x7f830021,0x3f9e3dc6,0x00000000}},	//   _धनंज, _الين, mstu_,
  { {0x3f9e6f12,0xadd5005e,0xaa7b0014,0x00000000}},	// [f6f0] lstu_, _топљ, _snýs,
  { {0xd2570063,0xb9c40021,0x0a680615,0x00000000}},	//   רשמה_, إقلي, урси_,
  { {0x6d471e82,0xccf20063,0x87071213,0x00000000}},	//   moja, _וכי_, ляде,
  { {0x3f9e6f13,0x257900cd,0x7aef6f14,0x00000000}},	//   istu_, _pèl_, _unct,
  { {0xdb07007a,0x4a9a0047,0xaa9a009a,0x00000000}},	//   stjó, _בירג, _בברכ,
  { {0x63a50080,0x290f001c,0x3f9e6f15,0x00000000}},	//   áhno, īgas_, kstu_,
  { {0x99920051,0xd7e424ad,0x98c40085,0x00000000}},	//   czył_, _літо, _усял,
  { {0x29034fbe,0xdc0f004c,0xdb1c0003,0x00000000}},	//   _hoja_, _něče, ttré,
  { {0x29030117,0x6d470d93,0x7159000d,0x00000000}},	//   _koja_, koja, крос_,
  { {0xbfc5000a,0x64450019,0x0fc50d82,0x00000000}},	//   абок, ühis, айон,
  { {0x6d471b74,0xdb1c0164,0x29035fbd,0x00000000}},	//   doja, stré, _moja_,
  { {0xf3b600b5,0x2903444c,0x5de60131,0x00000000}},	//   _כּדי_, _loja_, ажма,
  { {0x6b850139,0x3f9e6f16,0x28c60053,0x00000000}},	//   _athg, astu_, र्डि,
  { {0xed5a0001,0x2d84008f,0x3cca0062,0x00000000}},	//   тог_, īme_, ълго_,
  { {0x8fc4007e,0x6a960086,0xab2a0690,0x00000000}},	//   _هزين, ирає, вова_,
  { {0x25a03667,0x6a860caa,0x61e46f17,0x00000000}},	//   šili_, рлаа, _šili,
  { {0xe9da005a,0x290304c9,0x38760001,0x00000000}},	// [f700] ъка_, _boja_, аћет,
  { {0x69d6002b,0x98a6560e,0x6ab600a3,0x00000000}},	//   rwye, риже, sgyf,
  { {0xcd36005d,0x6367013d,0x1dde0082,0x00000000}},	//   _مرگب, _tűnh, मिकत,
  { {0xeab208aa,0x99920051,0xfc570063,0x00000000}},	//   _بعد_, rzył_, _כביש_,
  { {0x45d6005a,0x29030150,0x6f040051,0x00000000}},	//   рцет, _foja_, _moic,
  { {0xdc190045,0x6f040025,0xa4d402fe,0x00000000}},	//   _włąc, _loic, сокі,
  { {0xa507018e,0x6f160137,0x07a33ba6,0x00000000}},	//   реја_, _olyc, _марн,
  { {0x25a96f18,0xb7db009a,0x6d4701ff,0x00000000}},	//   šala_, _בקלי, zoja,
  { {0x7d010026,0xd2570086,0x28c60053,0x00000000}},	//   ölsk, иць_, र्थि,
  { {0x30a30086,0xdce5003b,0x506617db,0x00000000}},	//   орюв, _mihă, итна,
  { {0x6f16002b,0x6f041073,0x3f9e004c,0x00000000}},	//   _blyc, _boic, ustu_,
  { {0x28c60161,0x3f9e6f19,0x5f2702b3,0x00000000}},	//   र्ति, rstu_, рфоз,
  { {0x2ee00089,0x6d4766b5,0x6f04203b,0x00000000}},	//   _daif_, toja, _doic,
  { {0xfd47000d,0x6d4751ad,0x412706da,0x00000000}},	//   рэмн, uoja, _кочо_,
  { {0x29031c50,0x9f5900ea,0x6f0400be,0x00000000}},	//   _roja_, áró_, _foic,
  { {0x200f108f,0x29036f1a,0x6d476f1b,0x00000000}},	//   íliš_, _soja_, soja,
  { {0x212c0025,0x0cab0002,0x7bda0014,0x00000000}},	// [f710] oidh_, _итни_, ætur,
  { {0x6cd5006a,0x3eb90026,0x6ca70121,0x00000000}},	//   _اقدا, lgst_, _триж,
  { {0x2d8b00c2,0x672b006f,0x3eb900ca,0x00000000}},	//   lpce_, tigj, ogst_,
  { {0x212c0139,0xd639000d,0x3eb92e2d,0x00000000}},	//   hidh_, лялі_, ngst_,
  { {0x200c002b,0x7c3b0058,0xd6d801ce,0x00000000}},	//   hydi_, ğuru, ртх_,
  { {0x0395005a,0x9f5f00fe,0x15a8005a,0x00000000}},	//   брия, lytä_, ръци_,
  { {0xa5060062,0x23290200,0x629b0050,0x00000000}},	//   сеща_, локи_, tauo,
  { {0xec380063,0x5c380165,0x212c0139,0x00000000}},	//   יאור_, יטוב_, eidh_,
  { {0x212c0027,0xdb1e0137,0x67296f1c,0x00000000}},	//   fidh_, _uppå, _imej,
  { {0x6f040025,0x3eb900ca,0x42220121,0x00000000}},	//   _soic, egst_, ядыв,
  { {0x6f04051e,0x201e0078,0x201150dc,0x00000000}},	//   _poic, gzti_, ázi_,
  { {0x212c0027,0x69dd175f,0x3eb90014,0x00000000}},	//   aidh_, _osse, ggst_,
  { {0xd5f900b5,0x6f041b30,0x6d4102f7,0x00000000}},	//   נפֿר, _voic, član,
  { {0x307900b5,0xd5fa0063,0x4d390076,0x00000000}},	//   _גאַנ, אפשר, аяся_,
  { {0x67290198,0x69dd6ec3,0x1d070062,0x00000000}},	//   _omej, _asse, щери_,
  { {0x673b017f,0x9f4812a2,0xfaf50054,0x00000000}},	//   _njuj, _orné_, очую,
  { {0xdb070019,0x69090046,0x00000000,0x00000000}},	// [f720] dujä, _nþes,   ,
  { {0x67290035,0x62990ac3,0x7c9604d6,0x00000000}},	//   _amej, _lewo, _уриц,
  { {0x69dd055b,0x409a0047,0xb09a0047,0x00000000}},	//   _esse, רבעס, ריער,
  { {0x7bde017f,0x63ae0146,0x9956001c,0x00000000}},	//   _ispu, _åbni, _kļūs_,
  { {0xdb1c3502,0xa50a0e48,0x44980200,0x00000000}},	//   ntrí, леда_, авлю_,
  { {0xe0c70021,0x69c46f1d,0x7ae46f1e,0x00000000}},	//   _عز_, mtie, ldit,
  { {0xe73a000a,0x61eb2894,0x66e602d8,0x00000000}},	//   _бев_, _argl, _лова,
  { {0x521403d6,0x11d80021,0x7ae46195,0x00000000}},	//   ждит, لوبة_, ndit,
  { {0x69c46f1f,0x3a2000bd,0x7ae40ff8,0x00000000}},	//   ntie, nzip_, idit,
  { {0x443e6f20,0xf8d80053,0x7ae4077e,0x00000000}},	//   _txt_, ड़िय, hdit,
  { {0x69c400fe,0x212c0025,0x645a001c,0x00000000}},	//   htie, ridh_, _uzti,
  { {0x62994e61,0x3e07005a,0x7ae40dec,0x00000000}},	//   _gewo, бягв, jdit,
  { {0x7ae424aa,0x201e00ea,0x2d8b115b,0x00000000}},	//   ddit, szti_, upce_,
  { {0x3a200139,0x69c40066,0x7b2c0058,0x00000000}},	//   dzip_, dtie, uşun,
  { {0x69c4003d,0xd1383164,0xdb1c0331,0x00000000}},	//   etie, mną_, atrí,
  { {0xd1381738,0x7d1c004d,0x3b55071f,0x00000000}},	//   lną_, ahrs, ікар,
  { {0x7bde0aca,0x69c43a7a,0x7b2c0058,0x00000000}},	// [f730] _espu, gtie, mşul,
  { {0x672908ea,0x6341001c,0xd1380051,0x00000000}},	//   _smej, mēne, nną_,
  { {0xb9010053,0x7b2c005b,0x7ae43436,0x00000000}},	//   _दस_, oşul, bdit,
  { {0xf655000a,0xbebb006f,0x69c46f21,0x00000000}},	//   овеќ, ciët, btie,
  { {0xd24604de,0x69c402b0,0xf8a9006a,0x00000000}},	//   _آن_, ctie, _نگاه_,
  { {0xd1380051,0x798d0089,0x25a92583,0x00000000}},	//   jną_, mpaw, šalo_,
  { {0xd1380051,0x9f60013d,0xd3f90085,0x00000000}},	//   dną_, őség_, рэлі_,
  { {0xd1380006,0x13090156,0x41a902a1,0x00000000}},	//   eną_, рний_, авин_,
  { {0x9f44004c,0x20d5071f,0x11d60044,0x00000000}},	//   íjí_, оінс, قوية_,
  { {0x61eb00a8,0xd1380022,0x3ea96f22,0x00000000}},	//   _vrgl, gną_, _adat_,
  { {0x69c4001c,0xf8b20063,0x61e40078,0x00000000}},	//   ztie, ושי_, _šilt,
  { {0x798d00a4,0xd5a70086,0xd1380051,0x00000000}},	//   kpaw, _вiдп, aną_,
  { {0xa3ea0235,0xd1380051,0xfe460083,0x00000000}},	//   मिथ_, bną_, інго,
  { {0x3ea90268,0x3f660164,0x3b960002,0x00000000}},	//   _edat_, _cœur_, жјат,
  { {0x61e909ff,0xdb1c431e,0x3a9a0e82,0x00000000}},	//   lvel, strí, итаю_,
  { {0x6f1d00bd,0xa3ea0161,0x7ae42359,0x00000000}},	//   chsc, मित_, udit,
  { {0x09060189,0x61e40025,0xfce66f23,0x00000000}},	// [f740] опан, _áilt, _допо,
  { {0xb8560001,0x61e96f24,0xad9b006d,0x00000000}},	//   ођењ, ivel, ayús,
  { {0x28c60053,0x7bde007d,0x97a50054,0x00000000}},	//   र्षि, _uspu, зріл,
  { {0xdb1c000c,0xd1380051,0x61e96f25,0x00000000}},	//   strâ, zną_, kvel,
  { {0xd1381435,0xe5a30893,0x35f700de,0x00000000}},	//   yną_, дичи, قرود_,
  { {0x28c60161,0xbebb0179,0x61e96f26,0x00000000}},	//   र्शि, niër, dvel,
  { {0x61e96f27,0x2cfb0041,0xd3770085,0x00000000}},	//   evel, ילסא, очы_,
  { {0xe73a005a,0xf1a61b79,0xdb1c00cd,0x00000000}},	//   _теб_, орон, ntrà,
  { {0xd1380051,0x61e9238a,0xd13a0f56,0x00000000}},	//   tną_, gvel, ихо_,
  { {0x4fc60076,0x710a0816,0xa3ea0042,0x00000000}},	//   осма, рхив_, मिद_,
  { {0x6f1d0027,0x287b0063,0xbebb0104,0x00000000}},	//   thsc, ינימ, diër,
  { {0x3f660164,0xd1380051,0xdb0e0014,0x00000000}},	//   _sœur_, sną_, ttbý,
  { {0xbebb016d,0x224b00bd,0x63750006,0x00000000}},	//   fiër, ückt_, _išna,
  { {0xbebb00ca,0xdb210014,0xc16f0054,0x00000000}},	//   giër, ðuþe, _ії_,
  { {0xc04f0304,0xdb070066,0x6367013d,0x00000000}},	//   _ці_, mujú, _tűnt,
  { {0xdb07243a,0xdb500021,0x4f670044,0x00000000}},	//   frjá, نَّ_, _باتف,
  { {0xd99900de,0x00000000,0x00000000,0x00000000}},	// [f750] صنات_,   ,   ,
  { {0x2907007a,0xbebb006f,0x657b0072,0x00000000}},	//   ðna_, ciër, _ruuh,
  { {0xbf780013,0x61e90494,0x657b0050,0x00000000}},	//   _đuợc_, zvel, _suuh,
  { {0xdb070024,0x61ed16fe,0x657b01cf,0x00000000}},	//   hujú, _šalm, _puuh,
  { {0xbafa0063,0xdb070066,0xd6180593,0x00000000}},	//   _ההרש, kujú, يتها_,
  { {0x039518bf,0xb97a0063,0xdb070066,0x00000000}},	//   прия, _לנשי, jujú,
  { {0xdb07034d,0x7bc76f28,0xc9520063,0x00000000}},	//   dujú, ntju, _נמל_,
  { {0x11d90032,0x61e964a1,0x25b00058,0x00000000}},	//   موعة_, tvel, üllü_,
  { {0x94ab0021,0x61e96f29,0xdb1c6f2a,0x00000000}},	//   _نطاق_, uvel, ntrá,
  { {0x61e9412e,0xdb070066,0x44b414cd,0x00000000}},	//   rvel, gujú, _обус,
  { {0x61e90181,0xdee602b1,0xdd3c0078,0x00000000}},	//   svel, пони, jąšl,
  { {0xba3b00e8,0xd00e0021,0xbebb00ac,0x00000000}},	//   _geïg, الَ_, wiër,
  { {0xee370086,0xbebb006f,0x427a0063,0x00000000}},	//   зня_, tiër, _האנג,
  { {0xdb070066,0xc0e50121,0xf1b908c1,0x00000000}},	//   cujú, _хокк, muš_,
  { {0xbebb0983,0xdb1c0331,0xab1a05ac,0x00000000}},	//   riër, etrá, бцах_,
  { {0xbebb0104,0xdf290044,0x00000000,0x00000000}},	//   siër, _وأين_,   ,
  { {0xbebb0122,0x61ed017f,0x3b07065b,0x00000000}},	// [f760] piër, _šalj, чето_,
  { {0xdb1c00cd,0xddcd007d,0x63a4008f,0x00000000}},	//   strà, _ugaš, ņini,
  { {0xe73a6f2b,0x7ceb009a,0xbc7b009a,0x00000000}},	//   беж_, _הַכֶ, _לנית,
  { {0xb5aa0032,0xdb070024,0xdb0e00ea,0x00000000}},	//   ماتك_, zujú, rtbó,
  { {0x5fdd0053,0x7ae61310,0x59830085,0x00000000}},	//   _फैसल, _iakt, _пляб,
  { {0x6d4e192f,0xdb070066,0x3ea200ca,0x00000000}},	//   noba, xujú, hakt_,
  { {0xdb070066,0x7ae63af1,0xdc89009a,0x00000000}},	//   vujú, _kakt, חְפָ,
  { {0xa6b50076,0x6d4e0d12,0x7ae61c64,0x00000000}},	//   _осущ, hoba, _jakt,
  { {0x7ae66f2c,0xf74305c5,0xd4d6000d,0x00000000}},	//   _makt, _чето, _ніжэ,
  { {0xf55a0021,0x75d3014d,0x290a0130,0x00000000}},	//   _الطب_, _سيما, _joba_,
  { {0xdb1c6f2d,0x03a60002,0xdb070066,0x00000000}},	//   mtræ, _ѕидо, rujú,
  { {0x3f8a003d,0xdb1c0146,0xc7b30063,0x00000000}},	//   ību_, ltræ, עבר_,
  { {0xdb070066,0x25a66f2e,0x4ea40085,0x00000000}},	//   pujú, nsol_, эрэа,
  { {0x6018011c,0x3ea2006f,0x98ba0080,0x00000000}},	//   _моля_, aakt_, ropě_,
  { {0xb5fd00c2,0x7ae66f2f,0xb09b016e,0x00000000}},	//   _izše, _bakt, _פיהר,
  { {0x60da005b,0x403b0063,0x7bc70ed5,0x00000000}},	//   letm, _לגוג, rtju,
  { {0x7ae66f30,0x7b180014,0x497549bb,0x00000000}},	// [f770] _dakt, _tíun, длас,
  { {0x290a00f3,0x60da6f31,0xe79b0021,0x00000000}},	//   _coba_, netm, مخصص_,
  { {0xdb1c6f32,0x7ae66f33,0x290a041f,0x00000000}},	//   strá, _fakt, _doba_,
  { {0x96550062,0xd763005d,0x8f8b009d,0x00000000}},	//   мълч, رنشی, צְבֵ,
  { {0x84e50bb2,0xa5091599,0xa2a00042,0x00000000}},	//   долж, жела_, _गज़्,
  { {0x290a00c2,0x7ae66f34,0x3ea200ca,0x00000000}},	//   _goba_, _zakt, zakt_,
  { {0x67d41491,0xa3d200d7,0x61e26f35,0x00000000}},	//   _пору, војч, _asol,
  { {0x6d4e0035,0x27f8027d,0x25a6003b,0x00000000}},	//   zoba, šený_, bsol_,
  { {0x6d4e6f36,0xc2450065,0x3ea20829,0x00000000}},	//   yoba, ьник, vakt_,
  { {0x6fa90001,0x3ea200ca,0x9f8502b6,0x00000000}},	//   овог_, wakt_, мгод,
  { {0x61e26f37,0x6d4e00a8,0xd009173e,0x00000000}},	//   _esol, voba, цене_,
  { {0x941f0058,0x63a5004c,0x521529c2,0x00000000}},	//   ışıy, áhnu, _одет,
  { {0x7ae60812,0x6d4e6f38,0x3ea206f1,0x00000000}},	//   _rakt, toba, rakt_,
  { {0x68e708c4,0x7ae66f39,0xdb07004d,0x00000000}},	//   _najd, _sakt, hrjä,
  { {0x3ea206aa,0x290a6f3a,0x6d4e67ca,0x00000000}},	//   pakt_, _roba_, roba,
  { {0x8f9a01d8,0xc0520063,0xbec8001c,0x00000000}},	//   _ויקי, _שזה_, _brīž,
  { {0xc3320063,0x7ae66f3b,0x00000000,0x00000000}},	// [f780] דון_, _vakt,   ,
  { {0x7ae608f0,0x8ccd0053,0xe81a009e,0x00000000}},	//   _wakt, द्दो, يزات_,
  { {0x3ce70235,0x7ae61600,0x46ea03d6,0x00000000}},	//   _छोटे_, _takt, жден_,
  { {0x7ae60051,0x7d1e6de8,0xe7376f3c,0x00000000}},	//   _uakt, _hlps, мех_,
  { {0x056a0635,0x290a6f3d,0xa5da0067,0x00000000}},	//   ојки_, _toba_, تبار_,
  { {0x3ea0007a,0xa3ea0161,0xa5070001,0x00000000}},	//   _leit_, मिल_, деља_,
  { {0xdb1c0146,0x25a66f3e,0x73c300de,0x00000000}},	//   rtræ, ssol_, نيوم,
  { {0xdb1c1c23,0x25a62660,0x6aa41158,0x00000000}},	//   stræ, psol_, naif,
  { {0xdb1c2118,0xb355005d,0xd5d60044,0x00000000}},	//   mträ, ریها_, _تتأث,
  { {0x3d0d0053,0x6aa40035,0x7b180014,0x00000000}},	//   _सकें_, haif, _síul,
  { {0x60da005b,0x39840137,0x3ea06f3f,0x00000000}},	//   retm, _lös_, _beit_,
  { {0xdb1c0832,0x672200fe,0x7d1e3715,0x00000000}},	//   nträ, nhoj, _alps,
  { {0xdb1c004d,0x2d8000dd,0x91b70043,0x00000000}},	//   iträ, _cuie_, _قطور_,
  { {0xdb1c0244,0xa3e30042,0x00000000,0x00000000}},	//   hträ, _पैड_,   ,
  { {0x3ea00179,0xead50121,0xdb1c00a5,0x00000000}},	//   _feit_, новь, kträ,
  { {0x61ed00eb,0xa3b60053,0x25a936ef,0x00000000}},	//   _šali, _जिन_, šali_,
  { {0x5d670121,0x2ee96f40,0xaa580054,0x00000000}},	// [f790] _отоз, _iaaf_, диту_,
  { {0x3ea00199,0xdb1c004d,0x00000000,0x00000000}},	//   _zeit_, eträ,   ,
  { {0x636500ea,0xdb1c004d,0x9b590131,0x00000000}},	//   lóne, fträ, _ниот_,
  { {0x19950475,0x39840014,0x6f0d6f41,0x00000000}},	//   _памя, _fös_, _joac,
  { {0x25a90027,0x2ee9053b,0x68e75792,0x00000000}},	//   éal_, _maaf_, _tajd,
  { {0x236601c2,0x2edc0053,0x659201ce,0x00000000}},	//   _ahoj_, _बस्त, ћају,
  { {0x3946006c,0xc7c41f1d,0x8699012c,0x00000000}},	//   éose_, _исти, _нквс_,
  { {0x213e0034,0xc2c50021,0x2d842de9,0x00000000}},	//   enth_, ريخي, ímek_,
  { {0x91350086,0x3ea04303,0x28cf0053,0x00000000}},	//   ехні, _reit_, स्थि,
  { {0x3ea0601a,0x636505ec,0xa156005e,0x00000000}},	//   _seit_, dóne, нању_,
  { {0xdb1c0093,0x2d8000dd,0x7b180046,0x00000000}},	//   ltrå, _suie_, _síum,
  { {0x6f0d1033,0x28cf0053,0xe28e005e,0x00000000}},	//   _coac, स्ति, _ља_,
  { {0x3ea00627,0xdb1c00a5,0xf2d2009d,0x00000000}},	//   _veit_, ntrå, _תעד_,
  { {0x3ea000bd,0xc0e200d7,0x52380021,0x00000000}},	//   _weit_, _бошк, _تسمح_,
  { {0x6aa436b2,0x3ea00072,0x8c433ba4,0x00000000}},	//   taif, _teit_, гере,
  { {0x62896f42,0x26dd0022,0x00000000,0x00000000}},	//   nceo, jewo_,   ,
  { {0xaa460088,0x6aa4001f,0x718c0047,0x00000000}},	// [f7a0] хеал, raif, ַװאַ,
  { {0xdb1c1778,0xebe6076a,0xfce601ce,0x00000000}},	//   dtrå, _зооп, _џоно,
  { {0x2cac0026,0xdb1c0989,0xfaa600fb,0x00000000}},	//   óddu_, tträ, _пано,
  { {0xe5c61379,0x6d5c6f43,0x44270023,0x00000000}},	//   еско, llra, dzn_,
  { {0xdb1c2063,0x0f370041,0xceb303c3,0x00000000}},	//   rträ, ערנט_, ריד_,
  { {0x2b406f44,0x53e60432,0xdb1c0502,0x00000000}},	//   lnic_, ециа, strä,
  { {0xdb1c0137,0x6d5c0014,0xd9430962,0x00000000}},	//   pträ, ilra, _сери,
  { {0x6d5c004d,0x722a0456,0x2b406f45,0x00000000}},	//   hlra, зцов_, nnic_,
  { {0x2b4000dd,0xe1d70085,0x9f4b004c,0x00000000}},	//   inic_, едыі_, íbí_,
  { {0x2b4067ab,0x6d5c00b9,0x645e0124,0x00000000}},	//   hnic_, jlra, ýpis,
  { {0x44382ddc,0x657a00ac,0x6f0d6c3f,0x00000000}},	//   _är_, _iith, _poac,
  { {0x657a04bf,0x9f350054,0x6d5c181a,0x00000000}},	//   _hith, темі, elra,
  { {0x657a0035,0xe3370047,0x67d3004c,0x00000000}},	//   _kith, _אראפ_, mějš,
  { {0x6365006d,0x26dd0022,0x6286005f,0x00000000}},	//   róne, zewo_, žkod,
  { {0x7b670121,0x78a50072,0x7e643c07,0x00000000}},	//   етае, vahv, _ezip,
  { {0x67d30080,0x3df50002,0x645a0b19,0x00000000}},	//   nějš, _азис, _myti,
  { {0x7b640076,0x645a0006,0x78a5004b,0x00000000}},	// [f7b0] утре, _lyti, tahv,
  { {0x3da4005a,0x2b406f46,0x63b80734,0x00000000}},	//   _сръб, anic_, krvn,
  { {0x78a50019,0xe8df0013,0xe944212b,0x00000000}},	//   rahv, _ngục_, ухто,
  { {0x657a0027,0xf7700242,0x8ccd0053,0x00000000}},	//   _aith, مان_, द्रो,
  { {0x7aed6f47,0x7afd6f48,0x55e50f8d,0x00000000}},	//   mdat, _inst, толб,
  { {0xdbdd007a,0xdb1c00b9,0x7aed6f49,0x00000000}},	//   ráæt, rtrå, ldat,
  { {0x7aed26a2,0xdb070014,0xdb1c0246,0x00000000}},	//   odat, drjú, strå,
  { {0x7aed6f4a,0x657a04bf,0x5275065b,0x00000000}},	//   ndat, _eith, купу,
  { {0x225900b9,0x657a0139,0x7aed6f4b,0x00000000}},	//   æsk_, _fith, idat,
  { {0x62890139,0x70850062,0x657a266a,0x00000000}},	//   sceo, ъгоз, _gith,
  { {0x69cd0019,0x34943d57,0x28c60053,0x00000000}},	//   htae, _сахр, र्टि,
  { {0xa295019d,0x7afd00d1,0x61ed005f,0x00000000}},	//   _раді, _nnst, _šalu,
  { {0xf7720ca4,0x7aed6f4c,0xd00e007e,0x00000000}},	//   יקט_, ddat, ملی_,
  { {0x7aed6f4d,0xdbdc0014,0x7afd6f4e,0x00000000}},	//   edat, _báða, _anst,
  { {0xa1560001,0x2b406f4f,0xdb1c0046,0x00000000}},	//   _шаљу_, tnic_, luré,
  { {0x7aed002c,0x3a3f14cb,0x0b431afc,0x00000000}},	//   gdat, _župa_, ансн,
  { {0x2b406f50,0x60260003,0xe8ea01d5,0x00000000}},	// [f7c0] rnic_, _témé, ммад_,
  { {0xa92324fe,0x7afd6f51,0xf1b90078,0x00000000}},	//   адул, _enst, irš_,
  { {0x657a0d5d,0x2b401035,0x69cd04aa,0x00000000}},	//   _rith, pnic_, atae,
  { {0x7521004d,0xa855005e,0x645a6f52,0x00000000}},	//   _allz, утуј, _ryti,
  { {0x67d302f4,0xd7070062,0x4ead0047,0x00000000}},	//   vějš, ънце_, לבאַ,
  { {0xd9461f1d,0x645a002b,0xda4b009a,0x00000000}},	//   _реги, _pyti, _חֲלָ,
  { {0x67d30080,0x7bce051b,0x657a00a5,0x00000000}},	//   tějš, ntbu, _vith,
  { {0x657a0034,0x645a01c2,0x7b2c0058,0x00000000}},	//   _with, _vyti, mşus,
  { {0xdb1c0164,0x657a057a,0x55e30bd8,0x00000000}},	//   guré, _tith, _котб,
  { {0x657a6f53,0x7bce00b8,0x7aed1058,0x00000000}},	//   _uith, ktbu, zdat,
  { {0x61ed0006,0xdbe40003,0x7aed6f54,0x00000000}},	//   _šalt, héât, ydat,
  { {0x7aed1165,0xdbdc0014,0x41c30043,0x00000000}},	//   xdat, _ráða, دقیق,
  { {0xa3ea0053,0x7e470500,0x7aed6f55,0x00000000}},	//   मिक_, тхне, vdat,
  { {0xba3b0179,0xc27b0149,0x222b005d,0x00000000}},	//   _beïn, _חרדי, _غزنی_,
  { {0x636500ea,0x612400cd,0xd1381435,0x00000000}},	//   lóna, _còle, mią_,
  { {0xba3b00e8,0x69cd024a,0x2bb80032,0x00000000}},	//   _deïn, ttae, ضافة_,
  { {0x28a70076,0x7bce0f49,0x58d55432,0x00000000}},	// [f7d0] вшег, atbu, лоат,
  { {0x69cd6f56,0xd1381435,0x7aed0246,0x00000000}},	//   rtae, nią_, sdat,
  { {0xba3b0ac8,0x7aed1ebe,0x56950076,0x00000000}},	//   _geïn, pdat, гает,
  { {0x69cd007a,0x6f1d0337,0x7afd3114,0x00000000}},	//   ptae, nksc, _unst,
  { {0xd1380006,0x63650014,0xaa6717e2,0x00000000}},	//   kią_, jóna, _шток,
  { {0xe8940121,0x6365013d,0x6d556f57,0x00000000}},	//   _варь, dóna, noza,
  { {0x3f8a01a8,0x8882005d,0xd1380022,0x00000000}},	//   íbul_, _ایمن, dią_,
  { {0xdb1c0003,0x6f1d006f,0xbc7c0063,0x00000000}},	//   turé, jksc, ונות,
  { {0x6d5500ea,0x78b20026,0x3f5900be,0x00000000}},	//   koza, _ákvö, héus_,
  { {0x6f1d09fe,0x60094ae0,0x41051743,0x00000000}},	//   eksc, еном_, узов,
  { {0xdb1c0164,0x6d5500ea,0x29110331,0x00000000}},	//   suré, doza, _moza_,
  { {0x8fc4007e,0xba3b424d,0x8cd60053,0x00000000}},	//   گزین, _reïn, म्नो,
  { {0x2d840164,0xef1703d1,0xd1380022,0x00000000}},	//   ême_, умя_, bią_,
  { {0xd1380051,0x7c3a0066,0x7bce6f58,0x00000000}},	//   cią_, útro, ttbu,
  { {0xe0d20047,0x1c390121,0x9f060044,0x00000000}},	//   _לײג_, вять_, _موثو,
  { {0xa3b60161,0xba3b00cd,0x7d1c007d,0x00000000}},	//   _जिस_, _veïn, skrs,
  { {0x7bce27b9,0x6d550331,0xe9da27b8,0x00000000}},	// [f7e0] stbu, boza, эка_,
  { {0x28cf0053,0x8ca50053,0x2d950062,0x00000000}},	//   स्लि, करणो, _тръс,
  { {0x9b460021,0x636500ea,0xd6da0002,0x00000000}},	//   _مندو, zóna, етл_,
  { {0x4422008f,0x7b2c0075,0xd138056c,0x00000000}},	//   _āk_, rşus, zią_,
  { {0x35b6047e,0x363600f2,0x85b70c0a,0x00000000}},	//   ущес, دراس, هاوس_,
  { {0xb5fd00c2,0x29110e7c,0xa5071f89,0x00000000}},	//   _izšl, _goza_, леча_,
  { {0xd4990086,0x68ef0080,0x753800c2,0x00000000}},	//   трі_, řidá, rivz,
  { {0xd1380051,0xdc08001c,0xd378007d,0x00000000}},	//   wią_, dēļa, _opće_,
  { {0x86460001,0x79860035,0xc0ca0121,0x00000000}},	//   _снаж, _jukw, нуне_,
  { {0x79860035,0x63651a34,0x320a0022,0x00000000}},	//   _mukw, róna, ćby_,
  { {0xd1380c47,0x39570063,0x6aa6006f,0x00000000}},	//   rią_, רשים_, _oekf,
  { {0xd1380006,0xd24f007e,0xaf070002,0x00000000}},	//   sią_, _کنه_, учок,
  { {0x62826f59,0x6d556f5a,0x6f1d1c2a,0x00000000}},	//   _igoo, toza, rksc,
  { {0x2eed085a,0x5d6800de,0x9d4700de,0x00000000}},	//   žef_, ُمَّ_, ائحن,
  { {0xd5280013,0xa3ea0053,0x6d556f5b,0x00000000}},	//   _cổn, मिट_, roza,
  { {0xab62005b,0x25a0004c,0x00000000,0x00000000}},	//   şünc, šily_,   ,
  { {0xba3b006f,0x29114c36,0x2d84013d,0x00000000}},	// [f7f0] _geïl, _poza_, ímet_,
  { {0x68ee00cd,0x63650014,0x2d9900e5,0x00000000}},	//   _cabd, jónn, mpse_,
  { {0x7aee00fe,0x1a65007e,0x645e004b,0x00000000}},	//   öntä, _چیزی_, üpil,
  { {0xef1f005b,0x36d537ed,0x62826f5c,0x00000000}},	//   nkü_, родр, _ngoo,
  { {0x6365034d,0x3f660003,0x660537c4,0x00000000}},	//   fónn, _vœux_, рпла,
  { {0x66190022,0x6341008f,0xfbd0005d,0x00000000}},	//   rywk, mēni, _بتی_,
  { {0x6341001c,0x0d180063,0x59a90082,0x00000000}},	//   lēni, רקוט_, _चौतर,
  { {0xd2510021,0x5c380063,0x11d90021,0x00000000}},	//   ينغ_, טרון_, نوعة_,
  { {0x86270088,0x13060076,0x629b0006,0x00000000}},	//   _сьве, рный_, rbuo,
  { {0xdb1c0093,0x7aef1f6c,0x216901ce,0x00000000}},	//   strø, _lact, ђини_,
  { {0x63480080,0x52b50021,0x8fa50141,0x00000000}},	//   měnn, _نماذ, јаме,
  { {0x539a014e,0x25a00529,0xa8560063,0x00000000}},	//   _ייעו, ţile_, ייתה_,
  { {0x78b500c2,0x6365017c,0x9105066f,0x00000000}},	//   _odzv, lóno, _впле,
  { {0x78a70080,0x408700e1,0x59a90053,0x00000000}},	//   _nejv, _судб, _चौधर,
  { {0xbb560021,0x63650066,0x68ee2eba,0x00000000}},	//   لنسب, nóno, _rabd,
  { {0x68ee0360,0x0d860571,0x63650061,0x00000000}},	//   _sabd, _клин, zónn,

  { {0x88ca0054,0x7aef6f5d,0x2f5b009a,0x00000000}},	// [f800] клав_, _dact, _בדקנ,
  { {0x09030001,0xba3b016d,0xd528008b,0x00000000}},	//   опун, _geïm, _tổn,
  { {0x3f87007d,0x2ba50053,0x78a7007c,0x00000000}},	//   _junu_, गीदा, _dejv,
  { {0x3f87007a,0xb5aa0032,0x7a2c0164,0x00000000}},	//   _munu_, ناتك_, _côté,
  { {0x550605fb,0x5976000d,0x1a9b0047,0x00000000}},	//   ичка, _выву, _ביכע,
  { {0xb7960001,0xa5330086,0x67f0013d,0x00000000}},	//   _враћ, оніч, gójá,
  { {0xb2260026,0x4519000d,0xdb1c003b,0x00000000}},	//   kvæð, ыцця_, murâ,
  { {0xb02400aa,0x7ae46f5e,0x3eab6f5f,0x00000000}},	//   _ngườ, neit, xact_,
  { {0x69c46f60,0xdb1d00ea,0x64580022,0x00000000}},	//   nuie, ézés, _ścię,
  { {0x7bde02f6,0x3f8701f7,0x33d60086,0x00000000}},	//   _oppu, _bunu_, _відт,
  { {0x61eb0268,0xa2e61bdd,0x25ec0053,0x00000000}},	//   _esgl, _воед, _आईडी_,
  { {0x61240268,0xe29a6f61,0x7ae46f62,0x00000000}},	//   _dòla, _рад_, jeit,
  { {0x7ae4001f,0x7bde6f63,0xf1940121,0x00000000}},	//   deit, _appu, _уиль,
  { {0x7c844fc2,0x69c421cc,0x30a30062,0x00000000}},	//   жуте, duie, _дръв,
  { {0xfaa7000a,0x7ae46f64,0x7aef0530,0x00000000}},	//   ишан, feit, _pact,
  { {0xbb28000d,0x307b0063,0x61eb002b,0x00000000}},	//   ацуе_, _באונ, _ysgl,
  { {0x69c4048e,0x6d560026,0x7bde0290,0x00000000}},	// [f810] guie, ófað, _eppu,
  { {0x3ea95eb8,0xdb1c003b,0xa3d60082,0x00000000}},	//   _heat_, gurâ, ाझा_,
  { {0x7ae4061d,0x3ea90089,0x78a700b9,0x00000000}},	//   beit, _keat_, _vejv,
  { {0x7ae41c1f,0x69c4032c,0x778401dd,0x00000000}},	//   ceit, buie, іліз,
  { {0x3ea90034,0x69c4000c,0x67f000ea,0x00000000}},	//   _meat_, cuie, tójá,
  { {0x3ea9018d,0x6498005a,0x63655e77,0x00000000}},	//   _leat_, атър_, tóno,
  { {0xd7c9007e,0x6d474069,0x62860066,0x00000000}},	//   _حوزه_, inja, ľkon,
  { {0x68e500fe,0x63651078,0x3ea96f65,0x00000000}},	//   lehd, róno, _neat_,
  { {0x6348004c,0x9f52004c,0x3f876f66,0x00000000}},	//   měnl, ízí_, _sunu_,
  { {0x7ae400bd,0x3f87017f,0x6aad0717,0x00000000}},	//   zeit, _punu_, haaf,
  { {0x3ea92b71,0x7ae40035,0x14190021,0x00000000}},	//   _beat_, yeit, _حياة_,
  { {0x6d4706a7,0x2d8100fe,0x643a0047,0x00000000}},	//   enja, _aihe_, _געענ,
  { {0xdfce007e,0x32090058,0x7ae46f67,0x00000000}},	//   ويی_, _çay_, veit,
  { {0x40950032,0xb226007a,0x2d9e0a63,0x00000000}},	//   _الغر, svæð, ďte_,
  { {0x7ae46f68,0x3f80004b,0xab2a012d,0x00000000}},	//   teit, _tiiu_, гова_,
  { {0x6d471c80,0x8c430002,0x6aad006f,0x00000000}},	//   anja, чесе, gaaf,
  { {0x0dc9000a,0x6d47017f,0x6f043ea0,0x00000000}},	// [f820] _куќи_, bnja, _inic,
  { {0x7ae45241,0xdb0e0139,0x6341008f,0x00000000}},	//   seit, isbé, mēnu,
  { {0xf548008b,0x61e9071c,0xf9890063,0x00000000}},	//   hục_, hwel, תר_,
  { {0x61e96f69,0x99800024,0xd378007d,0x00000000}},	//   kwel, dziť_, _opća_,
  { {0x69c46f6a,0xdbe30014,0x09f60054,0x00000000}},	//   quie, _héða, _учня,
  { {0xdb1c004b,0x15b90085,0x61e93eee,0x00000000}},	//   htrü, рыцы_, dwel,
  { {0x63a4017f,0x61e96f6b,0x394f013d,0x00000000}},	//   ćino, ewel, égse_,
  { {0xfbd3014e,0x61e9002b,0x070c0053,0x00000000}},	//   פתח_, fwel, _सचिव_,
  { {0xc8cf0161,0x25690025,0x4420001c,0x00000000}},	//   स्कट, súla_, ņi_,
  { {0x3ea90034,0x644f0051,0x6f046f6c,0x00000000}},	//   _seat_, _ście, _anic,
  { {0x6d470198,0xf1b90024,0xb5fd0114,0x00000000}},	//   vnja, vyše_, _vyše,
  { {0x67220b4f,0x487b0063,0x2d81004d,0x00000000}},	//   nkoj, טטיס, _sihe_,
  { {0x6d47082a,0xe287007e,0x2018004b,0x00000000}},	//   tnja, _اطمی, ärib_,
  { {0xdb1c0066,0x7f83005d,0x3039005d,0x00000000}},	//   ktró, _کلين, اتیک_,
  { {0x672200fe,0x6aad006f,0x6d4708ed,0x00000000}},	//   kkoj, taaf, rnja,
  { {0xeafb007e,0x213e33ca,0x7b180046,0x00000000}},	//   درست_, lith_, _síur,
  { {0x5939000d,0x201e0006,0x91bb0047,0x00000000}},	// [f830] азаў_, lyti_, ָמבי,
  { {0x6d40317d,0x6722001c,0x798d2630,0x00000000}},	//   émat, ekoj, rqaw,
  { {0x201e0078,0x68e50072,0x286b005e,0x00000000}},	//   nyti_, rehd, урао_,
  { {0xcf930047,0x68e500fe,0x7bc70089,0x00000000}},	//   לטע_, sehd, muju,
  { {0xd5bb6f6d,0x62860066,0xff7c0041,0x00000000}},	//   усе_, ľkol, אטאמ,
  { {0x201e00eb,0x0395042c,0x672200c2,0x00000000}},	//   kyti_, ория, akoj,
  { {0xdb1c6f6e,0x7bc71f38,0x7bd5004d,0x00000000}},	//   ctró, nuju, ntzu,
  { {0x201e00eb,0xb06500fe,0x213e0d17,0x00000000}},	//   dyti_, hdää, eith_,
  { {0x7bc70228,0x61e94a36,0xe6130021,0x00000000}},	//   huju, uwel, _عشر_,
  { {0xe0d60076,0x7bc76f6f,0x61e96f70,0x00000000}},	//   овь_, kuju, rwel,
  { {0x7bc76f71,0xddc4003b,0xa93a0063,0x00000000}},	//   juju, _oziţ, שתתפ,
  { {0xb5fd00c2,0x213e402d,0x7bc76f72,0x00000000}},	//   _azši, aith_, duju,
  { {0x9267006a,0x20d50086,0x7e6d0022,0x00000000}},	//   _ادام, _дійс, _czap,
  { {0x7bd5004d,0x23dd0042,0xdb1c6f73,0x00000000}},	//   ftzu, _महाद, durá,
  { {0x30790047,0xe1f90006,0x0caa0053,0x00000000}},	//   _דאַנ, lvų_, _क़ीम,
  { {0x6f044350,0xff52007e,0x612d6f74,0x00000000}},	//   _unic, _تخت_, _búlg,
  { {0x7bc70006,0x395a6f75,0xdb1c66c8,0x00000000}},	// [f840] auju, tops_, gurá,
  { {0x67296f76,0xd910007e,0xa3ba0053,0x00000000}},	//   _alej, ریز_, _अटल_,
  { {0x7bc7007d,0x6d5c2822,0x67222c17,0x00000000}},	//   cuju, mora, tkoj,
  { {0xd6d90086,0xa0260213,0xdb1c00ea,0x00000000}},	//   йті_, ltöö, rtró,
  { {0x6d5c67c7,0xa026004b,0x7af60078,0x00000000}},	//   oora, otöö, mdyt,
  { {0xdb1c0994,0x7af600eb,0x672900ea,0x00000000}},	//   ctrò, ldyt, _elej,
  { {0x7af60006,0x66e60044,0xf2c60054,0x00000000}},	//   odyt, _وأرق, оспн,
  { {0x7af600eb,0x672900c3,0xe61a000d,0x00000000}},	//   ndyt, _glej, _кдб_,
  { {0x90d5008b,0x7bc7007d,0x5a170047,0x00000000}},	//   rìn, zuju, ַקטן_,
  { {0x201e00eb,0x6d5c6f77,0x7af60072,0x00000000}},	//   tyti_, jora, hdyt,
  { {0x291806bb,0x7af60006,0x7e6d00ea,0x00000000}},	//   _mora_, kdyt, _szap,
  { {0x201e00eb,0x6d5c0360,0xd5280013,0x00000000}},	//   ryti_, eora, _hồn,
  { {0x201e00eb,0x7bc7053b,0x3f98001c,0x00000000}},	//   syti_, wuju, ūru_,
  { {0x7bc72c8d,0x29186f78,0x612d0139,0x00000000}},	//   tuju, _nora_, _cúld,
  { {0x7bd5004d,0x2aab005e,0xd5280013,0x00000000}},	//   utzu, итао_, _mồn,
  { {0x7bc71f06,0x6d400003,0x7bd5004d,0x00000000}},	//   ruju, émar, rtzu,
  { {0x29180035,0x7bd500bd,0x5a350189,0x00000000}},	// [f850] _bora_, stzu, чнат,
  { {0x6729001c,0x62860058,0xc86722c4,0x00000000}},	//   _slej, ıkoy, отеи,
  { {0x7af600eb,0xad27007e,0x67296f79,0x00000000}},	//   bdyt, _هرگو, _plej,
  { {0xd366006a,0xf77004f6,0xe1f90006,0x00000000}},	//   _سه_, نان_, yvų_,
  { {0xd246043b,0xc1780006,0x29186f7a,0x00000000}},	//   _أن_, kmė_, _fora_,
  { {0xd006043b,0x2918027c,0x7e60004b,0x00000000}},	//   _كل_, _gora_, ümpi,
  { {0x63656f7b,0x6729644d,0x61e26f7c,0x00000000}},	//   lóni, _tlej, _apol,
  { {0x67290146,0x13090086,0x61e20025,0x00000000}},	//   _ulej, сний_, _bpol,
  { {0x63650942,0x5159000d,0x95670062,0x00000000}},	//   nóni, йшоў_, _дъжд,
  { {0x2cb10051,0xe1f90078,0x6d5c1422,0x00000000}},	//   jazd_, rvų_, xora,
  { {0x6d5c6f7d,0x7f5d00cd,0x7af60072,0x00000000}},	//   vora, fosq, ydyt,
  { {0x68f50078,0x3f840014,0x635300dd,0x00000000}},	//   _lazd, ömu_, făne,
  { {0xa02600fe,0x63650026,0x42540002,0x00000000}},	//   ttöö, jóni, _отшт,
  { {0x6d5c00fe,0xc27a0063,0x865a0063,0x00000000}},	//   uora, _פרסי, מדרי,
  { {0xf092014e,0xa0260019,0x61e200a2,0x00000000}},	//   _אנו_, rtöö, _zpol,
  { {0xa0260004,0x63656f7e,0x69d600fe,0x00000000}},	//   stöö, fóni, ttye,
  { {0x29186f7f,0x61fb5e26,0x6d5c49b3,0x00000000}},	// [f860] _pora_, nvul, pora,
  { {0x61fb00fe,0x0e570063,0xdcb1008b,0x00000000}},	//   ivul, _משפט_, ửa_,
  { {0x29186377,0xe9ff008b,0x8706000d,0x00000000}},	//   _vora_, _tiếc_, зяле,
  { {0x69d600a4,0x62860066,0x96b701ce,0x00000000}},	//   ptye, ľkok, пуљу_,
  { {0x68f52d6f,0x29186f80,0x6286005f,0x00000000}},	//   _fazd, _tora_, žkok,
  { {0x63480080,0x644f0051,0x68f56f81,0x00000000}},	//   měni, _ścia, _gazd,
  { {0x61e24a00,0x69c41b25,0x3393030b,0x00000000}},	//   _spol, lrie, нащё,
  { {0xe73a005a,0xdb2418e6,0x77bb0063,0x00000000}},	//   _уеб_, érès, _למלח,
  { {0x68f5005b,0x61fb006f,0xc1740062,0x00000000}},	//   _yazd, gvul, млищ,
  { {0x859b0063,0x7d1a0137,0x61140054,0x00000000}},	//   _לשמו, ötsl, єдну,
  { {0x69c40199,0xdb1c00cd,0x6365006d,0x00000000}},	//   hrie, curç, zóni,
  { {0x69c4131d,0x612d0139,0xc1780078,0x00000000}},	//   krie, _cúlb, smė_,
  { {0xada4000d,0xddcf0078,0x61e20534,0x00000000}},	//   наўл, ždži, _upol,
  { {0xc16f019d,0x2d850019,0x14df0053,0x00000000}},	//   _її_, öle_, प्पण,
  { {0x68f502e2,0xdb070072,0x60db0063,0x00000000}},	//   _razd, ysjä, _הקונ,
  { {0x63653502,0xae9b0021,0x139b0047,0x00000000}},	//   tóni, _اضغط_, מבלע,
  { {0x69c4179d,0xdebc0063,0xd8e70062,0x00000000}},	// [f870] grie, _המחל, зцеп,
  { {0x63651e1a,0x9e67007e,0x320200fe,0x00000000}},	//   róni, _واکن, äkyy_,
  { {0x290701f7,0x68f5017f,0x6365006d,0x00000000}},	//   ına_, _vazd, sóni,
  { {0x63650e7c,0x69c46f82,0xdb070072,0x00000000}},	//   póni, brie, usjä,
  { {0x69c46f83,0xd5280013,0xbafa009a,0x00000000}},	//   crie, _sốn, _והרש,
  { {0x85e80086,0xba3b01a8,0x6592005e,0x00000000}},	//   ядів_, _deït, њају,
  { {0xc9520063,0x00000000,0x00000000,0x00000000}},	//   _סמל_,   ,   ,
  { {0xb4ac0053,0xf773007e,0x34db007e,0x00000000}},	//   _कड़ी_, _ساز_, _گذرد_,
  { {0xdb24000f,0x201800fe,0x61fb0072,0x00000000}},	//   érés, ärin_, uvul,
  { {0x61fb6f84,0x63650014,0xa156005e,0x00000000}},	//   rvul, jónv, мању_,
  { {0x69c40024,0x916c008b,0xceea3ba6,0x00000000}},	//   zrie, uốn_, одне_,
  { {0xe28e6f85,0xd5d10235,0x26cf00bb,0x00000000}},	//   _ја_, _समाज, nggo_,
  { {0xb5fd0024,0xbebb005f,0xe0ce0af0,0x00000000}},	//   _myšo, okëj, _ив_,
  { {0x69c427c6,0xe045005e,0xac0a16b4,0x00000000}},	//   vrie, _онли, онга_,
  { {0x69c40185,0x2f560092,0xeb971326,0x00000000}},	//   wrie, _отис, дис_,
  { {0x61ed0006,0x69c42280,0xfaf5071f,0x00000000}},	//   _šaly, trie, нчую,
  { {0x79870122,0xf2d200b5,0x59860002,0x00000000}},	// [f880] _bijw, כען_, длаб,
  { {0x69c407b9,0x6d8b0023,0xb5fd01c8,0x00000000}},	//   rrie, _pļav, _pyšn,
  { {0x28dd0053,0x8b950121,0x5fc50042,0x00000000}},	//   न्धि, _пряч, _विफल,
  { {0x9f5d027d,0x86460002,0x78ae6f86,0x00000000}},	//   _prvé_, мнеж, _webv,
  { {0x3f7b0041,0xdb1c181a,0xd90d0043,0x00000000}},	//   קאנס, ftrö, _گیل_,
  { {0x6d4e00bd,0x628b013d,0xdb0e004d,0x00000000}},	//   nnba, _aggo, hrbü,
  { {0x32190072,0x6d4e1417,0x9294082d,0x00000000}},	//   äsyn_, inba, найц,
  { {0xd7030062,0xba3b0983,0x6d4e004d,0x00000000}},	//   _изси, _geïs, hnba,
  { {0x6365007a,0x966303ec,0x51f80086,0x00000000}},	//   jónu, _акте, їною_,
  { {0x6d4e006f,0xb5fd0114,0xd130014d,0x00000000}},	//   jnba, _myšl, امد_,
  { {0xe29a000d,0x00000000,0x00000000,0x00000000}},	//   _дае_,   ,   ,
  { {0x6d4e0524,0xd80b0063,0x43930054,0x00000000}},	//   enba, קִיָ, _раїс,
  { {0xde64005a,0xbe380085,0x23ba0023,0x00000000}},	//   върп, дзях_, līj_,
  { {0x6353000c,0x6d4e00d1,0xdb15013d,0x00000000}},	//   măna, gnba, mszé,
  { {0xd30f008b,0x212b0003,0xe2f500c2,0x00000000}},	//   _mệnh_, êche_, ščeš_,
  { {0xd30f008b,0x79a70002,0x6d4e6f87,0x00000000}},	//   _lệnh_, држе, anba,
  { {0x09750121,0x63650139,0xfb8402dc,0x00000000}},	// [f890] егаю, mónt, тырн,
  { {0x6e200137,0xdb070014,0xe6a70053,0x00000000}},	//   ämbe, nsjú, खर्ज,
  { {0xe610007e,0x58d405cf,0xfecb009a,0x00000000}},	//   یشه_, тохт, ַמַּ,
  { {0x7c280093,0xcaa700f2,0xcad5009d,0x00000000}},	//   ødre, _تصدي, _אוֹת_,
  { {0xd30f001b,0x65940054,0xdb1c00a5,0x00000000}},	//   _bệnh_, вачу, ttrö,
  { {0x7aed0dfc,0xc4c90053,0x29350047,0x00000000}},	//   leat, रलेख, _טאָן_,
  { {0xdb1500ea,0xdb1c0989,0xc8640121,0x00000000}},	//   eszé, rtrö, _атти,
  { {0x7bc70019,0xdb1c6f88,0x7aed4350,0x00000000}},	//   irju, orrá, neat,
  { {0x6d4e00ac,0xa2d00053,0xdb1c00be,0x00000000}},	//   ynba, _धार्, ctrõ,
  { {0x7aed6f89,0xb6cc0058,0xf8af0082,0x00000000}},	//   heat, _çürü, टरिय,
  { {0xd009293a,0x3f8965d8,0x7aed6f8a,0x00000000}},	//   чене_, _biau_, keat,
  { {0xdb1c0164,0x7aed00a8,0x69cd004b,0x00000000}},	//   ntrô, jeat, kuae,
  { {0x7bc76f8b,0xa2270044,0x7aed008e,0x00000000}},	//   erju, _تراه, deat,
  { {0x721a0063,0x5274007e,0x6d8b008f,0x00000000}},	//   _מונח, _شانز, _aļas,
  { {0x7aed0034,0x98ba000c,0x63650026,0x00000000}},	//   feat, hipă_, sónu,
  { {0x62860024,0x7aed31ed,0x6a860002,0x00000000}},	//   ľkov, geat, елба,
  { {0x612400cd,0x7bc7004b,0x69cd004b,0x00000000}},	// [f8a0] _sòli, arju, guae,
  { {0xb5fd0114,0x612401a8,0x291c0014,0x00000000}},	//   _vyšl, _pòli, ðva_,
  { {0xacd70047,0x61460003,0xdb1c0025,0x00000000}},	//   _אויפ_, _hélè, arrá,
  { {0x60c60006,0x7bce1cc7,0x7d1e00a5,0x00000000}},	//   ėkmi, mubu, _hops,
  { {0x7d1e003d,0x7bce192e,0xfb1b0041,0x00000000}},	//   _kops, lubu, _זוכמ,
  { {0x66030001,0xdb15013d,0x24f7014b,0x00000000}},	//   упља, vszé, еншы_,
  { {0x7bce6f8c,0xe4a50086,0xdb1c0014,0x00000000}},	//   nubu, тріо, durú,
  { {0xb7db0063,0xdb15013d,0xdb1c00be,0x00000000}},	//   _מקלי, tszé, ctrô,
  { {0x3f89028d,0x612d0024,0x32022f42,0x00000000}},	//   _riau_, _súla, íky_,
  { {0x7bc70026,0x7bce3a2c,0xd4910013,0x00000000}},	//   yrju, kubu, _hàn_,
  { {0x39960146,0x7bce00a8,0x6ab60014,0x00000000}},	//   _læs_, jubu, kayf,
  { {0xe2920032,0xceeb0021,0xd378007d,0x00000000}},	//   _إذا_, أردن_, _opći_,
  { {0x61460164,0x5ce70086,0xd4910013,0x00000000}},	//   _célè, нюва, _màn_,
  { {0x7bc700c3,0xc05a0086,0x71770086,0x00000000}},	//   trju, _ній_, _збір_,
  { {0x7aed52fb,0xd4910013,0x3eb201a8,0x00000000}},	//   teat, _oàn_, _feyt_,
  { {0xdb076f8d,0x98ad00c2,0x9f5d011b,0x00000000}},	//   nsjø, čoči_, _krví_,
  { {0xf99303eb,0xda34000d,0x6f0d516f,0x00000000}},	// [f8b0] ابر_, геты, _inac,
  { {0x7bce1362,0xb9c40021,0x3eb20244,0x00000000}},	//   bubu, اقلي, _zeyt_,
  { {0x7aed0898,0xd4910013,0x6348004c,0x00000000}},	//   peat, _bàn_, něns,
  { {0xdcfe000c,0x99890066,0x6d476f8e,0x00000000}},	//   _tipă, dzať_, lija,
  { {0xf770002a,0xd491008d,0xf6d4005d,0x00000000}},	//   حال_, _dàn_, ازمد,
  { {0xe4c20076,0x05770021,0xcd980063,0x00000000}},	//   айши, راشد, עדות_,
  { {0xdce4001c,0x6f0d006f,0x14d20053,0x00000000}},	//   _etiķ, _onac, _सारण,
  { {0x6d4723ce,0x53320002,0x05c90042,0x00000000}},	//   hija, иејт, _रिपब,
  { {0x4429003d,0xc692014e,0x6d476f8f,0x00000000}},	//   ņa_, _כאן_, kija,
  { {0x63650124,0x3eb2004d,0x41020085,0x00000000}},	//   tóns, _seyt_, азьв,
  { {0x7bdc00c7,0x7d1e007d,0xd4910013,0x00000000}},	//   xtru, _rops, _hào_,
  { {0x7d1e017f,0x65632fb8,0x0caa0042,0x00000000}},	//   _sops, lonh, कर्म,
  { {0xb6ba014e,0x7d1e0be7,0x44276f90,0x00000000}},	//   וצרי, _pops, lyn_,
  { {0x7bce6f91,0x6f0d58f8,0x2360074f,0x00000000}},	//   tubu, _enac, čije_,
  { {0x44276f92,0xcb94007e,0x236d6f93,0x00000000}},	//   nyn_, اهرک, olej_,
  { {0x6d470035,0xef26005b,0x7bce27da,0x00000000}},	//   aija, çüde_, rubu,
  { {0xd491001b,0xe9da15d4,0x6d476f94,0x00000000}},	// [f8c0] _nào_, ька_, bija,
  { {0x4427021f,0x6f0d427f,0x6ab6005b,0x00000000}},	//   kyn_, _znac, sayf,
  { {0x61fc001c,0x2cb8166e,0x6f0d002b,0x00000000}},	//   ārli, mard_, _ynac,
  { {0x44270185,0x2cb8597c,0xe5c613d3,0x00000000}},	//   dyn_, lard_, вско,
  { {0x45f30021,0x7413007e,0x96630121,0x00000000}},	//   لأوس, یوها, акце,
  { {0x44270185,0x5558000d,0x63750078,0x00000000}},	//   fyn_, эаля_, _išny,
  { {0x4427001f,0x68fc62f5,0xdb0704aa,0x00000000}},	//   gyn_, _iard, tsjø,
  { {0x51f80055,0x236d00c3,0x6d476f95,0x00000000}},	//   ению_, glej_, zija,
  { {0x8755005a,0xdb0700d1,0xcb130063,0x00000000}},	//   _сърц, rsjø, שלח_,
  { {0x44270185,0x65630016,0x25a63b40,0x00000000}},	//   byn_, conh, mpol_,
  { {0x63a4017f,0x3013000d,0x44380070,0x00000000}},	//   ćins, адэр, _år_,
  { {0xe9ff0013,0x68fc6f96,0xc2460131,0x00000000}},	//   _giặc_, _lard, _инек,
  { {0x62860024,0xa2d70161,0xb5fd0006,0x00000000}},	//   ľkos, _यात्, _ryšk,
  { {0x2cb804bc,0x62861994,0x68fc332e,0x00000000}},	//   gard_, žkos, _nard,
  { {0xa5cc0161,0x256900ea,0xd00f0021,0x00000000}},	//   _समझौ, múlt_, _وله_,
  { {0x6f0d075a,0x8b080080,0x68fc0276,0x00000000}},	//   _unac, vyří, _aard,
  { {0x27ea00f3,0x68fc2cd0,0x3eb9324f,0x00000000}},	// [f8d0] _apbn_, _bard, mast_,
  { {0xacf50138,0x3da4005a,0x442700fe,0x00000000}},	//   _спољ, _тръб, yyn_,
  { {0xdb1500ea,0x6563013d,0x6720055f,0x00000000}},	//   lszí, vonh, _bomj,
  { {0xdbd10004,0x65951d27,0x44270ef1,0x00000000}},	//   _müüg, гаду, vyn_,
  { {0x44272415,0x7afd000c,0x24e90121,0x00000000}},	//   wyn_, _iast, емли_,
  { {0xd49100aa,0x2a3a00b5,0x3eb90019,0x00000000}},	//   _vào_, _טערמ, hast_,
  { {0xe2990597,0x3eb93fc2,0x656800b9,0x00000000}},	//   най_, kast_, _dkdh,
  { {0x8219000a,0x2cb80625,0x3eb9414f,0x00000000}},	//   ецот_, zard_, jast_,
  { {0x3eb910b5,0x442768c2,0x68fc1a8d,0x00000000}},	//   dast_, syn_, _yard,
  { {0x4427001f,0x629b2437,0x236d0a80,0x00000000}},	//   pyn_, scuo, slej_,
  { {0x7afd003b,0x9f860932,0x7e760022,0x00000000}},	//   _oast, лгод, _szyp,
  { {0x3eb90627,0x6d45139d,0x2cb8050b,0x00000000}},	//   gast_, _amha, ward_,
  { {0xd491001b,0xb0620019,0xc0e50189,0x00000000}},	//   _làm_, ääru, _болк,
  { {0x7afd1fc9,0x3eb9056f,0x2d8c10c8,0x00000000}},	//   _aast, aast_, öde_,
  { {0x7afd6f97,0x2cb86f98,0x3eb96f99,0x00000000}},	//   _bast, rard_, bast_,
  { {0x2cb80164,0x3eb96f9a,0x68fc012a,0x00000000}},	//   sard_, cast_, _sard,
  { {0x68fc6f9b,0xa3b30042,0x78b52b4e,0x00000000}},	// [f8e0] _pard, जीत_, _bezv,
  { {0x63ad0117,0x7afd6f9c,0x2e3b009a,0x00000000}},	//   ćanj, _east, _נגינ,
  { {0x78b50529,0x68fc2a05,0xddcd007d,0x00000000}},	//   _dezv, _vard, _izaš,
  { {0x7afd6f9d,0x47890086,0x68fc011f,0x00000000}},	//   _gast, всім_, _ward,
  { {0x75216f9e,0x68fc0419,0xe4e60454,0x00000000}},	//   _bolz, _tard, гійн,
  { {0x25a66f9f,0x7ae46fa0,0x68fc0d2d,0x00000000}},	//   rpol_, lfit, _uard,
  { {0x25bf003b,0xb795005e,0x25a66fa1,0x00000000}},	//   _evul_, _врућ, spol_,
  { {0x7ae46fa2,0x61360003,0xfbac0053,0x00000000}},	//   nfit, _mâle, टीएम,
  { {0x3eb90705,0x2007001f,0xe4d60021,0x00000000}},	//   vast_, _arni_, _متاب,
  { {0xdcb1008b,0xdbd1004b,0x99f7009a,0x00000000}},	//   ửi_, _püüg, נזיה_,
  { {0x04930032,0x25a45f06,0x3eb93a92,0x00000000}},	//   _المح, _html_, tast_,
  { {0x32063183,0x88570041,0x539b009a,0x00000000}},	//   _troy_, רשטע_, _נידו,
  { {0x3eb96fa3,0x20070150,0x7afd1c43,0x00000000}},	//   rast_, _erni_, _rast,
  { {0x7afd6fa4,0x78a9007d,0x3eb96fa5,0x00000000}},	//   _sast, _đevo, sast_,
  { {0x3eb96fa6,0x8ca40053,0x1169007e,0x00000000}},	//   past_, कड़ो, _جلوی_,
  { {0xdb15013d,0xc5fe0023,0xa08b009d,0x00000000}},	//   pszí, ķēja_, _נְגִ,
  { {0x7afd6fa7,0x2b4959ab,0xcd34005d,0x00000000}},	// [f8f0] _vast, riac_, _گريب,
  { {0x2b490024,0x7afd6fa8,0xfe700044,0x00000000}},	//   siac_, _wast, _عدي_,
  { {0x7afd6fa9,0x798e00a3,0x6f1d0130,0x00000000}},	//   _tast, _dibw, ojsc,
  { {0x75216faa,0x8c1a089e,0x2d83013d,0x00000000}},	//   _solz, _סורי, lmje_,
  { {0xfad600b5,0x752100cd,0xeef80047,0x00000000}},	//   _דורך_, _polz, טמאר_,
  { {0x69cd0185,0x6fc50042,0x6d55004d,0x00000000}},	//   mrae, _विलं, nnza,
  { {0xc6a70d34,0xd5380021,0xa26200be,0x00000000}},	//   _брзи, دثنا_, çôni,
  { {0x13090065,0x66280260,0x03251cce,0x00000000}},	//   тний_, íská, рдин,
  { {0x11d60021,0xa2350085,0xd24e005d,0x00000000}},	//   لوية_, рэйш, وچه_,
  { {0x60090175,0x29015fa9,0x66096fab,0x00000000}},	//   вном_, ndha_, _irek,
  { {0x9fc90062,0xa2f512ab,0x66090046,0x00000000}},	//   ъгна_, _впеч, _hrek,
  { {0x6d55051e,0x200700c3,0x9f5d0024,0x00000000}},	//   enza, _vrni_, _prvá_,
  { {0x471a0063,0xe28e01e2,0xdb1c0046,0x00000000}},	//   דורג, _фа_, turþ,
  { {0x69cd0185,0x4f950002,0x61360003,0x00000000}},	//   drae, _криу, _pâle,
  { {0x29013e1c,0x20070ad5,0x6ab60a74,0x00000000}},	//   ddha_, _urni_, исах,
  { {0x29110035,0x6d556fac,0x9f5d0240,0x00000000}},	//   _anza_, anza, _trvá_,
  { {0xc8960095,0x3946195a,0x3ead0331,0x00000000}},	// [f900] арењ, анаг, ñete_,
  { {0x78bb0164,0xf0920047,0x7ae40b27,0x00000000}},	//   _œuvr, ַנד_, sfit,
  { {0x98aa000c,0x22a6004c,0xf71a0085,0x00000000}},	//   _albă_, líků_, кіды_,
  { {0x66092d27,0x95ca0785,0x69cd6b2c,0x00000000}},	//   _brek, вука_, brae,
  { {0x22a60080,0x6b84308d,0x2005004b,0x00000000}},	//   níků_, mmig, hvli_,
  { {0x7bce6fad,0x03c60818,0x6b840526,0x00000000}},	//   orbu, асим, lmig,
  { {0xdb1500ea,0xd4990086,0xdb1c004b,0x00000000}},	//   lszá, урі_, kurü,
  { {0x661600fe,0x6b846fae,0x66096faf,0x00000000}},	//   äyks, nmig, _frek,
  { {0x660902f0,0xdb1500ea,0x24f619da,0x00000000}},	//   _grek, nszá, _вчер,
  { {0x6b8400bd,0xf8b30041,0xd134005e,0x00000000}},	//   hmig, ֿשר_, сноћ,
  { {0xc2c6005d,0x88bb009a,0xb4d20042,0x00000000}},	//   _نياي, כזיי, वली_,
  { {0xdb1500ea,0x91e60713,0x69cd00a3,0x00000000}},	//   kszá, _воде, yrae,
  { {0x97570063,0x7bce1689,0x9df81406,0x00000000}},	//   שיכו_, erbu, анят_,
  { {0xd0d30062,0xc5f30063,0x6b8421ef,0x00000000}},	//   _дошъ, חדש_, emig,
  { {0xdb15013d,0xb17b016e,0x717b009a,0x00000000}},	//   eszá, _שטור, _שנוס,
  { {0x4ea700d7,0x69cd6fb0,0xdb1c0046,0x00000000}},	//   _трка, trae, duró,
  { {0xdb1500ea,0x63ad007d,0x6ce701dd,0x00000000}},	// [f910] gszá, ćani, _кіне,
  { {0x69cd0c78,0x28a7000d,0x6b846fb1,0x00000000}},	//   rrae, ршаг, amig,
  { {0xb8680002,0x69cd6fb2,0xf99f0013,0x00000000}},	//   ајце_, srae, _trèo_,
  { {0x66090648,0x7bd50058,0x69cd6fb3,0x00000000}},	//   _prek, muzu, prae,
  { {0x06c80086,0xd4910013,0xdb070014,0x00000000}},	//   ргій_, _hài_, ssjó,
  { {0xe4e70086,0x291c0137,0xbdf80063,0x00000000}},	//   рідн, övat_, שֶׁה_,
  { {0x7bd5005b,0x27fc00b9,0x0394000d,0x00000000}},	//   nuzu, ævnt_, орыя,
  { {0x66096fb4,0xd491008d,0xb0650072,0x00000000}},	//   _trek, _mài_, heää,
  { {0x13060076,0xe1f10021,0x16340076,0x00000000}},	//   сный_, سسة_, _детя,
  { {0x23e7019d,0x64a40001,0x24750013,0x00000000}},	//   _відв, _мађа, _t́m_,
  { {0xe8df008b,0xe1880021,0x612d6fb5,0x00000000}},	//   _ngọc_, جئين_, _júli,
  { {0x22950032,0x612d013d,0xd5c5071f,0x00000000}},	//   _الإس, _múli, _вiдн,
  { {0x52850021,0xa3b30082,0x00000000,0x00000000}},	//   _الشك, जीर_,   ,
  { {0xa0090032,0x6136003b,0x7bd51c8a,0x00000000}},	//   _مقتل_, _vâlc, fuzu,
  { {0xd491001b,0x201801cf,0x83fc008d,0x00000000}},	//   _bài_, ärit_, _hyđr,
  { {0xd491001b,0x2b9c0080,0xdb1500ea,0x00000000}},	//   _cài_, _víc_, tszá,
  { {0x3b07005a,0xd491008b,0x6b846fb6,0x00000000}},	// [f920] щето_, _dài_, rmig,
  { {0xdb15000f,0x6b841013,0x2d4d00a8,0x00000000}},	//   rszá, smig, lžen_,
  { {0xca290e2a,0xdb1500ea,0xdb0e01e1,0x00000000}},	//   עם_, sszá, ksbø,
  { {0x98b8005b,0x6d4e20fe,0xd6d90086,0x00000000}},	//   ızın_, liba, иті_,
  { {0x690100fe,0x291c0137,0x23950023,0x00000000}},	//   öydä, övas_, _māju_,
  { {0x6d4e6fb7,0xdb050003,0x7af60046,0x00000000}},	//   niba, _athè, leyt,
  { {0x69d6006d,0x29370047,0xccf30063,0x00000000}},	//   luye, _פאלן_, פכה_,
  { {0x236000c3,0xc2980001,0x66e320cc,0x00000000}},	//   čijo_, шких_, _носа,
  { {0x6d4e58eb,0x9406007e,0x69d64093,0x00000000}},	//   kiba, _گواه, nuye,
  { {0x6d4e00f3,0x86370063,0x7af60072,0x00000000}},	//   jiba, _הרמב_, heyt,
  { {0x7af64645,0x6d4e004e,0xe2ca2530,0x00000000}},	//   keyt, diba, _блед_,
  { {0xe29a0fe2,0x6d4e0229,0x7bd5005b,0x00000000}},	//   _сад_, eiba, vuzu,
  { {0x51860088,0x442e6fb8,0x78be00ac,0x00000000}},	//   _лука, lyf_, kapv,
  { {0xab950001,0x6d4e6fb9,0x394a00ca,0x00000000}},	//   жављ, giba, _nmbs_,
  { {0xdfa6013a,0x7c342046,0x442e00a3,0x00000000}},	//   _احتي, перх, nyf_,
  { {0x7bd50035,0x6d4e1207,0xb0650072,0x00000000}},	//   ruzu, aiba, seää,
  { {0xd491008b,0x7bd5004c,0x645c0046,0x00000000}},	// [f930] _vài_, suzu, _þrif,
  { {0x2be20053,0x442e00ac,0x6d4e5961,0x00000000}},	//   _पहचा, kyf_, ciba,
  { {0xd49100aa,0xaa950601,0x228f0075,0x00000000}},	//   _tài_, _минч, _kökü_,
  { {0x69d61cbe,0x291c0137,0x9a876fba,0x00000000}},	//   buye, övar_, _гугл,
  { {0x35e7019d,0x2cb200c7,0xceb40063,0x00000000}},	//   сцев, _ändå_, ליף_,
  { {0x2c830164,0xdb1c0014,0xa5091579,0x00000000}},	//   cédé_, lurð, река_,
  { {0x3ea20137,0x443300ed,0xdb056fbb,0x00000000}},	//   yckt_, áx_, _athé,
  { {0x6d4e0441,0x29036fbc,0x644f0051,0x00000000}},	//   ziba, _haja_, _ścis,
  { {0x612d00ea,0x290301cd,0x7c2e0022,0x00000000}},	//   _múlv, _kaja_, zybr,
  { {0xa508005e,0x95570049,0x29036fbd,0x00000000}},	//   _леђа_, _اخرا, _jaja_,
  { {0x3d1d0053,0xdb1c0014,0x29036fbe,0x00000000}},	//   माने_, kurð, _maja_,
  { {0x6d4e390b,0xb7da0149,0x3e8a1406,0x00000000}},	//   wiba, סקרי, ийно_,
  { {0x5fc50161,0xc332014e,0xaa7b0080,0x00000000}},	//   _विकल, _קוד_, _zbýv,
  { {0xd009183f,0x6d8b0022,0x201900de,0x00000000}},	//   _веке_, _mżaw, _نتبع_,
  { {0x69cb02dd,0x7af6024a,0x6d4e6d65,0x00000000}},	//   ágen, teyt, riba,
  { {0x69d602dd,0xdb1c0014,0x2d9301a8,0x00000000}},	//   tuye, gurð, _eixe_,
  { {0x7af6007a,0x29036fbf,0x394a005e,0x00000000}},	// [f940] reyt, _baja_, азао_,
  { {0x38cb006a,0x2903006d,0x69d66c2d,0x00000000}},	//   لامی_, _caja_, ruye,
  { {0xdb1c0026,0xeb9a0001,0x61fb004d,0x00000000}},	//   burð, _њим_, hwul,
  { {0x69d60164,0xeab20021,0x929d0022,0x00000000}},	//   puye, _تعد_, ydła,
  { {0xd491008b,0x6f04003b,0x442e001f,0x00000000}},	//   _màu_, _maic, wyf_,
  { {0x69c4003d,0x2d930003,0x6aa46fc0,0x00000000}},	//   msie, _xixe_, lcif,
  { {0x69c46fc1,0x78bc00ca,0x18790085,0x00000000}},	//   lsie, _ierv, _гётэ_,
  { {0x44200117,0x442e021f,0xc1b80086,0x00000000}},	//   ći_, ryf_, блих_,
  { {0x69c46fc2,0x316e0089,0x78bc6fc3,0x00000000}},	//   nsie, _pkfz_, _kerv,
  { {0x69c46fc4,0x308a0062,0xe7d10042,0x00000000}},	//   isie, ищно_, _हिमप,
  { {0xa2e60138,0x78bc6fc5,0x67220078,0x00000000}},	//   _можд, _merv, ojoj,
  { {0x69c46fc6,0x78bc6fc7,0x6f046fc8,0x00000000}},	//   ksie, _lerv, _caic,
  { {0xada4000d,0x35d20053,0x75280051,0x00000000}},	//   маўл, _सिफ़, _kodz,
  { {0x3af50013,0x236908ed,0x78bc6fc9,0x00000000}},	//   _ấp_, čaje_, _nerv,
  { {0x29036fca,0xdb1c0026,0x6f042336,0x00000000}},	//   _raja_, turð, _faic,
  { {0x2903014f,0x7528003d,0xbfa3008b,0x00000000}},	//   _saja_, _lodz, _miễ,
  { {0x78bc1643,0x69c4001c,0x2903006d,0x00000000}},	// [f950] _berv, gsie, _paja_,
  { {0x78bc6fcb,0x752858ac,0x6f040244,0x00000000}},	//   _cerv, _nodz, _zaic,
  { {0x29030004,0x78bc6fcc,0xc7c40121,0x00000000}},	//   _vaja_, _derv, дсчи,
  { {0x4439001c,0xdb140014,0x78bc00ca,0x00000000}},	//   _ās_, _þaða, _eerv,
  { {0x29030035,0x78bc386b,0xe945005d,0x00000000}},	//   _taja_, _ferv, _فرآی,
  { {0x75280051,0x64a560e2,0x78bc6fcd,0x00000000}},	//   _codz, чака, _gerv,
  { {0x7d050009,0x612d6fce,0x6136003b,0x00000000}},	//   _mahs, _múlt, _pâln,
  { {0xd6870062,0xbfa30013,0x78bc0740,0x00000000}},	//   _дузп, _diễ, _zerv,
  { {0xe4e70097,0xda0e0042,0x00000000,0x00000000}},	//   _міжн, सियत_,   ,
  { {0x75280045,0x213e0034,0x8a160063,0x00000000}},	//   _godz, ghth_, פחתו_,
  { {0x63ad007d,0x2d4d004c,0x3cf805a5,0x00000000}},	//   ćans, ržel_, verv_,
  { {0x6abd003b,0x547a0063,0x644300a8,0x00000000}},	//   _nesf, _הטעו, mzni,
  { {0x6f04001c,0x7d05005b,0x612d0014,0x00000000}},	//   _vaic, _bahs, _súlu,
  { {0xcfe9006a,0xdb1c0026,0x612d60c3,0x00000000}},	//   _هفته_, rsrí, _cúlt,
  { {0x799d0199,0x7aef005b,0x673b08c1,0x00000000}},	//   _ausw, _bbct, _oluj,
  { {0x3f67005a,0x69c46fcf,0x2f550121,0x00000000}},	//   _нищо_, tsie, _отыс,
  { {0x7f3b0063,0xdb1c0019,0x78bc6fd0,0x00000000}},	// [f960] _לעקו, kurö, _perv,
  { {0x6aa45fe4,0x60c11bb7,0x69c4376a,0x00000000}},	//   scif, nalm, rsie,
  { {0x78bc0ac8,0x75280045,0x69c43186,0x00000000}},	//   _verv, _rodz, ssie,
  { {0x78bc006f,0x69c4015e,0xe61a11ec,0x00000000}},	//   _werv, psie, йде_,
  { {0x60c1000f,0x9f5d0024,0x672200fe,0x00000000}},	//   kalm, _prvú_, rjoj,
  { {0x629900ac,0x994f005b,0x673b004b,0x00000000}},	//   _agwo, müş_, _eluj,
  { {0x60c100ea,0x673b006d,0xdb070137,0x00000000}},	//   dalm, _fluj, rsjö,
  { {0xbfa3008b,0x75280051,0xdce7007d,0x00000000}},	//   _viễ, _wodz, vojč,
  { {0x257603eb,0x60c10035,0x994f005b,0x00000000}},	//   _فهرس, falm, nüş_,
  { {0x64a3000a,0xe1ef0754,0xb0340690,0x00000000}},	//   _зафа, اسي_, днош,
  { {0x64430045,0x7d0500e3,0xc05701dd,0x00000000}},	//   czni, _rahs, зія_,
  { {0x60c10019,0x987b0063,0x7d050089,0x00000000}},	//   aalm, מריק, _sahs,
  { {0x0e340076,0x6abd1c4e,0xd259008f,0x00000000}},	//   еняю, _resf, paņa_,
  { {0x2ba700d7,0x60c10764,0x3f9c008f,0x00000000}},	//   зјав, calm, _tuvu_,
  { {0x961d003d,0x68e10046,0x317b009a,0x00000000}},	//   _izņe, _öldi, _האגד,
  { {0x905b009a,0x6d5c00a3,0x0a6b0131,0x00000000}},	//   _לכות, anra, брзи_,
  { {0x7d05005b,0x433b0047,0x612d00ea,0x00000000}},	// [f970] _tahs, צעמב, _túlt,
  { {0x673b000c,0x6abd00ac,0x9cf5000d,0x00000000}},	//   _sluj, _wesf, _ўзні,
  { {0x9735006a,0xed600006,0x673b6fd1,0x00000000}},	//   وکرا, ėžti_, _pluj,
  { {0xf77003eb,0x60c1121c,0x78a56fd2,0x00000000}},	//   هان_, zalm, schv,
  { {0xc1780006,0x7aed02e0,0x247c0013,0x00000000}},	//   klė_, mfat, _ảm_,
  { {0x64430244,0x7bd50e52,0x7aed6fd3,0x00000000}},	//   tzni, orzu, lfat,
  { {0x7bc72545,0x6286027d,0x60c16fd4,0x00000000}},	//   nsju, ýkon, valm,
  { {0x7aed6fd5,0x613f0003,0xe8940085,0x00000000}},	//   nfat, _mêle, _чась,
  { {0x7aed0185,0x45d400d7,0x60c16fd6,0x00000000}},	//   ifat, _потс, talm,
  { {0xe1250086,0x25ad00ca,0x7bc7004b,0x00000000}},	//   ємни, _itel_, ksju,
  { {0x60c11bb7,0xdb0e004d,0x9267005d,0x00000000}},	//   ralm, tsbü, _کدام,
  { {0xd24e04de,0xd3d80021,0x60c12d33,0x00000000}},	//   انی_, _ربما_, salm,
  { {0x60c10b16,0x612d0139,0x7aed1ede,0x00000000}},	//   palm, _dúlr, dfat,
  { {0x61e9405c,0x2d8a085a,0xdb140014,0x00000000}},	//   mtel, umbe_, ðaþj,
  { {0x8b96000a,0x7ff5007e,0x2b406533,0x00000000}},	//   драч, _آستا, thic_,
  { {0x7e76024a,0xf0920063,0xb0dd0053,0x00000000}},	//   _tyyp, _בנו_, _माँग,
  { {0x61e96fd7,0x7940004d,0x320d00e5,0x00000000}},	// [f980] ntel, _löwe, nvey_,
  { {0x2360074f,0x994f005b,0x718a0047,0x00000000}},	//   čiji_, rüş_, ַװײַ,
  { {0x2b400034,0x6b9e00a4,0xad1b0047,0x00000000}},	//   phic_, _uupg, _וויר,
  { {0x61e93ffb,0x7bdc11c1,0x0ab60021,0x00000000}},	//   ktel, muru, _تحدد,
  { {0x7bdc014f,0xb0dd0053,0xc178005f,0x00000000}},	//   luru, _मांग, ylė_,
  { {0x61e96fd8,0x200b0023,0xbbe9005d,0x00000000}},	//   dtel, ācij_, _بریم_,
  { {0x7bdc08f0,0xdce7001c,0xe73a0086,0x00000000}},	//   nuru, nojā, _дев_,
  { {0x61e96fd9,0x7bdc0089,0xc1b80a8f,0x00000000}},	//   ftel, iuru, плих_,
  { {0x9676000d,0x2d4d004c,0x61e96fda,0x00000000}},	//   _цыві, užek_, gtel,
  { {0x7bdc1668,0x2369074f,0x3ea9000c,0x00000000}},	//   kuru, čaja_, _sfat_,
  { {0xe8d70063,0x7bdc6d1f,0x7aed002b,0x00000000}},	//   וויר_, juru, yfat,
  { {0xdce7001c,0xdb1500ea,0x7bdc6fdb,0x00000000}},	//   dojā, sszú, duru,
  { {0x61e9000c,0x7e2b000d,0x925a0593,0x00000000}},	//   ctel, ціна_, _بشار_,
  { {0xd010007e,0xc05a0086,0x961d001c,0x00000000}},	//   _ملت_, _мій_, _uzņe,
  { {0x7bdc6fdc,0xdd9427b8,0x9f593d05,0x00000000}},	//   guru, тары, író_,
  { {0xd1381435,0x7bc70137,0x00000000,0x00000000}},	//   lką_, rsju,   ,
  { {0xf99f0994,0x0dbb006a,0x7aed28d7,0x00000000}},	// [f990] _què_, _باعث_, rfat,
  { {0x7aed6fdd,0xd138232c,0x7bdc1642,0x00000000}},	//   sfat, nką_, buru,
  { {0x25ad1a20,0x61e900ea,0xdca40002,0x00000000}},	//   _stel_, ztel, _шаќи,
  { {0x98bf01f7,0x290701b3,0xdc360047,0x00000000}},	//   ırın_, žna_, _נארט_,
  { {0xd2460032,0xfad60063,0x6b8d6fde,0x00000000}},	//   _إن_, _אורך_, mmag,
  { {0x38780026,0x0608000d,0x61e900ea,0x00000000}},	//   _fyrr_, ьнік_, vtel,
  { {0x6b8d6df3,0x36d516d9,0xd1380051,0x00000000}},	//   omag, _повр, dką_,
  { {0x61e96fdf,0x26cd007d,0xd1380022,0x00000000}},	//   ttel, _udeo_, eką_,
  { {0x61e91a20,0x51551804,0x7bdc6fe0,0x00000000}},	//   utel, етну, zuru,
  { {0x61e96fe1,0x320d6fe2,0x7bdc005b,0x00000000}},	//   rtel, rvey_, yuru,
  { {0x6d556fe3,0xdbd7021e,0x61e96fe4,0x00000000}},	//   diza, _jääv, stel,
  { {0x9f480146,0x61e96fe5,0x7bdc005b,0x00000000}},	//   _opnå_, ptel, vuru,
  { {0x6464000c,0x6d553bb3,0x3e850078,0x00000000}},	//   ătiţ, fiza, jūtį_,
  { {0xd1380051,0x7bdc6fe6,0xdce7008f,0x00000000}},	//   cką_, turu, tojā,
  { {0x629c0080,0x7bdc004b,0x6b8d0014,0x00000000}},	//   ěrov, uuru, fmag,
  { {0xc9aa000d,0x6d550089,0x6b8d00ea,0x00000000}},	//   звае_, aiza, gmag,
  { {0xe9da6fe7,0xfe720021,0xed5a0062,0x00000000}},	// [f9a0] яка_, _حدث_, _нои_,
  { {0x186a005a,0x6d551b38,0x6b8d6fe8,0x00000000}},	//   пази_, ciza, amag,
  { {0x5975000d,0x31360047,0x3d1d0053,0x00000000}},	//   тыту, ענעם_, मारे_,
  { {0xd1380022,0x16a70f56,0x8bd7009a,0x00000000}},	//   zką_, евци_, _אוטו_,
  { {0x63a1006c,0xd1380022,0xba9b03c3,0x00000000}},	//   _auln, yką_, _מסכי,
  { {0x96330088,0x83f83e42,0x2ebe0082,0x00000000}},	//   ыніц, декс_, ्णुत,
  { {0x769601f7,0x443a0013,0x27ef004c,0x00000000}},	//   _büyü, áp_, ělní_,
  { {0x290a15e7,0xfbd30063,0xf99f0003,0x00000000}},	//   _haba_, אתה_, _grès_,
  { {0xd250006a,0xdb1c0137,0xd1380051,0x00000000}},	//   شند_, msrä, tką_,
  { {0xd1380006,0xd1340001,0x69cb00be,0x00000000}},	//   uką_, тноћ, ágei,
  { {0xd1381265,0x6d556fe9,0x6b8d6fea,0x00000000}},	//   rką_, viza, ymag,
  { {0xde59000d,0xd1381265,0x290a6feb,0x00000000}},	//   дамі_, ską_, _laba_,
  { {0x6b430019,0x6d551073,0x6b650078,0x00000000}},	//   _jõge, tiza, jėga,
  { {0x10740076,0x463b0047,0x2360007d,0x00000000}},	//   _иллю, לעכע, čiju_,
  { {0x291f008b,0xa926008f,0x6d550cde,0x00000000}},	//   _đua_, iežā, riza,
  { {0x6b8d002c,0x6d556fec,0x79a71528,0x00000000}},	//   umag, siza, ерже,
  { {0x290a3d2e,0xdb1c0137,0x6b8d6fed,0x00000000}},	// [f9b0] _baba_, dsrä, rmag,
  { {0x3eb90199,0x6b8d5cbc,0xdbd70072,0x00000000}},	//   lbst_, smag, _pääv,
  { {0xb9090235,0xf99f0164,0x290a4e15,0x00000000}},	//   _या_, _près_, _daba_,
  { {0x613f0003,0x63a101e1,0xdb1c0137,0x00000000}},	//   _mêla, _ruln, gsrä,
  { {0x5b14005a,0xa5094345,0x6136003b,0x00000000}},	//   _смят, дела_, _tâlh,
  { {0xe3c50044,0x00000000,0x00000000,0x00000000}},	//   نْتَ,   ,   ,
  { {0xf99f03b2,0x3ce90053,0xf5320002,0x00000000}},	//   _très_, _जाने_, рејќ,
  { {0x9f5d0024,0x236900c3,0x3f89001b,0x00000000}},	//   _prvý_, čajo_, _nhau_,
  { {0x33920032,0x13060076,0xd49b0001,0x00000000}},	//   جليز, тный_, _ере_,
  { {0x63a10019,0x32da0075,0x442b030b,0x00000000}},	//   _tuln, tüyü_, _нцем_,
  { {0x3f6a46af,0xef8626b8,0x2d9a1098,0x00000000}},	//   дино_, клоп, _ripe_,
  { {0x3f89002b,0x32550a3a,0x00000000,0x00000000}},	//   _chau_, _ивер,   ,
  { {0x83360041,0x2d9a1b30,0x91e50481,0x00000000}},	//   _שאנס_, _pipe_, _роле,
  { {0x3afc0013,0x10a2005e,0xde0302f8,0x00000000}},	//   _ập_, _кишн, јпри,
  { {0x290a5060,0x40320002,0x60c30023,0x00000000}},	//   _raba_, _вејс, _ienm,
  { {0x290a6fee,0xf8b90013,0x6b63237c,0x00000000}},	//   _saba_, _đũa_, акса,
  { {0x60c34051,0xdb1c00c7,0x9e660086,0x00000000}},	// [f9c0] _kenm, vsrä, _швид,
  { {0x61360003,0xdb1c102d,0x3ce90053,0x00000000}},	//   _pâli, dsrå, _जाये_,
  { {0x290a0019,0x65f10047,0xc896005e,0x00000000}},	//   _vaba_, _געפֿו, трањ,
  { {0x7c210205,0x6b43004b,0x60c3559b,0x00000000}},	//   ålre, _põge, _lenm,
  { {0x7ae400a4,0x7bda6cda,0xdb1c0203,0x00000000}},	//   mgit, štud, gsrå,
  { {0x7ae40004,0xcdb70063,0x66020150,0x00000000}},	//   lgit, דפסה_, rwok,
  { {0x66020150,0xb9060042,0xf3660f63,0x00000000}},	//   swok, फल_, ктин,
  { {0xd5b2006a,0x7ae40e18,0xdcee00a8,0x00000000}},	//   _نفر_, ngit, dobč,
  { {0x7ae46b2f,0x6d800072,0x35a6218b,0x00000000}},	//   igit, töal, _разг,
  { {0x3ea00164,0xc3d6000d,0xe5060044,0x00000000}},	//   _agit_, _аўды, _جبري,
  { {0x60c36fef,0x41d40053,0x32060072,0x00000000}},	//   _denm, _दिवस, _wsoy_,
  { {0x60c30179,0x3eb90244,0xfbd30043,0x00000000}},	//   _eenm, ubst_, یتز_,
  { {0x3eb900bd,0x77621806,0x91e30054,0x00000000}},	//   rbst_, inox, _воче,
  { {0x799c1c6f,0x7ae46ff0,0x61e06ff1,0x00000000}},	//   _nirw, egit, muml,
  { {0x2d4d017f,0x60c81c38,0xead50363,0x00000000}},	//   džet_, madm, ловь,
  { {0xa0970063,0x7ae46ff2,0x60c8446e,0x00000000}},	//   _בדוק_, ggit, ladm,
  { {0x61e0005b,0xab940054,0x60c30058,0x00000000}},	// [f9d0] numl, риті, _yenm,
  { {0x58b80032,0xd8b80021,0x3ad3008b,0x00000000}},	//   نامج_, ندما_, ệp_,
  { {0xd7d50095,0x799c001f,0xf8070062,0x00000000}},	//   ужењ, _dirw, ъчан,
  { {0x2366017f,0x61e0001c,0x26c4007d,0x00000000}},	//   _njoj_, kuml, _cemo_,
  { {0x61e06ff3,0x60c80504,0x6d470072,0x00000000}},	//   juml, kadm, ohja,
  { {0x04c90021,0x3cdc0042,0xa3e92636,0x00000000}},	//   روبي_, _बाज़ा, едка_,
  { {0xe4e40086,0x6d4b0006,0x60c8069f,0x00000000}},	//   річн, _įgal, dadm,
  { {0x44290117,0x13050001,0x42090001,0x00000000}},	//   ća_, узим, енио_,
  { {0xdb1500ea,0x69cd002b,0x60c30ac9,0x00000000}},	//   lszó, nsae, _penm,
  { {0xea160047,0x60c80f07,0x29015a5f,0x00000000}},	//   אַטי_, gadm, neha_,
  { {0x68e50025,0xb5fd0078,0x6b650078,0x00000000}},	//   ighd, _ryšy, jėgo,
  { {0x29cf003d,0xe1f1007e,0xdb1500ea,0x00000000}},	//   kļa_, _هست_, gszü,
  { {0x8e5601dd,0x60c36ff4,0x8e550054,0x00000000}},	//   утні, _tenm, атрі,
  { {0xafe5005a,0x6b9d0025,0x2901007d,0x00000000}},	//   _бокл, _aisg, jeha_,
  { {0x65630031,0x7ae400d1,0x8c431527,0x00000000}},	//   innh, tgit, бере,
  { {0x2ee60121,0x7ae4004e,0x3b0704d6,0x00000000}},	//   _сжиг, ugit, лесо_,
  { {0x7ae40019,0x6b9d04bf,0x26c43ed4,0x00000000}},	// [f9e0] rgit, _disg, _remo_,
  { {0x7ae46ff5,0xcd060094,0x8288009d,0x00000000}},	//   sgit, _спой, דְעֶ,
  { {0x8c26006a,0x7ae40031,0x3ce90161,0x00000000}},	//   _صفحه, pgit, _जाते_,
  { {0x7bce0ca9,0x6aad0a02,0xe5c60121,0x00000000}},	//   msbu, ccaf, гско,
  { {0x660900ea,0x26c400c2,0x799c002b,0x00000000}},	//   _csek, _vemo_, _tirw,
  { {0x7bdc3339,0x15b9000d,0x5693005e,0x00000000}},	//   orru, тыцы_, љашт,
  { {0x0d17014e,0x26c43795,0xdc360047,0x00000000}},	//   טקסט_, _temo_, טאַט_,
  { {0x2481004b,0x395a0112,0x722a1e3b,0x00000000}},	//   ühma_, lips_, ецов_,
  { {0xf2e7007e,0xd1300021,0x36670002,0x00000000}},	//   اکمه_, قمة_, _бато_,
  { {0x61e001f7,0x2154000d,0x7f445ab3,0x00000000}},	//   ruml, ркоў, _aliq,
  { {0x44380031,0x60c802ea,0xf5930021,0x00000000}},	//   _ær_, radm, _اللج,
  { {0x395a0034,0x7f446ff6,0x32ba0021,0x00000000}},	//   hips_, _cliq, _أداة_,
  { {0x2d4d017f,0x9f540e74,0x9757009a,0x00000000}},	//   džer_, свяч, ריכו_,
  { {0xdb152262,0x3d0f0053,0x70940854,0x00000000}},	//   sszü, ायें_, _калф,
  { {0xbc95000a,0x4c950054,0x317b0041,0x00000000}},	//   равј, ривс, _ראוד,
  { {0x29cf008f,0x929d056c,0xdb15009c,0x00000000}},	//   tļa_, adłu, vszó,
  { {0xb955005a,0x7bdc6ff7,0x6b9d0078,0x00000000}},	// [f9f0] аващ, arru, _visg,
  { {0x6b9d002b,0x6aad48e7,0x17fb0021,0x00000000}},	//   _wisg, scaf, فرصة_,
  { {0x290100bb,0x28870001,0x6d456ff8,0x00000000}},	//   reha_, ућав, _ilha,
  { {0xa6150055,0xdb151556,0x87d814d7,0x00000000}},	//   имеч, rszó, ابلس_,
  { {0xdb15000f,0x290108ed,0x65950085,0x00000000}},	//   sszó, peha_, ааду,
  { {0x8cba0053,0x660900c2,0x290f001c,0x00000000}},	//   ्रयो, _vsek, ēgas_,
  { {0x2907002b,0x04456ef2,0xd928009a,0x00000000}},	//   ônau_, рейн, _עֵשָ,
  { {0x66091621,0x613f017d,0x657a00d1,0x00000000}},	//   _tsek, _pêlo, _ekth,
  { {0x6d450016,0x8cba0053,0x62650002,0x00000000}},	//   _olha, ्रमो, рвпа,
  { {0xe9ff0013,0x3d0f0053,0x59da0042,0x00000000}},	//   _giấc_, ायों_, यूटर,
  { {0xdcec004c,0xff260133,0xa0690cd6,0x00000000}},	//   _řiďt, амно, тана_,
  { {0x2f5601dd,0x8234007e,0x98ab0078,0x00000000}},	//   ртос, _گرما, ėmęs_,
  { {0x9394007e,0xada66ff9,0x7bce3248,0x00000000}},	//   _اجلا, рагл, wsbu,
  { {0x823401fb,0x2d9e6ffa,0xc0e220fb,0x00000000}},	//   _درما, öte_, _дошк,
  { {0xdea2006a,0x30790047,0x40790047,0x00000000}},	//   _ویدی, _באַנ, _באַװ,
  { {0xbb43000a,0x6d4500ea,0xfaa301d5,0x00000000}},	//   оеск, _elha, жато,
  { {0xc9a7000a,0x3b07071a,0xeb9722fa,0x00000000}},	// [fa00] ивте_, шето_, рит_,
  { {0x224d00a8,0xa9230c03,0xdce70022,0x00000000}},	//   izek_, одул, koję,
  { {0xc796000d,0xd259001c,0x6d5c0640,0x00000000}},	//   арды, maņu_, mira,
  { {0x28e20161,0x09e614cf,0xf746005e,0x00000000}},	//   _पाकि, _комн, једо,
  { {0xe737005e,0x3f820022,0x6d5c0072,0x00000000}},	//   јеч_, ilku_, oira,
  { {0x6d5c6ffb,0xd491008d,0xa96a1326,0x00000000}},	//   nira, _hày_, _рига_,
  { {0x6d5c0019,0xaaaa0053,0xdce70078,0x00000000}},	//   iira, _कलाक, goję,
  { {0x6d5c20fe,0x320a0022,0x938a02d8,0x00000000}},	//   hira, łbym_, њска_,
  { {0x6d5c1e2e,0x926a0062,0xdb050137,0x00000000}},	//   kira, ърка_, _uthå,
  { {0x09f70063,0x3253000d,0x3f820124,0x00000000}},	//   סמים_, івэр, elku_,
  { {0x940604de,0x1306011c,0x506600d7,0x00000000}},	//   _خواه, _взем, ртпа,
  { {0xd49100aa,0xc2e90021,0x6578017c,0x00000000}},	//   _này_, _معهم_, lovh,
  { {0x443c0024,0x3f85001c,0x224d0051,0x00000000}},	//   lyv_, ēlu_, czek_,
  { {0x7c3c002b,0x6d5c6ffc,0x6578017c,0x00000000}},	//   fyrr, gira, novh,
  { {0xd4910013,0x2ac7005e,0xb0b7009a,0x00000000}},	//   _bày_, иљав, _דפוס_,
  { {0x6d5c6ffd,0xb09b009f,0x4fb3002a,0x00000000}},	//   aira, _ביור, _بصور,
  { {0xe29300b5,0x63a80051,0x28a70076,0x00000000}},	// [fa10] ַװע_, _ludn, ашег,
  { {0x6d5c0add,0x236902f7,0x98b8030b,0x00000000}},	//   cira, čaji_, илут_,
  { {0x2d83055e,0x57f509b3,0x63a84374,0x00000000}},	//   mlje_, спет, _nudn,
  { {0xd4910013,0xe796005d,0x2d83013d,0x00000000}},	//   _gày_, مانک, llje_,
  { {0xa997007e,0x2d8308ed,0x201a0130,0x00000000}},	//   _نشست, olje_, _špil_,
  { {0x24e90086,0xe578013c,0x2907004b,0x00000000}},	//   умки_, азі_, õnad_,
  { {0x6e3d001f,0xf9920063,0xbddb006c,0x00000000}},	//   hysb, _זרם_, lyèd,
  { {0x6d5c6ffe,0xdb050139,0x2911013d,0x00000000}},	//   zira, _athú, _haza_,
  { {0x2911455a,0xb3080021,0xdb0e0003,0x00000000}},	//   _kaza_, شغيل_, édéf,
  { {0x29110035,0xdd040023,0xdce70022,0x00000000}},	//   _jaza_, ēsīb, poję,
  { {0x6d5c6fff,0x224d1504,0x29117000,0x00000000}},	//   vira, szek_, _maza_,
  { {0x6d5c7001,0x3ea4000e,0x29117002,0x00000000}},	//   wira, ømt_, _laza_,
  { {0x23740021,0x02440021,0xf1a70781,0x00000000}},	//   _بالح, _وَمَ, _трен,
  { {0x7c3c02ab,0x29110089,0x661b1147,0x00000000}},	//   tyrr, _naza_, _mruk,
  { {0x8c4324f8,0x6d5c7003,0xdfce0044,0x00000000}},	//   пере, rira, _كيو_,
  { {0xce5a007e,0x6d5c0cd9,0x7aa60062,0x00000000}},	//   _مشخص_, sira, сиаз,
  { {0x2d83027c,0xd259001c,0x29117004,0x00000000}},	// [fa20] blje_, paņu_, _baza_,
  { {0x4a43000a,0xeeeb001b,0x2911006d,0x00000000}},	//   чнув, ượng_, _caza_,
  { {0x6f06006f,0x3ead226f,0x661b0526,0x00000000}},	//   oekc, žete_, _aruk,
  { {0x661b0d96,0xab2a005e,0x7fd60047,0x00000000}},	//   _bruk, _сома_, מועס_,
  { {0x9916019d,0x6b843385,0x63a80f74,0x00000000}},	//   _льві, mlig, _sudn,
  { {0x6b840f4a,0x29113484,0x28e20053,0x00000000}},	//   llig, _gaza_, _पाटि,
  { {0xf1aa007e,0x1cbb0063,0x65780066,0x00000000}},	//   گابه_, אמצע, rovh,
  { {0x6b8428d7,0x661b7005,0x938a0121,0x00000000}},	//   nlig, _fruk, ысла_,
  { {0xd5b20021,0xcb130063,0x7f5d01a8,0x00000000}},	//   _رفض_, ללה_, visq,
  { {0x63a800ea,0xf8ba0053,0x3a370132,0x00000000}},	//   _tudn, ेरिय, צרים_,
  { {0x2d83074f,0x6b847006,0x6e3d00ac,0x00000000}},	//   vlje_, klig, wysb,
  { {0x6b84417c,0x8f477007,0x7f5d0003,0x00000000}},	//   jlig, сход, uisq,
  { {0x6b8402ea,0x7f5d27c2,0x32960021,0x00000000}},	//   dlig, risq, _الشأ,
  { {0x63a20025,0x6b650006,0x2d832dfc,0x00000000}},	//   _hion, mėgi, ulje_,
  { {0x63a20035,0x7bda017f,0x29117008,0x00000000}},	//   _kion, štun, _raza_,
  { {0x6b8406a3,0xfb580021,0x2d83007d,0x00000000}},	//   glig, مؤقت_, slje_,
  { {0x63a20025,0x2d830734,0x3c180066,0x00000000}},	// [fa30] _mion, plje_, _ečv_,
  { {0x6b847009,0xdcee003b,0x394701a8,0x00000000}},	//   alig, robă, óns_,
  { {0x6b84700a,0x645e0066,0xe7870454,0x00000000}},	//   blig, úpil, будо,
  { {0x6b840509,0xcb0b000d,0x63a2700b,0x00000000}},	//   clig, _сход_, _nion,
  { {0x2911006d,0x6b650078,0xbef80063,0x00000000}},	//   _taza_, jėgi, מצאו_,
  { {0x33d90076,0xe4e70054,0x7d15013d,0x00000000}},	//   афию_, сідн, ndzs,
  { {0xf8ae007e,0x7d070051,0x63a2700c,0x00000000}},	//   _شکل_, iejs, _bion,
  { {0x63a25af4,0x628200ac,0xf1d40053,0x00000000}},	//   _cion, _byoo, _दिखन,
  { {0xeab201f9,0x26cf700d,0x42250636,0x00000000}},	//   וֹת_, mago_, ідов,
  { {0x628b00c2,0xa7d30053,0x26cf700e,0x00000000}},	//   _vzgo, _डिफ़ॉ, lago_,
  { {0x63a20025,0x6b84700f,0x7afd7010,0x00000000}},	//   _fion, ylig, _obst,
  { {0x26cf002c,0x7c2a0268,0x63a201f4,0x00000000}},	//   nago_, _àfri, _gion,
  { {0x237800ea,0xe0ce0184,0x80ba0053,0x00000000}},	//   _írja_, _ов_, _श्वे,
  { {0x23691181,0x7afd2901,0x7d070261,0x00000000}},	//   čaju_, _abst, gejs,
  { {0x6b8406a3,0x26cf0130,0x661d005f,0x00000000}},	//   tlig, kago_, _šskl,
  { {0x6b8405dd,0xeeeb008b,0x63a204ec,0x00000000}},	//   ulig, ưỡng_, _xion,
  { {0x6b841781,0xf2960041,0x6d4b0078,0x00000000}},	// [fa40] rlig, ַכער_, _įgav,
  { {0x7afd01b0,0x6e3b004d,0x6b847011,0x00000000}},	//   _ebst, äube, slig,
  { {0x7aef024a,0xb9020161,0x6b842118,0x00000000}},	//   äntö, _नए_, plig,
  { {0xe61a032d,0xf989009f,0xc4b40042,0x00000000}},	//   иде_, דר_, ुर्ख,
  { {0x63a21027,0x2b4700dd,0x929d0022,0x00000000}},	//   _rion, _înca_, wełn,
  { {0x9876005e,0x63a24b40,0x9e0b009a,0x00000000}},	//   _дубљ, _sion, שִׁ֖,
  { {0x26cf00bb,0xb8e0016a,0xb4930001,0x00000000}},	//   bago_, ीर_, мишљ,
  { {0xdb1500ea,0x26cf18b4,0x6625004c,0x00000000}},	//   sszö, cago_, átký,
  { {0x6d4e00e3,0x416a0001,0x63a20035,0x00000000}},	//   khba, ијом_, _vion,
  { {0x321d0185,0x929d0045,0x201c0add,0x00000000}},	//   _drwy_, pełn, _prvi_,
  { {0x63a225e1,0x6d4e0025,0xf8b30063,0x00000000}},	//   _tion, dhba, ושת_,
  { {0x80ba0161,0x71a6000d,0x00000000,0x00000000}},	//   _श्रे, _дадз,   ,
  { {0xdb1c00cd,0xd252007e,0xe29a005e,0x00000000}},	//   mprè, _تنش_, _тад_,
  { {0xbfd400de,0x00000000,0x00000000,0x00000000}},	//   _فيتع,   ,   ,
  { {0x93bc003b,0x3326283b,0x7d070d84,0x00000000}},	//   _drăg, _knox_, rejs,
  { {0x6d4b0078,0x48fd0082,0xeea70044,0x00000000}},	//   _įgau, र्नो_, _بحثً,
  { {0xaf4b006a,0x7d070051,0x48ab0076,0x00000000}},	// [fa50] _مشکل_, pejs, атем_,
  { {0x6d4e00bd,0xcd000051,0x929d0051,0x00000000}},	//   chba, ęści_, zeło,
  { {0x26cf002c,0x332601a8,0xb8d30042,0x00000000}},	//   tago_, _onox_, _ऑल_,
  { {0x47580086,0xe7a80085,0xcce7005d,0x00000000}},	//   орія_, івіл_, _اسکي,
  { {0x98aa0051,0x26cf6441,0xe56e286c,0x00000000}},	//   _sobą_, rago_, ез_,
  { {0x25bd001f,0x7aed7012,0x7bd50022,0x00000000}},	//   rpwl_, lgat, oszu,
  { {0x26cf006d,0x64a20001,0x2b4b0089,0x00000000}},	//   pago_, наша, _klcc_,
  { {0x7aed184f,0x6d800137,0x3f99007d,0x00000000}},	//   ngat, nöar, jmsu_,
  { {0xc2e80021,0x2019008f,0x81f600de,0x00000000}},	//   زعيم_, āsim_, كفير_,
  { {0x3ea90027,0x98aa0051,0x9f460003,0x00000000}},	//   _agat_, _tobą_, mulé_,
  { {0xf3f00032,0xf51a009a,0xd009012c,0x00000000}},	//   _لأن_, _לֵאל, щене_,
  { {0x321d0185,0x25a52a9b,0x7bda2a2e,0x00000000}},	//   _trwy_, _hill_, átum,
  { {0x25a50034,0x7aed7013,0x6d4e396e,0x00000000}},	//   _kill_, dgat, thba,
  { {0xb2260026,0xdb1c109c,0x7bda0078,0x00000000}},	//   stæð, mpré, štum,
  { {0x93bc000c,0x20540062,0x25a57014,0x00000000}},	//   _grăd, _отър, _mill_,
  { {0x6d8000fe,0x23b118a8,0x2d8d00ac,0x00000000}},	//   töas, _máj_, ïeer_,
  { {0x6b650006,0x93bc003b,0x61e906f1,0x00000000}},	// [fa60] jėgu, _trăg, nuel,
  { {0xef18008f,0x2896005e,0x7aed7015,0x00000000}},	//   ēļu_, пјес, agat,
  { {0x61e97016,0x5d3b0063,0x0d3b0063,0x00000000}},	//   huel, _התיא, _הגיב,
  { {0x61e97017,0xdc8b0063,0x00000000,0x00000000}},	//   kuel, _לְכָ,   ,
  { {0x61e905d5,0x25a57018,0xd6cf0049,0x00000000}},	//   juel, _bill_, اقه_,
  { {0x25a50139,0x61e97019,0x23b1013d,0x00000000}},	//   _cill_, duel, _báj_,
  { {0xdb1c0003,0xa0260072,0x25a5701a,0x00000000}},	//   epré, isöö, _dill_,
  { {0x25ad0c69,0xb7db0063,0x03a3005e,0x00000000}},	//   _fuel_, _לקלי, нијо,
  { {0x69d600e3,0xdb1c00f4,0x51861dd6,0x00000000}},	//   nsye, rprè, зуна,
  { {0xdb1c00cd,0x7bd50051,0x7aed00ea,0x00000000}},	//   sprè, yszu, zgat,
  { {0x7bda01b3,0x75280022,0x7aed056c,0x00000000}},	//   štuj, _indz, ygat,
  { {0x69d647d4,0x61e9006d,0x6d5e701b,0x00000000}},	//   ksye, buel, _ampa,
  { {0x61e9701c,0xd3370063,0x877b009f,0x00000000}},	//   cuel, _מראה_, מאטי,
  { {0x69d600ac,0x93bc003b,0x7bd5004d,0x00000000}},	//   dsye, _trăd, tszu,
  { {0x69d60089,0x7bd5004d,0x5c0402dc,0x00000000}},	//   esye, uszu, нята,
  { {0x3ea900a4,0x7aed1826,0xcb340062,0x00000000}},	//   _ugat_, ugat, несъ,
  { {0x7bd500ea,0xad550021,0x6d800137,0x00000000}},	// [fa70] sszu, _ينبغ, röar,
  { {0x7aed701d,0x6d800137,0x76420075,0x00000000}},	//   sgat, söar, dyoy,
  { {0x61e90402,0xf770005d,0xacfa009a,0x00000000}},	//   zuel, گال_, _והתכ,
  { {0xdb0700fe,0x9f460003,0xf1dd0053,0x00000000}},	//   ömäs, tulé_, _मिलन,
  { {0x25ad11ff,0x95991224,0x61e9701e,0x00000000}},	//   _quel_, отку_, xuel,
  { {0x61e9701f,0xc9840086,0xe9a40085,0x00000000}},	//   vuel, _зуси, _паўп,
  { {0x25a52ddc,0x753a00cd,0xe9ff008b,0x00000000}},	//   _vill_, _dotz, _khắc_,
  { {0x25a50780,0x61e97020,0x9f46006c,0x00000000}},	//   _will_, tuel, pulé_,
  { {0x25a52ddc,0x25ad004b,0x6d470014,0x00000000}},	//   _till_, _uuel_, kkja,
  { {0xdb1c0164,0x61e97021,0x15150054,0x00000000}},	//   rpré, ruel, _ідея,
  { {0xdb1c0994,0x656303d9,0xe2f90086,0x00000000}},	//   spré, minh, _межі_,
  { {0xe9ff008b,0x7f4d09ef,0xe8050053,0x00000000}},	//   _nhắc_, _claq, _रहना_,
  { {0x236d4afb,0x6443001f,0x93bc003b,0x00000000}},	//   mnej_, lyni, _grăb,
  { {0xfce60086,0x236d0d10,0x2480005b,0x00000000}},	//   ього, lnej_, şime_,
  { {0x628f017f,0x6da30793,0xe1f90078,0x00000000}},	//   škoć, тира, ltų_,
  { {0xe9ff001b,0xe1f90006,0x236d7022,0x00000000}},	//   _chắc_, otų_, nnej_,
  { {0xe1f900eb,0xed5a22fa,0xe9da0500,0x00000000}},	// [fa80] ntų_, _мои_, юка_,
  { {0xe1f900eb,0x6d5e2ff8,0x69d6683d,0x00000000}},	//   itų_, _umpa, rsye,
  { {0x65633605,0xc0ac0047,0xb17a0041,0x00000000}},	//   dinh, ציאָ, קטער,
  { {0xe1f900eb,0x64431435,0x236d27f1,0x00000000}},	//   ktų_, dyni, jnej_,
  { {0x236d06ce,0x99d60021,0x64430014,0x00000000}},	//   dnej_, _تتجا, eyni,
  { {0x6443001f,0xef1f00ea,0x65637023,0x00000000}},	//   fyni, elül_, ginh,
  { {0xe1f90078,0xbfa4008d,0x98a30131,0x00000000}},	//   etų_, _phễ, _аире,
  { {0x27f701c2,0x93bc003b,0xd214005e,0x00000000}},	//   žení_, _prăb, емић,
  { {0x6d473dcc,0xe1f90078,0x65637024,0x00000000}},	//   ykja, gtų_, binh,
  { {0x93bc000c,0x65637025,0x6443001f,0x00000000}},	//   _crăc, cinh, byni,
  { {0x2918282c,0xc0570086,0x236d06ce,0x00000000}},	//   _mara_, дія_, bnej_,
  { {0x122a0076,0x236d1a03,0x63b70066,0x00000000}},	//   _моей_, cnej_, žané,
  { {0xec680047,0x291800dd,0xcd000022,0x00000000}},	//   _פֿ_, _oara_, ęśni_,
  { {0x2bbb0044,0x29187026,0xb118005d,0x00000000}},	//   قارة_, _nara_, _رقبا_,
  { {0x6d47007a,0xac187027,0x2ba70092,0x00000000}},	//   rkja, мору_, дјав,
  { {0x65630016,0x2918004b,0x16000042,0x00000000}},	//   zinh, _aara_, ोबार_,
  { {0x29187028,0x64430051,0xd91b0121,0x00000000}},	// [fa90] _bara_, zyni, жье_,
  { {0x29187029,0x661d0026,0x6563017d,0x00000000}},	//   _cara_, _áski, xinh,
  { {0x6563017d,0xe9ff008b,0x2918702a,0x00000000}},	//   vinh, _thắc_, _dara_,
  { {0xe1f90006,0x64430078,0xf0930041,0x00000000}},	//   ytų_, vyni, דנע_,
  { {0x236d0024,0x291831e4,0x6563702b,0x00000000}},	//   vnej_, _fara_, tinh,
  { {0xfbd0006a,0x236d0051,0x2918702c,0x00000000}},	//   _حتی_, wnej_, _gara_,
  { {0x673b03b2,0x236d4afb,0x6563702d,0x00000000}},	//   _touj, tnej_, rinh,
  { {0x6b5100c7,0x6563702e,0xe894000d,0x00000000}},	//   _fåge, sinh, _рась,
  { {0x236d06ce,0xe1f90006,0x6563702f,0x00000000}},	//   rnej_, utų_, pinh,
  { {0xe1f90006,0x236d2b8f,0x00000000,0x00000000}},	//   rtų_, snej_,   ,
  { {0xe1f900eb,0x13f50054,0x236d16bb,0x00000000}},	//   stų_, _їздя, pnej_,
  { {0xe1f90006,0xdb1c0046,0x141a009a,0x00000000}},	//   ptų_, lsrö, _מועב,
  { {0x3ea400c7,0xc0e5014b,0x9756009a,0x00000000}},	//   ämt_, _золк, תירו_,
  { {0x98aa0080,0xe2a50014,0xdb05013d,0x00000000}},	//   _době_, öðug_, _ruhá,
  { {0x3b96000a,0xeb9a01ef,0x291808c9,0x00000000}},	//   ејат, зив_, _rara_,
  { {0xdbd60019,0x29187030,0x61fb003b,0x00000000}},	//   _rääg, _sara_, otul,
  { {0x29187031,0x61fb7032,0x2d840003,0x00000000}},	// [faa0] _para_, ntul, îmes_,
  { {0x5e5700b5,0xdb06013d,0x394e0014,0x00000000}},	//   _נייע_, _miké, ófs_,
  { {0x61fb0019,0x29187033,0x6e2400c2,0x00000000}},	//   htul, _vara_, _hrib,
  { {0xdc370047,0x61fb0da5,0x98b1003b,0x00000000}},	//   _נאכט_, ktul, _poză_,
  { {0x2918324d,0x45b7012c,0x9e0a009a,0x00000000}},	//   _tara_, егію_, לִַ֖,
  { {0x59b50161,0x6b5114a7,0x20070014,0x00000000}},	//   _अंतर, _våge, _opni_,
  { {0xf8a70053,0x6f041052,0x66e61577,0x00000000}},	//   _कृपय, _obic, _пова,
  { {0xe8050053,0x6b516097,0x69c47034,0x00000000}},	//   _रहता_, _tåge, opie,
  { {0x61fb002c,0x2d54004b,0x3f827035,0x00000000}},	//   gtul, _käed_, doku_,
  { {0x09f70063,0x69c47036,0xdcee011b,0x00000000}},	//   עמים_, ipie, robě,
  { {0xf65f007a,0x61fb7037,0x6e244e0f,0x00000000}},	//   _þær_, atul, _arib,
  { {0x98aa0080,0x95820051,0x3ead0093,0x00000000}},	//   _sobě_, żąda, øet_,
  { {0x61fb000c,0x69c40051,0x853c0078,0x00000000}},	//   ctul, jpie, _riėj,
  { {0x2d540019,0x2d850003,0xc6930149,0x00000000}},	//   _näed_, ôle_, טאר_,
  { {0xef1f01f7,0xdb1c0024,0x69c4001c,0x00000000}},	//   nlük_, aprí, epie,
  { {0xa3e80053,0x6e247038,0x64580023,0x00000000}},	//   _बिन_, _frib, izvi,
  { {0x6f0f01f4,0xf1b30047,0x58d9000d,0x00000000}},	// [fab0] mecc, ָסע_, ддзя_,
  { {0x6f0f3ab4,0x6f1d0c84,0xef1f0058,0x00000000}},	//   lecc, ldsc, klük_,
  { {0x2d8300eb,0x6f1d00ca,0x99890058,0x00000000}},	//   moje_, odsc, avaş_,
  { {0xdc360047,0x2d830006,0x6f1d02ce,0x00000000}},	//   _סארט_, loje_, ndsc,
  { {0x61fb000c,0x64580066,0xdb1c00a5,0x00000000}},	//   xtul, ezvi, tsrö,
  { {0x2d830006,0x8644000d,0x6b8d7039,0x00000000}},	//   noje_, ыніж, llag,
  { {0x2d830006,0xe8940121,0xb6f5005e,0x00000000}},	//   ioje_, _барь, _извј,
  { {0x6f0f0268,0x6f1d0122,0xd1380051,0x00000000}},	//   jecc, jdsc, eją_,
  { {0x2d832365,0x6b8d0a64,0x645829c3,0x00000000}},	//   koje_, ilag, azvi,
  { {0x2d8300eb,0x6b8d00bd,0xa1560001,0x00000000}},	//   joje_, hlag, кању_,
  { {0xf8b2014e,0x69c40045,0x6b8d0c23,0x00000000}},	//   ישי_, zpie, klag,
  { {0x6b8d2e30,0xd1380051,0x61fb6a94,0x00000000}},	//   jlag, ają_, ptul,
  { {0x6b8d703a,0xee370065,0xaed30085,0x00000000}},	//   dlag, вня_, шоўш,
  { {0x6da60001,0xd1380051,0x2d83146a,0x00000000}},	//   ђива, cją_, goje_,
  { {0x69dd0ddc,0x5c73000d,0x0c790121,0x00000000}},	//   _avse, алёт, есты_,
  { {0x6b8d00bb,0x6f04703b,0xed59001c,0x00000000}},	//   glag, _ubic, īža_,
  { {0xf2d200b5,0x6e240297,0xc9aa000d,0x00000000}},	// [fac0] יען_, _urib, двае_,
  { {0x6b8d4fb3,0x63ab38d0,0x76590022,0x00000000}},	//   alag, _lign, dzwy,
  { {0x6609002c,0x69c4703c,0x6b8d703d,0x00000000}},	//   _apek, spie, blag,
  { {0x69c4015e,0xd1380022,0x61e900a5,0x00000000}},	//   ppie, zją_, krel,
  { {0x6b840164,0x628e0051,0x7bdc0d1a,0x00000000}},	//   moig, ębok, lsru,
  { {0x5693000a,0xad9b0026,0x61e9703e,0x00000000}},	//   јашт, rtúg, drel,
  { {0x6609002c,0x6f0f6c2d,0x86ea0021,0x00000000}},	//   _epek, yecc, _يعرف_,
  { {0x92940088,0xef1f005b,0x67a50049,0x00000000}},	//   лайц, rlük_, _محقق,
  { {0xf743000a,0x6f0f2ae4,0xdb0d00ea,0x00000000}},	//   _тето, vecc, ókén,
  { {0x63ab1d36,0x6b8d08ea,0x4a9b0047,0x00000000}},	//   _eign, zlag, ויפג,
  { {0x6b510147,0x6f0f0b14,0x33f6000d,0x00000000}},	//   _låga, tecc, _шчас,
  { {0x7bdc67cc,0x2d540019,0x2d830051,0x00000000}},	//   dsru, _näeb_, woje_,
  { {0x2d8300eb,0x6f0f22c2,0x61e9005b,0x00000000}},	//   toje_, recc, crel,
  { {0xac19000a,0x644500bd,0xe9ff001b,0x00000000}},	//   ногу_, ähig, _nhạc_,
  { {0x99890051,0x2d830114,0x6f0f332e,0x00000000}},	//   ywał_, roje_, pecc,
  { {0x2d8333ae,0x2019008f,0x6b5100a5,0x00000000}},	//   soje_, āsit_, _båga,
  { {0xdb120025,0x999946af,0x2d83703f,0x00000000}},	// [fad0] ágái, екат_, poje_,
  { {0x6b8d7040,0xef1f005b,0xfaa4005e,0x00000000}},	//   slag, ldü_, рађо,
  { {0x6b8d7041,0x61e97042,0x29880699,0x00000000}},	//   plag, zrel, тсто_,
  { {0x7c2a007a,0x7bc7017f,0xef1f0058,0x00000000}},	//   _áfra, mpju, ndü_,
  { {0x44257043,0x99890051,0xdcfc008f,0x00000000}},	//   _srl_, rwał_, lorā,
  { {0x75d20021,0x63ab10c5,0x61e97044,0x00000000}},	//   حيوا, _sign, vrel,
  { {0xdcfc001c,0x63ab5f4e,0xad9b0331,0x00000000}},	//   norā, _pign, ctúe,
  { {0xb882027d,0xaad30053,0x93bc0013,0x00000000}},	//   číta, तरिक, _trăn,
  { {0x66090009,0x7764005a,0x63ab7045,0x00000000}},	//   _upek, _търж, _vign,
  { {0x61e97046,0x61e60240,0x628b01e1,0x00000000}},	//   rrel, ákla, _vygo,
  { {0x63ab00bb,0xe97c0047,0x628b0051,0x00000000}},	//   _tign, ונזש, _wygo,
  { {0x628b0051,0x69c17047,0x61e97048,0x00000000}},	//   _tygo, _člen, prel,
  { {0xcdf606bc,0x6f630121,0x4df60085,0x00000000}},	//   ычны, связ, ыянт,
  { {0xe1f6005e,0x7bdc0137,0x6145005e,0x00000000}},	//   _сгш_, tsru, _љека,
  { {0x6b510203,0x3b0a04d8,0x4032005e,0x00000000}},	//   _såga, нево_, _гејс,
  { {0x7bdc481e,0xe7f70042,0x00000000,0x00000000}},	//   rsru, ँढना_,   ,
  { {0x0eaa019d,0x7bdc080f,0x3a260085,0x00000000}},	// [fae0] _який_, ssru, ымаг,
  { {0x7bda00ea,0x6b511310,0x98560092,0x00000000}},	//   átus, _våga, лтеш,
  { {0x3cfb0063,0x46ea0571,0xc89602d8,0x00000000}},	//   _אלינ, еден_, урањ,
  { {0x27e70027,0xcc3b0047,0xf6d6005d,0x00000000}},	//   ánna_, _נעכט, ازاد,
  { {0xe9ff0013,0x7d1e7049,0x16340edb,0x00000000}},	//   _thạc_, _kaps, реля,
  { {0x7af60078,0x6d4e704a,0x00000000,0x00000000}},	//   lgyt, nkba,   ,
  { {0x97b5000a,0x4ab80161,0x6d4e0250,0x00000000}},	//   _всуш, _अलाव, ikba,
  { {0x7d1e047f,0x75d60049,0x3ead704b,0x00000000}},	//   _laps, _ميرا, žeti_,
  { {0x6d4e5d3e,0x22580121,0x316a1f1d,0x00000000}},	//   kkba, типы_, ешно_,
  { {0x6d4e0122,0x69fb00b5,0x7d1e0b3d,0x00000000}},	//   jkba, עליק, _naps,
  { {0x661d0026,0x89370047,0xb4c20053,0x00000000}},	//   _áskr, אריע_, ूरी_,
  { {0x60c401f7,0x6d4e006f,0x3cfa01a8,0x00000000}},	//   _şimd, ekba, _acpv_,
  { {0xe2920032,0x5ce7019d,0xef1f005b,0x00000000}},	//   _اذا_, люва, rdü_,
  { {0x7c870189,0x74ca0042,0x7d1e704c,0x00000000}},	//   губе, _स्मृ, _caps,
  { {0x07040053,0x60da704d,0x5d640121,0x00000000}},	//   रभाव_, matm, стяз,
  { {0x5b150002,0x60da005b,0x6d4e704e,0x00000000}},	//   јмат, latm, akba,
  { {0x5a35026b,0x5f74007e,0x3e070054,0x00000000}},	// [faf0] шнат, _داور, _сяйв,
  { {0x7bc7004b,0x2907403d,0x60da704f,0x00000000}},	//   ppju, ýna_, natm,
  { {0xdb1c0240,0xa81504d8,0xdb1f00ea,0x00000000}},	//   sprá, рдеш, ívók,
  { {0x644a0051,0x7d1e0080,0xdb1c00b9,0x00000000}},	//   dyfi, _zaps, epræ,
  { {0x60da0150,0x644a308e,0xa3ae0042,0x00000000}},	//   katm, eyfi, ओआई_,
  { {0xe5a5623c,0xa5092338,0x644a0046,0x00000000}},	//   шили, тека_, fyfi,
  { {0x36d5000d,0x93bc003b,0xa9540054,0x00000000}},	//   _вобр, _frăm, _укрі,
  { {0x93bc003b,0x29137050,0x60da7051,0x00000000}},	//   _grăm, lexa_, eatm,
  { {0xe0d1005d,0x6b48009d,0x00000000,0x00000000}},	//   يزد_, ר֨וּ_,   ,
  { {0x32d3008b,0xe610007e,0xd6d90051,0x00000000}},	//   ảy_, _عشق_, _koło_,
  { {0x6b5101e3,0x764b001f,0x644a0051,0x00000000}},	//   _någo, lygy, cyfi,
  { {0x2d910080,0x60da004b,0x3f6a293a,0x00000000}},	//   elze_, aatm, тимо_,
  { {0x7bc5007a,0x43840032,0x20180026,0x00000000}},	//   _athu, _النق, ærir_,
  { {0x31790041,0x1d190e82,0xfbc6012c,0x00000000}},	//   _שאַד, люсь_, ибго,
  { {0x6d4e61a6,0xdfd10021,0x29136ace,0x00000000}},	//   rkba, _بيع_, dexa_,
  { {0xb4c1016a,0x207a0047,0xd00e0021,0x00000000}},	//   ंडु_, _באצא, _آلي_,
  { {0x4420001b,0x6b5812c7,0x6d890014,0x00000000}},	// [fb00] ̉i_, _níge, rþar,
  { {0x38cb007e,0x48e60085,0x7e9b009a,0x00000000}},	//   نامی_, рожв, _בספו,
  { {0x661b0449,0xad9b0066,0xa3d70042,0x00000000}},	//   _asuk, stúc, ़ीम_,
  { {0xe739001f,0xdcfc003b,0xb8ed0053,0x00000000}},	//   _siŵr_, boră, _ष्_,
  { {0xb4c1016a,0x799c002b,0x98de0054,0x00000000}},	//   ंडू_, _thrw, _освi,
  { {0x6e3b00bd,0x91a60013,0xe5e50021,0x00000000}},	//   äubi, _trỏ_, إثني,
  { {0xdb1c00b9,0xdb0d004d,0xd37a0094,0x00000000}},	//   rpræ, nmaß, кчи_,
  { {0x644a7052,0xdb1c00b9,0xd32601d5,0x00000000}},	//   ryfi, spræ, рьки,
  { {0xd1300032,0x3e4a0078,0x2f2d0078,0x00000000}},	//   كمة_, nėtą_, _jėgų_,
  { {0x7a0a001c,0x66025482,0x2154000d,0x00000000}},	//   mētā, mtok, скоў,
  { {0x60da005b,0x7a0a001c,0x65680025,0x00000000}},	//   ratm, lētā, _imdh,
  { {0xdb1c004d,0x3e4a0078,0x67227053,0x00000000}},	//   nprä, kėtą_, ndoj,
  { {0x6722001c,0x60da005b,0x7a0a008f,0x00000000}},	//   idoj, patm, nētā,
  { {0x3e4a0078,0x21670062,0x66027054,0x00000000}},	//   dėtą_, _кичи_, itok,
  { {0x6b5100c7,0xfb670001,0x66020072,0x00000000}},	//   _fågl, ањам, htok,
  { {0x6720017f,0x93bc003b,0x6b510137,0x00000000}},	//   _namj, _prăj, _vågo,
  { {0x88c70021,0xba990054,0x8f7c009d,0x00000000}},	// [fb10] لتال, уває_, _שנחק,
  { {0x93bc003b,0xdb1c004d,0x7a0a008f,0x00000000}},	//   _vrăj, eprä, dētā,
  { {0x7d15005b,0xad9b006d,0x66024e43,0x00000000}},	//   mezs, ctúa, etok,
  { {0x3ead5d6a,0x61e25fc3,0x7d1510c9,0x00000000}},	//   žetu_, _ovol, lezs,
  { {0x6d450004,0x61e200cd,0x79a70002,0x00000000}},	//   _koha, _nvol, _врве,
  { {0x356b0062,0x5dda0047,0x05640054,0x00000000}},	//   ърен_, אַקס, овін,
  { {0x66020009,0x6d4518fe,0x61e24cc6,0x00000000}},	//   atok, _moha, _avol,
  { {0xe1f90121,0x2d540bda,0xcc780063,0x00000000}},	//   гги_, _näen_, יגות_,
  { {0x7a0a001c,0x661b02a8,0x00000000,0x00000000}},	//   cētā, _usuk,   ,
  { {0x6720017f,0x00c90076,0x8c490058,0x00000000}},	//   _zamj, ылок_, _kaşı,
  { {0x04950032,0x61e25f17,0xa2d5005d,0x00000000}},	//   _الاح, _evol, _هيات,
  { {0x2f5642cc,0xd5b1008d,0x9f4d011b,0x00000000}},	//   стос, _hí_, budí_,
  { {0x877a00b5,0x6b510137,0x6d4526c3,0x00000000}},	//   רארי, _vågl, _boha,
  { {0xc0cb0001,0xd491001b,0x987a003b,0x00000000}},	//   _руде_, _kỳ_, nţăm_,
  { {0x7a0a003d,0x61e2016b,0x7521005b,0x00000000}},	//   zētā, _zvol, _malz,
  { {0x236d0045,0xdb0d00bd,0x4092007e,0x00000000}},	//   niej_, rmaß, _علير,
  { {0xbb430001,0xeb97183f,0xdb0d004d,0x00000000}},	// [fb20] четк, сит_, smaß,
  { {0x8c4901f7,0xa3e80053,0x3ec80006,0x00000000}},	//   _başı, _बिल_, žutę_,
  { {0x236d0045,0x6d5c0025,0x60da0047,0x00000000}},	//   kiej_, mhra, רקענ,
  { {0x6602024a,0x6d450b54,0x67220078,0x00000000}},	//   ttok, _zoha, udoj,
  { {0x66020009,0x6d450509,0xd5b1008b,0x00000000}},	//   utok, _yoha, _bí_,
  { {0xdb1c00bd,0x7a0a001c,0x75216232,0x00000000}},	//   sprä, rētā, _calz,
  { {0xdb1c0137,0x61e204e4,0x66027055,0x00000000}},	//   pprä, _svol, stok,
  { {0x236d0051,0x08770047,0x60d80058,0x00000000}},	//   giej_, _העלט_, _sevm,
  { {0x442706a5,0x07a3000d,0x24530013,0x00000000}},	//   avn_, _хатн, ạm_,
  { {0x8c49005b,0xdd05008f,0x2fc77056,0x00000000}},	//   _yaşı, ēsīs, _btng_,
  { {0x6d4527ca,0x2d8a7057,0x6d5c0eb0,0x00000000}},	//   _roha, dobe_, dhra,
  { {0x236d0051,0x224d0150,0x43430121,0x00000000}},	//   ciej_, byek_, _нехв,
  { {0x6e22003d,0x61e20080,0x2d4f00cd,0x00000000}},	//   _šobr, _uvol, _yüeh_,
  { {0x6d5c46b8,0x63ba4bae,0x01fb009a,0x00000000}},	//   ghra, _kutn, _עפול,
  { {0x93bc003b,0x63ba013d,0x55770041,0x00000000}},	//   _brăi, _jutn, צעלן_,
  { {0xc1780078,0x93bc003b,0x442c7058,0x00000000}},	//   lnė_, _crăi, _mrd_,
  { {0x6d5c0027,0x8b04004c,0xc8d90054,0x00000000}},	// [fb30] bhra, ířat, имає_,
  { {0x442c18eb,0x236d0045,0x6d5c7059,0x00000000}},	//   _ord_, ziej_, chra,
  { {0x225f00ea,0x63ba0114,0xd8790021,0x00000000}},	//   zzuk_, _nutn, جمات_,
  { {0x93bc003b,0x75212067,0x18a40054,0x00000000}},	//   _grăi, _salz, чаєм,
  { {0x442c0025,0x6f0d0139,0xdb0f0b6d,0x00000000}},	//   _ard_, _mbac, _nicé,
  { {0x6e2d0009,0x8c4901f7,0x67d5705a,0x00000000}},	//   _mrab, _taşı, _могу,
  { {0xd5b1001b,0xdb1c0a2e,0x6b58006d,0x00000000}},	//   _ví_, språ, _híga,
  { {0x6d5c0a63,0xc1780078,0x7521004d,0x00000000}},	//   zhra, enė_, _walz,
  { {0x24890051,0x44270013,0xdb0f0003,0x00000000}},	//   łam_, svn_, _cicé,
  { {0x63ba00ea,0x236d0022,0x600920c0,0x00000000}},	//   _futn, siej_, аном_,
  { {0x236d0051,0x73c401fb,0x63ba1233,0x00000000}},	//   piej_, _فيلم, _gutn,
  { {0x61ee005b,0x99540066,0x6e2d705b,0x00000000}},	//   ünlü, mäť_, _brab,
  { {0x200a01f7,0x6d5c139d,0x25b2005b,0x00000000}},	//   çbir_, thra, _ünlü_,
  { {0xad9b0025,0x6e2d705c,0x127a0047,0x00000000}},	//   stún, _drab, _דאנע,
  { {0x8b260940,0x2d8a705d,0x3a290058,0x00000000}},	//   одве, robe_, evap_,
  { {0x399400fe,0x2d8a1536,0x5dda0416,0x00000000}},	//   mäsi_, sobe_, _кфор_,
  { {0x6e2d705e,0x2480005b,0x39940072,0x00000000}},	// [fb40] _grab, ğimi_, läsi_,
  { {0xc8960001,0x2480005b,0x6b58006d,0x00000000}},	//   орењ, şimi_, _díga,
  { {0x93bc000c,0x39940072,0x200508af,0x00000000}},	//   _trăi, näsi_, ntli_,
  { {0x6b58039f,0x95ca006e,0x2005008f,0x00000000}},	//   _fíga, аука_, itli_,
  { {0xe5340088,0x6b81000f,0xdb1c00ea,0x00000000}},	//   зель, élge, őzón,
  { {0x442c6776,0x63ba705f,0x1cba0063,0x00000000}},	//   _prd_, _putn, ׁמְע,
  { {0x399400fe,0x6b96171a,0xdce7008f,0x00000000}},	//   jäsi_, olyg, nijā,
  { {0xdb040003,0x03a3005e,0x442c004b,0x00000000}},	//   umiè, мијо, _vrd_,
  { {0x9f4d017d,0xdb040003,0x20050022,0x00000000}},	//   judá_, rmiè, etli_,
  { {0x442c00a8,0x24890058,0x6b96002b,0x00000000}},	//   _trd_, şama_, hlyg,
  { {0x88bb009a,0xb8bb0047,0x41b4007e,0x00000000}},	//   ימיז, יזיש, _کمتر,
  { {0xc1780006,0x6e2d7060,0xdce70023,0x00000000}},	//   snė_, _prab, dijā,
  { {0xdb0600fe,0x628e004d,0x637e008f,0x00000000}},	//   _mikä, ßbod, cīna,
  { {0x6ad30053,0xc5f3089e,0x224b0989,0x00000000}},	//   तर्र, ודש_, äcke_,
  { {0x6b9619e5,0xdc3d0066,0x63a27061,0x00000000}},	//   flyg, páčt, _khon,
  { {0x6f0d017f,0x6e2d112b,0xa3dc0053,0x00000000}},	//   _ubac, _trab, तीय_,
  { {0xecf9000d,0x63a27062,0xb9550062,0x00000000}},	// [fb50] _лепш_, _mhon, пващ,
  { {0xe739002b,0xdce7008f,0xceb40063,0x00000000}},	//   _chŵn_, bijā, _קיץ_,
  { {0x63a20185,0xdce7001c,0x6b96001f,0x00000000}},	//   _ohon, cijā, blyg,
  { {0xf6e70086,0x63a27063,0x99540066,0x00000000}},	//   іцен, _nhon, väť_,
  { {0xf7700032,0xbc68007e,0xeb3a0047,0x00000000}},	//   خال_, _همین_, _הערש,
  { {0x20050240,0x39940072,0x63a27064,0x00000000}},	//   ytli_, yäsi_, _ahon,
  { {0x63a20025,0x9cd8009a,0xf992009a,0x00000000}},	//   _bhon, חווה_, _נרל_,
  { {0x96f80076,0x399400fe,0x63a21200,0x00000000}},	//   _мест_, väsi_, _chon,
  { {0xddc60045,0xe1f10021,0xf6280054,0x00000000}},	//   zykł, رسة_, _міфи_,
  { {0x99540024,0x399400fe,0xc6920047,0x00000000}},	//   päť_, täsi_, _טאן_,
  { {0x63a20025,0xad9b01a8,0x628200ca,0x00000000}},	//   _fhon, rtúl, _exoo,
  { {0x7c2a04a6,0x3ea40066,0xa8560063,0x00000000}},	//   _áfri, ýmto_, פירה_,
  { {0x399400fe,0xde36000d,0x200501c2,0x00000000}},	//   säsi_, чэнь, stli_,
  { {0x63a90764,0x1d0a005e,0xe1640021,0x00000000}},	//   lmen, љеви_, _يدوي,
  { {0x63a97065,0x6b960078,0xdbd70050,0x00000000}},	//   omen, tlyg, jääh,
  { {0xbb430dd5,0xdce7001c,0x63a97066,0x00000000}},	//   неск, rijā, nmen,
  { {0x7f77014e,0xb1830080,0x443a0013,0x00000000}},	// [fb60] _מעקב_, šťuj, ̣p_,
  { {0x63a9103b,0xdb060072,0x6d55004d,0x00000000}},	//   hmen, _sikä, ckza,
  { {0x63a97067,0x8d850021,0xb19a0041,0x00000000}},	//   kmen, _تشين, ציעכ,
  { {0xf98900b5,0x63a9027d,0x2d980137,0x00000000}},	//   אר_, jmen, llre_,
  { {0x63a93edc,0x63a2035a,0xba76014d,0x00000000}},	//   dmen, _rhon, _راحت,
  { {0x63a96d20,0x63a22cca,0xd5b90083,0x00000000}},	//   emen, _shon, ісі_,
  { {0x29370047,0x63a26706,0x94230141,0x00000000}},	//   _צאלן_, _phon, емје,
  { {0x987b0047,0x63a90951,0x938a005e,0x00000000}},	//   _האלט, gmen, љска_,
  { {0x93bc0529,0xa3dc0161,0xb17d0066,0x00000000}},	//   _arăt, _तौर_, vrťr,
  { {0x63a97068,0x6f190051,0x394a3687,0x00000000}},	//   amen, _ówcz, _jobs_,
  { {0x291a005f,0x63a27069,0x394a0168,0x00000000}},	//   iepa_, _thon, _mobs_,
  { {0x389b00b5,0x643b0047,0x27e70014,0x00000000}},	//   מיינ, _לעבנ, ánni_,
  { {0x7d0301e3,0x91a6008b,0xa3c20053,0x00000000}},	//   _önsk, _trò_, _एंड_,
  { {0x291a007d,0x6143706a,0x8bc72303,0x00000000}},	//   jepa_, _печа, зсад,
  { {0x6d550122,0xab950086,0x40eb0063,0x00000000}},	//   rkza, диві, _הַחֲ,
  { {0x3a2200ac,0x307b0063,0x4f680085,0x00000000}},	//   _bskp_, _לאונ, _ншым_,
  { {0x394a706b,0x6d410050,0xa3dc0082,0x00000000}},	// [fb70] _bobs_, ölas, तीत_,
  { {0xa8a72785,0x63a9706c,0x3994004b,0x00000000}},	//   прек, zmen, käsu_,
  { {0x63a9706d,0xf990013a,0xa3e80042,0x00000000}},	//   ymen, ابق_, _बिग_,
  { {0x64450656,0x00000000,0x00000000,0x00000000}},	//   ähim,   ,   ,
  { {0x9f5f051e,0x5a34013c,0x63a9039a,0x00000000}},	//   ittà_, _знят, vmen,
  { {0xe6180086,0xdbd70072,0x63a90c4c,0x00000000}},	//   яді_, pääh, wmen,
  { {0xf5320002,0x63a9706e,0xa3d70042,0x00000000}},	//   тејќ, tmen, ़ीं_,
  { {0xd1c90062,0x63a9277f,0x67c50078,0x00000000}},	//   олие_, umen, _gėja,
  { {0x10f5000d,0xf8e10053,0x63a9706f,0x00000000}},	//   мяня, _फ़ाय, rmen,
  { {0x63a97070,0x4fe901ce,0xd5b104a0,0x00000000}},	//   smen, омон_, _شفا_,
  { {0x63a97071,0x212b0080,0xdb17017d,0x00000000}},	//   pmen, ěch_, _auxí,
  { {0x25bf004b,0x836701fb,0x399400a5,0x00000000}},	//   _kuul_, _عدال, läst_,
  { {0x6f63000d,0x25bf7072,0xb6060130,0x00000000}},	//   твяз, _juul_, _gušć,
  { {0x25bf0019,0x3f990089,0xa135007e,0x00000000}},	//   _muul_, alsu_, _زرتش,
  { {0xdbf2004c,0x61fb01a9,0x1c39030b,0x00000000}},	//   přít, luul, пять_,
  { {0xf092014e,0x2127055f,0xe9da7073,0x00000000}},	//   _שנה_, _hanh_, жка_,
  { {0xe3b8005b,0xb2260026,0x09e33f79,0x00000000}},	// [fb80] _asıl_, mræð, котн,
  { {0xb2260026,0x15fc0042,0x66060072,0x00000000}},	//   lræð, उंसर_, _äkki,
  { {0x6d5e7074,0x21270013,0x7d1c7075,0x00000000}},	//   _ilpa, _manh_, mers,
  { {0x61fb0ff2,0x21277076,0x7d1c4a84,0x00000000}},	//   kuul, _lanh_, lers,
  { {0x5976000d,0x21270013,0x7ae47077,0x00000000}},	//   _жыву, _oanh_, mait,
  { {0x61fb00fe,0x7ae47078,0x2ee010ed,0x00000000}},	//   duul, lait, _leif_,
  { {0xd8230635,0xc10e0013,0x13940330,0x00000000}},	//   _идри, _bỗng_, никю,
  { {0x7ae40027,0xdb0f003b,0x7d1c3973,0x00000000}},	//   nait, _zicâ, hers,
  { {0x61fb002c,0x7d1c7079,0x21270013,0x00000000}},	//   guul, kers, _banh_,
  { {0x7ae4707a,0x224b00c7,0x2127008b,0x00000000}},	//   hait, äcka_, _canh_,
  { {0x2127001b,0xb226007a,0x7ae4707b,0x00000000}},	//   _danh_, fræð, kait,
  { {0xb226007a,0x7ae400fe,0x6d5e707c,0x00000000}},	//   græð, jait, _alpa,
  { {0x93bc000c,0x7ae42389,0x61fb006f,0x00000000}},	//   _trăs, dait, cuul,
  { {0x6b510147,0xada4000d,0x2127008d,0x00000000}},	//   _lågt, каўл, _ganh_,
  { {0x6e240290,0x7ae4707d,0x23a100ea,0x00000000}},	//   _esib, fait, lója_,
  { {0x7ae4707e,0xc3340063,0x00000000,0x00000000}},	//   gait, עוּ_,   ,
  { {0x753a006f,0x4429008b,0x9f46004a,0x00000000}},	// [fb90] _ontz, ̉a_, nulý_,
  { {0x7d1c707f,0x2127008b,0x75281e2d,0x00000000}},	//   cers, _xanh_, _nadz,
  { {0x9cd6014e,0x39940137,0x7ae47080,0x00000000}},	//   _אותה_, väst_, bait,
  { {0x8c440002,0x7c25007d,0x2d917081,0x00000000}},	//   _реџе, _ishr, loze_,
  { {0xc10e0013,0x8f9c0063,0x3ce1004b,0x00000000}},	//   _rỗng_, קידי, _kehv_,
  { {0x78a20080,0xbdda0047,0x23a1013d,0x00000000}},	//   řova, פֿנט, dója_,
  { {0x68e500fe,0x21270013,0x07f80044,0x00000000}},	//   mahd, _ranh_, _يرفع_,
  { {0x753a00bd,0x68e50072,0x21274b74,0x00000000}},	//   _entz, lahd, _sanh_,
  { {0x75280089,0x6f1d2fe8,0x7d054a33,0x00000000}},	//   _fadz, desc, _ochs,
  { {0x2ee00025,0x2901584d,0x6f0401f4,0x00000000}},	//   _seif_, ngha_, _scic,
  { {0xad9b0025,0x7d1c5f17,0x6f1d17b1,0x00000000}},	//   ctúi, vers, fesc,
  { {0x6d890024,0x7d1c0045,0x6f1d27a0,0x00000000}},	//   hľad, wers, gesc,
  { {0x68e51761,0x3f9e003d,0x7ae451ad,0x00000000}},	//   kahd, ētu_, vait,
  { {0x7ae40185,0x61e97082,0xd1380051,0x00000000}},	//   wait, msel, gląd_,
  { {0x69cf003d,0x6f1d7083,0x30790047,0x00000000}},	//   _atce, besc, _מאַנ,
  { {0x7ae40025,0x6f1d7084,0x6d5e002b,0x00000000}},	//   uait, cesc, _wlpa,
  { {0x6e240035,0x7ae47085,0x61e97086,0x00000000}},	// [fba0] _usib, rait, nsel,
  { {0x7ae47087,0x9c260002,0x61e97088,0x00000000}},	//   sait, _здод, isel,
  { {0x61e900bd,0x6299001f,0x7ae43897,0x00000000}},	//   hsel, _lywo, pait,
  { {0xdc7700b5,0x61e97089,0x75284eb3,0x00000000}},	//   _טעיפ_, ksel, _sadz,
  { {0x7528008f,0x49c70085,0xb17d0066,0x00000000}},	//   _padz, _плян_, esťm,
  { {0x96d00053,0x61e914e3,0x344a0054,0x00000000}},	//   _ड्रॉ, dsel, зчин_,
  { {0x61e9708a,0x93bc00dd,0xb8950062,0x00000000}},	//   esel, _crăp, _артъ,
  { {0x23a100ea,0x62992891,0x61e90104,0x00000000}},	//   tója_, _bywo, fsel,
  { {0x6f1d051e,0xd1300032,0x36671321,0x00000000}},	//   vesc, لمة_, _зато_,
  { {0x506600d7,0xb034005e,0x44250b2a,0x00000000}},	//   етма, внош, _fsl_,
  { {0x6299708b,0x61e922cb,0x9f46708c,0x00000000}},	//   _eywo, asel, bulü_,
  { {0xdb1c00ea,0x9f46013d,0x629900a3,0x00000000}},	//   ipró, duló_, _fywo,
  { {0x6f1d708d,0x2d72008f,0x61e92f15,0x00000000}},	//   resc, aņem_, csel,
  { {0x6b5101e3,0x30140088,0x6f1d000c,0x00000000}},	//   _någr, _адкр, sesc,
  { {0x6f1d708e,0xac950fd0,0xdb1c004d,0x00000000}},	//   pesc, тавш, bprü,
  { {0x409b0063,0xddd00080,0x5bb80121,0x00000000}},	//   _מבוס, řeši, елся_,
  { {0x2385008f,0xcfb80063,0xe6af0023,0x00000000}},	// [fbb0] nēja_, _אלהי_, _ņižņ,
  { {0x29010009,0xd83800a8,0x9998030b,0x00000000}},	//   ugha_, _šča_, екут_,
  { {0x2d540019,0xdb1c00ea,0xdbf20080,0x00000000}},	//   _päev_, gpró, přát,
  { {0x57270032,0x61e9708f,0xf0930041,0x00000000}},	//   عراق, ysel, אנע_,
  { {0x2d72001c,0x672b00d1,0xa6e20014,0x00000000}},	//   zņem_, rdgj, æðam,
  { {0x4a5a0132,0x61e9550a,0x93bc003b,0x00000000}},	//   _חדשו, vsel, _prăp,
  { {0xd7f80138,0x6498011c,0xdb1e0164,0x00000000}},	//   _пут_, нтър_, _supé,
  { {0x9f5f00fe,0x0395005a,0x61e97090,0x00000000}},	//   nttä_, ърля, tsel,
  { {0x35b50088,0x9f4d0024,0x6b580139,0x00000000}},	//   _абар, budú_, _dígh,
  { {0x61e97091,0x2127005d,0x2d720023,0x00000000}},	//   rsel, ريجی_, tņem_,
  { {0x62990051,0xe5360047,0x61e902ce,0x00000000}},	//   _wywo, _שטעט_, ssel,
  { {0x78ba0014,0x61e97092,0x3f84004b,0x00000000}},	//   _útve, psel, õmu_,
  { {0xdb1c00bd,0xc7b200b5,0xfe25000d,0x00000000}},	//   rprü, יבט_, льён,
  { {0xdb1c0d25,0x2d5400fe,0xa0590021,0x00000000}},	//   sprü, _näet_, _يؤثر_,
  { {0x69cb7093,0xeb9a335f,0x1ae60002,0x00000000}},	//   ígen, див_, ковм,
  { {0x332d7094,0xfaa6000d,0x9f46013d,0x00000000}},	//   ndex_, вабо, ruló_,
  { {0xdd8a000a,0x6b510093,0xeb9722fa,0x00000000}},	// [fbc0] _обид_, _pågr, тит_,
  { {0xa3c10235,0x3d110053,0x9f46013d,0x00000000}},	//   ंदा_, द्दे_, puló_,
  { {0x6b510137,0xd70a0121,0x2385008f,0x00000000}},	//   _vågr, днее_, zēja_,
  { {0xe1f90006,0x6e3600b9,0xdb1c0014,0x00000000}},	//   krų_, _kryb, rpró,
  { {0xe7ee0053,0x6d5c04c8,0x5f050042,0x00000000}},	//   _चटका_, okra, _वास्_,
  { {0x2385001c,0x6d5c7095,0xe1f90078,0x00000000}},	//   vēja_, nkra, drų_,
  { {0x637e008f,0xa3dc0053,0x9f4d0139,0x00000000}},	//   līni, तीं_, rudú_,
  { {0x040d001b,0x2d540019,0x2385008f,0x00000000}},	//   _hướn, _käes_, tēja_,
  { {0x6d5c0026,0x24920051,0x60cd18ad,0x00000000}},	//   kkra, łym_, _şama,
  { {0x6f160080,0x2385001c,0x3f820b33,0x00000000}},	//   _abyc, rēja_, enku_,
  { {0x9f5f024a,0x39570063,0x934612ab,0x00000000}},	//   yttä_, דשים_, _инже,
  { {0xe4790047,0x2385001c,0x6d5c7096,0x00000000}},	//   _אָנש, pēja_, ekra,
  { {0x6d5c007a,0x8d77007e,0x6e36002b,0x00000000}},	//   fkra, ناسا, _cryb,
  { {0xd12f0032,0xd2570063,0xc10d0013,0x00000000}},	//   _ومن_, _בשדה_, _mơịt_,
  { {0x30a3005a,0xc04f0086,0x2ca50137,0x00000000}},	//   _кръв, _ті_, åld_,
  { {0xe0b70047,0x6d5c7097,0x7b647098,0x00000000}},	//   _בלוט_, akra, атуе,
  { {0xeab00032,0x5f74007e,0x64580072,0x00000000}},	// [fbd0] قعك_, _خاور, hyvi,
  { {0x7bc100ea,0x64580ab6,0x6d5c06bf,0x00000000}},	//   ílus, kyvi, ckra,
  { {0xc7f50001,0x2d83007d,0x4e94005d,0x00000000}},	//   узећ, mnje_, _مشیر,
  { {0x29070045,0xe1f90078,0x57a40085,0x00000000}},	//   żna_, yrų_, ашча,
  { {0xd2467099,0xe7300032,0x7bc50332,0x00000000}},	//   _ان_, تصل_, _huhu,
  { {0x7bc510ca,0x6b581289,0x24092254,0x00000000}},	//   _kuhu, _rígi, енки_,
  { {0x7bc5709a,0x37c40002,0x2d83061f,0x00000000}},	//   _juhu, _вљуб, inje_,
  { {0xe1f90006,0x03251489,0xe7870a29,0x00000000}},	//   trų_, удин, _руго,
  { {0x7bc50150,0xdce70006,0xad9b0139,0x00000000}},	//   _luhu, siję, ntús,
  { {0x95c80635,0xdb0f017d,0x2d83007d,0x00000000}},	//   _јута_, _ficç, jnje_,
  { {0x2d8301a6,0x7659001f,0xdee607f6,0x00000000}},	//   dnje_, lywy, лони,
  { {0x9f440003,0x6d5c00ca,0xe1f9005f,0x00000000}},	//   éjà_, wkra, prų_,
  { {0x9f600014,0x6d5c709b,0xa159005e,0x00000000}},	//   _þrír_, tkra, _паду_,
  { {0x6d5c0618,0x8e752049,0x2d830077,0x00000000}},	//   ukra, руюч, gnje_,
  { {0x6d5c709c,0xd00e0044,0x23850023,0x00000000}},	//   rkra, _فلو_, nējo_,
  { {0xa09a00b5,0x6e360051,0x61fb005b,0x00000000}},	//   _איצט, _tryb, orul,
  { {0xa3ab0053,0x6d48004b,0x6d5c005f,0x00000000}},	// [fbe0] _गठन_, ödas, pkra,
  { {0x6d5a0019,0xb882004c,0x637e0023,0x00000000}},	//   ötad, římn, rīni,
  { {0x040d0013,0xdb06013d,0x661b0072,0x00000000}},	//   _vướn, _kikü, _apuk,
  { {0x2385003d,0xf7290086,0x61fb00ca,0x00000000}},	//   dējo_, кцій_, krul,
  { {0x7bc500e3,0xe5050161,0x040d001b,0x00000000}},	//   _zuhu, _राशि_, _tướn,
  { {0x64583635,0x7ae6238e,0xad9b38b6,0x00000000}},	//   tyvi, _hekt, ltúr,
  { {0x98a3003d,0x6b840019,0xa928001c,0x00000000}},	//   _tajā_, onig, režģ,
  { {0xad9b0024,0x6b84709d,0xf363000d,0x00000000}},	//   ntúr, nnig, йтын,
  { {0xd250007e,0xdcfc001c,0xb6a30121,0x00000000}},	//   زند_, norē, _гитл,
  { {0xd130007e,0x69c00003,0x238c004c,0x00000000}},	//   آمد_, _émeu, děje_,
  { {0xe1ef006a,0x69c6024a,0x660200fe,0x00000000}},	//   يسی_, _luke, luok,
  { {0x7bc50009,0x7ae6709e,0xde59000d,0x00000000}},	//   _ruhu, _nekt, вамі_,
  { {0x9f5f0240,0x6b844cfb,0x2d83027c,0x00000000}},	//   nuté_, dnig, tnje_,
  { {0x7bc5047f,0x40340156,0xbd450021,0x00000000}},	//   _puhu, _векс, جنسي,
  { {0x2d83082a,0x69c60072,0x6b5801a8,0x00000000}},	//   rnje_, _auke, _lígu,
  { {0x29184582,0x61170058,0x2d83007d,0x00000000}},	//   _abra_, ağlı, snje_,
  { {0x6722234b,0x2d831253,0x66020b4f,0x00000000}},	// [fbf0] deoj, pnje_, juok,
  { {0xd944005e,0x66020078,0x6b84004b,0x00000000}},	//   беђи, duok, anig,
  { {0x290f0051,0x2bf40085,0x7ae6709f,0x00000000}},	//   ęga_, _ляўр, _fekt,
  { {0xad9b0139,0x7d070046,0x23850023,0x00000000}},	//   ctúr, lgjs, vējo_,
  { {0x66020006,0xaaa80062,0x06c80054,0x00000000}},	//   guok, _бърз_, угій_,
  { {0x7c3500c2,0x2385001c,0x61fb0058,0x00000000}},	//   ovzr, tējo_, vrul,
  { {0x67d40055,0x9f5f0003,0x7ae61a59,0x00000000}},	//   _госу, auté_, _yekt,
  { {0xe2990088,0x27fc0024,0x9f5f0003,0x00000000}},	//   кай_, ávne_, buté_,
  { {0x69c00003,0x61fb15e1,0xe6672101,0x00000000}},	//   _émet, urul, _ство,
  { {0xdb0a0024,0x2385001c,0x68e7004c,0x00000000}},	//   ľnéh, pējo_, _jejd,
  { {0x2d840080,0x752370a0,0xdb0a027d,0x00000000}},	//   émem_, menz, žnéh,
  { {0x752370a1,0x200a00cd,0x683019ba,0x00000000}},	//   lenz, àbia_, lódá,
  { {0x61455082,0x4427001f,0x3ea90022,0x00000000}},	//   _вела, lwn_, _czat_,
  { {0x69c60031,0x752370a2,0x68e701c2,0x00000000}},	//   _ruke, nenz, _nejd,
  { {0x66020006,0xad9b0014,0x61e236fc,0x00000000}},	//   zuok, ttúr, _zwol,
  { {0x6b8470a3,0x752370a4,0x69c670a5,0x00000000}},	//   unig, henz, _puke,

  { {0x2fc71898,0x7ae670a6,0xdb1d00f4,0x00000000}},	// [fc00] _hung_, _vekt, _misè,
  { {0x2fc70273,0xad9b0555,0x613400ea,0x00000000}},	//   _kung_, stúr, pülő,
  { {0x752370a7,0x46ea0854,0x67220331,0x00000000}},	//   denz, вден_, teoj,
  { {0x69c600fe,0x2d98055b,0x4427001f,0x00000000}},	//   _tuke, lore_, dwn_,
  { {0x44270185,0x2fc709ee,0x68e70b2a,0x00000000}},	//   ewn_, _lung_, _fejd,
  { {0xad9b0025,0x66020b4f,0x752370a8,0x00000000}},	//   crúd, ruok, genz,
  { {0x4427001f,0x6d4e006f,0x2fc70013,0x00000000}},	//   gwn_, ijba, _nung_,
  { {0x9f5f0164,0xe3af0021,0x66020078,0x00000000}},	//   puté_, وري_, puok,
  { {0x752370a9,0x4427035a,0x2fc76b8d,0x00000000}},	//   benz, awn_, _aung_,
  { {0x2fc7028d,0x6d890024,0x752370aa,0x00000000}},	//   _bung_, eľan, cenz,
  { {0x2fc7001b,0xfe7f00cd,0x656a0025,0x00000000}},	//   _cung_, raïm_, mhfh,
  { {0x2fc7001b,0xdcf5001c,0xc2070043,0x00000000}},	//   _dung_, pozī, دقین_,
  { {0x2d980037,0x61e20022,0x7985002b,0x00000000}},	//   fore_, _uwol, ynhw,
  { {0x2d9870ab,0x61fd01c2,0x6d48004b,0x00000000}},	//   gore_, ásle, ödap,
  { {0xcc540062,0xe0cf0021,0x1bd50062,0x00000000}},	//   овръ, _غزو_, собя,
  { {0x75231cef,0x2bbb0021,0x6830013d,0x00000000}},	//   zenz, ئاسة_, zódá,
  { {0x98a30045,0xcf78007e,0x2d9870ac,0x00000000}},	// [fc10] _mają_, _خصوص_, bore_,
  { {0x2d9803b2,0x2fc70a9f,0x7f9d0003,0x00000000}},	//   core_, _yung_, réqu,
  { {0x752370ad,0xe7270086,0x2fc7008b,0x00000000}},	//   venz, иєдн, _xung_,
  { {0xf77008aa,0x3f991871,0x7523083f,0x00000000}},	//   وان_, nosu_, wenz,
  { {0x752370ae,0xfb1a0063,0x7aed70af,0x00000000}},	//   tenz, _גורמ, maat,
  { {0x2ee90034,0x7aed70b0,0x4427002b,0x00000000}},	//   _leaf_, laat, twn_,
  { {0x752370b1,0xdb1d0003,0xad1c0063,0x00000000}},	//   renz, _aisé, דוור,
  { {0x7523033f,0x2d980c61,0x69c00003,0x00000000}},	//   senz, zore_, _émer,
  { {0x75230035,0x2fc770b2,0x4427002b,0x00000000}},	//   penz, _sung_, swn_,
  { {0x7aed006f,0x656a0025,0x0fd9026c,0x00000000}},	//   haat, chfh, льмы_,
  { {0x33190086,0x7aed70b3,0x6b580014,0x00000000}},	//   _біля_, kaat, _mígr,
  { {0x320406ce,0x2fc70013,0x3f990745,0x00000000}},	//   bumy_, _vung_, gosu_,
  { {0x2d9802f6,0xd00e007e,0x7aed70b4,0x00000000}},	//   tore_, ولی_, daat,
  { {0x61d6014e,0x2fc770b5,0x78a2011b,0x00000000}},	//   _הוסף_, _tung_, řovi,
  { {0x2d9802f6,0x645c0004,0x6e2d005b,0x00000000}},	//   rore_, _ürit, _esab,
  { {0xad9b0024,0xd1130161,0x256b0205,0x00000000}},	//   stúp, त्रण_, _følg_,
  { {0xdd1c0080,0xdb1e0139,0x200570b6,0x00000000}},	// [fc20] mážd, _cupá, luli_,
  { {0xfe370047,0xcd060062,0x38cb005d,0x00000000}},	//   _פריי_, _упой, هامی_,
  { {0xb17a00b5,0x86c6007e,0x19b90086,0x00000000}},	//   נטער, ميان, руть_,
  { {0x7bdc02dd,0x7aed0122,0xdcf5001c,0x00000000}},	//   mpru, caat, mizā,
  { {0x2005002c,0xdcf5001c,0x656a0025,0x00000000}},	//   huli_, lizā, thfh,
  { {0x52e00053,0x442c0493,0xbbe9007e,0x00000000}},	//   नर्स, _psd_, _حریم_,
  { {0xdcf5001c,0x8884007e,0xb97b0041,0x00000000}},	//   nizā, _بیان, _ענלי,
  { {0xd326019d,0x51f80055,0x32040024,0x00000000}},	//   ськи, анию_, tumy_,
  { {0xda7b0047,0x62340002,0x637e0078,0x00000000}},	//   ָניר, цепу, gūna,
  { {0x6f0d0290,0x442c004b,0xdb1d0003,0x00000000}},	//   _scac, _tsd_, _visé,
  { {0x200570b7,0x04960021,0x657a0139,0x00000000}},	//   guli_, _الضح, _imth,
  { {0x3f6770b8,0xd5be008f,0x637e0078,0x00000000}},	//   стоб, žāda_, būna,
  { {0x7aed70b9,0xdcfc0078,0x539b0063,0x00000000}},	//   vaat, norė, _גיאו,
  { {0x41b6005a,0x661d00fe,0x200570ba,0x00000000}},	//   _усет, _äske, buli_,
  { {0x317b0063,0x7aed70bb,0x99890022,0x00000000}},	//   _תרומ, taat, ytał_,
  { {0x317e1eca,0x7c3a0046,0x3d1a0042,0x00000000}},	//   litz_, ætra, म्बे_,
  { {0x7bdc0bbb,0xad9b0025,0x9f5f0114,0x00000000}},	// [fc30] apru, grúc, nutí_,
  { {0x7aed003a,0xb8820114,0x98c70a91,0x00000000}},	//   saat, čína, ссал,
  { {0x6d454584,0x48ab000d,0x7aed0cb0,0x00000000}},	//   _inha, утам_, paat,
  { {0x27fc0124,0xf1c80042,0x1efc009a,0x00000000}},	//   ávna_, रदान, ָּׁמ,
  { {0xc5fb000a,0x99893f63,0x6b580014,0x00000000}},	//   уѓе_, evať_, _tígr,
  { {0x99890045,0x637e0006,0x2385008f,0x00000000}},	//   stał_, vūna, mēji_,
  { {0x99890022,0xa3492a3b,0xf59200de,0x00000000}},	//   ptał_, изка_, بلوج,
  { {0x6fcf0161,0xe1f943d4,0x6d430046,0x00000000}},	//   _संबं, аги_, _ónaf,
  { {0x99890066,0x6d4519bd,0xdc3c004c,0x00000000}},	//   avať_, _onha, váče,
  { {0xbebb00e8,0xd83800c2,0x637e0078,0x00000000}},	//   reël, _šči_, rūna,
  { {0xdb040139,0xcea90149,0xb80b0054,0x00000000}},	//   rmiú, _סי_, влiн,
  { {0x60dc01f7,0x6d45330b,0x25f00053,0x00000000}},	//   ırma, _anha, ुंची_,
  { {0xd109007e,0x200570bc,0xdb06013d,0x00000000}},	//   _نقشه_, suli_, _kikö,
  { {0x7bdc00ac,0x2d9e0003,0x256b000e,0x00000000}},	//   tpru, ôte_, _føle_,
  { {0xdb0a0080,0xdb0600ea,0xeb7a0002,0x00000000}},	//   žníh, _mikö, асај_,
  { {0x7f4404bc,0x6d4570bd,0x99800006,0x00000000}},	//   _uniq, _enha, yvių_,
  { {0x99890024,0xfaa370be,0x7bdc70bf,0x00000000}},	// [fc40] zvať_, дато, spru,
  { {0x8a030076,0x291c0066,0x2cad004c,0x00000000}},	//   ьзуе, ýva_, ředa_,
  { {0x6ac60044,0x9d1b009a,0x00000000,0x00000000}},	//   _وقدم, _דויט,   ,
  { {0x99800078,0x2c780066,0xd6d00044,0x00000000}},	//   tvių_, aždú_, رقت_,
  { {0x6d890066,0xa4d4013c,0x98aa008f,0x00000000}},	//   dľaj, полі, _dabā_,
  { {0xdcf5000c,0x9633000d,0xfe9b0063,0x00000000}},	//   miză, ьніц, סיסמ,
  { {0xdcf50529,0x04430699,0x317e0151,0x00000000}},	//   liză, дејн, vitz_,
  { {0x39580164,0x938a0095,0x9f890046,0x00000000}},	//   _hors_, јска_, jóðs_,
  { {0xa50a0001,0x39580666,0xdcf5003b,0x00000000}},	//   _веза_, _kors_, niză,
  { {0x55030376,0x20740085,0xd1300044,0x00000000}},	//   _опуб, злоў, رمج_,
  { {0x3a220089,0xd336000d,0x39581023,0x00000000}},	//   _lpkp_, _мэды, _mors_,
  { {0x395803b2,0x317e00bd,0x6d5a10c8,0x00000000}},	//   _lors_, sitz_, ötan,
  { {0x3ead010a,0x224b00c7,0x443e70c0,0x00000000}},	//   ået_, äckt_, _hrt_,
  { {0x395800eb,0x7d1b017f,0x2385001c,0x00000000}},	//   _nors_, đuso, vēji_,
  { {0xe88b0066,0x2bcb01f6,0x1bd40505,0x00000000}},	//   _ťažš, руго_, дося,
  { {0x3a220150,0xe8e0008b,0x443e05e9,0x00000000}},	//   _bpkp_, _đền_, _mrt_,
  { {0x49d80076,0x395870c1,0x7c3e004d,0x00000000}},	// [fc50] ждую_, _bors_, _erpr,
  { {0x443e70c2,0x395870c3,0xad9b0014,0x00000000}},	//   _ort_, _cors_, brúa,
  { {0x66020150,0x395800c6,0x77695550,0x00000000}},	//   erok, _dors_, _plex,
  { {0x23850023,0xd774005d,0x35f90044,0x00000000}},	//   pēji_, وانع, مرتد_,
  { {0x8d74007e,0x9f6200ea,0x3f8b0003,0x00000000}},	//   _رایا, épés_, incu_,
  { {0xe5780086,0x3958002b,0x443e70c4,0x00000000}},	//   озі_, _gors_, _brt_,
  { {0xdb1d1795,0xb8e10053,0xad1c009a,0x00000000}},	//   _lisí, ुश_, יוגר,
  { {0x37040001,0x66024b3e,0x99890022,0x00000000}},	//   _очув, brok, stań_,
  { {0x443e007a,0x0ca80042,0x422205ac,0x00000000}},	//   _ert_, _गर्म, едыв,
  { {0x60090f82,0x99800075,0xe3b80075,0x00000000}},	//   бном_, itiş_, _upın_,
  { {0x225f0150,0x237f0051,0x8fa60062,0x00000000}},	//   syuk_, piuj_, зане,
  { {0x224b0137,0x78a80093,0xd6d9056c,0x00000000}},	//   äcks_, _ødve, _poły_,
  { {0x3ea40026,0x12280054,0x32451849,0x00000000}},	//   æmt_, _моїй_, _хелг,
  { {0xe80c0053,0xad9b0014,0xe3b9013d,0x00000000}},	//   _हमला_, trúa, lmű_,
  { {0x2b5900cd,0xdb040003,0x9f5f01a8,0x00000000}},	//   _bosc_, llié, butà_,
  { {0x5aca000a,0x2b590025,0xdcf5003b,0x00000000}},	//   слам_, _cosc_, tiză,
  { {0xe8fa137a,0x3f8270c5,0x6d8970c6,0x00000000}},	// [fc60] йла_, miku_, džaf,
  { {0x3f8270c7,0xdcf5000c,0x2385001c,0x00000000}},	//   liku_, riză, mēju_,
  { {0x2b5900cd,0x7e6000bd,0xc72603d6,0x00000000}},	//   _fosc_, ämpf, здей,
  { {0xe5c60095,0x660270c8,0x443e0150,0x00000000}},	//   пско, trok, _rrt_,
  { {0xe5340bb3,0x7ae40ca5,0x9f5f4b28,0x00000000}},	//   дель, mbit, nutá_,
  { {0x660200fe,0xa5330085,0x3f8225e8,0x00000000}},	//   rrok, еншч, hiku_,
  { {0x7bc60009,0x6ba70016,0x7ae42dc3,0x00000000}},	//   _kiku, _órgã, obit,
  { {0x68ee48cf,0x443e70c9,0xb882004c,0x00000000}},	//   _hebd, _vrt_, řísn,
  { {0x7ae40290,0x7bc670ca,0x784e00ea,0x00000000}},	//   ibit, _miku, _fővá,
  { {0x26c00078,0xc1730121,0x2385008f,0x00000000}},	//   žios_, ельщ, dēju_,
  { {0x6e240006,0x3013000d,0x3f8270cb,0x00000000}},	//   _apib, ндэр, fiku_,
  { {0x69da0080,0xdb040164,0x201100cd,0x00000000}},	//   _čten, blié, àzia_,
  { {0x623408a7,0x63a270cc,0x614670cd,0x00000000}},	//   _целу, _ikon, _неда,
  { {0xdb1d0016,0x7bc600fe,0x7ae470ce,0x00000000}},	//   _visí, _aiku, ebit,
  { {0x2ca500b9,0xf3890013,0x7ae4004b,0x00000000}},	//   æld_, iản_, fbit,
  { {0xf389008b,0xdb1d004a,0xd13823a8,0x00000000}},	//   hản_, _tisí, ldą_,
  { {0x63a20009,0x7bc6003e,0xd1380006,0x00000000}},	// [fc70] _mkon, _diku, odą_,
  { {0xd138091b,0x9f460137,0x3ec3004c,0x00000000}},	//   ndą_, rslå_, ěstě_,
  { {0xd1380006,0x2d83027c,0x63a2158e,0x00000000}},	//   idą_, mije_, _okon,
  { {0x2d83027c,0xcb0b0121,0xc5880013,0x00000000}},	//   lije_, _уход_, uồn_,
  { {0x7afd01e1,0xe60e0062,0xbb3a0063,0x00000000}},	//   _idst, ъд_, _וערי,
  { {0x2d830add,0x63a270cf,0x69dd0bcf,0x00000000}},	//   nije_, _akon, _itse,
  { {0x26d201f7,0x320400ac,0x2385008f,0x00000000}},	//   ıyor_, ermy_, zēju_,
  { {0x69c7017f,0x6f1d006f,0xd1380006,0x00000000}},	//   _hije, jfsc, edą_,
  { {0x6b8d70d0,0x44290024,0x3f82170d,0x00000000}},	//   inag, ňa_, viku_,
  { {0x63a2059e,0x2385001c,0x6f1d0717,0x00000000}},	//   _ekon, vēju_, efsc,
  { {0x69c7017f,0x6d5a0019,0x2d83027c,0x00000000}},	//   _mije, ötam, dije_,
  { {0x69c7017f,0x69dd0019,0x7afd1686,0x00000000}},	//   _lije, _otse, _ndst,
  { {0x7bc60019,0x69cf0080,0x2d8301b3,0x00000000}},	//   _riku, _nuce, fije_,
  { {0x63a202f4,0x22420146,0x6f1d006f,0x00000000}},	//   _zkon, ække_, afsc,
  { {0x69dd003d,0x8c950086,0x7ae400d1,0x00000000}},	//   _atse, ерті, tbit,
  { {0x63a901f7,0x5baa000d,0x2385183d,0x00000000}},	//   nlen, ікам_, pēju_,
  { {0x7bc65941,0xb2ba00b5,0x2d8370d1,0x00000000}},	// [fc80] _viku, ַמער, bije_,
  { {0x69c70117,0x2d831847,0x63bb00bd,0x00000000}},	//   _cije, cije_, hmun,
  { {0x69c71832,0x63a970d2,0xb8f60053,0x00000000}},	//   _dije, klen, _हल_,
  { {0xdb1d0016,0xd1380006,0xf9890063,0x00000000}},	//   _visã, zdą_, בר_,
  { {0xbddb0003,0x63a970d3,0x2bd20053,0x00000000}},	//   rvèg, dlen, _दूता,
  { {0x63a270d4,0x6b840ff2,0xf389008b,0x00000000}},	//   _skon, liig, uản_,
  { {0x63a933a2,0xf993009a,0x33f30cac,0x00000000}},	//   flen, _ירש_, نسيس,
  { {0xdb0d03d9,0x6d5a0004,0x63a91446,0x00000000}},	//   rmaç, ötaj, glen,
  { {0x44250019,0x644170d5,0x200570d6,0x00000000}},	//   _epl_, _erli, erli_,
  { {0x7bde017f,0x63bb70d7,0x63a970d8,0x00000000}},	//   _otpu, amun, alen,
  { {0xd13800eb,0x2d83027c,0x63a970d9,0x00000000}},	//   rdą_, vije_, blen,
  { {0x63bb02dd,0x63a20a63,0x63a970da,0x00000000}},	//   cmun, _ukon, clen,
  { {0x2d83074f,0x6d89027d,0x200501f4,0x00000000}},	//   tije_, yžad, arli_,
  { {0x7aef1e3e,0x550e0042,0x9f5f004c,0x00000000}},	//   _sect, सलिए_, mrtí_,
  { {0x69c70a0d,0x69cf70db,0x2d836032,0x00000000}},	//   _rije, _suce, rije_,
  { {0x69c7017f,0x2d8400cd,0x2d83027c,0x00000000}},	//   _sije, émer_, sije_,
  { {0xdb1d0024,0x200c70dc,0x2d8301b3,0x00000000}},	// [fc90] _cisá, ludi_, pije_,
  { {0x9f5f0025,0x63a970dd,0x7e6000a5,0x00000000}},	//   irtí_, zlen, ämpe,
  { {0x69c70117,0x63bb1370,0x6b8400a4,0x00000000}},	//   _vije, ymun, biig,
  { {0xf8df0394,0x28df0161,0x7afd0146,0x00000000}},	//   _प्रय, _प्रि, _udst,
  { {0x69c70117,0x69dd0c4a,0x3c390080,0x00000000}},	//   _tije, _utse, bývá_,
  { {0x660b0162,0x44250509,0x63a9004d,0x00000000}},	//   rugk, _ppl_, wlen,
  { {0x64a20184,0xb5c2000d,0x63a970de,0x00000000}},	//   лаша, ыйшл, tlen,
  { {0x63bb70df,0x2385001c,0x425505fb,0x00000000}},	//   umun, vējs_, етот,
  { {0x63a970e0,0x6d5a004b,0x63bb70e1,0x00000000}},	//   rlen, ötak, rmun,
  { {0x63bb007a,0x60093f17,0x35b40085,0x00000000}},	//   smun, пном_, _абур,
  { {0x3ea906a7,0x63a93709,0x63bb70e2,0x00000000}},	//   _ayat_, plen, pmun,
  { {0x3c390080,0xc275007b,0x2385008f,0x00000000}},	//   zývá_, _плеј, rējs_,
  { {0x6f63000d,0x2385008f,0x6d89005f,0x00000000}},	//   увяз, sējs_, džab,
  { {0x3ead00cd,0x200500c2,0xf3890013,0x00000000}},	//   üeta_, prli_, iảm_,
  { {0xc4d2014e,0x6ea00053,0x3f6a0259,0x00000000}},	//   רגל_, _गुरु, _нико_,
  { {0x645c01a8,0xe9da2ea3,0x00000000,0x00000000}},	//   _àrie, зка_,   ,
  { {0x6b840004,0xdcfc001c,0xe1f90006,0x00000000}},	// [fca0] riig, airā, nsų_,
  { {0x850e0161,0xe1f90006,0x5983030b,0x00000000}},	//   _साइट_, isų_, глуб,
  { {0x7bde1036,0xc8960001,0x3c39004c,0x00000000}},	//   _utpu, храњ, rývá_,
  { {0x68e301f7,0x65ad0024,0xd6c4007e,0x00000000}},	//   ında, súhl, نمای,
  { {0x6d5e3c80,0x163418bf,0xbbbe0042,0x00000000}},	//   _kopa, теля, ्दीक,
  { {0x26cd3208,0x9f5f011b,0xceb3009a,0x00000000}},	//   _egeo_, vrtí_, איד_,
  { {0x533400a0,0x6d5e70e3,0x63a070e4,0x00000000}},	//   вейт, _mopa, tomn,
  { {0xd3770076,0x6d5e43c6,0x31c80042,0x00000000}},	//   ечь_, _lopa, रद्ध,
  { {0xc2980928,0x7d0170e5,0x238c004c,0x00000000}},	//   ьких_, ólsk, něji_,
  { {0x200c70e6,0x63a070e7,0x02e00042,0x00000000}},	//   tudi_, somn, _ग्रह_,
  { {0x63a070e8,0x200c0075,0xdc190023,0x00000000}},	//   pomn, uudi_, rāīt,
  { {0x20020add,0x200c0035,0x637e0078,0x00000000}},	//   čki_, rudi_, kūni,
  { {0x753a00bd,0x200c5133,0x51863444,0x00000000}},	//   _katz, sudi_, _пука,
  { {0x238c0080,0x6d5e70e9,0xee3f0066,0x00000000}},	//   ději_, _copa, rvý_,
  { {0x3ce00053,0x1fa72f9e,0x6d5e154d,0x00000000}},	//   कड़े_, _приг, _dopa,
  { {0xcb340062,0x80370044,0x9b580481,0x00000000}},	//   лесъ, _أسوأ_, нист_,
  { {0x5a350062,0x09070002,0x28c30042,0x00000000}},	// [fcb0] ънат, ечем, वेनि,
  { {0x93bc003b,0xdd050078,0x7cd90121,0x00000000}},	//   _spăl, _įpėd, _юмор_,
  { {0x7af60058,0xe787005e,0x481502b6,0x00000000}},	//   bayt, нудо, тмес,
  { {0xdddd0051,0x6d5e0114,0x35a90053,0x00000000}},	//   mysł, _zopa, _चीज़,
  { {0x26c2004c,0x5f040042,0x4efc0041,0x00000000}},	//   _úkol_, _वयस्_, להאו,
  { {0xdb160137,0xceb40063,0xdb040046,0x00000000}},	//   åbör, ניס_, lmið,
  { {0xd4e40086,0x753a0717,0x03950062,0x00000000}},	//   уючи, _datz, крия,
  { {0x91c60013,0x78b500a8,0x6604005f,0x00000000}},	//   _đúp_, _izzv, šika,
  { {0x45d50086,0xe1f90006,0xa535422b,0x00000000}},	//   _розс, usų_, _инач,
  { {0x673b0009,0xeeeb008b,0xe1f90078,0x00000000}},	//   _hauj, ướng_, rsų_,
  { {0x673b008f,0xdee60571,0x6d5e70ea,0x00000000}},	//   _kauj, кони, _ropa,
  { {0x2d91051e,0xdddd0051,0x6d5e0e83,0x00000000}},	//   enze_, dysł, _sopa,
  { {0x9f5f024a,0x6d5e70eb,0x42040021,0x00000000}},	//   yttö_, _popa, _مِنْ,
  { {0xdb1d09ff,0x60250088,0x637e0078,0x00000000}},	//   _lisä, _адка, vūni,
  { {0xddca00ea,0xdb040014,0xdca6182b,0x00000000}},	//   ínűl, fmið, тави,
  { {0x673b0812,0x98a70080,0x2d9104ad,0x00000000}},	//   _nauj, žně_, anze_,
  { {0x4b230002,0x6d5e70ec,0xad9b0066,0x00000000}},	// [fcc0] јмув, _topa, krúh,
  { {0x61fb4ade,0x186a09c2,0xda650044,0x00000000}},	//   isul, мази_, دافي,
  { {0x753a70ed,0xd884007e,0x3f97005d,0x00000000}},	//   _ratz, دهای, _سپید_,
  { {0x753a00bd,0x61fb70ee,0xf0b60041,0x00000000}},	//   _satz, ksul, דלער_,
  { {0x9f590164,0x36330044,0xc6760044,0x00000000}},	//   éré_, لروس, خطاب,
  { {0x6e29005b,0xe5e50021,0x4e7b0047,0x00000000}},	//   çebi, اثني, ואנצ,
  { {0xe9df008b,0x61fb70ef,0x29180058,0x00000000}},	//   _trúc_, esul, _icra_,
  { {0xd214005e,0xdcee0066,0xe8e00013,0x00000000}},	//   гмић, jobľ, _độn_,
  { {0x171b00b5,0x61fb002c,0x3253005a,0x00000000}},	//   _קומע, gsul, ивър,
  { {0x673b027d,0x21540085,0x71740cac,0x00000000}},	//   _zauj, укоў, اهدا,
  { {0x7bda0297,0x61fb3e35,0xc0570e74,0x00000000}},	//   ítul, asul, вія_,
  { {0x63750331,0x03a30263,0xb3630094,0x00000000}},	//   _cánd, _кихо, _въшк,
  { {0x6375006d,0x764270f0,0x5f94247b,0x00000000}},	//   _dánd, nvoy, рият,
  { {0x7e6000c7,0x9f5f0066,0x61e201f4,0x00000000}},	//   ämpa, nutú_, _itol,
  { {0xdb040026,0xc5880013,0xfaff008f,0x00000000}},	//   tmið, gồi_, žīmu_,
  { {0x6117005b,0x22462671,0xa057089e,0x00000000}},	//   aşlı, _krok_, _יסוד_,
  { {0xdb040026,0xa021004b,0xd91b0121,0x00000000}},	// [fcd0] rmið, _ööra, дье_,
  { {0xdb1d09ff,0xd7e7019d,0xdb04007a,0x00000000}},	//   _sisä, відо, smið,
  { {0x201e024a,0x9e67007e,0x213e3872,0x00000000}},	//   ntti_, _ساکن, idth_,
  { {0xd6db0086,0x201e00fe,0x6d5a0019,0x00000000}},	//   єте_, itti_, ötav,
  { {0x63b90185,0x98b1000c,0xf77001fb,0x00000000}},	//   _rhwn, _bază_, غام_,
  { {0xad9b0139,0x59640062,0xe5b40085,0x00000000}},	//   frúi, _къса, айчы,
  { {0x33f4000d,0xdd030078,0xdb04013d,0x00000000}},	//   ачыс, ūrėd, lliá,
  { {0x274200ea,0x61fb4bb4,0x1cb80063,0x00000000}},	//   ténő_, tsul, כלול_,
  { {0x68f5000f,0x201e07a0,0xd6d90051,0x00000000}},	//   _kezd, etti_, _całe_,
  { {0xf389008b,0x68f570f1,0xc10501fb,0x00000000}},	//   iải_, _jezd, دودي,
  { {0xbfc6005a,0xf389008b,0x61fb4f27,0x00000000}},	//   лбок, hải_, ssul,
  { {0x20180994,0xeeeb001b,0x213e00e5,0x00000000}},	//   ària_, ường_, adth_,
  { {0x5fcf0053,0x201e2e37,0x877a0063,0x00000000}},	//   _संकल, atti_, תארי,
  { {0x90450049,0x68f50574,0x6443004c,0x00000000}},	//   _منته, _nezd, ovni,
  { {0x6561017d,0x919a0047,0xa3e60053,0x00000000}},	//   _molh, _אױספ, _बढ़ा_,
  { {0x2903000f,0xf092014e,0x3f8b0003,0x00000000}},	//   _adja_, _לנו_, ébut_,
  { {0xf2d200b7,0xdb04013d,0x68f50ad6,0x00000000}},	// [fce0] מען_, gliá, _bezd,
  { {0x236d017c,0xdcee0023,0x1e57009a,0x00000000}},	//   hkej_, ribē, _עשיר_,
  { {0x9d1b00b5,0xa8060001,0xbddb00cd,0x00000000}},	//   _אויט, узел, nvèn,
  { {0x97a50054,0xdb04009c,0x00000000,0x00000000}},	//   аріл, bliá,   ,
  { {0xab65008f,0x656170f2,0xe9df0014,0x00000000}},	//   _daļā, _bolh, _trúa_,
  { {0xceb301f9,0x65612b1f,0x201e6509,0x00000000}},	//   ציג_, _colh, ytti_,
  { {0x6f040290,0x61e209a1,0x44260021,0x00000000}},	//   _odic, _stol, ارتف,
  { {0x6f041928,0xb8930021,0x2d8a70f3,0x00000000}},	//   _ndic, _الفع, hibe_,
  { {0x06760088,0x65610016,0x69ce0035,0x00000000}},	//   _сувя, _folh, _kibe,
  { {0x6f0470f4,0xdb1e01d9,0x236d0089,0x00000000}},	//   _adic, _kupó, akej_,
  { {0x201e3b7e,0x05770032,0x7e600137,0x00000000}},	//   utti_, _حملة_, ämpn,
  { {0x236d034d,0x22460122,0x201e70f5,0x00000000}},	//   ckej_, _trok_, rtti_,
  { {0x61e2000f,0xf1ba008b,0x3ead00b9,0x00000000}},	//   _utol, _thơ_, æet_,
  { {0x6f0470f6,0xa158005e,0x442c30e6,0x00000000}},	//   _edic, _јаку_, _kpd_,
  { {0x80db0063,0xeb4b0054,0x60db009a,0x00000000}},	//   _אחוז, нчак_, _אקונ,
  { {0x501b009a,0x00000000,0x00000000,0x00000000}},	//   _נוחו,   ,   ,
  { {0x3d950086,0x3f8b70f7,0xd8f50001,0x00000000}},	// [fcf0] _випр, micu_, изањ,
  { {0x2d8a02dd,0x6e2d00a4,0x6d5a0019,0x00000000}},	//   cibe_, _ipab, ötat,
  { {0x69ce0397,0xdb1e006d,0xc6d5005e,0x00000000}},	//   _dibe, _cupó, ажећ,
  { {0xdb04006d,0x3f8b04c9,0x99d70021,0x00000000}},	//   pliá, nicu_, _متسا,
  { {0x69ce1a22,0x644870f8,0x7aed579e,0x00000000}},	//   _fibe, _ardi, mbat,
  { {0x442c0150,0x2cad0080,0x7aed70f9,0x00000000}},	//   _bpd_, ředu_, lbat,
  { {0x65610524,0xf8a90042,0x3f8b0130,0x00000000}},	//   _volh, _कडिय, kicu_,
  { {0x442c00f3,0x3f8b08c1,0x644370fa,0x00000000}},	//   _dpd_, jicu_, rvni,
  { {0x3f8b017f,0x200c70fb,0x644870fc,0x00000000}},	//   dicu_, erdi_, _erdi,
  { {0x236d0024,0x200300c2,0x2d8a017d,0x00000000}},	//   skej_, šjim_, xibe_,
  { {0x6e2d0397,0x637502dd,0x76490026,0x00000000}},	//   _apab, _cánc, _hrey,
  { {0x8fa6046f,0x7bcf70fd,0x00000000,0x00000000}},	//   раме, _nicu,   ,
  { {0x200c69ae,0xd2350062,0x6d890f6a,0x00000000}},	//   ardi_, _ъндъ, ržan,
  { {0xeeeb001b,0x427a0063,0x2166005e,0x00000000}},	//   ưởng_, _באנג, _виши_,
  { {0x6b66005a,0x61e90006,0x67290051,0x00000000}},	//   аква, lpel, _obej,
  { {0x7aed002c,0x69ce18f0,0x28a90053,0x00000000}},	//   gbat, _sibe, _कड़ि,
  { {0x7bcf053b,0x6d5a0019,0x69ce6765,0x00000000}},	// [fd00] _dicu, ötas, _pibe,
  { {0x4dfb0047,0xfd4a0062,0x7aed70fe,0x00000000}},	//   _שפיא, _рзок_, abat,
  { {0x3a203c67,0x49990086,0xa8560d34,0x00000000}},	//   stip_, уття_, штај,
  { {0x76490ac6,0xe6660054,0x6604017c,0x00000000}},	//   _brey, итло, šikm,
  { {0x7649006d,0xe4da007e,0x61e9006f,0x00000000}},	//   _crey, نوشت_, jpel,
  { {0x2508007e,0x764970ff,0x7bc47100,0x00000000}},	//   ارشی_, _drey, lmiu,
  { {0x9cd7014e,0x61e97101,0x7d7b0063,0x00000000}},	//   בוצה_, epel, כנסו,
  { {0x200c007d,0x320d7102,0xc3540092,0x00000000}},	//   vrdi_, frey_, скиј,
  { {0x7e6000c7,0x63750873,0x7649602a,0x00000000}},	//   ämpl, _sánc, _grey,
  { {0x644800c3,0x200c00c3,0x7aed000c,0x00000000}},	//   _trdi, trdi_, zbat,
  { {0x4034005a,0x3f8b007c,0x7aed0058,0x00000000}},	//   щенс, ticu_, ybat,
  { {0xde59000d,0x6d89007d,0x7e7d004d,0x00000000}},	//   гамі_, ažal, tzsp,
  { {0xa116006a,0x7bcf3834,0x290700ea,0x00000000}},	//   _نوشت, _ricu, ónak_,
  { {0x7bcf02f6,0xac1908ef,0xd6d90022,0x00000000}},	//   _sicu, логу_, _mała_,
  { {0x3f8b1643,0xef1f013d,0xdd940085,0x00000000}},	//   picu_, niük_, цары,
  { {0x7aed004b,0x6d5a0527,0x6375013d,0x00000000}},	//   ubat, ötar, _kána,
  { {0x7aed2f2b,0xf1ba0053,0x8d87005d,0x00000000}},	// [fd10] rbat, _उठान, _نشدن,
  { {0x6375007a,0x7aed46cb,0x69da004c,0x00000000}},	//   _mána, sbat, _čtet,
  { {0xd246007e,0xab5b00cd,0x320d0089,0x00000000}},	//   _کن_, _diür, zrey_,
  { {0xdc360047,0x870701d5,0x6d89008f,0x00000000}},	//   _פארט_, ряже, ižam,
  { {0x63750026,0xd6d90051,0xa50901e4,0x00000000}},	//   _nána, _cała_, гела_,
  { {0x2707008b,0x2a3a0047,0x6b8d0120,0x00000000}},	//   ốn_, _געשמ, liag,
  { {0x84580062,0xe8940121,0x7b06013d,0x00000000}},	//   ирът_, _дарь, _áttö,
  { {0x6b8d7103,0x76490026,0x6375009c,0x00000000}},	//   niag, _trey, _bána,
  { {0x63750025,0xe507007e,0xb384007e,0x00000000}},	//   _cána, _نباي, تجوه,
  { {0x61e93d44,0x3f89001f,0x69c50139,0x00000000}},	//   rpel, _amau_, nmhe,
  { {0x61e97104,0x98b8008f,0x6d897105,0x00000000}},	//   spel, _karā_, ržal,
  { {0x63750025,0x61e92585,0x2d9e0080,0x00000000}},	//   _fána, ppel, čtem_,
  { {0x86350047,0x6b8d2494,0x42da0041,0x00000000}},	//   זאָג_, diag, _עקסע,
  { {0x61e60014,0x63a97106,0xfce3560e,0x00000000}},	//   íkle, loen, зоро,
  { {0xc0c80001,0x7d1b007d,0x3b0a0098,0x00000000}},	//   _куће_, đusp, лево_,
  { {0xef1a015a,0x63a904aa,0x6b8d5097,0x00000000}},	//   _сми_, noen, giag,
  { {0x9f5f027d,0x25790003,0x7bc45e8d,0x00000000}},	// [fd20] nutý_, _zèle_, rmiu,
  { {0x63a92aee,0x8a03007f,0xe8f7085e,0x00000000}},	//   hoen, язуе, йлу_,
  { {0x46ea000a,0x6b8d01f4,0x28c30042,0x00000000}},	//   гден_, biag, वेलि,
  { {0x7c3e0117,0x63a900ac,0xc795000d,0x00000000}},	//   _ispr, joen, орчы,
  { {0x63a90162,0x200300c3,0x858a000d,0x00000000}},	//   doen, šjih_, лёка_,
  { {0x3eb20072,0x96330085,0x09e31326,0x00000000}},	//   _myyt_, яніц, _хорн,
  { {0xf7463121,0x985c0023,0xe3af005d,0x00000000}},	//   _лево, nāļa_, کرو_,
  { {0xd377000d,0x3ea0008d,0xd7960044,0x00000000}},	//   йчы_, _oxit_, _الرخ,
  { {0xc1140141,0x8b570aeb,0xf1a60e82,0x00000000}},	//   омпј, מיקס_, йрон,
  { {0x256b06a5,0x7c3e160f,0x660200ea,0x00000000}},	//   _sølv_, _ospr, msok,
  { {0x3ea00013,0xdbf1004c,0x9f99005e,0x00000000}},	//   _axit_, _přín, ивоу_,
  { {0x443e0cd4,0x83c60ac5,0xd4910013,0x00000000}},	//   _ist_, _убеж, _kèn_,
  { {0x68fe00ac,0x7c3e7107,0x71a6000d,0x00000000}},	//   kapd, _aspr, _ладз,
  { {0x660202f7,0x61432125,0x6d5a0072,0x00000000}},	//   isok, _неча, ötap,
  { {0x9fe60032,0x3ea00d99,0x6b8d0516,0x00000000}},	//   _استه, _exit_, tiag,
  { {0x62802329,0x66020050,0x443e57f0,0x00000000}},	//   ozmo, ksok, _mst_,
  { {0x6b8d7108,0xeab30021,0x7c3e7109,0x00000000}},	// [fd30] riag, سعر_, _espr,
  { {0x8895005a,0x63a9006f,0x443e710a,0x00000000}},	//   оизх, zoen, _ost_,
  { {0x69c50027,0xdb0d0025,0x443e0089,0x00000000}},	//   rmhe, llaí, _nst_,
  { {0xdb0d0027,0xbb55005d,0x00000000,0x00000000}},	//   olaí, _بچسب,   ,
  { {0x637c006d,0x443e4317,0x98b80023,0x00000000}},	//   _ménd, _ast_, _varā_,
  { {0xdcf5003d,0x443e710b,0x85c80044,0x00000000}},	//   mizē, _bst_, مِنْ_,
  { {0xdcf5003d,0x63a9710c,0x443e00e5,0x00000000}},	//   lizē, toen, _cst_,
  { {0x443e06b8,0x4209005e,0xe3b90699,0x00000000}},	//   _dst_, анио_, јби_,
  { {0x443e0c6e,0x93bc000c,0x6d89017f,0x00000000}},	//   _est_, _apăs, ržaj,
  { {0x63a918dc,0x66060014,0x63a46c85,0x00000000}},	//   soen, _ækka, čina,
  { {0x25a00027,0x98b8003b,0x63a9710d,0x00000000}},	//   éile_, _iară_, poen,
  { {0xd6d90051,0x200b4e28,0x1eca5432,0x00000000}},	//   _mało_, čci_, илни_,
  { {0xdb0d0139,0xa224005d,0x92a6056c,0x00000000}},	//   glaí, _فروه, gałę,
  { {0x9f460139,0xb4f90041,0x7dc0710e,0x00000000}},	//   mplí_, יפֿי, köse,
  { {0x3d1b0053,0x2fc00025,0xdb0d0139,0x00000000}},	//   _बारे_, _thig_, alaí,
  { {0xdb040027,0xe8e00013,0x645e0050,0x00000000}},	//   lliú, _đốn_, äpii,
  { {0x98b8000c,0xc3320a7a,0xdb0d0025,0x00000000}},	// [fd40] _oară_, וון_, claí,
  { {0x61e40025,0x9f5f006d,0xb8b6005e,0x00000000}},	//   _éile, butó_, осећ,
  { {0x19b90086,0xb17a0047,0x93bc003b,0x00000000}},	//   суть_, סטער, _mpăr,
  { {0xd378017f,0xc66a0141,0x464a019c,0x00000000}},	//   _kuće_, ишле_, изен_,
  { {0x98b8000c,0xdcf5001c,0x68e9003b,0x00000000}},	//   _bară_, cizē, _şede,
  { {0x53e6042c,0x1dbc0053,0x637c006c,0x00000000}},	//   оциа, ोगित, _méne,
  { {0xd8230138,0x68fc00e8,0x475a18cc,0x00000000}},	//   _одри, _ierd, _края_,
  { {0x93bc0529,0x7ae4710f,0xad9b0139,0x00000000}},	//   _apăr, ncit, hrúp,
  { {0xa5f70079,0x613f0078,0x2e240014,0x00000000}},	//   _меѓу_, kšlė, jöf_,
  { {0x31780051,0x316a005e,0x98b800dd,0x00000000}},	//   órz_, ршио_, _gară_,
  { {0x68fc0cdc,0x6fe1001c,0xd8db0047,0x00000000}},	//   _merd, _pēca, יקיר,
  { {0x68fc0058,0x6375013d,0x6266005d,0x00000000}},	//   _lerd, _jánl, _واشق,
  { {0x68fc00f5,0x644a04aa,0x8d6b005e,0x00000000}},	//   _oerd, lvfi, ајва_,
  { {0xdcf5003d,0x225900b9,0xdb0d0139,0x00000000}},	//   vizē, åske_, rlaí,
  { {0xbc480076,0x65680025,0xa3b10053,0x00000000}},	//   очте_, _modh, _फ़ीड_,
  { {0xdcf5001c,0x6d4b0078,0x929d0022,0x00000000}},	//   tizē, _ėgau, egły,
  { {0x29d50032,0x68fc0397,0x637c0297,0x00000000}},	// [fd50] سياس, _berd, _géne,
  { {0xdcf5001c,0x68fc7110,0x6f1d0396,0x00000000}},	//   rizē, _cerd, lgsc,
  { {0x68fc04c6,0x2ca7003b,0x2d917111,0x00000000}},	//   _derd, _ând_, mize_,
  { {0x657a0037,0x68fc0173,0x6d451040,0x00000000}},	//   _alth, _eerd, _haha,
  { {0x7afd003d,0x68fc0de0,0x6d457112,0x00000000}},	//   _iest, _ferd, _kaha,
  { {0x2d9101f7,0x68fc0185,0x7afd7113,0x00000000}},	//   nize_, _gerd, _hest,
  { {0x7dc000bd,0x6d457114,0x98b8003b,0x00000000}},	//   lösc, _maha, _vară_,
  { {0x6d457115,0x03a80032,0x68e5001f,0x00000000}},	//   _laha, يديو_, lchd,
  { {0x68fc005b,0x7afd7116,0x6800013d,0x00000000}},	//   _yerd, _mest, _tájá,
  { {0x61e6016b,0x6d457117,0x29017118,0x00000000}},	//   íkla, _naha, naha_,
  { {0xcea90047,0x7afd7119,0xd491008b,0x00000000}},	//   _עי_, _oest, _kèm_,
  { {0x69d500bd,0x7afd711a,0x7640001f,0x00000000}},	//   _lize, _nest, _ysmy,
  { {0x6d451687,0xe8b80053,0xd5be0023,0x00000000}},	//   _baha, _अर्च, ļāva_,
  { {0x6d45053b,0x69d500c2,0x7afd12a9,0x00000000}},	//   _caha, _nize, _aest,
  { {0x7afd2492,0x30790047,0xdbf10080,0x00000000}},	//   _best, _לאַנ, _přán,
  { {0x69dd1a22,0xbea60086,0xd00e0021,0x00000000}},	//   _buse, _найк, _إلي_,
  { {0x2d840164,0x68fc2933,0x7ae4711b,0x00000000}},	// [fd60] èmes_, _perd, rcit,
  { {0x7afd1fc9,0x7ae4711c,0xe8e0008b,0x00000000}},	//   _eest, scit, _đồn_,
  { {0x69d5711d,0x6568711e,0x7afd03a3,0x00000000}},	//   _dize, _rodh, _fest,
  { {0x68fc0a12,0xd7ef0021,0x99890051,0x00000000}},	//   _werd, اكن_, grał_,
  { {0x68fc0397,0x69d5711f,0x64410cc6,0x00000000}},	//   _terd, _fize, _asli,
  { {0x7bde2de0,0x7afd40be,0x200505b5,0x00000000}},	//   _kupu, _zest, ksli_,
  { {0xd4670138,0x777b7120,0xe5b3000d,0x00000000}},	//   зије_, _flux, эйшы,
  { {0xfaff0003,0x63a40607,0x929d0051,0x00000000}},	//   _noël_, čino, załe,
  { {0x7bde463c,0x65680139,0xd6eb0063,0x00000000}},	//   _lupu, _todh, _הַבָ,
  { {0xad9b0025,0x20740085,0x04460d0a,0x00000000}},	//   gsúl, длоў, _незн,
  { {0x2d910080,0x6d457121,0x7bde004b,0x00000000}},	//   vize_, _raha, _nupu,
  { {0x6d457122,0x929d0051,0x4fc7000d,0x00000000}},	//   _saha, wałe, яспа,
  { {0x6e3d0122,0x798e0035,0x32ba0021,0x00000000}},	//   uwsb, _ombw, _اداة_,
  { {0x69dd6a80,0x7afd7123,0xeb9f00d1,0x00000000}},	//   _ruse, _sest, _sjø_,
  { {0x40a8007e,0x91bb0063,0x718b0063,0x00000000}},	//   _بخشی_, _המגי, _לְהַ,
  { {0x69d547cf,0x1fa4000d,0x6d457124,0x00000000}},	//   _size, _прыг, _waha,
  { {0x7afd7125,0x6d454026,0xaa580413,0x00000000}},	// [fd70] _vest, _taha, питу_,
  { {0x6827000d,0x6d8900c2,0x7afd02ce,0x00000000}},	//   зьдз, ežav, _west,
  { {0x29017126,0x68e52ea2,0x69d57127,0x00000000}},	//   raha_, rchd, _vize,
  { {0x290106a7,0x7afd7128,0x69dd0c4a,0x00000000}},	//   saha_, _uest, _tuse,
  { {0x7dc00137,0x69d500ea,0x44253aab,0x00000000}},	//   lösa, _tize, _sql_,
  { {0x660d16fe,0x7c94005d,0xda5a009d,0x00000000}},	//   šako, _آشیا, _וכשל,
  { {0x443300cd,0x98b80c3b,0x04450121,0x00000000}},	//   ïx_, _parą_, фейн,
  { {0x7705006a,0x6f0d003b,0x27f6004c,0x00000000}},	//   _آژان, _ndac, ýdnů_,
  { {0x3a29053b,0x42220121,0xd346007e,0x00000000}},	//   ntap_, вдыв, بینه_,
  { {0x442700e3,0xfaff00ac,0xa1890086,0x00000000}},	//   ptn_, _leë_, ібна_,
  { {0x8fa60878,0x6441017f,0x645e00fe,0x00000000}},	//   дане, _usli, äpit,
  { {0x7bde003b,0x5434007e,0xdbcc0014,0x00000000}},	//   _rupu, _سرمر, jóðn,
  { {0x8e550086,0x7bde7129,0xfaff37a1,0x00000000}},	//   нтрі, _supu, _voël_,
  { {0x7bde240d,0x6f0d712a,0x2256005d,0x00000000}},	//   _pupu, _edac, _آلود_,
  { {0x2d840006,0x3a29017e,0xfce3712b,0x00000000}},	//   ėme_, etap_, тосо,
  { {0xd378017f,0x05dd0053,0x2746005f,0x00000000}},	//   _kuća_, मदाब, _kūnų_,
  { {0xaec6047e,0x6fe8004c,0x394602fe,0x00000000}},	// [fd80] _юбил, _věce, мнаг,
  { {0x637c0164,0x7bde116d,0xda650021,0x00000000}},	//   _ména, _tupu, راقي,
  { {0x6f0d002b,0x637c0014,0xcb6a4890,0x00000000}},	//   _ydac, _léna, _дане_,
  { {0x29070014,0x00000000,0x00000000,0x00000000}},	//   ónar_,   ,   ,
  { {0x6d890add,0xc6a30002,0xa5f8005e,0x00000000}},	//   ržav, крши, челу_,
  { {0x91620013,0xef1f0058,0x2508005d,0x00000000}},	//   iữ_, zgü_, سرتی_,
  { {0x91620013,0x224d013d,0xe71a0044,0x00000000}},	//   hữ_, evek_, _ويست_,
  { {0xe7370054,0x938a0085,0x00000000,0x00000000}},	//   _оес_, ўска_,   ,
  { {0xc2980156,0xd62600f2,0x25fd0042,0x00000000}},	//   яких_, _تعزي, रीदी_,
  { {0x99de000d,0x637c0003,0x661d0137,0x00000000}},	//   вiка_, _déna, _åska,
  { {0x645c0006,0xa0a60156,0x224d00a8,0x00000000}},	//   _šrif, ьшил, avek_,
  { {0xd2520044,0x2011712c,0x28c30082,0x00000000}},	//   _لنص_, ázia_, वेटि,
  { {0xdb0d0994,0x91620013,0xef1f0058,0x00000000}},	//   llaç, gữ_, rgü_,
  { {0x63ad06d6,0x6fde008f,0x7dc00072,0x00000000}},	//   čane, _līci, tösa,
  { {0x1fa70888,0xfe79011b,0x5f956447,0x00000000}},	//   _ориг, šů_, _пикт,
  { {0x6d890066,0xc1780078,0x7af6188f,0x00000000}},	//   ežat, lkė_, gbyt,
  { {0x4efc009a,0x99d90044,0xb9550094,0x00000000}},	// [fd90] _והחו, سواء_, нващ,
  { {0x7dc00137,0xc1780078,0x929d0022,0x00000000}},	//   lösn, nkė_, nała,
  { {0x63a4017f,0x6609712d,0x63a200ac,0x00000000}},	//   činj, _svek, _ojon,
  { {0x8c1a00b5,0x224d004c,0x7dc0013d,0x00000000}},	//   _צורי, yvek_, nösn,
  { {0x659513bd,0xdb0d00be,0x7bcd129c,0x00000000}},	//   наду, elaç, mmau,
  { {0xdb0d017d,0x9f5f01d9,0x63a2002e,0x00000000}},	//   flaç, vrtý_, _ajon,
  { {0x637c0164,0x7bcd00fe,0x23d5006e,0x00000000}},	//   _séna, omau, нцир,
  { {0x1309019d,0x637c0003,0x66091310,0x00000000}},	//   чний_, _péna, _tvek,
  { {0x4615007e,0xd7940062,0x7bcd004d,0x00000000}},	//   _سوار, _ритъ, imau,
  { {0x7af60080,0x9980005b,0x91b40013,0x00000000}},	//   zbyt, iriş_, _đẹp_,
  { {0x442701f3,0x00000000,0x00000000,0x00000000}},	//   _زراف,   ,   ,
  { {0xf1b91aa5,0x987a0047,0x99890051,0x00000000}},	//   duše_, פארט, eważ_,
  { {0x69c7024a,0x63bb712e,0xa159167b,0x00000000}},	//   _ohje, mlun, _наду_,
  { {0x63bb162b,0x66d601f7,0x91620013,0x00000000}},	//   llun, _hükü, rữ_,
  { {0x6d8900eb,0xdca30ab1,0x63bb712f,0x00000000}},	//   ežas, гари, olun,
  { {0x63bb02c0,0xbb4323cf,0x00000000,0x00000000}},	//   nlun, леск,   ,
  { {0x63bb00bd,0xfce6259e,0x19c625a6,0x00000000}},	// [fda0] ilun, _попо, ебам,
  { {0x63bb00bd,0x7af66437,0x3afe0013,0x00000000}},	//   hlun, sbyt, ắp_,
  { {0x6d890f43,0xad1b0047,0xb9b50062,0x00000000}},	//   ržat, _צוטר, тстъ,
  { {0x63a40606,0xad9b0066,0x7bc6078c,0x00000000}},	//   čink, esúh, _uhku,
  { {0x63bb0bfc,0xe4e60054,0x2bbf0082,0x00000000}},	//   dlun, нійн, ्षरा,
  { {0x63a20f4e,0x63bb7130,0x746a0d3b,0x00000000}},	//   _sjon, elun, зрив_,
  { {0x63bb7131,0x6d8900a8,0x63a21502,0x00000000}},	//   flun, ožar, _pjon,
  { {0x3266323e,0x6b84001f,0x63bb7132,0x00000000}},	//   етов, nhig, glun,
  { {0xdb0d0016,0xe1ef007e,0x6b840ef2,0x00000000}},	//   slaç, یسی_, ihig,
  { {0xdb0d0110,0xc1780006,0x63bb37a6,0x00000000}},	//   plaç, ukė_, alun,
  { {0x6722280e,0x98b80051,0xc1780078,0x00000000}},	//   ogoj, _parę_, rkė_,
  { {0x67224367,0x27fc0066,0x98b3003b,0x00000000}},	//   ngoj, ávny_, lexă_,
  { {0x6d891c9c,0x67220078,0xdd910044,0x00000000}},	//   džar, igoj, لوح_,
  { {0xad9b0025,0x7ec9001c,0x6f060051,0x00000000}},	//   osúi, _rūpī, aakc,
  { {0x61e200fe,0x66d6005b,0x645c00f8,0x00000000}},	//   _huol, _yükü, _árid,
  { {0x201e0004,0x61e200fe,0x63754543,0x00000000}},	//   muti_, _kuol, _páni,
  { {0x201e7133,0x63a00025,0x4fd80063,0x00000000}},	// [fdb0] luti_, inmn, _אוהב_,
  { {0x25a00139,0x213e28c5,0x7bcd7134,0x00000000}},	//   éill_, neth_, smau,
  { {0x201e7135,0xac99007e,0x39a402a9,0x00000000}},	//   nuti_, _آنجا_, уштв,
  { {0x6b8455ca,0x7d0761bd,0x98140044,0x00000000}},	//   chig, lajs, ابلا,
  { {0x61e21dc1,0x213e00e5,0x63bb04aa,0x00000000}},	//   _nuol, keth_, vlun,
  { {0xe4e7019d,0x201e7136,0x7d075ade,0x00000000}},	//   хідн, kuti_, najs,
  { {0x63bb0026,0xad9b0139,0x29030023,0x00000000}},	//   tlun, gsúi, _ieja_,
  { {0x637c0164,0x201e4493,0x63bb7137,0x00000000}},	//   _déno, duti_, ulun,
  { {0x2d81017d,0xd36e0021,0x7d070066,0x00000000}},	//   _olhe_, تهي_, kajs,
  { {0x201e0035,0x63bb00d0,0x61e201f4,0x00000000}},	//   futi_, slun, _duol,
  { {0x22460228,0x29033409,0x7d070114,0x00000000}},	//   _esok_, _meja_, dajs,
  { {0x213e0185,0x2292007e,0x7dc00072,0x00000000}},	//   aeth_, الیس, töso,
  { {0x201e0006,0x333f0003,0x213e7138,0x00000000}},	//   auti_, meux_, beth_,
  { {0x201e7139,0x333f0164,0x672200a8,0x00000000}},	//   buti_, leux_, zgoj,
  { {0x1c390071,0x67220006,0x201e713a,0x00000000}},	//   нять_, ygoj, cuti_,
  { {0x333f0164,0xbddb0003,0x6e960021,0x00000000}},	//   neux_, uvèr, _للعا,
  { {0x333f0003,0xbb430169,0x29030fda,0x00000000}},	// [fdc0] ieux_, шетк, _beja_,
  { {0x8c960454,0x63a41cfe,0x0c960085,0x00000000}},	//   _армі, čini, _ашмя,
  { {0x2903713b,0x6bd60021,0x6d5e0c5f,0x00000000}},	//   _deja_, _لتحر, _inpa,
  { {0xeb9a0086,0xf9890063,0x8a06713c,0x00000000}},	//   _цим_, חר_, _изме,
  { {0xc6f70454,0x394a713d,0x333f0003,0x00000000}},	//   тніх_, _tabs_, deux_,
  { {0x61e223c5,0x6375007a,0x2d981386,0x00000000}},	//   _ruol, _mánu, nire_,
  { {0x61e2713e,0x213e00e5,0x7c2e5b45,0x00000000}},	//   _suol, veth_, ntbr,
  { {0x201e35c6,0x61e22d09,0x7c2e0717,0x00000000}},	//   vuti_, _puol, itbr,
  { {0x2fc90185,0x69dc0035,0x55e60086,0x00000000}},	//   _rhag_, _kire, _розб,
  { {0x61e2051e,0x45d30001,0x201e713f,0x00000000}},	//   _vuol, _вођс, tuti_,
  { {0xf9930063,0x2d987140,0x6f040333,0x00000000}},	//   שרת_, dire_, _beic,
  { {0x6d5e1b58,0x61e200fe,0xf8b30063,0x00000000}},	//   _anpa, _tuol, ישת_,
  { {0x213e001f,0x7d07040d,0x2b4b0290,0x00000000}},	//   peth_, tajs, _racc_,
  { {0x69dc002c,0x201e517c,0x2d987141,0x00000000}},	//   _nire, puti_, gire_,
  { {0x6f04139d,0xfbd301fb,0x29037142,0x00000000}},	//   _feic, لتر_, _reja_,
  { {0x290303d9,0x2d983791,0x5b14042c,0x00000000}},	//   _seja_, aire_, имст,
  { {0x69dc005b,0x2d987143,0x1bd41b08,0x00000000}},	// [fdd0] _bire, bire_, ротя,
  { {0x6f040199,0x69dc7144,0x2d987145,0x00000000}},	//   _zeic, _cire, cire_,
  { {0x29030016,0x481500a0,0x333f066d,0x00000000}},	//   _veja_, умес, yeux_,
  { {0xf7700242,0x69dc0d17,0xcc560063,0x00000000}},	//   يان_, _eire, _עברי_,
  { {0x333f0164,0x29032d04,0x7bdd1423,0x00000000}},	//   veux_, _teja_, _iisu,
  { {0xdb1d017d,0xf1b9007d,0x7aed38e0,0x00000000}},	//   _visõ, kuša_, lcat,
  { {0x333f0003,0xd4350021,0x5435005d,0x00000000}},	//   teux_, اعتب, ارتر,
  { {0x2a6d0051,0x7aed5584,0xe474000d,0x00000000}},	//   _żeby_, ncat, рушэ,
  { {0x333f03b2,0x6f0404da,0x7bdd0965,0x00000000}},	//   reux_, _reic, _misu,
  { {0x6f047146,0x6fe8004c,0x333f006c,0x00000000}},	//   _seic, _věcn, seux_,
  { {0x2d987147,0xc9520063,0x6f04004d,0x00000000}},	//   vire_, זמי_, _peic,
  { {0x6375006d,0x56b50047,0xd6110054,0x00000000}},	//   _cánt, ָפֿן_, _вiдб,
  { {0xd2280021,0x2b40001c,0xd00e007e,0x00000000}},	//   _لكنه_, veic_, يلی_,
  { {0x6f0400bd,0x7c2e7148,0x9f5f00fe,0x00000000}},	//   _weic, ttbr, estä_,
  { {0x2d987149,0x6f044344,0x69dc0003,0x00000000}},	//   rire_, _teic, _rire,
  { {0x2d98406a,0x7c2e714a,0x69dc714b,0x00000000}},	//   sire_, rtbr, _sire,
  { {0x7bdd1e0f,0x2b40001f,0xed5a0062,0x00000000}},	// [fde0] _disu, reic_, _зоп_,
  { {0x6d5e68eb,0x3a2000ac,0x7aed0331,0x00000000}},	//   _unpa, ruip_, acat,
  { {0xb17a00b5,0x69dc714c,0x7bdd714d,0x00000000}},	//   עטער, _vire, _fisu,
  { {0x7aed051e,0x69dc714e,0xa855005e,0x00000000}},	//   ccat, _wire, штуј,
  { {0x69dc04bc,0xd5ba01e8,0x3a20714f,0x00000000}},	//   _tire, нск_, quip_,
  { {0x69dc0139,0x75d30049,0xa5330085,0x00000000}},	//   _uire, مينا, йніч,
  { {0x07a6065b,0xf9832c9e,0xa2d60082,0x00000000}},	//   _бавн, _угро, मेन्,
  { {0x087700b5,0x52140571,0xad9b0046,0x00000000}},	//   _געלט_, адит, lsút,
  { {0xbb3b0047,0x442e01e1,0x7791005d,0x00000000}},	//   געפי, stf_, _بینا,
  { {0xc33900ea,0x71780330,0x3f990022,0x00000000}},	//   áírá, тбор_, wisu_,
  { {0x9f5f00fe,0xb0ce0053,0x29370047,0x00000000}},	//   ystä_, हेंग, נאטן_,
  { {0x7dc00137,0xe81c0042,0x63750061,0x00000000}},	//   lösh, _पटना_, _dáns,
  { {0x7bdd02f6,0x5f94005a,0x957c0045,0x00000000}},	//   _risu, сият, _ciąg,
  { {0x7bdd0004,0x2259000e,0x9f5f00b9,0x00000000}},	//   _sisu, æske_, dstå_,
  { {0x7bdd30af,0x99920022,0x41bb0063,0x00000000}},	//   _pisu, krył_, _רצוע,
  { {0x9be40085,0x7aed7150,0x9aa50044,0x00000000}},	//   сірк, ucat, لمزو,
  { {0x7aed7151,0xdb040026,0xbda703eb,0x00000000}},	// [fdf0] rcat, rlið, _محدو,
  { {0x7bdd0150,0x7aed22a8,0x99800066,0x00000000}},	//   _wisu, scat, ytiť_,
  { {0x7bdd017f,0x661c008f,0x38c7130d,0x00000000}},	//   _tisu, _ārka, ущав,
  { {0x98a70078,0x55f50601,0x7dc00072,0x00000000}},	//   žnį_, ачку, yösk,
  { {0xd24601a7,0xd1380022,0xf5057152,0x00000000}},	//   _بن_, ciąg_, азло,
  { {0x35f8006a,0x2715008b,0x5a9a12cd,0x00000000}},	//   ارند_, ền_, _ישרא,
  { {0x64980062,0xdcfc0078,0x2db80041,0x00000000}},	//   лтър_, airė, אלגן_,
  { {0x63ad0648,0x7dc00072,0x32350062,0x00000000}},	//   čano, tösk, ахос,
  { {0x99800024,0x6375006d,0xe299005e,0x00000000}},	//   stiť_, _sáns, ђао_,
  { {0x320d1e3e,0x63750061,0x21750ada,0x00000000}},	//   rsey_, _páns, руир,
  { {0x320d7153,0x64c40044,0x00000000,0x00000000}},	//   ssey_, _هيكل,   ,
  { {0x201829b9,0x62350376,0x3f840066,0x00000000}},	//   ária_, _веду, ómu_,
  { {0x398400c7,0xde36000d,0xa294000d,0x00000000}},	//   _lösa_, шэнь, _лаці,
  { {0xe2c80086,0x8cb10042,0xe1f9005f,0x00000000}},	//   _слід_, _आँखो, mpų_,
  { {0x41260086,0x3b960001,0xeb9a1bc5,0x00000000}},	//   _тощо_, ајат, вив_,
  { {0xdca30086,0x6fb30021,0x9f5f08a9,0x00000000}},	//   іати, _وموا, tstå_,
  { {0x6da6019d,0x1d1a0121,0x5f770044,0x00000000}},	// [fe00] _випа, _июнь_, _خميس_,
  { {0x9f5f0d7d,0xe8f71b06,0x6e2001a8,0x00000000}},	//   rstå_, илу_, àmbu,
  { {0xd1160063,0xd70a0121,0x870a0131,0x00000000}},	//   שקעה_, внее_, веев_,
  { {0x9f5f00df,0xfbdf0013,0xf1b9008f,0x00000000}},	//   pstå_, _giê_, kušo_,
  { {0xf1b9008f,0xad9b67f1,0x237f056c,0x00000000}},	//   jušo_, csús, dkuj_,
  { {0x5e570047,0xdcfe001c,0x7b3e0051,0x00000000}},	//   יינע_, _impē, _dłuż,
  { {0x25a90025,0xe4b8000d,0x3a3201bb,0x00000000}},	//   éala_, ылкі_, ltyp_,
  { {0xfaff00e8,0xea00001b,0xd378017f,0x00000000}},	//   _hoër_, _luật_, _kući_,
  { {0xe3af007e,0x68e9000c,0xf1b9001c,0x00000000}},	//   برو_, _şedi, gušo_,
  { {0x7c3e076c,0x637c0003,0xaa37009f,0x00000000}},	//   _oppr, _méni, סטיק_,
  { {0xafd90076,0x0496000d,0xb3660062,0x00000000}},	//   лдоф_, _траў, _вълк,
  { {0x25fd0161,0x63a400c3,0x443e0089,0x00000000}},	//   रीकी_, čins, _ipt_,
  { {0x6f16001f,0x5db70021,0x7c3e07b9,0x00000000}},	//   _ddyc, لإسر, _appr,
  { {0x6f160051,0x443e3752,0x61ed0139,0x00000000}},	//   _edyc, _kpt_, _éala,
  { {0x25b90139,0xd0f70063,0x443e004e,0x00000000}},	//   _ísle_, _דמות_, _jpt_,
  { {0xdb040003,0x637c7154,0x7e62007d,0x00000000}},	//   nniè, _béni, _šope,
  { {0x443e2a14,0x59c50044,0x00000000,0x00000000}},	// [fe10] _lpt_, ميرك,   ,
  { {0x443e7155,0x645a2337,0xad9b0139,0x00000000}},	//   _opt_, _orti, asúr,
  { {0x6f160185,0x7b3e0045,0x66160006,0x00000000}},	//   _ydyc, _służ, šykl,
  { {0x60d900b5,0x30d90047,0x201e0014,0x00000000}},	//   אַנג, אַנע, irti_,
  { {0x98a701f7,0x637c0164,0xbb3a0047,0x00000000}},	//   ını_, _géni, _גערי,
  { {0x99850032,0xd90f007e,0x7dc00072,0x00000000}},	//   _السو, _آیا_, tösi,
  { {0x645a007d,0xaadb0042,0x637c006c,0x00000000}},	//   _crti, _मृतक, _zéni,
  { {0xf3490076,0x13680001,0x443e7156,0x00000000}},	//   упил_, ишњи_, _dpt_,
  { {0x645a7157,0x22590014,0x645c0014,0x00000000}},	//   _erti, ísk_, _árin,
  { {0xe1f90006,0x057401a7,0x443e008d,0x00000000}},	//   rpų_, _والد, _fpt_,
  { {0xc355005a,0x3951008f,0xdee60330,0x00000000}},	//   _гълъ, _mazs_, йони,
  { {0x083a0047,0x6fe8004c,0x4f96030b,0x00000000}},	//   נערל, _měch, ёрну,
  { {0x201e7158,0xddc4003b,0xd7ba009a,0x00000000}},	//   arti_, _criş, רֶיך,
  { {0x61fb165d,0x98a70080,0xea000013,0x00000000}},	//   mpul, ýně_, _quật_,
  { {0x7ff5006a,0xddc401f7,0x6ff50021,0x00000000}},	//   _استا, _eriş, _استط,
  { {0x637c0164,0x3a320137,0x61fb7159,0x00000000}},	//   _péni, ttyp_, opul,
  { {0x661c0023,0x5aca0183,0xc9aa0085,0x00000000}},	// [fe20] _ārko, улам_, гвае_,
  { {0x186a0138,0x3a320d88,0x637c0003,0x00000000}},	//   лази_, rtyp_, _véni,
  { {0x63ad1312,0x3a320d88,0x6ff3000c,0x00000000}},	//   čanj, styp_, _făce,
  { {0xcb6a29c9,0xf7290086,0xdc3b00b5,0x00000000}},	//   _саме_, ицій_, _געטר,
  { {0x443e0150,0x765b715a,0xd1380022,0x00000000}},	//   _spt_, _cruy, niąc_,
  { {0x443e715b,0x86070021,0x7d0e004d,0x00000000}},	//   _ppt_, حقوق_, nabs,
  { {0x61fb15f3,0x7e7d0051,0x7bc4005f,0x00000000}},	//   epul, zysp, oliu,
  { {0x645a00b2,0xd6da005d,0x7d0e017c,0x00000000}},	//   _vrti, _موزش_, habs,
  { {0xdb0403b2,0xa6860088,0x7d0e0146,0x00000000}},	//   rniè, _улад, kabs,
  { {0x201803d9,0x6e2600e8,0xc01403d6,0x00000000}},	//   ário_, dukb, омощ,
  { {0xdb0f000f,0xc32a0021,0x64c6007e,0x00000000}},	//   ődés, _مكان_, _ايال,
  { {0x7e7d00fe,0x3a2000a4,0x29180014,0x00000000}},	//   tysp, krip_, _ldra_,
  { {0x2918715c,0x6ff300dd,0x6e26013d,0x00000000}},	//   _odra_, _răce, gukb,
  { {0x3ce51b49,0xc6930047,0x291c00ea,0x00000000}},	//   ølv_, לאר_, óval_,
  { {0xfc640062,0x661d0137,0x8f350062,0x00000000}},	//   пътн, _åskv, _дейц,
  { {0x7bc4051e,0xec340086,0x8fa40095,0x00000000}},	//   gliu, янсь, _наје,
  { {0x3a200179,0x645c00c2,0xf1bf0066,0x00000000}},	// [fe30] grip_, _šril, ššej_,
  { {0x7bc40006,0x6f0f715d,0x6fe8004c,0x00000000}},	//   aliu, lacc, _pěch,
  { {0x290a006d,0x6d47715e,0x6ff3003b,0x00000000}},	//   _deba_, meja, _tăce,
  { {0xd378017f,0x6f0f715f,0x6d550717,0x00000000}},	//   _kuću_, nacc, ldza,
  { {0xf7700032,0xf6250086,0x6f0f01f4,0x00000000}},	//   عام_, ідко, iacc,
  { {0x2d837160,0x6fe80080,0xce38014e,0x00000000}},	//   nkje_, _těch, צאות_,
  { {0x3f89002b,0x6d553d6a,0x6d47260f,0x00000000}},	//   _olau_, idza, ieja,
  { {0x765b001b,0x257900cd,0x7dc032b0,0x00000000}},	//   _truy, _pèls_, löst,
  { {0x6d470397,0x64582d40,0xe667013c,0x00000000}},	//   keja, avvi, _утво,
  { {0x6d470089,0x61fb6d1f,0x7dc01ea9,0x00000000}},	//   jeja, rpul, nöst,
  { {0x3f897161,0x6d477162,0x6f0f13b3,0x00000000}},	//   _blau_, deja, facc,
  { {0x3f890c3f,0x4427059e,0x4094000d,0x00000000}},	//   _clau_, mun_, ярыт,
  { {0x6d55006f,0x63a97163,0x7d0e3392,0x00000000}},	//   fdza, mnen, tabs,
  { {0x6d4727fe,0x63a91aec,0x637c0003,0x00000000}},	//   geja, lnen, _dénu,
  { {0x44277164,0xd1380051,0x7d0e7165,0x00000000}},	//   nun_, siąc_, rabs,
  { {0x63bb0034,0x6f0f0a02,0x290a7166,0x00000000}},	//   noun, cacc, _seba_,
  { {0x44277029,0x61e30a9f,0x3fe3000d,0x00000000}},	// [fe40] hun_, _kinl, _ўжыв,
  { {0x4427138d,0x63a900bd,0x2d84001c,0x00000000}},	//   kun_, hnen, īmes_,
  { {0x61eb051e,0x63bb017f,0xa81a007e,0x00000000}},	//   _lugl, koun, شتار_,
  { {0x6b8d7167,0xdb0d017d,0x44277168,0x00000000}},	//   chag, voaç, dun_,
  { {0x63bb02dd,0x63a90066,0xab5b030c,0x00000000}},	//   doun, dnen, _thür,
  { {0xa2da0053,0x8c43005b,0x44274303,0x00000000}},	//   _पृष्, ışve, fun_,
  { {0x61eb0ac6,0x63bb0034,0x44277169,0x00000000}},	//   _augl, foun, gun_,
  { {0x63a916a2,0xdb0d017d,0x6d470022,0x00000000}},	//   gnen, roaç, zeja,
  { {0xfbd3014e,0x05b90161,0xb6a30086,0x00000000}},	//   ותה_, ेतशब, _житл,
  { {0x63a90035,0xc05a000d,0x24580013,0x00000000}},	//   anen, аім_, _tĩm_,
  { {0x3f890994,0x6f0f051e,0x4427716a,0x00000000}},	//   _plau_, tacc, cun_,
  { {0x63a90024,0x61e31d30,0x91e6413b,0x00000000}},	//   cnen, _einl, _доде,
  { {0x7dc000fe,0x61eb716b,0x6f0f716c,0x00000000}},	//   yöst, _gugl, racc,
  { {0x6b84006f,0x0cab0062,0x6f0f29aa,0x00000000}},	//   ekig, атби_, sacc,
  { {0x672b007a,0x61eb00bd,0xfe6e007e,0x00000000}},	//   yggj, _zugl, نگی_,
  { {0x6d47716d,0x2d8300d1,0x799c002b,0x00000000}},	//   seja, skje_, _amrw,
  { {0x05ca0161,0x4427005b,0x7dc000fe,0x00000000}},	// [fe50] िताब, zun_, töst,
  { {0x442709fb,0x63bb0035,0x69c5017d,0x00000000}},	//   yun_, zoun, ulhe,
  { {0x7dc00d88,0x63bb0c55,0x29010d12,0x00000000}},	//   röst, youn, rbha_,
  { {0x4427024a,0x6b840bfc,0x62800078,0x00000000}},	//   vun_, ckig, kymo,
  { {0x63a9716e,0x6ff3000c,0x4427001f,0x00000000}},	//   vnen, _măca, wun_,
  { {0x4427716f,0x6ff3003b,0x5dfc0149,0x00000000}},	//   tun_, _lăca, ספונ,
  { {0x63a9034d,0x61eb55be,0x442701cf,0x00000000}},	//   tnen, _sugl, uun_,
  { {0x64410198,0x0595006a,0xf1b9001c,0x00000000}},	//   _vpli, _کارگ, muši_,
  { {0x13060076,0x7dd200b9,0x63a97170,0x00000000}},	//   чный_, læse, rnen,
  { {0x44270e53,0x63a97171,0x63bb487f,0x00000000}},	//   pun_, snen, soun,
  { {0x7dc0000f,0x63bb00e5,0x6f0d7172,0x00000000}},	//   zöss, poun, _beac,
  { {0x6f0d0025,0x7dc00072,0x660900ca,0x00000000}},	//   _ceac, yöss, _kwek,
  { {0xee370086,0x6f0d7173,0x1e830edb,0x00000000}},	//   пня_, _deac, елям,
  { {0xf1b9001c,0xad9b0955,0x2011013d,0x00000000}},	//   kuši_, epúb, ázis_,
  { {0xaffe001b,0xf1b9003d,0x6f0d0025,0x00000000}},	//   _trướ, juši_, _feac,
  { {0x6f0d02b0,0x661600eb,0x33f10b23,0x00000000}},	//   _geac, šyki, _máx_,
  { {0x01f90047,0xada623d6,0x6b841013,0x00000000}},	// [fe60] מפּל, _наил, rkig,
  { {0x63a00089,0x6b84004b,0x7dc018de,0x00000000}},	//   zimn, skig, röss,
  { {0x7d7b0165,0xc18c0047,0xf1b9001c,0x00000000}},	//   _הניו, ױטאָ, guši_,
  { {0x1b4a005e,0xdb24005d,0xcf57009a,0x00000000}},	//   _узми_, _توحی, ּ֑את_,
  { {0x66036ee9,0x96660054,0xd6220085,0x00000000}},	//   епча, якде, _вiна,
  { {0xdb0d0026,0x186a0002,0xf5780021,0x00000000}},	//   llað, _лаги_, تمتع_,
  { {0x74670121,0x63a0306e,0xc448005d,0x00000000}},	//   зрыв_, timn, تیان_,
  { {0x63a00139,0x51f80121,0x722a0e82,0x00000000}},	//   uimn, онию_, бцов_,
  { {0x63a00024,0x22580121,0x6f0d2b63,0x00000000}},	//   rimn, ципы_, _reac,
  { {0xb60302f4,0x6f0d0027,0xdb0d0014,0x00000000}},	//   ášen, _seac, hlað,
  { {0x6568010a,0x6f0d0969,0x6ff3000c,0x00000000}},	//   _indh, _peac, _păca,
  { {0x657a0d17,0x929d0022,0xd4690044,0x00000000}},	//   _hoth, tałt, _بحكم_,
  { {0x6f0d003b,0x59be0053,0x54f00042,0x00000000}},	//   _veac, ्तार, _चलाए_,
  { {0x6e20013d,0x6143005e,0xdcfc0023,0x00000000}},	//   ámba, _зеља, tkrā,
  { {0x657a1a74,0x6f0d057a,0x7dc00072,0x00000000}},	//   _moth, _teac, tösr,
  { {0x8bc400e1,0x7dd200b9,0xf1b9008f,0x00000000}},	//   есуд, væse, vuši_,
  { {0xb5fd027c,0xf9790141,0xadb5005e,0x00000000}},	// [fe70] _krše, обај_, _обиш,
  { {0x657a7174,0xddc4008f,0x00000000,0x00000000}},	//   _noth, _asiņ,   ,
  { {0x473524dc,0xdb0d0026,0x3a290089,0x00000000}},	//   днес, blað, suap_,
  { {0x7dd200b9,0x7dc00072,0xf1b97175,0x00000000}},	//   ræse, lösp, ruši_,
  { {0xa3c00053,0xf1b9008f,0x657a6a5f,0x00000000}},	//   ंकन_, suši_, _both,
  { {0x657a0025,0x09e4000d,0xceb40047,0x00000000}},	//   _coth, _поўн, עיס_,
  { {0x6d571233,0xad1c3997,0x00000000,0x00000000}},	//   _maxa, מוגר,   ,
  { {0x27fc0024,0x9f5f006d,0xe1f920c0,0x00000000}},	//   ívne_, istó_, оги_,
  { {0x657a0027,0x66090035,0x6d576ea0,0x00000000}},	//   _foth, _uwek, _oaxa,
  { {0x657a4c2e,0x11d60044,0xc6d400de,0x00000000}},	//   _goth, ووية_, _ستقت,
  { {0xff260076,0x29380047,0xd2f90094,0x00000000}},	//   ммно, לאזן_, _деец_,
  { {0x6b83000c,0x3f6a005e,0x777b006c,0x00000000}},	//   _îngh, цимо_, _joux,
  { {0xa3b800f2,0x63bc013d,0xe716009a,0x00000000}},	//   _عامر_, _írna, וחרר_,
  { {0xf0b8006a,0x2d8c0066,0x2e360046,0x00000000}},	//   _کاهش_, óde_, ræf_,
  { {0xef1f005b,0xdb0d0026,0xdca60121,0x00000000}},	//   mkün_, tlað, фави,
  { {0x77690003,0x7c210139,0x00000000,0x00000000}},	//   _nnex, álra,   ,
  { {0xc3320063,0xed5a3f23,0x6d570137,0x00000000}},	// [fe80] כון_, _доп_, _faxa,
  { {0x26170053,0x7769126d,0xe9d77176,0x00000000}},	//   _निजी_, _anex, дку_,
  { {0x657a7177,0xa84a0044,0xb46b014b,0x00000000}},	//   _roth, تلام_, _воiн,
  { {0x657a7178,0x6ff300dd,0x6ac60044,0x00000000}},	//   _soth, _lăco, _يقدم,
  { {0xc7a302d8,0x657a7179,0xcb13009a,0x00000000}},	//   њичк, _poth, _שלש_,
  { {0xa4d40054,0x6ff300dd,0x29160043,0x00000000}},	//   нолі, _răcn, _زورآ,
  { {0xd4670138,0x9f5f0290,0xb176008b,0x00000000}},	//   дије_, istò_, _nhượ,
  { {0x44201bdb,0x7c370058,0x63750066,0x00000000}},	//   či_, _çarş, _kány,
  { {0x99890024,0x07a30001,0x657a0268,0x00000000}},	//   stať_, _ратн, _toth,
  { {0x660207b7,0x9f5f0003,0xa697009f,0x00000000}},	//   mpok, mpté_, _חכמה_,
  { {0x6e26006f,0xb5fd007d,0x39580712,0x00000000}},	//   erkb, _vrše, _mars_,
  { {0x8354006a,0x59d00053,0x6e950612,0x00000000}},	//   _سپتا, _तीसर, еиму,
  { {0x5f94005a,0x98b80006,0xdb060072,0x00000000}},	//   тият, _tarė_, _ykkö,
  { {0xea00001b,0xd6d90051,0x61fd004c,0x00000000}},	//   _xuất_, _cały_, ísle,
  { {0x4c950141,0x70540021,0xd6d90022,0x00000000}},	//   хивс, _أنبا, _dały_,
  { {0x69d40161,0x798e0185,0x213e00e5,0x00000000}},	//   _बीबी, _albw, lfth_,
  { {0x6d57717a,0x29133717,0x395802a0,0x00000000}},	// [fe90] _taxa, taxa_, _bars_,
  { {0x3958717b,0x6602004a,0xe29f0014,0x00000000}},	//   _cars_, dpok, úði_,
  { {0x7d15005b,0x213e00e5,0x00000000,0x00000000}},	//   mazs, ifth_,   ,
  { {0x39580034,0xea00008b,0xef12009a,0x00000000}},	//   _ears_, _suất_, ָּא_,
  { {0x2b590139,0x0608000d,0x39580f8c,0x00000000}},	//   _iasc_, днік_, _fars_,
  { {0xdd02007d,0x6fd60066,0xea000013,0x00000000}},	//   čući, máce, _quất_,
  { {0x6ff3003b,0xf9920063,0x57f402f8,0x00000000}},	//   _răco, _גרם_, _апст,
  { {0x77690034,0xd6db000d,0xdb1d0014,0x00000000}},	//   _unex, _дтз_, _oksí,
  { {0xea000013,0xd2a90121,0x52a90094,0x00000000}},	//   _tuất_, якие_, явим_,
  { {0xf99200b5,0x3cfb0053,0xe001000d,0x00000000}},	//   ָרט_, ्रों_, льмi_,
  { {0x2cfb0161,0xcea90a7a,0x22466ed6,0x00000000}},	//   ्रैल_, _פי_, _epok_,
  { {0x2b590027,0xdef9000d,0xf8b20047,0x00000000}},	//   _nasc_, дыё_, רשט_,
  { {0xe28e717c,0x8db60086,0xf269030b,0x00000000}},	//   _са_, есві, _хилл_,
  { {0xef1f000f,0xc69200ff,0xb176008b,0x00000000}},	//   lkül_, ראך_, _thượ,
  { {0x2b5900cd,0x1c390076,0x61420062,0x00000000}},	//   _basc_, мять_, _сеща,
  { {0xffd60088,0x2b5900cd,0x4427717d,0x00000000}},	//   _яўля, _casc_, irn_,
  { {0x29110089,0x44270114,0x395812fe,0x00000000}},	// [fea0] _beza_, hrn_, _pars_,
  { {0x2911005b,0x2b590139,0xf1b9008f,0x00000000}},	//   _ceza_, _easc_, pušu_,
  { {0x3958633c,0x6d4e717e,0x661b717f,0x00000000}},	//   _vars_, meba, _avuk,
  { {0x6d5c5016,0x29070026,0x3958212e,0x00000000}},	//   ldra, ðnar_, _wars_,
  { {0x442700bd,0x7bc600fe,0xe5340156,0x00000000}},	//   ern_, _ikku, вель,
  { {0x6d4e7180,0x6d5c7181,0xb6030066,0x00000000}},	//   neba, ndra, ášan,
  { {0xf3f1001b,0x68460076,0x53e60ac5,0x00000000}},	//   _cụ_, _янва, нциа,
  { {0xddcd000c,0x6d4e0228,0xf3f1001b,0x00000000}},	//   _oraş, heba, _dụ_,
  { {0x6d4e7182,0x69de5f48,0x7c2e00ca,0x00000000}},	//   keba, ompe, hubr,
  { {0x6d5c7183,0xaa370047,0x1a9b0047,0x00000000}},	//   jdra, עטיק_, פייע,
  { {0x7bc6007a,0xddcd005b,0x69de0025,0x00000000}},	//   _okku, _araş, impe,
  { {0x6d5c7184,0xddcd003b,0x67100053,0x00000000}},	//   edra, _braş, ारिक_,
  { {0x442e017d,0x7e641a72,0xbddb006c,0x00000000}},	//   luf_, _crip, ntèg,
  { {0x7e6404bf,0x6d5c7185,0x7bc67186,0x00000000}},	//   _drip, gdra, _akku,
  { {0x3ce500c7,0x2b40107e,0x7e64112c,0x00000000}},	//   älv_, ffic_, _erip,
  { {0xa3c00161,0x5ba409d2,0x69de31eb,0x00000000}},	//   ंकि_, груз, empe,
  { {0x6d4e06a7,0x442e004d,0x7e647187,0x00000000}},	// [feb0] beba, huf_, _grip,
  { {0x7dd200b9,0xdd04000c,0x6fd60080,0x00000000}},	//   læsn, ărăr, ráce,
  { {0x2911017f,0x63a27188,0x7c2e05d5,0x00000000}},	//   _veza_, _omon, cubr,
  { {0x27fc0024,0x29110035,0x8c1a0063,0x00000000}},	//   ívna_, _weza_, _קורי,
  { {0x4427001f,0x7bcd004d,0x442e0003,0x00000000}},	//   wrn_, mlau, euf_,
  { {0x63a20034,0x6e3d00bd,0x0684000d,0x00000000}},	//   _amon, itsb, ыгін,
  { {0x6e3d00ca,0x7bc60014,0x442717e4,0x00000000}},	//   htsb, _ykku, urn_,
  { {0xf3f1001b,0x44270bfc,0x6d4e0051,0x00000000}},	//   _vụ_, rrn_, zeba,
  { {0x2489001c,0x6d4e0397,0x6b83003b,0x00000000}},	//   ņam_, yeba, _îngu,
  { {0x3f4c008b,0xd1b90021,0x7bcd7189,0x00000000}},	//   _ếu_, بابا_, hlau,
  { {0x7bcd00eb,0x61ea001f,0x60250062,0x00000000}},	//   klau, _difl, ъдна,
  { {0x6d4e0831,0x7e64718a,0x3a2900ac,0x00000000}},	//   weba, _prip, krap_,
  { {0x27760047,0x6d5c1ecb,0x6d4e718b,0x00000000}},	//   דערש_, tdra, teba,
  { {0x7afd4106,0x7c2e0b16,0xe29f0014,0x00000000}},	//   _afst, tubr, úðu_,
  { {0x3a290360,0x6d5c23df,0x6d4e718c,0x00000000}},	//   erap_, rdra, reba,
  { {0x7c2e0140,0x6d5c21e1,0x6d4e374b,0x00000000}},	//   rubr, sdra, seba,
  { {0x6d5c02b0,0x7c2e01f4,0x987800a8,0x00000000}},	// [fec0] pdra, subr, ršča_,
  { {0x7afd0026,0x3f80004b,0x7bcd28c6,0x00000000}},	//   _efst, _hoiu_, alau,
  { {0x38c8007e,0x7bcd030c,0xe73a093d,0x00000000}},	//   راطی_, blau, дее_,
  { {0x7bcd718d,0xb7650054,0x4789012c,0x00000000}},	//   clau, лтій, нсім_,
  { {0x442e017e,0x6b9601e1,0x6934005d,0x00000000}},	//   wuf_, mhyg, _مکار,
  { {0xdb0d0164,0x63a20290,0xbddb0003,0x00000000}},	//   nnaî, _smon, rtèg,
  { {0x61ea055b,0x7f8600be,0xb5fd007d,0x00000000}},	//   _rifl, _hóqu, _vrša,
  { {0x442e2743,0xe2340002,0x6b96718e,0x00000000}},	//   ruf_, гнињ, nhyg,
  { {0x442e0b21,0xb5fd00a8,0x98af056c,0x00000000}},	//   suf_, _trša, ęgą_,
  { {0x69c300c3,0x7bc40019,0x11d80021,0x00000000}},	//   čneg, hoiu, عودة_,
  { {0xb42501fb,0xc9170063,0x9f5f0050,0x00000000}},	//   _معنو, כחית_, istö_,
  { {0x331a006a,0x83830076,0x6e3d114f,0x00000000}},	//   _آزاد_, _выше, ttsb,
  { {0x6e3d00e8,0xdd910021,0x7f4f006c,0x00000000}},	//   utsb, موح_, recq,
  { {0x6e3d4845,0x40340893,0x21a302d8,0x00000000}},	//   rtsb, _бекс, _кичм,
  { {0xebc70001,0x7bcd252f,0x0c240121,0x00000000}},	//   вљан, tlau, имён,
  { {0x69c70031,0xf1b9074f,0x7bcd43b8,0x00000000}},	//   _skje, vrši_, ulau,
  { {0x6d410019,0x7d02003b,0x7bcd718f,0x00000000}},	// [fed0] õlas, _şose, rlau,
  { {0x7bcd3635,0x0a680062,0x6d4500ac,0x00000000}},	//   slau, ърси_, _ubha,
  { {0x398400c7,0x7bc4003b,0x7bcd3649,0x00000000}},	//   _röst_, boiu, plau,
  { {0x2d8100bd,0x569503d6,0x6d580014,0x00000000}},	//   _hohe_, лает, _óvar,
  { {0x2d810019,0xa6340054,0x0596005d,0x00000000}},	//   _kohe_, инці, گانگ,
  { {0x69c71609,0xc9840131,0x84595f9f,0x00000000}},	//   _ukje, _куси, ерит_,
  { {0x628606a5,0x0596005d,0x03a50201,0x00000000}},	//   økon, دانگ, лико,
  { {0xdb04017d,0xd2510021,0x9989237b,0x00000000}},	//   rniç, منع_, ntaž_,
  { {0x51f50044,0x01155e1e,0x7bdc009a,0x00000000}},	//   دسبر, льню, וקהו,
  { {0x60090076,0xdd3c0078,0x95d80699,0x00000000}},	//   нном_, _sąži, _адут_,
  { {0x80a50032,0x7a47008f,0xa4390054,0x00000000}},	//   امجن, lītā, _їзду_,
  { {0x69c50244,0x00000000,0x00000000,0x00000000}},	//   hohe,   ,   ,
  { {0x61450597,0x63a97190,0xe2f80086,0x00000000}},	//   _бела, mien, _речі_,
  { {0x27ed03b2,0x621a0047,0x63a97191,0x00000000}},	//   _lien_, _טונק, lien,
  { {0x6b960185,0xa066005a,0x63a91a05,0x00000000}},	//   thyg, _баща_, oien,
  { {0x6b8d00a4,0x63a97192,0x8b9502d7,0x00000000}},	//   gkag, nien, аруч,
  { {0x39960146,0xe9da7193,0xeb75000d,0x00000000}},	// [fee0] _læse_, ека_, шырэ,
  { {0x7a47003d,0xed5a00e1,0x6b8d0178,0x00000000}},	//   dītā, _џон_, akag,
  { {0x27ed3338,0x63a97194,0xdc3c00c2,0x00000000}},	//   _bien_, kien, ošče,
  { {0x4b56011c,0x6d5e0035,0x27ed2ac0,0x00000000}},	//   _съот, _hapa, _cien_,
  { {0x6d5e18ab,0x27ed7195,0xdc3c00c2,0x00000000}},	//   _kapa, _dien_, išče,
  { {0x6b83000c,0x6f160717,0x9f990003,0x00000000}},	//   _îngr, _leyc, réé_,
  { {0x69dc0199,0x6d5e18ab,0xd7f8000c,0x00000000}},	//   _ihre, _mapa, _îă_,
  { {0x6d5e7196,0x291a10de,0x63a96ad3,0x00000000}},	//   _lapa, lapa_, gien,
  { {0x171b0047,0xf1aa007e,0x20d30013,0x00000000}},	//   _רומע, فاده_, _ại_,
  { {0x27ed02b0,0x291a003e,0x6d5e7197,0x00000000}},	//   _zien_, napa_, _napa,
  { {0x291a017e,0x63a908c9,0x1f750062,0x00000000}},	//   iapa_, bien, алня,
  { {0xe1fa0001,0x291a00a4,0x63a90d6c,0x00000000}},	//   _згд_, hapa_, cien,
  { {0x6d5e003e,0x291a304a,0x69dc004d,0x00000000}},	//   _bapa, kapa_, _ohre,
  { {0x69dc001f,0xf2370063,0x98b80078,0x00000000}},	//   _nhre, _ערוץ_, _narį_,
  { {0x6d5e7198,0x291a00a4,0xee3f0114,0x00000000}},	//   _dapa, dapa_, stý_,
  { {0x2d9800bd,0x3b550699,0xaab50086,0x00000000}},	//   ahre_, јкар, айбі,
  { {0x27ed03b2,0x69dc0025,0x201e001c,0x00000000}},	// [fef0] _rien_, _bhre, lsti_,
  { {0x27ed021f,0x645a7199,0x201e719a,0x00000000}},	//   _sien_, _osti, osti_,
  { {0x629b719b,0x6ff3003b,0x69dc0139,0x00000000}},	//   zzuo, _păci, _dhre,
  { {0x7a47001c,0x69dc045e,0x6d5e2cf2,0x00000000}},	//   tītā, _ehre, _zapa,
  { {0x69dc0027,0x6d5e3cde,0xdb0d0025,0x00000000}},	//   _fhre, _yapa, nnaí,
  { {0x63a90045,0x69dc0025,0x291a16eb,0x00000000}},	//   wien, _ghre, capa_,
  { {0x7a47001c,0x27ed3c94,0x63a92308,0x00000000}},	//   sītā, _tien_, tien,
  { {0x63a90e7c,0x360500f2,0x61fd0061,0x00000000}},	//   uien, _نورف, íslo,
  { {0xe29905a1,0x201e2a03,0x645a0764,0x00000000}},	//   тап_, esti_, _esti,
  { {0xd49b0138,0x6f165642,0x2127007e,0x00000000}},	//   _пре_, _seyc, ديدی_,
  { {0x6d5e0cf8,0x201e719c,0x1ee7005d,0x00000000}},	//   _rapa, gsti_, یوپی_,
  { {0x6d5e719d,0xe47a0047,0xdee60f55,0x00000000}},	//   _sapa, _ברעכ, иони,
  { {0xdc3c00c3,0x2d980025,0x291a0d89,0x00000000}},	//   ršče, thre_, yapa_,
  { {0xc0e50431,0xf2d20063,0x929a0165,0x00000000}},	//   _колк, _ועד_, _בינת,
  { {0x99890512,0x6d5e024a,0x395300cd,0x00000000}},	//   mpaň_, _vapa, dexs_,
  { {0x291a0035,0x8024005d,0x69dc719e,0x00000000}},	//   wapa_, _اروم, _shre,
  { {0x637c000f,0x2907005b,0x6d5e719f,0x00000000}},	// [ff00] _pénz, ınan_, _tapa,
  { {0x44d50013,0xdb040139,0x186a046a,0x00000000}},	//   _ó_, nniú, кази_,
  { {0x291a08f0,0x7d1c71a0,0x9836000d,0x00000000}},	//   rapa_, mars, рэзі,
  { {0x291a0150,0xf62a0086,0xdb040025,0x00000000}},	//   sapa_, віки_, hniú,
  { {0x69dc54f8,0x291a71a1,0x63bc013d,0x00000000}},	//   _thre, papa_, _írni,
  { {0xceb30063,0x23ba001c,0x7d1c71a2,0x00000000}},	//   חיד_, dīja_, nars,
  { {0x9553005d,0x34370044,0x00000000,0x00000000}},	//   زخوا, لسيد_,   ,
  { {0x3a204675,0x201e01e1,0x7d1c05ff,0x00000000}},	//   osip_, vsti_, hars,
  { {0x3a20003e,0xbb3b0047,0x1dc60053,0x00000000}},	//   nsip_, דעפי, लकात,
  { {0x3a2057e3,0x29180150,0x7d1c71a3,0x00000000}},	//   isip_, _jera_, jars,
  { {0x201e00eb,0x29183f66,0x7d1c71a4,0x00000000}},	//   usti_, _mera_, dars,
  { {0x7d0e00c7,0x7d1c0d12,0xbde201a8,0x00000000}},	//   ebbs, ears, üènc,
  { {0x539b014e,0x0e340156,0x7c2e71a5,0x00000000}},	//   _ביאו, оняю, erbr,
  { {0x44d5001b,0x29180c99,0x320600a4,0x00000000}},	//   _ý_, _nera_, _itoy_,
  { {0x2ba700d7,0x5f77007e,0xdb0d0139,0x00000000}},	//   ајав, _ناظر, snaí,
  { {0x5bb80076,0x7d1c0983,0x853c0078,0x00000000}},	//   ался_, aars, _smėl,
  { {0x29180627,0x2b8e0080,0xdad90001,0x00000000}},	// [ff10] _bera_, _mých_, умац_,
  { {0xd13800eb,0x6f1d71a6,0x7d1c71a7,0x00000000}},	//   ngą_, lasc, cars,
  { {0x6ff30529,0x291871a8,0x57e7000d,0x00000000}},	//   _făcu, _dera_, аўдз,
  { {0x6d5571a9,0x6f1d71aa,0x637c013d,0x00000000}},	//   leza, nasc, _tény,
  { {0x29180ec6,0x442e0173,0x6f1d3dd1,0x00000000}},	//   _fera_, erf_, iasc,
  { {0x6d550035,0x291871ab,0x5e58009a,0x00000000}},	//   neza, _gera_, יידע_,
  { {0xe8df001b,0xb8950032,0xd49b0062,0x00000000}},	//   _trực_, _الأع, ърд_,
  { {0x61b10161,0x7d1c02dd,0x23ba001c,0x00000000}},	//   ीक्ष, zars, tīja_,
  { {0x6f1d71ac,0x6d550035,0x957c0051,0x00000000}},	//   dasc, keza, _piąt,
  { {0x290126b3,0x917b008b,0x7d1c0331,0x00000000}},	//   ncha_, _kể_, xars,
  { {0x9315006a,0x29010009,0x7d1c17d5,0x00000000}},	//   _هواش, icha_, vars,
  { {0x644300c7,0x6f1d5a7c,0xd1380078,0x00000000}},	//   mtni, gasc, agą_,
  { {0x6e290080,0x64431c2d,0x7d1c71ad,0x00000000}},	//   šebn, ltni, tars,
  { {0x237f00c3,0x6d550d13,0xdb160072,0x00000000}},	//   ljuj_, geza, nlyö,
  { {0x7d1c606d,0x65610ec6,0x6f1d2546,0x00000000}},	//   rars, _malh, basc,
  { {0x291871ae,0x394a0150,0xfbdf0013,0x00000000}},	//   _sera_, _sbbs_, _chê_,
  { {0x291871af,0x6d5571b0,0x2441008b,0x00000000}},	// [ff20] _pera_, beza, hóm_,
  { {0xf2d200b5,0x644371b1,0x6e20006d,0x00000000}},	//   לען_, ktni, ámbu,
  { {0x29180627,0x6ff3003b,0xa3c90053,0x00000000}},	//   _vera_, _tăcu, ोता_,
  { {0xb5fd00c3,0x29014956,0x3a2000a4,0x00000000}},	//   _gršk, acha_, psip_,
  { {0xd1380006,0x9f480139,0x644371b2,0x00000000}},	//   ygą_, _bunú_, etni,
  { {0xb9960032,0x27f871b3,0x64432f5a,0x00000000}},	//   _السب, _turn_, ftni,
  { {0x64430146,0x764200fe,0x78780063,0x00000000}},	//   gtni, stoy, _דָּו,
  { {0xf7431314,0xd467005e,0x6d551556,0x00000000}},	//   _несо, сиће_, zeza,
  { {0x27e60034,0x65610016,0x6f1d71b4,0x00000000}},	//   mmon_, _falh, vasc,
  { {0xd1380006,0x6f0471b5,0x27e60d11,0x00000000}},	//   ugą_, _afic, lmon_,
  { {0x6d5571b6,0x2b8e0024,0xe97b0047,0x00000000}},	//   veza, _tých_, אניש,
  { {0x6d550035,0x27e600f1,0x7c350445,0x00000000}},	//   weza, nmon_, vuzr,
  { {0x3ebf2986,0x41e60636,0x6f1d71b7,0x00000000}},	//   çut_, _ліка, rasc,
  { {0xd0100021,0x6f045dec,0x27e60072,0x00000000}},	//   _قلت_, _efic, hmon_,
  { {0xfbdf008b,0x6f040003,0x6d5571b8,0x00000000}},	//   _phê_, _ffic, reza,
  { {0x39960014,0x6d55007d,0x6ab40042,0x00000000}},	//   _ræsa_, seza, ंपूर,
  { {0x6d5502dd,0x75280051,0x290171b9,0x00000000}},	// [ff30] peza, _oddz, tcha_,
  { {0x661d0026,0x42db0047,0x290171ba,0x00000000}},	//   _æski, רקמע, ucha_,
  { {0x29014236,0xb5fd00c2,0xfbdf0013,0x00000000}},	//   rcha_, _tršk, _thê_,
  { {0x6b86006f,0x7bc10003,0xae44007e,0x00000000}},	//   _gokg, élud, _بپیو,
  { {0xb5fd08ea,0x6561017d,0xbb3a0047,0x00000000}},	//   _krši, _palh, _דערי,
  { {0x644301e3,0xdcfe001c,0x99800066,0x00000000}},	//   ttni, _kopā, triť_,
  { {0x2a69004b,0x6ff300dd,0x656171bb,0x00000000}},	//   lvab_, _lăcr, _valh,
  { {0xbb3c0047,0x7dd22ad6,0x65615553,0x00000000}},	//   ָעזי, ræsi, _walh,
  { {0xd1790086,0x0cd60053,0x644371bc,0x00000000}},	//   асні_, _धर्म, stni,
  { {0x0595006a,0x644300a8,0x41750044,0x00000000}},	//   _بارگ, ptni, زاخس,
  { {0x6e24017f,0x7e6d6444,0xadf30042,0x00000000}},	//   _svib, _arap, _इंजन_,
  { {0xe7c90161,0x27fc00ea,0x98b30078,0x00000000}},	//   िकिप, ívni_, ždės_,
  { {0xbddb00cd,0x7e6d1e99,0xa2d00042,0x00000000}},	//   rtèn, _crap, _डुप्,
  { {0xbddb0268,0xa069000a,0x7e6d71bd,0x00000000}},	//   stèn, _вака_, _drap,
  { {0xab1a0076,0x7e6d0019,0x672903a4,0x00000000}},	//   ицах_, _erap, _odej,
  { {0x7e6d0164,0x0b46000d,0xeb970893,0x00000000}},	//   _frap, ўнан, оис_,
  { {0x69c30024,0x660900ac,0x7e6d632b,0x00000000}},	// [ff40] čnen, _ntek, _grap,
  { {0x3f82007d,0x1d0a005e,0x67293995,0x00000000}},	//   ljku_, _њени_, _adej,
  { {0xfce60be8,0x00000000,0x00000000,0x00000000}},	//   _фоно,   ,   ,
  { {0x2cb5013d,0xe7375a0f,0xcb6a05e0,0x00000000}},	//   őadó_, жец_, _таме_,
  { {0x16a708b0,0xa6130054,0x27e671be,0x00000000}},	//   овци_, дміч, rmon_,
  { {0x27e600f1,0x672900a8,0x98a6210d,0x00000000}},	//   smon_, _edej, _диге,
  { {0x6fdd006c,0x7d1a0014,0x66090e6f,0x00000000}},	//   héca, ótsy, _etek,
  { {0x24800117,0xccf30063,0xe7370eaf,0x00000000}},	//   ćim_, וכו_, _мес_,
  { {0xd250006a,0xc17a0086,0xef1f005b,0x00000000}},	//   رند_, аїн_, kkür_,
  { {0x6fdd0003,0xd5a4005d,0x67291f26,0x00000000}},	//   déca, _علای, _zdej,
  { {0x78fb0165,0x4346030b,0x30a371bf,0x00000000}},	//   יפיו, _межв, дряв,
  { {0xd36f0021,0x2d9a22c8,0x7e6d71c0,0x00000000}},	//   _لهم_, _alpe_, _prap,
  { {0x35df0053,0x80ca0042,0x51863a82,0x00000000}},	//   _पीड़, _सुरे, _мука,
  { {0x0dcb114d,0x7e6d007d,0x7d040085,0x00000000}},	//   руми_, _vrap, дзёж,
  { {0x5f950076,0xb5fd0c61,0x7e6d04ff,0x00000000}},	//   _никт, _vrši, _wrap,
  { {0x7e6d71c1,0x3f15030b,0xa3c00082,0x00000000}},	//   _trap, _эдис, ंकट_,
  { {0x3a3200ac,0x5a350ed2,0x79a703d1,0x00000000}},	// [ff50] gryp_, янат, орже,
  { {0x89370021,0x2b49003b,0x35df0042,0x00000000}},	//   تعرا, sfac_, _पीढ़,
  { {0x2b9c0024,0x2a690019,0x660971c2,0x00000000}},	//   _síce_, svab_, _stek,
  { {0xdb210072,0xf773013a,0x4425004b,0x00000000}},	//   ätäv, باط_, _rvl_,
  { {0xddc4017f,0x4b7a0165,0x68fb0058,0x00000000}},	//   _hriš, _הארו, _şudu,
  { {0x2b9c0080,0x05a80086,0xce380063,0x00000000}},	//   _více_, овій_, קאות_,
  { {0xdb0d017d,0x62860072,0xe7330044,0x00000000}},	//   gnaç, äkon, _يصر_,
  { {0x7dd200b9,0x6fd6004c,0x8c1c0063,0x00000000}},	//   læst, ráck, בוהי,
  { {0xad9b0014,0x3e72008d,0x46380044,0x00000000}},	//   npús, _môtô_, _وأكد_,
  { {0x10a5373b,0x6fd671c3,0xdb16013d,0x00000000}},	//   зион, máci, rnyé,
  { {0x6fd644a9,0x3f6a5f9f,0xc948009a,0x00000000}},	//   láci, бино_, חֲרֹ,
  { {0xad9b0066,0xe3a5005d,0x00000000,0x00000000}},	//   zpút, _عشای,   ,
  { {0x6fd60e08,0x63bb005b,0x644b0008,0x00000000}},	//   náci, mnun, žnič,
  { {0xddc4027c,0x6fdd0003,0xbbc40053,0x00000000}},	//   _briš, réca, वक्क,
  { {0x6ab40042,0x8b960085,0x5b9a005e,0x00000000}},	//   ंप्र, прач, бњар_,
  { {0x6fd6557c,0x63bb71c4,0x50b8007e,0x00000000}},	//   káci, nnun, _بدهد_,
  { {0x7dd200b9,0x799e002b,0x63bb71c5,0x00000000}},	// [ff60] fæst, thpw, inun,
  { {0x63bb00bd,0x291c017d,0x6fd671c6,0x00000000}},	//   hnun, úva_, dáci,
  { {0xacfb0063,0x63bb0014,0x7d1e008f,0x00000000}},	//   _להיכ, knun, _ieps,
  { {0x7d1e005b,0x6fd6017d,0xdb04013d,0x00000000}},	//   _heps, fáci, nniü,
  { {0x63bb00bd,0x6fd671c7,0x00000000,0x00000000}},	//   dnun, gáci,   ,
  { {0x7dd20146,0x67fa0080,0x63bb62a7,0x00000000}},	//   mæss, _půjd, enun,
  { {0x65d9000d,0x09e30726,0x63bb0649,0x00000000}},	//   цьцё_, _чорн, fnun,
  { {0xdb0d71c8,0x7d1e0051,0x6b84082a,0x00000000}},	//   rnaç, _leps, njig,
  { {0xdcfc003d,0x6fd6017d,0x7dd200b9,0x00000000}},	//   nkrē, cáci, næss,
  { {0x63bb06ed,0xc05a0085,0x7d1e011b,0x00000000}},	//   anun, бім_, _neps,
  { {0xd250007e,0x68050078,0x9f350454,0x00000000}},	//   رنگ_, _kėda, мені,
  { {0x2d8c40d3,0x547b009a,0xb36900de,0x00000000}},	//   öden_, _לטבו, _وإنك_,
  { {0xbddb03b2,0xe8b90042,0x00000000,0x00000000}},	//   stèm, _आश्च,   ,
  { {0xddc414d5,0xf8be0053,0x41e30054,0x00000000}},	//   _priš, ्थाय, _піща,
  { {0x6fd61990,0x7d1e0150,0x28ac0042,0x00000000}},	//   záci, _deps, _टेलि,
  { {0xb5fd007d,0xdb040022,0x69c30d71,0x00000000}},	//   _kršt, dnió, čnem,
  { {0x6fdd0003,0x256d013d,0x64450075,0x00000000}},	// [ff70] léco, lölő_, çhiz,
  { {0x213e0034,0xa9280088,0x6fd618a8,0x00000000}},	//   ngth_, зіце_, váci,
  { {0x4af93e42,0xdcfe0078,0x7dd271c9,0x00000000}},	//   _меню_, _alpė, ræst,
  { {0x6fd64e0d,0xa8180021,0xe7380054,0x00000000}},	//   táci, ستمر_, зеї_,
  { {0x6fdd0003,0x63a00139,0xb8d40042,0x00000000}},	//   héco, dhmn, _जे_,
  { {0x6fd618a8,0x395a71ca,0xdb04013d,0x00000000}},	//   ráci, ceps_, zniü,
  { {0xa3e90af2,0xf992009a,0x00000000,0x00000000}},	//   одка_, _ירך_,   ,
  { {0x6fdd0003,0x63bb71cb,0x6fd60066,0x00000000}},	//   déco, unun, páci,
  { {0x63bb3240,0x15ab0062,0x6fdd0e7c,0x00000000}},	//   rnun, _лъжи_, técn,
  { {0x35b4012c,0x55bb0044,0x00000000,0x00000000}},	//   _збур, _اطرح_,   ,
  { {0x752371cc,0x40940121,0x7d1e71cd,0x00000000}},	//   manz, ерят, _reps,
  { {0x26140053,0x442701e1,0x752371ce,0x00000000}},	//   नीकी_, msn_, lanz,
  { {0x61452ab5,0x69c303f5,0x59bf0053,0x00000000}},	//   _жела, čnej, ्वार,
  { {0xe9ff001b,0x61fd0a63,0x752371cf,0x00000000}},	//   _hoặc_, íslu, nanz,
  { {0xe5020161,0x8d630062,0x395a04aa,0x00000000}},	//   रुटि_, ъвре, veps_,
  { {0xee3a1087,0x752305cc,0x917b0013,0x00000000}},	//   _дни_, hanz, _hề_,
  { {0x6d4f0026,0x395a00e5,0x917b008d,0x00000000}},	// [ff80] únað, teps_, _kề_,
  { {0x7523006d,0x7e645072,0x6aa40075,0x00000000}},	//   janz, _isip, rzif,
  { {0x7766011c,0x75234dcf,0xca290063,0x00000000}},	//   дълж, danz, שם_,
  { {0x917b0013,0x6d5c6d61,0x6d4e0807,0x00000000}},	//   _lề_, lera, lfba,
  { {0x752371d0,0xe5c65bcc,0xe5a61810,0x00000000}},	//   fanz, мско, миди,
  { {0x2d98000f,0x7c3c0164,0x661b0051,0x00000000}},	//   nkre_, ourr, _dwuk,
  { {0x2d9871d1,0x6d4e24f5,0x6d5c71d2,0x00000000}},	//   ikre_, ifba, iera,
  { {0x6d5c71d3,0x256d013d,0xbefd0082,0x00000000}},	//   hera, völő_, _एलेन_,
  { {0x6d5c136a,0x75460a74,0x75230331,0x00000000}},	//   kera, _оназ, banz,
  { {0x75235d46,0x67360051,0x6d5c71d4,0x00000000}},	//   canz, łają, jera,
  { {0x130a0076,0xb0c60121,0xc1490013,0x00000000}},	//   _дней_, ьщик, _hơịp_,
  { {0x6568058c,0x7c3c71d5,0x443c004b,0x00000000}},	//   _hadh, durr, muv_,
  { {0x02e20161,0x65680009,0x6d5c71d6,0x00000000}},	//   _परिभ, _kadh, fera,
  { {0x316700bd,0x6d5c71d7,0x23ba0023,0x00000000}},	//   _ganz_, gera, dīji_,
  { {0x0cd40086,0x656871d8,0xbddb0003,0x00000000}},	//   ворю, _madh, ntèi,
  { {0x6d5c00f3,0x644a01e1,0x2d9800a5,0x00000000}},	//   aera, itfi, akre_,
  { {0x6d5c4ab0,0x657a0250,0xb7c6003b,0x00000000}},	// [ff90] bera, _onth, inţă,
  { {0xf770006a,0x6d5c71d9,0x656824d1,0x00000000}},	//   یان_, cera, _nadh,
  { {0xb9070053,0x4735006e,0x75234dcf,0x00000000}},	//   _पर_, енес, vanz,
  { {0x61f86188,0x443c199a,0x657a081b,0x00000000}},	//   _livl, duv_, _anth,
  { {0x752371cf,0xe6180086,0xa50921a9,0x00000000}},	//   tanz, дді_, пела_,
  { {0x75230035,0xd4691321,0x6fd60e7c,0x00000000}},	//   uanz, зике_, láct,
  { {0x6d450035,0x75232546,0xdc3c007d,0x00000000}},	//   _mcha, ranz, ršće,
  { {0x61c70161,0x36d50086,0x6fd60080,0x00000000}},	//   रक्ष, _зобр, náct,
  { {0x7c3c051e,0x656871da,0xf7480021,0x00000000}},	//   zurr, _fadh, _تلقي_,
  { {0x6d5c71db,0x6e3d004b,0x65150044,0x00000000}},	//   xera, dusb, _أوائ,
  { {0x917b001b,0x61f8017f,0xd00e007e,0x00000000}},	//   _về_, _divl, یلی_,
  { {0x6d45687f,0x34940505,0x3f6a71dc,0x00000000}},	//   _acha, _шахр, чимо_,
  { {0xa195000d,0x6fd637c9,0x3167004d,0x00000000}},	//   _падч, dáct, _tanz_,
  { {0x752100ea,0x6d4e004d,0x7afd00ac,0x00000000}},	//   _jelz, ufba, _agst,
  { {0x6d5c01e3,0xc4d20047,0x3a29005b,0x00000000}},	//   rera, ָגן_, esap_,
  { {0x69d500bd,0x6d452608,0x6fd6039f,0x00000000}},	//   _akze, _echa, tácu,
  { {0xdb0f00ea,0x7e640035,0x6720007d,0x00000000}},	// [ffa0] ájár, _usip, _remj,
  { {0x75210080,0xe9d7413b,0x7c3c039f,0x00000000}},	//   _nelz, еку_, purr,
  { {0x656871dd,0x644a71de,0x23ba0023,0x00000000}},	//   _radh, xtfi, sīji_,
  { {0xd6d90045,0x62860072,0xd70771df,0x00000000}},	//   _był_, äkok, енце_,
  { {0xb7d701fb,0xfaff00a3,0xeb970d3b,0x00000000}},	//   روها_, _maël_, _чия_,
  { {0xceb30047,0x443c004b,0x644a71e0,0x00000000}},	//   ניג_, tuv_, ttfi,
  { {0x6fd600ea,0x94d3005e,0xddc40078,0x00000000}},	//   nács, лошц, _asiū,
  { {0x65680035,0xff5f0003,0x644a3c7c,0x00000000}},	//   _wadh, noît_, rtfi,
  { {0xdbc70019,0x656871e1,0x443c71e2,0x00000000}},	//   _tööh, _tadh, suv_,
  { {0xe4d60021,0x657a71e3,0xc0ca3320,0x00000000}},	//   _كتاب, _unth, зуме_,
  { {0x89370047,0xc9530063,0x7f5d1b61,0x00000000}},	//   ערטע_, אמת_, tesq,
  { {0x6d452be6,0x6e3d6c1a,0x6e95012c,0x00000000}},	//   _scha, tusb, виму,
  { {0x7f5d46fb,0x6d45056c,0x73e3012c,0x00000000}},	//   resq, _pcha, _соцз,
  { {0xc2970088,0x127b00b5,0x99800006,0x00000000}},	//   _якіх_, _מאדע, irių_,
  { {0xe0d400b5,0x21670001,0x6fd6013d,0x00000000}},	//   _בײַ_, _чији_, gács,
  { {0x80db0063,0x50db069a,0x60db009a,0x00000000}},	//   _מחוז, _מקוא, _מקונ,
  { {0xdb04007a,0x99890024,0x6fd60942,0x00000000}},	// [ffb0] rnið, hrať_, ráct,
  { {0x6d4571e4,0xdb040026,0xddc40066,0x00000000}},	//   _ucha, snið, _priť,
  { {0xbb1b03b2,0x2ca701f2,0xa9c4071f,0x00000000}},	//   _boît, _ånd_, устк,
  { {0xdb0700fe,0x1ab5000d,0xe7840002,0x00000000}},	//   ämät, _абмя, лучо,
  { {0x99890b33,0x7521004d,0xbb3a0041,0x00000000}},	//   erať_, _pelz, _קעשי,
  { {0xc58b0121,0xdb0d01a8,0x917b008d,0x00000000}},	//   ящее_, liaà, _mễ_,
  { {0x65920001,0x917b008b,0x99800078,0x00000000}},	//   рају, _lễ_, arių_,
  { {0x442c71e5,0x58d438bf,0x75210f89,0x00000000}},	//   _dvd_, _сост, _welz,
  { {0xdcfe007d,0x42220121,0xddcb004c,0x00000000}},	//   _uopć, адыв, řiřa,
  { {0x9989034d,0x6f0d0529,0x6fdd0164,0x00000000}},	//   brať_, _afac, léch,
  { {0x8fa6011c,0x7a47008f,0x98b10075,0x00000000}},	//   ване, lūtā, _kazı_,
  { {0x6fdd0003,0x7bc10516,0x4f9651c4,0x00000000}},	//   néch, élul, троу,
  { {0xe28e148d,0x9e630088,0xaec301d5,0x00000000}},	//   _та_, авяд, ибюл,
  { {0x917b008b,0x6f0d00a3,0x30850044,0x00000000}},	//   _dễ_, _efac, _للتف,
  { {0x224d00ea,0x6f0d0f06,0x1d070094,0x00000000}},	//   ltek_, _ffac, теси_,
  { {0x25e80053,0x99800006,0x236d007d,0x00000000}},	//   _चीनी_, yrių_, ndej_,
  { {0xff5f0003,0x224d4c13,0xdb040046,0x00000000}},	// [ffc0] roît_, ntek_, kniö,
  { {0x957c0022,0x7794005d,0x00000000,0x00000000}},	//   _wiąz, گیرا,   ,
  { {0x98b101f7,0x574a000d,0xdca61225,0x00000000}},	//   _bazı_, дзем_, _рани,
  { {0x224d2a3e,0x7e7653cb,0xc7af00de,0x00000000}},	//   ktek_, _kryp, يّل_,
  { {0x99800006,0x4733013c,0x06540021,0x00000000}},	//   urių_, рніс, انتح,
  { {0x442c71e6,0xd6930138,0x35b6005a,0x00000000}},	//   _pvd_, ришћ, ъщес,
  { {0xa823007e,0x67e3004b,0x03c62474,0x00000000}},	//   _نکنن, sõja, ксим,
  { {0x68e371e7,0x442c2493,0x98b10058,0x00000000}},	//   ünde, _vvd_, _gazı_,
  { {0xc5660001,0x69de0331,0x056612ab,0x00000000}},	//   _икак, olpe, _иван,
  { {0xbddb00cd,0x6f0d01f4,0xc17301d5,0x00000000}},	//   ntèt, _sfac, альщ,
  { {0x98b1005b,0x25d70063,0x993b0063,0x00000000}},	//   _yazı_, _יומן_, ותיה,
  { {0xdb04004b,0x23ba008f,0x67220042,0x00000000}},	//   oniõ, tīju_, मरिक_,
  { {0x7e7671e8,0x28d90053,0x63a271e9,0x00000000}},	//   _cryp, _बुनि, _ilon,
  { {0x5bbd0042,0x60a60044,0x814400de,0x00000000}},	//   ्क्व, _لإبق, _صنعن,
  { {0x1df80121,0x63a20f79,0xddc7013d,0x00000000}},	//   теры_, _klon, óműv,
  { {0xddcd003b,0x69de0d1e,0x2ba40131,0x00000000}},	//   _braţ, elpe, ајув,
  { {0xb9550062,0x98b10058,0x7e7671ea,0x00000000}},	// [ffd0] лващ, _razı_, _gryp,
  { {0x63a2001f,0x6fdd0b6c,0x645a71eb,0x00000000}},	//   _llon, déci, _opti,
  { {0x224d00ea,0x7bc80003,0xddcd003b,0x00000000}},	//   ztek_, éduc, _eraţ,
  { {0xddcd003b,0x224d22b6,0xc0530041,0x00000000}},	//   _fraţ, ytek_, יזע_,
  { {0x6fdd0164,0xddcd003b,0x26c90c77,0x00000000}},	//   réch, _graţ, çao_,
  { {0x63a23bf1,0x7bdf00bd,0x69cb00ea,0x00000000}},	//   _alon, llqu, éged,
  { {0x26d2005b,0x7a47001c,0x200a004c,0x00000000}},	//   üyor_, sūtā, íbil_,
  { {0x04560032,0x224d000f,0x2489017f,0x00000000}},	//   الية_, ttek_, ćam_,
  { {0xd24e0021,0xc7b2009a,0xe1f9034b,0x00000000}},	//   كني_, _הבן_, нги_,
  { {0x64684e43,0x63a271ec,0x224d71ed,0x00000000}},	//   äsiä, _elon, rtek_,
  { {0x224d71ee,0x84151862,0xa988009d,0x00000000}},	//   stek_, _смех, דָרִ,
  { {0x39960014,0x2011008f,0xa3de0042,0x00000000}},	//   _hæst_, īzi_, णतः_,
  { {0x5274007e,0xdb0d0014,0xd7ba009a,0x00000000}},	//   _پانز, fnaþ, תֶיך,
  { {0xe8e0008b,0x63a200b2,0xde0332e4,0x00000000}},	//   hiều_, _zlon, спри,
  { {0x8c950086,0x9989056c,0xdca3354e,0x00000000}},	//   арті, braź_, бари,
  { {0xcb670001,0x39961c23,0x69de00ca,0x00000000}},	//   ласе_, _læst_, wlpe,
  { {0x39ea005e,0x4e1d0053,0x1d0a2530,0x00000000}},	// [ffe0] едао_, बीआई_, _пепи_,
  { {0x39960026,0x8d6664a2,0x680c0075,0x00000000}},	//   _næst_, _свое, _ağda,
  { {0xf99f0268,0xdcf7003b,0x485a000d,0x00000000}},	//   _atès_, ăcăt, эраў_,
  { {0xddcd0ed9,0x46a609b4,0xfaa60085,0x00000000}},	//   _iraš, лаев, _бамо,
  { {0x9f8b0019,0x6d413d05,0x7c2e50ab,0x00000000}},	//   _tööl_, ólag, lsbr,
  { {0x7bc471ef,0xddcd319e,0x6fdd11f5,0x00000000}},	//   lniu, _kraš, réci,
  { {0x69c30d58,0x63a271f0,0x7c2e71f1,0x00000000}},	//   čnet, _plon, nsbr,
  { {0x6fdd18b3,0xbddb0003,0x7c2e0760,0x00000000}},	//   péci, ntèr, isbr,
  { {0xf1261b79,0x39960026,0x7bc44e91,0x00000000}},	//   льно, _fæst_, iniu,
  { {0x399600b9,0x7642005b,0xdb0d00a5,0x00000000}},	//   _gæst_, muoy, _åhör,
  { {0x7c2e006f,0x3f920058,0x84e60121,0x00000000}},	//   jsbr, _boyu_, _сожж,
  { {0x7c2e0146,0xdb0d017d,0xf8b30063,0x00000000}},	//   dsbr, miaç, משת_,
  { {0xdb0d0016,0x9f92007a,0xef1f000f,0x00000000}},	//   liaç, ráð_, ljük_,
  { {0xddcd007c,0x3f8001a8,0x6fc80058,0x00000000}},	//   _braš, _eniu_, rıca,
  { {0x2b9c001b,0xef1f00ea,0x7c2e35aa,0x00000000}},	//   _kích_, njük_, gsbr,
  { {0x40eb0063,0xddcd007c,0x307b07e9,0x00000000}},	//   _אַחֲ, _draš, _טאונ,
  { {0x645c0019,0x7ac70085,0x52e20042,0x00000000}},	// [fff0] _ärif, усве, _परोस,
  { {0x7d180066,0xbddb01a8,0x6f1d004d,0x00000000}},	//   časí, atèr, lbsc,
  { {0x31570047,0xddcd00b2,0x7ae2008f,0x00000000}},	//   ריבן_, _graš, ļota,
  { {0xbddb03b2,0x6d470026,0xdb0d1805,0x00000000}},	//   ctèr, lgja, diaç,
  { {0x366964ab,0xe8e00013,0x6b8b0014,0x00000000}},	//   тало_, riều_, öggu,
  { {0x6d4771f2,0xd6180021,0x8624000d,0x00000000}},	//   ngja, اتنا_, сьце,
  { {0x6d470014,0x2b9c0013,0xcd980063,0x00000000}},	//   igja, _bích_, רדות_,
  { {0x6b8d053b,0xf8b20063,0x4255058f,0x00000000}},	//   njag, _ושל_, атот,
  { {0x69c571f3,0xe6100021,0xe29f0014,0x00000000}},	//   onhe, _فشل_, áð_,
  { {0x69c5659f,0x7bc4013d,0x6b8d004e,0x00000000}},	//   nnhe, zniu, hjag,
  { {0xdb0d0016,0xbfc60086,0x27ed008b,0x00000000}},	//   ciaç, ибок, _khen_,
  { {0xe8d60063,0x69c5004d,0x644306d5,0x00000000}},	//   יותר_, hnhe, muni,
  { {0x539a014e,0x64431b33,0x63a90026,0x00000000}},	//   _שינו, luni, mhen,
  { {0xddcd0812,0x7c2e0c4a,0x61420001,0x00000000}},	//   _praš, tsbr, _деша,
  { {0x1c390376,0x69c50089,0xbddb0003,0x00000000}},	//   лять_, dnhe, ttèr,
  { {0x63bb27d7,0x6d4100cd,0x2b9c0013,0x00000000}},	//   niun, òlar, _xích_,

  };

static const uint32 kQuadTableInd[29172] = {
  // [0000]
  0x00000000, 0x00001e0f, 0x00002506, 0x00000506,
  0x0000191c, 0x38000509, 0x0000160f, 0x03066612,
  0x451d4012, 0x00003f1c, 0x0000250f, 0x05001412,
  0x0000170f, 0x0000300f, 0x0b000208, 0x0000181c,
  // [0010]
  0x050d0f07, 0x2b003f14, 0x19002113, 0x00004306,
  0x00001406, 0x17000822, 0x00000d0f, 0x00001c2d,
  0x0b0602af, 0x0000190f, 0x1d001707, 0x0000431c,
  0x0000150f, 0x03050621, 0x063821a4, 0x00002b0f,
  // [0020]
  0x1d450c21, 0x0000370f, 0x00000c06, 0x00001501,
  0x0000450f, 0x00001f0f, 0x0000140f, 0x00001f1c,
  0x1d271912, 0x27192912, 0x37004e14, 0x00002b06,
  0x0000210f, 0x030b0221, 0x05190407, 0x43002b07,
  // [0030]
  0x220b1055, 0x00000b0f, 0x0000371c, 0x10060da4,
  0x0000010f, 0x00003f0f, 0x06100809, 0x0000011c,
  0x16001712, 0x0b061012, 0x19000414, 0x00001706,
  0x06100d09, 0x0000151c, 0x29002714, 0x1d4016ad,
  // [0040]
  0x06430d02, 0x00005c06, 0x00002406, 0x00004e01,
  0x00003706, 0x00000c1c, 0x00001401, 0x00005c0f,
  0x40013f12, 0x37004e13, 0x45001214, 0x00001906,
  0x00001206, 0x00000606, 0x00001901, 0x02120107,
  // [0050]
  0x00000401, 0x00000c0f, 0x29002708, 0x0000240f,
  0x00002306, 0x00000e1c, 0x08192907, 0x16004012,
  0x00002206, 0x04003802, 0x00001c0f, 0x0000220f,
  0x450b0202, 0x00004e06, 0x00001e06, 0x00001601,
  // [0060]
  0x180d05a4, 0x12004509, 0x00001c06, 0x0000070f,
  0x18221012, 0x0e002313, 0x00004506, 0x4e003722,
  0x06451702, 0x04010209, 0x00004e1c, 0x160427af,
  0x00000501, 0x00000f06, 0x1c1e2512, 0x00000306,
  // [0070]
  0x020b1023, 0x23000e13, 0x00000406, 0x020b1422,
  0x0e001e07, 0x00002201, 0x00000e0f, 0x1d004002,
  0x00001606, 0x0000251c, 0x0000141c, 0x1e002509,
  0x12001d07, 0x00001d06, 0x00004e0f, 0x30000e07,
  // [0080]
  0x0000120f, 0x251c0e08, 0x00002401, 0x30002308,
  0x1e0e2313, 0x00003006, 0x0000230f, 0x270d29a4,
  0x0000301c, 0x00002906, 0x04050112, 0x0000430f,
  0x43450f07, 0x00004301, 0x08012b07, 0x00001506,
  // [0090]
  0x14001812, 0x1e230e07, 0x25001e08, 0x02000b08,
  0x00001c01, 0x25001e13, 0x2b272912, 0x30002323,
  0x251c0e12, 0x171812a4, 0x00000706, 0x4e003707,
  0x00001801, 0x00000701, 0x4e003711, 0x07005c13,
  // [00a0]
  0x0e001c12, 0x05000308, 0x12004008, 0x00002b01,
  0x00002106, 0x00001001, 0x14000608, 0x220105a4,
  0x00004001, 0x0c291409, 0x0000432d, 0x150806bb,
  0x00006606, 0x38000b08, 0x0f002707, 0x17380fa4,
  // [00b0]
  0x10006612, 0x0c1d1009, 0x1d004008, 0x37004e20,
  0x0d041212, 0x00005c1c, 0x10150309, 0x00005c2d,
  0x10000b02, 0x00000206, 0x01020ba4, 0x0000211c,
  0x01190307, 0x0000060f, 0x00000d01, 0x30001c20,
  // [00c0]
  0x0c000b13, 0x0c660312, 0x00004006, 0x0000400f,
  0x0f1708a4, 0x380f0d13, 0x05003802, 0x0000100f,
  0x0c011712, 0x06000502, 0x00000301, 0x430104a4,
  0x15001611, 0x00003806, 0x380d1809, 0x0b001009,
  // [00d0]
  0x06001420, 0x00000b06, 0x0f0610af, 0x0c400bbb,
  0x011d0f07, 0x05001607, 0x1e0e2502, 0x1e002512,
  0x38170112, 0x1e0e25a4, 0x23251c60, 0x0f010502,
  0x10003f07, 0x00001701, 0x00003701, 0x10000b09,
  // [00e0]
  0x04000607, 0x1e002514, 0x0e251e12, 0x0000290f,
  0x060127ad, 0x00000106, 0x01382b07, 0x19000609,
  0x0000660f, 0x380f0512, 0x0000180f, 0x0000161c,
  0x060c01a4, 0x0f000d08, 0x43386607, 0x03001921,
  // [00f0]
  0x04160513, 0x01002b07, 0x4e003712, 0x0000270f,
  0x38000507, 0x03006607, 0x2b000112, 0x27001f12,
  0x0f000d09, 0x0d170107, 0x04032b07, 0x231c2509,
  0x1d001612, 0x1e250eaf, 0x0000040f, 0x07005c14,
  // [0100]
  0x40183f09, 0x30002335, 0x03006623, 0x06220309,
  0x03006608, 0x02060baf, 0x0c002b20, 0x01380455,
  0x06011908, 0x03020b09, 0x0000021c, 0x06036660,
  0x0b020407, 0x231c2520, 0x19000113, 0x45083808,
  // [0110]
  0x05003808, 0x164512af, 0x66030112, 0x2b011f12,
  0x45001213, 0x01030613, 0x01083820, 0x00001d1c,
  0x38000f07, 0x10020b55, 0x011f2112, 0x00001201,
  0x00001c1c, 0x10020b08, 0x0b220407, 0x272b0112,
  // [0120]
  0x051f0112, 0x00000e06, 0x0000030f, 0x1f002b13,
  0x12004507, 0x2b000120, 0x042729a4, 0x662b0112,
  0x100b0808, 0x1e002302, 0x05380809, 0x10001808,
  0x00002301, 0x1c251e13, 0x1c230ebe, 0x25000e08,
  // [0130]
  0x00001d01, 0x00002501, 0x5c000721, 0x1e230e13,
  0x061f0121, 0x17016607, 0x060501af, 0x00001006,
  0x00001e1c, 0x00001f06, 0x4e003714, 0x061f2b55,
  0x30002312, 0x00001806, 0x0e252309, 0x1c251e08,
  // [0140]
  0x19001012, 0x1e002508, 0x1c0e1e07, 0x0d381412,
  0x18000311, 0x30000e02, 0x0000020f, 0x10005108,
  0x231e1cad, 0x07005c12, 0x23251ca4, 0x00003001,
  0x30000e14, 0x37004e11, 0x0000071c, 0x29002713,
  // [0150]
  0x00002706, 0x010d10a4, 0x251e1c13, 0x0f000507,
  0x1c230e07, 0x011904a4, 0x0e002312, 0x03010412,
  0x01210411, 0x19006607, 0x23000e11, 0x250e1ea4,
  0x04000308, 0x66000412, 0x66000113, 0x010466a4,
  // [0160]
  0x1e1c0e12, 0x0000241c, 0x03006614, 0x0c001811,
  0x0000050f, 0x0000070a, 0x01196612, 0x18451211,
  0x00000101, 0x0e1c1e12, 0x24004108, 0x45001223,
  0x01001908, 0x66000312, 0x07005c07, 0x2b001f34,
  // [0170]
  0x060b0307, 0x01180308, 0x02000402, 0x66000314,
  0x0e1c2560, 0x0e001e14, 0x04002121, 0x1d0b1007,
  0x01002108, 0x66000313, 0x66190313, 0x27036608,
  0x00004501, 0x00000d06, 0x29002709, 0x00001d0f,
  // [0180]
  0x03001912, 0x0b036612, 0x05141612, 0x0e003008,
  0x0e001e13, 0x00002b1c, 0x03006611, 0x1c001e22,
  0x19141007, 0x25001c14, 0x12004014, 0x23001e12,
  0x0b100208, 0x00001f2d, 0x1e002513, 0x06011007,
  // [0190]
  0x18006612, 0x01050812, 0x0b030609, 0x1e002314,
  0x06000311, 0x12004508, 0x020b1009, 0x190529ad,
  0x0000401c, 0x0000061c, 0x05001621, 0x23001e11,
  0x1c002509, 0x0000231c, 0x01002913, 0x40001513,
  // [01a0]
  0x04000111, 0x22000407, 0x0b020612, 0x01060b08,
  0x0e001c09, 0x19000420, 0x1d004022, 0x4e003721,
  0x00003801, 0x04001909, 0x0000252d, 0x17100b14,
  0x02036609, 0x05106607, 0x151d1608, 0x02000308,
  // [01b0]
  0x03000207, 0x081938a4, 0x18000412, 0x40001d14,
  0x23250ebe, 0x401d1511, 0x16000208, 0x1d1040af,
  0x12041913, 0x0b001012, 0x100c1fbb, 0x06001007,
  0x0b000222, 0x10151421, 0x14001011, 0x100c6655,
  // [01c0]
  0x03012b07, 0x02030608, 0x45001212, 0x0f061013,
  0x21100b11, 0x10060b07, 0x38000108, 0x150f1612,
  0x45001208, 0x010821ac, 0x05001812, 0x66011009,
  0x010408a4, 0x1d001907, 0x00001e01, 0x19000407,
  // [01d0]
  0x080b1012, 0x45001209, 0x14100b14, 0x2b1701af,
  0x05001813, 0x23000e07, 0x0d213f12, 0x020118bc,
  0x0000072d, 0x12004512, 0x45001211, 0x0b040209,
  0x19002b08, 0x30002313, 0x01105107, 0x06020b14,
  // [01e0]
  0x05001807, 0x00000201, 0x1e1c25a4, 0x0000101c,
  0x1c0e2509, 0x06010409, 0x06141913, 0x38010809,
  0x0e003020, 0x04001007, 0x1c250ea4, 0x0e003009,
  0x01192707, 0x080c05a4, 0x020b0812, 0x23251e12,
  // [01f0]
  0x1d0c4007, 0x0d010f02, 0x02000b09, 0x37004e07,
  0x00000801, 0x1d451260, 0x1c1e2509, 0x0000221c,
  0x1c230e13, 0x5c000720, 0x0d0f05a4, 0x37004e12,
  0x30251c07, 0x1e302321, 0x1c0e1e09, 0x12001d02,
  // [0200]
  0x23000e09, 0x1e230e09, 0x30251c6f, 0x0b100207,
  0x0f000813, 0x0b000214, 0x01000607, 0x400c1d07,
  0x29004320, 0x16151921, 0x1527296f, 0x080c17a4,
  0x10030202, 0x221d45af, 0x043f1509, 0x02101909,
  // [0210]
  0x0d272908, 0x27294012, 0x10190809, 0x19000413,
  0x19292713, 0x19004022, 0x2b0143a4, 0x23001c02,
  0x19001611, 0x19401d22, 0x0d003807, 0x0b401d23,
  0x19000f12, 0x0d1d2107, 0x04001913, 0x0000661c,
  // [0220]
  0x02140b12, 0x01000611, 0x01002907, 0x16401da4,
  0x18000b11, 0x1d1540af, 0x0c001d13, 0x04151921,
  0x27002912, 0x03006609, 0x16041960, 0x29142713,
  0x231c0e11, 0x01022b07, 0x14021009, 0x27020b12,
  // [0230]
  0x0b010212, 0x19272913, 0x100b0211, 0x03001412,
  0x04020b11, 0x24004113, 0x061440bc, 0x66270621,
  0x06050112, 0x0e002507, 0x10026612, 0x30231e12,
  0x22451212, 0x40100b09, 0x291d6609, 0x456612bb,
  // [0240]
  0x12004514, 0x010c2b12, 0x37004e22, 0x38052b08,
  0x00000601, 0x1c000e22, 0x100b0209, 0x1d002909,
  0x030129a4, 0x1d001507, 0x0000041c, 0x18124508,
  0x24004112, 0x38000207, 0x2b0d08be, 0x0d1d4012,
  // [0250]
  0x03006613, 0x0e231c60, 0x40182207, 0x12001d11,
  0x45124002, 0x121d4555, 0x1c0e25a4, 0x230e1c13,
  0x1e231c07, 0x25001e12, 0x1c2530ad, 0x03061407,
  0x14012908, 0x16001d14, 0x16061412, 0x45000c08,
  // [0260]
  0x45001207, 0x12000207, 0x2b0104bc, 0x1e251ca4,
  0x14001f13, 0x181d27a4, 0x12004009, 0x013803a4,
  0x0000380f, 0x06010512, 0x21004513, 0x1c002514,
  0x30000e13, 0x04000602, 0x40100b55, 0x010603af,
  // [0270]
  0x02031d02, 0x06160112, 0x06140512, 0x0000212d,
  0x10050108, 0x29002120, 0x19660313, 0x21272913,
  0x041f3f60, 0x293f2113, 0x0f272960, 0x0f292712,
  0x40001d13, 0x12004513, 0x011d1712, 0x27100b60,
  // [0280]
  0x01080f6f, 0x21152912, 0x1d000813, 0x0d380faf,
  0x38054511, 0x03000602, 0x380d05be, 0x052b01af,
  0x02000111, 0x380105be, 0x04010612, 0x0f212908,
  0x0f001913, 0x29002712, 0x0f380521, 0x021008a4,
  // [0290]
  0x00000806, 0x38000521, 0x160f21ad, 0x66192909,
  0x38010508, 0x01003811, 0x03050612, 0x0d000f13,
  0x22000c12, 0x0e002302, 0x10660313, 0x66010612,
  0x12000f07, 0x66004012, 0x01030b07, 0x19121d07,
  // [02a0]
  0x38050112, 0x0e002311, 0x1c251e22, 0x0f000521,
  0x05001712, 0x38000513, 0x063f04af, 0x38000512,
  0x19006608, 0x25001e22, 0x0b0210be, 0x02000b13,
  0x1c0e2311, 0x0b0210af, 0x66003f12, 0x0b001807,
  // [02b0]
  0x0000031c, 0x0e1e25af, 0x0f040513, 0x1e1c2507,
  0x272904bc, 0x1f000413, 0x1c002508, 0x0b0238af,
  0x06226607, 0x22046614, 0x0b055112, 0x0f000420,
  0x01036613, 0x022901a4, 0x14220809, 0x04051f12,
  // [02c0]
  0x100b0208, 0x120118ad, 0x0b050212, 0x010f3807,
  0x080f0109, 0x38100b07, 0x050f0812, 0x05000207,
  0x020608ad, 0x0f030112, 0x293f2213, 0x16001008,
  0x22002908, 0x050104be, 0x030601af, 0x0b140223,
  // [02d0]
  0x0f081d14, 0x041f0513, 0x19000607, 0x43010807,
  0x0f0b0209, 0x22664008, 0x08160102, 0x0e233007,
  0x25001e07, 0x08010d12, 0x37004e02, 0x1d0d08a4,
  0x0e003012, 0x00000f0f, 0x0d001013, 0x10001820,
  // [02e0]
  0x0b100209, 0x1c003013, 0x1d004014, 0x0f010809,
  0x230e1c12, 0x0b0266a4, 0x19081812, 0x3f124521,
  0x43002708, 0x1d000f21, 0x10020b12, 0x10005113,
  0x400f2912, 0x171f0112, 0x05290f09, 0x40430107,
  // [02f0]
  0x10000b13, 0x1d0466ad, 0x0c1d4022, 0x291d3f12,
  0x0000121c, 0x0f002908, 0x0000081c, 0x1d004009,
  0x25001e09, 0x230e1ca4, 0x23000e02, 0x10000b12,
  0x18000f09, 0x0b001002, 0x23003012, 0x1d0522ac,
  // [0300]
  0x45151d13, 0x0c002908, 0x2b002913, 0x14100b08,
  0x23003022, 0x052b0112, 0x29003f12, 0x0b000223,
  0x290f1d13, 0x27002b21, 0x03121f12, 0x00000e01,
  0x03000608, 0x05010f12, 0x100b1512, 0x15000c14,
  // [0310]
  0x0b101413, 0x400c3f12, 0x100b0612, 0x1d000513,
  0x05010807, 0x06000402, 0x060105bb, 0x03044512,
  0x12450c07, 0x050b01ac, 0x011f0412, 0x10050112,
  0x15001622, 0x2b050112, 0x0e1c1e13, 0x1d0504ad,
  // [0320]
  0x1e1c2508, 0x66000613, 0x27002b12, 0x06100b12,
  0x01000c11, 0x08120507, 0x18001708, 0x030105a4,
  0x16001907, 0x03186609, 0x0f003807, 0x66044013,
  0x03001707, 0x1e1c25af, 0x18001913, 0x01004508,
  // [0330]
  0x0e001c07, 0x00000f01, 0x04002108, 0x06002b12,
  0x380f1d07, 0x03002b08, 0x1e1c2514, 0x10030607,
  0x0f0d0309, 0x0c001713, 0x40171daf, 0x12002107,
  0x12000112, 0x1d401712, 0x0d220f09, 0x06000812,
  // [0340]
  0x06001711, 0x16000411, 0x190429af, 0x05001808,
  0x02004007, 0x03050107, 0x16001908, 0x3f016609,
  0x190414af, 0x1e003013, 0x400c1daf, 0x1c230e09,
  0x452b01a4, 0x0000451c, 0x06003807, 0x22026660,
  // [0350]
  0x27222114, 0x272229af, 0x382b0112, 0x0b036607,
  0x06001008, 0x10000223, 0x292151af, 0x3f292712,
  0x38001013, 0x06000113, 0x01002b12, 0x3f001021,
  0x060c1d07, 0x212927af, 0x0d272912, 0x0f4301af,
  // [0360]
  0x27002909, 0x0b062207, 0x14021022, 0x1c000e07,
  0x451d0d09, 0x29222114, 0x25002311, 0x38000d13,
  0x1d001512, 0x29272b21, 0x1c002511, 0x38222114,
  0x3827296f, 0x03662712, 0x17401d12, 0x38140521,
  // [0370]
  0x06002707, 0x1c300e21, 0x10080102, 0x66292712,
  0x29226609, 0x22000611, 0x23000e14, 0x170c0855,
  0x22000607, 0x22006607, 0x0c451d02, 0x30231c12,
  0x231c0ead, 0x02660360, 0x19000423, 0x451d12cf,
  // [0380]
  0x21003f13, 0x180306a4, 0x17080209, 0x08020baf,
  0x0c004007, 0x06000121, 0x02660baf, 0x12000807,
  0x1d000213, 0x1f002120, 0x08030baf, 0x1d000809,
  0x22170daf, 0x081d4008, 0x030b026f, 0x1d0c40ac,
  // [0390]
  0x12080107, 0x08021721, 0x121d4009, 0x120c1d07,
  0x0000242d, 0x45182211, 0x03060207, 0x27002913,
  0x08020b23, 0x08050112, 0x010b1007, 0x19120113,
  0x0f451214, 0x06000f02, 0x17020b22, 0x0f000d07,
  // [03a0]
  0x08000b13, 0x05000f08, 0x01272909, 0x08060112,
  0x0c001213, 0x15160b12, 0x0e231e11, 0x01000608,
  0x66000322, 0x29012709, 0x0f6601af, 0x21030112,
  0x06036613, 0x18000f12, 0x43000112, 0x18003811,
  // [03b0]
  0x10001913, 0x0b000113, 0x0000051c, 0x0d002123,
  0x18020b14, 0x10191fac, 0x1d4004a4, 0x0d010809,
  0x1d041fad, 0x10000f07, 0x23301eac, 0x404503be,
  0x0b06666f, 0x1d000113, 0x04061012, 0x100b0307,
  // [03c0]
  0x21014512, 0x27661960, 0x10030107, 0x5c000714,
  0x19061002, 0x02080b07, 0x0d002712, 0x451d1812,
  0x04001012, 0x026604af, 0x0b1051ad, 0x040529a4,
  0x01000d07, 0x0b190212, 0x10023f08, 0x38060d07,
  // [03d0]
  0x01271909, 0x1c000e11, 0x04191faf, 0x211f1712,
  0x02100b08, 0x3f002121, 0x0e001c14, 0x29273f21,
  0x22193f09, 0x00000d1c, 0x0d010813, 0x380f01af,
  0x21020b12, 0x191f01af, 0x19000620, 0x2b1f0812,
  // [03e0]
  0x27001612, 0x0d0f01af, 0x15221914, 0x1d0f19ad,
  0x084519af, 0x301e2507, 0x0e003023, 0x17051d12,
  0x0000182d, 0x0000012d, 0x0d003808, 0x37004e21,
  0x0e002513, 0x010f0607, 0x43384021, 0x01192109,
  // [03f0]
  0x1e302311, 0x06172212, 0x081751af, 0x27380d13,
  0x06020d09, 0x45004013, 0x03005108, 0x29212712,
  0x0f002b22, 0x212729af, 0x04000d12, 0x06030b07,
  0x19170560, 0x056645a4, 0x0f001720, 0x38052709,

  // [0400]
  0x273f0112, 0x01001d07, 0x010d0f13, 0x2b401d12,
  0x0c000614, 0x18001f12, 0x1d4021a4, 0x22000c08,
  0x050c0809, 0x380508a4, 0x0b020609, 0x0d050f11,
  0x05001422, 0x0c004012, 0x18154009, 0x45000508,
  // [0410]
  0x08005108, 0x12000107, 0x120c4013, 0x1e002311,
  0x05002111, 0x1d001007, 0x231e2507, 0x00001503,
  0x0000152d, 0x080d0f09, 0x1d124520, 0x00004e42,
  0x1d024008, 0x25001e23, 0x03100b07, 0x45121daf,
  // [0420]
  0x17001213, 0x02030baf, 0x06012207, 0x19221060,
  0x10000812, 0x19000212, 0x02002207, 0x38180855,
  0x18170812, 0x250e1c12, 0x300e1c12, 0x66030608,
  0x0e001c13, 0x1f030612, 0x18001912, 0x0b033802,
  // [0430]
  0x251e0eaf, 0x25001c23, 0x0e001c23, 0x06002208,
  0x02290111, 0x40452909, 0x22001921, 0x43001811,
  0x03006612, 0x01104007, 0x25230eaf, 0x0000372d,
  0x08041712, 0x400c1d20, 0x37004e09, 0x12042b12,
  // [0440]
  0x04163f12, 0x18003f12, 0x451810ad, 0x21222712,
  0x0e1c25ac, 0x12004502, 0x0e233012, 0x29271daf,
  0x231c2512, 0x04001921, 0x08000413, 0x18040814,
  0x082b0512, 0x08041fa4, 0x01001711, 0x0c151655,
  // [0450]
  0x1d053855, 0x18004508, 0x03660d08, 0x45000807,
  0x30002314, 0x19002107, 0x1c000e08, 0x300e25a4,
  0x08272212, 0x25001e21, 0x15006608, 0x23003008,
  0x18150822, 0x05012712, 0x04000611, 0x29051408,
  // [0460]
  0x0d000f09, 0x04000613, 0x1903666f, 0x030466bc,
  0x06041012, 0x21000113, 0x03000411, 0x04000b12,
  0x40000c22, 0x0000172d, 0x1e232513, 0x02100bbe,
  0x0c003f21, 0x100402a4, 0x23003007, 0x23300eaf,
  // [0470]
  0x45120cad, 0x0c1245af, 0x23002513, 0x0c004011,
  0x01006607, 0x0e003022, 0x0104196f, 0x43001720,
  0x04004512, 0x660301af, 0x213f4011, 0x06012707,
  0x040c1614, 0x40003f21, 0x1c000e13, 0x04001922,
  // [0480]
  0x29271614, 0x251c0e09, 0x042716ad, 0x12041612,
  0x29181614, 0x10270408, 0x172b2255, 0x45033812,
  0x18002708, 0x160c2708, 0x22006612, 0x0f014021,
  0x05000d12, 0x0f1551af, 0x00000f1c, 0x22291d12,
  // [0490]
  0x1f003f12, 0x2b013f12, 0x17002913, 0x0d001712,
  0x171d40a4, 0x03124513, 0x030c06a4, 0x2b4027af,
  0x16000113, 0x0e002314, 0x030b0112, 0x05100107,
  0x22000608, 0x290627af, 0x17010812, 0x1e1c2555,
  // [04a0]
  0x37004e08, 0x0c000307, 0x190340af, 0x12000113,
  0x0c002712, 0x38000d08, 0x0f000d14, 0x0b000607,
  0x1d451213, 0x0e251c55, 0x00000b01, 0x0000222d,
  0x12000114, 0x06000807, 0x080116ad, 0x19225112,
  // [04b0]
  0x0d0f1608, 0x020b51af, 0x14001521, 0x10002212,
  0x29001912, 0x01292755, 0x10222109, 0x06171f13,
  0x171f1960, 0x1d220112, 0x0d1701af, 0x25001c20,
  0x05000113, 0x1f3f1221, 0x02000802, 0x2b000113,
  // [04c0]
  0x66031012, 0x10000622, 0x080d0112, 0x0e1c25a4,
  0x66170813, 0x10002220, 0x03006622, 0x10000b07,
  0x1d124512, 0x1d004513, 0x05080112, 0x2b162112,
  0x08401d21, 0x0f0d1f08, 0x0b190508, 0x08380f09,
  // [04d0]
  0x01000f07, 0x060b0207, 0x22002112, 0x06100209,
  0x083805ac, 0x661f3f13, 0x0e002308, 0x0c120507,
  0x1c232507, 0x401d4512, 0x01000620, 0x660b0612,
  0x1e230ea4, 0x1d170812, 0x00004e2d, 0x121d0808,
  // [04e0]
  0x08121d21, 0x04001014, 0x0c170807, 0x250e1c13,
  0x08001213, 0x17380812, 0x151601af, 0x171d08ac,
  0x18450d08, 0x12004012, 0x120c1da4, 0x104504a0,
  0x06013807, 0x1e001c02, 0x031d0607, 0x1c000e02,
  // [04f0]
  0x0f100b12, 0x01170fa4, 0x1e1c2509, 0x17220809,
  0x66170812, 0x38120807, 0x37004e23, 0x150f2108,
  0x01292707, 0x0b040202, 0x17004302, 0x100216a4,
  0x03000d07, 0x451d4007, 0x3f292720, 0x66000112,
  // [0500]
  0x23003013, 0x1f030620, 0x06001013, 0x30230ea4,
  0x19001007, 0x0e002307, 0x0c451912, 0x451701a4,
  0x292227af, 0x01002707, 0x291d3faf, 0x062b0112,
  0x03000611, 0x062b0155, 0x38140112, 0x230e2512,
  // [0510]
  0x012b0512, 0x270b1009, 0x12004523, 0x45120112,
  0x06661812, 0x22002b13, 0x0d000f02, 0x08003802,
  0x03066609, 0x230e1c55, 0x06000413, 0x38000307,
  0x10000607, 0x03000620, 0x0000080f, 0x08000607,
  // [0520]
  0x19292709, 0x38000f12, 0x27001620, 0x660306be,
  0x01036608, 0x0e3023ac, 0x01001907, 0x10000407,
  0x10661faf, 0x0000171c, 0x04001021, 0x0f1245a4,
  0x04001022, 0x03004311, 0x231c0e23, 0x06172712,
  // [0530]
  0x0d0f3809, 0x040b0507, 0x01276608, 0x17016609,
  0x0c001d02, 0x040106a4, 0x3f000435, 0x66002112,
  0x120c5112, 0x191d4011, 0x3f002123, 0x27002914,
  0x0f001707, 0x0b080207, 0x3f214013, 0x380801af,
  // [0540]
  0x1e002523, 0x1e0e2312, 0x040d1707, 0x274045af,
  0x0c120faf, 0x0f0d3821, 0x06001911, 0x27660308,
  0x01222708, 0x0d040612, 0x660f3f12, 0x1f213f12,
  0x38273fad, 0x1d401909, 0x1d451212, 0x01431daf,
  // [0550]
  0x03062b07, 0x19002713, 0x0f380da4, 0x06100207,
  0x40121dbb, 0x38000d07, 0x04272913, 0x0c1d4008,
  0x40010507, 0x0b062707, 0x19051f07, 0x08000113,
  0x0c1d2907, 0x0e232507, 0x40001d21, 0x01004307,
  // [0560]
  0x19001f21, 0x40041821, 0x1d124008, 0x10000623,
  0x061d0507, 0x0c3f1d14, 0x45001202, 0x1d120fa4,
  0x0f001721, 0x380f0dac, 0x06270312, 0x0f002b02,
  0x00000c01, 0x38001f12, 0x451210ba, 0x19000307,
  // [0570]
  0x12000c14, 0x1c1e2514, 0x0b0604af, 0x1d020307,
  0x40451212, 0x0c001207, 0x19151612, 0x380f0daf,
  0x40001622, 0x16001f14, 0x1f000113, 0x021f0b11,
  0x0c002b08, 0x012119af, 0x19000b12, 0x17660311,
  // [0580]
  0x22001813, 0x1c002522, 0x060b1009, 0x14000208,
  0x0d380520, 0x29004013, 0x051701a4, 0x062966a4,
  0x12292755, 0x190b0260, 0x380d6608, 0x38001902,
  0x3f002913, 0x1c300ea4, 0x04002109, 0x251c1eaf,
  // [0590]
  0x1c0e1ea4, 0x1c000e09, 0x21000112, 0x4e003713,
  0x120145a4, 0x14000812, 0x16121d08, 0x0000302d,
  0x062951af, 0x45004012, 0x40160f55, 0x01292714,
  0x29042260, 0x45121d08, 0x22292712, 0x03000107,
  // [05a0]
  0x231e0e55, 0x1c232512, 0x14002221, 0x19040507,
  0x04222707, 0x0b000202, 0x224519af, 0x08002212,
  0x12662b08, 0x0b000308, 0x152212af, 0x380d0f07,
  0x30000e08, 0x10000213, 0x22060f23, 0x121440be,
  // [05b0]
  0x01220207, 0x1d082713, 0x2b292713, 0x00003f06,
  0x22012707, 0x19001607, 0x032b0112, 0x19170807,
  0x191d4060, 0x0b000207, 0x380f0d20, 0x1d122207,
  0x2b0c1212, 0x0e251c12, 0x01030608, 0x291606af,
  // [05c0]
  0x22041908, 0x1d221712, 0x0c380d02, 0x0c1245a4,
  0x1d151421, 0x1c001e12, 0x271722af, 0x231e1c13,
  0x03000b12, 0x1d004020, 0x0f0d3822, 0x1d170813,
  0x06003f12, 0x10401709, 0x1c1e2508, 0x23251e08,
  // [05d0]
  0x27291d09, 0x0d0f1d09, 0x251c0e22, 0x0b380f02,
  0x03001909, 0x0d000f07, 0x04012909, 0x17000512,
  0x18272912, 0x100322ad, 0x03660baf, 0x14000b21,
  0x19142212, 0x0b000213, 0x3f290baf, 0x03000614,
  // [05e0]
  0x1c001e02, 0x66060313, 0x06660360, 0x18030612,
  0x03000612, 0x03020b12, 0x03190d12, 0x02000b02,
  0x17433809, 0x06036655, 0x0c1201af, 0x12450121,
  0x0f001407, 0x18000612, 0x1c301e13, 0x1e251c14,
  // [05f0]
  0x12030108, 0x0e251c13, 0x0c030607, 0x06380809,
  0x1e000e08, 0x01120c07, 0x661201bb, 0x231c0e21,
  0x10060ba4, 0x1e1c2522, 0x124501af, 0x1c002513,
  0x43660112, 0x0e233008, 0x190b1009, 0x12401d09,
  // [0600]
  0x064018a4, 0x25001c08, 0x12402207, 0x23003011,
  0x0f030155, 0x40001d02, 0x121d4012, 0x451d40af,
  0x010d45a4, 0x100b02ac, 0x22160d08, 0x100b0260,
  0x30251eaf, 0x251c2307, 0x0e1e2521, 0x1c2325bc,
  // [0610]
  0x10036613, 0x020b1013, 0x1c000e12, 0x0c220112,
  0x45120609, 0x25231c13, 0x06002b07, 0x14030620,
  0x02006607, 0x23000e22, 0x0000452d, 0x02000b20,
  0x121d4060, 0x2b000623, 0x19002111, 0x100b0207,
  // [0620]
  0x0d0508a4, 0x02060308, 0x010f1709, 0x05003823,
  0x06272914, 0x03000113, 0x10001412, 0x14005113,
  0x400c45af, 0x27102913, 0x0c0f08cf, 0x05020b22,
  0x0d4512af, 0x030614af, 0x061f51af, 0x011f0611,
  // [0630]
  0x024551a4, 0x1d0c45af, 0x050d45af, 0x0b0f0809,
  0x036616af, 0x1e002511, 0x30002311, 0x020551af,
  0x080c1720, 0x2b0638af, 0x45126613, 0x0d004523,
  0x401d17bb, 0x0c1d3faf, 0x221d2108, 0x17004009,
  // [0640]
  0x401d01af, 0x170801a4, 0x22171408, 0x382b0821,
  0x45120daf, 0x272129af, 0x0c4045af, 0x161419af,
  0x1d4045af, 0x06001414, 0x45120d22, 0x231e2512,
  0x061451af, 0x030b0234, 0x04170307, 0x401d45af,
  // [0650]
  0x450d1221, 0x23003023, 0x221d4012, 0x080f01af,
  0x0f220555, 0x170605a4, 0x19000408, 0x06050307,
  0x0f001f10, 0x19000412, 0x291d22af, 0x25001c13,
  0x04001914, 0x17003823, 0x10001908, 0x40001d23,
  // [0660]
  0x38221d22, 0x17222712, 0x0d221523, 0x060416af,
  0x401d2912, 0x450c1d14, 0x02100b12, 0x02000521,
  0x06170512, 0x01050313, 0x17190512, 0x22001908,
  0x30001c13, 0x01000507, 0x0e003013, 0x25001c02,
  // [0670]
  0x06042207, 0x06052111, 0x2b220c13, 0x021001a4,
  0x04002b07, 0x1e000e23, 0x1e001c14, 0x100817bc,
  0x0c2b2255, 0x10170823, 0x100851af, 0x0c002b34,
  0x29002734, 0x10190307, 0x17105112, 0x27173f09,
  // [0680]
  0x0f0d3808, 0x17380555, 0x38000811, 0x17002212,
  0x061d66a4, 0x1c002320, 0x18000c14, 0x66170309,
  0x08001723, 0x0f1d0112, 0x121d4013, 0x0f080da4,
  0x140b1009, 0x05273812, 0x27211934, 0x04000f07,
  // [0690]
  0x1e002312, 0x036645af, 0x171008be, 0x271d21af,
  0x08016609, 0x08030507, 0x270f2112, 0x17050160,
  0x15000813, 0x1e002507, 0x07005c08, 0x19041007,
  0x021d5107, 0x0f0d3fbc, 0x06000b13, 0x02000b07,
  // [06a0]
  0x19140411, 0x170419a4, 0x020b0d12, 0x02100baf,
  0x0c172909, 0x0b000209, 0x08000d11, 0x29002722,
  0x2729026f, 0x02100b11, 0x06000308, 0x15060112,
  0x03066607, 0x66030614, 0x03660609, 0x010b1013,
  // [06b0]
  0x08436609, 0x1d4540af, 0x0d000f14, 0x1e002534,
  0x1e1c2512, 0x1d1751a4, 0x0e1e2511, 0x05190420,
  0x27000113, 0x121d4020, 0x08660111, 0x1d004023,
  0x0e003021, 0x1e232514, 0x25001c12, 0x011006a4,
  // [06c0]
  0x0d010607, 0x020c0611, 0x29002721, 0x23300e12,
  0x06022155, 0x080d0f08, 0x08001712, 0x19000c13,
  0x17121609, 0x0e003002, 0x171f0811, 0x1c002523,
  0x0c000211, 0x03170555, 0x0c004513, 0x0f190809,
  // [06d0]
  0x0c001412, 0x19000509, 0x06080509, 0x660c0112,
  0x15006622, 0x0d380f09, 0x45124008, 0x121729a4,
  0x1d1940a4, 0x660512af, 0x1c002507, 0x17006613,
  0x230e1ebc, 0x080c4512, 0x0f380814, 0x08191f09,
  // [06e0]
  0x1e1c0e14, 0x271929af, 0x380f0812, 0x450d0112,
  0x06000c22, 0x15450334, 0x1e0e1caf, 0x030c6633,
  0x38050108, 0x01660d09, 0x10001409, 0x05031022,
  0x142729af, 0x22002109, 0x06292709, 0x662101af,
  // [06f0]
  0x25001c11, 0x10020b09, 0x0d1419af, 0x032b6612,
  0x27010d09, 0x102205a4, 0x22002b21, 0x06016607,
  0x03000407, 0x10430112, 0x0b0208a4, 0x06100ba4,
  0x451210af, 0x29102708, 0x0f004508, 0x08001820,
  // [0700]
  0x06032b07, 0x0d011aaf, 0x03001920, 0x27060da4,
  0x10190112, 0x14001920, 0x03000112, 0x10000b23,
  0x06190112, 0x05010b12, 0x251c0ebc, 0x66000c21,
  0x38190112, 0x030d0f14, 0x01292760, 0x06036623,
  // [0710]
  0x2b063f12, 0x27036621, 0x100501af, 0x1e251c13,
  0x10001d08, 0x120227a4, 0x21001412, 0x06000307,
  0x380f0dad, 0x031901af, 0x25001c22, 0x052b0107,
  0x06002b13, 0x170801af, 0x120603ad, 0x30002307,
  // [0720]
  0x19001d21, 0x14101da4, 0x170645a4, 0x0d040202,
  0x45000313, 0x0f3801af, 0x30002322, 0x231c2507,
  0x0f183812, 0x1d001711, 0x08272155, 0x0c012708,
  0x10140b60, 0x231c0e55, 0x66000508, 0x0b1002ad,
  // [0730]
  0x02100b55, 0x0c002b11, 0x05000d13, 0x23251ea4,
  0x40001d08, 0x40171dad, 0x27000413, 0x15451d6f,
  0x14052b21, 0x140b0209, 0x020b1055, 0x38050f14,
  0x451d1212, 0x0f380d14, 0x451d12af, 0x1c2523ac,
  // [0740]
  0x06001807, 0x0f3808af, 0x14002b22, 0x12001d12,
  0x302325be, 0x1d002207, 0x0c151708, 0x0f000d23,
  0x19000314, 0x0d0f01a4, 0x02193faf, 0x120c2bbb,
  0x12060809, 0x43170509, 0x12451dbc, 0x40001d12,
  // [0750]
  0x45001d21, 0x04221412, 0x080366ad, 0x1f001d20,
  0x4e003720, 0x12001d13, 0x06140355, 0x03016607,
  0x0c001812, 0x01380daf, 0x01003f12, 0x190f1d09,
  0x0c062b07, 0x0d031812, 0x0c0b1907, 0x1c003008,
  // [0760]
  0x06036607, 0x16170812, 0x14002b13, 0x17001912,
  0x0f0d3809, 0x060803af, 0x30000e09, 0x22002b11,
  0x25230ea4, 0x230e25a4, 0x1c0e2308, 0x293f27af,
  0x00000b1c, 0x08380f07, 0x14022908, 0x1e3023ad,
  // [0770]
  0x01001f13, 0x06011aaf, 0x19001822, 0x0b2b1960,
  0x27001908, 0x0d003f12, 0x1c252321, 0x30232507,
  0x143f5112, 0x18002212, 0x05000809, 0x04000221,
  0x06100b02, 0x3f000113, 0x22000413, 0x08040b11,
  // [0780]
  0x06000112, 0x1c251eaf, 0x0e231c07, 0x08000107,
  0x220801af, 0x1e003012, 0x301c2513, 0x0d0108a4,
  0x01170860, 0x1c302509, 0x0c001623, 0x00000c0a,
  0x04001907, 0x08003807, 0x3f020baf, 0x040501af,
  // [0790]
  0x012b0613, 0x05060809, 0x29002212, 0x1e1c2523,
  0x1e1c2513, 0x251c0e21, 0x0c1712af, 0x100c51ad,
  0x1e3025a4, 0x15080512, 0x300e23af, 0x231e2509,
  0x1d002212, 0x14001614, 0x1c00371f, 0x0e002309,
  // [07a0]
  0x04000808, 0x231e0e12, 0x01031907, 0x0e231caf,
  0x12432b07, 0x04002207, 0x19010b02, 0x2b006614,
  0x380d0fa4, 0x061d29a4, 0x1d403813, 0x030801a4,
  0x250e1c22, 0x01100460, 0x03061807, 0x15000809,
  // [07b0]
  0x1e000e11, 0x3f2b1f21, 0x12450daf, 0x230e1c14,
  0x45401d12, 0x062b0d13, 0x184027a4, 0x19002707,
  0x27012908, 0x080501af, 0x08000407, 0x18431411,
  0x1f3f2912, 0x08050111, 0x06001908, 0x0e1c2555,
  // [07c0]
  0x02000d11, 0x06000511, 0x14001821, 0x18401d20,
  0x06213f12, 0x0c180860, 0x05010612, 0x06005113,
  0x0d453821, 0x06292712, 0x01103821, 0x06192112,
  0x01451d12, 0x05060823, 0x0c1745be, 0x06001422,
  // [07d0]
  0x384008a4, 0x19222907, 0x04190112, 0x01061faf,
  0x191f04af, 0x05003f11, 0x01153fad, 0x06292713,
  0x300e2509, 0x0d1638af, 0x23001c12, 0x02380baf,
  0x450d3821, 0x0f0d08ac, 0x151d0808, 0x0f191212,
  // [07e0]
  0x14162908, 0x1d000421, 0x02001420, 0x12003f20,
  0x02660b12, 0x220605af, 0x02000b12, 0x0419166f,
  0x220c3f13, 0x07005c11, 0x05173809, 0x100106ad,
  0x220f1960, 0x1e000e02, 0x12000111, 0x1722196f,
  // [07f0]
  0x1c003021, 0x011d4060, 0x0c041908, 0x01036609,
  0x16292760, 0x012166a4, 0x250e1e21, 0x12450c09,
  0x380c4308, 0x3f292714, 0x04292713, 0x14001007,
  0x10006608, 0x21272909, 0x1c001e14, 0x16292713,

  // [0800]
  0x16292709, 0x16292712, 0x06100b08, 0x05003809,
  0x04121d09, 0x06000507, 0x1c232513, 0x020b1008,
  0x12002709, 0x0000060a, 0x1e0e1c08, 0x1e251c55,
  0x430b0255, 0x2b003f12, 0x021d40a4, 0x0b061007,
  // [0810]
  0x16272923, 0x231c0e14, 0x0000162d, 0x05003807,
  0x00000f2d, 0x1c232514, 0x250e1c07, 0x23002512,
  0x251e1c12, 0x07005c1a, 0x45121d13, 0x050601af,
  0x2b001008, 0x06101907, 0x06160109, 0x23301e60,
  // [0820]
  0x231c0ebc, 0x03000b08, 0x16002708, 0x010810ad,
  0x382751af, 0x2b4501af, 0x1d29276f, 0x12000d07,
  0x1d061708, 0x10000b08, 0x1d004013, 0x1c1e25bc,
  0x0c062107, 0x0e003007, 0x020308a4, 0x0f1608a4,
  // [0830]
  0x18001d13, 0x02000b14, 0x10000613, 0x06105112,
  0x451206ad, 0x10161421, 0x12450d14, 0x29062709,
  0x02001007, 0x66144060, 0x1d401007, 0x1e300eaf,
  0x1d401813, 0x12100c08, 0x40272909, 0x06006608,
  // [0840]
  0x40450baf, 0x19660112, 0x30232521, 0x21163f09,
  0x66020baf, 0x1d000333, 0x45194011, 0x1d036620,
  0x43276655, 0x03016608, 0x1e002309, 0x151622ac,
  0x14272921, 0x1d454055, 0x66000413, 0x450d14bc,
  // [0850]
  0x0b006607, 0x45401d21, 0x0e251cac, 0x060b6609,
  0x25001c07, 0x1d020b12, 0x25001e11, 0x0f003808,
  0x0d003809, 0x21292709, 0x1d004007, 0x19000302,
  0x01002b13, 0x051516ac, 0x30230e08, 0x08002707,
  // [0860]
  0x0d000113, 0x0e1e2509, 0x01052b55, 0x124518ad,
  0x012b0d55, 0x14004513, 0x06141609, 0x0e251c09,
  0x04002212, 0x12401daf, 0x1f0f1812, 0x210c1009,
  0x1e251c6f, 0x181f0f60, 0x0b1d3f12, 0x04001008,
  // [0870]
  0x03290112, 0x38000f08, 0x04030b07, 0x0d180f07,
  0x29061d08, 0x180b1d12, 0x38000f14, 0x010d0f08,
  0x30001c12, 0x38180fad, 0x15005113, 0x18001008,
  0x03380509, 0x03000607, 0x14100211, 0x12000311,
  // [0880]
  0x12001814, 0x45190460, 0x0f001821, 0x04001d08,
  0x04001421, 0x18380f12, 0x0c000113, 0x18040112,
  0x231e0e09, 0x12006607, 0x170501a4, 0x04061d09,
  0x01170609, 0x18040809, 0x231e1caf, 0x18004507,
  // [0890]
  0x1f0801af, 0x19004008, 0x0f190102, 0x1c251e07,
  0x0e231ea4, 0x0e003014, 0x1e002502, 0x060801a4,
  0x19000112, 0x1e251c08, 0x0e001c02, 0x034512af,
  0x05380112, 0x231c0ea4, 0x5c000713, 0x10000614,
  // [08a0]
  0x23001e20, 0x40451d02, 0x23301e12, 0x03272955,
  0x19272912, 0x01006608, 0x30000e22, 0x1e0e1c12,
  0x231e2508, 0x0b001008, 0x4e003723, 0x2b001f23,
  0x1e002313, 0x03001708, 0x06000c13, 0x19002207,
  // [08b0]
  0x1e251caf, 0x10001611, 0x05036655, 0x0c006607,
  0x18224512, 0x38000c08, 0x03003811, 0x1d004507,
  0x27291f21, 0x1c230e12, 0x45000c02, 0x150621ad,
  0x01121702, 0x011d06a4, 0x1f000d14, 0x02001407,
  // [08c0]
  0x38002202, 0x45001d07, 0x231c30ac, 0x013f1911,
  0x40001213, 0x0000140a, 0x120302a4, 0x170d0309,
  0x17000812, 0x0d080f09, 0x101708a4, 0x010840a4,
  0x14121907, 0x661f3f09, 0x020b6609, 0x1d001609,
  // [08d0]
  0x03000f12, 0x03001013, 0x04000107, 0x06180c09,
  0x1c0e30bb, 0x18000b13, 0x18001621, 0x23002522,
  0x08010209, 0x380117af, 0x1d021f14, 0x010b0202,
  0x02000113, 0x01051fbb, 0x10002b13, 0x18080b12,
  // [08e0]
  0x04171812, 0x17080b12, 0x161951af, 0x14170baf,
  0x05011fa4, 0x1c0e2314, 0x02101d14, 0x17272920,
  0x0d061012, 0x10001411, 0x1d004012, 0x2b001013,
  0x180c3f12, 0x40001d09, 0x22001d08, 0x0e231e12,
  // [08f0]
  0x29002723, 0x16003f13, 0x00002101, 0x02000407,
  0x041f3f09, 0x1f001814, 0x0e233009, 0x0c002912,
  0x03272960, 0x02065112, 0x06001411, 0x18124514,
  0x036602be, 0x66031412, 0x18401d22, 0x0d660314,
  // [0900]
  0x661027a4, 0x0b401d82, 0x124529af, 0x030b51af,
  0x1d400baf, 0x0e001c11, 0x046603be, 0x03004009,
  0x040b0f12, 0x21002908, 0x0c0f3f60, 0x29270412,
  0x08003f11, 0x03003807, 0x661f05bb, 0x231e2513,
  // [0910]
  0x3f0c0112, 0x19013807, 0x02292760, 0x38000821,
  0x040366a4, 0x0c001620, 0x0f000212, 0x06006607,
  0x17000814, 0x03405112, 0x030666be, 0x0c001612,
  0x293f2713, 0x1940106f, 0x400c0314, 0x01060d07,
  // [0920]
  0x12450112, 0x03081f14, 0x031f0512, 0x03046607,
  0x10000113, 0x1c251ead, 0x08120107, 0x0c001009,
  0x0e002322, 0x37004e34, 0x06002207, 0x01451255,
  0x10020bbe, 0x121845a4, 0x06001009, 0x0b100609,
  // [0930]
  0x1c0e2502, 0x03011fa4, 0x1c250e07, 0x03004008,
  0x10000302, 0x0b023fad, 0x08060209, 0x120d2122,
  0x0c401d09, 0x45000202, 0x38001d20, 0x16002221,
  0x05060109, 0x0e251c07, 0x30000e12, 0x1c1e0e22,
  // [0940]
  0x0e002512, 0x08000b07, 0x0d000f12, 0x060114a4,
  0x2b0f086f, 0x052919bc, 0x14100baf, 0x151612a4,
  0x17660308, 0x22002708, 0x38140f13, 0x45150f09,
  0x380d0fbe, 0x020b1002, 0x03066622, 0x2b030112,
  // [0950]
  0x01172707, 0x0d380112, 0x22292722, 0x01061f08,
  0x0d081712, 0x380d0f09, 0x0e1c25be, 0x05400809,
  0x27381612, 0x45000207, 0x22001707, 0x0f0d01af,
  0x0f1701af, 0x0f0d0108, 0x18001f09, 0x05040112,
  // [0960]
  0x45151402, 0x03010fa4, 0x0e1c2514, 0x06000412,
  0x15000f07, 0x01000813, 0x66010c09, 0x3f292709,
  0x04022907, 0x27000112, 0x01273f09, 0x0c040112,
  0x08050107, 0x052b4555, 0x662701af, 0x170f0809,
  // [0970]
  0x661d4021, 0x120c0421, 0x010c1d07, 0x01150807,
  0x27002922, 0x400508a4, 0x01000c12, 0x66060420,
  0x66041421, 0x0b0c0107, 0x0c451208, 0x45010809,
  0x22000812, 0x03380221, 0x27052909, 0x29001212,
  // [0980]
  0x251e1cbe, 0x0c010f07, 0x181d0412, 0x66000309,
  0x15160421, 0x2b1001af, 0x401202a4, 0x04004008,
  0x1e1c0e13, 0x06001002, 0x25300eaf, 0x220d0f60,
  0x0d380813, 0x01001212, 0x1c1e25be, 0x171812ad,
  // [0990]
  0x030b0202, 0x23301e21, 0x38010507, 0x12401d14,
  0x0000381c, 0x03000621, 0x012b2708, 0x01291908,
  0x060d03be, 0x0d432909, 0x19000d07, 0x00002142,
  0x22060313, 0x18000f21, 0x1d001207, 0x38000802,
  // [09a0]
  0x121d4512, 0x1d124014, 0x17010d11, 0x0c1838a4,
  0x0c061007, 0x38021aa4, 0x08061d11, 0x10010f09,
  0x10432108, 0x40100b12, 0x0d380f07, 0x0d083808,
  0x1f002b12, 0x06002212, 0x2b220860, 0x40170d08,
  // [09b0]
  0x1d000207, 0x45120fa4, 0x10001d09, 0x30230e12,
  0x1c300e12, 0x080c0112, 0x45001602, 0x0d080112,
  0x041f0112, 0x290604af, 0x0d454021, 0x16150814,
  0x40180c09, 0x0c1040a4, 0x401d1922, 0x0d083802,
  // [09c0]
  0x45161d13, 0x40001d35, 0x23002507, 0x23251e11,
  0x01050c07, 0x2b002221, 0x18001602, 0x170d0f09,
  0x251c1e07, 0x19003f12, 0x1d0c166f, 0x2b004020,
  0x1f000313, 0x04100b20, 0x120c4520, 0x19043fac,
  // [09d0]
  0x451812ad, 0x0d0f0309, 0x30230e21, 0x15004013,
  0x03050f07, 0x04004012, 0x03001f12, 0x19144014,
  0x66031f12, 0x40001508, 0x1c251e60, 0x0b001907,
  0x12101955, 0x14000d09, 0x01051607, 0x05292760,
  // [09e0]
  0x01293f12, 0x0e002521, 0x0f040112, 0x08012707,
  0x03161f12, 0x0b031702, 0x17270809, 0x29001834,
  0x27002936, 0x03002707, 0x0b001911, 0x0d0f0555,
  0x15221609, 0x0f0d0512, 0x17000113, 0x010d0507,
  // [09f0]
  0x24020b5e, 0x301c0ead, 0x22001612, 0x22006621,
  0x38181712, 0x22000807, 0x03662213, 0x19002213,
  0x2b000622, 0x2b3805be, 0x14062711, 0x22002713,
  0x1d001620, 0x06001f11, 0x01000307, 0x0000042d,
  // [0a00]
  0x38290211, 0x04220122, 0x01000807, 0x016603bc,
  0x17060112, 0x030806ad, 0x04005113, 0x01000811,
  0x04001422, 0x04082221, 0x210f3821, 0x3f000121,
  0x272204bb, 0x00001d2d, 0x1d102712, 0x04192912,
  // [0a10]
  0x15001609, 0x10020112, 0x03000634, 0x0f430d07,
  0x12450c12, 0x08030421, 0x1e230e08, 0x27005113,
  0x011904af, 0x190104af, 0x1d003f12, 0x66151d08,
  0x1d001611, 0x0b0222ad, 0x12004002, 0x1c230eaf,
  // [0a20]
  0x0d000c07, 0x293f4060, 0x17014355, 0x01402220,
  0x12431d07, 0x30001e09, 0x10001907, 0x19002b07,
  0x45120c13, 0x0e1e2507, 0x012b1908, 0x0d660312,
  0x17000507, 0x01181508, 0x0b001014, 0x1c230e08,
  // [0a30]
  0x0e1c23a4, 0x38006608, 0x01041902, 0x14001f14,
  0x0e232502, 0x03000102, 0x1c002312, 0x0c001707,
  0x430d0109, 0x250e2307, 0x0e001e02, 0x0c124555,
  0x12010c09, 0x1e251cad, 0x170c4502, 0x0b0210a4,
  // [0a40]
  0x08161007, 0x032251af, 0x10002b21, 0x020b0309,
  0x19000b02, 0x03050daf, 0x180d0b12, 0x141821a4,
  0x03020509, 0x01222107, 0x01432707, 0x03120209,
  0x08036609, 0x02660322, 0x01171009, 0x030f3f11,
  // [0a50]
  0x0d001713, 0x30231e21, 0x06001507, 0x66000321,
  0x17080f09, 0x1e1c2502, 0x1d002221, 0x02220baf,
  0x062b2112, 0x100b0221, 0x19020655, 0x06103808,
  0x08000d09, 0x660651af, 0x17060baf, 0x04006612,
  // [0a60]
  0x660d0f20, 0x01001420, 0x06160d08, 0x12004522,
  0x06102155, 0x436605ad, 0x06020112, 0x0c000607,
  0x19100baf, 0x29100baf, 0x12150507, 0x08003822,
  0x1c252311, 0x011d1408, 0x1c0e2522, 0x03662122,
  // [0a70]
  0x060b51af, 0x1e0e2508, 0x1e0e1ca4, 0x2b002122,
  0x1e001c07, 0x0b140dbb, 0x2b020112, 0x0c1610a4,
  0x021451a4, 0x2b0d1faf, 0x5c000722, 0x2b000d14,
  0x120c0d14, 0x23300e07, 0x14180d12, 0x011d4011,
  // [0a80]
  0x45004008, 0x061912af, 0x062b0dad, 0x230e1ead,
  0x120d0609, 0x01060255, 0x06190d21, 0x0f000607,
  0x2b2166af, 0x17060d07, 0x06081aa4, 0x18140d12,
  0x0b021007, 0x0c002b13, 0x16180d12, 0x23001e08,
  // [0a90]
  0x231e2560, 0x1e000e07, 0x181d0d12, 0x0d180baf,
  0x03124507, 0x10001423, 0x400d12af, 0x1d4012af,
  0x10001f07, 0x40121dad, 0x06000d08, 0x1d0c1212,
  0x0c0612af, 0x170c1260, 0x27290b09, 0x01002107,
  // [0aa0]
  0x400f4509, 0x01150c08, 0x0c010508, 0x0c124509,
  0x21293f14, 0x16182709, 0x1d401613, 0x0b0c0f55,
  0x08292708, 0x160c4021, 0x04026607, 0x251c3021,
  0x03160808, 0x231c1ea4, 0x16184509, 0x0d080f02,
  // [0ab0]
  0x160c1509, 0x1e1c2560, 0x40003f11, 0x121d45af,
  0x0f222909, 0x3f211621, 0x16000413, 0x03180655,
  0x23251c11, 0x0f003f12, 0x04001923, 0x30001e12,
  0x0f036608, 0x011d2909, 0x211d1709, 0x17003f21,
  // [0ac0]
  0x0f080d08, 0x02140b02, 0x17000407, 0x01000c07,
  0x06171909, 0x1c000e14, 0x0000142d, 0x0d010c11,
  0x66000323, 0x01002b08, 0x0d0f0809, 0x190d17ac,
  0x180b4009, 0x10006607, 0x0e1c2507, 0x45121612,
  // [0ad0]
  0x1d174011, 0x19014007, 0x0c000620, 0x45000c20,
  0x04140fa4, 0x19004007, 0x0c124513, 0x01123f12,
  0x191002ac, 0x251c1ebe, 0x1e0e2507, 0x0c0d3808,
  0x18000220, 0x40001d22, 0x10660baf, 0x18124012,
  // [0ae0]
  0x14181011, 0x12004011, 0x10000609, 0x03170207,
  0x0c1840ad, 0x08061faf, 0x0d384012, 0x19011f12,
  0x1e251c12, 0x450c4008, 0x0f000407, 0x07005c09,
  0x27223f14, 0x01000421, 0x06001f12, 0x01080414,
  // [0af0]
  0x1e251c09, 0x401f0108, 0x301c0e08, 0x17060108,
  0x01043f20, 0x17001f21, 0x2b0501af, 0x0d0c0808,
  0x180129a4, 0x17000107, 0x01006613, 0x38140111,
  0x1e251c21, 0x011708a4, 0x020b0307, 0x02032b09,
  // [0b00]
  0x01190f09, 0x01033f11, 0x663f01af, 0x180108a4,
  0x0f196660, 0x01036611, 0x03000609, 0x0f003823,
  0x05102907, 0x030108a4, 0x300e1ebc, 0x03020607,
  0x02106609, 0x10171d09, 0x231c25af, 0x23000e21,
  // [0b10]
  0x17000807, 0x0d2901af, 0x06050407, 0x0c001007,
  0x0f003814, 0x030801ad, 0x380f0d14, 0x0d0f2122,
  0x2b080d08, 0x10020ba4, 0x0d2b0fbe, 0x12100207,
  0x29273faf, 0x21042908, 0x2b0f0d60, 0x22100807,
  // [0b20]
  0x0d2b0f14, 0x01292712, 0x17220807, 0x0f000d13,
  0x080d0f60, 0x221514be, 0x29001d08, 0x01000808,
  0x0f000307, 0x0e002335, 0x10000202, 0x0d000f22,
  0x1d154009, 0x450f0da4, 0x1f2b08af, 0x15452b12,
  // [0b30]
  0x290f0d09, 0x19101612, 0x0d0f0409, 0x0c004512,
  0x01001912, 0x22001812, 0x06221060, 0x160c1212,
  0x272922af, 0x0e251c6f, 0x29270121, 0x031d0207,
  0x0c000107, 0x04001213, 0x45001007, 0x23000e12,
  // [0b40]
  0x190b0213, 0x1c231e07, 0x19002209, 0x010b0208,
  0x04001023, 0x27192909, 0x0b061907, 0x25231caf,
  0x01080508, 0x04001902, 0x1c1e2560, 0x190b0212,
  0x1c1e2312, 0x0c004502, 0x16000412, 0x04001612,
  // [0b50]
  0x15001812, 0x160415be, 0x38222909, 0x15000422,
  0x01003f11, 0x040610a4, 0x66150cbe, 0x45001d02,
  0x06000411, 0x40001d07, 0x15000c22, 0x0c001514,
  0x14002b09, 0x15170c13, 0x042b01ac, 0x0b001f12,
  // [0b60]
  0x010f0d21, 0x15004513, 0x23000e23, 0x40013fa4,
  0x19000612, 0x04100612, 0x27291612, 0x29222113,
  0x14001008, 0x0e1c2508, 0x0c004511, 0x661427af,
  0x0f000508, 0x0f0d0507, 0x04001009, 0x01052909,
  // [0b70]
  0x01000411, 0x10040860, 0x120c45af, 0x04000609,
  0x050d2712, 0x06000409, 0x0c293f08, 0x1829216f,
  0x08012907, 0x0f001d08, 0x03000111, 0x38000412,
  0x04000102, 0x0000032d, 0x40003f20, 0x0f270109,
  // [0b80]
  0x0b140208, 0x010c1812, 0x0b0201af, 0x17050808,
  0x03100609, 0x06143fad, 0x19401d07, 0x381f0108,
  0x22003f13, 0x272916be, 0x0c224008, 0x0c030608,
  0x1f0506bb, 0x27402112, 0x1d400412, 0x06000322,
  // [0b90]
  0x2927226f, 0x06002211, 0x0f000612, 0x29660360,
  0x66060309, 0x29270112, 0x14272909, 0x0d002b08,
  0x01004002, 0x061003a4, 0x221d4008, 0x0f001f12,
  0x14000113, 0x0c006608, 0x18063fa4, 0x08020b13,
  // [0ba0]
  0x380f0dbe, 0x27293f08, 0x02100caf, 0x02101aa4,
  0x1d1640be, 0x1d001911, 0x01660612, 0x27013f12,
  0x03450112, 0x0b030412, 0x22000613, 0x01292709,
  0x0c222113, 0x27001412, 0x0d016607, 0x0c0108a4,
  // [0bb0]
  0x0d0f0307, 0x06004509, 0x0e002520, 0x23000e20,
  0x450114ad, 0x16032709, 0x38010f09, 0x10000412,
  0x251c0e11, 0x170d3812, 0x19003813, 0x17002107,
  0x17003821, 0x05003814, 0x05012121, 0x272921af,
  // [0bc0]
  0x10000409, 0x0c002112, 0x191004a4, 0x0d003820,
  0x16004014, 0x0600100c, 0x0d003811, 0x300e1e12,
  0x0d003814, 0x142b0808, 0x17380dbc, 0x0b060202,
  0x04221922, 0x04221921, 0x12001712, 0x04000113,
  // [0bd0]
  0x050d3820, 0x0d003821, 0x03170823, 0x172b38bc,
  0x2b013f07, 0x0e002509, 0x0d0f0c09, 0x19061007,
  0x1e251c07, 0x00005c0a, 0x04001908, 0x01170da4,
  0x01451209, 0x0b042212, 0x1d194014, 0x01040f07,
  // [0be0]
  0x0f083f12, 0x1d001212, 0x0d2729ad, 0x17000413,
  0x12173f12, 0x0d002120, 0x30000e11, 0x0c001211,
  0x25230e08, 0x06000111, 0x010f0d09, 0x0f2708ad,
  0x0f082112, 0x1c000e20, 0x171d4021, 0x060103ad,
  // [0bf0]
  0x1d171212, 0x04170809, 0x0c1d1212, 0x0c001202,
  0x17120808, 0x1c002313, 0x01124560, 0x0b101807,
  0x01031002, 0x04213821, 0x38163fa4, 0x22001723,
  0x10000611, 0x19100b55, 0x14002b14, 0x171801af,

  // [0c00]
  0x14060308, 0x0b001402, 0x0c002709, 0x231c0e08,
  0x120c4512, 0x401d21a4, 0x10010608, 0x1c000e23,
  0x2b004313, 0x1e002520, 0x4e003702, 0x25002312,
  0x0c001f12, 0x19031d02, 0x14170b09, 0x2b001009,
  // [0c10]
  0x05030d07, 0x08002208, 0x0d002707, 0x05031002,
  0x03062908, 0x12451dad, 0x04001013, 0x0c1640af,
  0x122b1008, 0x12451d14, 0x12062907, 0x15123f09,
  0x01001d08, 0x291014be, 0x1d062202, 0x06290109,
  // [0c20]
  0x0f053808, 0x14000d20, 0x0c004008, 0x06020b12,
  0x08292713, 0x14120d22, 0x011d03a4, 0x06002b02,
  0x01102712, 0x06000b07, 0x430d1fbe, 0x02061f12,
  0x16101f11, 0x66141f21, 0x05030112, 0x04380f08,
  // [0c30]
  0x03063f13, 0x0d1f4321, 0x08020b12, 0x12451f21,
  0x12000402, 0x1f001422, 0x66050121, 0x0b101607,
  0x10000612, 0x40001507, 0x0f171d08, 0x0c001608,
  0x12226611, 0x06030207, 0x0d001412, 0x0000382d,
  // [0c40]
  0x18000d13, 0x16170612, 0x03000214, 0x050118a4,
  0x22000112, 0x1c251ebe, 0x230e1c09, 0x0c001621,
  0x0c001622, 0x06386608, 0x10000b14, 0x18100222,
  0x2b000108, 0x0e1c1ea4, 0x10011408, 0x01006610,
  // [0c50]
  0x21000108, 0x060c0f11, 0x120666a4, 0x0c212712,
  0x0c000623, 0x21003f12, 0x05292711, 0x03060c07,
  0x0c150321, 0x230e2507, 0x141810af, 0x661003be,
  0x27290812, 0x38000302, 0x0c002109, 0x01000302,
  // [0c60]
  0x0c006612, 0x40001d11, 0x06081609, 0x010c2707,
  0x27002921, 0x0c000622, 0x1f036612, 0x100b08ac,
  0x02100b13, 0x29000112, 0x00001f0a, 0x29270421,
  0x18051fa4, 0x1d1240a4, 0x0000052d, 0x29042714,
  // [0c70]
  0x00002b2d, 0x43003821, 0x0f0d1212, 0x141f0d13,
  0x100302a4, 0x38003f12, 0x29271921, 0x05000d08,
  0x19002b20, 0x0d0f1f09, 0x450121a4, 0x14001f35,
  0x02401d12, 0x0f1f0d60, 0x45401d07, 0x12000b07,
  // [0c80]
  0x12184311, 0x1f123821, 0x0f122707, 0x06000220,
  0x03000613, 0x0429276f, 0x290427be, 0x10020bac,
  0x08001722, 0x0b006611, 0x38010302, 0x17000108,
  0x19401211, 0x1e1c2521, 0x0b000220, 0x05170807,
  // [0c90]
  0x19401212, 0x25001c21, 0x16270809, 0x40004502,
  0x01400da4, 0x0f100112, 0x1d272912, 0x16000414,
  0x100c04ad, 0x16000812, 0x38011211, 0x173801ad,
  0x0f0d0812, 0x40080f08, 0x0d080f6f, 0x0f0c0812,
  // [0ca0]
  0x400d0fa4, 0x012718ad, 0x40000c13, 0x060b01ac,
  0x07005c22, 0x16002112, 0x38182108, 0x010b2107,
  0x2b016609, 0x02000b11, 0x1c1e2507, 0x030610ad,
  0x4e003709, 0x151d40af, 0x14120c11, 0x06016608,
  // [0cb0]
  0x19000409, 0x14001d13, 0x25001c09, 0x0d0b0213,
  0x181201a4, 0x1e000e12, 0x12000c07, 0x25231e07,
  0x18380408, 0x0e251ead, 0x1c002311, 0x1c0e2512,
  0x030d0655, 0x1c0e1e08, 0x04161daf, 0x06001011,
  // [0cc0]
  0x06001402, 0x06042b12, 0x0f190302, 0x01162208,
  0x0c002b12, 0x0f001012, 0x22002707, 0x10002b12,
  0x020b01af, 0x45210b12, 0x21041921, 0x05012709,
  0x060d0b60, 0x05040107, 0x1f0d0112, 0x17050da4,
  // [0cd0]
  0x032901a4, 0x10020109, 0x050d0109, 0x0f0838ad,
  0x0000062d, 0x0f1d21ce, 0x0e1c2509, 0x29010309,
  0x0f001f1d, 0x1d160112, 0x080f3fac, 0x1c251e02,
  0x22272911, 0x050817a4, 0x0f0d1714, 0x1c002314,
  // [0ce0]
  0x193f1422, 0x0d0129ad, 0x05000314, 0x0c001920,
  0x0d030507, 0x031f05bc, 0x15161d09, 0x29001f21,
  0x272919af, 0x150c0112, 0x0b010307, 0x29221521,
  0x21292782, 0x45291509, 0x01292109, 0x291551af,
  // [0cf0]
  0x38051f12, 0x401d1508, 0x06030507, 0x150d27a4,
  0x03060507, 0x0c221913, 0x1d401f09, 0x1c251ea4,
  0x0d292714, 0x05001f34, 0x292705bc, 0x29151daf,
  0x05000112, 0x1d120212, 0x27032913, 0x1d451255,
  // [0d00]
  0x14150d23, 0x061529af, 0x0b000212, 0x221929a4,
  0x060c1612, 0x0c151607, 0x0c276612, 0x0c001609,
  0x1c0e23bb, 0x27661509, 0x0e231c09, 0x0d030612,
  0x0d0603a4, 0x17000f21, 0x1d000311, 0x0f000113,
  // [0d10]
  0x45000c22, 0x18000113, 0x01001f11, 0x06000309,
  0x06100b55, 0x03120d07, 0x01020b07, 0x01001f07,
  0x05010b07, 0x030b0207, 0x10020b02, 0x020b0c13,
  0x380306af, 0x160612a4, 0x01000308, 0x18060c21,
  // [0d20]
  0x1f050112, 0x06001812, 0x01190802, 0x05001f12,
  0x16040112, 0x0c000612, 0x012b0f55, 0x2b000308,
  0x011627a4, 0x451d1609, 0x251e3021, 0x14001f07,
  0x10020b23, 0x0f001f13, 0x01000802, 0x0d001f12,
  // [0d30]
  0x431f3f6f, 0x29013f09, 0x27011d08, 0x1f001d14,
  0x25001e14, 0x1d012108, 0x66272908, 0x191d40be,
  0x27001413, 0x01020b55, 0x0f084302, 0x1c002308,
  0x1d190f55, 0x08141008, 0x301c25af, 0x2b002912,
  // [0d40]
  0x382b1508, 0x10000802, 0x03196621, 0x45001413,
  0x030619af, 0x10000c13, 0x03661913, 0x19660309,
  0x08012bac, 0x08002b07, 0x181766af, 0x19002b09,
  0x251c1e14, 0x051901a4, 0x23302509, 0x38190d14,
  // [0d50]
  0x010b3fa4, 0x03210209, 0x19002907, 0x301c0e02,
  0x1d0c19a4, 0x01182ba4, 0x0d170509, 0x120d0109,
  0x451d4014, 0x06010fa4, 0x1f001013, 0x03041911,
  0x0d0f2912, 0x14001f12, 0x060366af, 0x05010802,
  // [0d60]
  0x020466a4, 0x03012109, 0x30001e13, 0x66002b22,
  0x23001c11, 0x19004507, 0x01052707, 0x38000f20,
  0x19000422, 0x19003f11, 0x17380112, 0x401d0fa4,
  0x050f0112, 0x1d124509, 0x03276608, 0x1d0d40a4,
  // [0d70]
  0x0c000108, 0x40124513, 0x1d014009, 0x05001f08,
  0x19003f20, 0x0f27296f, 0x451d4013, 0x451d4008,
  0x19040fa4, 0x036604ad, 0x08001207, 0x0d121d14,
  0x01004302, 0x100b0214, 0x05010f07, 0x08401da4,
  // [0d80]
  0x0e2330af, 0x27142914, 0x1c0e2312, 0x14001d07,
  0x12451d09, 0x16001011, 0x021d2207, 0x22002912,
  0x06001012, 0x01032107, 0x221d4007, 0x23251c55,
  0x66161908, 0x01173809, 0x1d270411, 0x160b1509,
  // [0d90]
  0x06000407, 0x0b001834, 0x18001411, 0x15001620,
  0x1d012912, 0x22002711, 0x00000b2d, 0x03061002,
  0x0b101912, 0x0c4501ad, 0x451d1213, 0x19006620,
  0x00000403, 0x06002b21, 0x19000421, 0x0b001411,
  // [0da0]
  0x03066614, 0x053801af, 0x0e231e07, 0x40292760,
  0x1f001414, 0x1d002107, 0x0e001e20, 0x19290409,
  0x0f031707, 0x1e251c60, 0x10061912, 0x1d084009,
  0x03002107, 0x45121da4, 0x08290608, 0x1e000e21,
  // [0db0]
  0x031906a4, 0x031021a4, 0x16272907, 0x19001008,
  0x19001011, 0x22272907, 0x0d060109, 0x12001512,
  0x012b0b07, 0x160d0809, 0x100b4009, 0x29192712,
  0x05100813, 0x06102707, 0x06160d55, 0x21272922,
  // [0dc0]
  0x16010807, 0x1d164008, 0x190610a4, 0x08161d14,
  0x0f0d0808, 0x16031907, 0x0f160808, 0x400f0812,
  0x1e253012, 0x100406ad, 0x020b10af, 0x0e251e09,
  0x12001f12, 0x1d151609, 0x0f084012, 0x17001f07,
  // [0dd0]
  0x16010809, 0x0f0d0809, 0x010f0da4, 0x21004022,
  0x18001d08, 0x1e002521, 0x25231c11, 0x3f660408,
  0x40451260, 0x180b0209, 0x40004522, 0x10190b07,
  0x0b001013, 0x04002107, 0x0c002707, 0x0e301cad,
  // [0de0]
  0x01080b12, 0x40161d09, 0x01030855, 0x15401d09,
  0x02661011, 0x1d0108a4, 0x66120b09, 0x2b010508,
  0x0b036613, 0x04010809, 0x40003f35, 0x140410af,
  0x45004014, 0x38000613, 0x066602af, 0x12004013,
  // [0df0]
  0x060d3813, 0x16193f13, 0x10081908, 0x17001d12,
  0x10020608, 0x45060f13, 0x12041909, 0x27060412,
  0x27153f60, 0x16001513, 0x02161521, 0x02000b23,
  0x08001f21, 0x3f001921, 0x45000611, 0x14001612,
  // [0e00]
  0x29271908, 0x01290512, 0x1d002109, 0x45000113,
  0x03001007, 0x0d0f17a4, 0x1d000f02, 0x18404512,
  0x18004514, 0x400106ad, 0x061d45af, 0x0c436607,
  0x144504bb, 0x23251ebe, 0x0b000612, 0x0f0d2709,
  // [0e10]
  0x29380112, 0x10384008, 0x251c0eac, 0x101d6608,
  0x231c1e21, 0x382927af, 0x0c010607, 0x16062b21,
  0x381901af, 0x05450109, 0x05000f07, 0x0c060baf,
  0x3f002b21, 0x1900060b, 0x231c2522, 0x0d0f38a4,
  // [0e20]
  0x221d4013, 0x40101d08, 0x012b1a12, 0x1d120b07,
  0x27290d09, 0x15213f60, 0x0c1d12ad, 0x21002b22,
  0x0000122d, 0x27293f21, 0x07005c20, 0x16211922,
  0x0c001911, 0x19002133, 0x140d21a4, 0x17002b12,
  // [0e30]
  0x100f0308, 0x0f150daf, 0x40121d13, 0x030f19a4,
  0x1c1e0e12, 0x01050da4, 0x1f000813, 0x160c0f13,
  0x054301ad, 0x19003f14, 0x050f1709, 0x190f2121,
  0x0f161921, 0x17162107, 0x66002b11, 0x10000b21,
  // [0e40]
  0x10020612, 0x14000b08, 0x080c0307, 0x38272914,
  0x380d0520, 0x0c2927af, 0x0b000302, 0x0c3f27af,
  0x251c1e13, 0x270c3faf, 0x270c2914, 0x19380307,
  0x02103807, 0x01153f09, 0x03020b13, 0x38292713,
  // [0e50]
  0x0f192112, 0x1e1c0ead, 0x06000c08, 0x27002923,
  0x402b2908, 0x0d0f0109, 0x06100212, 0x380f0d09,
  0x29000c13, 0x0b000c07, 0x02000b21, 0x21272921,
  0x080d01af, 0x29000c20, 0x1c0e2507, 0x1804226f,
  // [0e60]
  0x0c272920, 0x223829af, 0x0c1729a4, 0x29043f08,
  0x04190655, 0x0b190155, 0x18002b13, 0x19272911,
  0x66062109, 0x01270f09, 0x0f0d2b12, 0x1e1c2511,
  0x0b021009, 0x060b10a4, 0x2b006620, 0x03002207,
  // [0e70]
  0x22000c13, 0x03022213, 0x38192107, 0x210b29af,
  0x23003009, 0x381d05a4, 0x03162b55, 0x10000608,
  0x40001907, 0x0c380d08, 0x17060d13, 0x06000408,
  0x0d000f08, 0x400c2b07, 0x04001f12, 0x66002b12,
  // [0e80]
  0x1d1608a4, 0x0e231e13, 0x23000e08, 0x38272908,
  0x10380112, 0x0d0c0612, 0x0b0d1aa4, 0x1e003021,
  0x0c4512af, 0x0c401212, 0x0f1f1712, 0x12050113,
  0x0d0b0214, 0x121f0112, 0x05220812, 0x231c25be,
  // [0e90]
  0x0b002713, 0x450c12bb, 0x17001d14, 0x0d404512,
  0x401d3f09, 0x02036613, 0x450c12a4, 0x053801a4,
  0x29002b23, 0x100d0212, 0x0f040d09, 0x080f3814,
  0x190540a4, 0x0f081721, 0x01041f12, 0x40122212,
  // [0ea0]
  0x036606be, 0x0b050160, 0x16003808, 0x40451213,
  0x17004513, 0x12041721, 0x0c050112, 0x14002b12,
  0x0c081f6f, 0x01661508, 0x0f451712, 0x041917af,
  0x050317a4, 0x04000d02, 0x30251c13, 0x301c0e07,
  // [0eb0]
  0x40124508, 0x45401dad, 0x10001607, 0x270f1908,
  0x0f270d09, 0x1d000c07, 0x27050609, 0x120c1d60,
  0x150f3809, 0x0f062708, 0x293f2712, 0x1d000b09,
  0x1e1c0ebc, 0x38050f09, 0x27293f12, 0x0f2b3808,
  // [0ec0]
  0x0d0f0823, 0x10661daf, 0x14190433, 0x401d0812,
  0x19041012, 0x2b042112, 0x0d000512, 0x19220412,
  0x06382709, 0x08140b12, 0x04216609, 0x3f100b09,
  0x06052709, 0x0b275112, 0x0c190412, 0x45001d12,
  // [0ed0]
  0x451d0cad, 0x664301a4, 0x30001c11, 0x030605a4,
  0x210b01af, 0x10001812, 0x1f1929af, 0x10194002,
  0x101914be, 0x16004008, 0x0c0104af, 0x231c0eaf,
  0x03010507, 0x25000e13, 0x04061007, 0x05270b12,
  // [0ee0]
  0x301c23a4, 0x07005c23, 0x0c002b09, 0x38290108,
  0x14162208, 0x1c300e07, 0x08003f12, 0x1d1645bb,
  0x2b454009, 0x10001813, 0x150c04bb, 0x190f0809,
  0x0d020f12, 0x38001409, 0x0d036609, 0x2b001911,
  // [0ef0]
  0x16001d07, 0x10000408, 0x06002107, 0x1e252312,
  0x450d12af, 0x020b1908, 0x06040212, 0x661d3f12,
  0x03001809, 0x010b0309, 0x18000c21, 0x380f2b12,
  0x06120309, 0x010f08a4, 0x060b0302, 0x2b000f21,
  // [0f00]
  0x06100407, 0x66000d12, 0x430d0508, 0x1d012911,
  0x02031008, 0x10030b09, 0x05002b11, 0x0d0b0255,
  0x060305bc, 0x01402712, 0x1c232509, 0x2b103809,
  0x120c1d09, 0x052701af, 0x05001223, 0x010b0260,
  // [0f10]
  0x1d6640be, 0x17080102, 0x2b0f08af, 0x030417a4,
  0x2b660314, 0x0d0f0112, 0x01032907, 0x1d001509,
  0x40124514, 0x400f2b09, 0x020b0612, 0x10000209,
  0x0e1c23be, 0x15080521, 0x0d1d0112, 0x12164512,
  // [0f20]
  0x01003802, 0x0c000112, 0x08000421, 0x22181907,
  0x660b0409, 0x04190613, 0x080604a4, 0x0e1c2313,
  0x061951af, 0x1d001208, 0x0c190b13, 0x04292709,
  0x191d406f, 0x0b021013, 0x231c2514, 0x06000d02,
  // [0f30]
  0x23002514, 0x04010bac, 0x12454013, 0x08010309,
  0x251c0e13, 0x01040512, 0x051f0460, 0x0b061013,
  0x05000413, 0x05101407, 0x15002221, 0x05000412,
  0x060b6612, 0x06151914, 0x19010612, 0x3f000414,
  // [0f40]
  0x27061912, 0x01170bbc, 0x0c380507, 0x16401d07,
  0x1c0e1e02, 0x0b000633, 0x15061412, 0x231c1ead,
  0x38050412, 0x0b001407, 0x0b060209, 0x10020b14,
  0x012914bc, 0x16061007, 0x03000b07, 0x04051908,
  // [0f50]
  0x231c0e09, 0x45003f11, 0x2b001920, 0x1c002323,
  0x0d0f3820, 0x1c1e2513, 0x251e1ca4, 0x04001807,
  0x010622ac, 0x25002308, 0x221d4512, 0x013f1f60,
  0x0c224012, 0x221d40af, 0x27660312, 0x2b026612,
  // [0f60]
  0x2b404511, 0x432b0109, 0x3f1617bc, 0x230e1ea4,
  0x251c0ead, 0x010d1f12, 0x1d001f07, 0x04004507,
  0x06190407, 0x18000308, 0x401d4513, 0x40180360,
  0x17004507, 0x00000715, 0x100b5107, 0x1d001720,
  // [0f70]
  0x18001013, 0x1d044012, 0x18001011, 0x10401d22,
  0x0c001d07, 0x19000435, 0x0d003823, 0x0d180808,
  0x43002913, 0x27121d09, 0x1f061020, 0x3f000613,
  0x6606036f, 0x292703af, 0x40000307, 0x02100614,
  // [0f80]
  0x66000222, 0x010f0821, 0x0e001e09, 0x2b0c01a4,
  0x0d001707, 0x0e2523af, 0x041245a4, 0x0b020107,
  0x180d1521, 0x08000307, 0x020629af, 0x0f660309,
  0x02100b09, 0x25000e07, 0x04002b08, 0x01040302,
  // [0f90]
  0x0b001602, 0x06051709, 0x1e001c12, 0x02001607,
  0x16000b13, 0x04001713, 0x05120f07, 0x0b051209,
  0x660b0209, 0x22001821, 0x231e25a4, 0x0b022ba4,
  0x2b0b0220, 0x06011707, 0x04060802, 0x251c0e07,
  // [0fa0]
  0x183f0112, 0x19041755, 0x01041712, 0x400c1609,
  0x16041521, 0x05384055, 0x0b011907, 0x124504af,
  0x10190f09, 0x0f0d45af, 0x19120b09, 0x15401daf,
  0x0f000d22, 0x150866ad, 0x0c401dad, 0x0c064509,
  // [0fb0]
  0x05170f08, 0x14021809, 0x3000371d, 0x10002213,
  0x1c1e0ea4, 0x190d1d08, 0x450b12a4, 0x162166a4,
  0x0d003802, 0x16004022, 0x1d194009, 0x10000f13,
  0x0f000812, 0x01191d12, 0x0f0d0814, 0x0000402d,
  // [0fc0]
  0x150c1d09, 0x02001411, 0x45120c23, 0x251c0ea4,
  0x01001708, 0x2b0d0112, 0x27052109, 0x0e231c13,
  0x0d000b07, 0x14061011, 0x0d000f23, 0x01012707,
  0x30251ca4, 0x0110026f, 0x30001e08, 0x051d0607,
  // [0fd0]
  0x1e230e12, 0x05012907, 0x1400101f, 0x02182111,
  0x0d030207, 0x03403807, 0x1966036f, 0x14005108,
  0x0b012912, 0x30002334, 0x0c000d02, 0x100801af,
  0x230e3007, 0x030d0521, 0x190d51af, 0x66030baf,
  // [0fe0]
  0x4e003735, 0x03001507, 0x1e002522, 0x22292714,
  0x12000802, 0x22002111, 0x18001911, 0x66031913,
  0x1d0427af, 0x16004511, 0x01190808, 0x1d001807,
  0x0e1c25af, 0x041901af, 0x03061560, 0x040b0209,
  // [0ff0]
  0x01272912, 0x10140baf, 0x04001912, 0x066614ad,
  0x1d120107, 0x0c060160, 0x042927af, 0x0f060509,
  0x45124009, 0x12010607, 0x400c1209, 0x1d004514,
  0x401d1212, 0x06046607, 0x40003f12, 0x45124021,

  // [1000]
  0x10062709, 0x1c002512, 0x1e1c3012, 0x301e0e08,
  0x1d1901ac, 0x04020302, 0x1c1e0e02, 0x121d0c09,
  0x0d0f1807, 0x29000120, 0x450c1213, 0x1e001c11,
  0x060c6655, 0x1f6603af, 0x0d171921, 0x380d0f14,
  // [1010]
  0x270c6660, 0x06276608, 0x030621a4, 0x06001907,
  0x050801a4, 0x020c4007, 0x45154007, 0x15001213,
  0x020b6608, 0x401d1613, 0x1c250e12, 0x0b035112,
  0x06010ba4, 0x18000c13, 0x03061d14, 0x01001002,
  // [1020]
  0x0b660212, 0x0b1d08a4, 0x04380855, 0x0b026609,
  0x660b02be, 0x0f013807, 0x45120c12, 0x0f050807,
  0x0f380d23, 0x172b0111, 0x0d0c0f09, 0x0b1002a4,
  0x06000313, 0x10000208, 0x27000c12, 0x03006635,
  // [1030]
  0x060f6621, 0x66000308, 0x0c0f386f, 0x060301ad,
  0x02001008, 0x12004007, 0x01000207, 0x18003f14,
  0x19036611, 0x2b000412, 0x10013f12, 0x01000612,
  0x40271d21, 0x19660612, 0x1d222707, 0x040b1007,
  // [1040]
  0x3f002114, 0x0c002713, 0x190451af, 0x17190d13,
  0x27062109, 0x19001408, 0x041019a4, 0x04120209,
  0x10000522, 0x180f0811, 0x22052b12, 0x05173834,
  0x40004514, 0x01050ba4, 0x04000807, 0x0000082d,
  // [1050]
  0x06220411, 0x22001009, 0x1d001712, 0x38122912,
  0x19662714, 0x1d214009, 0x0f0b4002, 0x0c103f11,
  0x12401d08, 0x0f000808, 0x10020b11, 0x380b0112,
  0x14001f20, 0x21002214, 0x053f0860, 0x081915a4,
  // [1060]
  0x08173f11, 0x0d002107, 0x0f0d4307, 0x05271460,
  0x08036608, 0x220b2b09, 0x27291daf, 0x0b155107,
  0x380f19bb, 0x06401d07, 0x0e301ea4, 0x40451214,
  0x1d0d0f07, 0x1c0e1eac, 0x0d010fa4, 0x22002134,
  // [1070]
  0x080f0d14, 0x140f1fa4, 0x17012155, 0x170f0d09,
  0x17182109, 0x38013f12, 0x10010607, 0x18001f13,
  0x0f004507, 0x1f001813, 0x1c001e13, 0x01002207,
  0x27000513, 0x0f1f3814, 0x030601ad, 0x400c1d21,
  // [1080]
  0x0138066f, 0x0c001011, 0x12451d55, 0x12451f23,
  0x1f001812, 0x010c0f11, 0x03053855, 0x0e001c21,
  0x0f000d12, 0x18124560, 0x10020314, 0x0f1406bc,
  0x01041707, 0x14192113, 0x18124512, 0x45001222,
  // [1090]
  0x08000507, 0x0c101612, 0x18124513, 0x05030607,
  0x03080507, 0x0d0f08af, 0x03000513, 0x02061d21,
  0x05000107, 0x0e002320, 0x01053809, 0x38001713,
  0x38000508, 0x04080c21, 0x1200180b, 0x15001613,
  // [10a0]
  0x220419af, 0x03000508, 0x04161913, 0x1e1c25bb,
  0x05004007, 0x19272909, 0x220d08a4, 0x14001809,
  0x120c1d12, 0x12451d07, 0x16180fa4, 0x04064007,
  0x0d160fad, 0x06452b12, 0x0e232509, 0x38050307,
  // [10b0]
  0x231e0e60, 0x45002b14, 0x030c0bac, 0x2b4506be,
  0x0d0f1912, 0x19001021, 0x45431702, 0x141d45af,
  0x06100307, 0x19001013, 0x18001412, 0x16000d22,
  0x06000b12, 0x05000608, 0x660f0808, 0x12001817,
  // [10c0]
  0x66060bbe, 0x2b004513, 0x22003f20, 0x1f004513,
  0x0b000211, 0x380501af, 0x01173807, 0x0d191013,
  0x10001912, 0x12001807, 0x00003f2d, 0x14050baf,
  0x06000b22, 0x01000b21, 0x06000312, 0x12403f21,
  // [10d0]
  0x66032712, 0x0c124012, 0x1d003f21, 0x08002709,
  0x40191d11, 0x2b001822, 0x2b660320, 0x020b0855,
  0x04000511, 0x12000d20, 0x01036607, 0x0c150255,
  0x0f0d18af, 0x19040808, 0x15292760, 0x16272921,
  // [10e0]
  0x0c042112, 0x14000d08, 0x140b06a4, 0x0b180613,
  0x1c1e0e21, 0x153f1409, 0x040b06a4, 0x06226621,
  0x1d043f11, 0x0000662d, 0x276617bc, 0x06020baf,
  0x02186613, 0x02100b02, 0x16063f08, 0x380f0309,
  // [10f0]
  0x19000411, 0x10010308, 0x12020107, 0x19100409,
  0x4e003734, 0x12001d08, 0x250e1ca4, 0x04000313,
  0x04032707, 0x01050307, 0x060b0809, 0x19380509,
  0x19210312, 0x0000180a, 0x27190412, 0x04001d12,
  // [1100]
  0x38010fa4, 0x01001011, 0x04192107, 0x04660311,
  0x04036614, 0x046619af, 0x401d1708, 0x10024509,
  0x17002b09, 0x22454008, 0x0b001213, 0x12194513,
  0x3f161513, 0x032b6621, 0x0d180507, 0x660310be,
  // [1110]
  0x021001af, 0x231c30ad, 0x00000c2d, 0x0d0f05ac,
  0x380f0d23, 0x05001911, 0x291227af, 0x0d380f13,
  0x380f0d60, 0x293f27be, 0x050145af, 0x300e2507,
  0x291d2213, 0x0f182109, 0x08272108, 0x053827a4,
  // [1120]
  0x14002112, 0x292701af, 0x1c232508, 0x05001407,
  0x08161d12, 0x12082ba4, 0x1d0f0d6f, 0x050f0d12,
  0x0f002112, 0x45050dad, 0x01180307, 0x210f0d22,
  0x04001911, 0x29083f14, 0x161510be, 0x0f0d2214,
  // [1130]
  0x050801af, 0x0f051d07, 0x45120f07, 0x30002521,
  0x1e231c08, 0x0e1e2307, 0x45180d13, 0x0e1e2512,
  0x1e002308, 0x010b2707, 0x0f080108, 0x21452708,
  0x01002908, 0x10192113, 0x21003f20, 0x17001002,
  // [1140]
  0x01002711, 0x21001512, 0x16002b21, 0x0d000f11,
  0x16002b20, 0x271f4521, 0x45002b12, 0x0c003f12,
  0x2b162912, 0x18000c12, 0x05000623, 0x1d1245af,
  0x3f002122, 0x25231c12, 0x190d01af, 0x0b100112,
  // [1150]
  0x2b006609, 0x08000f14, 0x660306af, 0x0f662709,
  0x16002108, 0x66100b08, 0x29271faf, 0x27290112,
  0x15002b07, 0x250e1c08, 0x121d406f, 0x1d401212,
  0x0b080209, 0x0c1f0109, 0x10036607, 0x160f0855,
  // [1160]
  0x220d0fa4, 0x10000311, 0x210b0209, 0x2b660308,
  0x06010412, 0x12000607, 0x06000f12, 0x0f002108,
  0x1c001e11, 0x04292711, 0x22192109, 0x21060112,
  0x15000f12, 0x0f002107, 0x27000f13, 0x0f1d3f60,
  // [1170]
  0x190210af, 0x0b030207, 0x0f010d12, 0x02030409,
  0x010d0fbc, 0x0f150607, 0x08050f08, 0x040b0208,
  0x17210808, 0x271d4021, 0x022101bc, 0x12000308,
  0x0b1002be, 0x05001208, 0x0d0801a4, 0x40292711,
  // [1180]
  0x0d2b08a4, 0x40001d20, 0x031d4007, 0x01270555,
  0x05660312, 0x14160b12, 0x02001d07, 0x2b100b12,
  0x05001221, 0x080d0f14, 0x05004013, 0x120506ad,
  0x27001d13, 0x012b1fa4, 0x1d0d4012, 0x06004007,
  // [1190]
  0x29274009, 0x18000621, 0x02380509, 0x21292714,
  0x050f1508, 0x27040612, 0x15001911, 0x10080507,
  0x06102107, 0x251c2314, 0x0b010209, 0x18000c08,
  0x38002108, 0x03000412, 0x06041414, 0x18170609,
  // [11a0]
  0x3f210112, 0x04000309, 0x01050609, 0x400b0209,
  0x21196609, 0x021805ad, 0x1d053fad, 0x030b0212,
  0x12450255, 0x03066613, 0x060b5112, 0x16192712,
  0x21401d13, 0x06001707, 0x010210af, 0x17052207,
  // [11b0]
  0x03046612, 0x19660314, 0x0b142b12, 0x19080112,
  0x07005c21, 0x10021907, 0x14000112, 0x402205a4,
  0x292721a4, 0x060b6608, 0x0f001811, 0x051703af,
  0x19160455, 0x04196621, 0x170201ad, 0x66291f12,
  // [11c0]
  0x02001907, 0x27152909, 0x17034507, 0x22000212,
  0x27212913, 0x21000421, 0x10080107, 0x1c250e08,
  0x19036613, 0x0c031755, 0x191d0b08, 0x011d0d07,
  0x19041009, 0x0c000812, 0x290b0421, 0x0f036607,
  // [11d0]
  0x04151912, 0x19221407, 0x0c121812, 0x0f050109,
  0x22272908, 0x184551af, 0x17080f12, 0x451d4021,
  0x02123809, 0x45100608, 0x1c1e2555, 0x0e1c1e09,
  0x160d0f55, 0x16181721, 0x0f0d3fad, 0x40180109,
  // [11e0]
  0x27081212, 0x27292b12, 0x3f001421, 0x03064511,
  0x013f06af, 0x03660207, 0x0e231e21, 0x0b012bad,
  0x21050112, 0x660305bc, 0x0e251c02, 0x050d01af,
  0x23001c13, 0x0d0f1709, 0x383f0809, 0x141651a4,
  // [11f0]
  0x17002211, 0x15002b13, 0x030604ad, 0x170d0f12,
  0x06141908, 0x0d000507, 0x04220b07, 0x1e1c0e07,
  0x3f100b6f, 0x01270baf, 0x18450f08, 0x17003813,
  0x02062baf, 0x1e0e2308, 0x050127a4, 0x05000814,
  // [1200]
  0x01291f12, 0x661801af, 0x01001f20, 0x06036612,
  0x03001613, 0x06001f07, 0x380604a4, 0x03002108,
  0x18012109, 0x40661712, 0x06006611, 0x04381712,
  0x01210320, 0x17003807, 0x06660112, 0x192b0112,
  // [1210]
  0x22003812, 0x1d003808, 0x18001920, 0x231c0e07,
  0x062b0109, 0x08010307, 0x2b003813, 0x061f0112,
  0x03010613, 0x43050107, 0x380f27af, 0x14065112,
  0x22001811, 0x19001811, 0x0e1c1e60, 0x191f0112,
  // [1220]
  0x29012108, 0x06401d02, 0x380f0507, 0x1d041207,
  0x30230e07, 0x1c251e12, 0x0d001f1f, 0x03011512,
  0x0c1d4012, 0x0b000407, 0x40004507, 0x30000e20,
  0x05001f10, 0x0f0d1208, 0x0f0d1f09, 0x10181dbc,
  // [1230]
  0x0f001f11, 0x2b010d12, 0x08004007, 0x01001007,
  0x170215a4, 0x45001d08, 0x03001d07, 0x06150112,
  0x1c1e2502, 0x0c010807, 0x1d000808, 0x22021413,
  0x12000502, 0x02220b13, 0x1c230e14, 0x080b0112,
  // [1240]
  0x250e1e13, 0x66060409, 0x032b27a4, 0x020b0421,
  0x03000208, 0x45150221, 0x0c002b14, 0x45382712,
  0x10060f02, 0x180c22ad, 0x45012ba4, 0x662b2212,
  0x010f0d08, 0x66031921, 0x27292208, 0x0b000602,
  // [1250]
  0x0b0601af, 0x16041909, 0x23250ebc, 0x1d004011,
  0x301c0e12, 0x06001912, 0x0c000408, 0x23251ead,
  0x14000420, 0x1c1e25af, 0x05380107, 0x21270112,
  0x380401af, 0x0f290112, 0x16061409, 0x0f380d02,
  // [1260]
  0x1d001211, 0x45122212, 0x0b005108, 0x40290d08,
  0x380d0814, 0x0c001614, 0x05020308, 0x29020621,
  0x012b1907, 0x29000113, 0x1d400221, 0x23003021,
  0x29000c12, 0x170f0d13, 0x19660311, 0x22100b08,
  // [1270]
  0x0f001807, 0x140419bc, 0x06170809, 0x401d1607,
  0x06051412, 0x1d2719ad, 0x01000508, 0x031d4034,
  0x272b2911, 0x01052212, 0x15000c21, 0x17030111,
  0x16216609, 0x03450f07, 0x15001607, 0x17451da4,
  // [1280]
  0x14195112, 0x06003812, 0x060f0855, 0x0d0f1612,
  0x22081821, 0x0d100f08, 0x16401d09, 0x38000620,
  0x060c1211, 0x380f0da4, 0x04020ba4, 0x18000c22,
  0x01124508, 0x03020b14, 0x0b021914, 0x25230e55,
  // [1290]
  0x160d0f20, 0x30250e12, 0x083801af, 0x0b000112,
  0x0d000307, 0x19080107, 0x190414ad, 0x40190412,
  0x06196611, 0x1d0604a4, 0x23300e09, 0x45290612,
  0x0c060407, 0x301c2309, 0x190b1055, 0x064001ad,
  // [12a0]
  0x190601a4, 0x17000d08, 0x12000507, 0x01166607,
  0x0f000209, 0x231e0ea4, 0x0c001809, 0x1c250e55,
  0x19001d02, 0x06000107, 0x01050d07, 0x250e1c14,
  0x45051402, 0x0e001e21, 0x020b0509, 0x16450312,
  // [12b0]
  0x1e1c2314, 0x01001607, 0x03661911, 0x2b2101ad,
  0x030419ad, 0x04190314, 0x03662708, 0x06020ba4,
  0x04000608, 0x251e1c07, 0x220403a4, 0x66030208,
  0x01036660, 0x18002709, 0x04006608, 0x12401d07,
  // [12c0]
  0x19010607, 0x25300e07, 0x0e231e02, 0x022103a4,
  0x45121dac, 0x27660321, 0x10450c21, 0x380f0d08,
  0x05010655, 0x38010812, 0x06002907, 0x190301af,
  0x2b000c12, 0x5c000723, 0x010d3809, 0x080d0512,
  // [12d0]
  0x010f1612, 0x160d0f13, 0x38180813, 0x0f080d07,
  0x0d0801af, 0x1e251c23, 0x14000d12, 0x03000d12,
  0x010d0f21, 0x14000f10, 0x140d0f08, 0x05031907,
  0x0c000609, 0x0c0d0f60, 0x10060107, 0x43004513,
  // [12e0]
  0x16053faf, 0x45141221, 0x0d0f3807, 0x19431a12,
  0x01081da4, 0x101406a4, 0x15165112, 0x29062112,
  0x080f0112, 0x04190612, 0x430527a4, 0x0d100b08,
  0x1f0f0d14, 0x0f060807, 0x01000511, 0x17001f12,
  // [12f0]
  0x01163812, 0x16000b14, 0x102721af, 0x38140f11,
  0x14000f20, 0x020b1012, 0x15100212, 0x08380507,
  0x2b001d02, 0x04660308, 0x191651af, 0x180b1012,
  0x1d002712, 0x08006607, 0x06010507, 0x180604a4,
  // [1300]
  0x04222108, 0x182922bc, 0x08000622, 0x18140b09,
  0x031f0112, 0x04191d07, 0x0b021408, 0x02051aaf,
  0x15000c12, 0x14000f12, 0x04001622, 0x14000f13,
  0x14000f08, 0x23001c07, 0x02100ba4, 0x1e0e2302,
  // [1310]
  0x0b001007, 0x010429a4, 0x1d004021, 0x25001e02,
  0x25000e14, 0x04271608, 0x04061612, 0x17002b08,
  0x19290d08, 0x06030b09, 0x01400307, 0x0e001e22,
  0x06153812, 0x15160612, 0x05272913, 0x10033fad,
  // [1320]
  0x21292760, 0x0e001e12, 0x15061621, 0x2b174312,
  0x21292713, 0x05061512, 0x0e1e2508, 0x0c0b0212,
  0x19080407, 0x18001208, 0x040122a4, 0x01003807,
  0x05001212, 0x21002212, 0x01002912, 0x01020b09,
  // [1330]
  0x43000102, 0x22182112, 0x29213f12, 0x121d4007,
  0x45001614, 0x1e1c0e11, 0x223f2712, 0x053f1f13,
  0x021245a4, 0x0c150612, 0x662b0813, 0x0b190307,
  0x27290412, 0x03182155, 0x01121907, 0x0b000107,
  // [1340]
  0x23251c13, 0x04006613, 0x22401d55, 0x010b0307,
  0x010305ad, 0x043f1960, 0x01030507, 0x170801be,
  0x230e1c02, 0x1f2701af, 0x17002713, 0x05011007,
  0x17293f09, 0x01291009, 0x0e251ebb, 0x1d292722,
  // [1350]
  0x38141060, 0x2b020b12, 0x0f060307, 0x1d0f0d08,
  0x0b022107, 0x011f3faf, 0x010f0d02, 0x012221a4,
  0x0f000d02, 0x210103af, 0x19001608, 0x05015112,
  0x02002b11, 0x08000511, 0x03660621, 0x06006613,
  // [1360]
  0x45210112, 0x1d0c4021, 0x27002112, 0x12042712,
  0x0c0d2707, 0x04191509, 0x01272960, 0x0e231c02,
  0x10000211, 0x250e1c20, 0x100b27af, 0x272229a4,
  0x66060b08, 0x2b000614, 0x04151609, 0x0b1006a4,
  // [1370]
  0x22002b12, 0x27190413, 0x292721bc, 0x27295112,
  0x02001013, 0x1e251cbe, 0x23250e13, 0x1e230e02,
  0x45140f09, 0x1c1e0ebe, 0x231c0e12, 0x02060507,
  0x1e250ea4, 0x29222709, 0x251e3013, 0x22272112,
  // [1380]
  0x17054512, 0x0f272108, 0x050c3802, 0x19043f60,
  0x05001907, 0x04003f14, 0x17000813, 0x1d020b22,
  0x012b0813, 0x08191411, 0x173801a4, 0x38050f02,
  0x08002122, 0x29142712, 0x19220407, 0x1d001412,
  // [1390]
  0x0f4008af, 0x400c0860, 0x050f3855, 0x0f0108ac,
  0x21002222, 0x22002120, 0x04190b13, 0x0d001f13,
  0x270b0212, 0x0d400809, 0x0b022baf, 0x17401609,
  0x080f0d13, 0x2b001f21, 0x1c250e21, 0x0f222112,
  // [13a0]
  0x1d4008be, 0x08272bad, 0x0e251ca4, 0x38000d14,
  0x1d083f21, 0x12001d22, 0x401d0809, 0x06021412,
  0x00000d2d, 0x0d2b0fbb, 0x050608a4, 0x0c082108,
  0x18000613, 0x1f000114, 0x04101407, 0x19010b12,
  // [13b0]
  0x06002108, 0x30231ebe, 0x01060b13, 0x380f0809,
  0x0b190213, 0x45400d11, 0x050301af, 0x0b050112,
  0x04272912, 0x23300e23, 0x08000d07, 0x100b01af,
  0x10140113, 0x30002513, 0x050138a4, 0x06150413,
  // [13c0]
  0x14292708, 0x174505ad, 0x08000f09, 0x29270413,
  0x0f011002, 0x1c253055, 0x1e231c14, 0x22040ba4,
  0x22290409, 0x14001908, 0x0e1c2523, 0x01001707,
  0x2b660108, 0x050f01a4, 0x0d000509, 0x06000422,
  // [13d0]
  0x04001621, 0x04001823, 0x04062bad, 0x251e0e12,
  0x27296609, 0x2b001f13, 0x0f043809, 0x0c001d08,
  0x01000c09, 0x0c001808, 0x1c300e09, 0x0d380512,
  0x273f29af, 0x1916046f, 0x06660308, 0x04062107,
  // [13e0]
  0x1f100b14, 0x251c1e22, 0x06021012, 0x036621ad,
  0x12000c12, 0x0b021008, 0x01001712, 0x02100bad,
  0x06001708, 0x19060308, 0x06001d22, 0x450629af,
  0x19021721, 0x16001512, 0x230e1e55, 0x06004514,
  // [13f0]
  0x22000802, 0x19140112, 0x12001d20, 0x06001421,
  0x06010808, 0x29001612, 0x0d060355, 0x04660314,
  0x17000d12, 0x45000612, 0x04081fbc, 0x17001f20,
  0x380f0807, 0x45000620, 0x66140baf, 0x38000d22,

  // [1400]
  0x0c030112, 0x1d004512, 0x04001f07, 0x1e2530be,
  0x04001611, 0x04001608, 0x0e001c08, 0x160c0412,
  0x01081707, 0x0f011712, 0x19000f07, 0x010b0214,
  0x03060102, 0x08430107, 0x1e1c23bc, 0x250e1e08,
  // [1410]
  0x1c0e2514, 0x38001712, 0x101d1611, 0x02010507,
  0x04182b08, 0x0e231c08, 0x14004508, 0x010c0607,
  0x19060107, 0x17000120, 0x01000f11, 0x0f0d1712,
  0x01100312, 0x10010b08, 0x05001721, 0x380d0f21,
  // [1420]
  0x17051f07, 0x432b0508, 0x0f0105a4, 0x19001707,
  0x03002b02, 0x270c12af, 0x01050407, 0x08001620,
  0x08150508, 0x17004007, 0x30230eaf, 0x01191712,
  0x19100613, 0x08005113, 0x171f01af, 0x1f170111,
  // [1430]
  0x030b6608, 0x1f190460, 0x22001713, 0x060501a4,
  0x40001912, 0x16000c12, 0x400d19ad, 0x19004021,
  0x19004012, 0x0d0538bc, 0x1d404514, 0x15001612,
  0x0e301e13, 0x38004021, 0x3f401921, 0x16080f13,
  // [1440]
  0x05010608, 0x193840af, 0x40001933, 0x04190312,
  0x3f191413, 0x18000420, 0x2b000b13, 0x051806bc,
  0x1d080408, 0x0f100307, 0x06012b11, 0x01060309,
  0x0b064512, 0x01050813, 0x08010509, 0x056606ad,
  // [1450]
  0x21000409, 0x08060b09, 0x05380da4, 0x17021412,
  0x0f0d2908, 0x06001233, 0x04020f13, 0x020b40ac,
  0x140b0212, 0x01380808, 0x04196614, 0x19040308,
  0x05016609, 0x27000620, 0x06050812, 0x04191707,
  // [1460]
  0x45040308, 0x0d050607, 0x04011407, 0x15004002,
  0x0e1c2311, 0x19100b08, 0x030666af, 0x03146609,
  0x21100112, 0x07005c10, 0x16004013, 0x0b100211,
  0x08001607, 0x38050f08, 0x454016af, 0x16004020,
  // [1470]
  0x050108ac, 0x04001407, 0x27002908, 0x06190d08,
  0x1d0427ac, 0x02100608, 0x0f001f08, 0x16154009,
  0x1d1521a4, 0x1d193f08, 0x40001602, 0x40450ba4,
  0x1d0c66a4, 0x45121d12, 0x10162912, 0x14002708,
  // [1480]
  0x0b0c6612, 0x02291da4, 0x04292755, 0x161d4055,
  0x40191d12, 0x30000e21, 0x02002b07, 0x40152712,
  0x0c161d14, 0x0e1e23ac, 0x3f004513, 0x1c0e2560,
  0x04060202, 0x0000232d, 0x45041da4, 0x25231c08,
  // [1490]
  0x060229a4, 0x23001e22, 0x3f1f1aa4, 0x0d380f12,
  0x38000d02, 0x06142ba4, 0x01272911, 0x0b0210ac,
  0x40006608, 0x0e302512, 0x19062707, 0x660d01a4,
  0x22003807, 0x0d061607, 0x251e1cac, 0x22000408,
  // [14a0]
  0x06002709, 0x03100b20, 0x10170809, 0x16020b08,
  0x0f010507, 0x160315af, 0x3f171821, 0x020b10a4,
  0x160d0f08, 0x0d170f09, 0x19032707, 0x45001813,
  0x05180112, 0x010d0308, 0x3f6605af, 0x05001007,
  // [14b0]
  0x220b0209, 0x0d003813, 0x0201086f, 0x1d454008,
  0x1e002307, 0x1d002708, 0x151d4021, 0x0d050f22,
  0x1d221007, 0x38170822, 0x0c001d11, 0x12451811,
  0x0d002210, 0x05001f13, 0x1c1e3021, 0x18004023,
  // [14c0]
  0x12004521, 0x1d001209, 0x19006611, 0x06180baf,
  0x080f3812, 0x01272913, 0x23001e21, 0x38004008,
  0x19002709, 0x0c180112, 0x0d053808, 0x1d1245a4,
  0x06150c55, 0x1c0e1e12, 0x0c003f13, 0x1e000e13,
  // [14d0]
  0x080c0513, 0x29273f12, 0x170d01af, 0x66000f12,
  0x14005112, 0x40004513, 0x18050c13, 0x4e003708,
  0x0c001d12, 0x03142221, 0x03000122, 0x230e1c07,
  0x0f0d0823, 0x05380f09, 0x1d0c0f12, 0x1d000c13,
  // [14e0]
  0x0c001813, 0x432901af, 0x1d000c12, 0x190b0208,
  0x06002114, 0x22061908, 0x06002713, 0x06003f14,
  0x194027a4, 0x1e250e14, 0x0e302334, 0x3f2927be,
  0x04193fac, 0x291d2709, 0x3f002713, 0x66011a12,
  // [14f0]
  0x271d3f12, 0x3f2927af, 0x18006614, 0x15002111,
  0x14001f21, 0x27001013, 0x01030208, 0x04401d07,
  0x12380f07, 0x18003f13, 0x01000f02, 0x08013fac,
  0x0b013fbb, 0x190c1d07, 0x3f04196f, 0x01000514,
  // [1500]
  0x03001908, 0x23001c08, 0x40141da4, 0x1d0d0508,
  0x0c001814, 0x38004513, 0x40272908, 0x451d12ac,
  0x020b0809, 0x401d0409, 0x1e1c0e08, 0x251c1e02,
  0x190366be, 0x1d000820, 0x036619ad, 0x1c2325af,
  // [1510]
  0x38050d08, 0x19001020, 0x04100b09, 0x0d380f23,
  0x12005113, 0x0e1c2322, 0x66013faf, 0x066603af,
  0x1c0e2321, 0x22191460, 0x21142712, 0x0e1c1eaf,
  0x0c010308, 0x17053808, 0x251c0e20, 0x27000c13,
  // [1520]
  0x296603af, 0x01081955, 0x3f006621, 0x0c010509,
  0x0c003f09, 0x151d40ad, 0x12050cac, 0x0e251caf,
  0x231e0e07, 0x101d4008, 0x01001211, 0x290601af,
  0x060d0f09, 0x43001f23, 0x66001913, 0x15401d13,
  // [1530]
  0x0f0c2712, 0x2b001212, 0x17450808, 0x1c0e2322,
  0x2129276f, 0x15001d11, 0x1d004508, 0x15001d23,
  0x01270609, 0x030b66ad, 0x03000209, 0x0f050108,
  0x0b1003af, 0x401d1521, 0x170f3809, 0x15001d14,
  // [1540]
  0x1d001514, 0x45120f08, 0x0c012b07, 0x060f21a4,
  0x401d2709, 0x01276655, 0x1f000521, 0x38001522,
  0x19000608, 0x15001411, 0x12151dac, 0x080d3f60,
  0x45171212, 0x1d120c12, 0x03661909, 0x19001511,
  // [1550]
  0x40171dbe, 0x22003811, 0x010f2909, 0x66384013,
  0x050f0d08, 0x19000613, 0x0c001807, 0x12451655,
  0x01000f08, 0x02044512, 0x18004020, 0x18011921,
  0x38000112, 0x38000522, 0x22000d07, 0x0d002b07,
  // [1560]
  0x05000d07, 0x19001807, 0x1d031902, 0x05211709,
  0x0b000608, 0x1c1e2320, 0x12002b07, 0x0e232508,
  0x03080112, 0x05003813, 0x401917a4, 0x01060d08,
  0x17000d09, 0x29272221, 0x0000170a, 0x0d0f38be,
  // [1570]
  0x1d121707, 0x1d220d07, 0x1d273814, 0x1d1227ad,
  0x05000108, 0x17010508, 0x02100c07, 0x0e252312,
  0x0e1e2312, 0x251c1e09, 0x0e301e09, 0x19272960,
  0x0e251eaf, 0x08660311, 0x38080f09, 0x250e1e07,
  // [1580]
  0x25231c09, 0x12151d09, 0x124045af, 0x40021d08,
  0x0d001812, 0x250e1c60, 0x45661f09, 0x0c401d13,
  0x400c51af, 0x101d0b09, 0x2b101909, 0x082b1a11,
  0x17006620, 0x401d08af, 0x0c401d12, 0x01060307,
  // [1590]
  0x0f450812, 0x1d0c4008, 0x38172707, 0x16002909,
  0x25230e13, 0x03013809, 0x0d140f08, 0x38400109,
  0x1c0e1e10, 0x0e1c25ad, 0x0c401d07, 0x0d0b1812,
  0x38401d12, 0x18100b12, 0x10016612, 0x15002213,
  // [15a0]
  0x19221d12, 0x2b000f13, 0x0f060312, 0x0b036608,
  0x06030208, 0x27290421, 0x15193f12, 0x18291708,
  0x272b2909, 0x031719af, 0x05380d02, 0x0d160f60,
  0x2b27296f, 0x153f1921, 0x0d0501af, 0x05170313,
  // [15b0]
  0x18060112, 0x27223faf, 0x0b001511, 0x22000813,
  0x15043813, 0x16001912, 0x16151912, 0x19002712,
  0x0b272912, 0x2b292722, 0x23251e13, 0x04010509,
  0x03665112, 0x03001f21, 0x22141912, 0x1d272121,
  // [15c0]
  0x04002713, 0x3f212712, 0x22042109, 0x3f4021cf,
  0x21002913, 0x051d6609, 0x45294008, 0x16152912,
  0x06000522, 0x191f04bb, 0x05150421, 0x17380208,
  0x1f050421, 0x061f0411, 0x30002309, 0x30000e34,
  // [15d0]
  0x051f1560, 0x0d004313, 0x19021008, 0x1c002521,
  0x30002321, 0x1f041613, 0x1f1505a4, 0x04001521,
  0x01293f07, 0x0c083807, 0x08002708, 0x29220112,
  0x19000311, 0x0d170809, 0x21660323, 0x45124014,
  // [15e0]
  0x0d081413, 0x19002212, 0x142227af, 0x042b0baf,
  0x061021a4, 0x01170813, 0x18290112, 0x29002113,
  0x02060b09, 0x1f002221, 0x051738be, 0x14001d22,
  0x030c1d07, 0x196603af, 0x16271708, 0x660c0b13,
  // [15f0]
  0x06450521, 0x02010307, 0x05020b09, 0x0d0f27a4,
  0x12004520, 0x0f0b51a4, 0x020b1909, 0x17380baf,
  0x1d122707, 0x190427a4, 0x273f01af, 0x17012907,
  0x163819af, 0x160c1d09, 0x0b101d09, 0x00001703,
  // [1600]
  0x14124512, 0x05010d07, 0x050f1f12, 0x17124002,
  0x16662909, 0x04012709, 0x0f292709, 0x020b5112,
  0x161551a4, 0x0b005113, 0x17081d08, 0x19002b11,
  0x0c006620, 0x0d292708, 0x14002713, 0x12404512,
  // [1610]
  0x01060d12, 0x171d0809, 0x29271422, 0x1d001421,
  0x22001420, 0x662b0309, 0x0d001422, 0x06012bac,
  0x06033f21, 0x05170812, 0x02000612, 0x10001413,
  0x02080355, 0x0f010d08, 0x142201af, 0x06000c07,
  // [1620]
  0x19143821, 0x19042112, 0x0c004020, 0x154540a4,
  0x0c052907, 0x12454014, 0x40001521, 0x06120c07,
  0x03010611, 0x18060308, 0x10002120, 0x2b000621,
  0x2b000620, 0x01002b11, 0x1d3819ad, 0x29271913,
  // [1630]
  0x19001414, 0x0000022d, 0x19001f11, 0x100d0f55,
  0x03000c07, 0x0c401513, 0x30231ea4, 0x27184008,
  0x17002208, 0x1d193f60, 0x0d433f07, 0x23301c60,
  0x22041907, 0x17190408, 0x011240a4, 0x27004012,
  // [1640]
  0x1d214007, 0x2b0b0213, 0x27293faf, 0x1d002707,
  0x40211908, 0x05060108, 0x1d4008af, 0x06036608,
  0x06401d55, 0x08213f12, 0x08011208, 0x45001f12,
  0x121d4021, 0x030166a4, 0x171d40ad, 0x14004011,
  // [1650]
  0x010c66a4, 0x02161513, 0x40000508, 0x05001707,
  0x050b0fa4, 0x0b2b0309, 0x16450812, 0x231c25a4,
  0x0f013808, 0x052b3809, 0x43010608, 0x19000402,
  0x430d0faf, 0x17272912, 0x19046609, 0x191701af,
  // [1660]
  0x14000612, 0x0f1908ad, 0x02000507, 0x19000808,
  0x050401af, 0x0d0108af, 0x06220b08, 0x03002708,
  0x04003f12, 0x170f1f12, 0x3f272921, 0x05000613,
  0x0e251e13, 0x03100808, 0x010f0507, 0x19036612,
  // [1670]
  0x290f3813, 0x030419ac, 0x66010512, 0x01050d14,
  0x381466af, 0x0b0105a4, 0x0d000514, 0x0d050112,
  0x431901a4, 0x0b1410a4, 0x21000109, 0x23001e07,
  0x40001f11, 0x3f270509, 0x19001512, 0x3f2729af,
  // [1680]
  0x170c2912, 0x0e231c55, 0x12272113, 0x27210112,
  0x29151aaf, 0x0b0302ac, 0x14000211, 0x3f272913,
  0x0c001822, 0x06292760, 0x151f29a4, 0x0f2927af,
  0x15191613, 0x19140434, 0x0c042b12, 0x27102212,
  // [1690]
  0x02185112, 0x66062709, 0x40010820, 0x08170f08,
  0x1f055112, 0x021851af, 0x380c01af, 0x080f17ad,
  0x182b1f12, 0x100b51af, 0x1f011912, 0x081701af,
  0x380f45af, 0x100d1712, 0x1d011f12, 0x060b0208,
  // [16a0]
  0x161027af, 0x080f1aa4, 0x05020b12, 0x38171608,
  0x0d2205be, 0x380d0f12, 0x173805a4, 0x05663822,
  0x08055112, 0x45004007, 0x01002120, 0x010f0302,
  0x0f013f12, 0x06030808, 0x0c003f11, 0x02100b07,
  // [16b0]
  0x21272960, 0x0f030107, 0x020c0513, 0x40001211,
  0x1c1e0e07, 0x010c21a4, 0x0c293f09, 0x01270cad,
  0x43012108, 0x022b0560, 0x0b0c45ad, 0x0c004508,
  0x150c06ac, 0x06380109, 0x060103a4, 0x01222155,
  // [16c0]
  0x05000111, 0x0e1e2522, 0x0b0206a4, 0x01002213,
  0x22001f12, 0x08002213, 0x03010fac, 0x0d041daf,
  0x08190507, 0x07005c0c, 0x1d4029af, 0x27003f21,
  0x160b01a4, 0x0c000807, 0x06080208, 0x06402b07,
  // [16d0]
  0x01380609, 0x08191655, 0x0d0f1d12, 0x0d000822,
  0x0c010602, 0x01380612, 0x05220112, 0x0d051013,
  0x27162912, 0x1c251e6f, 0x14000614, 0x1d004302,
  0x060345a4, 0x0b380509, 0x663801a4, 0x19000d21,
  // [16e0]
  0x30231c07, 0x38180111, 0x66002709, 0x0b010608,
  0x01180812, 0x12661f09, 0x012b0611, 0x1d2927be,
  0x030d0609, 0x1d402960, 0x1d004035, 0x380d0f08,
  0x04161512, 0x271d4012, 0x06001612, 0x1c251eac,
  // [16f0]
  0x40001d36, 0x18451260, 0x23003002, 0x401d27af,
  0x29401d20, 0x0b190421, 0x06001611, 0x380406be,
  0x43000607, 0x66060ba4, 0x16270412, 0x25231e14,
  0x1e001c08, 0x22161407, 0x1d001607, 0x16004512,
  // [1700]
  0x03002913, 0x15161da4, 0x1e1c0eaf, 0x66000414,
  0x19161511, 0x23001c14, 0x031d0609, 0x14001822,
  0x12002707, 0x04001514, 0x230e1c60, 0x3f2129af,
  0x08001f12, 0x1d001912, 0x040116af, 0x01274308,
  // [1710]
  0x2b162122, 0x15001914, 0x2b271612, 0x1d453802,
  0x15191760, 0x19120408, 0x19001523, 0x1d160107,
  0x14151912, 0x081721a4, 0x16002b12, 0x102766a4,
  0x031f0208, 0x0b020112, 0x29270f09, 0x29190112,
  // [1720]
  0x0b4501a4, 0x10020602, 0x1f050623, 0x66001934,
  0x400302ad, 0x10193fcf, 0x22036608, 0x040c19bb,
  0x0d001612, 0x17000112, 0x16002b22, 0x04006607,
  0x191504ad, 0x12154014, 0x432b0112, 0x27451212,
  // [1730]
  0x081729af, 0x2b0c1f21, 0x081451af, 0x0c001f34,
  0x40100b02, 0x0c292711, 0x23001e14, 0x45000c23,
  0x16000c22, 0x661904be, 0x0c001f21, 0x08010f22,
  0x21006608, 0x05190209, 0x0e001e08, 0x27293813,
  // [1740]
  0x0c1245ac, 0x0e1e1cad, 0x66292760, 0x25230e07,
  0x29276609, 0x27000122, 0x40122708, 0x2b1f0c20,
  0x16000c13, 0x120c1daf, 0x040f01ac, 0x1f000c13,
  0x08003809, 0x01000c13, 0x14402708, 0x45012912,
  // [1750]
  0x222b1711, 0x0c272913, 0x0c1d1709, 0x084305a4,
  0x0d0419ad, 0x0e1c2302, 0x3f000c22, 0x12382b07,
  0x06000c11, 0x1d1722a4, 0x190c0111, 0x15001723,
  0x19002b12, 0x01000412, 0x0d004507, 0x05000812,
  // [1760]
  0x22272914, 0x0000291c, 0x16121709, 0x19001d09,
  0x06012b08, 0x210366bc, 0x380c2207, 0x03003f11,
  0x030b0612, 0x143804ac, 0x04036612, 0x0d050108,
  0x0c002708, 0x050d38af, 0x29270321, 0x020b08af,
  // [1770]
  0x04012707, 0x0b190202, 0x0b060812, 0x14043811,
  0x38010f02, 0x0d000502, 0x14220412, 0x011d1709,
  0x02001002, 0x12170f11, 0x1d013faf, 0x032b2908,
  0x0f081707, 0x06080112, 0x010d0f60, 0x05001f11,
  // [1780]
  0x0c002b07, 0x10020baf, 0x0b030509, 0x0b661421,
  0x0b1908af, 0x142b6608, 0x011822ad, 0x450c03bc,
  0x05380f22, 0x0b1014ce, 0x04001712, 0x06382b02,
  0x060822be, 0x06211408, 0x01190855, 0x031d66ac,
  // [1790]
  0x01292121, 0x23300ebe, 0x12190407, 0x180f66a4,
  0x17001d11, 0x0f003802, 0x1d451613, 0x04120f08,
  0x08000412, 0x05660360, 0x03041760, 0x29003f13,
  0x0d0117a4, 0x06001521, 0x15000614, 0x1d046607,
  // [17a0]
  0x1f000622, 0x06001621, 0x14150309, 0x0c451255,
  0x16061420, 0x120f4509, 0x45000507, 0x16191512,
  0x15380da4, 0x224012a4, 0x0d054307, 0x30000e23,
  0x140d06af, 0x2b0140a4, 0x173843a4, 0x1d002b08,
  // [17b0]
  0x04140660, 0x38151602, 0x1e302320, 0x1d1815ad,
  0x29030109, 0x02450108, 0x02221055, 0x0e251e02,
  0x40001612, 0x1d0c12ad, 0x16272912, 0x18052b60,
  0x66000622, 0x40001610, 0x1f000613, 0x66030512,
  // [17c0]
  0x05060808, 0x06010c07, 0x0f000807, 0x180603af,
  0x43020507, 0x0b0214ad, 0x020b1021, 0x03020621,
  0x38661755, 0x16001913, 0x660506af, 0x10000411,
  0x0c0401ac, 0x15272112, 0x451219a4, 0x121d40ad,
  // [17d0]
  0x1e0e1c21, 0x250e37ad, 0x40001614, 0x14000b13,
  0x1d036607, 0x100b0213, 0x04060308, 0x0f153808,
  0x03001012, 0x43016611, 0x100c0208, 0x250e1caf,
  0x0f0d0b21, 0x27001009, 0x40000112, 0x06660307,
  // [17e0]
  0x3f006622, 0x1c0e2513, 0x300e1ea4, 0x22000420,
  0x02000107, 0x45292708, 0x251e0e13, 0x010d27af,
  0x0d011709, 0x0b030208, 0x01102b21, 0x12450da4,
  0x0b050209, 0x010602a4, 0x170c0109, 0x663f0521,
  // [17f0]
  0x081666bc, 0x061d40a4, 0x0e1c2312, 0x191822af,
  0x0e251c20, 0x1e252322, 0x19002214, 0x45171012,
  0x050d0f09, 0x0d004512, 0x2b004509, 0x0f000513,
  0x19121008, 0x1f004333, 0x120d01a4, 0x22001509,

  // [1800]
  0x0b166607, 0x29050d09, 0x66221960, 0x186622bb,
  0x25000e20, 0x19000d09, 0x01000502, 0x0f123807,
  0x0c173802, 0x291827af, 0x0d272960, 0x18272920,
  0x1c0e23a4, 0x07005c1d, 0x231c1e12, 0x1d0817af,
  // [1810]
  0x251e1c08, 0x0b060521, 0x0d172912, 0x0d292711,
  0x0d380f08, 0x03002b20, 0x04291912, 0x04010307,
  0x030b0607, 0x19020412, 0x10000602, 0x38081413,
  0x10001609, 0x06001914, 0x19050612, 0x02661aa4,
  // [1820]
  0x19382907, 0x40220860, 0x1e3025af, 0x03050112,
  0x40001208, 0x0d0105a4, 0x08001707, 0x1c2530af,
  0x14181007, 0x030c2b55, 0x18000f07, 0x1c1e0e14,
  0x061416a4, 0x38036607, 0x1c250e09, 0x03006636,
  // [1830]
  0x1d154021, 0x27062914, 0x271d2912, 0x66292713,
  0x04001811, 0x38450202, 0x0f170509, 0x10000307,
  0x0f380d60, 0x10292713, 0x45162708, 0x22001712,
  0x22005108, 0x0000150a, 0x300e2307, 0x25000e12,
  // [1840]
  0x1d001608, 0x06000b08, 0x04160821, 0x15401da4,
  0x1d001508, 0x300e1e07, 0x19042107, 0x1d004036,
  0x19002708, 0x1c001e07, 0x1c000e21, 0x1c0e25af,
  0x18100608, 0x3f066613, 0x080d0107, 0x293f2714,
  // [1850]
  0x23301c12, 0x30251c09, 0x27012909, 0x300e1c20,
  0x27211412, 0x03660612, 0x190b0f07, 0x250e1eaf,
  0x66000611, 0x29031909, 0x0d052707, 0x0e251cad,
  0x03180507, 0x0f382109, 0x03296607, 0x04192711,
  // [1860]
  0x19036655, 0x190666a4, 0x300e1c08, 0x03001407,
  0x38150f02, 0x036601af, 0x401d4560, 0x16001523,
  0x01401d13, 0x19006622, 0x15002b20, 0x25231c02,
  0x0d163fac, 0x43033809, 0x27080f13, 0x451501ac,
  // [1870]
  0x16273fad, 0x40121daf, 0x402b1507, 0x08001813,
  0x19100608, 0x1c0e25bc, 0x170f0daf, 0x14271612,
  0x0d381721, 0x0f1d1707, 0x04031913, 0x27000412,
  0x1d292bad, 0x012716bc, 0x06146608, 0x08186612,
  // [1880]
  0x01002911, 0x191d3fad, 0x04002707, 0x0b062709,
  0x02062209, 0x0b000512, 0x40000308, 0x0b170214,
  0x142b0633, 0x2b0f0513, 0x04011fa4, 0x0f272913,
  0x192903ad, 0x0c040109, 0x22430109, 0x03000202,
  // [1890]
  0x12400355, 0x02002121, 0x06021907, 0x0f1f0baf,
  0x04292760, 0x66291012, 0x10170560, 0x03061707,
  0x43000113, 0x38002711, 0x18142209, 0x660d0808,
  0x16451211, 0x1d000607, 0x22292709, 0x45401212,
  // [18a0]
  0x0f0601ad, 0x21001612, 0x22001622, 0x0b450607,
  0x10000212, 0x29272121, 0x27002920, 0x17000f07,
  0x18004513, 0x40051d12, 0x0e1e23af, 0x21002713,
  0x17001911, 0x17002207, 0x16020b20, 0x19001421,
  // [18b0]
  0x1d000c14, 0x27292121, 0x1f000513, 0x05000d14,
  0x050f01af, 0x38080dbe, 0x01046655, 0x012b0d09,
  0x16020112, 0x66050112, 0x01040dac, 0x660351a4,
  0x660d0111, 0x38212712, 0x18402709, 0x231c0e20,
  // [18c0]
  0x01002b02, 0x01102b07, 0x19272908, 0x01432907,
  0x1d404512, 0x12430209, 0x06011fa4, 0x21036612,
  0x01002208, 0x050f38af, 0x08002b11, 0x06002b23,
  0x0e001c20, 0x02001014, 0x0f0d05ac, 0x06190202,
  // [18d0]
  0x45014009, 0x06000d14, 0x19020b09, 0x0c034007,
  0x10453802, 0x19292708, 0x04061055, 0x19001d07,
  0x082b01ad, 0x66380112, 0x0000040a, 0x02181907,
  0x19036607, 0x12000d12, 0x06001808, 0x451f1209,
  // [18e0]
  0x1c002321, 0x0c013f12, 0x38080f21, 0x142b0821,
  0x050f08a4, 0x450b0507, 0x43000507, 0x1d0c4012,
  0x042b2712, 0x0f171609, 0x250e1c09, 0x100251af,
  0x0b020809, 0x10171907, 0x0d180f55, 0x4522176f,
  // [18f0]
  0x013f2912, 0x080b1821, 0x16152b22, 0x0b0151af,
  0x0f3827af, 0x0f170d09, 0x66000621, 0x300e1c13,
  0x06121907, 0x380b0108, 0x1f001014, 0x38000f02,
  0x010f0d60, 0x05380d20, 0x270129af, 0x0f272912,
  // [1900]
  0x21001d12, 0x1d213f11, 0x1e250e07, 0x101229a4,
  0x14001813, 0x2b036609, 0x38224302, 0x38000308,
  0x38000d12, 0x1f0d0f13, 0x01053fac, 0x04001414,
  0x14000409, 0x0f033807, 0x38004312, 0x06010312,
  // [1910]
  0x30251c12, 0x0f002711, 0x380d0f02, 0x030c6607,
  0x10001407, 0x1c003012, 0x1d0b40a4, 0x0d010612,
  0x15000312, 0x18000f08, 0x0d1245a4, 0x1f12456f,
  0x01270fa4, 0x010366a4, 0x22272920, 0x02000b22,
  // [1920]
  0x14020b12, 0x17292708, 0x0b0301af, 0x020366af,
  0x04001011, 0x04001813, 0x082b0112, 0x01432709,
  0x0d0f0807, 0x06001811, 0x05000607, 0x17001d13,
  0x38010daf, 0x120c3808, 0x22292755, 0x1d272908,
  // [1930]
  0x38000111, 0x21003f09, 0x0d010507, 0x0f433812,
  0x12042160, 0x15001610, 0x38660f60, 0x45000d12,
  0x1d042107, 0x251e1c21, 0x03021009, 0x0d010f09,
  0x04001812, 0x301c2560, 0x0b1015ad, 0x180c1221,
  // [1940]
  0x4504216f, 0x430b0207, 0x10001807, 0x100406af,
  0x290f2709, 0x27170860, 0x45000d11, 0x191d08a4,
  0x1c302307, 0x1d082b07, 0x120f3802, 0x19401d12,
  0x21000c12, 0x401421a4, 0x45180d07, 0x17001d07,
  // [1950]
  0x0f0501a4, 0x22161907, 0x04000809, 0x1c231ea4,
  0x12001812, 0x041245af, 0x401d27a4, 0x0c272955,
  0x45121812, 0x450c1212, 0x1e003011, 0x18380f11,
  0x220c2107, 0x0f1838af, 0x12451807, 0x1e0e23a4,
  // [1960]
  0x1f180f12, 0x180f3821, 0x05000407, 0x05041208,
  0x1d003f11, 0x18003834, 0x16002114, 0x0b660311,
  0x1e0e2512, 0x12000414, 0x272b0c12, 0x18272909,
  0x0b180809, 0x2b001213, 0x01380d13, 0x01030f08,
  // [1970]
  0x40002b21, 0x0d0f1da4, 0x0b102b12, 0x45121d21,
  0x04210809, 0x16002122, 0x2b010812, 0x16140f09,
  0x0d000312, 0x0c0d0f07, 0x231e25af, 0x251c1ea4,
  0x38000808, 0x40002711, 0x02000102, 0x192b0dad,
  // [1980]
  0x1d004312, 0x01401d11, 0x01401d07, 0x0d450f07,
  0x04192114, 0x0f083860, 0x04000307, 0x06056655,
  0x05006613, 0x122227af, 0x140d0f11, 0x0f0d3813,
  0x15401d20, 0x1d4027ad, 0x01660511, 0x17124560,
  // [1990]
  0x18004522, 0x05006611, 0x27022909, 0x45003812,
  0x12004511, 0x1f002212, 0x020b4007, 0x38000d09,
  0x451d1211, 0x01660360, 0x17001907, 0x66192712,
  0x23251cad, 0x400b02a4, 0x0f1d1007, 0x1d002b02,
  // [19a0]
  0x141810ac, 0x08270d08, 0x100b03ac, 0x05010baf,
  0x01180309, 0x03001411, 0x170f0d08, 0x052b21ad,
  0x080d0f07, 0x18001209, 0x06020312, 0x060d3812,
  0x15272908, 0x0f001812, 0x21001521, 0x1f001821,
  // [19b0]
  0x0f172160, 0x1c1e0e60, 0x02140baf, 0x0b450307,
  0x1d0c0112, 0x66430112, 0x0e1c1e07, 0x190f2707,
  0x18450da4, 0x38000813, 0x18001f14, 0x231c0e6f,
  0x18001213, 0x04000302, 0x18001712, 0x660315bc,
  // [19c0]
  0x08000d08, 0x16040cad, 0x45022121, 0x660b0312,
  0x0f1838a4, 0x2b005113, 0x0d2b4512, 0x0f124507,
  0x01031721, 0x08003813, 0x400b0207, 0x0c000313,
  0x1d120607, 0x030106af, 0x22001412, 0x452138af,
  // [19d0]
  0x18001713, 0x66001621, 0x08002b12, 0x27064009,
  0x38003f20, 0x1f001713, 0x0b660313, 0x0d1938a4,
  0x05660112, 0x01001f12, 0x0e1c2520, 0x251e0e60,
  0x1418121e, 0x050301ad, 0x0c063807, 0x22000d11,
  // [19e0]
  0x0c035112, 0x27291aaf, 0x38660355, 0x12191d07,
  0x12450baf, 0x020b1007, 0x45001812, 0x12010c07,
  0x06010209, 0x02451211, 0x03190612, 0x06171008,
  0x01101422, 0x12000f09, 0x38001813, 0x12271613,
  // [19f0]
  0x102b0214, 0x0d0f3802, 0x382b08af, 0x2b002123,
  0x22003f23, 0x102129af, 0x18152baf, 0x25231e09,
  0x182b21af, 0x033f2bbc, 0x0f3845af, 0x19002108,
  0x1c0e236f, 0x18663f12, 0x05001f07, 0x181d2b21,
  // [1a00]
  0x08171212, 0x212b29af, 0x0e1c3012, 0x45000c12,
  0x0c124021, 0x03000507, 0x29001d13, 0x1d0f0d13,
  0x23251e14, 0x27401d08, 0x18000f13, 0x19000d20,
  0x10210f11, 0x3f1929af, 0x21001012, 0x451218ad,
  // [1a10]
  0x04190b08, 0x3f002213, 0x100c2907, 0x18401d14,
  0x04000612, 0x121845ac, 0x0f012109, 0x1d170f12,
  0x0b145112, 0x0c0d1012, 0x0c291dbb, 0x19001d08,
  0x19101809, 0x04001d11, 0x04193f13, 0x27290faf,
  // [1a20]
  0x03006621, 0x180d0f11, 0x01005113, 0x19002912,
  0x0b0302a4, 0x020b08a4, 0x0b003809, 0x15000611,
  0x03010b12, 0x12450207, 0x03050408, 0x010d0faf,
  0x03173808, 0x0d000511, 0x121910a4, 0x250e1e12,
  // [1a30]
  0x0d000102, 0x19001004, 0x40021012, 0x06660312,
  0x18001f08, 0x0b003f12, 0x40005108, 0x22195107,
  0x08212207, 0x15004012, 0x01660311, 0x22293f12,
  0x06190b09, 0x273f19bc, 0x01010107, 0x180d0f60,
  // [1a40]
  0x17003f12, 0x01172712, 0x10140614, 0x45401da4,
  0x22403f12, 0x0c102b07, 0x0c0d08a4, 0x1f060309,
  0x0e251ebe, 0x040c27ad, 0x19166609, 0x0b060214,
  0x66040f13, 0x29000420, 0x180f0d09, 0x10031908,
  // [1a50]
  0x29000309, 0x0d0c3808, 0x063801ad, 0x0b101412,
  0x1d452112, 0x451d40a4, 0x120c4513, 0x12380d12,
  0x30001e21, 0x12002207, 0x38292708, 0x19061055,
  0x0e1c2512, 0x0e301c07, 0x012b0509, 0x2b006611,
  // [1a60]
  0x18000802, 0x19002112, 0x06000302, 0x1d160f12,
  0x06040b07, 0x08001614, 0x22271912, 0x292721be,
  0x050f3f09, 0x060122ad, 0x38000814, 0x1c233012,
  0x66000612, 0x220d3f12, 0x381901a4, 0x180f1f08,
  // [1a70]
  0x08270112, 0x301c0ea4, 0x01170d09, 0x10021908,
  0x1f000112, 0x031d4508, 0x45380fa4, 0x1d124507,
  0x30001c08, 0x45401209, 0x12451660, 0x0c153fbc,
  0x40002b11, 0x22030c07, 0x1d124508, 0x08451209,
  // [1a80]
  0x050d0808, 0x0b026607, 0x216602af, 0x04012121,
  0x01000311, 0x05003f14, 0x01660621, 0x06000d12,
  0x18150422, 0x220b0313, 0x10001911, 0x18102113,
  0x06010309, 0x22000113, 0x01051512, 0x40451d07,
  // [1a90]
  0x14002220, 0x06000323, 0x0b0366af, 0x18051512,
  0x100b026f, 0x2b001421, 0x40000c12, 0x3818156f,
  0x040c1521, 0x0c000308, 0x08010f09, 0x0c041612,
  0x0b064012, 0x061002a4, 0x12030507, 0x0c271d09,
  // [1aa0]
  0x0b026608, 0x29193f09, 0x010419ad, 0x38002909,
  0x29222121, 0x1d001213, 0x66272913, 0x401229af,
  0x1d0f2b12, 0x19124008, 0x16120302, 0x291921be,
  0x06012709, 0x142717a4, 0x0d292712, 0x0b1001af,
  // [1ab0]
  0x10001520, 0x0f0d21af, 0x06001913, 0x0c1d4009,
  0x0c3f0421, 0x171938a4, 0x124001af, 0x0c001f07,
  0x023801af, 0x1d0f45af, 0x192901af, 0x161d01af,
  0x290d27af, 0x400c21af, 0x2b104512, 0x02064008,
  // [1ac0]
  0x020306a4, 0x1c301e20, 0x12001007, 0x19001808,
  0x12001911, 0x19171d07, 0x0c002b21, 0x192729a4,
  0x16060313, 0x0c2927a4, 0x16012108, 0x21293f09,
  0x21292712, 0x66100b60, 0x032b1008, 0x190b0612,
  // [1ad0]
  0x27290614, 0x15002713, 0x45191508, 0x0c451212,
  0x12171d08, 0x27001520, 0x19081d07, 0x25231c55,
  0x04101913, 0x27060cbc, 0x0c161d09, 0x19046608,
  0x40000802, 0x272101af, 0x023f01a4, 0x03140b55,
  // [1ae0]
  0x1d401002, 0x17063809, 0x06123802, 0x2b170112,
  0x17000c07, 0x08001821, 0x17001008, 0x0f080107,
  0x08003811, 0x01381909, 0x0c1d40af, 0x08036621,
  0x19004513, 0x451d4023, 0x29192714, 0x08000302,
  // [1af0]
  0x06180b09, 0x031d4021, 0x2b001921, 0x21190112,
  0x19012b14, 0x151419af, 0x060f0309, 0x27002209,
  0x1d170109, 0x01050f09, 0x121706a4, 0x21002b21,
  0x0e302309, 0x21190209, 0x042b19a4, 0x19002909,
  // [1b00]
  0x1f661913, 0x272919be, 0x151d45af, 0x0f182b21,
  0x301e25be, 0x02080d07, 0x230e1e12, 0x04000f20,
  0x0e1c2307, 0x10060407, 0x0410066f, 0x12451760,
  0x05060107, 0x10030207, 0x02011208, 0x03660660,
  // [1b10]
  0x212b01af, 0x0f001f20, 0x222101af, 0x05030107,
  0x01063f08, 0x10010307, 0x163f01af, 0x05161f12,
  0x06272912, 0x05002908, 0x02002b12, 0x08222911,
  0x053f0112, 0x27296612, 0x01040508, 0x400c1dbe,
  // [1b20]
  0x01000b07, 0x02006612, 0x29002108, 0x270d2922,
  0x0c401d23, 0x030601a4, 0x06660313, 0x0c1d40be,
  0x66030612, 0x1c230e22, 0x1d0c4014, 0x22002911,
  0x010229a4, 0x05010809, 0x03060ba4, 0x1d001021,
  // [1b30]
  0x02050112, 0x01191760, 0x060b1407, 0x14002b21,
  0x141f066f, 0x66001912, 0x120210a4, 0x300e2313,
  0x1d001713, 0x2b002112, 0x29191012, 0x100601af,
  0x03060208, 0x160b0212, 0x06000202, 0x0f0801a4,
  // [1b40]
  0x03002202, 0x23251c14, 0x0e302509, 0x23300ea4,
  0x10190455, 0x061d0b07, 0x06000b21, 0x43011aa4,
  0x04191820, 0x02005108, 0x06012107, 0x03660214,
  0x27210412, 0x01052155, 0x012b18ad, 0x082b02cf,
  // [1b50]
  0x01061207, 0x03180da4, 0x046603ad, 0x19002122,
  0x06140b12, 0x1d0429ac, 0x1d000b20, 0x2b660608,
  0x06001021, 0x2b170f08, 0x271f0112, 0x100301a4,
  0x06021909, 0x0c122ba4, 0x0e233022, 0x231e1c09,
  // [1b60]
  0x100406a4, 0x05000109, 0x45001807, 0x1d004502,
  0x06012912, 0x230e1e11, 0x45001609, 0x1d000202,
  0x22001521, 0x0f0801af, 0x2b1901af, 0x19000207,
  0x04162107, 0x17190b12, 0x100c1da4, 0x01190407,
  // [1b70]
  0x040f2707, 0x06210112, 0x17122109, 0x190415af,
  0x15001621, 0x121701af, 0x1c1e2521, 0x10382123,
  0x03292721, 0x0e002323, 0x12152221, 0x18381709,
  0x16210808, 0x19040ba4, 0x1d454012, 0x03171221,
  // [1b80]
  0x10001420, 0x01103808, 0x171012be, 0x12451d12,
  0x05003812, 0x0d060112, 0x66270409, 0x29122121,
  0x29274012, 0x06002213, 0x042216ad, 0x23251e21,
  0x03180fac, 0x02006609, 0x22192121, 0x22213f6f,
  // [1b90]
  0x0b022709, 0x22193fcf, 0x16031f09, 0x0f004511,
  0x0f3822af, 0x1c301e07, 0x2b2201a4, 0x08272909,
  0x38052202, 0x1d001622, 0x43000c11, 0x10120609,
  0x1e250e12, 0x40121d12, 0x40124509, 0x0b272955,
  // [1ba0]
  0x21270809, 0x25002314, 0x08000f08, 0x12401d12,
  0x120d1d07, 0x0c272908, 0x01100b07, 0x080f1707,
  0x10020355, 0x0c121d07, 0x03106609, 0x17030d02,
  0x12400407, 0x292127af, 0x0d0f3808, 0x19182107,
  // [1bb0]
  0x0b010207, 0x010317a4, 0x04000812, 0x3f271621,
  0x01062709, 0x02082b09, 0x161f3f09, 0x0d0f3814,
  0x01002112, 0x16453f12, 0x16001507, 0x04190209,
  0x100b0223, 0x1d001513, 0x1545401f, 0x18380f55,
  // [1bc0]
  0x02401060, 0x0c124507, 0x45000c34, 0x0c401d6f,
  0x0b292712, 0x25230e60, 0x100b0812, 0x381f3f11,
  0x0b001d20, 0x231c2508, 0x29032709, 0x122927af,
  0x0c002b22, 0x031d2107, 0x1d454021, 0x06031d08,
  // [1bd0]
  0x0c031007, 0x1d000b12, 0x45001235, 0x40061909,
  0x12001611, 0x04061011, 0x10000807, 0x151d16a4,
  0x0c100b09, 0x1e1c2311, 0x041d2907, 0x45401d13,
  0x40033809, 0x0e002511, 0x38190ba4, 0x0d1f2113,
  // [1be0]
  0x060b1507, 0x380b02a4, 0x400c1d09, 0x01172b60,
  0x10002b22, 0x03662912, 0x1d010b12, 0x29000521,
  0x660801af, 0x08170f13, 0x01050834, 0x38000514,
  0x00001003, 0x43080f22, 0x140c1f60, 0x38012907,
  // [1bf0]
  0x43016608, 0x10290312, 0x0c080b02, 0x140b1fbc,
  0x011f0421, 0x1c302309, 0x02100612, 0x380127a4,
  0x02450112, 0x03000121, 0x10052721, 0x03061f23,
  0x2b000421, 0x290608bb, 0x22002114, 0x0d120f07,

  // [1c00]
  0x401d1512, 0x151918bc, 0x0b000412, 0x10000811,
  0x1e252321, 0x2b141faf, 0x451708af, 0x05002707,
  0x0b190208, 0x0e1e2514, 0x22000302, 0x3f012114,
  0x12001520, 0x40004512, 0x66041912, 0x660b06af,
  // [1c10]
  0x10124012, 0x15006612, 0x05220baf, 0x15012bac,
  0x100b1212, 0x30002320, 0x18000d07, 0x06193fad,
  0x12021708, 0x0d292722, 0x210229af, 0x1e0e23af,
  0x16000f12, 0x06000207, 0x04002908, 0x15000d12,
  // [1c20]
  0x0b221507, 0x18190408, 0x01401007, 0x14000212,
  0x12292722, 0x1d4045a4, 0x0f1d1908, 0x140366ad,
  0x400b5112, 0x2b000302, 0x01030607, 0x0000020a,
  0x1f012b12, 0x10020b13, 0x0d001709, 0x06000c14,
  // [1c30]
  0x0f380d22, 0x01223821, 0x0d0f45ad, 0x250e1e11,
  0x18212712, 0x38000807, 0x100b0222, 0x0d0f21be,
  0x100b02af, 0x15140321, 0x01062955, 0x140c0311,
  0x04273f60, 0x12003810, 0x0f000d20, 0x10000621,
  // [1c40]
  0x0b000307, 0x0b060307, 0x190366a4, 0x0d0f45af,
  0x0d000211, 0x211601af, 0x06140322, 0x140b1021,
  0x271d3fbc, 0x0310026f, 0x0d050209, 0x12451faf,
  0x12451f10, 0x05191612, 0x170f0d07, 0x05010307,
  // [1c50]
  0x38000f13, 0x16660112, 0x190b27a4, 0x1d384009,
  0x182166a4, 0x14190ba4, 0x43003808, 0x1e1c2308,
  0x08003823, 0x100b0255, 0x04002221, 0x02061021,
  0x0d3f01af, 0x01380f07, 0x1c1e2523, 0x0f0105ac,
  // [1c60]
  0x02002907, 0x14061021, 0x02040b09, 0x020b0409,
  0x0c100b08, 0x1d403f13, 0x10660308, 0x1c2530bc,
  0x12036660, 0x160c2b12, 0x0c1d16a4, 0x0c1d40bc,
  0x0f380809, 0x27000609, 0x0c006609, 0x060c2707,
  // [1c70]
  0x0b1401af, 0x04000312, 0x251e1cbb, 0x2b660355,
  0x0d430108, 0x140b51af, 0x401d0ca4, 0x16451223,
  0x06002909, 0x0c010307, 0x1e1c25ad, 0x45004020,
  0x3f002113, 0x06001413, 0x0b1001ad, 0x1d2b1655,
  // [1c80]
  0x1d292755, 0x38002913, 0x181408a4, 0x0b021002,
  0x0f380109, 0x170b0208, 0x16272908, 0x02190b12,
  0x2b010d60, 0x01064507, 0x22001708, 0x06001407,
  0x01191012, 0x0b100202, 0x02182708, 0x19001412,
  // [1c90]
  0x02124508, 0x03003f21, 0x190f0b12, 0x22001714,
  0x40000107, 0x150c4009, 0x27661a12, 0x19002211,
  0x293f2721, 0x08000614, 0x38190508, 0x251e0e07,
  0x1d164012, 0x251c0e60, 0x12061d6f, 0x2b000111,
  // [1ca0]
  0x061d0f07, 0x05030455, 0x17030807, 0x08000608,
  0x45001d1f, 0x170b10a4, 0x10002707, 0x181d0808,
  0x08010507, 0x12450f08, 0x0c010507, 0x1e301c13,
  0x01000513, 0x181001af, 0x10036612, 0x250e2311,
  // [1cb0]
  0x45000f13, 0x0f140dad, 0x0d0f06ad, 0x06000212,
  0x02012107, 0x21000614, 0x2b002713, 0x03003f22,
  0x450c3f12, 0x30002511, 0x031d0612, 0x01021012,
  0x15182108, 0x0d030f08, 0x43000f07, 0x2b006612,
  // [1cc0]
  0x22292708, 0x40181709, 0x2b006608, 0x40001702,
  0x14020313, 0x0c0b3f12, 0x1d0c1807, 0x21002909,
  0x300e23bc, 0x16124008, 0x1d0c40af, 0x663f1aaf,
  0x1d1640a9, 0x10161d09, 0x251e0e09, 0x38171607,
  // [1cd0]
  0x0c001710, 0x231e2520, 0x1d454009, 0x16004021,
  0x0b040802, 0x2b010f13, 0x041d4511, 0x1d000c22,
  0x66000111, 0x38001711, 0x07005c33, 0x0c660307,
  0x15184509, 0x030627af, 0x04161908, 0x30002302,
  // [1ce0]
  0x0f083809, 0x0d060b09, 0x2b004013, 0x04002b14,
  0x454021a4, 0x194527a4, 0x45401d60, 0x25301c08,
  0x0b1214ad, 0x38452707, 0x1c000e35, 0x17180809,
  0x27012112, 0x1d400808, 0x29002234, 0x18000611,
  // [1cf0]
  0x06023f22, 0x451240af, 0x10401d07, 0x0c0301a4,
  0x402729af, 0x29021760, 0x01001a08, 0x1d001214,
  0x1d084008, 0x40290809, 0x08451712, 0x22170808,
  0x08173860, 0x276629af, 0x161d1212, 0x18002108,
  // [1d00]
  0x06021008, 0x0c451222, 0x38100209, 0x06003f11,
  0x2b0f0d07, 0x011f2b12, 0x0f14180c, 0x03000622,
  0x38001002, 0x29002735, 0x1d181008, 0x38100ba4,
  0x01060c07, 0x020b51a4, 0x27292112, 0x292b43bc,
  // [1d10]
  0x16664308, 0x1c1e0e09, 0x27211f08, 0x0b041009,
  0x45124012, 0x66060809, 0x0d0f1712, 0x170108a4,
  0x151f2bbe, 0x2b1d4512, 0x3f272912, 0x050d0112,
  0x08451daf, 0x01002b22, 0x080f1faf, 0x0c2b0112,
  // [1d20]
  0x0c210112, 0x18660382, 0x251c1e21, 0x2b012912,
  0x06000102, 0x0f2901a4, 0x05002b07, 0x25002313,
  0x1c302355, 0x22272913, 0x08001907, 0x19001812,
  0x12222107, 0x06000209, 0x15100b12, 0x0f0517a4,
  // [1d30]
  0x14000611, 0x22124509, 0x16270460, 0x04002b02,
  0x18002b11, 0x190b2108, 0x06145112, 0x3f000114,
  0x06001f22, 0x012b1912, 0x1f000b20, 0x18045112,
  0x06010f08, 0x27001421, 0x29271412, 0x10141faf,
  // [1d40]
  0x0d030107, 0x01191f09, 0x1f2b0baf, 0x16001f12,
  0x66050314, 0x032b0612, 0x191f06be, 0x04031907,
  0x30231e07, 0x38040b12, 0x1d124502, 0x12000f12,
  0x01272955, 0x160221a4, 0x01660f09, 0x38190512,
  // [1d50]
  0x38001702, 0x0f0529a4, 0x0d002108, 0x052b4008,
  0x2b140312, 0x22382909, 0x16002713, 0x17052107,
  0x3f000422, 0x0f3806ad, 0x2b222908, 0x05190809,
  0x033f6660, 0x30251e60, 0x192704af, 0x08040512,
  // [1d60]
  0x06000811, 0x22001608, 0x45120612, 0x10010c07,
  0x040621a4, 0x020c0b02, 0x66080460, 0x08040309,
  0x062b1920, 0x29660baf, 0x121840af, 0x18004512,
  0x0b036655, 0x1c250e11, 0x2b0301a4, 0x03013807,
  // [1d70]
  0x12221820, 0x17004002, 0x38051702, 0x08431f08,
  0x2b660322, 0x19042b02, 0x190b6608, 0x06050809,
  0x192201af, 0x0b221934, 0x0d0501a4, 0x27002109,
  0x0e251c21, 0x03003f23, 0x04002909, 0x0f0c0509,
  // [1d80]
  0x040c1608, 0x04001609, 0x2b004009, 0x29000111,
  0x1d2b0308, 0x16044012, 0x1f000121, 0x1d4001af,
  0x080f0d09, 0x01062bad, 0x014517a4, 0x0d0f2b12,
  0x0b000411, 0x1f2b0112, 0x0b002b12, 0x06042755,
  // [1d90]
  0x29271421, 0x022901af, 0x01401d12, 0x01380f09,
  0x061f3f60, 0x21153f09, 0x18063f08, 0x29041912,
  0x19401d20, 0x0b043814, 0x12002908, 0x2b000c14,
  0x222927af, 0x23301c09, 0x10191807, 0x29402760,
  // [1da0]
  0x193821a4, 0x0d010821, 0x29382709, 0x04061908,
  0x43010507, 0x251c2322, 0x02044302, 0x08380c07,
  0x2b4001af, 0x022b01cf, 0x01060809, 0x1d124555,
  0x19180121, 0x1d000b14, 0x2b190112, 0x19180112,
  // [1db0]
  0x0f001907, 0x0d000513, 0x032b0120, 0x06010f07,
  0x2b000121, 0x19000508, 0x17010509, 0x01000512,
  0x19161812, 0x29271f09, 0x01060507, 0x660c0412,
  0x210201af, 0x1d2b0112, 0x120c4514, 0x40190112,
  // [1dc0]
  0x02060112, 0x04001613, 0x010f1907, 0x0f140207,
  0x0b292708, 0x0f011f08, 0x300e23a4, 0x19000f08,
  0x2b6601ad, 0x1d164013, 0x45210108, 0x154516a4,
  0x1e000e22, 0x190204af, 0x29192713, 0x0d000811,
  // [1dd0]
  0x1c251e09, 0x0e1e2560, 0x2b0401a4, 0x03061008,
  0x104003a4, 0x012b6609, 0x30001c07, 0x0b0302be,
  0x030b0222, 0x16004513, 0x012b38bb, 0x1d0b0213,
  0x05000802, 0x38011f08, 0x10030407, 0x16660207,
  // [1de0]
  0x021051af, 0x3f012709, 0x1e302307, 0x040b02ad,
  0x01381f13, 0x04163807, 0x16451dac, 0x0f0d38bc,
  0x43001907, 0x0b002107, 0x05382207, 0x023845a4,
  0x220601a4, 0x08014307, 0x0b046614, 0x1e232507,
  // [1df0]
  0x22292721, 0x301c0ebb, 0x18001d09, 0x0b6627af,
  0x040d08a4, 0x06020b08, 0x3f0501af, 0x050f0d60,
  0x15001420, 0x1d000307, 0x03060107, 0x430d08a4,
  0x16000d08, 0x30001c09, 0x0f172909, 0x16003f20,
  // [1e00]
  0x04192709, 0x120c0112, 0x0c161522, 0x450f3809,
  0x01380fa4, 0x02060b12, 0x0d380fad, 0x45180f60,
  0x120f4508, 0x300e2514, 0x180f1412, 0x45180f55,
  0x45000f02, 0x0f1f4512, 0x031f0f12, 0x0f292760,
  // [1e10]
  0x0f001f09, 0x19001507, 0x192204a4, 0x45000c21,
  0x12006612, 0x23251caf, 0x0c663f09, 0x1d0d0f09,
  0x191d2707, 0x1f000f20, 0x0d000f21, 0x251e1c09,
  0x0b0602ad, 0x1f450faf, 0x0c013f08, 0x230e1e60,
  // [1e20]
  0x012b0508, 0x1d002112, 0x04272112, 0x050f0109,
  0x01176613, 0x0f012b12, 0x27040513, 0x08170112,
  0x2b1d01a4, 0x15000421, 0x05170809, 0x030d0f13,
  0x04060808, 0x1d0c40be, 0x40292712, 0x022b3809,
  // [1e30]
  0x0f010508, 0x050c1d12, 0x38000f23, 0x270c2121,
  0x0e1c3021, 0x05080109, 0x190416af, 0x210c1660,
  0x01162712, 0x08223807, 0x14272914, 0x23250e07,
  0x15401d21, 0x01000407, 0x0f050112, 0x040366bb,
  // [1e40]
  0x03002b11, 0x0d0f3810, 0x01006611, 0x08010502,
  0x0f0d3812, 0x1d124012, 0x061801ad, 0x0b022b12,
  0x1d0140a4, 0x1d001811, 0x020c0b09, 0x0f001711,
  0x0d0f3813, 0x03046613, 0x1e1c0e6f, 0x0f080d12,
  // [1e50]
  0x06011907, 0x0e1c1e21, 0x12001702, 0x1d004033,
  0x12001714, 0x10000414, 0x0b190209, 0x0c001513,
  0x04001707, 0x0b101d02, 0x29221421, 0x1f013f09,
  0x10180b12, 0x660b1834, 0x02052912, 0x014529a4,
  // [1e60]
  0x04020b12, 0x030104af, 0x22000521, 0x18100214,
  0x17002b07, 0x06000c20, 0x18450221, 0x120f4507,
  0x0b030812, 0x12000212, 0x08001720, 0x10050209,
  0x190b6612, 0x12182155, 0x12031821, 0x210b2221,
  // [1e70]
  0x020b0408, 0x223f2912, 0x06012109, 0x03660c21,
  0x030502ad, 0x220b02be, 0x12020421, 0x18100bbe,
  0x14003f13, 0x0b105112, 0x66292708, 0x19220308,
  0x19222712, 0x02160308, 0x1d002713, 0x23251c23,
  // [1e80]
  0x08030d13, 0x1f004313, 0x16003f11, 0x43001d07,
  0x27021908, 0x01042212, 0x66291812, 0x220b04bb,
  0x220c0312, 0x66292212, 0x14004533, 0x1d010409,
  0x662b0314, 0x04001f11, 0x060c0302, 0x0e1c1ebb,
  // [1e90]
  0x19002114, 0x01030809, 0x060105a4, 0x0c000114,
  0x0b221407, 0x0f041913, 0x43010502, 0x0e252307,
  0x17292760, 0x170105a4, 0x0c010408, 0x3f001d14,
  0x38430512, 0x06000512, 0x38010802, 0x40004509,
  // [1ea0]
  0x0f380d09, 0x1d154014, 0x05000f09, 0x06100baf,
  0x0f143807, 0x380117ac, 0x0d380f21, 0x17161921,
  0x17003822, 0x10000413, 0x2b001014, 0x010f1fbc,
  0x10021212, 0x27010809, 0x011522a4, 0x231e30a4,
  // [1eb0]
  0x050f0d14, 0x19002121, 0x12010507, 0x12001d14,
  0x0f080112, 0x05173811, 0x06222b21, 0x03101421,
  0x180d0560, 0x17436609, 0x66222b13, 0x16000611,
  0x1d403f6f, 0x27662913, 0x02100b22, 0x030b0608,
  // [1ec0]
  0x45164013, 0x0c0306ad, 0x402b01af, 0x27294021,
  0x221d1707, 0x031066a4, 0x0c1204a4, 0x02061008,
  0x230e3060, 0x050d4512, 0x03010608, 0x03100b08,
  0x0f0d01a4, 0x02060309, 0x30230e09, 0x43380507,
  // [1ed0]
  0x1e001c09, 0x451240a4, 0x03040112, 0x060110ad,
  0x02665112, 0x0b1951a4, 0x0f0127ad, 0x10060312,
  0x45062208, 0x12160109, 0x030b02a4, 0x04662708,
  0x06010311, 0x06002b22, 0x03430107, 0x12381d09,
  // [1ee0]
  0x031f1608, 0x120501a4, 0x04014507, 0x16271712,
  0x16154512, 0x03051d02, 0x45010807, 0x0f0c0313,
  0x1f000512, 0x1d124513, 0x0c381512, 0x27010212,
  0x0d010808, 0x1f151009, 0x0d0f08a4, 0x12041921,
  // [1ef0]
  0x030614bb, 0x10001708, 0x380f08af, 0x0c4540af,
  0x0e1c23bb, 0x191d21a4, 0x1c231ebb, 0x080f4512,
  0x160815be, 0x1d400c12, 0x1c1e2522, 0x04004513,
  0x0c454007, 0x06040ca4, 0x1c0e3020, 0x0b000507,
  // [1f00]
  0x0d012709, 0x3f380814, 0x0c020b55, 0x17454002,
  0x2b000411, 0x293f1421, 0x1d272913, 0x0c1d0807,
  0x19003807, 0x08001708, 0x08273f08, 0x0f160809,
  0x27292214, 0x04160c55, 0x19271709, 0x08160c11,
  // [1f10]
  0x08004020, 0x27291912, 0x03000811, 0x18401d60,
  0x01430812, 0x27213f08, 0x053817ad, 0x083f3814,
  0x08293813, 0x38191707, 0x43124508, 0x14273f21,
  0x17003814, 0x251e1c14, 0x01162707, 0x172927af,
  // [1f20]
  0x0d0f0507, 0x042729af, 0x0f003809, 0x29080d09,
  0x19381712, 0x0c124508, 0x0c001208, 0x29041620,
  0x16002b11, 0x05004312, 0x0d664360, 0x15000413,
  0x150b1013, 0x10061408, 0x05004311, 0x43000d12,
  // [1f30]
  0x0e1e2513, 0x380f1f09, 0x43000d11, 0x43000d09,
  0x0d050802, 0x010d0521, 0x04002b12, 0x010819ac,
  0x1d192707, 0x451901af, 0x052729ad, 0x106603af,
  0x17001d08, 0x17292755, 0x166603af, 0x10080412,
  // [1f40]
  0x05270112, 0x27182113, 0x452b0109, 0x30251e6f,
  0x00000503, 0x160d0f14, 0x180f0d22, 0x16005113,
  0x06050107, 0x04221408, 0x22001913, 0x66150112,
  0x14100412, 0x230e1ebb, 0x0f000b13, 0x380b0202,
  // [1f50]
  0x1c1e2313, 0x0f060107, 0x08001713, 0x160415a4,
  0x160f0d14, 0x160d2109, 0x0d160f12, 0x06020309,
  0x0f2201af, 0x22400112, 0x14060baf, 0x45151611,
  0x29042213, 0x0d1d0f14, 0x030615bc, 0x02066608,
  // [1f60]
  0x01121713, 0x1d104055, 0x021d2212, 0x230e3055,
  0x171d04af, 0x14060313, 0x01080f07, 0x43002707,
  0x45061208, 0x182202af, 0x19066611, 0x29061021,
  0x38270109, 0x19170814, 0x19382b09, 0x29192708,
  // [1f70]
  0x022729a4, 0x220306a4, 0x1d401921, 0x02030b09,
  0x38272b12, 0x01663f09, 0x0b1001ac, 0x1d172907,
  0x10082108, 0x03196614, 0x0d1f01af, 0x18402912,
  0x10030612, 0x05210112, 0x190501a4, 0x040366be,
  // [1f80]
  0x660419be, 0x27001812, 0x06160809, 0x06000802,
  0x19291055, 0x03042155, 0x191410ac, 0x01453f12,
  0x231c2502, 0x0e302307, 0x0d060f07, 0x010b38a4,
  0x380601af, 0x01100612, 0x10161807, 0x19036622,
  // [1f90]
  0x27000814, 0x66030422, 0x120b0307, 0x29142714,
  0x0b006608, 0x1f292714, 0x01000b02, 0x0d2266a4,
  0x290d0108, 0x121d1622, 0x18002112, 0x66000b12,
  0x0f001702, 0x23002502, 0x45401d55, 0x0b002112,
  // [1fa0]
  0x1c003011, 0x0f430d02, 0x301e2555, 0x22000612,
  0x1e0e3012, 0x0e301c12, 0x17000811, 0x18000408,
  0x121d0211, 0x0b662712, 0x38056608, 0x02032b21,
  0x16386609, 0x0d0106a4, 0x01182755, 0x10051212,
  // [1fb0]
  0x151929a4, 0x2b0338a4, 0x17000802, 0x04183808,
  0x38004002, 0x66000334, 0x05012207, 0x0f080d55,
  0x03012708, 0x1f1051af, 0x0f004007, 0x15191d09,
  0x21000f35, 0x04011907, 0x191f0113, 0x062b1f12,
  // [1fc0]
  0x01662baf, 0x1821156f, 0x430f0213, 0x16001d11,
  0x03196608, 0x030c0112, 0x0e251c08, 0x29181d13,
  0x66000320, 0x0000192d, 0x450f12af, 0x29212b12,
  0x66191009, 0x1f2b1021, 0x1d6627af, 0x1900100d,
  // [1fd0]
  0x450106a4, 0x04061060, 0x01271aaf, 0x45151255,
  0x170d16a4, 0x100c40a4, 0x08000508, 0x16381509,
  0x0e2330ad, 0x10000108, 0x1d0314a4, 0x04001002,
  0x04002907, 0x08172912, 0x220619ac, 0x1d403f09,
  // [1fe0]
  0x02060b55, 0x1d6601af, 0x2b0419a4, 0x0d1751af,
  0x274551a4, 0x0d291612, 0x66001412, 0x010d1607,
  0x18015112, 0x401d21bc, 0x0f0d2b09, 0x06036633,
  0x10380d60, 0x06010cad, 0x21000420, 0x0f0c0108,
  // [1ff0]
  0x0f000802, 0x450c0109, 0x2b1f0112, 0x0d0c0f02,
  0x0b036609, 0x080d0114, 0x16000f09, 0x08401621,
  0x15001d12, 0x301e1cac, 0x210d0f12, 0x1000191d,
  0x0d000f20, 0x01080f12, 0x16010da4, 0x27292113,

  // [2000]
  0x29182212, 0x040f0d13, 0x03010555, 0x0d040ba4,
  0x01451f07, 0x08004021, 0x1d163f60, 0x1c1e3012,
  0x22000602, 0x1e1c3021, 0x43042107, 0x66101212,
  0x30232508, 0x191801af, 0x03181909, 0x063803ac,
  // [2010]
  0x25301c22, 0x3f6619be, 0x01170507, 0x0d0f3faf,
  0x05081914, 0x301c2355, 0x05030809, 0x25003011,
  0x38001922, 0x38100d07, 0x03270112, 0x03083809,
  0x05660322, 0x0366066f, 0x43010f07, 0x40124507,
  // [2020]
  0x06030109, 0x06010b07, 0x1d120c07, 0x19001022,
  0x1d124011, 0x380d0f22, 0x0d0b5107, 0x17001d21,
  0x16451d55, 0x40004508, 0x38001d09, 0x012927a4,
  0x05011960, 0x21432913, 0x04080f09, 0x1c251e14,
  // [2030]
  0x01082907, 0x10180b08, 0x38450807, 0x03001807,
  0x04660360, 0x170d0f08, 0x080f3808, 0x08380f55,
  0x10001909, 0x450c01ac, 0x0f0d1f60, 0x17001f11,
  0x01062b07, 0x03000807, 0x016608ad, 0x27002911,
  // [2040]
  0x08013808, 0x036619af, 0x10190407, 0x10190460,
  0x251c0e55, 0x10190411, 0x1c1e25a4, 0x1c2523a4,
  0x29182109, 0x23003014, 0x043829a4, 0x010616af,
  0x1e1c23a4, 0x29272114, 0x271829af, 0x04101907,
  // [2050]
  0x231e0eaf, 0x19041508, 0x660312af, 0x100622a4,
  0x02032107, 0x66042709, 0x382729af, 0x05381722,
  0x14020ba4, 0x08193809, 0x16000821, 0x10060f21,
  0x27173834, 0x010d04bb, 0x2b1f0111, 0x0d150fac,
  // [2060]
  0x010b5107, 0x12401d11, 0x0d2b0f12, 0x06001014,
  0x38080d21, 0x2b0d29a4, 0x01170d08, 0x38010612,
  0x03050807, 0x0d000802, 0x01292b12, 0x0b660209,
  0x06000523, 0x05001620, 0x01000f09, 0x050108a4,
  // [2070]
  0x080f3809, 0x19001407, 0x22211921, 0x21450baf,
  0x3f1d1921, 0x0d012907, 0x02010b07, 0x16213f23,
  0x22190412, 0x012b06a4, 0x010221af, 0x01171921,
  0x213f0c08, 0x29273809, 0x16270108, 0x3f192108,
  // [2080]
  0x010321af, 0x04036608, 0x0c000613, 0x19004502,
  0x0d030f07, 0x03000c02, 0x1d180d09, 0x03010607,
  0x231e3012, 0x22000313, 0x04190620, 0x12401d6f,
  0x250e2312, 0x0c001802, 0x18161d09, 0x161d45a4,
  // [2090]
  0x381601a4, 0x0b190207, 0x38290412, 0x38001502,
  0x020f27a4, 0x1d032709, 0x06292720, 0x16292708,
  0x030151a4, 0x0e251e07, 0x12140308, 0x0f0c40af,
  0x080c1d09, 0x041516a4, 0x66220112, 0x01220802,
  // [20a0]
  0x0f010307, 0x03272913, 0x080566a4, 0x27293f23,
  0x01660355, 0x14272908, 0x0f0601af, 0x010c0807,
  0x43454002, 0x05081713, 0x04272960, 0x080106af,
  0x66002109, 0x06031fa4, 0x16001522, 0x19292711,
  // [20b0]
  0x04001511, 0x0c0314ad, 0x45021412, 0x12004302,
  0x15001623, 0x160f21af, 0x451d01af, 0x170d0813,
  0x02431002, 0x07005c35, 0x0f1d3fad, 0x14031009,
  0x04196612, 0x08050f07, 0x08010611, 0x101d1407,
  // [20c0]
  0x0e1e2314, 0x0d083809, 0x01380d55, 0x18000d11,
  0x18003f11, 0x010d17a4, 0x1e2530ad, 0x0d080113,
  0x01273f12, 0x080d2107, 0x3f081422, 0x0e1e3021,
  0x301e2512, 0x01051909, 0x010627a4, 0x00001e2d,
  // [20d0]
  0x0b021d09, 0x45120c22, 0x15001d13, 0x01060311,
  0x14002212, 0x16152111, 0x03193f11, 0x451d1909,
  0x0b194009, 0x05030813, 0x19001d12, 0x45000d09,
  0x1f000612, 0x0c064021, 0x0c00061f, 0x01000613,
  // [20e0]
  0x45120621, 0x2b001412, 0x22004008, 0x43661f55,
  0x0d450809, 0x231e1c07, 0x23250ead, 0x10180baf,
  0x1d0b0209, 0x1d060c60, 0x0c002107, 0x010638a4,
  0x1c230ebc, 0x1f000621, 0x1d400b12, 0x16182b09,
  // [20f0]
  0x16380f08, 0x17001502, 0x380551af, 0x17050baf,
  0x43272913, 0x18000122, 0x05381709, 0x05002108,
  0x29212713, 0x0b013809, 0x270f0112, 0x0e302312,
  0x1f004321, 0x231e25ad, 0x27212914, 0x050c0411,
  // [2100]
  0x16010ca4, 0x1e3023be, 0x02061707, 0x12002111,
  0x051d0409, 0x06001502, 0x06001607, 0x45004302,
  0x06012708, 0x06000208, 0x270f0512, 0x05012108,
  0x022201af, 0x23251e07, 0x020c0507, 0x15400808,
  // [2110]
  0x272219a4, 0x19223f09, 0x190f0407, 0x02160d13,
  0x27062909, 0x01020620, 0x140229af, 0x0d140209,
  0x02001012, 0x0d0f2212, 0x030d2212, 0x0e253013,
  0x381d0207, 0x0b660308, 0x01030612, 0x21221709,
  // [2120]
  0x02000807, 0x2b0222be, 0x19022221, 0x1e300ea4,
  0x30231ca4, 0x230e3012, 0x0f270809, 0x230e1caf,
  0x16001509, 0x251e1c55, 0x06014502, 0x0e2330a4,
  0x0b0266af, 0x01081509, 0x03020112, 0x012b1f6f,
  // [2130]
  0x080c1f07, 0x380103a4, 0x1f000614, 0x21002709,
  0x100c0308, 0x17010355, 0x38001507, 0x380c1fac,
  0x1f380fbe, 0x08000414, 0x08000f02, 0x660f0d13,
  0x16004508, 0x0f0103a4, 0x100166af, 0x27010312,
  // [2140]
  0x43001412, 0x380f03af, 0x05006608, 0x18002109,
  0x45012155, 0x010f1f08, 0x08000d21, 0x160f0d13,
  0x660f0d09, 0x17190513, 0x03001511, 0x03002208,
  0x1d041907, 0x45021609, 0x02010f09, 0x05000309,
  // [2150]
  0x27292114, 0x151945af, 0x05040109, 0x19011607,
  0x06006620, 0x10002b11, 0x0c0f3814, 0x3f210509,
  0x030501af, 0x30231e11, 0x10660608, 0x0c401509,
  0x170c0309, 0x17000311, 0x22002113, 0x081d3812,
  // [2160]
  0x06010560, 0x1d0501af, 0x0c173855, 0x02050109,
  0x38080c12, 0x21226609, 0x43290108, 0x12003807,
  0x02006613, 0x12154511, 0x04083fad, 0x0c000b07,
  0x1d292708, 0x10030baf, 0x100b1909, 0x1d001009,
  // [2170]
  0x19001721, 0x382b0302, 0x120b1011, 0x01220807,
  0x16001521, 0x05062707, 0x1f000309, 0x5c000712,
  0x230e1c22, 0x22162109, 0x27041960, 0x03060412,
  0x401d3fbe, 0x19040d13, 0x04030655, 0x1f3f6609,
  // [2180]
  0x03156609, 0x02061009, 0x1c1e2322, 0x230e1e08,
  0x1e0e1c09, 0x10221408, 0x04190608, 0x031966af,
  0x18000c09, 0x01170802, 0x1c230ead, 0x301c2509,
  0x1c001e08, 0x0000100a, 0x22181008, 0x45121d07,
  // [2190]
  0x19000611, 0x17060509, 0x12660311, 0x29051709,
  0x1f001213, 0x03050da4, 0x14004509, 0x17003802,
  0x1d001407, 0x12000309, 0x17001608, 0x0e1c1e08,
  0x0600100d, 0x101822bc, 0x1766036f, 0x161d4013,
  // [21a0]
  0x10040ba4, 0x10040b07, 0x010805be, 0x060c3fbc,
  0x011f0812, 0x18002214, 0x38026613, 0x300e2555,
  0x04003f11, 0x0e301e12, 0x400f45af, 0x010b0607,
  0x30230e23, 0x02001412, 0x160366a4, 0x14380f09,
  // [21b0]
  0x15164023, 0x010405a4, 0x12151607, 0x17212914,
  0x030166ad, 0x04001409, 0x12451d08, 0x0f0d0807,
  0x190b06ac, 0x300e2312, 0x0d661aa4, 0x05061007,
  0x14001814, 0x21002213, 0x16001535, 0x2b006613,
  // [21c0]
  0x0b436608, 0x12450f07, 0x0b141807, 0x18036620,
  0x66001713, 0x14180612, 0x19272121, 0x06080508,
  0x400c12af, 0x04192109, 0x04003f21, 0x010c0813,
  0x0d061707, 0x401d0402, 0x0c0117af, 0x1d6651af,
  // [21d0]
  0x100c0108, 0x170c0809, 0x04181007, 0x231e0e08,
  0x2b0c6612, 0x12401d21, 0x45121dad, 0x27212921,
  0x0c292108, 0x29274021, 0x06451fad, 0x08000c11,
  0x03001612, 0x250e3007, 0x12161dac, 0x15001d21,
  // [21e0]
  0x0b380d20, 0x06100308, 0x12184507, 0x45001613,
  0x16001d08, 0x08051f12, 0x04191412, 0x020b5107,
  0x1c0e1eaf, 0x1e252309, 0x140c1008, 0x14001014,
  0x18001514, 0x292740a4, 0x0b050855, 0x03001907,
  // [21f0]
  0x121d1612, 0x08661713, 0x251c2312, 0x05001613,
  0x18140460, 0x0f042212, 0x15170811, 0x15162709,
  0x01381408, 0x171d0daf, 0x17401d60, 0x020c0112,
  0x17120da4, 0x10001602, 0x0b000204, 0x12401611,
  // [2200]
  0x15000c13, 0x0310665e, 0x12221d12, 0x38000520,
  0x430f1dac, 0x401245a4, 0x401d12a4, 0x011d2707,
  0x17001512, 0x04000112, 0x010d0307, 0x080c1da4,
  0x14000221, 0x14001013, 0x17430607, 0x0c1d3f12,
  // [2210]
  0x0d012908, 0x400c1da4, 0x380f0411, 0x0c002210,
  0x1d2729af, 0x2b0103a4, 0x0c000f11, 0x0b2b6612,
  0x0f061007, 0x0b660255, 0x161d4011, 0x140b0208,
  0x06001032, 0x0c2b6607, 0x2200181f, 0x0d000112,
  // [2220]
  0x190b0112, 0x0b021407, 0x12021911, 0x1d003807,
  0x010651af, 0x45401d09, 0x04000512, 0x100b1407,
  0x16150112, 0x43006607, 0x19010313, 0x19020b11,
  0x05011f08, 0x05011712, 0x45001d14, 0x1f000f09,
  // [2230]
  0x16143f09, 0x02010302, 0x1d453faf, 0x16081d21,
  0x140f0d14, 0x0f030809, 0x04163faf, 0x40002913,
  0x032901ad, 0x1d0f0855, 0x45001509, 0x14000602,
  0x05062907, 0x1d144022, 0x04003807, 0x062927af,
  // [2240]
  0x0f081d09, 0x191d0408, 0x01020b22, 0x19100207,
  0x0d0117bb, 0x17000b02, 0x0d0f1fac, 0x10001402,
  0x29271812, 0x37004e10, 0x1d214012, 0x38660321,
  0x1e0e2309, 0x19000313, 0x381d0809, 0x19010307,
  // [2250]
  0x03176607, 0x450c2b20, 0x170366bc, 0x03170112,
  0x0e1c2513, 0x43001408, 0x15000c08, 0x050c66ac,
  0x01190d13, 0x45000c11, 0x160f3813, 0x08450c07,
  0x10450c12, 0x17000322, 0x050366be, 0x45380f09,
  // [2260]
  0x1e1c2313, 0x080c4555, 0x0c001810, 0x0f0c3809,
  0x380f0808, 0x06031fac, 0x43380607, 0x1c231e09,
  0x29002b12, 0x380f0d12, 0x0e302508, 0x0e1c2511,
  0x38143f21, 0x15003f12, 0x0b012b07, 0x1d4512af,
  // [2270]
  0x222b0308, 0x06020b07, 0x0b210213, 0x102b0baf,
  0x0e1e2308, 0x0d0f3812, 0x123f2912, 0x21193f21,
  0x0c222907, 0x301e1c12, 0x031d6613, 0x0d061912,
  0x01292711, 0x22003f12, 0x04082707, 0x19001820,
  // [2280]
  0x45060112, 0x010f0307, 0x30232509, 0x0f3801a4,
  0x16172712, 0x0b0214ac, 0x103f2911, 0x020b1022,
  0x27001911, 0x17010313, 0x1f000509, 0x03661921,
  0x10001212, 0x251e0ea4, 0x43032907, 0x14292108,
  // [2290]
  0x661f05af, 0x45001607, 0x1c003022, 0x17430d08,
  0x18002913, 0x401d3fa4, 0x12194009, 0x19001814,
  0x14194008, 0x0d121f07, 0x01001802, 0x0f080612,
  0x1d4018af, 0x01221807, 0x181d19af, 0x21040baf,
  // [22a0]
  0x38011907, 0x050301a4, 0x01190f07, 0x18066609,
  0x1f3f0112, 0x01060dac, 0x0e3023bc, 0x29223f13,
  0x01080f09, 0x05062207, 0x1d002214, 0x05272912,
  0x18291908, 0x06665112, 0x0319666f, 0x273f2909,
  // [22b0]
  0x0f010512, 0x0c0501a4, 0x0d043f14, 0x05210d09,
  0x16000c08, 0x052b0102, 0x0c001212, 0x033f0113,
  0x190166ad, 0x15053808, 0x38292711, 0x19122712,
  0x05010308, 0x18000212, 0x040c2755, 0x0d0f0813,
  // [22c0]
  0x0e251c11, 0x00000e2d, 0x08380f21, 0x40190408,
  0x251c1e12, 0x451d0812, 0x1c230e02, 0x1d002211,
  0x1d0840a4, 0x04401da4, 0x10381707, 0x401d1912,
  0x0d000809, 0x08001d07, 0x23251c12, 0x251e23af,
  // [22d0]
  0x15190808, 0x1e252313, 0x0b010602, 0x38080d09,
  0x08060507, 0x020b2b07, 0x08105112, 0x08050fa4,
  0x40000823, 0x190804ac, 0x450d0f08, 0x22000b02,
  0x163801a4, 0x21001709, 0x05010fa4, 0x38030809,
  // [22e0]
  0x182b1012, 0x2b020ba4, 0x05430108, 0x06140407,
  0x013f2b13, 0x05000d09, 0x400366a4, 0x1d454060,
  0x230e1e02, 0x0c0138ac, 0x27000d12, 0x03010808,
  0x0c124522, 0x12454012, 0x40291013, 0x12150d13,
  // [22f0]
  0x43010d07, 0x45004021, 0x25231e13, 0x1c0e1e34,
  0x1d000c11, 0x230e3008, 0x06101407, 0x1c0e235e,
  0x01051207, 0x040d1709, 0x1c250eaf, 0x010d0512,
  0x042b0b55, 0x19142707, 0x176603af, 0x10040112,
  // [2300]
  0x04000502, 0x45120521, 0x19011dac, 0x23001c09,
  0x14451813, 0x0d050f09, 0x03050255, 0x380d0f60,
  0x0f0501af, 0x2b0601ac, 0x06180507, 0x370e23bb,
  0x10030611, 0x02060ba4, 0x04451509, 0x02000514,
  // [2310]
  0x16140fa4, 0x05000209, 0x45401d22, 0x013805af,
  0x66020313, 0x30002509, 0x010d2712, 0x1e002323,
  0x231e25ac, 0x380d0faf, 0x251c2309, 0x1e003014,
  0x0e302308, 0x45000d08, 0x03220c07, 0x0c1d4011,
  // [2320]
  0x0c004522, 0x0d380fa4, 0x01002708, 0x273f2912,
  0x23301cac, 0x124517a4, 0x12002909, 0x17272909,
  0x250e1c11, 0x45000c07, 0x1d4015be, 0x043f2160,
  0x0c001613, 0x12000c11, 0x30231c09, 0x170d1fad,
  // [2330]
  0x0b001023, 0x19001720, 0x153805af, 0x05001021,
  0x1f004021, 0x013805a4, 0x2b000508, 0x05010f08,
  0x0e251e08, 0x10153860, 0x38000113, 0x19181655,
  0x03196613, 0x04100308, 0x0d001007, 0x02000b34,
  // [2340]
  0x08001511, 0x15001d08, 0x05011509, 0x2b211aaf,
  0x18002b14, 0x38010521, 0x19000507, 0x0d3801af,
  0x19002b02, 0x27180112, 0x19145112, 0x0f003813,
  0x45124013, 0x02221212, 0x1d010fa4, 0x30001e02,
  // [2350]
  0x27294521, 0x16006608, 0x66001820, 0x0f1402af,
  0x0c1d0809, 0x01080507, 0x0c002123, 0x060127a4,
  0x380f0814, 0x19001520, 0x05086609, 0x2b0106af,
  0x192b14ad, 0x17000808, 0x21222b21, 0x120c40ad,
  // [2360]
  0x301c2512, 0x0b0d0207, 0x041805bb, 0x251e2312,
  0x16182707, 0x12001612, 0x06041812, 0x1f2129af,
  0x0d1f0112, 0x05030109, 0x23300e13, 0x18000512,
  0x18000522, 0x0d012909, 0x05001822, 0x01000521,
  // [2370]
  0x05001823, 0x05002109, 0x29402709, 0x231e0e13,
  0x051d3fad, 0x01001008, 0x1d292711, 0x0e231c12,
  0x022927ad, 0x04000207, 0x1f060809, 0x16004002,
  0x25003012, 0x04060307, 0x01080313, 0x01066612,
  // [2380]
  0x10220112, 0x2b030b20, 0x01002220, 0x08041912,
  0x0d0f27ad, 0x040210ac, 0x1d000f08, 0x012b0811,
  0x29151012, 0x2b001f12, 0x14000308, 0x1d0c40a4,
  0x030f0da4, 0x031d01af, 0x19292712, 0x19060407,
  // [2390]
  0x0d0f1002, 0x06100355, 0x661f0112, 0x0d001912,
  0x04020baf, 0x051801a4, 0x06036621, 0x22030621,
  0x1d002223, 0x0f180d55, 0x450b1d12, 0x380508ac,
  0x0f0108a4, 0x1c2330a4, 0x14000d02, 0x04020b13,
  // [23a0]
  0x01000812, 0x031504ac, 0x046629af, 0x040366bc,
  0x400d0f12, 0x66002713, 0x12451413, 0x062201af,
  0x0c001607, 0x1d401614, 0x27662260, 0x0b020312,
  0x0e1e2320, 0x03660220, 0x021d03a4, 0x66031914,
  // [23b0]
  0x196603bc, 0x0f002113, 0x06002710, 0x19030407,
  0x22001807, 0x03101d08, 0x06000f07, 0x020b27af,
  0x01060d55, 0x301e25ad, 0x06190baf, 0x05000811,
  0x29061921, 0x29273f13, 0x14190260, 0x02190baf,
  // [23c0]
  0x060201af, 0x27222912, 0x02003f11, 0x01050802,
  0x06003820, 0x66000812, 0x06002b20, 0x06193f12,
  0x45001f13, 0x030b0209, 0x12450fbb, 0x1e2325ad,
  0x404566a4, 0x01192912, 0x271d2909, 0x301e2509,
  // [23d0]
  0x12100112, 0x45000d02, 0x0d0f18a4, 0x45120cbe,
  0x3f001914, 0x08180112, 0x1e000e09, 0x0b002108,
  0x08001711, 0x430d1207, 0x40660355, 0x10000107,
  0x2b4003a4, 0x27163f12, 0x0d010309, 0x66100309,
  // [23e0]
  0x2b036660, 0x0b660307, 0x15030208, 0x45400c02,
  0x0f0366ad, 0x06273808, 0x011227a4, 0x0f124555,
  0x040f15ac, 0x100501a4, 0x0000160a, 0x1d4015af,
  0x1d044008, 0x120b0202, 0x08380f02, 0x060366a4,
  // [23f0]
  0x18004307, 0x14020baf, 0x14661908, 0x14272912,
  0x1d000408, 0x03062907, 0x38016608, 0x060501ac,
  0x38450611, 0x181027af, 0x0b4066a4, 0x010508bc,
  0x140b0222, 0x173f0220, 0x0f001214, 0x38011709,

  // [2400]
  0x04002113, 0x15001608, 0x15000621, 0x38081fbc,
  0x1f000809, 0x12180f09, 0x0b272112, 0x1d191221,
  0x1d000d07, 0x161d0309, 0x12000f08, 0x080d1daf,
  0x08001520, 0x29272113, 0x1f380808, 0x222729af,
  // [2410]
  0x19042707, 0x0f100d02, 0x151d4012, 0x0f170d08,
  0x45004011, 0x66002b21, 0x043f0521, 0x04001211,
  0x15000420, 0x01380512, 0x22181910, 0x14004313,
  0x16006609, 0x0d0f38cf, 0x04003821, 0x02210112,
  // [2420]
  0x10000c10, 0x0f3817a4, 0x22003f11, 0x38000602,
  0x17194009, 0x0f053855, 0x27222909, 0x27380d09,
  0x17053809, 0x04151660, 0x05001421, 0x251c1e08,
  0x062b1f07, 0x40161d07, 0x040b02a4, 0x10060209,
  // [2430]
  0x04191007, 0x220302a4, 0x01050360, 0x10004513,
  0x301c1e21, 0x124518bb, 0x430f0112, 0x0f010807,
  0x014003ad, 0x050103a4, 0x45001412, 0x0c061621,
  0x12001808, 0x0d010faf, 0x230e1e13, 0x38012108,
  // [2440]
  0x18000614, 0x0b062907, 0x060b0255, 0x0d0f0808,
  0x1d002709, 0x01450807, 0x10001935, 0x0c003f20,
  0x17380807, 0x01002223, 0x1d0266a4, 0x1d0b1714,
  0x06030112, 0x22121709, 0x220201a4, 0x25233002,
  // [2450]
  0x451229a4, 0x16451d02, 0x184512af, 0x02100b23,
  0x0f050d02, 0x061701af, 0x661d0608, 0x1c302520,
  0x080f1708, 0x18004312, 0x0d1418ad, 0x0f380808,
  0x2b003809, 0x17013807, 0x0f184509, 0x0c082707,
  // [2460]
  0x10001414, 0x0f1d4512, 0x19031007, 0x0d270114,
  0x01000520, 0x12000f11, 0x0f292b12, 0x062b0308,
  0x170c0d11, 0x1e302312, 0x10272955, 0x05451212,
  0x45000502, 0x100b0302, 0x45120f14, 0x1214456f,
  // [2470]
  0x181d4008, 0x211451af, 0x0c1d4511, 0x1d450c14,
  0x1c0e1e14, 0x06003f13, 0x17080512, 0x380f1f13,
  0x01224009, 0x081d4007, 0x08000521, 0x0e231c21,
  0x18000f11, 0x0e233014, 0x27173812, 0x1e1c0e60,
  // [2480]
  0x081d1507, 0x08010555, 0x15003f13, 0x08401d60,
  0x052201a4, 0x401d2114, 0x17120d07, 0x081d4060,
  0x04192908, 0x0d1d4007, 0x19022155, 0x12043f60,
  0x45121f12, 0x04002714, 0x030f1209, 0x19001009,
  // [2490]
  0x2b660312, 0x660601af, 0x06030baf, 0x06010307,
  0x0b020309, 0x17000f14, 0x17292112, 0x0b010308,
  0x16001d22, 0x01100baf, 0x0c273812, 0x290f0d13,
  0x03660614, 0x0d0f0512, 0x066603ad, 0x0d0f3823,
  // [24a0]
  0x14000120, 0x271951af, 0x190401af, 0x12451d21,
  0x12000508, 0x15170808, 0x250e1e14, 0x1f1d166f,
  0x042927a4, 0x02100bce, 0x05010812, 0x03060807,
  0x451d1207, 0x23003020, 0x01050809, 0x0b012907,
  // [24b0]
  0x06101412, 0x17000202, 0x04010807, 0x060b10af,
  0x05000820, 0x01050808, 0x19031011, 0x01124507,
  0x030629a4, 0x05000807, 0x12450f09, 0x10180207,
  0x020b2107, 0x191d4007, 0x3f662b14, 0x03002b07,
  // [24c0]
  0x1d400ca4, 0x17081555, 0x40001002, 0x0d012107,
  0x020503a4, 0x19042160, 0x043f2121, 0x43010407,
  0x66002213, 0x19001713, 0x04002120, 0x160219a4,
  0x0e1e1c07, 0x050601ad, 0x0c000409, 0x22001d11,
  // [24d0]
  0x27401dbe, 0x12003f12, 0x0f0d1707, 0x191d2709,
  0x04003f23, 0x162729af, 0x05380f07, 0x220129a4,
  0x01060502, 0x0e001c35, 0x2b663f13, 0x120c4555,
  0x1e232512, 0x0d1d1212, 0x401d1213, 0x08041908,
  // [24e0]
  0x04021009, 0x06140bad, 0x160419be, 0x1d2908af,
  0x0d050fa4, 0x04193faf, 0x27291721, 0x05010c07,
  0x06272908, 0x12004020, 0x0c403f12, 0x16000108,
  0x2b660112, 0x19002913, 0x0b140dac, 0x160166a4,
  // [24f0]
  0x17062b07, 0x222b3807, 0x0e302322, 0x0c000d07,
  0x23300e55, 0x03066608, 0x23002523, 0x1c0e30a4,
  0x0e002321, 0x0d0638a4, 0x0000240a, 0x1f003f14,
  0x38400d07, 0x0b0206af, 0x30002507, 0x061f03af,
  // [2500]
  0x0f000512, 0x10660607, 0x22001007, 0x660319bb,
  0x03020107, 0x1c0e3011, 0x19031f55, 0x18191709,
  0x1d404555, 0x0e233011, 0x66101912, 0x1c0e2320,
  0x2b010607, 0x12000511, 0x03156607, 0x22151f09,
  // [2510]
  0x270d0c60, 0x45000512, 0x0c011d12, 0x270f06ad,
  0x23251e6f, 0x08001420, 0x38180f12, 0x0c403fad,
  0x27010812, 0x40082712, 0x0d081fbe, 0x05081f12,
  0x08051f08, 0x01061707, 0x08002907, 0x1d0c2707,
  // [2520]
  0x38010d08, 0x29270813, 0x166602af, 0x060b0209,
  0x66160f12, 0x0f400807, 0x213f27af, 0x1d041707,
  0x01002909, 0x0b1017ad, 0x1e1c3002, 0x1d080f08,
  0x0f170d02, 0x050f0813, 0x17080108, 0x06001412,
  // [2530]
  0x1c002502, 0x0c002213, 0x02081902, 0x15221412,
  0x66431f09, 0x04100107, 0x12004536, 0x150538ad,
  0x15033807, 0x18001207, 0x01053812, 0x1c1e23af,
  0x21100b20, 0x0c453f12, 0x0c0b0d08, 0x25000e22,
  // [2540]
  0x1d0c0508, 0x03100608, 0x191503a4, 0x08220f09,
  0x1c0e1e21, 0x06100b07, 0x060f0808, 0x061d0102,
  0x1d290f08, 0x08053fac, 0x66000608, 0x0c001502,
  0x01100607, 0x17181608, 0x062b66a4, 0x1c002309,
  // [2550]
  0x08170308, 0x66063f12, 0x100b01a4, 0x060210ad,
  0x660b0208, 0x014327a4, 0x060366ac, 0x032b06ad,
  0x433f0112, 0x08170509, 0x05012b02, 0x1c302511,
  0x221001af, 0x0c190209, 0x0d163f12, 0x180314af,
  // [2560]
  0x040d0f12, 0x191451af, 0x66150baf, 0x100f1921,
  0x18000407, 0x0f0d1013, 0x0c0f2707, 0x2b0614af,
  0x0d142113, 0x03020b11, 0x66033f12, 0x080f0dbe,
  0x45050f08, 0x08041921, 0x0f1905ac, 0x08171914,
  // [2570]
  0x041917ad, 0x220d0f14, 0x04170507, 0x16001412,
  0x0c000f07, 0x0d191021, 0x0f080dbe, 0x15190809,
  0x293f0660, 0x04000b07, 0x3f142712, 0x0d3f0f14,
  0x400819ad, 0x106651af, 0x25001e20, 0x171d2707,
  // [2580]
  0x10013f09, 0x02145112, 0x18140312, 0x451d40ad,
  0x16031955, 0x06030b12, 0x19002202, 0x0b054009,
  0x1d0817bc, 0x03380f07, 0x38000f11, 0x03000f07,
  0x1d0d3f09, 0x401d0808, 0x29061821, 0x031d4008,
  // [2590]
  0x66220314, 0x0d180fa4, 0x38010312, 0x02062109,
  0x16000c14, 0x02292708, 0x0d0f2709, 0x19451509,
  0x2b151808, 0x40002b12, 0x0e2325a4, 0x0f170112,
  0x0c380f12, 0x45121fa4, 0x1c2325a4, 0x25000e21,
  // [25a0]
  0x0b190407, 0x010f0d07, 0x43001f13, 0x02272913,
  0x5c00070e, 0x1d1501a4, 0x23001e09, 0x06014302,
  0x380f12af, 0x150c2709, 0x1e001c13, 0x1c1e25ac,
  0x03191007, 0x06142907, 0x301e2511, 0x013f1f08,
  // [25b0]
  0x430151af, 0x1f003f09, 0x2b004320, 0x3f001922,
  0x3f050112, 0x04000f02, 0x0e231ead, 0x06190308,
  0x0d000f10, 0x020366ad, 0x45004009, 0x01192107,
  0x06011f21, 0x01001811, 0x66001f12, 0x16002912,
  // [25c0]
  0x022b1023, 0x2b0b1012, 0x011d3f08, 0x18000f14,
  0x45164009, 0x22000b13, 0x02102b12, 0x052b2213,
  0x170b22a4, 0x292b0112, 0x01006612, 0x080501a4,
  0x3f001714, 0x380f1809, 0x0f0c29a4, 0x01270812,
  // [25d0]
  0x052201af, 0x01060b02, 0x03001911, 0x38193f12,
  0x04190111, 0x251e1c60, 0x063f6609, 0x1d050112,
  0x0e1e1c14, 0x251e1c23, 0x03000408, 0x12450409,
  0x23251c07, 0x15000c11, 0x0e1c2502, 0x05380f08,
  // [25e0]
  0x0c001f08, 0x1f002713, 0x14061060, 0x1c1e30ad,
  0x1d001602, 0x27003f12, 0x401508af, 0x100615bc,
  0x12001907, 0x08002713, 0x0e2325ad, 0x22173813,
  0x0e3023ad, 0x15142ba4, 0x01120809, 0x1c0e2307,
  // [25f0]
  0x1d024055, 0x08001411, 0x401d2708, 0x1d010809,
  0x1d382b09, 0x0b0c1012, 0x04011212, 0x1e002322,
  0x1e1c25be, 0x271d406f, 0x011d406f, 0x04183fad,
  0x29001521, 0x03190607, 0x220f3807, 0x172212af,
  // [2600]
  0x1d002913, 0x0c0f0d09, 0x0c036613, 0x020b0dbe,
  0x401d2bbb, 0x011d4511, 0x02011d09, 0x0d4051a4,
  0x050d0fad, 0x0c000333, 0x16000612, 0x01020b33,
  0x2b000513, 0x05010c09, 0x0f002713, 0x0c001602,
  // [2610]
  0x19003f07, 0x0f660509, 0x25231e22, 0x053801ad,
  0x66000512, 0x0d000114, 0x120f4502, 0x27162913,
  0x19451702, 0x19174007, 0x45180d12, 0x02180608,
  0x03146607, 0x1e302509, 0x222729be, 0x14100b60,
  // [2620]
  0x40223fad, 0x106603a4, 0x1c2325be, 0x432206a4,
  0x0c220b07, 0x1e230ead, 0x2b001621, 0x0b660314,
  0x0b196612, 0x2b001633, 0x10060308, 0x2b001613,
  0x060c0102, 0x29182712, 0x0b0501a4, 0x38001007,
  // [2630]
  0x17430d09, 0x171566a4, 0x270f2213, 0x041910a4,
  0x011d4009, 0x0b000611, 0x300e1c09, 0x0b140112,
  0x031d0cbb, 0x0c000212, 0x120501ad, 0x054501a4,
  0x2b060512, 0x1c0e2508, 0x02001421, 0x29000d12,
  // [2640]
  0x020127a4, 0x45040209, 0x45120107, 0x0d061460,
  0x121f0109, 0x01451214, 0x430103a4, 0x040b1009,
  0x07005c1f, 0x02384309, 0x010f3808, 0x10080307,
  0x1f002b21, 0x18000208, 0x050627a4, 0x01042b12,
  // [2650]
  0x14180808, 0x012227af, 0x0f0105af, 0x27291712,
  0x10002712, 0x01042707, 0x153f2222, 0x172729af,
  0x1d170407, 0x01062b12, 0x15181607, 0x38081712,
  0x0b180409, 0x22292720, 0x173f2913, 0x29001721,
  // [2660]
  0x0d0f2707, 0x011f2b07, 0x17003f14, 0x1d020caf,
  0x22010460, 0x04401702, 0x1d161721, 0x06003808,
  0x27172121, 0x18001f20, 0x12001f07, 0x27192922,
  0x66004021, 0x01153807, 0x0b0318a4, 0x10041913,
  // [2670]
  0x06006609, 0x0c124514, 0x05010808, 0x0f450502,
  0x2b100808, 0x03143812, 0x66192912, 0x273f1921,
  0x150d2b12, 0x12180f13, 0x12451daf, 0x0b1003bb,
  0x0e301cbc, 0x031f0f08, 0x18022709, 0x1c300e14,
  // [2680]
  0x18000609, 0x40121d09, 0x17080da4, 0x16002722,
  0x15001923, 0x174515a4, 0x45121f11, 0x1e001c21,
  0x10002b07, 0x0c270baf, 0x19660412, 0x0f081f12,
  0x060105af, 0x100c0209, 0x230e3021, 0x251e2321,
  // [2690]
  0x40001820, 0x06000421, 0x0c060109, 0x0d002212,
  0x0b2212af, 0x10030509, 0x0529276f, 0x27662921,
  0x0d292713, 0x06293fad, 0x0c1d0b09, 0x380829a4,
  0x04003f34, 0x21000812, 0x012708af, 0x0d032209,
  // [26a0]
  0x401d21af, 0x270f0d09, 0x0c1d4013, 0x06012908,
  0x052901af, 0x0f171621, 0x04401d14, 0x271d2921,
  0x061d17a4, 0x29400409, 0x1d143f13, 0x2b001020,
  0x10400b07, 0x05000307, 0x010829a4, 0x1d0d2909,
  // [26b0]
  0x0c150314, 0x1d104014, 0x21003f22, 0x050d0f12,
  0x06001f13, 0x21003f23, 0x15100b14, 0x1c232560,
  0x1c1e0e13, 0x292221bc, 0x060d27a4, 0x270f29af,
  0x0d271d11, 0x050d0f13, 0x0d002b11, 0x0d0105af,
  // [26c0]
  0x0c1d4014, 0x1d0d4512, 0x19031402, 0x450c12af,
  0x21001622, 0x01272908, 0x1d000208, 0x08000102,
  0x0c0b1002, 0x0c120212, 0x10050407, 0x12001711,
  0x1d401908, 0x0b104014, 0x050112af, 0x45060111,
  // [26d0]
  0x14000b23, 0x0b6602ad, 0x0c040607, 0x66030613,
  0x18191721, 0x02060b60, 0x04001212, 0x10452707,
  0x0b0217af, 0x27291713, 0x29170112, 0x29191713,
  0x2b060102, 0x291722bc, 0x27001720, 0x03020b55,
  // [26e0]
  0x14002709, 0x291821af, 0x21002721, 0x18001721,
  0x22661760, 0x272917ce, 0x12001810, 0x27220421,
  0x05060d09, 0x29271721, 0x38001907, 0x43010660,
  0x0f0d1721, 0x030d0b12, 0x011706ac, 0x03000b11,
  // [26f0]
  0x38100213, 0x14006622, 0x0d000321, 0x030f3809,
  0x05065112, 0x10060b09, 0x401d2221, 0x05011d09,
  0x1d184012, 0x0c291712, 0x291d10af, 0x03063f12,
  0x0e002336, 0x17062207, 0x10000102, 0x21023f12,
  // [2700]
  0x0f1d2912, 0x0b222955, 0x15190d08, 0x15002220,
  0x27050112, 0x661f3faf, 0x01000f22, 0x0b181f11,
  0x180108af, 0x02140b13, 0x38000f09, 0x08060107,
  0x0d050807, 0x080f0da4, 0x16272112, 0x30232512,
  // [2710]
  0x0b3806a4, 0x08380f20, 0x17010807, 0x06140b08,
  0x2b0f1920, 0x66100baf, 0x2b001933, 0x14001808,
  0x222719a4, 0x19001213, 0x06003802, 0x162b1f09,
  0x02001911, 0x19000802, 0x1c301eaf, 0x38000107,
  // [2720]
  0x1f002b20, 0x0d051755, 0x1f0601a4, 0x01001412,
  0x1c232521, 0x12001f08, 0x19105112, 0x1f000f13,
  0x181f3f09, 0x10292708, 0x0c1245bb, 0x2b190213,
  0x1e301c07, 0x080f1907, 0x22193807, 0x01101412,
  // [2730]
  0x12164508, 0x0c010209, 0x19100b07, 0x10272908,
  0x19102707, 0x0d272112, 0x0e233020, 0x2b0f3809,
  0x3f2729be, 0x18100307, 0x06001508, 0x22212712,
  0x171821ce, 0x0f292711, 0x0c1738af, 0x660b0309,
  // [2740]
  0x40452109, 0x3f292722, 0x27012208, 0x29062712,
  0x0d010f07, 0x060804a4, 0x0b1451af, 0x0c660311,
  0x1d402712, 0x383f2912, 0x060f2113, 0x1d004509,
  0x06010f09, 0x380b01af, 0x18001f07, 0x190b04a4,
  // [2750]
  0x0b0f2107, 0x19153808, 0x10140b08, 0x04191534,
  0x3f220b12, 0x0b061009, 0x0b145111, 0x0c011d09,
  0x0e002514, 0x082b14a4, 0x08010607, 0x0b0201a4,
  0x05380808, 0x0d381055, 0x0f010d02, 0x0203666f,
  // [2760]
  0x0d060809, 0x06000c12, 0x27186609, 0x0e1c2308,
  0x033f0209, 0x12450c23, 0x22062908, 0x10060baf,
  0x101906ad, 0x01062909, 0x03126607, 0x031d0f07,
  0x15001614, 0x03061912, 0x23000e35, 0x0b100621,
  // [2770]
  0x05000313, 0x08380d12, 0x38400d09, 0x08170507,
  0x010f2112, 0x1d001920, 0x012227a4, 0x08380d13,
  0x01190655, 0x661006af, 0x0e251ebc, 0x19061209,
  0x0d184020, 0x380d0812, 0x40380d09, 0x080d3809,
  // [2780]
  0x1d000308, 0x10660b21, 0x0b140202, 0x17010d09,
  0x05000213, 0x0e1e1c12, 0x0c004002, 0x04191008,
  0x27451213, 0x01030407, 0x210d0111, 0x05011da4,
  0x14001720, 0x1c250e22, 0x1c1e23bc, 0x15100b09,
  // [2790]
  0x06036614, 0x080f2707, 0x19660308, 0x2b000d09,
  0x270b0208, 0x03086607, 0x05180808, 0x0d380809,
  0x2b0b1fa4, 0x0d291f08, 0x042b0307, 0x010827af,
  0x0b2227a4, 0x12001804, 0x06000808, 0x01380814,
  // [27a0]
  0x03000623, 0x02140612, 0x301c2521, 0x010b0255,
  0x0b061060, 0x03010f07, 0x02060d09, 0x3f1040bc,
  0x06100208, 0x02404512, 0x19380fac, 0x19150412,
  0x10003807, 0x231c2521, 0x04170d08, 0x1d292712,
  // [27b0]
  0x17001902, 0x45001011, 0x401d1207, 0x66081509,
  0x030615a4, 0x23001e13, 0x06011407, 0x30251e55,
  0x0e003011, 0x06010355, 0x23301cbc, 0x01000609,
  0x01220312, 0x19213faf, 0x1c0e23bc, 0x66142b22,
  // [27c0]
  0x06292708, 0x211f2b12, 0x0f3805a4, 0x04290b08,
  0x020b2712, 0x382904af, 0x660305af, 0x03222909,
  0x0e231eaf, 0x02292711, 0x18272913, 0x22292713,
  0x04272914, 0x29003821, 0x06660c55, 0x29060508,
  // [27d0]
  0x38292722, 0x01221721, 0x1d190d55, 0x22082912,
  0x01214009, 0x03060802, 0x19022708, 0x0c001712,
  0x1d151712, 0x03000511, 0x27002212, 0x0c1722bb,
  0x08002207, 0x041929af, 0x1d290ca4, 0x06000f08,
  // [27e0]
  0x38000822, 0x03381f12, 0x050f3808, 0x01272922,
  0x450c1d12, 0x1d400312, 0x030b1f21, 0x06002112,
  0x19000b07, 0x1f002114, 0x06192160, 0x38002b12,
  0x1d040d07, 0x66190314, 0x0f1721bc, 0x05163f08,
  // [27f0]
  0x0d430112, 0x45000c13, 0x3f001621, 0x030105bc,
  0x01066608, 0x020f1f08, 0x19053808, 0x271f1960,
  0x06181508, 0x0b030408, 0x19661609, 0x030d18ad,
  0x293f27a4, 0x18190dad, 0x27001912, 0x27190112,

  // [2800]
  0x23251ebc, 0x404501af, 0x45400baf, 0x45001f11,
  0x452927a4, 0x0b024512, 0x17002708, 0x1403066f,
  0x66031f21, 0x03020413, 0x1d40456f, 0x430503af,
  0x141006ad, 0x25002321, 0x18004012, 0x401245af,
  // [2810]
  0x0f010d09, 0x01170811, 0x29060312, 0x16180460,
  0x22001f13, 0x121d0c55, 0x66004512, 0x0c4027a4,
  0x40000133, 0x1d012708, 0x01002712, 0x27120809,
  0x40221612, 0x15292720, 0x45060308, 0x291d4013,
  // [2820]
  0x05000602, 0x43011d12, 0x290d0112, 0x1d010609,
  0x030121af, 0x66060360, 0x080f0d08, 0x301e25ac,
  0x1d4001a4, 0x0f141807, 0x010619af, 0x1d402955,
  0x29003f21, 0x22001d07, 0x22002122, 0x123f1460,
  // [2830]
  0x170822af, 0x19002221, 0x08010b07, 0x2b0b1009,
  0x011d45af, 0x01041f13, 0x16406655, 0x050d3807,
  0x192b0612, 0x0f050107, 0x1f041909, 0x38050107,
  0x05012909, 0x03011daf, 0x2b001002, 0x190f0d07,
  // [2840]
  0x0d001213, 0x0b220412, 0x0f041608, 0x43000111,
  0x19210112, 0x04660812, 0x04001821, 0x12000d08,
  0x0e251e20, 0x0b2b0208, 0x0b1404af, 0x01063807,
  0x0b220421, 0x18100209, 0x2b050d07, 0x08011607,
  // [2850]
  0x660103a4, 0x01431d07, 0x122b0108, 0x0d2203a4,
  0x2b1f01af, 0x05001014, 0x1f001721, 0x381f0509,
  0x100b06ad, 0x40060207, 0x14012ba4, 0x02000314,
  0x19102b07, 0x01001902, 0x2b000422, 0x12023802,
  // [2860]
  0x21020612, 0x104301a4, 0x06102ba4, 0x22002b08,
  0x03002211, 0x190218bc, 0x1d000802, 0x1d000212,
  0x18003812, 0x02002b14, 0x1c302555, 0x22170d08,
  0x23251c09, 0x1d170607, 0x27021013, 0x0f001411,
  // [2870]
  0x14031014, 0x38661714, 0x0b1501af, 0x2b011713,
  0x100351a4, 0x031d0baf, 0x02000321, 0x23250eaf,
  0x0c380111, 0x03384007, 0x100b02be, 0x19030112,
  0x1e251cbc, 0x66030621, 0x27050111, 0x16106607,
  // [2880]
  0x050f1d08, 0x0f381f09, 0x1f000120, 0x0b100255,
  0x16450508, 0x1d172121, 0x16001511, 0x01296655,
  0x0c1d4060, 0x212b1f09, 0x180d0112, 0x1c0e25be,
  0x01101407, 0x1d400608, 0x141d0508, 0x21000413,
  // [2890]
  0x1d170807, 0x012b6655, 0x1d272911, 0x17012712,
  0x06002b11, 0x03160b12, 0x27662912, 0x100b0608,
  0x0e1c3007, 0x18001611, 0x1c231e08, 0x16002908,
  0x04380509, 0x0c152109, 0x43000509, 0x16001711,
  // [28a0]
  0x08160608, 0x08140107, 0x0b022b02, 0x05194512,
  0x270451a4, 0x0d2116bb, 0x16063f12, 0x2b036608,
  0x04036607, 0x1d272112, 0x25233022, 0x0f1838ad,
  0x030b10a4, 0x06050121, 0x011802af, 0x010517af,
  // [28b0]
  0x01000309, 0x1d0543ac, 0x03210112, 0x060366be,
  0x020b1707, 0x273f2113, 0x02036612, 0x12272960,
  0x400119ac, 0x04292121, 0x18001413, 0x3f292713,
  0x430f0802, 0x27293f60, 0x45001808, 0x06050155,
  // [28c0]
  0x22002121, 0x27292b14, 0x2715166f, 0x380f3fad,
  0x080b0407, 0x432b0107, 0x27290413, 0x01381821,
  0x1d103809, 0x0b064007, 0x37001e12, 0x061405a4,
  0x103801a4, 0x05013808, 0x38000114, 0x45031807,
  // [28d0]
  0x0d401807, 0x031f0111, 0x0c001611, 0x66020112,
  0x0f014507, 0x040b0811, 0x0c022207, 0x0b100214,
  0x27042912, 0x03060409, 0x03042912, 0x031666ad,
  0x010d0812, 0x230e1eaf, 0x14002b08, 0x27402909,
  // [28e0]
  0x020366bc, 0x12154512, 0x2b030baf, 0x02040baf,
  0x0f004022, 0x1d662909, 0x08212b12, 0x06000314,
  0x220601af, 0x1f001714, 0x38001f07, 0x192901ad,
  0x0f020d55, 0x12184008, 0x080f0509, 0x40151dbc,
  // [28f0]
  0x66000120, 0x12062912, 0x25301c21, 0x40171d12,
  0x0d0f0509, 0x1d164022, 0x16151d07, 0x0f020ba4,
  0x22030112, 0x03100b09, 0x211701af, 0x01380509,
  0x041201a4, 0x1e002535, 0x03066655, 0x25231c21,
  // [2900]
  0x06011013, 0x05060112, 0x15000311, 0x010605ad,
  0x1d124560, 0x06020b60, 0x171201a4, 0x10001608,
  0x04000622, 0x0b030209, 0x1e232502, 0x0e001e11,
  0x05001708, 0x66020d09, 0x16001211, 0x140b01af,
  // [2910]
  0x1f272912, 0x0b2166af, 0x030205be, 0x121516ad,
  0x170105af, 0x21452b12, 0x43220107, 0x38220f07,
  0x0d170fac, 0x01401dad, 0x0f011912, 0x05013821,
  0x0b1008be, 0x14660ba4, 0x0d1f0812, 0x0e001e36,
  // [2920]
  0x29002736, 0x03060420, 0x080106ac, 0x66020b6f,
  0x06030f13, 0x01162255, 0x02100308, 0x38081721,
  0x18000309, 0x18000812, 0x17000820, 0x08000513,
  0x03010807, 0x450c2b07, 0x021006bc, 0x01020508,
  // [2930]
  0x06036634, 0x04000c22, 0x120d17ac, 0x0d2927af,
  0x0c1545af, 0x01450d02, 0x051001af, 0x03060c12,
  0x08381721, 0x19000602, 0x1c231e12, 0x0c000f14,
  0x10191707, 0x272908bb, 0x01222707, 0x1c23256f,
  // [2940]
  0x16402912, 0x0d433f12, 0x290d3808, 0x02660309,
  0x010f0c12, 0x060445af, 0x14001f11, 0x03000c20,
  0x05060fbe, 0x1d034055, 0x40021002, 0x14010bad,
  0x01273809, 0x45000f12, 0x19052908, 0x06140112,
  // [2950]
  0x01060fa4, 0x380d01af, 0x08160107, 0x0e251c14,
  0x40140112, 0x19181007, 0x1c001e20, 0x18001009,
  0x142915ad, 0x010621bc, 0x15191608, 0x172215ad,
  0x08050108, 0x230e3020, 0x1e1c256f, 0x300e1c07,
  // [2960]
  0x010445af, 0x01400b12, 0x0c1517bc, 0x1d272921,
  0x1d0f2b13, 0x01061aa4, 0x0d080109, 0x171d27a4,
  0x45401daf, 0x08176612, 0x221703a4, 0x190c4008,
  0x1c253012, 0x38001213, 0x38000c07, 0x030605af,
  // [2970]
  0x01273faf, 0x04020309, 0x0c031055, 0x0b001420,
  0x05450f09, 0x06050113, 0x04272155, 0x251c0eaf,
  0x181214a4, 0x1e233007, 0x0d101912, 0x04100209,
  0x18000814, 0x02400b13, 0x064504bb, 0x40001511,
  // [2980]
  0x03040612, 0x451004bb, 0x050f3823, 0x292721af,
  0x15292712, 0x12000c09, 0x38000511, 0x21192712,
  0x08432b33, 0x04272121, 0x19273f12, 0x2921276f,
  0x06003809, 0x15380421, 0x0b030802, 0x02050420,
  // [2990]
  0x38060ba4, 0x046627af, 0x663f43bc, 0x18161d12,
  0x01380f21, 0x02004320, 0x380f0112, 0x051f3f21,
  0x21001621, 0x043f27af, 0x66062712, 0x060b1055,
  0x0f2729af, 0x19292108, 0x3f001f22, 0x271516af,
  // [29a0]
  0x3f2b0112, 0x1d0c2912, 0x27152913, 0x012b1512,
  0x27100b12, 0x100d0112, 0x06380108, 0x12030612,
  0x17053f13, 0x190d0111, 0x05080309, 0x06013faf,
  0x18001021, 0x052729af, 0x0b0d06a4, 0x45292714,
  // [29b0]
  0x0d1821bc, 0x40001911, 0x08010402, 0x450166a4,
  0x03016612, 0x1f2b1012, 0x12063faf, 0x1f2b01af,
  0x19020b12, 0x18000d20, 0x06000d07, 0x14004312,
  0x401866af, 0x030f0112, 0x45120507, 0x19000309,
  // [29c0]
  0x16380dad, 0x0d181212, 0x1e0e2509, 0x451d4055,
  0x010308ad, 0x14002211, 0x04001412, 0x18000d09,
  0x14000223, 0x1e002320, 0x0b141609, 0x0b140255,
  0x04021002, 0x430d2707, 0x04002208, 0x0c002212,
  // [29d0]
  0x2b222709, 0x151d1620, 0x21052712, 0x2b010521,
  0x40172b12, 0x40001621, 0x2b004309, 0x01080da4,
  0x432b01af, 0x02000302, 0x01003f21, 0x04662108,
  0x01120d07, 0x171d0d08, 0x10020307, 0x10001207,
  // [29e0]
  0x0b100307, 0x01000314, 0x0f082212, 0x01143820,
  0x01060f07, 0x43020112, 0x1d104008, 0x030501ad,
  0x01210355, 0x22000f08, 0x03020b60, 0x29006613,
  0x1e230e60, 0x0f002207, 0x0c120121, 0x1d124007,
  // [29f0]
  0x45122108, 0x02291812, 0x12452109, 0x061601a4,
  0x18270b07, 0x660501af, 0x012b3811, 0x66180209,
  0x1d1821a4, 0x05120da4, 0x301c2511, 0x021518a4,
  0x0c1940a4, 0x166638bc, 0x08021412, 0x19100b09,
  // [2a00]
  0x0b063809, 0x21001922, 0x18013809, 0x04161921,
  0x45192108, 0x22001623, 0x3f272922, 0x010803a4,
  0x170f0d14, 0x1d184055, 0x1d192207, 0x660116af,
  0x0d060507, 0x03160112, 0x2b060112, 0x1d010207,
  // [2a10]
  0x0b100509, 0x16013808, 0x0d012b55, 0x2b012112,
  0x0c002907, 0x040201af, 0x40121714, 0x29150112,
  0x66000336, 0x141501af, 0x02154022, 0x013f0da4,
  0x100c1212, 0x400b1408, 0x030f06a4, 0x12272920,
  // [2a20]
  0x0b0214bb, 0x1c302507, 0x0d0b0609, 0x0f403808,
  0x18030608, 0x06043821, 0x100201af, 0x190c0412,
  0x0f451207, 0x0d2901a4, 0x45100b09, 0x40000c08,
  0x060c6607, 0x06011002, 0x45001820, 0x29184512,
  // [2a30]
  0x19380508, 0x182729be, 0x01190308, 0x272918bb,
  0x21660309, 0x231c0e60, 0x27190360, 0x0b102113,
  0x140b0213, 0x0d0127a4, 0x140203af, 0x230e1c08,
  0x10060b08, 0x27211833, 0x18002713, 0x03661912,
  // [2a40]
  0x01660307, 0x0b021055, 0x050d01a4, 0x29272112,
  0x18001613, 0x2b001811, 0x434527a4, 0x18001614,
  0x03100614, 0x01180ba4, 0x02030b12, 0x25001c36,
  0x66180b09, 0x10060307, 0x01000313, 0x1c2325bb,
  // [2a50]
  0x18032baf, 0x18001620, 0x161466af, 0x271f2912,
  0x660651a4, 0x2b001812, 0x06220322, 0x3f012b13,
  0x12000408, 0x0b016607, 0x05000102, 0x10036655,
  0x181005a4, 0x66020b13, 0x12040555, 0x05380421,
  // [2a60]
  0x010618ad, 0x223f2109, 0x381d21a4, 0x02101712,
  0x0f080d09, 0x23300e22, 0x050d08a4, 0x0c080307,
  0x05220308, 0x190b0209, 0x0b180112, 0x060b0108,
  0x0c1722a4, 0x14000202, 0x271d1709, 0x22152109,
  // [2a70]
  0x06100807, 0x38400202, 0x04450c55, 0x17120d60,
  0x16191daf, 0x2b2912af, 0x02000307, 0x010d2b07,
  0x29000413, 0x010f0508, 0x01002113, 0x12160d09,
  0x18002102, 0x38055112, 0x0f0c2107, 0x050f38a4,
  // [2a80]
  0x10272909, 0x010605a4, 0x080219a4, 0x181d02a4,
  0x38001d11, 0x272b0814, 0x190366af, 0x010101a4,
  0x43051712, 0x01001d02, 0x05010212, 0x04190307,
  0x0b021d14, 0x45044008, 0x40161d08, 0x100b0212,
  // [2a90]
  0x1c301e60, 0x120c1d20, 0x23251e55, 0x08031d08,
  0x0b021d08, 0x060319a4, 0x063801af, 0x05103811,
  0x02036621, 0x061d0307, 0x06173860, 0x02080112,
  0x17380412, 0x06010807, 0x062b2908, 0x0b101d21,
  // [2aa0]
  0x1d120412, 0x1c0e2521, 0x033801af, 0x141d1014,
  0x301c1e12, 0x17060321, 0x38001722, 0x25231e12,
  0x661f3f12, 0x0c001d22, 0x1d060112, 0x174003a4,
  0x0f0d3814, 0x036651af, 0x19182109, 0x0b002709,
  // [2ab0]
  0x0d0f2b09, 0x66003821, 0x01021013, 0x0f180d08,
  0x01181955, 0x0e001c22, 0x1d164055, 0x222b0807,
  0x03026607, 0x0b031021, 0x12162912, 0x1e1c0ebe,
  0x0b162707, 0x40182909, 0x0c000208, 0x18000508,
  // [2ac0]
  0x0f004513, 0x21001809, 0x03006620, 0x1c230e20,
  0x231e0eac, 0x38006609, 0x05036660, 0x03226608,
  0x0c010809, 0x060838a4, 0x1c25236f, 0x381705bb,
  0x66003812, 0x18024007, 0x0c660813, 0x16270808,
  // [2ad0]
  0x230e30be, 0x38000609, 0x66051712, 0x05660313,
  0x01380555, 0x030c19ad, 0x14000209, 0x0d020112,
  0x1c252307, 0x43170f02, 0x25301e12, 0x0f010808,
  0x02141023, 0x121d1712, 0x0b004013, 0x19170b08,
  // [2ae0]
  0x21000814, 0x18192213, 0x0c1d2912, 0x16000d09,
  0x010f0807, 0x1f002913, 0x021d0ba4, 0x40020b14,
  0x0f000214, 0x0c0306a4, 0x18270b12, 0x25231cad,
  0x45400620, 0x29011f12, 0x01000312, 0x060c3f12,
  // [2af0]
  0x020103a4, 0x180608a4, 0x19006613, 0x062b03a4,
  0x0f151634, 0x160f0d82, 0x184027af, 0x14000411,
  0x160f0d09, 0x19000308, 0x0f1645af, 0x29160f12,
  0x0f002122, 0x0f0d3860, 0x160d0f22, 0x140502ad,
  // [2b00]
  0x3f000f21, 0x1f053813, 0x03061907, 0x401905ac,
  0x1d190411, 0x0e251e14, 0x17082907, 0x1d030607,
  0x01041909, 0x06002b08, 0x0c450102, 0x381f2b12,
  0x17000420, 0x050f0108, 0x08061f08, 0x1c230e23,
  // [2b10]
  0x0f030613, 0x06022909, 0x10271812, 0x03020809,
  0x291f22af, 0x302325af, 0x17050809, 0x022227af,
  0x02062913, 0x2b062212, 0x022b0ba4, 0x18000b07,
  0x010f0baf, 0x041708a4, 0x1d182912, 0x17000d07,
  // [2b20]
  0x06140213, 0x01004507, 0x22272909, 0x272938bb,
  0x27222914, 0x291827a4, 0x1c002510, 0x16001514,
  0x38160808, 0x060408a4, 0x040c1708, 0x30230e14,
  0x0f450109, 0x170f0d12, 0x380d0f13, 0x19142912,
  // [2b30]
  0x0d083821, 0x230e1e14, 0x05012707, 0x1c231e02,
  0x04010b02, 0x01170309, 0x17210112, 0x0b2b0112,
  0x660c4008, 0x12002708, 0x18451fac, 0x29001609,
  0x06272911, 0x380301af, 0x01171007, 0x170601af,
  // [2b40]
  0x12002907, 0x08012b11, 0x2b6601af, 0x22274021,
  0x400c2221, 0x293810af, 0x27102909, 0x1d063809,
  0x171038af, 0x290801af, 0x01001713, 0x01191621,
  0x100b51a4, 0x121d4513, 0x45121d09, 0x0e002508,
  // [2b50]
  0x06381713, 0x25002323, 0x063804af, 0x27062912,
  0x140110a4, 0x38080d55, 0x0b1410af, 0x14661009,
  0x06660b12, 0x18050d12, 0x06101455, 0x03081d02,
  0x0d380b09, 0x14101909, 0x40270412, 0x041816ad,
  // [2b60]
  0x14010407, 0x0f2217a4, 0x1d164009, 0x381701af,
  0x38170121, 0x1f013814, 0x050d0609, 0x0f124007,
  0x29210f12, 0x010b0d07, 0x04000208, 0x43211612,
  0x401d0caf, 0x0c430112, 0x401508a4, 0x16010508,
  // [2b70]
  0x1c230ea4, 0x08000112, 0x0d0551af, 0x2b003820,
  0x180308ac, 0x17013812, 0x12400112, 0x19662212,
  0x66011612, 0x01050460, 0x01000221, 0x016603af,
  0x0b220212, 0x19150409, 0x66002212, 0x38170122,
  // [2b80]
  0x08001013, 0x1f380112, 0x3f401d6f, 0x22000b12,
  0x40451d34, 0x02401dad, 0x40430d07, 0x04001934,
  0x05060fa4, 0x020b2212, 0x1f223f22, 0x06080514,
  0x03004511, 0x16082109, 0x05193860, 0x0c004514,
  // [2b90]
  0x401d51a4, 0x401d12af, 0x0c1d4007, 0x124527ad,
  0x10000114, 0x050b02a4, 0x06000514, 0x1d404521,
  0x08051a12, 0x14001021, 0x03000635, 0x05140112,
  0x14060108, 0x291427af, 0x056601af, 0x02140112,
  // [2ba0]
  0x01660513, 0x1e231ca4, 0x401d0660, 0x1c002307,
  0x032b02a4, 0x010f0809, 0x231c1e11, 0x030119ac,
  0x062b2755, 0x1e002536, 0x05030b13, 0x180b5112,
  0x0b4038af, 0x1800141f, 0x01060208, 0x66000333,
  // [2bb0]
  0x29270609, 0x0b010607, 0x0b166609, 0x161027a4,
  0x0f012707, 0x08010612, 0x01080d07, 0x0d053812,
  0x1c233007, 0x06430508, 0x041027a4, 0x01290d09,
  0x151627a4, 0x0f0d08be, 0x01000f20, 0x0f000c07,
  // [2bc0]
  0x45001220, 0x01080c08, 0x222927bc, 0x22380dad,
  0x08170fa4, 0x22000d08, 0x14004511, 0x0e251c60,
  0x02060b13, 0x081738a4, 0x12450302, 0x06001f08,
  0x19000202, 0x0c023807, 0x05100402, 0x03222ba4,
  // [2bd0]
  0x29020412, 0x01100b12, 0x01382755, 0x3f001d35,
  0x40002713, 0x37004e36, 0x1f010b12, 0x010b0613,
  0x05012912, 0x01050308, 0x05013813, 0x100219a4,
  0x301c1e14, 0x22170209, 0x10003813, 0x02001f11,
  // [2be0]
  0x011038ac, 0x012b0209, 0x38000b12, 0x10010baf,
  0x19001f09, 0x0b0438a4, 0x03060baf, 0x03060421,
  0x140f3820, 0x04270621, 0x10400321, 0x06020b09,
  0x100366a4, 0x02100312, 0x45151412, 0x04221607,
  // [2bf0]
  0x12180508, 0x020c03a4, 0x14400208, 0x1f2b0509,
  0x1f2b0613, 0x06381002, 0x0d0f3811, 0x141716a4,
  0x16272909, 0x0b2204bb, 0x66162712, 0x2b170121,
  0x291651af, 0x05001912, 0x15002913, 0x22060322,

  // [2c00]
  0x16001f20, 0x2b000520, 0x062b2712, 0x16192709,
  0x190f0112, 0x05160d22, 0x05001920, 0x1f2127af,
  0x151f3809, 0x170c1da4, 0x051001a4, 0x23301e07,
  0x12164513, 0x0b0616a4, 0x030106a4, 0x15020b09,
  // [2c10]
  0x21012b21, 0x191628af, 0x03660513, 0x162901af,
  0x121d1609, 0x18004309, 0x23251c08, 0x0c000407,
  0x0e231cac, 0x01060b09, 0x160466af, 0x0e231e08,
  0x0d380f14, 0x0c183f12, 0x0b141055, 0x0b010609,
  // [2c20]
  0x08001908, 0x0d080f14, 0x191410af, 0x061003af,
  0x14000b09, 0x0b180412, 0x0c031d08, 0x0c042ba4,
  0x10024009, 0x0f1f0112, 0x0c186609, 0x02140307,
  0x22000207, 0x160b0208, 0x0b0f2baf, 0x27000111,
  // [2c30]
  0x0c001012, 0x02270b12, 0x21272933, 0x02001811,
  0x04000c11, 0x170d29af, 0x10146608, 0x0b1945af,
  0x2b001408, 0x2b0138ad, 0x10000c07, 0x300e1cbc,
  0x16150412, 0x152721af, 0x400c1d12, 0x45011fad,
  // [2c40]
  0x0c2221af, 0x17380faf, 0x16151f6f, 0x15162909,
  0x0b662113, 0x02000b0e, 0x16001508, 0x1c251e21,
  0x020310a4, 0x080f0ca4, 0x272b1f12, 0x02011fad,
  0x66040321, 0x08452909, 0x06030412, 0x0c213f14,
  // [2c50]
  0x3f001913, 0x080129ad, 0x2b030612, 0x06192707,
  0x0f030408, 0x43030112, 0x163f40af, 0x01030421,
  0x0f046608, 0x66000b09, 0x04030112, 0x043f1912,
  0x23250e09, 0x08000f07, 0x163f0112, 0x19043f21,
  // [2c60]
  0x04002708, 0x05380807, 0x0e1c256f, 0x01220611,
  0x1d012907, 0x031d02ad, 0x04001711, 0x3f000520,
  0x08004312, 0x170c4307, 0x01102212, 0x030602be,
  0x02220b12, 0x05002221, 0x05002b23, 0x19220b14,
  // [2c70]
  0x08170421, 0x1c0e3012, 0x43040512, 0x103851a4,
  0x180f0d08, 0x1d380108, 0x0c2245af, 0x451d0112,
  0x230e25bc, 0x12014007, 0x0e1e25a4, 0x03052708,
  0x170501af, 0x45004002, 0x380601a4, 0x08060208,
  // [2c80]
  0x01050607, 0x012215ad, 0x211d0112, 0x22270508,
  0x04001920, 0x27000508, 0x10181521, 0x03166612,
  0x18000d14, 0x29401d21, 0x18000307, 0x29401d13,
  0x21173809, 0x1d292760, 0x0d050fbe, 0x181516cf,
  // [2c90]
  0x04212712, 0x380d0213, 0x291d1f09, 0x0d020b09,
  0x082251a4, 0x2b080112, 0x010822a4, 0x080c1712,
  0x2b001512, 0x1e1c25ac, 0x18050d09, 0x1c0e1e20,
  0x10000421, 0x061001ad, 0x1e000e14, 0x37001c12,
  // [2ca0]
  0x40161d22, 0x05380108, 0x0f081713, 0x1d014007,
  0x01100255, 0x060366bc, 0x01151007, 0x080f1709,
  0x010f386f, 0x2b0c6611, 0x10020b07, 0x43001912,
  0x38011707, 0x0c1601af, 0x061d27a4, 0x0d051fac,
  // [2cb0]
  0x03020b08, 0x43211aa4, 0x08012712, 0x02030ba4,
  0x661f01af, 0x04020b07, 0x050f0d11, 0x450d0512,
  0x43003f12, 0x380b0307, 0x01170509, 0x380b14a4,
  0x16291aaf, 0x2b190809, 0x08380b12, 0x2b000612,
  // [2cc0]
  0x222719af, 0x45380da4, 0x66032221, 0x190c0b12,
  0x03660655, 0x22004513, 0x02190b09, 0x14292723,
  0x060203a4, 0x01060209, 0x01661f09, 0x450c4060,
  0x06272221, 0x05162b60, 0x03140112, 0x21160112,
  // [2cd0]
  0x2b000c22, 0x06170fa4, 0x10190111, 0x15036609,
  0x01081d07, 0x21000f12, 0x19010309, 0x1827296f,
  0x02062208, 0x22062b60, 0x45030f07, 0x2b003f13,
  0x18660309, 0x03010b09, 0x03191607, 0x10001821,
  // [2ce0]
  0x10030b11, 0x222729a4, 0x0601146f, 0x056601ad,
  0x080b0213, 0x29173809, 0x1d001413, 0x66272b09,
  0x0f003811, 0x05012ba4, 0x08001d08, 0x251e0e08,
  0x0c011f55, 0x01060cad, 0x0d003f11, 0x250e1c33,
  // [2cf0]
  0x08000111, 0x18004021, 0x120c1d21, 0x0f1d0807,
  0x19002711, 0x08220112, 0x0f000b07, 0x2b224013,
  0x160c04ad, 0x080166a4, 0x120416ad, 0x04080f07,
  0x22050f12, 0x184008bb, 0x0d0f2112, 0x05000f12,
  // [2d00]
  0x27192221, 0x08270512, 0x14001621, 0x02103fce,
  0x0f002907, 0x43000821, 0x03062baf, 0x23250e11,
  0x12050d13, 0x16000420, 0x03002220, 0x382b0308,
  0x12450614, 0x020b0314, 0x041745a4, 0x19002120,
  // [2d10]
  0x170b18ac, 0x03050409, 0x02002212, 0x06216609,
  0x38062707, 0x0302066f, 0x0d272909, 0x45122109,
  0x220317af, 0x19222113, 0x06660321, 0x10271711,
  0x19162b13, 0x660b2709, 0x050c1d07, 0x0f0d12af,
  // [2d20]
  0x0c0f0107, 0x0e231e55, 0x0d124521, 0x0d0301af,
  0x1d1727af, 0x08174512, 0x19400860, 0x03000b13,
  0x29006608, 0x1e300e11, 0x162205ad, 0x19211608,
  0x02005113, 0x12451fbe, 0x01000820, 0x0d180f09,
  // [2d30]
  0x1c0e1e55, 0x5c000733, 0x02010512, 0x01043fad,
  0x660503a4, 0x011606a4, 0x1d190cad, 0x180366a4,
  0x0c101707, 0x1d105112, 0x38000407, 0x40020baf,
  0x0b100520, 0x0b006622, 0x03011008, 0x041966a4,
  // [2d40]
  0x0b000809, 0x0c060314, 0x22003808, 0x06100309,
  0x0f3f22bc, 0x1d1240ad, 0x29104012, 0x45000112,
  0x0b10026f, 0x17010512, 0x103866a4, 0x02180b08,
  0x03050111, 0x66080b13, 0x04000b13, 0x06026609,
  // [2d50]
  0x12270508, 0x124516a4, 0x0c060108, 0x2b0601ad,
  0x10000112, 0x04010502, 0x192b0107, 0x301e1c09,
  0x080f3823, 0x0d120512, 0x01385112, 0x08381d12,
  0x1f0b0222, 0x18451212, 0x04191508, 0x02660109,
  // [2d60]
  0x14001012, 0x290c3faf, 0x0f451208, 0x05061812,
  0x06001722, 0x05124533, 0x251e0ebe, 0x124505be,
  0x08052b12, 0x05000f13, 0x120805a4, 0x10013f08,
  0x1d084012, 0x38002107, 0x02101d09, 0x22002907,
  // [2d70]
  0x01001611, 0x0f0d4309, 0x19404509, 0x083812bb,
  0x1d0115a4, 0x01030609, 0x25231e21, 0x12401808,
  0x40380dac, 0x1e2330ac, 0x45001811, 0x1e251c11,
  0x15000512, 0x16152709, 0x18000111, 0x10222755,
  // [2d80]
  0x08004323, 0x14036614, 0x17005113, 0x43001534,
  0x080343a4, 0x2b432112, 0x27432b12, 0x0b181008,
  0x0c0b2907, 0x170d43af, 0x172b0820, 0x120b1007,
  0x2b000820, 0x27004013, 0x2b054309, 0x06012955,
  // [2d90]
  0x10031912, 0x08292b12, 0x291d4012, 0x0d001534,
  0x01180521, 0x01030521, 0x080b5107, 0x2b160433,
  0x05036613, 0x0f0d2707, 0x02050baf, 0x30001c21,
  0x06660b55, 0x17120f08, 0x0b450508, 0x01030512,
  // [2da0]
  0x38001621, 0x01060312, 0x45170809, 0x011729a4,
  0x10054512, 0x05080312, 0x050b0209, 0x190b0207,
  0x30231e13, 0x010c45af, 0x03010512, 0x27120112,
  0x191001af, 0x0c660320, 0x0c120107, 0x01001610,
  // [2db0]
  0x01000c08, 0x05004508, 0x01294509, 0x120c0107,
  0x12010609, 0x45001611, 0x0d451212, 0x0d000212,
  0x23250eac, 0x124501bb, 0x100108a4, 0x66451d60,
  0x19120107, 0x060c0107, 0x40181212, 0x17000402,
  // [2dc0]
  0x030266af, 0x23250e12, 0x451d1214, 0x191d4008,
  0x45104012, 0x0b151413, 0x01143855, 0x29042709,
  0x22170811, 0x1d0f0507, 0x40164512, 0x66041920,
  0x01032b07, 0x21000b08, 0x050c6608, 0x0b0102a4,
  // [2dd0]
  0x01030f07, 0x05002708, 0x03061007, 0x430b0107,
  0x0b000409, 0x191d1507, 0x22006608, 0x084502a4,
  0x220c1f08, 0x17033809, 0x17153f12, 0x08000c07,
  0x0000102d, 0x22021d07, 0x0c380f09, 0x22166621,
  // [2de0]
  0x1d0c3f12, 0x22001213, 0x171d4002, 0x401218be,
  0x66161512, 0x18400607, 0x22182712, 0x661d2912,
  0x0b170207, 0x18001212, 0x40121dbe, 0x1d0c18af,
  0x08220107, 0x06000233, 0x400166a4, 0x0e1e25bb,
  // [2df0]
  0x14401d11, 0x401812af, 0x226627af, 0x0c4018cf,
  0x060801af, 0x10040f09, 0x10000313, 0x0e231ca4,
  0x22401008, 0x0c380f55, 0x1d040507, 0x15000408,
  0x1d000407, 0x0f004322, 0x66010513, 0x08020bad,
  // [2e00]
  0x10010208, 0x16000408, 0x0f1d0312, 0x0f4001af,
  0x010f3860, 0x294301a4, 0x0e1c2321, 0x02040b08,
  0x0f0c0109, 0x022b0b09, 0x050140af, 0x082101af,
  0x173822af, 0x3f000112, 0x050140be, 0x19143f21,
  // [2e10]
  0x22002107, 0x01141d11, 0x380f2912, 0x15001713,
  0x120c3f08, 0x0d1d2212, 0x0f220812, 0x272b16af,
  0x0d0c2bad, 0x1d3f01a4, 0x0e231e09, 0x45000c09,
  0x04080ba4, 0x223f1908, 0x14221508, 0x062101af,
  // [2e20]
  0x03003f13, 0x180c45af, 0x0c4518ad, 0x2b000207,
  0x30232513, 0x22292711, 0x1d45126f, 0x170106a4,
  0x2b000608, 0x08060312, 0x041410a4, 0x22000811,
  0x03011560, 0x031001af, 0x05016611, 0x1c1e2511,
  // [2e30]
  0x02000312, 0x0f124009, 0x0103666f, 0x22140112,
  0x0f013f09, 0x100838bb, 0x0b020d07, 0x08000409,
  0x03060112, 0x140f3808, 0x01050612, 0x19021209,
  0x1d0b0207, 0x16005108, 0x16004514, 0x12400513,
  // [2e40]
  0x19001711, 0x380f0312, 0x452101af, 0x03001011,
  0x061904ac, 0x02010b11, 0x120c0307, 0x010d0f09,
  0x192b1008, 0x0c0f3811, 0x10181912, 0x02001035,
  0x080f2121, 0x1f380f6f, 0x080f2112, 0x0b181009,
  // [2e50]
  0x02100b14, 0x1d080faf, 0x0d3808a4, 0x011014ad,
  0x010506a4, 0x061d1007, 0x1e232508, 0x0b292760,
  0x100b02a4, 0x271f2908, 0x300e25ad, 0x380f12a4,
  0x04401613, 0x38001602, 0x1d191607, 0x3f003822,
  // [2e60]
  0x0d161fac, 0x010421a4, 0x38661f08, 0x02660409,
  0x041d1655, 0x1d001633, 0x030d0607, 0x38001513,
  0x011705a4, 0x14003f11, 0x1d001613, 0x191d4020,
  0x0d080312, 0x1d041612, 0x16001534, 0x0b180209,
  // [2e70]
  0x06004513, 0x43272908, 0x0c160112, 0x06030255,
  0x062b1f09, 0x103f29af, 0x02010d02, 0x0b025107,
  0x011721a4, 0x0d430b02, 0x66020b12, 0x29001921,
  0x172201af, 0x080b0208, 0x22660355, 0x18020b12,
  // [2e80]
  0x030c2708, 0x03290160, 0x66032112, 0x06100112,
  0x45140fa4, 0x02270108, 0x01271f12, 0x1d010f09,
  0x29010d09, 0x01061fa4, 0x064018af, 0x17180620,
  0x10380620, 0x450c27a4, 0x1d120f09, 0x03040207,
  // [2e90]
  0x0f220120, 0x060301af, 0x01065112, 0x14102212,
  0x272b0f12, 0x10006613, 0x40272914, 0x060f2708,
  0x100b1f08, 0x0f002213, 0x0d0b0802, 0x18000622,
  0x08220ba4, 0x22080f14, 0x10060807, 0x12660308,
  // [2ea0]
  0x0c122108, 0x1d4012ad, 0x012b0607, 0x1c233014,
  0x03060108, 0x140221a4, 0x19002914, 0x03662b55,
  0x251c0e33, 0x0106035e, 0x66401621, 0x1d000412,
  0x17000511, 0x163f2baf, 0x0c012707, 0x06000108,
  // [2eb0]
  0x161d06a4, 0x011621ac, 0x04030b08, 0x08000612,
  0x2b000114, 0x45000808, 0x06380f08, 0x081d06ad,
  0x38066608, 0x18030f21, 0x38001707, 0x10193809,
  0x66080612, 0x06010813, 0x10212912, 0x01150d08,
  // [2ec0]
  0x43001f35, 0x191840a4, 0x2b291f12, 0x012b6612,
  0x18272960, 0x1712456f, 0x161801af, 0x16151412,
  0x27102908, 0x18000d08, 0x1f170112, 0x15002222,
  0x12181408, 0x15003802, 0x0b401d55, 0x121504a4,
  // [2ed0]
  0x38001807, 0x04194512, 0x100c2b12, 0x12453f14,
  0x101719a4, 0x08043802, 0x19042212, 0x181904ad,
  0x0f011007, 0x030f0d09, 0x22002709, 0x12001707,
  0x40292755, 0x0c001014, 0x16222113, 0x0f000102,
  // [2ee0]
  0x06012907, 0x0f003812, 0x12020b55, 0x030210af,
  0x1d121708, 0x40181dbc, 0x66272909, 0x0c001d09,
  0x19223809, 0x01141007, 0x0c002207, 0x0c144055,
  0x16002712, 0x29220413, 0x06220307, 0x061821a4,
  // [2ef0]
  0x160103a4, 0x163866a4, 0x16001212, 0x300e1ca4,
  0x01000211, 0x0c1929a4, 0x03216608, 0x0f0d1dad,
  0x10170108, 0x101701af, 0x08001d11, 0x22182108,
  0x061851af, 0x21140f6f, 0x01172708, 0x17100107,
  // [2f00]
  0x161d0baf, 0x063f1d12, 0x063802af, 0x010366ac,
  0x16006621, 0x0e302555, 0x66001612, 0x080d0f13,
  0x15004023, 0x40000c20, 0x210f0809, 0x01041608,
  0x21000408, 0x0c001408, 0x66000420, 0x03386613,
  // [2f10]
  0x17000f02, 0x0b004009, 0x40161da4, 0x050308a4,
  0x19050807, 0x18002b09, 0x1e251c22, 0x12180507,
  0x10000309, 0x02290108, 0x05081d07, 0x2b002109,
  0x16010520, 0x020b2b12, 0x43101602, 0x0d040108,
  // [2f20]
  0x2b080111, 0x101d4012, 0x060419bc, 0x16001d12,
  0x40002220, 0x0c124523, 0x430b0209, 0x03082107,
  0x19211612, 0x193801af, 0x050d3808, 0x012927af,
  0x161514bc, 0x0c011a11, 0x04191821, 0x10010660,
  // [2f30]
  0x100327a4, 0x18194012, 0x03662220, 0x22000808,
  0x18401d12, 0x180f0812, 0x0f030808, 0x0c022b12,
  0x04000c07, 0x190b02a4, 0x0c020b07, 0x0c124520,
  0x05001211, 0x40000b02, 0x121d40a4, 0x012103af,
  // [2f40]
  0x0c002108, 0x02036607, 0x45001221, 0x06380508,
  0x01061412, 0x05173802, 0x042901ad, 0x0b101909,
  0x0f002208, 0x0d004308, 0x18030209, 0x25001e34,
  0x0f003821, 0x01020b11, 0x15004522, 0x270b10af,
  // [2f50]
  0x03100b6f, 0x451d0412, 0x252330bc, 0x38080f13,
  0x27221d60, 0x12000412, 0x0c12456f, 0x0e1e1c21,
  0x0f170808, 0x0800381f, 0x0b0210ad, 0x08013807,
  0x0b026621, 0x10020bad, 0x010c27a4, 0x12011da4,
  // [2f60]
  0x080c0d21, 0x0d1d0f12, 0x0c124560, 0x27010b12,
  0x0f081f07, 0x19124512, 0x22004514, 0x0d0c0f08,
  0x380f21af, 0x010c3807, 0x10140b07, 0x18452708,
  0x121d0d08, 0x43186609, 0x220f0d09, 0x151d4011,
  // [2f70]
  0x22002913, 0x29273fbc, 0x190d2212, 0x01000209,
  0x0b0f3807, 0x0b100212, 0x17454013, 0x08020112,
  0x1d190420, 0x01270808, 0x381f0455, 0x03660112,
  0x250e2322, 0x451d16ad, 0x08000f12, 0x29000812,
  // [2f80]
  0x01050807, 0x011d6607, 0x0d084512, 0x0d0f08be,
  0x05000612, 0x401d0c13, 0x02041007, 0x38170fad,
  0x14000213, 0x15173812, 0x0f274307, 0x250e1c23,
  0x170143a4, 0x04001820, 0x29080612, 0x220d0baf,
  // [2f90]
  0x45181212, 0x17001507, 0x1e253011, 0x05001709,
  0x14660112, 0x010f4009, 0x06120408, 0x04002913,
  0x021014ad, 0x45271221, 0x19000811, 0x1c302512,
  0x012b1013, 0x301c2312, 0x1c230e21, 0x14292712,
  // [2fa0]
  0x1d454023, 0x22190807, 0x45122709, 0x01271912,
  0x220301ad, 0x223808a4, 0x051f0d20, 0x40001222,
  0x01211f12, 0x01270f08, 0x23301caf, 0x0c031d07,
  0x1d380f12, 0x45120407, 0x10000b22, 0x02080baf,
  // [2fb0]
  0x030b66a4, 0x30251c20, 0x272922ce, 0x182729af,
  0x10002207, 0x1d2918be, 0x05012b12, 0x40124560,
  0x04000d08, 0x21272914, 0x02010f08, 0x1d224508,
  0x02040b07, 0x1d1829af, 0x27292123, 0x251c0e02,
  // [2fc0]
  0x66292120, 0x0c030207, 0x03021013, 0x291d27af,
  0x22001013, 0x18272914, 0x0d040b60, 0x3f272908,
  0x08170d14, 0x14160813, 0x0c000420, 0x3f1606cf,
  0x0b662708, 0x141245af, 0x221218ad, 0x191622bc,
  // [2fd0]
  0x19220f13, 0x17000308, 0x291627ce, 0x150c1611,
  0x1d042212, 0x0d003822, 0x080651af, 0x0e3023be,
  0x23001c34, 0x05290108, 0x66220612, 0x16001702,
  0x22170f21, 0x142b6612, 0x04192208, 0x0f0422bc,
  // [2fe0]
  0x1d0c2221, 0x66222113, 0x1006196f, 0x0b0501af,
  0x01100b02, 0x01220621, 0x0f031009, 0x08100baf,
  0x17080111, 0x1c003020, 0x08060311, 0x10026609,
  0x06660b09, 0x10030260, 0x181008af, 0x190c16a4,
  // [2ff0]
  0x0e1e2321, 0x01060313, 0x23002521, 0x2b026621,
  0x01660309, 0x1e230e14, 0x1f660112, 0x0c012107,
  0x21272912, 0x08270d09, 0x19004013, 0x40124522,
  0x14190412, 0x1d1614ac, 0x22194060, 0x18000620,

  // [3000]
  0x45001608, 0x06081f55, 0x01051d12, 0x171f1d60,
  0x40011d12, 0x30001e20, 0x050c1d55, 0x100f2107,
  0x0f0c1608, 0x16022108, 0x0c2b3802, 0x450c01af,
  0x030b0208, 0x40041914, 0x17453f09, 0x05011dad,
  // [3010]
  0x45001d11, 0x17381d08, 0x08010512, 0x171f1da4,
  0x0c051dad, 0x0f011d12, 0x0f001712, 0x01141921,
  0x010f1760, 0x19292112, 0x66060314, 0x171f2713,
  0x66060321, 0x1f081712, 0x04292108, 0x386603af,
  // [3020]
  0x03221da4, 0x03062712, 0x17190809, 0x19000f13,
  0x18000608, 0x21292721, 0x0c0301ac, 0x2127291f,
  0x66000335, 0x04192155, 0x04190d08, 0x22001702,
  0x102b0208, 0x01381707, 0x38000d23, 0x08293814,
  // [3030]
  0x0c026612, 0x38050dad, 0x170c3fac, 0x38051707,
  0x1d380d09, 0x27293f22, 0x12451009, 0x06036609,
  0x120c0807, 0x22001709, 0x29000f12, 0x06010d07,
  0x12401dad, 0x301c2314, 0x1d0c16a4, 0x22001d12,
  // [3040]
  0x0f013809, 0x010f0dad, 0x0f0b0808, 0x2b010807,
  0x016605af, 0x031051af, 0x0d080f12, 0x19290308,
  0x22010607, 0x0b180655, 0x66001012, 0x013808a4,
  0x10060b02, 0x0f080d14, 0x66030221, 0x12164007,
  // [3050]
  0x14100812, 0x2b000b12, 0x25230e21, 0x03022212,
  0x03026621, 0x40272960, 0x2b401d22, 0x21153f60,
  0x381d1602, 0x40124523, 0x0f120d09, 0x020f2ba4,
  0x0d1d4009, 0x06100507, 0x211001af, 0x45040ba4,
  // [3060]
  0x062710a4, 0x120801a4, 0x662b01bb, 0x66012708,
  0x033f6621, 0x02660355, 0x40123fa4, 0x06210111,
  0x66000633, 0x08010f12, 0x0b0366a4, 0x080f0d07,
  0x380d1755, 0x060f0814, 0x121d40af, 0x121d40bc,
  // [3070]
  0x43000407, 0x29380f12, 0x29016623, 0x66000b13,
  0x18400f12, 0x0d120f55, 0x27042914, 0x16170d55,
  0x01043809, 0x0c000413, 0x14271007, 0x0c1d29af,
  0x03001811, 0x033810a4, 0x06010d09, 0x150d1634,
  // [3080]
  0x401f29a4, 0x0f152712, 0x01160d11, 0x161551af,
  0x0b1966af, 0x0f161534, 0x0f0d2912, 0x161527af,
  0x231c2560, 0x221914bc, 0x190421a4, 0x15212912,
  0x38002712, 0x19036620, 0x22001411, 0x150f0c21,
  // [3090]
  0x01210faf, 0x430d0112, 0x06040807, 0x190d1509,
  0x0f013802, 0x29270daf, 0x0d0c0807, 0x0f1029a4,
  0x0d161009, 0x0d291522, 0x0d1f0f09, 0x10050809,
  0x0b004007, 0x0e1c30ac, 0x1f010608, 0x1c233009,
  // [30a0]
  0x0c003808, 0x104301af, 0x23251cbe, 0x0d290f09,
  0x1c300eaf, 0x012b3855, 0x120f0b07, 0x01062907,
  0x380d0112, 0x23301e08, 0x080d0f11, 0x150810a4,
  0x151245bc, 0x450c1621, 0x0f2b0b09, 0x0f001911,
  // [30b0]
  0x270829af, 0x38084508, 0x19001620, 0x02030607,
  0x38011007, 0x01001013, 0x0f000d21, 0x210f0d60,
  0x45000813, 0x45160802, 0x03001611, 0x081916af,
  0x010508af, 0x03002b12, 0x66002b13, 0x01101907,
  // [30c0]
  0x04660307, 0x030127a4, 0x2b000511, 0x17080208,
  0x290d0812, 0x030d08a4, 0x43050607, 0x010629a4,
  0x02040309, 0x220627a4, 0x291927a4, 0x27042908,
  0x08002b02, 0x060b17ad, 0x14103f12, 0x05080607,
  // [30d0]
  0x10660212, 0x22010f07, 0x1d002108, 0x22292121,
  0x0c660612, 0x1f661aaf, 0x1f001d12, 0x38000411,
  0x45000412, 0x01170807, 0x08050f13, 0x10000d11,
  0x22012907, 0x041d0302, 0x030666a4, 0x45160fa4,
  // [30e0]
  0x142216ad, 0x17001812, 0x0d0b0807, 0x012b1f55,
  0x0f001402, 0x01221613, 0x05010607, 0x0c173808,
  0x01062b11, 0x10380faf, 0x220d0f09, 0x120610a4,
  0x08002108, 0x0d020c08, 0x1d170809, 0x080421a4,
  // [30f0]
  0x01062b60, 0x1d186608, 0x17000408, 0x19142ba4,
  0x180f0d60, 0x3f042113, 0x2b660360, 0x14061912,
  0x29380421, 0x0d0f0812, 0x21001912, 0x40043f21,
  0x27292109, 0x08173f08, 0x23301cad, 0x0000271c,
  // [3100]
  0x01023f09, 0x38000608, 0x0b3f0413, 0x27403f21,
  0x03000521, 0x1d0b40bc, 0x27290baf, 0x3f2721a4,
  0x19013f08, 0x38272933, 0x3829276f, 0x0c000207,
  0x0d0f06bb, 0x0c0805a4, 0x0c032bac, 0x06150160,
  // [3110]
  0x03660521, 0x272938af, 0x38000102, 0x0b001f13,
  0x06000109, 0x43001f11, 0x0b040602, 0x0d080502,
  0x0e1e2322, 0x231e2555, 0x040f3809, 0x45292709,
  0x162b0409, 0x011d0355, 0x10164012, 0x03272909,
  // [3120]
  0x01661d12, 0x1c1e0eaf, 0x45000402, 0x66061d12,
  0x454017a4, 0x080102a4, 0x1d0f3813, 0x1d210808,
  0x12101fac, 0x27290daf, 0x0d16086f, 0x16401d22,
  0x01272907, 0x04100dad, 0x380f1daf, 0x210f0d09,
  // [3130]
  0x12181f12, 0x2b0f0809, 0x40380f08, 0x191551a4,
  0x0f0d0821, 0x011204ad, 0x270f1d60, 0x10272108,
  0x01040307, 0x0b020307, 0x1d0f4014, 0x1d400814,
  0x19001621, 0x1d380f6f, 0x0d0f0814, 0x21040808,
  // [3140]
  0x01033807, 0x05380f12, 0x15190d09, 0x150c4511,
  0x0b001021, 0x17053807, 0x1f293f60, 0x1c0e23af,
  0x21004321, 0x06020b11, 0x010b0282, 0x14161913,
  0x0c400412, 0x03140255, 0x21100b09, 0x0b1002af,
  // [3150]
  0x1c30256f, 0x020627a4, 0x43002b12, 0x180338a4,
  0x01170207, 0x0c020f55, 0x05063808, 0x2b004314,
  0x29160408, 0x6604166f, 0x43000d07, 0x04211614,
  0x21043f12, 0x04002122, 0x231c2555, 0x16001823,
  // [3160]
  0x04126607, 0x1e0e1c60, 0x17001623, 0x100c0607,
  0x16000c11, 0x152b0509, 0x17031612, 0x03291608,
  0x273f6609, 0x05014512, 0x43002b14, 0x16181760,
  0x05010309, 0x38001811, 0x38180112, 0x0c060307,
  // [3170]
  0x01003808, 0x162b0412, 0x291627be, 0x27160809,
  0x66040209, 0x05011f07, 0x66190109, 0x141051af,
  0x45401513, 0x0b0219af, 0x161d2909, 0x2b080107,
  0x150306a4, 0x12000520, 0x03053860, 0x01003809,
  // [3180]
  0x04061920, 0x40000607, 0x40151d12, 0x05080107,
  0x30000e36, 0x0b120408, 0x05660309, 0x12001507,
  0x43224008, 0x18001407, 0x100d01af, 0x041d4307,
  0x40012712, 0x2b160baf, 0x21011413, 0x01001807,
  // [3190]
  0x19010407, 0x011738a4, 0x1c0e25ac, 0x0f4016af,
  0x301e0eaf, 0x400c16ad, 0x17000f11, 0x100c4512,
  0x0f0c0607, 0x10190608, 0x060c15bc, 0x080603bc,
  0x100c6613, 0x050c12a4, 0x1d401612, 0x163f4020,
  // [31a0]
  0x17380d11, 0x40181d09, 0x03010812, 0x0c0d0f13,
  0x12451d60, 0x0d050812, 0x27026608, 0x16000c23,
  0x02100307, 0x400c1d13, 0x15004512, 0x250e1e09,
  0x0f2b4508, 0x041922a4, 0x15170f14, 0x38082112,
  // [31b0]
  0x03180d08, 0x0e231c14, 0x0e001e35, 0x06106609,
  0x17380dad, 0x02061012, 0x0000120a, 0x01181f08,
  0x45121708, 0x40000f12, 0x01292720, 0x21662912,
  0x19041608, 0x17000313, 0x38290f09, 0x38001812,
  // [31c0]
  0x38001f13, 0x0d141807, 0x181008ad, 0x15030808,
  0x1d100dad, 0x193801a4, 0x16661913, 0x29276608,
  0x0b1051af, 0x01171d08, 0x45401214, 0x031606af,
  0x06012b07, 0x18003809, 0x14183807, 0x081722a4,
  // [31d0]
  0x5c000709, 0x381f0112, 0x15004508, 0x66190821,
  0x0b0251af, 0x66010f09, 0x1d0d0807, 0x251c1e55,
  0x17121d08, 0x18101d12, 0x05014334, 0x0b160207,
  0x15002b12, 0x16001d09, 0x40291d12, 0x022b3fa4,
  // [31e0]
  0x17126607, 0x10003f11, 0x431d01a4, 0x38660bad,
  0x17001421, 0x01142707, 0x27002121, 0x0f0401af,
  0x1d0c0f09, 0x1d040b12, 0x1d000f14, 0x08292760,
  0x0c030209, 0x0b001707, 0x17002b13, 0x01382907,
  // [31f0]
  0x04450fac, 0x1f002b22, 0x400c1709, 0x01002111,
  0x0f060d07, 0x1e230ebe, 0x012b0608, 0x12060108,
  0x38451255, 0x1e1c2309, 0x03100607, 0x0b001720,
  0x0b1410be, 0x01080c07, 0x04451223, 0x40192b55,
  // [3200]
  0x2b011fbb, 0x060201a4, 0x18001612, 0x38082bac,
  0x18011f12, 0x22001810, 0x15001709, 0x251c3008,
  0x38080f02, 0x1d292709, 0x27293f14, 0x032b02bc,
  0x032b02af, 0x15003821, 0x0f014307, 0x03180607,
  // [3210]
  0x03660221, 0x02000610, 0x011229a4, 0x062b0108,
  0x22004007, 0x082b0260, 0x27222112, 0x0f293812,
  0x0c001834, 0x0f0127a4, 0x38000622, 0x03026620,
  0x03120612, 0x0b020608, 0x45000820, 0x272b51af,
  // [3220]
  0x01124302, 0x0f080d21, 0x06010cac, 0x0f020b13,
  0x16173807, 0x251c1e23, 0x19001014, 0x060c4507,
  0x051f0109, 0x101804a4, 0x05081708, 0x030501a4,
  0x01000202, 0x14000b02, 0x66272960, 0x190c21a4,
  // [3230]
  0x19005108, 0x15000f21, 0x29274512, 0x010f29af,
  0x05002212, 0x22272921, 0x081d2907, 0x0b100602,
  0x1d050808, 0x121d4082, 0x10025112, 0x66210313,
  0x0b454011, 0x17020ba4, 0x250e1c21, 0x0b060208,
  // [3240]
  0x14000613, 0x0c220b13, 0x1e300e09, 0x1f221d08,
  0x19001d13, 0x3f1d16be, 0x04010b12, 0x66002708,
  0x0b2b0107, 0x1d400d22, 0x160c2912, 0x1d001914,
  0x29271021, 0x22011709, 0x0f001d21, 0x14001914,
  // [3250]
  0x02221812, 0x05380122, 0x270b0214, 0x1d003f22,
  0x0b101d07, 0x16105111, 0x06041013, 0x45026608,
  0x08191d21, 0x02181d07, 0x1d193f13, 0x08002911,
  0x451d1560, 0x18020b11, 0x0b18026f, 0x380b0255,
  // [3260]
  0x1c1e256f, 0x1d060b07, 0x27191a12, 0x38172ba4,
  0x2b001809, 0x00004315, 0x0e253012, 0x01222908,
  0x0000430a, 0x1f380822, 0x23300e11, 0x04080112,
  0x40020b55, 0x064501a4, 0x19660312, 0x01001920,
  // [3270]
  0x121d0cac, 0x010f0855, 0x661f3f14, 0x21020bbc,
  0x27210d09, 0x16190612, 0x292701a4, 0x050b0107,
  0x011706ad, 0x25002307, 0x2b0538af, 0x011d1907,
  0x2b1f06bb, 0x060119ad, 0x38172b09, 0x0f2b0112,
  // [3280]
  0x02010baf, 0x19005113, 0x0b030612, 0x38401da4,
  0x18001d12, 0x03661712, 0x03380107, 0x19003f13,
  0x1d006607, 0x1d001012, 0x1c250ebb, 0x38000b13,
  0x40173faf, 0x171538a4, 0x10380855, 0x0b030212,
  // [3290]
  0x08163808, 0x03061408, 0x40450cad, 0x080d0308,
  0x29002209, 0x08050f09, 0x04000b02, 0x1d403faf,
  0x0b000402, 0x171d3fad, 0x161d1908, 0x17004512,
  0x06041007, 0x270503af, 0x21290f08, 0x27153f34,
  // [32a0]
  0x08001007, 0x29162708, 0x12031d07, 0x27290512,
  0x21002223, 0x012b0412, 0x1f0d3f12, 0x21002912,
  0x1d050107, 0x1d0f01a4, 0x01660313, 0x162927af,
  0x01292708, 0x38031555, 0x0f012908, 0x381d1f12,
  // [32b0]
  0x100604af, 0x15272911, 0x0f000107, 0x0b102212,
  0x181245a4, 0x381001a4, 0x05004507, 0x45120111,
  0x176601af, 0x30251e12, 0x1d663f12, 0x080f1621,
  0x16171d11, 0x0c1601ac, 0x010d0f55, 0x0b040d09,
  // [32c0]
  0x03180d07, 0x06030407, 0x08001d12, 0x03100207,
  0x2b0f1aa4, 0x45000513, 0x22210d09, 0x01020521,
  0x01180d08, 0x05003811, 0x01063f11, 0x060d0309,
  0x30230ebe, 0x16181507, 0x38196612, 0x0f0538be,
  // [32d0]
  0x38191611, 0x050d1707, 0x1d0c0808, 0x10401dad,
  0x0c162155, 0x271d4013, 0x380f0db2, 0x400415ac,
  0x454004af, 0x04381612, 0x04054007, 0x06162709,
  0x272904af, 0x384501ac, 0x1d011212, 0x401d17a4,
  // [32e0]
  0x2b000514, 0x40002b07, 0x1e003009, 0x05020107,
  0x1e230e11, 0x1e003007, 0x251e3009, 0x66061421,
  0x29030209, 0x0b002b07, 0x231c0ebe, 0x66061009,
  0x0f060baf, 0x18062260, 0x08031912, 0x020c0107,
  // [32f0]
  0x30002512, 0x0d0f6612, 0x19060409, 0x0f0d1da4,
  0x400f0d60, 0x21170308, 0x1d012107, 0x0b080307,
  0x010d08af, 0x020b06ac, 0x0f0d4012, 0x450f6612,
  0x010527a4, 0x020b0412, 0x010d0855, 0x0d1266ad,
  // [3300]
  0x1d1817ad, 0x400f0412, 0x40002908, 0x21002712,
  0x381829af, 0x18002707, 0x0f003822, 0x10180413,
  0x66140420, 0x0b121421, 0x380b0207, 0x2b000613,
  0x40000113, 0x22002108, 0x05001d07, 0x0b401012,
  // [3310]
  0x18000c11, 0x17162b02, 0x0c2b0655, 0x03020111,
  0x01100b11, 0x080601a4, 0x01100860, 0x04191060,
  0x06000508, 0x161d4008, 0x0c401d60, 0x01080309,
  0x10140112, 0x030b6609, 0x03160fa4, 0x0d270f09,
  // [3320]
  0x30001e07, 0x01061808, 0x1d0c0fa4, 0x0d001d02,
  0x0d081f13, 0x12454021, 0x1c1e0eac, 0x14000b11,
  0x10050207, 0x40451d09, 0x22001911, 0x66001512,
  0x0f400d09, 0x1d080d09, 0x0f010802, 0x101f0b09,
  // [3330]
  0x40161511, 0x03000212, 0x0f041712, 0x0d000412,
  0x38450308, 0x19050b12, 0x0f060d12, 0x231e3009,
  0x0f000523, 0x19006612, 0x06381609, 0x040201a4,
  0x16011512, 0x43292711, 0x05032907, 0x193f01af,
  // [3340]
  0x0c2b1702, 0x15380512, 0x12000622, 0x250e1eac,
  0x15161d11, 0x0b125112, 0x43006608, 0x03012907,
  0x0d171f07, 0x18660312, 0x100b5112, 0x0d0c6612,
  0x430c4507, 0x01190608, 0x01180602, 0x2b272913,
  // [3350]
  0x02660609, 0x1e233012, 0x03660b14, 0x14036621,
  0x0d0f1812, 0x0c080f12, 0x0f0c1d21, 0x15002120,
  0x40000f11, 0x0b000f20, 0x0c0f1613, 0x10050b09,
  0x082b0f12, 0x0c180f09, 0x0d080f11, 0x25231c60,
  // [3360]
  0x1d0c0faf, 0x381705a4, 0x04154009, 0x140406af,
  0x04060baf, 0x04080f11, 0x06404560, 0x08160f12,
  0x290f1909, 0x3f000513, 0x18010809, 0x66001212,
  0x18001409, 0x14011511, 0x27060b12, 0x1c1e2321,
  // [3370]
  0x380b1013, 0x1e1c0ea4, 0x080122ad, 0x010f1407,
  0x15401d08, 0x01191709, 0x18141012, 0x141004bc,
  0x1d001820, 0x181f1621, 0x08140b09, 0x012b2712,
  0x012b1fad, 0x10004007, 0x01001407, 0x03182ba4,
  // [3380]
  0x0f000511, 0x0f154055, 0x451d4009, 0x18002211,
  0x12001820, 0x0b021012, 0x45000308, 0x080117a4,
  0x272b0312, 0x45012109, 0x01066607, 0x12000307,
  0x124503af, 0x01192b60, 0x38010f08, 0x010f0dbe,
  // [3390]
  0x180b0521, 0x0f080baf, 0x10020607, 0x010338a4,
  0x17060255, 0x01060308, 0x02102113, 0x2b292712,
  0x29270812, 0x100651a4, 0x040f0309, 0x102b51af,
  0x2b002214, 0x0c2b6608, 0x401d4511, 0x2b002212,
  // [33a0]
  0x01033808, 0x042729ad, 0x2b002222, 0x221d0609,
  0x660329af, 0x30250e09, 0x0c192955, 0x06021009,
  0x04271909, 0x03020402, 0x04292720, 0x19002908,
  0x15044512, 0x12161009, 0x40001608, 0x0f400d14,
  // [33b0]
  0x0f0638a4, 0x1e0e3009, 0x0f0d16af, 0x0f080dad,
  0x04292712, 0x06016609, 0x014506ac, 0x121d1521,
  0x40081912, 0x1d120d09, 0x29161922, 0x0d401660,
  0x22381707, 0x08402108, 0x170116ac, 0x18001214,
  // [33c0]
  0x0d030109, 0x1d020b07, 0x2b021d09, 0x450c4009,
  0x0e301ca4, 0x380f0d21, 0x100103a4, 0x0b660609,
  0x02212b07, 0x03290612, 0x06012ba4, 0x12100607,
  0x03051907, 0x0d0418cf, 0x0f0829af, 0x2b0603af,
  // [33d0]
  0x18000422, 0x040b1d21, 0x45010612, 0x060f51af,
  0x19003814, 0x29270209, 0x05000402, 0x013f2911,
  0x3f0f2121, 0x660c21af, 0x0d272920, 0x04001720,
  0x3f000c20, 0x66010313, 0x0e301e11, 0x1e251cac,
  // [33e0]
  0x381405a4, 0x0f381407, 0x14020b22, 0x301c2507,
  0x2b000208, 0x0b2b6660, 0x3f0b0112, 0x1e001c20,
  0x1d080555, 0x14272922, 0x140b2108, 0x181f0fbe,
  0x12000612, 0x170508a4, 0x1d020112, 0x1f000d13,
  // [33f0]
  0x27383f12, 0x27082909, 0x03001008, 0x01032bac,
  0x01046611, 0x21000121, 0x05193812, 0x0c026613,
  0x05040160, 0x03001607, 0x10050b12, 0x01056608,
  0x12000407, 0x0b000f11, 0x0b100221, 0x03050baf,

  // [3400]
  0x10000820, 0x19064008, 0x0f2b3812, 0x010d05ad,
  0x38100507, 0x38001614, 0x660d0512, 0x27001920,
  0x12001d21, 0x40292713, 0x192b2912, 0x270c2912,
  0x15000b08, 0x1927296f, 0x010d0f12, 0x43001709,
  // [3410]
  0x66035111, 0x16003813, 0x03160108, 0x12001f11,
  0x40272912, 0x402927ad, 0x01080611, 0x23253021,
  0x08050102, 0x19031855, 0x66100321, 0x30251e09,
  0x25231e60, 0x10190baf, 0x231e0e02, 0x08380d09,
  // [3420]
  0x22001008, 0x15001808, 0x40121d20, 0x05001d08,
  0x030b02af, 0x030b6612, 0x14002207, 0x08052112,
  0x29270da4, 0x38001708, 0x1c250e14, 0x231c2513,
  0x17210d09, 0x03000b02, 0x22160208, 0x0f3f2112,
  // [3430]
  0x2b1621bc, 0x14103f11, 0x19041807, 0x0f1d4011,
  0x1d2b10bc, 0x401d0baf, 0x0d380f55, 0x220d43a4,
  0x17000502, 0x191804ad, 0x05001d12, 0x3f080f13,
  0x02190b07, 0x21000c21, 0x011738ad, 0x270d01af,
  // [3440]
  0x08170508, 0x01270dbc, 0x45060508, 0x3f001f14,
  0x231c25ad, 0x10006609, 0x38220560, 0x0b141a12,
  0x14050b60, 0x38002707, 0x66013813, 0x38050113,
  0x05016612, 0x250e2308, 0x0f380112, 0x01001911,
  // [3450]
  0x380d08af, 0x10020b60, 0x03150112, 0x15006623,
  0x663801af, 0x140302a4, 0x06026608, 0x010529a4,
  0x2b290208, 0x2b004008, 0x19041409, 0x1c3025ad,
  0x27001409, 0x19001702, 0x0b060355, 0x12151708,
  // [3460]
  0x14660312, 0x23300e08, 0x12001410, 0x29000121,
  0x121916a4, 0x19061012, 0x3800121d, 0x2b453f12,
  0x08222107, 0x08001f08, 0x060c0309, 0x01061f09,
  0x17272212, 0x100d6609, 0x3f000313, 0x161f0421,
  // [3470]
  0x43030808, 0x0c033f08, 0x03050660, 0x0d001f07,
  0x1f29276f, 0x10273fbe, 0x0d100407, 0x30251cad,
  0x38012755, 0x2b080f09, 0x2b152908, 0x052b0421,
  0x051f5112, 0x19181f09, 0x16001f08, 0x161240af,
  // [3480]
  0x45123f09, 0x010b1009, 0x0d0f0802, 0x152b0309,
  0x0f430d09, 0x1d003f14, 0x0d0105ad, 0x3f401d13,
  0x40002707, 0x0c0b0612, 0x38170f02, 0x301e0e13,
  0x060327af, 0x12404509, 0x040306ce, 0x220306af,
  // [3490]
  0x190c2107, 0x10220baf, 0x10000308, 0x03063807,
  0x06031760, 0x10060b12, 0x061466a4, 0x06001408,
  0x02000621, 0x0f000520, 0x22030612, 0x38000321,
  0x162b6613, 0x38001623, 0x06001020, 0x0f121f07,
  // [34a0]
  0x03060413, 0x3f002120, 0x03042707, 0x0d380808,
  0x05000114, 0x22380d55, 0x060310a4, 0x25002302,
  0x0c0b1607, 0x06160420, 0x2b661621, 0x06001902,
  0x161d15bc, 0x22000102, 0x30251c14, 0x05033807,
  // [34b0]
  0x0b186609, 0x27145112, 0x43012907, 0x15061908,
  0x0d0551a4, 0x0f041909, 0x16001502, 0x0b004002,
  0x042919af, 0x0c100112, 0x0e301e07, 0x10030809,
  0x04190208, 0x1d0b4013, 0x16080f09, 0x04036609,
  // [34c0]
  0x16380da4, 0x210f0d21, 0x15192160, 0x0d0f2114,
  0x06192260, 0x03003f12, 0x22000821, 0x0d010c07,
  0x10001434, 0x0f002109, 0x16380809, 0x660302a4,
  0x210d0f22, 0x210f0d23, 0x210d0fbe, 0x0c000412,
  // [34d0]
  0x0e1e2302, 0x66041913, 0x05002907, 0x19001602,
  0x0d011707, 0x19032baf, 0x032b0611, 0x22011609,
  0x170d0fbe, 0x0d220107, 0x3f660112, 0x0400181f,
  0x101219a4, 0x03162712, 0x050b2707, 0x14001608,
  // [34e0]
  0x25000e02, 0x011d0f09, 0x05010407, 0x12450d08,
  0x01003820, 0x12172707, 0x29160b12, 0x172701af,
  0x013816bb, 0x1f292713, 0x38272912, 0x010f3812,
  0x40002709, 0x0c060107, 0x27001712, 0x66272920,
  // [34f0]
  0x1f043faf, 0x2b000507, 0x19042712, 0x2b172255,
  0x432729af, 0x2b1d45af, 0x21001722, 0x08401912,
  0x252330a4, 0x010c2b08, 0x060c3f07, 0x15001602,
  0x040306a4, 0x080b6612, 0x03660b09, 0x141866a4,
  // [3500]
  0x272966a4, 0x150440a4, 0x380f0d07, 0x0c103807,
  0x38000212, 0x14166613, 0x10662155, 0x100306af,
  0x03380607, 0x16060baf, 0x0c381f08, 0x1d124013,
  0x12000d09, 0x15000608, 0x1c250e13, 0x06380409,
  // [3510]
  0x25230e09, 0x040651af, 0x01273f11, 0x18121f14,
  0x043821a4, 0x301e2312, 0x0b002912, 0x0c0f27a4,
  0x08160607, 0x29160309, 0x034510a4, 0x45270cad,
  0x1d151614, 0x010c0f09, 0x01151612, 0x292751af,
  // [3520]
  0x02060307, 0x0f120c07, 0x04100b13, 0x0c000b08,
  0x25301e55, 0x18000513, 0x2b0d0509, 0x19220b07,
  0x080f0b08, 0x0c0d0f21, 0x40292708, 0x081719ad,
  0x19000d10, 0x301c0e20, 0x0f011fa4, 0x19403f12,
  // [3530]
  0x0c292707, 0x1d161255, 0x0d170821, 0x273829af,
  0x27212912, 0x19022709, 0x0d223813, 0x66100b14,
  0x06033808, 0x06100255, 0x17180302, 0x0f03066f,
  0x03065112, 0x2b430822, 0x04294009, 0x01003f13,
  // [3540]
  0x06000320, 0x01100609, 0x43063807, 0x380f0d55,
  0x12001811, 0x0e1c23ad, 0x0d160813, 0x01020812,
  0x033f06cf, 0x01190607, 0x064308af, 0x40000812,
  0x3f08056f, 0x021808ad, 0x1c252309, 0x06050802,
  // [3550]
  0x29193860, 0x162927bc, 0x1d272960, 0x15012908,
  0x180803af, 0x1d0140ad, 0x380d1daf, 0x061708bc,
  0x0c012907, 0x16000813, 0x08060333, 0x0d083f60,
  0x083f0621, 0x17400d07, 0x0f004011, 0x0d1d4055,
  // [3560]
  0x17293f12, 0x1d451211, 0x16081512, 0x1d141607,
  0x124540af, 0x06100160, 0x06000b02, 0x080c0108,
  0x38012ba4, 0x08181607, 0x10020b21, 0x15000113,
  0x010f2908, 0x01080d08, 0x051029af, 0x1d0f1621,
  // [3570]
  0x0d292709, 0x380621a4, 0x273f21bc, 0x102b0b08,
  0x16002b09, 0x051601ac, 0x43002107, 0x29002109,
  0x1629276f, 0x10380512, 0x2b1816bb, 0x450501af,
  0x0d0f29a4, 0x3f270112, 0x03000108, 0x18660409,
  // [3580]
  0x3f005113, 0x101401ad, 0x010551a4, 0x17103855,
  0x14002121, 0x010b51af, 0x0c272907, 0x291217af,
  0x0b021014, 0x0b0218be, 0x2b1606af, 0x03012908,
  0x18004013, 0x060301a4, 0x16042bbb, 0x030615ad,
  // [3590]
  0x45170409, 0x27211812, 0x19000614, 0x66170111,
  0x02141511, 0x010d1707, 0x04001935, 0x1f000635,
  0x40011909, 0x031f2bbb, 0x01002134, 0x06221508,
  0x08171d09, 0x432b0607, 0x1c002302, 0x10292121,
  // [35a0]
  0x080f15a4, 0x151408a4, 0x0c450309, 0x29270f12,
  0x03100baf, 0x170d08a4, 0x0d001735, 0x0b000434,
  0x03100212, 0x22000814, 0x02061007, 0x01106613,
  0x04003f13, 0x66004013, 0x292712ad, 0x02000512,
  // [35b0]
  0x1400041f, 0x01060302, 0x10380f55, 0x18031013,
  0x17012120, 0x181d406f, 0x14002b11, 0x060b2721,
  0x031004a4, 0x1d184011, 0x66042712, 0x060b66a4,
  0x1d126655, 0x01061007, 0x0c024512, 0x380b6608,
  // [35c0]
  0x062b0107, 0x06190b07, 0x00000603, 0x1d192755,
  0x40000222, 0x10000207, 0x19003f21, 0x0c062709,
  0x0d401a12, 0x38000312, 0x21001608, 0x1d0d16af,
  0x02140b09, 0x0b025112, 0x0e302320, 0x0f0519ac,
  // [35d0]
  0x0c011612, 0x19400302, 0x23251eaf, 0x120c1707,
  0x19082709, 0x38010555, 0x0f041907, 0x01001408,
  0x0b020807, 0x0f0c0802, 0x231e0e14, 0x10001507,
  0x0f003f11, 0x43002b08, 0x22001809, 0x1e250e09,
  // [35e0]
  0x25231ca4, 0x40001812, 0x010408bc, 0x08010523,
  0x0b1951af, 0x29145112, 0x0b001022, 0x10001922,
  0x06001022, 0x18380d60, 0x06001019, 0x19100611,
  0x0d014309, 0x041906a4, 0x1d170509, 0x04192909,
  // [35f0]
  0x192901a4, 0x023f0b09, 0x14021008, 0x03002908,
  0x192927af, 0x0c4501bc, 0x04171607, 0x380305a4,
  0x01061409, 0x1466036f, 0x451040ac, 0x21162708,
  0x15003f20, 0x01033809, 0x01036621, 0x16142912,
  // [3600]
  0x100b0107, 0x0b020607, 0x1d401655, 0x040121a4,
  0x03100255, 0x04030d07, 0x0b0c2b07, 0x250e1ebe,
  0x194016bb, 0x10272960, 0x05082b08, 0x02030609,
  0x16080508, 0x061d0107, 0x062b0baf, 0x0f021f14,
  // [3610]
  0x0d050813, 0x43013f09, 0x18000302, 0x12451fac,
  0x060351af, 0x18006611, 0x05030b07, 0x05101909,
  0x010d2707, 0x16081514, 0x0400190d, 0x19061060,
  0x0f080209, 0x01021912, 0x0b0603a4, 0x0b022723,
  // [3620]
  0x08380faf, 0x0b124555, 0x0b124560, 0x43000107,
  0x1f6601af, 0x062766ad, 0x030c6611, 0x05120d09,
  0x0d382207, 0x251c0e6f, 0x01212712, 0x22000412,
  0x270529af, 0x272921bc, 0x08190ba4, 0x08170d12,
  // [3630]
  0x15143fac, 0x27060112, 0x04051607, 0x17080fbe,
  0x22042907, 0x04001620, 0x0d004307, 0x01002b09,
  0x220b3807, 0x174340ac, 0x15162134, 0x04085112,
  0x38080508, 0x05013f09, 0x060538a4, 0x020105ad,
  // [3640]
  0x66080520, 0x063f0112, 0x03170509, 0x010d0612,
  0x100603ad, 0x2b051a12, 0x020b2908, 0x0b000312,
  0x19002b21, 0x051601af, 0x0d170813, 0x080b0214,
  0x38020baf, 0x19020612, 0x060104ac, 0x080b18af,
  // [3650]
  0x0c0508a4, 0x1f0d0113, 0x301e25a4, 0x17050112,
  0x19060213, 0x19001010, 0x27000321, 0x01120caf,
  0x03040609, 0x43210112, 0x034301a4, 0x04193fad,
  0x0c451214, 0x19043f09, 0x230e1c11, 0x450d12a4,
  // [3660]
  0x1d001709, 0x221927a4, 0x66004020, 0x400b0208,
  0x01196609, 0x12272912, 0x38083fbe, 0x45121d14,
  0x22001902, 0x06001910, 0x18004008, 0x1d1204ac,
  0x45002709, 0x0b381408, 0x21221d12, 0x29222712,
  // [3670]
  0x29161d13, 0x12013f12, 0x19161d12, 0x15161d22,
  0x191d2713, 0x14000108, 0x431d0111, 0x38106609,
  0x1f3f29af, 0x38013f08, 0x1c230ebb, 0x3f002b14,
  0x272921be, 0x15291d11, 0x15002711, 0x0c001821,
  // [3680]
  0x16003f22, 0x43010509, 0x170112a4, 0x12161513,
  0x06661008, 0x02150baf, 0x05060208, 0x06270112,
  0x17270509, 0x0f060207, 0x04143f11, 0x02661007,
  0x01003812, 0x38032108, 0x060502ac, 0x0b661008,
  // [3690]
  0x0d051512, 0x05106608, 0x12401d60, 0x040f0d08,
  0x1e252308, 0x100c4055, 0x03451260, 0x17040107,
  0x27182922, 0x0b2701a4, 0x0b060108, 0x401d18ad,
  0x01190408, 0x27222913, 0x29221808, 0x18002107,
  // [36a0]
  0x27020b09, 0x0b002707, 0x0c004023, 0x1829276f,
  0x03011907, 0x29000109, 0x040c1d07, 0x06010855,
  0x0b1014af, 0x1c0e25ad, 0x101606a4, 0x19660322,
  0x05000c07, 0x66010309, 0x05013807, 0x16000302,
  // [36b0]
  0x04000b08, 0x301e2508, 0x1f003f21, 0x0d0f38af,
  0x12144512, 0x066619af, 0x25003022, 0x15001908,
  0x01041907, 0x401d4508, 0x05451211, 0x18000c07,
  0x0d001008, 0x3f001013, 0x43660108, 0x01401011,
  // [36c0]
  0x45123855, 0x010b0213, 0x19171207, 0x121d4514,
  0x40381812, 0x4012456f, 0x38010da4, 0x10003802,
  0x450f0ca4, 0x0c381fba, 0x080d1808, 0x22001607,
  0x1c231e21, 0x010c0d08, 0x080d1512, 0x0f2b01a4,
  // [36d0]
  0x2b012908, 0x08191007, 0x401814ad, 0x103801af,
  0x22030207, 0x10061521, 0x05381712, 0x292b27af,
  0x19142107, 0x1d161007, 0x062b0d07, 0x38030112,
  0x16662b12, 0x29170809, 0x03661922, 0x120117a4,
  // [36e0]
  0x14150112, 0x27030112, 0x0d380f22, 0x292b2714,
  0x0b401009, 0x292740af, 0x1f000b13, 0x292766af,
  0x08010fa4, 0x010b51a4, 0x0f010d14, 0x66001921,
  0x190b1f07, 0x1c251e55, 0x01036612, 0x451d4060,
  // [36f0]
  0x010366af, 0x0f401d09, 0x100b1902, 0x0c000312,
  0x0f050d07, 0x02030b08, 0x19016609, 0x033801ad,
  0x06010f55, 0x01380312, 0x19121f5e, 0x45120d07,
  0x03000c12, 0x04140c12, 0x16221713, 0x01172212,
  // [3700]
  0x45120302, 0x38170107, 0x0c120307, 0x16221708,
  0x450c0307, 0x06000420, 0x062217bc, 0x04101709,
  0x15170c12, 0x0f0d38a4, 0x06020fa4, 0x38002b02,
  0x19031602, 0x17051921, 0x050d0f60, 0x17190807,
  // [3710]
  0x2b184008, 0x080105a4, 0x02010f07, 0x01083808,
  0x10000610, 0x1d124009, 0x19001612, 0x17000d02,
  0x0f184511, 0x1c231ebc, 0x432701a4, 0x1d005113,
  0x120c1d08, 0x08000d23, 0x19012109, 0x06450107,
  // [3720]
  0x17001f13, 0x04000c09, 0x1d181955, 0x30251e21,
  0x1c002533, 0x10291912, 0x020b1209, 0x0d051dbc,
  0x012b1655, 0x12450caf, 0x06011812, 0x05103855,
  0x170b0107, 0x03106608, 0x0d124513, 0x17001808,
  // [3730]
  0x451d4011, 0x0e1c1eac, 0x06296612, 0x17003f11,
  0x1c001e21, 0x0f0d0813, 0x0f010812, 0x66062912,
  0x08380b22, 0x12181d13, 0x43012707, 0x1e0e1c13,
  0x25001e35, 0x066601ad, 0x272b29af, 0x0d083834,
  // [3740]
  0x151629af, 0x40451da4, 0x380105bc, 0x05161509,
  0x0b2b1921, 0x18151621, 0x19001708, 0x0c292713,
  0x06001813, 0x66380d13, 0x2b052212, 0x272901af,
  0x18041012, 0x020501a4, 0x38191621, 0x2b000c13,
  // [3750]
  0x19180408, 0x29080112, 0x0c002909, 0x19001002,
  0x03060809, 0x0f2227a4, 0x40041da4, 0x40005113,
  0x16151922, 0x5c00070d, 0x15292722, 0x191627af,
  0x2b183813, 0x450b0d09, 0x02660112, 0x01065107,
  // [3760]
  0x08030209, 0x08060b07, 0x16172711, 0x2b663f12,
  0x0d004008, 0x010d38a4, 0x020f08a4, 0x010302a4,
  0x19043f12, 0x011906ad, 0x15036608, 0x121d4055,
  0x05022107, 0x301e1c13, 0x29000412, 0x0c121d12,
  // [3770]
  0x02030112, 0x050b0108, 0x220610af, 0x381d0609,
  0x0e1e2555, 0x040366ad, 0x15050112, 0x0e252302,
  0x660105be, 0x25233008, 0x08382b07, 0x1d002711,
  0x29000312, 0x18010d12, 0x38104502, 0x0e1c2309,
  // [3780]
  0x0b0145a4, 0x66000521, 0x02126609, 0x29190412,
  0x0f380daf, 0x18403f12, 0x04060d08, 0x06190b12,
  0x380d0413, 0x01000f12, 0x2b160612, 0x10010b02,
  0x25231e02, 0x03181d55, 0x03171507, 0x40451209,
  // [3790]
  0x011f0555, 0x03000512, 0x040601a4, 0x380c2b55,
  0x10000507, 0x0f004012, 0x12000410, 0x10000402,
  0x16451255, 0x04272909, 0x19293f12, 0x04191413,
  0x04401902, 0x193f0460, 0x0e233013, 0x04172109,
  // [37a0]
  0x19050f02, 0x00006601, 0x3f000c13, 0x30001e14,
  0x041903af, 0x04036622, 0x04192108, 0x1e0e2521,
  0x02016608, 0x10002112, 0x38006607, 0x1704226f,
  0x12000d11, 0x0b036660, 0x38010dbc, 0x050b0213,
  // [37b0]
  0x23002509, 0x05381012, 0x02000112, 0x38080d14,
  0x06002b14, 0x100229a4, 0x0c000102, 0x08040107,
  0x21002b14, 0x0b014307, 0x020c0d07, 0x05660355,
  0x050d27af, 0x661f01a4, 0x22381712, 0x02190409,
  // [37c0]
  0x0b011555, 0x401719a4, 0x19041d12, 0x19161712,
  0x0e3023af, 0x011619ac, 0x14290413, 0x18000808,
  0x12191421, 0x120d0f07, 0x161701af, 0x45001822,
  0x05011511, 0x04011607, 0x19001411, 0x16401712,
  // [37d0]
  0x06101d07, 0x171d2109, 0x02220b09, 0x10010ba4,
  0x15001912, 0x0c001d20, 0x06083faf, 0x1d380f14,
  0x01100209, 0x4027296f, 0x18210308, 0x18002123,
  0x400f3814, 0x400d1007, 0x04192112, 0x17030f13,
  // [37e0]
  0x1f000412, 0x03060f23, 0x190b0107, 0x10060fac,
  0x19100209, 0x150c1707, 0x190b51a4, 0x1d454014,
  0x05272955, 0x0e301eac, 0x12292712, 0x036619a4,
  0x10190302, 0x0e251e60, 0x18001211, 0x27042909,
  // [37f0]
  0x38001412, 0x381d0812, 0x16151da4, 0x061903ad,
  0x15036660, 0x1e3023af, 0x19006609, 0x101451af,
  0x030227a4, 0x01170f12, 0x17291412, 0x101d3807,
  0x03012709, 0x0f0d16a4, 0x0f0d0509, 0x40002208,

  // [3800]
  0x08380513, 0x2b0c1709, 0x180c15a4, 0x03013812,
  0x102b22ad, 0x0d066609, 0x12050f11, 0x12180f55,
  0x08001208, 0x220b0220, 0x0f080421, 0x270f01af,
  0x0d6608af, 0x38660f09, 0x0f1d10a4, 0x10000b11,
  // [3810]
  0x1d401607, 0x04084021, 0x12100355, 0x1e0e1cbb,
  0x45124060, 0x170f3fac, 0x06660309, 0x18002208,
  0x010605af, 0x19000512, 0x05086612, 0x0c141d14,
  0x450f0daf, 0x141d406f, 0x030d6607, 0x12000202,
  // [3820]
  0x66041609, 0x301c0e09, 0x0b661912, 0x401d0cbe,
  0x17061d09, 0x021d01af, 0x14026608, 0x12150c12,
  0x0c000411, 0x29182708, 0x22061008, 0x16401daf,
  0x10191413, 0x19001622, 0x0f2127af, 0x38290512,
  // [3830]
  0x08170522, 0x15036613, 0x21013faf, 0x010d3f12,
  0x1d000807, 0x124551a4, 0x15121d12, 0x38020112,
  0x380805cf, 0x06003f07, 0x29003f22, 0x0d014307,
  0x0d272922, 0x08002908, 0x270c29af, 0x0d4512ad,
  // [3840]
  0x29001512, 0x27190409, 0x273f2914, 0x21191612,
  0x0f162112, 0x14001912, 0x030201a4, 0x0c050660,
  0x06000321, 0x03100208, 0x020b0407, 0x01020602,
  0x06026613, 0x0d000608, 0x0f010522, 0x01100b60,
  // [3850]
  0x01001012, 0x2b0d43af, 0x1e0e1c07, 0x0f001213,
  0x0b292711, 0x17004012, 0x45121714, 0x01171faf,
  0x17041912, 0x04144060, 0x0c222709, 0x0d380507,
  0x21004012, 0x120b0107, 0x210266af, 0x0f083802,
  // [3860]
  0x0c402122, 0x03080f11, 0x140c2112, 0x19016608,
  0x100129a4, 0x14192907, 0x3f000b22, 0x0d0f1f08,
  0x18061421, 0x0f292707, 0x06010520, 0x05010d09,
  0x0c000320, 0x08272912, 0x14293fbe, 0x0c001508,
  // [3870]
  0x1d0b1f07, 0x43003813, 0x2b001f08, 0x272908af,
  0x06380f07, 0x121d0c07, 0x05272921, 0x01226609,
  0x08000d35, 0x272b0822, 0x66010fbc, 0x03196655,
  0x010f0555, 0x0f2b0d08, 0x10036609, 0x0b001408,
  // [3880]
  0x021006a4, 0x03012107, 0x24004310, 0x14004507,
  0x19001212, 0x380f21a4, 0x21013f13, 0x18004509,
  0x0f1f2912, 0x38002713, 0x1c1e0ead, 0x14036622,
  0x380d0f55, 0x02221655, 0x14002202, 0x18001908,
  // [3890]
  0x08100107, 0x300e2309, 0x40001711, 0x01052907,
  0x38081007, 0x04190514, 0x1f0d3812, 0x38042108,
  0x1d030207, 0x06050808, 0x2b000109, 0x19041707,
  0x16151908, 0x25231ebe, 0x12401d13, 0x08190155,
  // [38a0]
  0x222b0c08, 0x1f661aa4, 0x17190422, 0x10401d12,
  0x051d2b07, 0x1c1e0e08, 0x10010b12, 0x020b05ad,
  0x0f000c12, 0x19271007, 0x06000f09, 0x10020821,
  0x161d40af, 0x0b001620, 0x0d050f08, 0x251c0e14,
  // [38b0]
  0x020b05ac, 0x43450507, 0x0d000522, 0x0e1e1caf,
  0x1c300eac, 0x2b040caf, 0x1f184512, 0x23253012,
  0x0b1402af, 0x03000b09, 0x30230e55, 0x10030208,
  0x100c29af, 0x273f29be, 0x06222709, 0x25000e23,
  // [38c0]
  0x0d0f1821, 0x29001808, 0x0f184512, 0x45001712,
  0x27292122, 0x17041da4, 0x0c0b1412, 0x17001913,
  0x38270512, 0x0b180308, 0x0b220507, 0x180201af,
  0x19011707, 0x16000d02, 0x020b0608, 0x0b400d07,
  // [38d0]
  0x02050b12, 0x22050155, 0x291f0112, 0x45401d08,
  0x04211d12, 0x23001c20, 0x08060412, 0x020b0512,
  0x22042108, 0x450f1409, 0x40001212, 0x43660512,
  0x0c060408, 0x0c0b0211, 0x0c080620, 0x060d0f07,
  // [38e0]
  0x01170809, 0x1f0b6609, 0x04660355, 0x16060407,
  0x0d160612, 0x45140612, 0x12451dbe, 0x04660312,
  0x2b001713, 0x062b0355, 0x40001611, 0x1622196f,
  0x04001702, 0x1d400802, 0x02060409, 0x17451dbb,
  // [38f0]
  0x43000d02, 0x190527a4, 0x19004002, 0x0b000508,
  0x010610af, 0x15163f12, 0x03456609, 0x19182907,
  0x03005113, 0x12030512, 0x06021f14, 0x01001f21,
  0x0c1210a4, 0x17000302, 0x02380107, 0x1c0e2313,
  // [3900]
  0x66003f13, 0x180501a4, 0x182129af, 0x08012960,
  0x27400309, 0x18143809, 0x14000820, 0x19062107,
  0x450d0faf, 0x66190609, 0x01003f07, 0x2b002908,
  0x45124307, 0x271f0812, 0x18222112, 0x1f3f1aaf,
  // [3910]
  0x061703bc, 0x450b27a4, 0x0b0c6609, 0x02430ba4,
  0x01192907, 0x1c002535, 0x180f0521, 0x0b1510ad,
  0x0b031007, 0x38030f02, 0x12180d08, 0x180d0f09,
  0x38150f08, 0x020b106f, 0x450d1212, 0x43220b07,
  // [3920]
  0x02031721, 0x100666a4, 0x0b381060, 0x050f1507,
  0x05000b02, 0x0f0d1812, 0x0d180f02, 0x08660302,
  0x18000413, 0x100b0412, 0x0f401609, 0x19401d55,
  0x1d010607, 0x180d0f13, 0x060366ad, 0x030c1f21,
  // [3930]
  0x061f3f22, 0x060451af, 0x451240bc, 0x033f0660,
  0x03063f09, 0x18006608, 0x3f2b3821, 0x22184034,
  0x402b3f23, 0x27401d33, 0x061f0323, 0x29270823,
  0x2b0417cf, 0x290306af, 0x16000b20, 0x043f0612,
  // [3940]
  0x3f001721, 0x18003f20, 0x180c2908, 0x40432712,
  0x3f0429af, 0x1d400809, 0x030d0107, 0x10002b08,
  0x1d192260, 0x12030107, 0x66050308, 0x0f001f21,
  0x0d221412, 0x01066660, 0x0c401d08, 0x12451821,
  // [3950]
  0x66002b09, 0x03100209, 0x08000b12, 0x17040112,
  0x0d000408, 0x06012909, 0x061402a4, 0x0f004509,
  0x1c003007, 0x0b190411, 0x03041921, 0x1d122112,
  0x14002108, 0x02030809, 0x2b002108, 0x22660baf,
  // [3960]
  0x060b0213, 0x04191012, 0x1d033802, 0x450f1d11,
  0x031001ac, 0x12450f55, 0x0b0451af, 0x1200181f,
  0x0b000422, 0x45002b08, 0x10030209, 0x02101413,
  0x16001812, 0x22100412, 0x0c080107, 0x0d011aa4,
  // [3970]
  0x0c272911, 0x062221a4, 0x21004009, 0x01066609,
  0x120803a4, 0x2b010fa4, 0x0d0f1907, 0x45000511,
  0x06380d12, 0x1d451907, 0x191004ad, 0x100b0108,
  0x180301a4, 0x43013fad, 0x400115ad, 0x04013f12,
  // [3980]
  0x14013fad, 0x45401221, 0x43010d09, 0x031f01a4,
  0x1d1921af, 0x17212712, 0x21272908, 0x061221a4,
  0x02142155, 0x27171612, 0x0f002b08, 0x12140f55,
  0x12454060, 0x01120612, 0x06124511, 0x17001210,
  // [3990]
  0x010d0b09, 0x060b0112, 0x03080107, 0x45002908,
  0x1e2325be, 0x0d001207, 0x06030107, 0x00000703,
  0x18002221, 0x451621a4, 0x010306af, 0x192b0ba4,
  0x19001d11, 0x033808a4, 0x43002712, 0x102b02af,
  // [39a0]
  0x06001005, 0x030c1008, 0x08002b21, 0x012705af,
  0x271229bc, 0x04430209, 0x100b1460, 0x030b6607,
  0x0c000b12, 0x45121909, 0x0b406607, 0x27191f20,
  0x3f276609, 0x060c0308, 0x21272923, 0x08292755,
  // [39b0]
  0x29001f12, 0x06100213, 0x66100209, 0x042119af,
  0x060f2712, 0x3f292721, 0x272b19bc, 0x293f21af,
  0x080f3813, 0x38003f11, 0x08001920, 0x01660320,
  0x45000d07, 0x0b141013, 0x0b100109, 0x0d151760,
  // [39c0]
  0x0b021060, 0x081d1512, 0x01162912, 0x050322be,
  0x15124009, 0x151851a4, 0x27080f12, 0x12004022,
  0x19000b13, 0x251c2313, 0x12001608, 0x010227a4,
  0x0b060309, 0x06030ba4, 0x1c230e34, 0x01380212,
  // [39d0]
  0x12401da4, 0x080522af, 0x01220522, 0x03190208,
  0x032201af, 0x0b270209, 0x15051812, 0x22100b12,
  0x05061913, 0x16050112, 0x03010da4, 0x3f0601af,
  0x10060213, 0x08010521, 0x15121d07, 0x38400808,
  // [39e0]
  0x40180309, 0x0b002213, 0x19001f07, 0x18662212,
  0x010540cf, 0x27296660, 0x10030b08, 0x270d2b12,
  0x02002707, 0x08272913, 0x0f004521, 0x21002b12,
  0x02662712, 0x1e2325af, 0x08273812, 0x1d041902,
  // [39f0]
  0x1d4051af, 0x12000c20, 0x05180807, 0x0b3f51af,
  0x02226613, 0x0b021711, 0x061719a4, 0x08380da4,
  0x270d2912, 0x401018cf, 0x0b2b51af, 0x190d0f21,
  0x12050855, 0x100b1514, 0x040b1012, 0x66003f21,
  // [3a00]
  0x061916ac, 0x10021521, 0x401d0f09, 0x020b1014,
  0x29271009, 0x03270807, 0x452b66a4, 0x45154012,
  0x17001f23, 0x124551af, 0x0b101621, 0x180d0f14,
  0x16401d12, 0x06035112, 0x0b050108, 0x19020513,
  // [3a10]
  0x19000211, 0x0f003810, 0x1e0e25ad, 0x04101909,
  0x10002109, 0x190102af, 0x01213f09, 0x060f01a4,
  0x18100213, 0x010b0207, 0x19030107, 0x1d0c4060,
  0x10060208, 0x40000c14, 0x1d0340af, 0x43272107,
  // [3a20]
  0x01001512, 0x010814ad, 0x191829a4, 0x02050307,
  0x15000321, 0x01020b08, 0x27663faf, 0x0c191f07,
  0x03004014, 0x03041912, 0x126603af, 0x03154060,
  0x66273f12, 0x18226622, 0x12001009, 0x101d2709,
  // [3a30]
  0x22296608, 0x40003f23, 0x66450309, 0x161401a4,
  0x161545bb, 0x29032712, 0x01100cad, 0x03151612,
  0x0d0b0207, 0x0c003f23, 0x05660311, 0x0c012bac,
  0x021f0b12, 0x011d2912, 0x041921bc, 0x01213f6f,
  // [3a40]
  0x01161707, 0x38292712, 0x17086607, 0x0d002223,
  0x03063fac, 0x0c292714, 0x120b0260, 0x042715be,
  0x152921af, 0x0b020308, 0x45003807, 0x021d4008,
  0x0f0d0209, 0x22001822, 0x050f0d13, 0x0b060808,
  // [3a50]
  0x45084008, 0x380d0507, 0x18004535, 0x1d194008,
  0x01452ba4, 0x012b2955, 0x10162b07, 0x22003f22,
  0x1e1c2312, 0x08020b07, 0x020d08a4, 0x05011f09,
  0x15401614, 0x38291960, 0x38010ba4, 0x2b101408,
  // [3a60]
  0x662901a4, 0x04192907, 0x04004007, 0x250e1cbe,
  0x3f451212, 0x180f1faf, 0x45121f07, 0x45000621,
  0x0f2b6607, 0x0f1601af, 0x16191dac, 0x120c2ba4,
  0x151416ad, 0x1d404507, 0x02040155, 0x0b001209,
  // [3a70]
  0x43140ba4, 0x190b0d12, 0x08000423, 0x17000307,
  0x45020b08, 0x16270baf, 0x191d0608, 0x38001802,
  0x180c1fac, 0x034317a4, 0x06001511, 0x0f2b0108,
  0x18001909, 0x05000f02, 0x45004022, 0x0f0d22af,
  // [3a80]
  0x0d060fa4, 0x220d2907, 0x0e3023a4, 0x170f38a4,
  0x05191609, 0x16001520, 0x27662911, 0x040c1d08,
  0x40010b12, 0x01060f08, 0x050f0da4, 0x290d2221,
  0x25300e22, 0x15140109, 0x21002220, 0x1d121612,
  // [3a90]
  0x06011711, 0x2b011912, 0x10145112, 0x03216609,
  0x1e0e30ac, 0x660d0312, 0x0b6606a4, 0x14100b12,
  0x29000613, 0x0b050107, 0x19000622, 0x0c010207,
  0x1d0103a4, 0x020c40af, 0x1d053808, 0x0c194007,
  // [3aa0]
  0x300e2511, 0x40004521, 0x0c401d22, 0x0b3843a4,
  0x450f01a4, 0x020f1021, 0x10006620, 0x01220b07,
  0x0f0d0412, 0x15041921, 0x29212709, 0x03010d08,
  0x100314bc, 0x191d4014, 0x010f21a4, 0x16002111,
  // [3ab0]
  0x194021af, 0x14380fa4, 0x2b142234, 0x05001f21,
  0x0d0f386f, 0x22272922, 0x14221f22, 0x012b22ad,
  0x17000513, 0x2b1f1413, 0x2b2714bc, 0x14380baf,
  0x08000422, 0x040601ac, 0x16041933, 0x0f221412,
  // [3ac0]
  0x18004511, 0x291d0d13, 0x12000509, 0x0d1808ad,
  0x38221434, 0x10061d07, 0x100b1421, 0x401d2108,
  0x45001802, 0x38450fa4, 0x1c230e55, 0x30252308,
  0x1c0e1e23, 0x1c300e13, 0x06041712, 0x0d0f3821,
  // [3ad0]
  0x05010fac, 0x380105a4, 0x400466a4, 0x05010fbc,
  0x0b050312, 0x04272955, 0x03040b11, 0x160340a4,
  0x66061013, 0x0f0d08af, 0x02100809, 0x020b66bc,
  0x0b001414, 0x14001220, 0x17270508, 0x221d0bad,
  // [3ae0]
  0x10450302, 0x0f0d18ad, 0x2b0145af, 0x041d4014,
  0x170d2baf, 0x012b2908, 0x45272b12, 0x17001612,
  0x00001815, 0x1c252308, 0x0c454021, 0x22001f11,
  0x163f0460, 0x05380d21, 0x450c1f55, 0x40380f09,
  // [3af0]
  0x01051709, 0x0c121d02, 0x0f170809, 0x1c231e11,
  0x16081912, 0x1d12456f, 0x0b000413, 0x2b170409,
  0x010f4007, 0x38290f08, 0x18141f12, 0x14124521,
  0x04191708, 0x0d0f3f12, 0x12450307, 0x0b191f12,
  // [3b00]
  0x1f1901af, 0x1d163f12, 0x40161d12, 0x66001d14,
  0x29004020, 0x45154002, 0x0c1d06cf, 0x1d011aaf,
  0x0c010409, 0x0b0127a4, 0x02010b13, 0x172b0112,
  0x0f432212, 0x01082708, 0x01220508, 0x43000d33,
  // [3b10]
  0x050f29af, 0x29010f09, 0x2b012709, 0x010d0ba4,
  0x451240ad, 0x01291911, 0x1d454022, 0x01192921,
  0x0c010655, 0x25001c10, 0x06140d22, 0x18001410,
  0x0d180f08, 0x18020b09, 0x10030609, 0x04000811,
  // [3b20]
  0x1d000b07, 0x17060307, 0x0c400812, 0x1d030855,
  0x0c0127a4, 0x0b000808, 0x0c124512, 0x08190407,
  0x08001812, 0x40271013, 0x271429af, 0x1d102b21,
  0x38450107, 0x0f0d08bb, 0x270c10ad, 0x050d0f08,
  // [3b30]
  0x0f1d08af, 0x04036611, 0x29020b12, 0x10401d14,
  0x1d1614be, 0x1d401013, 0x402927af, 0x0f380d12,
  0x1d1427af, 0x17222109, 0x21170823, 0x383f0112,
  0x1d212260, 0x0e1c1e55, 0x29152109, 0x0f400309,
  // [3b40]
  0x27002113, 0x0c100b13, 0x08210112, 0x050d38ad,
  0x220f3f21, 0x3f05386f, 0x080f17be, 0x080f0d02,
  0x17041613, 0x0f013855, 0x16190412, 0x0d080209,
  0x1d404520, 0x23300e21, 0x16002120, 0x011d2913,
  // [3b50]
  0x08031707, 0x0d083823, 0x050d3802, 0x0f053809,
  0x0c190b12, 0x19160421, 0x0d4503af, 0x0d190821,
  0x0f080d13, 0x1d0b3f09, 0x1d404560, 0x0f0d40af,
  0x291738af, 0x01212709, 0x18100612, 0x01061420,
  // [3b60]
  0x43080b07, 0x04020b08, 0x0f2b0207, 0x080b0212,
  0x0b023f21, 0x21191709, 0x18001f23, 0x0c001702,
  0x0f0d0612, 0x1d224014, 0x04192122, 0x19141760,
  0x080b026f, 0x3f001713, 0x03010209, 0x06000822,
  // [3b70]
  0x29042712, 0x0c001411, 0x30231c21, 0x150817af,
  0x2300301f, 0x0f120d07, 0x170d05be, 0x011d4012,
  0x18141712, 0x29036613, 0x171d4014, 0x401d0813,
  0x401d08bc, 0x06170807, 0x04000813, 0x0d210821,
  // [3b80]
  0x0d011713, 0x082b3855, 0x08000d14, 0x27142912,
  0x0d000302, 0x0d1d40ac, 0x180f1207, 0x223f1421,
  0x191f2109, 0x010c0307, 0x0f210d09, 0x08001608,
  0x220d0808, 0x08142909, 0x0b1903a4, 0x03042111,
  // [3b90]
  0x0419036f, 0x18001414, 0x04003f20, 0x08400d12,
  0x100614ce, 0x22020b02, 0x06662112, 0x05000836,
  0x0d0c2755, 0x14100209, 0x04036613, 0x1f000821,
  0x0b100213, 0x16453fac, 0x16380f82, 0x0e002333,
  // [3ba0]
  0x66272912, 0x02120809, 0x380b0d09, 0x0b002212,
  0x1e0e2555, 0x0d180f12, 0x23301eaf, 0x38292112,
  0x66450112, 0x08001611, 0x18663fad, 0x01380607,
  0x0c001732, 0x271d3f08, 0x142722bb, 0x2b003f21,
  // [3bb0]
  0x10142b07, 0x01142155, 0x16273f13, 0x17002907,
  0x223f0822, 0x04272bad, 0x170f3f12, 0x0f273f12,
  0x0f00181d, 0x04211412, 0x451208a4, 0x66001d20,
  0x38000612, 0x0d040fad, 0x03082121, 0x27150baf,
  // [3bc0]
  0x22401dad, 0x14180409, 0x0f082909, 0x45190855,
  0x042129af, 0x1c2523ad, 0x010c1607, 0x21000c14,
  0x0b030407, 0x04163f13, 0x012729a4, 0x03660b11,
  0x06272913, 0x18030bad, 0x38002b07, 0x02180baf,
  // [3bd0]
  0x031701af, 0x103802ad, 0x272b2912, 0x66030622,
  0x451f1812, 0x060351a4, 0x0629276f, 0x18221912,
  0x06290212, 0x273f2109, 0x0f380111, 0x03001934,
  0x45001d09, 0x06001709, 0x1f290809, 0x020801a4,
  // [3be0]
  0x38043f09, 0x0b106607, 0x122b66a4, 0x0e3025bc,
  0x16001820, 0x03040509, 0x40000522, 0x4e00371f,
  0x14000511, 0x220617a4, 0x45660112, 0x251e1cad,
  0x40050da4, 0x05000122, 0x084045af, 0x020f0ba4,
  // [3bf0]
  0x040b1509, 0x0f000112, 0x0d080107, 0x01050d12,
  0x01290808, 0x18451209, 0x29272108, 0x04082912,
  0x182b0d60, 0x38160112, 0x45150860, 0x0e301c20,
  0x0d040808, 0x011027a4, 0x0f1f01a4, 0x16400da4,

  // [3c00]
  0x18451223, 0x03001822, 0x06451212, 0x03061009,
  0x10120b07, 0x19146609, 0x19060307, 0x12006608,
  0x0b150f07, 0x0d001807, 0x1c231e60, 0x03061da4,
  0x030c2907, 0x0b1d0214, 0x02006608, 0x100b2b20,
  // [3c10]
  0x12001020, 0x0c000611, 0x1d401560, 0x12452212,
  0x451206af, 0x18192208, 0x251e0e21, 0x1c232522,
  0x08660b12, 0x38220255, 0x0c060355, 0x03661d14,
  0x06660355, 0x45660312, 0x020f0d09, 0x101d4021,
  // [3c20]
  0x16000311, 0x1e250e21, 0x17161807, 0x16451213,
  0x160408a4, 0x031f3faf, 0x010b4309, 0x1d0f0808,
  0x012b1612, 0x19003809, 0x2b100208, 0x29000813,
  0x12453822, 0x15214023, 0x15044014, 0x1f002134,
  // [3c30]
  0x0d040809, 0x053f2912, 0x21003f21, 0x0c6640cf,
  0x0d0416ad, 0x121f2b60, 0x66030609, 0x010c1f34,
  0x083f27af, 0x3f03456f, 0x21000f21, 0x06002712,
  0x432b1712, 0x38004007, 0x1d150112, 0x0c006622,
  // [3c40]
  0x660603cf, 0x66060322, 0x40141660, 0x190301ac,
  0x0d0f29af, 0x38170fa4, 0x0f380d13, 0x08002211,
  0x230e2560, 0x29012baf, 0x45151608, 0x0d004513,
  0x271729af, 0x03011807, 0x08140408, 0x45001907,
  // [3c50]
  0x0d4012af, 0x0c452708, 0x0f002b11, 0x02012707,
  0x0f451407, 0x05030155, 0x38001d02, 0x04121f09,
  0x02661f09, 0x1d001f12, 0x2b2951a4, 0x0c0614ad,
  0x030d0f02, 0x0b2b2709, 0x053f2b60, 0x141d16ac,
  // [3c60]
  0x05001722, 0x2704196f, 0x45100b08, 0x18026612,
  0x04010513, 0x22124507, 0x380f10ac, 0x02000313,
  0x17020b12, 0x19040112, 0x190b1612, 0x141d18bb,
  0x191d02a4, 0x0f121f11, 0x300e1eac, 0x10014007,
  // [3c70]
  0x18191d12, 0x1d292713, 0x0f0817af, 0x0b100308,
  0x022216ac, 0x030627a4, 0x15001d02, 0x03061d07,
  0x221902a4, 0x020b2214, 0x0c000b02, 0x270d0508,
  0x100b0309, 0x0c401908, 0x2b000c20, 0x45002913,
  // [3c80]
  0x0c001521, 0x0f0d0508, 0x03180602, 0x22451509,
  0x040d1612, 0x30250e22, 0x401d0cbb, 0x02000608,
  0x14060112, 0x1d1915bc, 0x0c404512, 0x15193faf,
  0x0c1d29ad, 0x19152207, 0x04190d07, 0x06015107,
  // [3c90]
  0x01061055, 0x220121ad, 0x12001f1d, 0x160d15be,
  0x04660313, 0x0f211d11, 0x38152907, 0x04190309,
  0x15662709, 0x080601af, 0x011d4309, 0x18001512,
  0x0f050607, 0x02056609, 0x120d1fab, 0x18153f13,
  // [3ca0]
  0x18011912, 0x06011f34, 0x03060209, 0x193f0309,
  0x66030f09, 0x19210321, 0x00002b42, 0x12450809,
  0x1e230e22, 0x43220b12, 0x12450507, 0x06004321,
  0x10010d02, 0x02433809, 0x1d660baf, 0x033801ac,
  // [3cb0]
  0x10001511, 0x04010baf, 0x0d010207, 0x0b0c01a4,
  0x0d1218a4, 0x15145112, 0x08152908, 0x17011507,
  0x080d0f12, 0x190c12a4, 0x3f661aaf, 0x01103812,
  0x451412ac, 0x14124555, 0x160140a4, 0x270229af,
  // [3cc0]
  0x01050bad, 0x2b001922, 0x17122b12, 0x06022b07,
  0x020b1d08, 0x0c181d08, 0x220827af, 0x40210808,
  0x05380309, 0x124540a4, 0x062b2709, 0x03042108,
  0x12002b22, 0x122b1911, 0x10060b14, 0x010208a4,
  // [3cd0]
  0x45006608, 0x66001421, 0x0b271008, 0x15124560,
  0x15004011, 0x01006609, 0x02061812, 0x40002708,
  0x032b01af, 0x01032707, 0x06010508, 0x0c451daf,
  0x0f382207, 0x012b1711, 0x3f002221, 0x0f0d0121,
  // [3ce0]
  0x27000420, 0x43013812, 0x120c1d13, 0x01052107,
  0x02272909, 0x19050607, 0x191f3f08, 0x01030b09,
  0x23002508, 0x01152709, 0x01030f09, 0x451202ad,
  0x163f27af, 0x08380607, 0x0f1705bb, 0x06052708,
  // [3cf0]
  0x40170521, 0x010219ad, 0x03170f07, 0x0d050f14,
  0x17380512, 0x301e2307, 0x1d000521, 0x1d1705bc,
  0x0b010355, 0x400f0521, 0x3f292723, 0x0e1e23bb,
  0x06010308, 0x43272912, 0x22290307, 0x452927af,
  // [3d00]
  0x02270112, 0x0f0108af, 0x1f1701af, 0x38272909,
  0x060d17a4, 0x14001811, 0x080d0fa4, 0x10001914,
  0x40121da4, 0x38430112, 0x06082707, 0x1d190407,
  0x010c2bad, 0x450c2b08, 0x04024309, 0x1727296f,
  // [3d10]
  0x381801af, 0x02036655, 0x15041922, 0x05060122,
  0x22010f09, 0x10660b09, 0x010f1f09, 0x0f020b12,
  0x21431f23, 0x024317cf, 0x400d1d09, 0x01060f09,
  0x031d4022, 0x0c064523, 0x00003f42, 0x293f2121,
  // [3d20]
  0x19292760, 0x18004334, 0x1d452134, 0x27002120,
  0x05173833, 0x06222121, 0x1f080d14, 0x660340be,
  0x27293f13, 0x3f002223, 0x05000821, 0x02106612,
  0x06276607, 0x22190411, 0x66212912, 0x10000508,
  // [3d30]
  0x12020ba4, 0x27000512, 0x40121d02, 0x181d2211,
  0x06032707, 0x02221608, 0x250e1cac, 0x0d180812,
  0x17002707, 0x0e1e2355, 0x16000511, 0x14001810,
  0x19150112, 0x16006611, 0x0d380f02, 0x0c001002,
  // [3d40]
  0x1d061909, 0x30251c60, 0x38004511, 0x270304bc,
  0x03272912, 0x27220412, 0x05004307, 0x0e1e3012,
  0x0b0429a4, 0x04272911, 0x06082712, 0x0b140209,
  0x1f082b11, 0x172b0f55, 0x03222955, 0x170d0112,
  // [3d50]
  0x05000d02, 0x180114ad, 0x14045112, 0x221627a4,
  0x43012908, 0x080f3807, 0x43060155, 0x30001e11,
  0x08272908, 0x16001435, 0x19001f08, 0x04005108,
  0x1d000302, 0x15165111, 0x06036611, 0x27432913,
  // [3d60]
  0x01660509, 0x01030f02, 0x05382909, 0x38170809,
  0x02121d07, 0x0e2523bc, 0x0b002208, 0x45001514,
  0x04000122, 0x404512ad, 0x04001508, 0x18041909,
  0x0e1e2502, 0x301e0e09, 0x0f1f1821, 0x04103fa4,
  // [3d70]
  0x0d051f55, 0x231c1e08, 0x1e300e02, 0x160c0fa4,
  0x30251c21, 0x0c001f13, 0x40003f14, 0x16220fa4,
  0x0f181212, 0x18001222, 0x1f0f186f, 0x1f0f45af,
  0x08041fac, 0x19002134, 0x01056607, 0x292751a4,
  // [3d80]
  0x12020307, 0x22272912, 0x06660322, 0x01061008,
  0x15000c07, 0x120d1508, 0x030c4555, 0x05180309,
  0x15161d07, 0x062915bb, 0x17032912, 0x291921af,
  0x0b0814ac, 0x020301af, 0x14181008, 0x38272922,
  // [3d90]
  0x120b0209, 0x10040209, 0x01001921, 0x12174509,
  0x060214a4, 0x020b2ba4, 0x0d172207, 0x19100455,
  0x0b660412, 0x0b190609, 0x21050d12, 0x45180f12,
  0x05001213, 0x12050d55, 0x10182107, 0x2b010c09,
  // [3da0]
  0x220801ad, 0x382b01a4, 0x011d2207, 0x2b020b09,
  0x0b011d12, 0x272922be, 0x2b002220, 0x080501bb,
  0x430129af, 0x06004023, 0x10223f60, 0x10220814,
  0x221f06be, 0x01181a12, 0x0d002211, 0x01192709,
  // [3db0]
  0x1d001714, 0x0c000608, 0x1d122912, 0x0c1d3f08,
  0x03140221, 0x273f6613, 0x430c3f09, 0x1f216609,
  0x170214ac, 0x02006620, 0x0b026611, 0x1d451209,
  0x12382707, 0x43001820, 0x17000309, 0x1d124522,
  // [3dc0]
  0x1200450d, 0x17006623, 0x1f2901ad, 0x66000214,
  0x1c251ebc, 0x012b1002, 0x12001408, 0x04066607,
  0x06030555, 0x012b66a4, 0x1d400c21, 0x14060312,
  0x45001411, 0x380d0809, 0x031466a4, 0x051701af,
  // [3dd0]
  0x0b161513, 0x08001709, 0x02273f12, 0x01191d07,
  0x18001408, 0x191d4012, 0x01210855, 0x14020b20,
  0x0c000822, 0x01062712, 0x43000807, 0x40192912,
  0x053f0812, 0x43000808, 0x0e251e6f, 0x02150b09,
  // [3de0]
  0x17181d12, 0x06040112, 0x06400808, 0x08000512,
  0x10013fac, 0x1d0802a4, 0x010b5112, 0x0c122912,
  0x17000f08, 0x0610026f, 0x291d2712, 0x0d171912,
  0x22013807, 0x1e2523ad, 0x381827a4, 0x21051960,
  // [3df0]
  0x050c1207, 0x08002913, 0x021006af, 0x12451fa4,
  0x06010809, 0x251e1c02, 0x17003808, 0x15001920,
  0x062b01ad, 0x0e1e2313, 0x06050111, 0x66001d09,
  0x40154512, 0x17400c12, 0x16381912, 0x02275112,
  // [3e00]
  0x27162909, 0x04031709, 0x012b0fad, 0x38002b33,
  0x0c1d406f, 0x06430108, 0x17100213, 0x06022955,
  0x100b0408, 0x0b4001af, 0x011f6609, 0x16036608,
  0x08002712, 0x0d0b086f, 0x380529af, 0x02100d09,
  // [3e10]
  0x21002708, 0x012710ad, 0x0d001f09, 0x0b1003a4,
  0x430f0d11, 0x03061713, 0x0c210b09, 0x04062b07,
  0x292740bb, 0x124305a4, 0x0e301c21, 0x060538af,
  0x170127af, 0x0f0d0baf, 0x060515bc, 0x06001920,
  // [3e20]
  0x15004022, 0x06660213, 0x45181208, 0x1d161212,
  0x38060113, 0x02063807, 0x05003821, 0x01380f08,
  0x0f0d1709, 0x06000513, 0x19020baf, 0x380605ad,
  0x0f381509, 0x05193809, 0x15103809, 0x03001808,
  // [3e30]
  0x1c251e23, 0x0000380a, 0x01192911, 0x30001e23,
  0x19000221, 0x29271912, 0x01030ba4, 0x292719bb,
  0x0b0402a4, 0x10023809, 0x1929276f, 0x12004535,
  0x10080609, 0x10004020, 0x18002908, 0x1d056655,
  // [3e40]
  0x06192709, 0x02100512, 0x231c0e13, 0x400121ac,
  0x160f0da4, 0x0d001f1d, 0x45160f02, 0x0d0f0855,
  0x011d1008, 0x0b080212, 0x06000f11, 0x0b0227af,
  0x15003809, 0x0d080f08, 0x25300ead, 0x3f27296f,
  // [3e50]
  0x02190655, 0x300e23ad, 0x161d1008, 0x036610be,
  0x0c030107, 0x101d66a4, 0x27014309, 0x400f1dac,
  0x10170107, 0x01182255, 0x080f01a4, 0x1d403fad,
  0x04011d08, 0x0d2229ad, 0x0d170fa4, 0x401d3f23,
  // [3e60]
  0x01061012, 0x21012709, 0x1d2b1f07, 0x27000120,
  0x291208be, 0x220c4511, 0x0b002b02, 0x40123f08,
  0x10012108, 0x66100609, 0x01002b20, 0x1d002121,
  0x3f164013, 0x03062107, 0x041801af, 0x06002111,
  // [3e70]
  0x103f0b12, 0x19273f08, 0x01181609, 0x660d1709,
  0x14291d07, 0x01191aa4, 0x16381420, 0x0d173809,
  0x0f100d09, 0x01162708, 0x031001ad, 0x15293f12,
  0x036612af, 0x02003802, 0x010c6607, 0x12292760,
  // [3e80]
  0x0d1d1707, 0x0d002112, 0x14401921, 0x01292155,
  0x1d191021, 0x062751a4, 0x661f01ad, 0x12270baf,
  0x08063fac, 0x120140bc, 0x150f2b60, 0x2b000b02,
  0x01082bac, 0x01020b12, 0x0c0845af, 0x38050607,
  // [3e90]
  0x25000e09, 0x020b66a4, 0x02050807, 0x01080607,
  0x150c01af, 0x14190422, 0x2b063812, 0x0d380522,
  0x0d4027af, 0x150419ac, 0x1e0e2514, 0x14012209,
  0x0d3814a4, 0x38080112, 0x101f2912, 0x45126607,
  // [3ea0]
  0x0f0d3823, 0x15051607, 0x45000f08, 0x0d3851af,
  0x012729bc, 0x1e231c09, 0x38272960, 0x380d1009,
  0x272903af, 0x03020fa4, 0x12012707, 0x012229af,
  0x04020112, 0x06151960, 0x01082182, 0x40001607,
  // [3eb0]
  0x05061d09, 0x0f0d3807, 0x2b1f3f09, 0x020108bc,
  0x0e302314, 0x45121411, 0x0d080fbe, 0x01026608,
  0x04192712, 0x43450112, 0x0b012712, 0x45120ca4,
  0x0f4008a4, 0x02000d14, 0x03010508, 0x0e231e20,
  // [3ec0]
  0x03170607, 0x06020f12, 0x08004012, 0x02380ba4,
  0x010f0daf, 0x0f053814, 0x030f0d14, 0x0f080daf,
  0x231c3002, 0x0d000520, 0x38051913, 0x05002713,
  0x0f040307, 0x45222955, 0x03191008, 0x0d001708,
  // [3ed0]
  0x0d222707, 0x0b0227ac, 0x210f0d14, 0x122716a4,
  0x0d080fa4, 0x12224507, 0x012138a4, 0x02663f08,
  0x18012108, 0x0666036f, 0x14400808, 0x100105a4,
  0x100b1612, 0x08010308, 0x01382107, 0x06001513,
  // [3ee0]
  0x43003814, 0x08170d09, 0x01213f11, 0x45121dbe,
  0x21100b12, 0x400c1d23, 0x22014307, 0x03051707,
  0x151604af, 0x40451d13, 0x30230e22, 0x3f001814,
  0x0d2b0155, 0x04190109, 0x032b0108, 0x14001020,
  // [3ef0]
  0x16196660, 0x17010b12, 0x3f001514, 0x020b10be,
  0x12272922, 0x04195112, 0x081f0522, 0x1d054009,
  0x1d154055, 0x18000112, 0x04153f6f, 0x1d170533,
  0x0f001922, 0x27003f13, 0x21000f08, 0x03661020,
  // [3f00]
  0x08046655, 0x29042723, 0x0c004321, 0x04194012,
  0x19222108, 0x01030807, 0x06000f13, 0x01082908,
  0x45120f09, 0x0d010fad, 0x06010b12, 0x0b1902af,
  0x1d036682, 0x15662712, 0x04050208, 0x01100807,
  // [3f10]
  0x0f0d2109, 0x29401d09, 0x05010602, 0x12451d02,
  0x066605af, 0x03220107, 0x01061709, 0x230e1e07,
  0x30230e13, 0x03081702, 0x17661013, 0x0f0d0112,
  0x17211420, 0x17002223, 0x1d1240af, 0x221d0308,
  // [3f20]
  0x19150455, 0x17212221, 0x08030d09, 0x230e1cac,
  0x22213f14, 0x141d0812, 0x01002709, 0x05081407,
  0x21081709, 0x08173fbe, 0x17224012, 0x050119a4,
  0x40140b12, 0x0c224021, 0x08190421, 0x01041912,
  // [3f30]
  0x0f1004ad, 0x01120408, 0x10040814, 0x050666a4,
  0x01053f12, 0x19080412, 0x1e2523af, 0x2b101412,
  0x22002909, 0x010204ad, 0x19040812, 0x14001009,
  0x0d0f1412, 0x16004507, 0x03276655, 0x0d2b2207,
  // [3f40]
  0x22060314, 0x45001809, 0x16000308, 0x1c251e20,
  0x08010302, 0x1e231c13, 0x04220112, 0x450d18ad,
  0x1d014307, 0x120c4011, 0x08181521, 0x3f1d08be,
  0x1d001708, 0x3f401d21, 0x15000811, 0x06160807,
  // [3f50]
  0x29000808, 0x66003f14, 0x171d0812, 0x3f000821,
  0x451208be, 0x40060813, 0x01000c02, 0x16001414,
  0x1f2215bc, 0x06016612, 0x19146607, 0x380f0d02,
  0x06270355, 0x1c252312, 0x0c050607, 0x03660507,
  // [3f60]
  0x10000b36, 0x010603a4, 0x45010512, 0x0c004509,
  0x452b6608, 0x010d05a4, 0x401d1012, 0x230e25ad,
  0x0b660320, 0x1e302302, 0x01041d09, 0x1d1851af,
  0x1d0c3f21, 0x150c21a4, 0x45011d02, 0x140121a4,
  // [3f70]
  0x080d15a4, 0x25301e21, 0x664515bb, 0x12060f07,
  0x19080355, 0x40080108, 0x301e23af, 0x03661513,
  0x18401d09, 0x23302507, 0x080f3f08, 0x01032ba4,
  0x660d08af, 0x080c0620, 0x02000813, 0x45122112,
  // [3f80]
  0x29084512, 0x08380d14, 0x210f27af, 0x4e372355,
  0x400f0d07, 0x45161521, 0x181d0807, 0x03150421,
  0x150f3820, 0x01432155, 0x12081713, 0x0c150807,
  0x1d0845af, 0x18002b12, 0x23301e14, 0x3f0127af,
  // [3f90]
  0x17010f09, 0x15161912, 0x27290813, 0x060d0102,
  0x193f29af, 0x04163f21, 0x27003f20, 0x190110ad,
  0x06171509, 0x033f2113, 0x220c21af, 0x01100207,
  0x17004309, 0x2b222160, 0x19012909, 0x01080f08,
  // [3fa0]
  0x04380faf, 0x082201af, 0x03400107, 0x020b4308,
  0x18123f12, 0x00000142, 0x66140234, 0x2b001433,
  0x01080608, 0x010217a4, 0x030d17a4, 0x380b05a4,
  0x15000513, 0x301e1c34, 0x01381507, 0x15000409,
  // [3fb0]
  0x10182112, 0x1d451207, 0x381d1608, 0x43170112,
  0x011551a4, 0x1d006608, 0x19011512, 0x29270c09,
  0x06100211, 0x01126609, 0x08001512, 0x16272911,
  0x0c001921, 0x173f3813, 0x1d0c1714, 0x401d1620,
  // [3fc0]
  0x0d120602, 0x38034509, 0x101951af, 0x45061d11,
  0x162927a4, 0x05000302, 0x1d0608a4, 0x19002714,
  0x060b0260, 0x27100baf, 0x0f272908, 0x45022b12,
  0x0b0129a4, 0x04273f09, 0x29002122, 0x16172223,
  // [3fd0]
  0x27221f12, 0x03010b08, 0x052721af, 0x061002af,
  0x050d1009, 0x030119a4, 0x160427a4, 0x05002913,
  0x0d0829af, 0x271621be, 0x432927ad, 0x080d2909,
  0x1e2530a4, 0x430401a4, 0x30250e55, 0x1e0e1c55,
  // [3fe0]
  0x012b0612, 0x080f3802, 0x230e30af, 0x05011707,
  0x450c1609, 0x1d401255, 0x03011007, 0x04171f20,
  0x45151609, 0x660403a4, 0x1d190d02, 0x10066607,
  0x18001f11, 0x0b0614ad, 0x1e253021, 0x0f0106ad,
  // [3ff0]
  0x0000220a, 0x43380f07, 0x06142108, 0x3f000614,
  0x272906af, 0x18080f12, 0x10030621, 0x29382708,
  0x06003f20, 0x16004011, 0x27100621, 0x18100baf,
  0x06292714, 0x21043f20, 0x21001f12, 0x29213fbe,

  // [4000]
  0x1d081212, 0x021743a4, 0x2b002114, 0x27451260,
  0x04036660, 0x010419ac, 0x18431422, 0x16030509,
  0x050d3809, 0x40001214, 0x061403a4, 0x080301af,
  0x01190620, 0x0d0f4507, 0x190c51a4, 0x66060308,
  // [4010]
  0x1d401260, 0x19030212, 0x07005c34, 0x12450609,
  0x16183812, 0x23300ebc, 0x02000311, 0x01401fa4,
  0x01381d07, 0x082b0413, 0x19290daf, 0x1f2b0109,
  0x010308ac, 0x16270112, 0x40150408, 0x143f0814,
  // [4020]
  0x251e2309, 0x1c230eac, 0x16031013, 0x03026613,
  0x2b0140bc, 0x0d193fac, 0x290427af, 0x660d3821,
  0x01083809, 0x03000409, 0x1d662712, 0x05161912,
  0x12430308, 0x011f2b60, 0x08272960, 0x66030b12,
  // [4030]
  0x1d402909, 0x2b036633, 0x1d402109, 0x660319be,
  0x29105112, 0x1d192107, 0x151421ad, 0x451612ad,
  0x16105112, 0x0d0366bc, 0x663f0112, 0x10030112,
  0x032b6614, 0x45121412, 0x0d0f1d08, 0x121d4014,
  // [4040]
  0x190304ac, 0x12041d09, 0x06001423, 0x29271d08,
  0x45661f08, 0x12160802, 0x401d0213, 0x1e302309,
  0x161d405e, 0x081701a4, 0x0b042107, 0x041019ad,
  0x011904ad, 0x1f002213, 0x45190302, 0x66060112,
  // [4050]
  0x060405af, 0x03661aaf, 0x210327af, 0x03010855,
  0x66190112, 0x223f0fbc, 0x15004008, 0x0f080509,
  0x1d0d0f08, 0x190d0f14, 0x0f1729a4, 0x12404521,
  0x10036608, 0x0806666f, 0x0d000808, 0x12660312,
  // [4060]
  0x0b0f0d02, 0x43161555, 0x190f0d13, 0x19220809,
  0x1d000d12, 0x40100d13, 0x0f190112, 0x21002221,
  0x12184512, 0x04272908, 0x05170112, 0x2b004312,
  0x66190309, 0x434505a4, 0x0e1e1c09, 0x0f050d13,
  // [4070]
  0x1c253009, 0x03003808, 0x12400c12, 0x1e2325a4,
  0x3f451213, 0x06041008, 0x06001214, 0x02401d11,
  0x0f1704af, 0x020666a4, 0x38081f12, 0x40451d14,
  0x02430608, 0x01004012, 0x06220b07, 0x18001a13,
  // [4080]
  0x01031708, 0x451d1008, 0x150112a4, 0x19001413,
  0x0c0345a4, 0x101d0413, 0x0c180455, 0x0c034502,
  0x100f0ba4, 0x10001f12, 0x380b43a4, 0x1d001534,
  0x14061aa4, 0x1d044023, 0x45183f13, 0x290151af,
  // [4090]
  0x061d4007, 0x08001807, 0x10401daf, 0x0f000509,
  0x190f4060, 0x0b001d21, 0x01431d08, 0x03066660,
  0x020b2909, 0x1c300ead, 0x17004312, 0x04451d08,
  0x03044008, 0x18000d12, 0x250e3021, 0x23001c21,
  // [40a0]
  0x0f180d02, 0x0c0645a4, 0x0d101407, 0x18001012,
  0x102b0612, 0x17010307, 0x01210f12, 0x45042121,
  0x082729be, 0x140666af, 0x381d0d09, 0x10140b12,
  0x051d3809, 0x10002111, 0x0d2108bc, 0x170f0813,
  // [40b0]
  0x0b011055, 0x43006622, 0x0d060f12, 0x12660112,
  0x124538af, 0x12664312, 0x080f2109, 0x0d013f21,
  0x0c660112, 0x430c2ba4, 0x12002b12, 0x150c17af,
  0x43010309, 0x05001410, 0x03000c13, 0x01042207,
  // [40c0]
  0x43222907, 0x66002b35, 0x05150cbb, 0x17451f09,
  0x10451260, 0x060c0811, 0x21004312, 0x45010509,
  0x450c2212, 0x01000602, 0x1c1e236f, 0x0b000807,
  0x0b451d60, 0x0c1206a4, 0x0d160f09, 0x10062b08,
  // [40d0]
  0x010608a4, 0x25301ea4, 0x08166609, 0x03061055,
  0x0e251e55, 0x0c001907, 0x010f2955, 0x211002af,
  0x0e1c2522, 0x040c29af, 0x0b0c1613, 0x210f2208,
  0x062b1613, 0x01172b08, 0x273f2160, 0x14041812,
  // [40e0]
  0x21160508, 0x020601af, 0x0c100b02, 0x1d181912,
  0x03401d02, 0x22080512, 0x03040ba4, 0x02000420,
  0x106603ad, 0x01051d07, 0x15001009, 0x1f0f0d09,
  0x18100ba4, 0x1d041960, 0x01021608, 0x16013860,
  // [40f0]
  0x12001912, 0x15063807, 0x02181008, 0x14191009,
  0x0b0110af, 0x01100b22, 0x231c0eac, 0x301e0e55,
  0x1e0e1c20, 0x08004002, 0x0c0b0607, 0x050106a4,
  0x0c0b1407, 0x081d0407, 0x40001522, 0x03061409,
  // [4100]
  0x0f033fa4, 0x160121a4, 0x190d0807, 0x14162712,
  0x0d170f55, 0x2b060213, 0x02660313, 0x231c1e09,
  0x0c1d2955, 0x213822ad, 0x660201af, 0x45001d13,
  0x060138a4, 0x40121760, 0x013f0613, 0x23003035,
  // [4110]
  0x050666be, 0x22000f09, 0x16000f21, 0x060366bb,
  0x19100312, 0x1d120caf, 0x121d4011, 0x01384308,
  0x12454023, 0x663f0b12, 0x030102ad, 0x100c0b07,
  0x02101809, 0x140b1912, 0x0d1508ad, 0x380d05a4,
  // [4120]
  0x40121d14, 0x17120809, 0x14190208, 0x19046607,
  0x03021812, 0x03010511, 0x22021707, 0x10291411,
  0x2b161412, 0x03190b09, 0x0e1e1cac, 0x14190420,
  0x22000414, 0x03060b02, 0x03190112, 0x04190360,
  // [4130]
  0x0d001914, 0x661701af, 0x02060107, 0x18000822,
  0x10060802, 0x2b001402, 0x19210f08, 0x66060109,
  0x03050109, 0x01050613, 0x660221bc, 0x231e2521,
  0x01176609, 0x451d1655, 0x08003814, 0x05031755,
  // [4140]
  0x0d430107, 0x38060108, 0x03190da4, 0x18161508,
  0x0c016607, 0x05011908, 0x38021908, 0x06006622,
  0x3f0127a4, 0x06006612, 0x100f0b14, 0x04000520,
  0x0b660360, 0x1d003f09, 0x03192212, 0x19001422,
  // [4150]
  0x40020ba4, 0x05151012, 0x182b1f21, 0x12000313,
  0x14170814, 0x45404302, 0x1d010fad, 0x15101608,
  0x16002213, 0x16141913, 0x660351af, 0x251e0e20,
  0x0b1d2707, 0x101903a4, 0x213f22af, 0x220429a4,
  // [4160]
  0x04191455, 0x23001e02, 0x041615ac, 0x291922af,
  0x01124520, 0x0c001922, 0x04190b07, 0x041422ac,
  0x12451908, 0x45401dbe, 0x21021009, 0x141922bc,
  0x124540be, 0x19041411, 0x1e003020, 0x38124509,
  // [4170]
  0x06010502, 0x0e1c30af, 0x12272911, 0x02100412,
  0x66030809, 0x171f2209, 0x033817a4, 0x060104ad,
  0x22121d07, 0x380508af, 0x1c0e23be, 0x06140ba4,
  0x02001022, 0x1f4512af, 0x020b06ad, 0x22052b07,
  // [4180]
  0x0c6603af, 0x2b273f12, 0x01031902, 0x0c170112,
  0x03660412, 0x14000c13, 0x2b002107, 0x040103af,
  0x05002213, 0x1d2240be, 0x060d0f55, 0x1d003f20,
  0x27001f08, 0x3f001722, 0x38102107, 0x01063f07,
  // [4190]
  0x060c2107, 0x010c06ad, 0x29663f12, 0x08211609,
  0x01120507, 0x12050dad, 0x450d17a4, 0x29272109,
  0x1d063812, 0x2b001709, 0x14063f08, 0x10140207,
  0x0d0651a4, 0x12000512, 0x05000d20, 0x0c002711,
  // [41a0]
  0x04291621, 0x191601af, 0x0f0d1609, 0x00000215,
  0x0d0821bc, 0x43273fad, 0x141d1612, 0x141806ad,
  0x08380112, 0x10000809, 0x06051560, 0x0e1c23af,
  0x14153812, 0x17380521, 0x10190413, 0x0e232512,
  // [41b0]
  0x05013809, 0x05080408, 0x10170812, 0x10061709,
  0x161d4082, 0x380b0507, 0x19026607, 0x191766a4,
  0x1c1e25ad, 0x0d000111, 0x17036607, 0x38036613,
  0x046601ad, 0x17030112, 0x1e233009, 0x10060202,
  // [41c0]
  0x18100607, 0x0f036655, 0x030d6613, 0x2b1601ad,
  0x1d02056f, 0x27081408, 0x10061507, 0x03050655,
  0x01450808, 0x06140b55, 0x0b151602, 0x020b15ad,
  0x296627a4, 0x0b380502, 0x40451dad, 0x04066612,
  // [41d0]
  0x04020307, 0x10190b09, 0x041d40af, 0x143f1960,
  0x10140b02, 0x271d0c12, 0x04036655, 0x041214ac,
  0x16100208, 0x0b010c09, 0x020b10ad, 0x0e1c2521,
  0x661910af, 0x0d2201af, 0x40020b09, 0x45120dbc,
  // [41e0]
  0x2b0108a4, 0x061927af, 0x12100b02, 0x0b0c1d14,
  0x02001807, 0x0d190455, 0x22170812, 0x06223807,
  0x160c1da4, 0x40181908, 0x250e1c55, 0x1d160407,
  0x2b2706a4, 0x010f0808, 0x081f0112, 0x05220da4,
  // [41f0]
  0x29271d6f, 0x051538be, 0x06100b09, 0x05003820,
  0x01000213, 0x030b2b07, 0x19660421, 0x22001907,
  0x2b061f12, 0x38030111, 0x40000c07, 0x0b021423,
  0x170b1009, 0x030166af, 0x1d060802, 0x02032212,
  // [4200]
  0x0b031009, 0x45022260, 0x40000309, 0x2b001012,
  0x1c231eaf, 0x19000f11, 0x03001002, 0x19044013,
  0x2b020b13, 0x1d026609, 0x12181412, 0x040c4007,
  0x1d194013, 0x660c12af, 0x022b0baf, 0x45184360,
  // [4210]
  0x01191609, 0x380d01a4, 0x041905ac, 0x08190508,
  0x191d0409, 0x301c0e21, 0x0b3805a4, 0x08663808,
  0x1e003008, 0x0b160107, 0x05013f60, 0x1d080512,
  0x04061f08, 0x10021909, 0x1d0203bb, 0x0d3f0608,
  // [4220]
  0x2b0d0f08, 0x05010609, 0x30002508, 0x060f0209,
  0x21171aaf, 0x170f0d02, 0x02030621, 0x08050b60,
  0x221704ac, 0x081001af, 0x01380d07, 0x1e0e1c14,
  0x0f660508, 0x21660320, 0x050f3821, 0x154527a4,
  // [4230]
  0x40050112, 0x06290107, 0x45291609, 0x01661a12,
  0x0f000411, 0x1d0d4560, 0x050d0faf, 0x1d104009,
  0x180801af, 0x0c2b14a4, 0x19000107, 0x080d386f,
  0x381501af, 0x01140509, 0x0b3f0111, 0x66121d09,
  // [4240]
  0x021014a4, 0x030666ad, 0x100127af, 0x0c2b2108,
  0x382101af, 0x1d000309, 0x661222af, 0x01053808,
  0x101403a4, 0x0c401dbc, 0x0e301c08, 0x011910ad,
  0x0b000f08, 0x05036607, 0x08011013, 0x030b1020,
  // [4250]
  0x1e1c0e55, 0x45000608, 0x10140b09, 0x0e1e2523,
  0x45190cad, 0x0c401913, 0x1d044002, 0x104051a4,
  0x0c062907, 0x301e1c07, 0x0c006611, 0x171921a4,
  0x2b401d09, 0x081201a4, 0x191d22ad, 0x081901af,
  // [4260]
  0x192216a4, 0x181451af, 0x190445af, 0x1d001408,
  0x03270209, 0x0c1851af, 0x2b061460, 0x18145111,
  0x0c003809, 0x03101807, 0x0f001d11, 0x66181460,
  0x06181413, 0x0f143809, 0x010f1f07, 0x27193f11,
  // [4270]
  0x19271d07, 0x17080f11, 0x381601af, 0x1c251e11,
  0x1d0f40af, 0x45101d12, 0x030b1802, 0x10011f09,
  0x190427af, 0x01001f08, 0x10040213, 0x15000602,
  0x27002b09, 0x0f004008, 0x0f0805af, 0x1d000c21,
  // [4280]
  0x0b026613, 0x041519af, 0x21000612, 0x1c0e3008,
  0x0b0c0207, 0x1d270109, 0x080d1821, 0x16122160,
  0x450d0f07, 0x40161510, 0x05010d60, 0x43222107,
  0x18450f12, 0x25302308, 0x290d1009, 0x170f0dbe,
  // [4290]
  0x0f210d07, 0x0f002111, 0x12451602, 0x02380514,
  0x01050d09, 0x0c1f0111, 0x051d40a4, 0x152729af,
  0x01160812, 0x08020607, 0x1d010caf, 0x140608a4,
  0x1d044512, 0x12454009, 0x66160d12, 0x0d000807,
  // [42a0]
  0x02190111, 0x16010808, 0x0d080c12, 0x141801a4,
  0x27032909, 0x161738ad, 0x66080112, 0x66080b12,
  0x1d1745af, 0x171622a4, 0x22381921, 0x18000b22,
  0x300e23bb, 0x19660307, 0x0e251eac, 0x45400307,
  // [42b0]
  0x30231cad, 0x010d0f07, 0x04001512, 0x192b2212,
  0x06220f07, 0x02010fa4, 0x0d380514, 0x05041911,
  0x0f220112, 0x301e2522, 0x15003812, 0x05001811,
  0x1516196f, 0x0c0b0807, 0x17080513, 0x171f0512,
  // [42c0]
  0x38010509, 0x220619a4, 0x291d0112, 0x22020b12,
  0x020b0d09, 0x19001423, 0x06046621, 0x0c1d4023,
  0x17121d09, 0x10021412, 0x101406bc, 0x15001913,
  0x25002320, 0x16195112, 0x121d0c13, 0x140119a4,
  // [42d0]
  0x150b1921, 0x0d040f07, 0x1e0e30ad, 0x1c2325ad,
  0x0d180fad, 0x081619a4, 0x0d050f07, 0x180d0f08,
  0x272221af, 0x0c401d11, 0x19003808, 0x101421a4,
  0x082221af, 0x2b220cad, 0x14212708, 0x0c223860,
  // [42e0]
  0x161d4060, 0x0d000f36, 0x383f51a4, 0x0000050a,
  0x0f020b02, 0x271d2112, 0x27211920, 0x0b102b09,
  0x1d101560, 0x14290b09, 0x02222712, 0x3f001923,
  0x05292712, 0x0f191713, 0x0b2b1012, 0x01220f07,
  // [42f0]
  0x06010208, 0x1d381912, 0x0c1d0412, 0x0b192ba4,
  0x020b3f12, 0x19143f13, 0x01082bad, 0x082729af,
  0x270d3809, 0x120f0d55, 0x0f002b13, 0x0e2530a4,
  0x0e301e21, 0x00000c03, 0x0322666f, 0x06002222,
  // [4300]
  0x45180511, 0x03152708, 0x0d001208, 0x2b001413,
  0x10010302, 0x06012155, 0x0f180521, 0x0b661f21,
  0x0b020509, 0x17272913, 0x38451212, 0x0c002221,
  0x18272908, 0x27182912, 0x1d4502a4, 0x03150409,
  // [4310]
  0x0b182708, 0x01060b21, 0x230e1cad, 0x22000b09,
  0x431f01af, 0x29036612, 0x030b5107, 0x01060b12,
  0x05000614, 0x16020b6f, 0x21221712, 0x05006607,
  0x2b0c4012, 0x38000635, 0x0f381f12, 0x0c004021,
  // [4320]
  0x2b3f2711, 0x01193809, 0x1d0b0112, 0x270c4013,
  0x430c0107, 0x16001d13, 0x1d381712, 0x02660fa4,
  0x250e23ac, 0x27011d09, 0x0c014308, 0x01100b08,
  0x14001213, 0x401216a4, 0x0d0827af, 0x084512af,
  // [4330]
  0x38191022, 0x380f0108, 0x25301e22, 0x29010821,
  0x300e2314, 0x40162207, 0x15001636, 0x04013807,
  0x1d173f09, 0x27290809, 0x190604a4, 0x380b0209,
  0x04171907, 0x01450d55, 0x152b1f13, 0x0b1d0d13,
  // [4340]
  0x02660312, 0x101d0520, 0x0c004013, 0x1d006612,
  0x15001f12, 0x1e0e25af, 0x293f21a4, 0x011f06af,
  0x2740026f, 0x16004007, 0x040151af, 0x06222912,
  0x081d4512, 0x05190612, 0x05000421, 0x451812ac,
  // [4350]
  0x17080112, 0x221d4021, 0x05010f09, 0x012b22bc,
  0x45120bad, 0x012906ad, 0x02101daf, 0x01180512,
  0x04000114, 0x29213f08, 0x30230ead, 0x03220112,
  0x17050812, 0x0b1803af, 0x05012221, 0x03661023,
  // [4360]
  0x14053f12, 0x0b043809, 0x17000412, 0x05040213,
  0x141822ad, 0x05000414, 0x0f180507, 0x0f001611,
  0x38164308, 0x081d27af, 0x010306a4, 0x0b380f07,
  0x0c060311, 0x45124055, 0x03010612, 0x0c060813,
  // [4370]
  0x1d0110a4, 0x27160421, 0x0d000523, 0x0c0805bb,
  0x12000c08, 0x0f000611, 0x18000f22, 0x080105af,
  0x010d0fa4, 0x0f053821, 0x38050fbe, 0x3f212912,
  0x27212922, 0x03663faf, 0x40211dbe, 0x45380f07,
  // [4380]
  0x12003809, 0x0f1f0809, 0x18290d12, 0x0f0c1d12,
  0x22003f34, 0x18000813, 0x0f430802, 0x04080111,
  0x171618be, 0x29102121, 0x0b001412, 0x0d162712,
  0x231c1eaf, 0x22170f13, 0x0c2221ad, 0x01221607,
  // [4390]
  0x03052707, 0x172227a4, 0x1e0e2307, 0x01270f12,
  0x100b6609, 0x450d0f11, 0x0f012907, 0x0d140f09,
  0x06001213, 0x01001608, 0x0b451255, 0x080f17a4,
  0x301e0e07, 0x0c000809, 0x01291755, 0x02030555,
  // [43a0]
  0x19162109, 0x0f0d3802, 0x0c661609, 0x041d4020,
  0x40001613, 0x17000d14, 0x021d0b60, 0x01033860,
  0x0d020812, 0x022b0dbe, 0x182729bc, 0x432710ad,
  0x27290420, 0x060f3814, 0x0f013fa4, 0x0b272909,
  // [43b0]
  0x38292bbe, 0x0b1027af, 0x212b2913, 0x01210baf,
  0x15662bbc, 0x15010807, 0x0c000b14, 0x1002016f,
  0x04061607, 0x03041607, 0x100f45a4, 0x66002121,
  0x3f292121, 0x231c0e22, 0x21162712, 0x10293f22,
  // [43c0]
  0x193f21ce, 0x40272921, 0x08050d14, 0x01002110,
  0x101d21af, 0x45272912, 0x121d4008, 0x0b021609,
  0x273f216f, 0x1d211013, 0x290317af, 0x1d0d0808,
  0x18000514, 0x1d292721, 0x061410a4, 0x0d006614,
  // [43d0]
  0x2b2708bb, 0x2b003812, 0x66020314, 0x08000c12,
  0x1c2523af, 0x10001435, 0x0b273855, 0x05030d02,
  0x16002107, 0x020310bb, 0x0b100222, 0x3f271d08,
  0x12451412, 0x161419a4, 0x12450208, 0x40000f07,
  // [43e0]
  0x03014308, 0x170b16a4, 0x0c1666af, 0x43000602,
  0x1d020b14, 0x15166614, 0x0c210808, 0x192729bb,
  0x29271d12, 0x400b1012, 0x03051f6f, 0x0b0251a4,
  0x29060308, 0x140203a4, 0x401d0c12, 0x0b1d0602,
  // [43f0]
  0x381d0f12, 0x1d404522, 0x080c03ad, 0x45010212,
  0x031d6608, 0x0d3f2960, 0x2b0b1060, 0x0b0810a4,
  0x0f0d19af, 0x1c250ead, 0x10162909, 0x15450d12,
  0x190d3814, 0x1d082912, 0x190f3814, 0x17401d11,

  // [4400]
  0x0f380d11, 0x0b011008, 0x380d1921, 0x380d29a4,
  0x01381508, 0x03663809, 0x29660112, 0x030666bb,
  0x03660509, 0x06451202, 0x1d380f08, 0x27001012,
  0x2b001d08, 0x1d2b2709, 0x212b6612, 0x010c1d08,
  // [4410]
  0x01031912, 0x0c001214, 0x06020b02, 0x17060309,
  0x19062b12, 0x08012708, 0x02660382, 0x290c1912,
  0x18150308, 0x40271911, 0x400c2709, 0x380c08a4,
  0x450103a4, 0x0c061908, 0x030d2709, 0x152743af,
  // [4420]
  0x012b0d12, 0x10000f08, 0x02192107, 0x2b164009,
  0x12001908, 0x27001f13, 0x0b001902, 0x0c194512,
  0x38081907, 0x21190409, 0x430138a4, 0x062b0309,
  0x2b0f3fa4, 0x18041611, 0x2b001912, 0x183f22be,
  // [4430]
  0x27212909, 0x270f2909, 0x0f162707, 0x270c046f,
  0x274021be, 0x0f0c1d08, 0x0f272109, 0x1e0e2513,
  0x01051f07, 0x0d0151a4, 0x100c3fbb, 0x011440ad,
  0x15030112, 0x250e30a4, 0x1c302508, 0x01000208,
  // [4440]
  0x29041909, 0x2b16216f, 0x10450b09, 0x0b104007,
  0x020b1412, 0x0f052912, 0x050d1721, 0x0d005113,
  0x0e302313, 0x120f1807, 0x27293f11, 0x0f221707,
  0x0f000d11, 0x12221008, 0x0b1410ad, 0x02001507,
  // [4450]
  0x19660320, 0x21041912, 0x080d0202, 0x100203a4,
  0x0e1c1e14, 0x66144008, 0x663f1aa4, 0x1d164060,
  0x23250e21, 0x0b001721, 0x45121409, 0x66024021,
  0x01212b08, 0x450d0fa4, 0x45400112, 0x083f0112,
  // [4460]
  0x02001902, 0x0d0340ad, 0x083f2b12, 0x273f16bc,
  0x06450313, 0x082b0560, 0x01081609, 0x16002b08,
  0x08001d21, 0x120c4055, 0x43010d12, 0x15100ba4,
  0x151f0812, 0x0c060812, 0x100b6607, 0x011d1f08,
  // [4470]
  0x1804191f, 0x013f1f21, 0x06020307, 0x1f663f09,
  0x27081d13, 0x0c1201bb, 0x12190112, 0x40120409,
  0x120c3812, 0x191d08af, 0x0e001e23, 0x12223f12,
  0x08060d02, 0x451205a4, 0x164366a4, 0x14002913,
  // [4480]
  0x01000523, 0x22001422, 0x10190813, 0x38000611,
  0x2b1f2912, 0x193f0813, 0x38000d21, 0x19082712,
  0x18003f21, 0x01660520, 0x2b001434, 0x05001913,
  0x05100d13, 0x01220c08, 0x0f0d14ba, 0x03196609,
  // [4490]
  0x22001414, 0x2b292714, 0x292b14be, 0x19000807,
  0x450d3811, 0x381f0f09, 0x084019af, 0x3f003821,
  0x08051707, 0x66031421, 0x0b001821, 0x01221707,
  0x29122709, 0x21662712, 0x16210c13, 0x18002712,
  // [44a0]
  0x18005113, 0x04000b09, 0x0b0118a4, 0x0f173814,
  0x18450d12, 0x38002908, 0x18450d14, 0x0f173823,
  0x190b01a4, 0x180d4512, 0x21146612, 0x0b001820,
  0x2b1f0620, 0x01084507, 0x0d014508, 0x08030607,
  // [44b0]
  0x251c23ad, 0x1d430107, 0x38450d07, 0x12451855,
  0x40272955, 0x04002b11, 0x06190d55, 0x0d081507,
  0x38050102, 0x10060207, 0x02061055, 0x06100108,
  0x012b2912, 0x3f1f0112, 0x14052113, 0x140b5112,
  // [44c0]
  0x012266a4, 0x18000809, 0x04010308, 0x060f0302,
  0x05100213, 0x12001510, 0x051038a4, 0x01100bad,
  0x0d223812, 0x25003020, 0x222b0808, 0x01041507,
  0x1d001902, 0x40000b09, 0x03220baf, 0x25003014,
  // [44d0]
  0x060210a4, 0x0d001410, 0x0e232513, 0x0e251ea4,
  0x18001f21, 0x0e1c1e02, 0x1d002b07, 0x12025112,
  0x03001d12, 0x01080307, 0x21160baf, 0x0d020302,
  0x22000308, 0x050440af, 0x18060209, 0x29102713,
  // [44e0]
  0x19100d12, 0x080f0412, 0x183f0313, 0x251c0ebe,
  0x106619ad, 0x660b2112, 0x1f213faf, 0x380d1709,
  0x43211f6f, 0x2b042109, 0x271f2112, 0x063f01af,
  0x22013fac, 0x14661612, 0x193f0112, 0x1d011907,
  // [44f0]
  0x182203af, 0x02031d12, 0x0c190422, 0x293f0112,
  0x663f1060, 0x100601ad, 0x16191713, 0x03060514,
  0x0d210112, 0x01160b07, 0x0f012212, 0x04163fad,
  0x66290309, 0x27020baf, 0x05010314, 0x12190fa4,
  // [4500]
  0x170416be, 0x2b1422bc, 0x06000b09, 0x3f211922,
  0x05192221, 0x0f052220, 0x401d1560, 0x1d0d22ad,
  0x40010f08, 0x141822a4, 0x220f0d21, 0x19000434,
  0x45400802, 0x08011a07, 0x18010812, 0x5c000729,
  // [4510]
  0x184305ac, 0x061d4060, 0x19001f12, 0x060319ac,
  0x0f081508, 0x051d3fac, 0x18660812, 0x0f0d3f08,
  0x21180509, 0x0d000b13, 0x06100f07, 0x080d1007,
  0x38450d02, 0x38012b07, 0x0d660f08, 0x05010613,
  // [4520]
  0x27000612, 0x0d004002, 0x190f22be, 0x22001920,
  0x14270412, 0x0f011708, 0x021d0307, 0x0b3819ad,
  0x05660321, 0x66272112, 0x0f184513, 0x0b1019af,
  0x38000d11, 0x06004011, 0x19053821, 0x05014308,
  // [4530]
  0x0f0127af, 0x27036609, 0x194540a4, 0x0f173802,
  0x170b0212, 0x22292112, 0x040b03af, 0x10001613,
  0x1d222912, 0x030566af, 0x16660b09, 0x04190b11,
  0x1d170820, 0x22030202, 0x19000b20, 0x1d006609,
  // [4540]
  0x0e251c22, 0x06080d22, 0x01082107, 0x45180fa4,
  0x120d0f12, 0x0b080414, 0x290b0212, 0x0c1240be,
  0x19002109, 0x011202a4, 0x0d1901a4, 0x01005108,
  0x19000b14, 0x173f0812, 0x19381709, 0x01192260,
  // [4550]
  0x250e1cad, 0x181245be, 0x12050d12, 0x12001008,
  0x1f0b06be, 0x180f0d14, 0x45001408, 0x020d0f6f,
  0x0c012212, 0x660f0d08, 0x1d223fad, 0x1e001c22,
  0x02450b09, 0x18191d08, 0x05120d07, 0x0c001711,
  // [4560]
  0x101d6614, 0x100c0d11, 0x120b0207, 0x0f001802,
  0x05013f11, 0x05001009, 0x08180307, 0x08190d09,
  0x1708666f, 0x272912af, 0x45006621, 0x272921cf,
  0x0b004507, 0x22275112, 0x270629af, 0x03001f11,
  // [4570]
  0x14151760, 0x291f2121, 0x16170808, 0x660b10bc,
  0x3f166613, 0x382b0d09, 0x0d010b11, 0x22272122,
  0x19062712, 0x29215112, 0x15272909, 0x271f5112,
  0x101d0607, 0x061001a4, 0x1d212912, 0x19184507,
  // [4580]
  0x27042b6f, 0x17272112, 0x010f0d55, 0x292b0313,
  0x38060112, 0x011417ac, 0x04141721, 0x66032709,
  0x22181d60, 0x01401008, 0x22181060, 0x010638ad,
  0x21000412, 0x01381512, 0x01003814, 0x02453f07,
  // [4590]
  0x22001808, 0x100b2211, 0x38010d09, 0x04292722,
  0x0427296f, 0x14431808, 0x100d0f08, 0x10013813,
  0x0e1e1ca4, 0x01003822, 0x1e230e55, 0x1d0c1002,
  0x0f0201a4, 0x1d000422, 0x0d1245af, 0x0b061008,
  // [45a0]
  0x27001020, 0x06100260, 0x011d0f12, 0x17050107,
  0x660d0809, 0x22451012, 0x16001707, 0x271d40a4,
  0x12450d20, 0x06002b09, 0x190117be, 0x1d104023,
  0x38050309, 0x40021008, 0x060b02ad, 0x06121712,
  // [45b0]
  0x2b001708, 0x0c013f09, 0x062b2912, 0x43012708,
  0x03060512, 0x38005113, 0x011051af, 0x1d151022,
  0x432b2709, 0x0c041807, 0x030b0211, 0x0b001607,
  0x160529af, 0x38170512, 0x40222bac, 0x192203a4,
  // [45c0]
  0x380d0207, 0x38432708, 0x010d38af, 0x12044007,
  0x101645af, 0x29102714, 0x0b380f08, 0x192b2709,
  0x01161912, 0x22004014, 0x17000607, 0x10060112,
  0x29001520, 0x08062755, 0x660d0112, 0x01102707,
  // [45d0]
  0x100817a4, 0x08010cac, 0x1f001709, 0x02400b12,
  0x160108ad, 0x0b0f0812, 0x060c4007, 0x19060baf,
  0x19000b21, 0x15661621, 0x020b0613, 0x0c000d09,
  0x01401daf, 0x190210a4, 0x021d0b13, 0x17000b13,
  // [45e0]
  0x01100507, 0x66023f09, 0x06180355, 0x401410a4,
  0x401d1214, 0x021d4009, 0x40021d11, 0x0c660208,
  0x14010b12, 0x02001414, 0x430117a4, 0x011d0212,
  0x010c4002, 0x10001d12, 0x45181209, 0x12451812,
  // [45f0]
  0x1d401208, 0x29001412, 0x02012b07, 0x121d4509,
  0x03660455, 0x061d0112, 0x1e232509, 0x0f0829a4,
  0x1d400c55, 0x120d0cad, 0x0403666f, 0x29001714,
  0x40173809, 0x18081913, 0x19452712, 0x040d1912,
  // [4600]
  0x190440be, 0x291219bb, 0x40191d60, 0x18031912,
  0x40451dbc, 0x010d0808, 0x14450c21, 0x0d661f09,
  0x22404508, 0x0b030608, 0x120d1810, 0x081245af,
  0x16001921, 0x0d041921, 0x43041612, 0x080119ac,
  // [4610]
  0x06011912, 0x38014009, 0x040206a4, 0x190205af,
  0x43180113, 0x01063fac, 0x17660daf, 0x27001921,
  0x191d01be, 0x011f3f55, 0x0c0d2720, 0x17061f09,
  0x04101912, 0x0f430112, 0x14661720, 0x17011d02,
  // [4620]
  0x0d0c18ad, 0x40021d60, 0x0d173814, 0x031d3813,
  0x08386609, 0x17052ba4, 0x10121d08, 0x180f1407,
  0x22292760, 0x016604ad, 0x0f1d45af, 0x2b292760,
  0x0c380d09, 0x03000636, 0x02010ba4, 0x4512180c,
  // [4630]
  0x38140507, 0x08004307, 0x030b01af, 0x03166614,
  0x10060223, 0x0b040260, 0x03430112, 0x053810bc,
  0x05000d21, 0x060538bc, 0x14001820, 0x380d0509,
  0x17292712, 0x100538af, 0x0d041409, 0x38100bad,
  // [4640]
  0x0b226655, 0x01053811, 0x16036613, 0x04000507,
  0x2b272914, 0x14000408, 0x10003821, 0x38001022,
  0x02103813, 0x01432102, 0x23001c22, 0x45020ba4,
  0x026615af, 0x15031009, 0x0d0119ad, 0x212229af,
  // [4650]
  0x14191d14, 0x22000512, 0x1d174302, 0x19404507,
  0x292745af, 0x011f2b11, 0x18036607, 0x25231e20,
  0x22401d13, 0x10401d11, 0x1d221960, 0x0c1d1207,
  0x08041608, 0x0b0d0f02, 0x03000b21, 0x0d082907,
  // [4660]
  0x1d402baf, 0x063803a4, 0x19183808, 0x38001d21,
  0x170c1512, 0x231e0e20, 0x22030b09, 0x03050607,
  0x0f0b0207, 0x434518ac, 0x380501a4, 0x1d003820,
  0x0f2b19cf, 0x01051412, 0x38050c09, 0x3f056614,
  // [4670]
  0x060d1f09, 0x05002b12, 0x19030b12, 0x38400daf,
  0x1d220d12, 0x1d002907, 0x170421bb, 0x14001909,
  0x22293812, 0x160b0222, 0x19141009, 0x16190409,
  0x0f2104ac, 0x164021af, 0x1d4017ad, 0x66100612,
  // [4680]
  0x12000108, 0x45290c09, 0x27011812, 0x0c453fbe,
  0x0c124007, 0x03001812, 0x660d0582, 0x220c1d12,
  0x02101734, 0x101422a4, 0x173f0523, 0x2b002234,
  0x170d2bcf, 0x0f382908, 0x2b000822, 0x0f220807,
  // [4690]
  0x01004312, 0x161d0f14, 0x06270512, 0x16430511,
  0x053f0f08, 0x0f002714, 0x0f270112, 0x19452baf,
  0x2945126f, 0x151922be, 0x14292221, 0x401d08be,
  0x30251e07, 0x19160813, 0x010c4560, 0x03083812,
  // [46a0]
  0x1c230e6f, 0x23300ead, 0x19402207, 0x012205ac,
  0x080421af, 0x25231c14, 0x1d402912, 0x08453808,
  0x02381907, 0x43170d07, 0x020b06af, 0x042b06bb,
  0x660b0413, 0x18000213, 0x0b100507, 0x0e1c1ead,
  // [46b0]
  0x01190555, 0x060b1022, 0x1806146f, 0x1c300e6f,
  0x050d0209, 0x05040b12, 0x1d0127ac, 0x04012221,
  0x1f002b14, 0x03066621, 0x0b000521, 0x18002213,
  0x45400408, 0x151d1609, 0x16102108, 0x18163f12,
  // [46c0]
  0x14002b07, 0x231e1c12, 0x0d290112, 0x1d0812af,
  0x1d000312, 0x05001f09, 0x0b021412, 0x451d4034,
  0x01163f12, 0x40020d02, 0x0b040355, 0x02102707,
  0x103f51af, 0x040851af, 0x450c08a4, 0x22061012,
  // [46d0]
  0x01020bad, 0x403f29a4, 0x40451221, 0x0f0c0daf,
  0x1d042907, 0x17152212, 0x38012baf, 0x14221a07,
  0x06002214, 0x1f0f3f20, 0x3f001613, 0x17002b11,
  0x382966a4, 0x12002221, 0x0b1d02a4, 0x1d081707,
  // [46e0]
  0x121445af, 0x0d3801a4, 0x221f12af, 0x0c1022ad,
  0x220d1faf, 0x013f1f20, 0x03170213, 0x08191f21,
  0x06002221, 0x170d0509, 0x0d050faf, 0x0f100809,
  0x05382b12, 0x061727a4, 0x19212207, 0x0f191fad,
  // [46f0]
  0x01171f20, 0x2b054311, 0x29060209, 0x45380d08,
  0x1d002b13, 0x38222712, 0x0c1d2b08, 0x05080111,
  0x102b0b11, 0x02161507, 0x03662b08, 0x01000509,
  0x2b183821, 0x0c221455, 0x381d45af, 0x0d290fa4,
  // [4700]
  0x1c1e30bb, 0x27000109, 0x2b0f0112, 0x12452921,
  0x0c046607, 0x01001213, 0x43120112, 0x0e251e11,
  0x011f0809, 0x274304af, 0x25231ea4, 0x190151af,
  0x19171daf, 0x1f210112, 0x06002202, 0x01001411,
  // [4710]
  0x01020302, 0x1d0d0412, 0x0d000413, 0x173805af,
  0x192721ad, 0x22001011, 0x18002b21, 0x01400dbc,
  0x1e3023ac, 0x0c2b0baf, 0x060c4021, 0x27046612,
  0x0b2b0212, 0x2b001714, 0x190f0d08, 0x191245af,
  // [4720]
  0x451922af, 0x29006612, 0x1d403f21, 0x03012bac,
  0x15161d12, 0x02662b12, 0x16382712, 0x02220355,
  0x050b06a4, 0x02380808, 0x00002203, 0x190f0d02,
  0x0f1001a4, 0x04212912, 0x121d2907, 0x38276608,
  // [4730]
  0x0d170fbe, 0x0d0503a4, 0x19042ba4, 0x10022209,
  0x05066660, 0x10002108, 0x433f2109, 0x232530af,
  0x401d2bbe, 0x05012107, 0x3f19086f, 0x401427af,
  0x0f000111, 0x18140813, 0x011d06ac, 0x08193f21,
  // [4740]
  0x0b380f13, 0x181d4060, 0x400c1d08, 0x272b0108,
  0x0f221712, 0x1d4018be, 0x0c081909, 0x190c51af,
  0x011d51a4, 0x45401d6f, 0x38010f12, 0x0c4051af,
  0x08190f08, 0x400c5112, 0x05192112, 0x060c4013,
  // [4750]
  0x38001407, 0x143f0112, 0x05381412, 0x251c0e23,
  0x180d05af, 0x021714a4, 0x081d1902, 0x0c122909,
  0x01432955, 0x0b430507, 0x38272112, 0x45002b11,
  0x0c4001af, 0x45005113, 0x1d053faf, 0x191521af,
  // [4760]
  0x22005113, 0x23002520, 0x660827af, 0x08011912,
  0x3f220322, 0x0c001721, 0x023f51af, 0x0d050f13,
  0x030619ac, 0x22001820, 0x066651af, 0x020b51ad,
  0x151d4023, 0x0d660309, 0x0c292712, 0x080d01a4,
  // [4770]
  0x191d66a4, 0x2b160d07, 0x29272212, 0x18660314,
  0x0f011821, 0x1f193f09, 0x221901af, 0x190b0309,
  0x0f053faf, 0x152216ad, 0x03016609, 0x40002207,
  0x0b272913, 0x031002a4, 0x0e253008, 0x191016a4,
  // [4780]
  0x45001f22, 0x15160214, 0x21190412, 0x19042155,
  0x103f5112, 0x3f0f3809, 0x1c302523, 0x14100409,
  0x291451af, 0x08100214, 0x05170111, 0x140b0822,
  0x03121d07, 0x04173f14, 0x120c1720, 0x17272908,
  // [4790]
  0x120c176f, 0x08020b09, 0x01081902, 0x120c1712,
  0x0c4012af, 0x22140c6f, 0x12173f14, 0x171f2109,
  0x031506af, 0x0c160ba4, 0x2b030220, 0x18660813,
  0x180b1dbc, 0x0d030512, 0x22030baf, 0x213f51a4,
  // [47a0]
  0x10020621, 0x02000811, 0x020d0112, 0x01120508,
  0x01081708, 0x19020609, 0x451240bb, 0x220f0813,
  0x0c041713, 0x2b220608, 0x0c171212, 0x12041760,
  0x06660d21, 0x120c1713, 0x17081214, 0x2b062112,
  // [47b0]
  0x22400f09, 0x050c1007, 0x0d183809, 0x10190414,
  0x0f061655, 0x062b27af, 0x17000613, 0x18451213,
  0x10041da4, 0x0e302360, 0x230e2502, 0x041466ac,
  0x43000d08, 0x121743a4, 0x12660508, 0x38001207,
  // [47c0]
  0x0b002911, 0x16124502, 0x021810af, 0x22000f02,
  0x16290412, 0x12456608, 0x0b001207, 0x1f0b0213,
  0x141851a4, 0x0b001011, 0x05660320, 0x664301ad,
  0x06400112, 0x12001621, 0x0b021812, 0x0c000111,
  // [47d0]
  0x01100660, 0x010238bb, 0x170d1008, 0x0b041d07,
  0x04002911, 0x10660355, 0x2b001808, 0x162b1f12,
  0x04151f14, 0x05000408, 0x14000b12, 0x18000312,
  0x01080355, 0x1f000514, 0x45120cac, 0x010c2bbe,
  // [47e0]
  0x060b02a4, 0x01000d08, 0x01042b07, 0x0d003812,
  0x19161507, 0x38010512, 0x05291f14, 0x01000c21,
  0x15041f13, 0x0d043f34, 0x08453fa4, 0x1d100608,
  0x05060313, 0x3f450c22, 0x01083fbe, 0x3f161aaf,
  // [47f0]
  0x04003f22, 0x3f293809, 0x14000609, 0x05123807,
  0x38083f09, 0x100806a4, 0x05060813, 0x45083faf,
  0x10040c12, 0x38450d09, 0x15060b07, 0x0f001022,
  0x0c0f0621, 0x0f000c23, 0x1c002520, 0x3f000c21,

  // [4800]
  0x043f4511, 0x0d0f3f09, 0x080c0621, 0x04274512,
  0x0f050621, 0x061751af, 0x0f000621, 0x060b1907,
  0x23301ca4, 0x02660c09, 0x14011612, 0x25231e55,
  0x22400f60, 0x19000109, 0x43290112, 0x14001622,
  // [4810]
  0x05192b60, 0x12184508, 0x06001d08, 0x06041902,
  0x170f0d55, 0x45164022, 0x170b0108, 0x04181960,
  0x10140507, 0x03000502, 0x2b010608, 0x0f000809,
  0x66002b14, 0x1d454013, 0x10041907, 0x051914a4,
  // [4820]
  0x02002107, 0x22011907, 0x0d0f1d02, 0x01185112,
  0x45003f20, 0x06180112, 0x06041512, 0x10040b14,
  0x17083f09, 0x06291009, 0x17051d55, 0x19380f09,
  0x17142107, 0x10380209, 0x0f050d09, 0x05380d12,
  // [4830]
  0x01082709, 0x271001af, 0x400c4521, 0x38451709,
  0x662b3faf, 0x044017a4, 0x08020d12, 0x4022186f,
  0x45100f02, 0x0d380502, 0x04001f21, 0x212704af,
  0x19180421, 0x17192909, 0x16100b08, 0x011f1409,
  // [4840]
  0x27291f13, 0x05003f13, 0x66030412, 0x122721ad,
  0x29270221, 0x14020b14, 0x18191f14, 0x10180609,
  0x21011460, 0x40181d60, 0x01292b55, 0x06052b08,
  0x1e2330a4, 0x45121610, 0x19000c07, 0x15001d09,
  // [4850]
  0x2b380f12, 0x08380f08, 0x06001608, 0x14120fa4,
  0x22163f21, 0x22010d08, 0x0c2721af, 0x21005113,
  0x06000d13, 0x16271d12, 0x1f003f34, 0x01160f12,
  0x0f3f1f22, 0x2b170812, 0x1914046f, 0x40190c14,
  // [4860]
  0x220c1512, 0x012b1fbc, 0x18041d12, 0x010d3802,
  0x0c001914, 0x056601a4, 0x661921af, 0x03060121,
  0x0c191a07, 0x04173812, 0x291406af, 0x21143f09,
  0x04661909, 0x29192709, 0x272266af, 0x220c406f,
  // [4870]
  0x190c146f, 0x1d1527a4, 0x27000312, 0x03003f07,
  0x25230e02, 0x19291a11, 0x66032913, 0x16061508,
  0x120c1007, 0x100c1612, 0x0c002121, 0x04061907,
  0x041045ac, 0x02270b09, 0x06032207, 0x050f0107,
  // [4880]
  0x15122909, 0x0c002114, 0x0c002b02, 0x0b141602,
  0x182106a4, 0x02660611, 0x04001d20, 0x27010d12,
  0x041f0514, 0x05272911, 0x081405ad, 0x060b4002,
  0x0d1f1609, 0x01053855, 0x1d0c0f07, 0x0f1d1607,
  // [4890]
  0x25231e08, 0x2b050d60, 0x120c51af, 0x123f27a4,
  0x15291409, 0x04194009, 0x041451af, 0x450c1daf,
  0x03180660, 0x0c1d15af, 0x02100112, 0x1866036f,
  0x0c292709, 0x06041907, 0x03001821, 0x15210112,
  // [48a0]
  0x401d4514, 0x14120d12, 0x0b150313, 0x19660b12,
  0x1d061507, 0x04002709, 0x03451255, 0x2b001f07,
  0x2b0127af, 0x190627a4, 0x141d12af, 0x180f0d13,
  0x10192707, 0x020603a4, 0x250e23af, 0x180151af,
  // [48b0]
  0x010f2bbc, 0x0b1008af, 0x10002907, 0x17052908,
  0x03660209, 0x03292712, 0x03061421, 0x21001214,
  0x124518a4, 0x06030113, 0x1d010508, 0x2b292711,
  0x100b3faf, 0x21030612, 0x21273f13, 0x17380f09,
  // [48c0]
  0x01061f07, 0x45170807, 0x66210b09, 0x22162113,
  0x1d290baf, 0x01062b13, 0x660103af, 0x080f1721,
  0x43005108, 0x1d001202, 0x06270308, 0x100b0112,
  0x2b161fbe, 0x2b001622, 0x2b031721, 0x2b000509,
  // [48d0]
  0x08050dbc, 0x14401d6f, 0x16001d21, 0x0c1d4021,
  0x38041da4, 0x01042b11, 0x02160612, 0x03023802,
  0x29124560, 0x01451222, 0x38060322, 0x14004013,
  0x22004021, 0x01124513, 0x03041aa4, 0x190408a4,
  // [48e0]
  0x16192109, 0x450c4021, 0x080c6608, 0x0f0114a4,
  0x30230e6f, 0x0f2b0808, 0x10400b02, 0x0f0d0802,
  0x0c1d4512, 0x0d002111, 0x22191409, 0x011d1202,
  0x1d001812, 0x100f0b12, 0x06220313, 0x22060baf,
  // [48f0]
  0x191d4013, 0x450c1d08, 0x190629a4, 0x38050f60,
  0x15002109, 0x22160dad, 0x05226612, 0x17012709,
  0x22194009, 0x03100b12, 0x19160f07, 0x06050f6f,
  0x05190109, 0x03050f09, 0x08000408, 0x013f1aa4,
  // [4900]
  0x101718bb, 0x15000f13, 0x17003809, 0x03401608,
  0x01060407, 0x12050108, 0x010b03a4, 0x01382ba4,
  0x0c022209, 0x400c1dbc, 0x0b021921, 0x0c190421,
  0x45061808, 0x5c000735, 0x050b0112, 0x18010fa4,
  // [4910]
  0x02001712, 0x032701af, 0x03026612, 0x1d1851a4,
  0x04401d82, 0x0f041560, 0x18001421, 0x0c150d08,
  0x18001423, 0x032b2109, 0x1d100f09, 0x18043fad,
  0x181903a4, 0x151840af, 0x14185112, 0x380d16ad,
  // [4920]
  0x29142709, 0x381051af, 0x19000c22, 0x05083809,
  0x143819af, 0x190f0d6f, 0x020b1daf, 0x06041607,
  0x0129276f, 0x0b270214, 0x10193812, 0x08190f09,
  0x0d210107, 0x02030b07, 0x380f51af, 0x22193812,
  // [4930]
  0x01223814, 0x17290d09, 0x402b1daf, 0x1d381812,
  0x050f2707, 0x0f050102, 0x120d40ad, 0x060f0d08,
  0x03061913, 0x06023809, 0x1219386f, 0x0b103802,
  0x45381009, 0x0c1210af, 0x051d0f07, 0x10290d55,
  // [4940]
  0x041d2207, 0x140d1208, 0x08401907, 0x0b4521a4,
  0x041d2708, 0x45001f07, 0x102b0608, 0x1d000c08,
  0x151666a4, 0x04001607, 0x1c232523, 0x05170612,
  0x0f2b0608, 0x08013812, 0x43012112, 0x03660d12,
  // [4950]
  0x38400b08, 0x170f18ad, 0x05001f22, 0x16003812,
  0x14000623, 0x18011013, 0x3f001f21, 0x03292b12,
  0x66402912, 0x161704be, 0x2b1f3f13, 0x21660360,
  0x1f083860, 0x012b43a4, 0x140601af, 0x270b2909,
  // [4960]
  0x0e301c02, 0x1e0e2360, 0x060b2107, 0x120c2222,
  0x0b1004a4, 0x2b001602, 0x050f3813, 0x060216ac,
  0x1c0e2302, 0x036610af, 0x27382209, 0x1f292760,
  0x02046655, 0x16030cad, 0x0c011602, 0x380166a4,
  // [4970]
  0x0d010807, 0x0c004302, 0x1f272913, 0x1d000320,
  0x22380307, 0x40221d60, 0x101803a4, 0x38172909,
  0x1d031714, 0x170f2108, 0x37001c09, 0x17081912,
  0x14041921, 0x19002b13, 0x03001d23, 0x19080d55,
  // [4980]
  0x401245ac, 0x0b182909, 0x01020609, 0x0b0510ad,
  0x2b220809, 0x0b101414, 0x43453809, 0x0d3f3809,
  0x22004512, 0x0b022207, 0x38140c09, 0x291245af,
  0x1900041f, 0x1d0b0214, 0x08180309, 0x45120d09,
  // [4990]
  0x23250e14, 0x19221413, 0x143f2114, 0x27293f09,
  0x66222b21, 0x2b000823, 0x15001635, 0x45190c12,
  0x12272908, 0x020b4008, 0x1d194023, 0x66010514,
  0x2b002213, 0x0d013813, 0x081540af, 0x30002514,
  // [49a0]
  0x230e1e09, 0x181d1209, 0x19451222, 0x3f030108,
  0x40190521, 0x01162721, 0x010845a4, 0x03004512,
  0x121d4022, 0x03011809, 0x0f012912, 0x1c0e2360,
  0x16036622, 0x17270d09, 0x191f0613, 0x04220f07,
  // [49b0]
  0x381d01a4, 0x0f044002, 0x2229276f, 0x27402912,
  0x40000312, 0x1d192912, 0x01191a12, 0x08380311,
  0x0c100b11, 0x0d001711, 0x033f2712, 0x1e003002,
  0x011d5107, 0x17000d13, 0x0c1d45ad, 0x19100407,
  // [49c0]
  0x0c451d07, 0x45002713, 0x0b451207, 0x06020308,
  0x170f0108, 0x10140202, 0x02004302, 0x0d020612,
  0x271d2221, 0x191014be, 0x161540a4, 0x022b1021,
  0x061505bb, 0x1d211060, 0x66220609, 0x026638bc,
  // [49d0]
  0x14040baf, 0x06030809, 0x04066608, 0x19030412,
  0x29153f14, 0x022b6613, 0x05063813, 0x022b0112,
  0x05000621, 0x15190412, 0x660603be, 0x03220108,
  0x060b1912, 0x27020512, 0x14060b12, 0x22011d09,
  // [49e0]
  0x02004008, 0x1d190b09, 0x22062955, 0x21000c09,
  0x3f1f2909, 0x01170512, 0x08190609, 0x190b14bc,
  0x2b051f11, 0x450143a4, 0x181517bc, 0x19661708,
  0x01663809, 0x15161709, 0x17000809, 0x010d1708,
  // [49f0]
  0x061866af, 0x17270808, 0x381718ad, 0x0f0117a4,
  0x17001908, 0x16000621, 0x0f1d0d09, 0x45661f55,
  0x22011807, 0x08061708, 0x15171821, 0x0e302507,
  0x0b271012, 0x01380655, 0x140b10be, 0x251e30a4,
  // [4a00]
  0x1d451222, 0x0b001035, 0x08000d12, 0x0f0d0609,
  0x06042109, 0x02001d08, 0x0d046607, 0x02001822,
  0x0b430612, 0x02030660, 0x120c01af, 0x151206ac,
  0x042b1212, 0x0c4301a4, 0x120c40af, 0x120145af,
  // [4a10]
  0x451d66af, 0x062229a4, 0x220106ad, 0x02221755,
  0x1d454007, 0x150366ad, 0x01211955, 0x1d3f2113,
  0x010f1f13, 0x29221708, 0x1e250e11, 0x0c003807,
  0x1d150109, 0x1f001913, 0x14003809, 0x0f2b19ac,
  // [4a20]
  0x120f1d08, 0x38001714, 0x0d170faf, 0x251e3012,
  0x01041607, 0x45124023, 0x160c6611, 0x03000d09,
  0x18156608, 0x08011f08, 0x043f1720, 0x0f173f20,
  0x170119ad, 0x124517be, 0x66190322, 0x01004511,
  // [4a30]
  0x45051711, 0x38173fad, 0x01081712, 0x02000607,
  0x38080f14, 0x3f001213, 0x66000311, 0x06050102,
  0x1d041512, 0x3f001733, 0x25230e11, 0x3f170f21,
  0x170d0108, 0x04031921, 0x14000214, 0x6603196f,
  // [4a40]
  0x230e1c21, 0x66031922, 0x22173809, 0x38290112,
  0x0d1627a4, 0x060b6622, 0x0c0840ad, 0x0f001002,
  0x380f0855, 0x19272921, 0x38221d60, 0x012b19a4,
  0x431d19ad, 0x19152712, 0x12291612, 0x270d216f,
  // [4a50]
  0x1d0c0d14, 0x21000f20, 0x1f38056f, 0x0d000635,
  0x06004511, 0x401d2712, 0x0c0529ac, 0x2b2715ad,
  0x19002b22, 0x230e2508, 0x0d221912, 0x19062b11,
  0x08380555, 0x22192712, 0x272b66a4, 0x19014009,
  // [4a60]
  0x38290534, 0x451221a4, 0x036601cf, 0x0c040fbb,
  0x2b170512, 0x16101521, 0x401d19a4, 0x0b0203a4,
  0x06172221, 0x03181555, 0x222b1412, 0x22272955,
  0x060105ad, 0x450d0f13, 0x161f45af, 0x19012960,
  // [4a70]
  0x1d001702, 0x0c451612, 0x100414af, 0x080b1013,
  0x0c160b09, 0x1d160fbc, 0x080c0d07, 0x45000d13,
  0x431401a4, 0x38000812, 0x030d0f07, 0x0d000107,
  0x0d220112, 0x01160c12, 0x16000d12, 0x0d0f4512,
  // [4a80]
  0x1f0d4509, 0x141666a4, 0x250e30ad, 0x29160dbc,
  0x06220112, 0x1c300ebb, 0x19010509, 0x0b066609,
  0x06001602, 0x2b000413, 0x01170407, 0x190b1807,
  0x2b1d3809, 0x10061907, 0x17223802, 0x0f161fac,
  // [4a90]
  0x230e1ebe, 0x12180608, 0x29051812, 0x010f3813,
  0x190f0821, 0x0f180112, 0x0b0f0112, 0x22194002,
  0x14124560, 0x03102b09, 0x22106613, 0x04020809,
  0x23301c08, 0x381d2b07, 0x3f001414, 0x1d2214ac,
  // [4aa0]
  0x010b0608, 0x27080112, 0x04001814, 0x2b0801af,
  0x2b066612, 0x14002222, 0x010d0509, 0x19042709,
  0x0627296f, 0x08002b13, 0x16220260, 0x0d0f22ad,
  0x06192b07, 0x0b000620, 0x381d08af, 0x43011f08,
  // [4ab0]
  0x01292722, 0x300e1e02, 0x030f2911, 0x050419af,
  0x27293fbe, 0x22001511, 0x27212960, 0x2b660311,
  0x0c222121, 0x452b1212, 0x15011007, 0x3f222121,
  0x21223f20, 0x38000d20, 0x05010d12, 0x38170d23,
  // [4ac0]
  0x031966a4, 0x060305af, 0x14220411, 0x0b1005ac,
  0x17080121, 0x14192221, 0x15192bbb, 0x02663f09,
  0x29143f09, 0x01660507, 0x14001913, 0x14000821,
  0x19272920, 0x12041608, 0x38001613, 0x27151912,
  // [4ad0]
  0x22271914, 0x16002b13, 0x1e1c0e21, 0x12081d13,
  0x14160808, 0x22190413, 0x19000812, 0x38002907,
  0x0d041607, 0x04061fbe, 0x0d000421, 0x45164008,
  0x0d172708, 0x1d0d0208, 0x04190812, 0x16000802,
  // [4ae0]
  0x230e1e21, 0x0f032b07, 0x01003f20, 0x451d0c08,
  0x011d4008, 0x03063f08, 0x0c010612, 0x05272914,
  0x15451212, 0x03010c12, 0x0c001823, 0x19000209,
  0x272919bb, 0x081d0302, 0x081d40af, 0x06080107,
  // [4af0]
  0x06010dad, 0x171d2955, 0x01000d12, 0x01662955,
  0x1e0e23be, 0x381d0f09, 0x2b4301a4, 0x0d1d08af,
  0x663f1f08, 0x05014007, 0x06100107, 0x0c004521,
  0x18000b12, 0x430c3808, 0x030143a4, 0x2b012911,
  // [4b00]
  0x18225112, 0x151d1f12, 0x143f51af, 0x27290f14,
  0x45271f12, 0x01030209, 0x15401d60, 0x060b0309,
  0x14102712, 0x0f0306ad, 0x290f1709, 0x27182909,
  0x1d193f12, 0x40380808, 0x01190809, 0x10170802,
  // [4b10]
  0x06031907, 0x0d2b21ac, 0x03386609, 0x03010212,
  0x02173812, 0x660601a4, 0x29002121, 0x190d0f09,
  0x21271612, 0x210f16bc, 0x02002108, 0x0d2729af,
  0x01020807, 0x1d121607, 0x01190807, 0x0c020b13,
  // [4b20]
  0x0f272909, 0x02450107, 0x06011012, 0x1c252314,
  0x03270109, 0x14020b08, 0x0d101708, 0x38000502,
  0x05124512, 0x0b060112, 0x0f001207, 0x02100107,
  0x10152708, 0x66454012, 0x02100b21, 0x0e251c34,
  // [4b30]
  0x12144509, 0x25231eaf, 0x2b000b11, 0x0d015107,
  0x0b021023, 0x064045a4, 0x190301a4, 0x66000221,
  0x0f001607, 0x120566a4, 0x30001c14, 0x0f171fbc,
  0x06051407, 0x1d404502, 0x66010312, 0x1f380313,
  // [4b40]
  0x052b1f12, 0x251e0e22, 0x010f1007, 0x183805a4,
  0x3f29276f, 0x16180112, 0x29001f13, 0x0c166607,
  0x0c2729a4, 0x01004502, 0x663f2721, 0x2b401712,
  0x1d450c60, 0x22293fad, 0x1f000c09, 0x29273fbb,
  // [4b50]
  0x022714af, 0x221f0413, 0x161d1521, 0x023f01af,
  0x040838cf, 0x141510bc, 0x041917be, 0x03060109,
  0x22290baf, 0x21142914, 0x143843ad, 0x12001f33,
  0x400c2912, 0x290c4021, 0x40141021, 0x22002b14,
  // [4b60]
  0x0c1d4002, 0x252330ad, 0x1e230eac, 0x0d663f09,
  0x380f1fbe, 0x042215a4, 0x66060111, 0x45124302,
  0x45431faf, 0x100b1613, 0x01000809, 0x0c272155,
  0x2b160812, 0x080c01ad, 0x0c273f12, 0x060f6609,
  // [4b70]
  0x100b18af, 0x0c0106a4, 0x17181612, 0x0e002523,
  0x05014307, 0x27291414, 0x1d210f08, 0x16002913,
  0x060b01af, 0x18152912, 0x18151622, 0x45120613,
  0x0c380f07, 0x162b3faf, 0x16292733, 0x0c0806ad,
  // [4b80]
  0x0f001d07, 0x0c061fac, 0x290d2713, 0x06192107,
  0x15181614, 0x151816af, 0x17002209, 0x08052b07,
  0x29160ba4, 0x29002220, 0x29161809, 0x29152709,
  0x140121af, 0x0d060302, 0x030d1d07, 0x1e250ebb,
  // [4b90]
  0x0d032212, 0x17002213, 0x050c0107, 0x45150cbe,
  0x12030112, 0x03001502, 0x1d001511, 0x2b010509,
  0x12452ba4, 0x150f0609, 0x100c1607, 0x1e301ca4,
  0x020b0609, 0x05001f14, 0x19000b11, 0x12054522,
  // [4ba0]
  0x16014555, 0x0b0610bc, 0x02040b11, 0x18124523,
  0x230e25af, 0x0f272b12, 0x010517ac, 0x0f080111,
  0x250e2321, 0x0e232514, 0x661701a4, 0x18194009,
  0x29002211, 0x660c0b09, 0x0c1d1209, 0x2b1d0112,
  // [4bb0]
  0x2b176609, 0x1d225112, 0x01181da4, 0x19010f07,
  0x19042108, 0x08181608, 0x380f1012, 0x0d380855,
  0x3f000421, 0x12381707, 0x12454007, 0x1c0e3021,
  0x22042107, 0x19180202, 0x03660608, 0x022b2707,
  // [4bc0]
  0x05270613, 0x050104a4, 0x0c0d66a4, 0x10000222,
  0x02043f21, 0x183808a4, 0x080f3f12, 0x011f2baf,
  0x14080508, 0x0d142221, 0x04030607, 0x17142913,
  0x403f1dbc, 0x1d083f12, 0x19003f23, 0x450f08ac,
  // [4bd0]
  0x080f1713, 0x0f272922, 0x45271d12, 0x18000820,
  0x0f222107, 0x0b060312, 0x14002b20, 0x14002122,
  0x14292713, 0x14002120, 0x041d2112, 0x0f1d2755,
  0x080f3faf, 0x101d0107, 0x08173f13, 0x221d2112,
  // [4be0]
  0x0b0419a4, 0x05183f12, 0x38002b11, 0x66061f09,
  0x06002711, 0x080f1f60, 0x03170807, 0x27402b12,
  0x45120e07, 0x011d4512, 0x100d0808, 0x450f0d08,
  0x0d3808bc, 0x45001823, 0x15291fbc, 0x05002112,
  // [4bf0]
  0x22210112, 0x192b1f12, 0x43002122, 0x011816ad,
  0x08012955, 0x080c1607, 0x45000d21, 0x050b1609,
  0x190b0409, 0x22000502, 0x05000f21, 0x40000f14,
  0x01222111, 0x01002121, 0x01222108, 0x1f191613,

  // [4c00]
  0x04271612, 0x01292713, 0x03194009, 0x2b013f08,
  0x01270caf, 0x45013fac, 0x400f3809, 0x0b020f09,
  0x40272b12, 0x0b140108, 0x052b3808, 0x030210a4,
  0x45014302, 0x27184020, 0x010617ad, 0x05380812,
  // [4c10]
  0x25301e13, 0x12380809, 0x0d2118af, 0x29001812,
  0x04081811, 0x40040807, 0x1c301ebc, 0x430d18ac,
  0x29170fa4, 0x0e002502, 0x29270faf, 0x01006620,
  0x030108af, 0x40124511, 0x124518be, 0x0f192908,
  // [4c20]
  0x06004308, 0x1e2530af, 0x2b124560, 0x060f0107,
  0x10060311, 0x0c270609, 0x23250e08, 0x06100421,
  0x1d1540ad, 0x450201a4, 0x12010308, 0x0b0201bb,
  0x01000212, 0x1d000313, 0x03050108, 0x38003f13,
  // [4c30]
  0x1d0508a4, 0x401529a4, 0x1d124021, 0x10012707,
  0x083829af, 0x170d01a4, 0x17000c12, 0x38080555,
  0x123845a4, 0x0d0f0b08, 0x08150f09, 0x17661512,
  0x08052707, 0x38000536, 0x38060582, 0x27182111,
  // [4c40]
  0x0c1d08bc, 0x062b1011, 0x450c0860, 0x1d4002a4,
  0x0c0b0208, 0x38406614, 0x220205bc, 0x2219046f,
  0x0c180d08, 0x05016607, 0x0f3840af, 0x19290112,
  0x16052711, 0x19036608, 0x036602af, 0x06030807,
  // [4c50]
  0x38002b21, 0x18000b02, 0x12016608, 0x38172b21,
  0x041d19ad, 0x10000d08, 0x141508a4, 0x0c0801ad,
  0x08020b21, 0x0b002221, 0x05080fbe, 0x04002220,
  0x22001914, 0x45401912, 0x012b1f21, 0x04161909,
  // [4c60]
  0x1f000122, 0x062b0b11, 0x03010609, 0x03663f09,
  0x01030502, 0x1d2245a4, 0x08012b55, 0x0d031507,
  0x16221914, 0x18000411, 0x38220b12, 0x1d221711,
  0x060b08af, 0x150f3fac, 0x17380109, 0x43220d09,
  // [4c70]
  0x03082b12, 0x18160faf, 0x010b06ad, 0x2b000813,
  0x0b1805a4, 0x060d0507, 0x08011702, 0x181604af,
  0x06172207, 0x45001513, 0x22451d09, 0x0c2240bc,
  0x1d0f0d09, 0x1f3f0caf, 0x1e250e20, 0x0b6601ad,
  // [4c80]
  0x05020112, 0x0c404555, 0x031001a4, 0x03021412,
  0x10050607, 0x22400f21, 0x15080f08, 0x450401ac,
  0x380845af, 0x0f0d1fbe, 0x66160309, 0x02161012,
  0x450c40a4, 0x06380107, 0x08060109, 0x06053809,
  // [4c90]
  0x14180b09, 0x300e1eaf, 0x21004011, 0x1d060355,
  0x011d1607, 0x17060f07, 0x06031709, 0x030c0107,
  0x0e253021, 0x161421ac, 0x21001812, 0x05010302,
  0x05402708, 0x2b003f11, 0x16181d13, 0x153801af,
  // [4ca0]
  0x66101412, 0x2b0c40af, 0x401d1907, 0x01270d08,
  0x011d2907, 0x2b000d23, 0x17140108, 0x146604ad,
  0x0c122209, 0x150f1d12, 0x1e0e2511, 0x12001f09,
  0x04270b12, 0x301c0e11, 0x06030212, 0x45030209,
  // [4cb0]
  0x17380daf, 0x10213f08, 0x12450308, 0x06080411,
  0x66001909, 0x10210308, 0x19041013, 0x03192107,
  0x18040821, 0x02660414, 0x02001912, 0x06031013,
  0x0b056609, 0x0c183809, 0x14000414, 0x00001203,
  // [4cc0]
  0x02011902, 0x100b27a4, 0x0c401daf, 0x0f050812,
  0x0f011607, 0x1d170f07, 0x04000802, 0x150c0808,
  0x10002221, 0x04001f08, 0x401d0f08, 0x0f1d0d07,
  0x290401a4, 0x14080411, 0x01000d02, 0x1d402709,
  // [4cd0]
  0x06100c12, 0x02220407, 0x192204ac, 0x0f401711,
  0x041917a4, 0x01063faf, 0x084517ac, 0x0c2b01ad,
  0x27124509, 0x04081d09, 0x45120c02, 0x0b222107,
  0x050b666f, 0x14000b22, 0x100b6614, 0x17022709,
  // [4ce0]
  0x401d1021, 0x1d170f60, 0x100b1912, 0x66031022,
  0x0d100207, 0x012219af, 0x292719af, 0x04100607,
  0x40291412, 0x21661660, 0x190b1012, 0x0b210111,
  0x011d3f11, 0x01061002, 0x00002215, 0x22000108,
  // [4cf0]
  0x04223807, 0x1d402914, 0x05000235, 0x021d0bbe,
  0x1d000507, 0x05121da4, 0x40182908, 0x1d0129af,
  0x19000521, 0x030545af, 0x010521a4, 0x050801ac,
  0x0b0166a4, 0x05150d09, 0x03050855, 0x050117af,
  // [4d00]
  0x45221212, 0x12100b08, 0x150f0d08, 0x1d011809,
  0x15160809, 0x08660509, 0x40041212, 0x0b160112,
  0x0b160209, 0x291f27af, 0x01003821, 0x16272955,
  0x14036608, 0x03660b20, 0x40124512, 0x1f2729af,
  // [4d10]
  0x2b0c2108, 0x22401d60, 0x06020107, 0x16001536,
  0x38036612, 0x0f1745af, 0x08012ba4, 0x15160460,
  0x3f010660, 0x0f170da4, 0x03051f08, 0x38081709,
  0x0b010812, 0x0d401d07, 0x04171655, 0x1d0d0111,
  // [4d20]
  0x27222922, 0x1d164511, 0x061801af, 0x19401d13,
  0x082b0f08, 0x1d1940af, 0x15001909, 0x172b29af,
  0x382201af, 0x0b430307, 0x19080507, 0x10190ba4,
  0x0b010260, 0x04194002, 0x0c0327a4, 0x45040809,
  // [4d30]
  0x38220da4, 0x17145112, 0x03020ba4, 0x1d0405ad,
  0x150466ac, 0x22450c02, 0x10081909, 0x03140213,
  0x0c021921, 0x29222112, 0x192b04af, 0x450f17a4,
  0x19101514, 0x190f0da4, 0x01193fac, 0x662721af,
  // [4d40]
  0x06050f02, 0x02292112, 0x0f2766ad, 0x01060207,
  0x060b2709, 0x06031002, 0x081003a4, 0x010c05a4,
  0x16212712, 0x101906af, 0x01082b12, 0x19000111,
  0x03190102, 0x19000121, 0x03190808, 0x01002b14,
  // [4d50]
  0x1d041608, 0x052b08af, 0x45000111, 0x160c4512,
  0x29000614, 0x0c000309, 0x660c2209, 0x0c066609,
  0x1f290513, 0x19000120, 0x292b2712, 0x21000309,
  0x06660314, 0x020c0f09, 0x01182b07, 0x0b080421,
  // [4d60]
  0x2b381fad, 0x040b18ac, 0x02040bbc, 0x25000e11,
  0x100c21a4, 0x06080b12, 0x38213f08, 0x0b002b08,
  0x43181f14, 0x1c231e20, 0x04000b14, 0x06040813,
  0x0f061707, 0x270d29af, 0x0f010509, 0x18292712,
  // [4d70]
  0x27183f12, 0x150f0d09, 0x40151d13, 0x04290112,
  0x401d1f12, 0x18002b22, 0x16401708, 0x0f383f09,
  0x17001508, 0x382b2909, 0x450c0d09, 0x0f001820,
  0x01170812, 0x17430807, 0x22180312, 0x06002908,
  // [4d80]
  0x1d000b22, 0x05430112, 0x060412ad, 0x38010513,
  0x18041912, 0x10381612, 0x222b08a4, 0x051d01af,
  0x08000522, 0x1d0c22ad, 0x06001714, 0x380817a4,
  0x1e231caf, 0x12273f21, 0x121d3f13, 0x0c292755,
  // [4d90]
  0x0c214008, 0x1d192712, 0x19041511, 0x45120314,
  0x16401d13, 0x37004e33, 0x064512a4, 0x10002107,
  0x03006633, 0x273f2911, 0x382b0309, 0x100f38a4,
  0x19001813, 0x06080d07, 0x1d1712af, 0x66062b12,
  // [4da0]
  0x0c000507, 0x3f050121, 0x22402907, 0x0d053809,
  0x29012712, 0x052101af, 0x17052202, 0x03430108,
  0x25302309, 0x17660d12, 0x080c0212, 0x05001835,
  0x0f0106bb, 0x05001820, 0x300e2311, 0x19140808,
  // [4db0]
  0x38660d09, 0x191d3f14, 0x45660355, 0x030219a4,
  0x17452907, 0x010521ac, 0x03060d09, 0x22180509,
  0x03000f08, 0x0e1e3007, 0x106605af, 0x19222912,
  0x0f181912, 0x140d3823, 0x23251ebb, 0x1d400d12,
  // [4dc0]
  0x43036609, 0x0c6645af, 0x01166608, 0x45660c21,
  0x06010812, 0x030c66af, 0x290f66af, 0x1c2523bb,
  0x0f006613, 0x45120512, 0x0f3808a4, 0x12454055,
  0x25302360, 0x381d4512, 0x16150421, 0x060f0807,
  // [4dd0]
  0x660c0613, 0x15036621, 0x45401d11, 0x15066612,
  0x030466bb, 0x0f170834, 0x231e1cbc, 0x180305ad,
  0x30231c08, 0x270408af, 0x1d0c1707, 0x1f3f0121,
  0x1d0c4009, 0x060108ac, 0x011051a4, 0x06010802,
  // [4de0]
  0x40000512, 0x0c1215ac, 0x0f0d05af, 0x22191612,
  0x02001d11, 0x0f190d11, 0x151016bc, 0x10031d08,
  0x21006633, 0x101d0d12, 0x01662109, 0x0f160112,
  0x401916ad, 0x04001413, 0x19040560, 0x291d2108,
  // [4df0]
  0x0d082708, 0x0b1004ad, 0x27210413, 0x141601af,
  0x270f1011, 0x27001621, 0x220c3f23, 0x1d140407,
  0x050b0202, 0x160421ad, 0x011d3808, 0x05191808,
  0x0e1c2320, 0x04100b08, 0x384566a4, 0x1e302355,
  // [4e00]
  0x060214ac, 0x01171f13, 0x06104055, 0x18051412,
  0x1d020b13, 0x38004502, 0x43180507, 0x0d123813,
  0x01001502, 0x02040108, 0x02160112, 0x14000508,
  0x1d012113, 0x0d184512, 0x0b2b6621, 0x21663f12,
  // [4e10]
  0x38120d12, 0x380d0b14, 0x17002123, 0x0b0c1907,
  0x06011455, 0x15000f08, 0x17270112, 0x010610a4,
  0x38082109, 0x29082709, 0x0d380814, 0x031d18ad,
  0x186621bb, 0x1c301e14, 0x100c5112, 0x06141012,
  // [4e20]
  0x08050413, 0x0c053f12, 0x21153f13, 0x0f181f12,
  0x66193f12, 0x190c6607, 0x1d221502, 0x011406a4,
  0x12001d09, 0x27213f60, 0x38080d12, 0x10001408,
  0x01170f07, 0x0c186607, 0x03276609, 0x150640a4,
  // [4e30]
  0x381027af, 0x12001607, 0x66100b09, 0x0f171da4,
  0x251c30ac, 0x0d0f4012, 0x1d0c17bc, 0x030d0fa4,
  0x161921ad, 0x0e301ebb, 0x1f0d2909, 0x190d0112,
  0x0d164007, 0x271904af, 0x17003812, 0x40000d14,
  // [4e40]
  0x01380dbc, 0x38400f07, 0x27160c12, 0x45000408,
  0x120d0513, 0x041006ad, 0x301c1ead, 0x040d1f12,
  0x06001909, 0x22080fa4, 0x0e252308, 0x0e231c11,
  0x210f0d6f, 0x03401d55, 0x15121da4, 0x22001720,
  // [4e50]
  0x2b040c20, 0x19401d08, 0x1d124002, 0x22001507,
  0x06001d07, 0x2b0c0413, 0x16210112, 0x10000813,
  0x10210b12, 0x10021621, 0x382b6608, 0x08400fa4,
  0x0b100223, 0x04124520, 0x43010307, 0x061d6609,
  // [4e60]
  0x400c1613, 0x06036622, 0x160b02af, 0x05380109,
  0x2b000221, 0x0d0601af, 0x16061912, 0x06291daf,
  0x17150112, 0x2b451208, 0x04020107, 0x04174509,
  0x12001602, 0x191604a4, 0x0c012b08, 0x0c451507,
  // [4e70]
  0x292716bb, 0x100b0409, 0x0d161809, 0x05011fad,
  0x1f380faf, 0x662927af, 0x04160209, 0x0f210509,
  0x19020b60, 0x040c0112, 0x1d0c3f09, 0x0b222708,
  0x18193f08, 0x120c3f12, 0x080f2107, 0x052729a4,
  // [4e80]
  0x08050d20, 0x29004012, 0x16041913, 0x382b2260,
  0x1d001008, 0x16141da4, 0x08003808, 0x050614a4,
  0x04160612, 0x15004007, 0x251c30af, 0x451218af,
  0x03170d09, 0x0f051f09, 0x380608ad, 0x30001c02,
  // [4e90]
  0x661901af, 0x17001607, 0x04121d07, 0x170c1002,
  0x081f05a4, 0x010522a4, 0x17060320, 0x270d1d12,
  0x2b381fa4, 0x16063f13, 0x38020409, 0x45011aa4,
  0x08000f11, 0x080f3822, 0x08060faf, 0x012b06ad,
  // [4ea0]
  0x1f3f0521, 0x1f220112, 0x66221408, 0x292b27a4,
  0x38081613, 0x0c174512, 0x08272911, 0x0b0601be,
  0x0d100f55, 0x0c170808, 0x230e25ac, 0x12661908,
  0x100b21a4, 0x272918be, 0x66083f21, 0x16000809,
  // [4eb0]
  0x10192107, 0x19042109, 0x05060160, 0x150c4512,
  0x450c1807, 0x01001f09, 0x66102912, 0x0d272913,
  0x1d222712, 0x15002113, 0x0d0f51af, 0x27080f60,
  0x0f0d08a4, 0x012b0809, 0x022b2108, 0x21292708,
  // [4ec0]
  0x010f2707, 0x27160112, 0x0d124509, 0x0d031609,
  0x160f27a4, 0x0f1f2b12, 0x040f0812, 0x66005113,
  0x03000120, 0x0d161911, 0x0f084013, 0x21060f11,
  0x66002233, 0x10221460, 0x660203af, 0x1f000d22,
  // [4ed0]
  0x0b001d07, 0x18124509, 0x120c0f08, 0x03060212,
  0x12060321, 0x1d001913, 0x22003802, 0x02180b09,
  0x0b100608, 0x18000509, 0x08060511, 0x45120513,
  0x251c23be, 0x140b06ad, 0x231e2511, 0x231e3055,
  // [4ee0]
  0x0d001512, 0x030566a4, 0x06030512, 0x27152112,
  0x29000411, 0x22036607, 0x06180b11, 0x1d062112,
  0x0f6617a4, 0x1e300e14, 0x012b0308, 0x40191d09,
  0x401d0c07, 0x0f3f0834, 0x10023808, 0x2b3805af,
  // [4ef0]
  0x06191607, 0x38001620, 0x14001922, 0x01163813,
  0x10065112, 0x050338af, 0x05013860, 0x18080112,
  0x22211512, 0x19060209, 0x2b010512, 0x15222113,
  0x032b6608, 0x06004507, 0x3f001521, 0x0105386f,
  // [4f00]
  0x1d030b07, 0x272951af, 0x04160bad, 0x060827a4,
  0x02211412, 0x14050313, 0x06041708, 0x16020baf,
  0x193f2712, 0x1d382707, 0x180b0213, 0x030c2155,
  0x0b191421, 0x380c0fa4, 0x0c006621, 0x081405af,
  // [4f10]
  0x0f0c06ac, 0x1d000d02, 0x22000614, 0x06192212,
  0x0f222907, 0x19142712, 0x0d380c07, 0x1000021f,
  0x04016612, 0x06101912, 0x19100607, 0x24004109,
  0x060d0112, 0x12080607, 0x27290309, 0x05000808,
  // [4f20]
  0x1f001733, 0x27013fad, 0x19001030, 0x66160fad,
  0x3f0d0f21, 0x080d1aaf, 0x14000622, 0x19160412,
  0x401d16be, 0x011d1a12, 0x17191012, 0x010502a4,
  0x053f0b12, 0x38001914, 0x29061d13, 0x16196609,
  // [4f30]
  0x031d19ad, 0x660b0212, 0x19163f09, 0x05190f09,
  0x02450baf, 0x191602af, 0x022b51af, 0x291d4509,
  0x100119ad, 0x01050302, 0x210b0260, 0x10140409,
  0x17001d02, 0x40661f08, 0x0b021d07, 0x660419af,
  // [4f40]
  0x66001922, 0x16272922, 0x5c000734, 0x020604af,
  0x1000040c, 0x1d380f09, 0x29102709, 0x04036621,
  0x06660320, 0x27291521, 0x08161713, 0x01050b07,
  0x06051708, 0x25003002, 0x27222120, 0x03380612,
  // [4f50]
  0x03053811, 0x22212714, 0x22003f21, 0x01223f09,
  0x013f2255, 0x04061002, 0x2b013860, 0x10040307,
  0x0b1602a4, 0x192b0111, 0x0d050309, 0x06001810,
  0x30251e08, 0x01150802, 0x17380809, 0x2b000d08,
  // [4f60]
  0x2b380112, 0x18013811, 0x02380112, 0x0b040512,
  0x10181509, 0x453817ac, 0x030f02ad, 0x21000213,
  0x08000202, 0x1d451208, 0x18061f08, 0x082b0111,
  0x14000220, 0x16381909, 0x12170fa4, 0x1d382109,
  // [4f70]
  0x0d1002ac, 0x21060412, 0x38273fa4, 0x01061009,
  0x27020b60, 0x19292755, 0x25233007, 0x1f272109,
  0x38000809, 0x0d000613, 0x0b001702, 0x10010ca4,
  0x401d0508, 0x45272913, 0x43400302, 0x380143a4,
  // [4f80]
  0x04050821, 0x0b001822, 0x19060b07, 0x080b0421,
  0x106604a4, 0x05040bbc, 0x17101d12, 0x10000821,
  0x012706af, 0x08050607, 0x04180813, 0x081804cf,
  0x0b001813, 0x0d0501ac, 0x01190bbe, 0x191029af,
  // [4f90]
  0x19040811, 0x0c0129af, 0x18080212, 0x401d12ac,
  0x15002207, 0x290d6608, 0x0e1e2510, 0x10050107,
  0x660b0560, 0x0c181dad, 0x0b022212, 0x1c23306f,
  0x02002111, 0x03060b09, 0x38100b08, 0x08192bad,
  // [4fa0]
  0x45000407, 0x0b040521, 0x300e2355, 0x45120c08,
  0x0b1014bb, 0x192202ad, 0x19011055, 0x17061507,
  0x031d4055, 0x27290621, 0x03040108, 0x06004008,
  0x0e301eaf, 0x02031708, 0x16003f21, 0x120c1507,
  // [4fb0]
  0x190c04a4, 0x3f1d4060, 0x0e301caf, 0x40002112,
  0x12014509, 0x21000120, 0x0c050fa4, 0x01171f12,
  0x010306ad, 0x05400f09, 0x034016a4, 0x030401ad,
  0x19292714, 0x38102907, 0x0f003f22, 0x080d1955,
  // [4fc0]
  0x0f0427af, 0x19000d12, 0x25231c07, 0x25301e14,
  0x27063f12, 0x0c000f09, 0x150b1612, 0x04031914,
  0x03660408, 0x66030421, 0x1f190112, 0x230e30ad,
  0x0b000820, 0x18003814, 0x022201a4, 0x04002111,
  // [4fd0]
  0x17020307, 0x080d0507, 0x27290612, 0x0f1f3809,
  0x0d001f11, 0x032b06a4, 0x0c400302, 0x40001814,
  0x12401d20, 0x18000c20, 0x40150808, 0x19180809,
  0x660301a4, 0x1f041509, 0x16020b09, 0x08660313,
  // [4fe0]
  0x40034512, 0x29024012, 0x660638af, 0x14001902,
  0x05030807, 0x1d190809, 0x0f082107, 0x020651a4,
  0x2b001612, 0x140b0621, 0x10066609, 0x0d0516af,
  0x19000d08, 0x1d1651af, 0x0d000422, 0x1c002534,
  // [4ff0]
  0x03170612, 0x66120112, 0x160501af, 0x0e233060,
  0x18120d09, 0x221d27a4, 0x03380507, 0x0c002b23,
  0x43120d55, 0x22121d09, 0x45222707, 0x12150c09,
  0x38272955, 0x120c1509, 0x3f002112, 0x0b002908,

  // [5000]
  0x0d0f1507, 0x22430302, 0x30230e60, 0x05080f02,
  0x080129a4, 0x45001612, 0x18141d60, 0x021022bc,
  0x191d18bb, 0x10080607, 0x451738af, 0x0b010213,
  0x0b140213, 0x031910bc, 0x010f38af, 0x010321a4,
  // [5010]
  0x03140608, 0x17290455, 0x0c0f3812, 0x12040512,
  0x40382914, 0x380f0511, 0x10185112, 0x060b08ad,
  0x38403fac, 0x031510af, 0x0c2b2907, 0x06402907,
  0x3f080d13, 0x380d45af, 0x45001902, 0x1d151721,
  // [5020]
  0x38001f11, 0x16140b12, 0x0f060b12, 0x15124008,
  0x1d380812, 0x12451714, 0x08151f12, 0x30251c08,
  0x210d3f21, 0x170f3813, 0x16171d08, 0x060b0214,
  0x03000812, 0x04062209, 0x0b103808, 0x0c000509,
  // [5030]
  0x01040faf, 0x22402707, 0x04180d13, 0x1e1c0e20,
  0x180405a4, 0x010d1dac, 0x03180502, 0x22001012,
  0x10221907, 0x0c1d1f08, 0x2b1905a4, 0x1c252355,
  0x06292b08, 0x151d45a4, 0x020b10bb, 0x401d15af,
  // [5040]
  0x181905ad, 0x270c2b08, 0x0f210d13, 0x27291d12,
  0x0f010607, 0x0f100b09, 0x22040112, 0x1d051707,
  0x270b2912, 0x1d0c3fac, 0x19012212, 0x18041609,
  0x08210fa4, 0x01160d08, 0x05000b09, 0x1d000602,
  // [5050]
  0x10062707, 0x0d0f2909, 0x27291734, 0x0c016609,
  0x03004507, 0x160127a4, 0x040301ad, 0x104512ad,
  0x010406a4, 0x08430112, 0x230e30ac, 0x15450112,
  0x01430cac, 0x251e3020, 0x0d0166a4, 0x124502a4,
  // [5060]
  0x19124007, 0x66002b20, 0x060c0307, 0x011005a4,
  0x221866a4, 0x060f1007, 0x2b296612, 0x38050f11,
  0x3f002712, 0x160c0107, 0x06030c21, 0x0c003f22,
  0x270c3f22, 0x290c3f60, 0x0c036622, 0x450b05ac,
  // [5070]
  0x03081602, 0x06142160, 0x21003f14, 0x12040509,
  0x40161d11, 0x05402107, 0x0b102baf, 0x061901a4,
  0x051d38a4, 0x040c1507, 0x1d0c2107, 0x0b001020,
  0x021901af, 0x21040112, 0x0f171411, 0x032101ad,
  // [5080]
  0x01004007, 0x0f0d1008, 0x30002520, 0x161d3f12,
  0x08223f11, 0x01080520, 0x020b40a4, 0x0f430107,
  0x18001914, 0x14020bad, 0x03050b07, 0x0d2b0809,
  0x10002210, 0x16002222, 0x22001611, 0x12170107,
  // [5090]
  0x17060308, 0x0f191da4, 0x08401707, 0x08014508,
  0x0e1e1c02, 0x030c3f12, 0x060517ad, 0x16001909,
  0x10063f21, 0x02102107, 0x06050108, 0x170651af,
  0x121d1412, 0x1d0c1412, 0x12151d07, 0x22210c07,
  // [50a0]
  0x0f001d02, 0x021029a4, 0x142204a4, 0x450c2909,
  0x161d1411, 0x011d08ac, 0x04000202, 0x15080112,
  0x03660212, 0x05041010, 0x160827af, 0x030610a4,
  0x15191634, 0x45012108, 0x17192912, 0x04060313,
  // [50b0]
  0x08162155, 0x0d000508, 0x0b060809, 0x19011407,
  0x032101af, 0x22450807, 0x18040822, 0x16001422,
  0x04660322, 0x06010b09, 0x18060409, 0x04220821,
  0x10080baf, 0x1e230eaf, 0x1c231ead, 0x170d1612,
  // [50c0]
  0x0d2b0512, 0x05001609, 0x010305a4, 0x060d05ad,
  0x121d17bc, 0x05160d60, 0x0d0f1207, 0x1d191621,
  0x01100b55, 0x0d002912, 0x1445181d, 0x040f0daf,
  0x38120fa4, 0x12451f12, 0x29271909, 0x300e1ebe,
  // [50d0]
  0x1d010c12, 0x451d0b12, 0x1d214008, 0x14105112,
  0x18011612, 0x01221912, 0x122b08a4, 0x401d21be,
  0x401d29af, 0x01191dad, 0x102b1412, 0x01226655,
  0x45181255, 0x3f001020, 0x16151013, 0x1d0c1808,
  // [50e0]
  0x38160413, 0x160451af, 0x151051af, 0x291d3f21,
  0x0f010b12, 0x102915af, 0x051201a4, 0x1d403f60,
  0x10225112, 0x0c3f08af, 0x0d1951af, 0x02221013,
  0x052b3860, 0x060b0202, 0x083f0421, 0x08000d13,
  // [50f0]
  0x0b010c12, 0x18290109, 0x0b080112, 0x291716bb,
  0x050d5107, 0x08150daf, 0x1840146f, 0x01062bbb,
  0x27181921, 0x060b0121, 0x05384007, 0x19042114,
  0x660422a4, 0x062b03af, 0x19290107, 0x061f0faf,
  // [5100]
  0x10150209, 0x290c1512, 0x18210112, 0x662721bc,
  0x45000307, 0x29271734, 0x29003f20, 0x013827a4,
  0x29141021, 0x3f290112, 0x040527a4, 0x081766af,
  0x45121f13, 0x08011d07, 0x0c271921, 0x02062bac,
  // [5110]
  0x030d06af, 0x1d0b4020, 0x27180813, 0x02662109,
  0x0b1f1512, 0x0d381609, 0x061619ad, 0x15211922,
  0x02012909, 0x0d004508, 0x12181f60, 0x04381611,
  0x291617af, 0x662719af, 0x080d3860, 0x291d1920,
  // [5120]
  0x27190209, 0x0e233021, 0x2b000c08, 0x08221d07,
  0x0f001d12, 0x06021011, 0x290627a4, 0x450c1d07,
  0x04160607, 0x0e1e1c08, 0x04051408, 0x17221d55,
  0x12040111, 0x0b010fa4, 0x380f1dad, 0x150210ad,
  // [5130]
  0x270c1d60, 0x0b170807, 0x0d221d09, 0x1d003f13,
  0x22014002, 0x38010faf, 0x430b0208, 0x43011f07,
  0x141904a4, 0x45011213, 0x17002214, 0x251e2311,
  0x0c290112, 0x450c01a4, 0x45000d14, 0x2b1708af,
  // [5140]
  0x01051413, 0x29001421, 0x38004335, 0x2b140b09,
  0x19082209, 0x27382109, 0x401d0821, 0x0f1808a4,
  0x19003802, 0x0f2b0da4, 0x142b4512, 0x380108a4,
  0x1f00181f, 0x081627ad, 0x14082712, 0x0f183809,
  // [5150]
  0x15161909, 0x082b1421, 0x17223808, 0x400845af,
  0x0f2208a4, 0x0d1704bc, 0x010f0409, 0x380f3f21,
  0x18170809, 0x050d3f12, 0x66000c12, 0x38050860,
  0x05031008, 0x27212b09, 0x0f0d38be, 0x180c4012,
  // [5160]
  0x014506a4, 0x01660c12, 0x27292120, 0x380c4560,
  0x0c292113, 0x080f45af, 0x27294512, 0x02062107,
  0x191d4055, 0x27212911, 0x66013f09, 0x06171407,
  0x21270c12, 0x030c0660, 0x01152102, 0x173801af,
  // [5170]
  0x120d3807, 0x45050d12, 0x66160412, 0x013f1a12,
  0x0c001520, 0x04000623, 0x06010baf, 0x1f141821,
  0x14000822, 0x181f22bc, 0x080d17a4, 0x18140d21,
  0x21292711, 0x103f1821, 0x036610ce, 0x0c0f0809,
  // [5180]
  0x010f4312, 0x0b0508a4, 0x141f1013, 0x05002207,
  0x18190f08, 0x08171f09, 0x03182712, 0x060f38a4,
  0x06001712, 0x66100312, 0x08011602, 0x08210faf,
  0x05660d21, 0x10273809, 0x22212912, 0x180817be,
  // [5190]
  0x0d184507, 0x15122955, 0x10021712, 0x10000312,
  0x0b1d4507, 0x161f2b09, 0x221901a4, 0x21272260,
  0x02042707, 0x38000607, 0x06032ba4, 0x08040608,
  0x0f382112, 0x030b1011, 0x0b292720, 0x010327a4,
  // [51a0]
  0x231e0e21, 0x190138a4, 0x171501ac, 0x0f040107,
  0x451214a4, 0x45010312, 0x231e0ebe, 0x66033f09,
  0x29020b09, 0x27660360, 0x04060112, 0x1d2104bb,
  0x1e230e6f, 0x04001614, 0x06150455, 0x080414af,
  // [51b0]
  0x45053807, 0x0c0151a4, 0x060c1907, 0x080427af,
  0x29210baf, 0x27065112, 0x0b272121, 0x08270fa4,
  0x15041621, 0x0f1d3809, 0x2b041212, 0x29082712,
  0x08051414, 0x08050609, 0x22004521, 0x14192112,
  // [51c0]
  0x1d124521, 0x23301ebe, 0x01124555, 0x45042202,
  0x1c0e2309, 0x0d0129a4, 0x01451955, 0x17190421,
  0x66292b12, 0x011245a4, 0x120c0111, 0x0c000121,
  0x40080107, 0x0d014009, 0x03660512, 0x251c1ead,
  // [51d0]
  0x10150112, 0x05004308, 0x010c0508, 0x2b0401af,
  0x01382709, 0x19100112, 0x21010b12, 0x0c010302,
  0x183827a4, 0x27291212, 0x10030f02, 0x066621a4,
  0x210451af, 0x15100d21, 0x221708a4, 0x14194511,
  // [51e0]
  0x0f160812, 0x05381407, 0x05100b12, 0x27142913,
  0x1d1640a4, 0x212729be, 0x660b026f, 0x1d100207,
  0x66021812, 0x22142114, 0x1d020f08, 0x19182122,
  0x01080602, 0x38060b08, 0x141004be, 0x05001f20,
  // [51f0]
  0x061d10a4, 0x2b1f0421, 0x04001f13, 0x010d08ad,
  0x06021912, 0x190b0255, 0x1f000423, 0x01162207,
  0x06030508, 0x430117af, 0x10173809, 0x06170ba4,
  0x0d0c3855, 0x08191708, 0x1f0401af, 0x051601ad,
  // [5200]
  0x012b3f12, 0x12020b09, 0x0d122955, 0x160c0307,
  0x03000d08, 0x19162708, 0x2b216622, 0x124506be,
  0x3f2b27af, 0x050f0809, 0x1e00231f, 0x27060ba4,
  0x171f0c08, 0x27050612, 0x120c17af, 0x22001413,
  // [5210]
  0x01030555, 0x063f03be, 0x03052b12, 0x0b040607,
  0x1f010513, 0x02192113, 0x120c01a4, 0x0e1e25ad,
  0x450c0411, 0x1d173807, 0x16170408, 0x220117a4,
  0x22001407, 0x23301e13, 0x10000512, 0x05011faf,
  // [5220]
  0x0c1516a4, 0x0f014002, 0x0b0c01af, 0x27050108,
  0x451f0560, 0x18000507, 0x19143f08, 0x18173f12,
  0x04001910, 0x050366a4, 0x010617af, 0x01060509,
  0x230e1e20, 0x40171955, 0x041908ac, 0x14401d20,
  // [5230]
  0x2908046f, 0x14400807, 0x020b0308, 0x15001712,
  0x17043809, 0x01151608, 0x14171660, 0x03002212,
  0x060429ac, 0x29182713, 0x2b1d40a4, 0x2b213fad,
  0x04171411, 0x010843a4, 0x451812af, 0x190408af,
  // [5240]
  0x17001614, 0x18040612, 0x010d27a4, 0x04001f14,
  0x0b272109, 0x0d1f0512, 0x29050112, 0x19000d14,
  0x12180dad, 0x381f0d09, 0x18120d12, 0x02190421,
  0x19180411, 0x12453814, 0x66061012, 0x03190120,
  // [5250]
  0x021051a4, 0x124527af, 0x190b10af, 0x0c0b1f07,
  0x270329af, 0x66032109, 0x10160b12, 0x45120faf,
  0x450c3807, 0x66210122, 0x08042908, 0x3f272909,
  0x660301be, 0x29012113, 0x290527af, 0x43380108,
  // [5260]
  0x3f000111, 0x06030121, 0x06042707, 0x17012912,
  0x0d382707, 0x060121ad, 0x380f08a4, 0x66000809,
  0x06000c1f, 0x12012912, 0x19100ba4, 0x17080109,
  0x29013faf, 0x0c004523, 0x210301af, 0x0e2330be,
  // [5270]
  0x16430302, 0x27290113, 0x10014009, 0x0d161707,
  0x02451d08, 0x0f011f07, 0x19060411, 0x01003f08,
  0x082201a4, 0x1d3f0d60, 0x2b001f22, 0x161f0560,
  0x29270509, 0x051f2baf, 0x29153f12, 0x02186611,
  // [5280]
  0x19184009, 0x43002b11, 0x01160513, 0x08032212,
  0x031f01af, 0x04031008, 0x10081409, 0x45061009,
  0x0b101508, 0x66083809, 0x041840ad, 0x190b01af,
  0x18400460, 0x04271908, 0x661918bb, 0x08051fac,
  // [5290]
  0x080f1fa4, 0x12100313, 0x022701af, 0x01080d09,
  0x0f182107, 0x12294008, 0x02292114, 0x0c1217a4,
  0x0d120fa4, 0x21292722, 0x030201af, 0x222129af,
  0x1d1f6655, 0x0c050f08, 0x162229af, 0x0d3f0360,
  // [52a0]
  0x451d4022, 0x27191612, 0x080419af, 0x291904af,
  0x0c2b6611, 0x1d1708ac, 0x19041712, 0x18041960,
  0x10001811, 0x192127af, 0x122221af, 0x060b1411,
  0x19101508, 0x0b210209, 0x01020612, 0x45001f14,
  // [52b0]
  0x040322bb, 0x190f0d14, 0x180f3809, 0x1d4019a4,
  0x1d001520, 0x16663f12, 0x1d220212, 0x301e1cad,
  0x27222921, 0x0b0419af, 0x294027af, 0x196617a4,
  0x16141707, 0x03660b60, 0x431227a4, 0x03191d07,
  // [52c0]
  0x190c0109, 0x400c1d55, 0x45432707, 0x14002109,
  0x01054007, 0x2b100460, 0x060f2107, 0x1e002321,
  0x121d0c12, 0x05086621, 0x27183f60, 0x19040502,
  0x66292709, 0x21001509, 0x040b2907, 0x0c3f0baf,
  // [52d0]
  0x17003f13, 0x16660308, 0x156627af, 0x101427af,
  0x1d002912, 0x10060355, 0x3f001614, 0x011d0409,
  0x29083f12, 0x084314ad, 0x04000521, 0x21043f60,
  0x17001514, 0x140b16ad, 0x12451712, 0x050f1609,
  // [52e0]
  0x0b061912, 0x03060b13, 0x221408a4, 0x0b401d07,
  0x27082912, 0x2b1d04ad, 0x0d140f07, 0x15140855,
  0x173f19bc, 0x0d212707, 0x06190412, 0x06010555,
  0x190b6609, 0x030c4307, 0x66000b23, 0x06000222,
  // [52f0]
  0x222119a4, 0x011d0608, 0x010c1007, 0x01001d12,
  0x0d0804ad, 0x01662212, 0x04216612, 0x04120112,
  0x0b001914, 0x05010209, 0x01040807, 0x04161912,
  0x124566a4, 0x0c216613, 0x0d2b3821, 0x17040209,
  // [5300]
  0x38050f12, 0x041408bc, 0x270b0221, 0x15161921,
  0x0b662220, 0x021938ad, 0x0c2b0108, 0x05430107,
  0x29660309, 0x121d0512, 0x01432b07, 0x18000511,
  0x0f272921, 0x292114ce, 0x151d4508, 0x400c1808,
  // [5310]
  0x040b0213, 0x1f0501a4, 0x162b1712, 0x01053f09,
  0x1e250e55, 0x0f010409, 0x05042b55, 0x38662708,
  0x1d061f09, 0x380f0dbc, 0x080d0baf, 0x06010207,
  0x402b1d12, 0x17000612, 0x080d3822, 0x17190411,
  // [5320]
  0x01100602, 0x06012202, 0x0d170808, 0x100b0121,
  0x020f2707, 0x03010602, 0x10183f12, 0x18190412,
  0x17020f09, 0x162b1f60, 0x0b0105ad, 0x1d001908,
  0x10292760, 0x0b221007, 0x40000108, 0x2b002711,
  // [5330]
  0x011d0bad, 0x1e1c0e02, 0x1d406609, 0x150322a4,
  0x10060102, 0x121d1607, 0x12061dac, 0x0b001811,
  0x05000214, 0x0d173812, 0x191d0407, 0x45001908,
  0x1d1215bb, 0x02010508, 0x082b3809, 0x081d3f13,
  // [5340]
  0x18083fad, 0x10142221, 0x1d4027af, 0x08164512,
  0x082b19af, 0x0e1c30a4, 0x0c1d0808, 0x21000808,
  0x12003802, 0x15381712, 0x10012909, 0x12430d07,
  0x062729a4, 0x08272955, 0x02010b09, 0x031d0807,
  // [5350]
  0x014008a4, 0x14082108, 0x0c083f09, 0x193f4021,
  0x02271612, 0x660d0509, 0x40221d14, 0x01001621,
  0x22001a13, 0x17660313, 0x38170508, 0x1f001412,
  0x38221914, 0x17000f22, 0x0c270112, 0x29270122,
  // [5360]
  0x1f180112, 0x060305a4, 0x1e301c09, 0x19000809,
  0x01061f12, 0x040b0260, 0x251c2308, 0x02190107,
  0x01182b21, 0x01020308, 0x03001408, 0x14100b09,
  0x272b1f60, 0x1e253007, 0x38080507, 0x12292708,
  // [5370]
  0x29270ba4, 0x0d001522, 0x1d002908, 0x16181512,
  0x12000102, 0x0f451212, 0x06170d55, 0x270601af,
  0x0f001f07, 0x01181d55, 0x271f01af, 0x0d1529af,
  0x170d0522, 0x190201af, 0x0b000d07, 0x062b01af,
  // [5380]
  0x02052baf, 0x210201a4, 0x02010b08, 0x01034302,
  0x0b1416a4, 0x2b050108, 0x03061412, 0x2b000b14,
  0x01080202, 0x04660309, 0x3f000413, 0x0b1029a4,
  0x16273f12, 0x041927a4, 0x3f272914, 0x0d381714,
  // [5390]
  0x190440a4, 0x0c194014, 0x40020112, 0x40001509,
  0x1e1c0e09, 0x0f001808, 0x29270612, 0x45000d20,
  0x0b022712, 0x01020821, 0x04124008, 0x0c001f0d,
  0x08050109, 0x020412bb, 0x0c036614, 0x02101808,
  // [53a0]
  0x041840bb, 0x1d066655, 0x10021612, 0x1d450602,
  0x14010baf, 0x450305ac, 0x233025bc, 0x1c232555,
  0x0f016613, 0x03000f20, 0x150419bc, 0x2b0c0f08,
  0x0c001d14, 0x1f3f2b13, 0x291527af, 0x172708a4,
  // [53b0]
  0x2b0d0f21, 0x380d0807, 0x29180fa4, 0x03001720,
  0x272940af, 0x100306a4, 0x050d0309, 0x051817af,
  0x18292709, 0x05270d08, 0x12272955, 0x1f030613,
  0x120d4512, 0x30231e08, 0x0e253007, 0x40000d12,
  // [53c0]
  0x1d000d09, 0x27160b12, 0x401922af, 0x08223f12,
  0x0f380dbe, 0x27150d12, 0x3f081d14, 0x29081722,
  0x1d224013, 0x221d3f21, 0x0d001513, 0x0b1001a4,
  0x401d1413, 0x12140809, 0x1d162221, 0x430501af,
  // [53d0]
  0x30000e33, 0x01060b07, 0x1d3f2221, 0x22004020,
  0x450c3808, 0x12001411, 0x104051af, 0x03022908,
  0x0c191614, 0x45000f07, 0x1f451811, 0x15272912,
  0x03000c11, 0x22210607, 0x170f0da4, 0x0d001511,
  // [53e0]
  0x1e230ebc, 0x06004021, 0x0e301ebc, 0x010b0f08,
  0x18190660, 0x060b0222, 0x010c27af, 0x22001512,
  0x0c192907, 0x0d1238a4, 0x06272960, 0x0f001212,
  0x40171d21, 0x081929a4, 0x0d293809, 0x052b1d12,
  // [53f0]
  0x40181d08, 0x0c272912, 0x17432955, 0x21166609,
  0x223f29af, 0x06170802, 0x40002107, 0x030566ad,
  0x0c1921af, 0x120d0f6d, 0x05001633, 0x22123f07,
  0x22001014, 0x0f180511, 0x0d22086f, 0x102b0d09,

  // [5400]
  0x0d032b08, 0x0d1201a4, 0x0d036607, 0x38012708,
  0x02661f08, 0x161d1709, 0x271629af, 0x0d401721,
  0x03166609, 0x04000213, 0x0d124560, 0x140f18ad,
  0x14192114, 0x03451712, 0x01451911, 0x0f0d4512,
  // [5410]
  0x19010808, 0x01050f12, 0x0d100612, 0x15191009,
  0x14180d55, 0x21006609, 0x272129a4, 0x22180d12,
  0x430d0507, 0x06151708, 0x231e0ead, 0x14040b12,
  0x01002713, 0x120401ac, 0x0d1721ad, 0x0f0d05a4,
  // [5420]
  0x01001613, 0x15182212, 0x400d2909, 0x10272982,
  0x0f050821, 0x0c001820, 0x0f2714af, 0x01102107,
  0x381d51a4, 0x19172708, 0x190417be, 0x40040d09,
  0x192704ad, 0x1d000c20, 0x181908bc, 0x17292722,
  // [5430]
  0x05041760, 0x193f0409, 0x251e1caf, 0x040d1fa4,
  0x1d403f12, 0x030f0107, 0x011603a4, 0x0e1e30ad,
  0x43011f12, 0x18061209, 0x1d181512, 0x03183f6f,
  0x0d0f05af, 0x12450d12, 0x05180d08, 0x0f1205a4,
  // [5440]
  0x04180313, 0x216603af, 0x03662112, 0x220366af,
  0x22003f14, 0x380140a4, 0x0b061407, 0x66060508,
  0x036601a4, 0x020119a4, 0x1d0c2708, 0x0f290108,
  0x0b0516bb, 0x27006612, 0x03186623, 0x120c2b12,
  // [5450]
  0x1f081708, 0x140b51a4, 0x12454008, 0x03000213,
  0x190608a4, 0x451d17af, 0x06042907, 0x16023fad,
  0x18020b08, 0x38660360, 0x06031912, 0x10026613,
  0x27402914, 0x12004311, 0x291d4022, 0x1d2240af,
  // [5460]
  0x12004308, 0x38276607, 0x0b1402a4, 0x271d4014,
  0x140d3808, 0x1d224021, 0x100206a4, 0x050116a4,
  0x014005a4, 0x66001712, 0x40031760, 0x66010560,
  0x251e0e55, 0x171d6607, 0x0d050109, 0x03004007,
  // [5470]
  0x06196607, 0x08042255, 0x080105ad, 0x10180308,
  0x010512af, 0x12010512, 0x1d001721, 0x17430108,
  0x220f0d07, 0x081745af, 0x22001522, 0x16190f13,
  0x2b0108ad, 0x0d0c2221, 0x031002af, 0x03196607,
  // [5480]
  0x27292212, 0x0f220d09, 0x02001011, 0x01042107,
  0x0d220807, 0x403f0808, 0x12434514, 0x22004011,
  0x0f164022, 0x082b1aaf, 0x43000511, 0x0f220207,
  0x0d0f0caf, 0x45380f55, 0x40004533, 0x38000523,
  // [5490]
  0x04002112, 0x011d0407, 0x400f3f21, 0x0f213f22,
  0x01000c22, 0x1d000611, 0x18004308, 0x0d2112af,
  0x271051af, 0x430666ad, 0x06003811, 0x041d21af,
  0x041266a4, 0x456606af, 0x08001212, 0x18660112,
  // [54a0]
  0x15660b09, 0x190f27af, 0x18010f55, 0x29003809,
  0x06291608, 0x43001902, 0x1f000d12, 0x1d1840a4,
  0x40081d07, 0x08000420, 0x381466a4, 0x37001e10,
  0x300e2322, 0x0f270155, 0x01080209, 0x170d2207,
  // [54b0]
  0x08451212, 0x40081d08, 0x080c0107, 0x272b6613,
  0x432b0da4, 0x08011d09, 0x0f0d19a4, 0x012b1f12,
  0x19061711, 0x042b01a4, 0x16151209, 0x066616a4,
  0x19020b07, 0x270501af, 0x050122bb, 0x02141007,
  // [54c0]
  0x153f1920, 0x27041912, 0x453f4013, 0x15041611,
  0x17001920, 0x1d001522, 0x1d1004a4, 0x050145a4,
  0x02140b08, 0x38000d10, 0x15403faf, 0x08190413,
  0x40060812, 0x183819bb, 0x0d400b12, 0x401d45bb,
  // [54d0]
  0x2b003823, 0x40181daf, 0x18062bbe, 0x14272907,
  0x150c1721, 0x06011aa4, 0x45270209, 0x381940a4,
  0x12001407, 0x2b661f14, 0x66000620, 0x19011812,
  0x401d1812, 0x0d160155, 0x05183813, 0x0c154507,
  // [54e0]
  0x02002b13, 0x10450112, 0x22061007, 0x05081607,
  0x66190321, 0x10002b20, 0x251c2333, 0x14004512,
  0x1f001021, 0x01100621, 0x0b141f22, 0x03004513,
  0x16193f12, 0x19660360, 0x05081755, 0x02002713,
  // [54f0]
  0x43380511, 0x04454055, 0x29040b12, 0x19000114,
  0x66042bbb, 0x1d145112, 0x14042912, 0x040129a4,
  0x212b0112, 0x08100108, 0x0f080508, 0x03271412,
  0x38170d09, 0x38270812, 0x0d054302, 0x06002913,
  // [5500]
  0x120d05a4, 0x0c002111, 0x1d000812, 0x45001821,
  0x0f180512, 0x1d001220, 0x12451f07, 0x164512ac,
  0x0e1c1e22, 0x38140fa4, 0x22001912, 0x0c150b07,
  0x0b043802, 0x061217ad, 0x231c25bc, 0x0f3812af,
  // [5510]
  0x38050d11, 0x22160807, 0x0d001009, 0x011521a4,
  0x45051d12, 0x12451623, 0x40020b07, 0x1d0c0dac,
  0x40450302, 0x020d0f08, 0x40061dac, 0x40083f09,
  0x051f6609, 0x40083f08, 0x05193f09, 0x161d3f13,
  // [5520]
  0x222b29a4, 0x40081d09, 0x14382b60, 0x0c080112,
  0x12380112, 0x12100cad, 0x1d450c11, 0x16190509,
  0x381d27af, 0x03051702, 0x450229a4, 0x04430507,
  0x03042908, 0x02000412, 0x01400855, 0x14000813,
  // [5530]
  0x0d063855, 0x061d4009, 0x191427ad, 0x14120d07,
  0x05010412, 0x16041509, 0x0d0f2708, 0x06273f09,
  0x15190413, 0x17004014, 0x38065107, 0x190106ad,
  0x06010da4, 0x0e302355, 0x04003822, 0x0c121da4,
  // [5540]
  0x15050808, 0x030866ad, 0x01380511, 0x14451f12,
  0x1d0c0609, 0x454012af, 0x12384511, 0x27220112,
  0x1d406608, 0x18000521, 0x1f002222, 0x0b1d3f07,
  0x06031f21, 0x45380d09, 0x19001613, 0x453805a4,
  // [5550]
  0x0b0d01a4, 0x18292711, 0x16003f12, 0x06272955,
  0x22003809, 0x40121d08, 0x661803af, 0x01181912,
  0x02100607, 0x381006ad, 0x020b0460, 0x0c000802,
  0x06000114, 0x0f0366af, 0x382b06ad, 0x0d0f2121,
  // [5560]
  0x0b021907, 0x2b060211, 0x22190112, 0x06031913,
  0x190b03a4, 0x14380112, 0x29161921, 0x1627296f,
  0x45122911, 0x19002223, 0x27290313, 0x180f1fad,
  0x0c001020, 0x0d0f2bbb, 0x180d0f55, 0x22000307,
  // [5570]
  0x22141960, 0x04192121, 0x06180408, 0x660b1921,
  0x01051a07, 0x14450dad, 0x18004502, 0x02010b02,
  0x05141955, 0x14180d11, 0x04000322, 0x271d40af,
  0x18004521, 0x01272920, 0x10006621, 0x18061212,
  // [5580]
  0x27292134, 0x04100b12, 0x0229276f, 0x06291f12,
  0x27290814, 0x0b006613, 0x296606bc, 0x18002220,
  0x0f293f13, 0x21000209, 0x45120baf, 0x380b0611,
  0x01050814, 0x123845af, 0x0d0f17bb, 0x40451dbe,
  // [5590]
  0x011f0612, 0x081701ad, 0x160121bc, 0x19000f02,
  0x0d272955, 0x0e301e08, 0x0d380fa9, 0x05002208,
  0x161d1509, 0x1e000e20, 0x18050112, 0x18002209,
  0x0b6601a4, 0x0d0201af, 0x0d001809, 0x12161dad,
  // [55a0]
  0x05060307, 0x10010b09, 0x290601a4, 0x03196612,
  0x12052ba4, 0x45211909, 0x0d004007, 0x0b001413,
  0x02120112, 0x1f000f12, 0x03001914, 0x27192112,
  0x15270f11, 0x12050f09, 0x1d0f0509, 0x08004512,
  // [55b0]
  0x061004a4, 0x180206ac, 0x0117051f, 0x012b0b12,
  0x25233012, 0x04152112, 0x3f1d4022, 0x0b010202,
  0x45294012, 0x29036634, 0x14180bce, 0x22042707,
  0x172b0d12, 0x17221d12, 0x1d000814, 0x220b6614,
  // [55c0]
  0x19402707, 0x06001723, 0x40152707, 0x1d080c21,
  0x14292709, 0x10400812, 0x2b0c1622, 0x012b1608,
  0x18000d1f, 0x0c0d1811, 0x066601af, 0x0f0d3855,
  0x3800181f, 0x0c450daf, 0x03062207, 0x01170602,
  // [55d0]
  0x19000633, 0x17141907, 0x190b0407, 0x0e002534,
  0x04006611, 0x38002912, 0x43384509, 0x01012407,
  0x10182708, 0x012b0609, 0x10030b55, 0x03001902,
  0x02060b08, 0x19002208, 0x384501ad, 0x192214ac,
  // [55e0]
  0x22001022, 0x0e251cbc, 0x404512af, 0x1d184008,
  0x18000d02, 0x060166a4, 0x21272920, 0x16190b12,
  0x0c162712, 0x17121921, 0x191d0807, 0x191708a4,
  0x10152121, 0x1d150821, 0x100319af, 0x2b0f6609,
  // [55f0]
  0x1d0d3855, 0x0f0838a4, 0x38001d07, 0x16152114,
  0x04191621, 0x020b19ce, 0x18292121, 0x0c170407,
  0x15001921, 0x18011920, 0x19041209, 0x041d19a4,
  0x19000108, 0x19001420, 0x17010f08, 0x45001f08,
  // [5600]
  0x1d404523, 0x660f0512, 0x08041911, 0x010805a4,
  0x02001609, 0x453821a4, 0x38170da4, 0x0c001f09,
  0x141245ad, 0x0d222907, 0x14451211, 0x060f0b12,
  0x38403f12, 0x401d3f13, 0x230e2509, 0x170601a4,
  // [5610]
  0x301e2560, 0x181d4021, 0x04000614, 0x40001022,
  0x14012b08, 0x0b020421, 0x15001708, 0x1f6601a4,
  0x12061807, 0x062b0b08, 0x2b020baf, 0x12450d07,
  0x1d220802, 0x086601af, 0x400b0808, 0x191d1f07,
  // [5620]
  0x08190111, 0x04000820, 0x02401d07, 0x45001508,
  0x12020baf, 0x0f0d1fac, 0x10400407, 0x38171807,
  0x0b011812, 0x1400181d, 0x19100212, 0x033822ac,
  0x380f0509, 0x40000c11, 0x16004509, 0x170108af,
  // [5630]
  0x1d124023, 0x0b142b07, 0x0d3829a4, 0x161d4009,
  0x010d2bac, 0x1d0c2908, 0x06101960, 0x431619ac,
  0x0d082108, 0x38190c20, 0x120f0d02, 0x172b43a4,
  0x01060c12, 0x05001408, 0x020d22a4, 0x29182714,
  // [5640]
  0x06400309, 0x1d004523, 0x060266a4, 0x190140a4,
  0x18060d60, 0x03056609, 0x3f004514, 0x380d3fbe,
  0x104006af, 0x06142708, 0x01004008, 0x27294009,
  0x18294012, 0x011003a4, 0x380f0821, 0x38000810,
  // [5650]
  0x17013809, 0x08011da4, 0x17010309, 0x1d4027a4,
  0x05020307, 0x17010809, 0x29000612, 0x14060808,
  0x1d0815ad, 0x01141612, 0x04150808, 0x100b2212,
  0x17100308, 0x293f1d60, 0x1f0d06bc, 0x100f0d60,
  // [5660]
  0x171d12af, 0x661906af, 0x04221914, 0x0c002913,
  0x221604a4, 0x17221602, 0x10181407, 0x120c16a4,
  0x10002708, 0x0f032ba4, 0x2b270108, 0x29273f08,
  0x0c183f07, 0x660b0314, 0x06050855, 0x292708af,
  // [5670]
  0x27011f12, 0x29006614, 0x38010d13, 0x01291fad,
  0x171d0fa4, 0x45120808, 0x1412455e, 0x450d0f12,
  0x23301c07, 0x40001d33, 0x12450d09, 0x0f001f33,
  0x0b223821, 0x010d4302, 0x401f1612, 0x042118a4,
  // [5680]
  0x03661212, 0x10180612, 0x66010809, 0x082b01af,
  0x1f1845af, 0x011d4013, 0x2b1f0613, 0x1d430112,
  0x04001721, 0x063817ad, 0x05001536, 0x06036620,
  0x120f0d12, 0x662b0809, 0x10164002, 0x0d172b07,
  // [5690]
  0x29000c11, 0x0d141f13, 0x12106611, 0x14041934,
  0x170b0214, 0x03063809, 0x220b1007, 0x43003812,
  0x22020b13, 0x45080da4, 0x10036614, 0x18100b08,
  0x10002908, 0x100c0b12, 0x0d220809, 0x400d0f08,
  // [56a0]
  0x10082212, 0x01191008, 0x12220607, 0x080c3809,
  0x220151a4, 0x40002b09, 0x05120109, 0x01020b14,
  0x10001d07, 0x43120202, 0x060319af, 0x1f004509,
  0x10171f07, 0x03060221, 0x033801a4, 0x0d0f2907,
  // [56b0]
  0x052b01a4, 0x2b000512, 0x03055112, 0x0d2b0f13,
  0x190106a4, 0x0d1d10a4, 0x12044560, 0x12662909,
  0x430801ac, 0x2b1d0daf, 0x050f3809, 0x452729a4,
  0x101d4013, 0x1d401022, 0x0c191011, 0x66035112,
  // [56c0]
  0x221d0f12, 0x0c2b0111, 0x080506ad, 0x662b01a4,
  0x10000321, 0x27002108, 0x16012bbe, 0x18222712,
  0x061d0312, 0x0f451255, 0x0f0d2107, 0x12100bad,
  0x17001914, 0x06126612, 0x06083f13, 0x401d17af,
  // [56d0]
  0x03182108, 0x18292713, 0x0c0f08a4, 0x1c0e1ead,
  0x19101d07, 0x22380509, 0x193808a4, 0x0c401da4,
  0x3f080d09, 0x191821a4, 0x03002907, 0x27006613,
  0x04150809, 0x01182709, 0x0c150808, 0x12453f21,
  // [56e0]
  0x1d3f2912, 0x38180f55, 0x080b0202, 0x011d0fa4,
  0x18400b09, 0x292738af, 0x15271621, 0x1d2729a4,
  0x00005c15, 0x22141009, 0x18042912, 0x29273f11,
  0x01663f07, 0x011f6608, 0x18160412, 0x190b026f,
  // [56f0]
  0x04270bbb, 0x66000433, 0x21016609, 0x03192b07,
  0x031f1012, 0x190d0855, 0x0d081612, 0x0c272960,
  0x01272213, 0x453f1213, 0x27083fbc, 0x151722ad,
  0x27024012, 0x050601ac, 0x1d403f14, 0x14173809,
  // [5700]
  0x27083fad, 0x060b1707, 0x40081760, 0x03003812,
  0x0f0d1f21, 0x251c3012, 0x0d000812, 0x08401d13,
  0x3f271813, 0x3f1d4034, 0x40043f13, 0x210f08be,
  0x21042712, 0x22000f12, 0x19220c55, 0x19030b07,
  // [5710]
  0x06046608, 0x10184009, 0x293f2109, 0x03012707,
  0x0f211660, 0x121f1912, 0x01050f08, 0x034021af,
  0x0b660309, 0x0f190b11, 0x0f050809, 0x22041d09,
  0x140f19ad, 0x381819a4, 0x0f002920, 0x221521a4,
  // [5720]
  0x160c2108, 0x29002b13, 0x08191709, 0x3f0b0808,
  0x1c1e2309, 0x210145af, 0x1d400b09, 0x03001609,
  0x0f190209, 0x05660209, 0x05001814, 0x0b192107,
  0x03042107, 0x05001821, 0x660603af, 0x16000808,
  // [5730]
  0x66210309, 0x0c030655, 0x400c1d02, 0x02030612,
  0x0b124511, 0x161d4022, 0x0b176608, 0x180f0512,
  0x04006609, 0x180f0507, 0x10020614, 0x660206af,
  0x193f0421, 0x031008a4, 0x0b102209, 0x450f0d60,
  // [5740]
  0x0e2523ac, 0x0b380107, 0x121d0809, 0x01061702,
  0x1d100da4, 0x23250ea4, 0x450d2909, 0x01153f11,
  0x38401608, 0x08293fbc, 0x16124555, 0x19170422,
  0x40081d21, 0x0c290d13, 0x22030608, 0x451d3809,
  // [5750]
  0x1d001521, 0x030b51a4, 0x12220d11, 0x10010655,
  0x10380609, 0x12180609, 0x06014309, 0x08060daf,
  0x190129a4, 0x1e1c23af, 0x08010f07, 0x450b0609,
  0x02010d07, 0x251e2308, 0x02080309, 0x080f1d12,
  // [5760]
  0x010b02a4, 0x02081009, 0x380314a4, 0x10140421,
  0x010410a4, 0x15100660, 0x1c253013, 0x0c122b07,
  0x100602a4, 0x170119ac, 0x29161909, 0x193f4512,
  0x27003f22, 0x0c122709, 0x080127a4, 0x45211620,
  // [5770]
  0x2b3f2921, 0x0d082912, 0x451d406f, 0x29451421,
  0x29004512, 0x140d0508, 0x0c081812, 0x272b2914,
  0x104508ad, 0x45080c07, 0x061f6612, 0x160c2107,
  0x03660111, 0x012b0614, 0x0b060207, 0x160c38a4,
  // [5780]
  0x0b100607, 0x45221d12, 0x16271407, 0x16080bac,
  0x121d08a4, 0x2b066621, 0x0c120812, 0x02221d12,
  0x19010608, 0x18380512, 0x1e250e02, 0x02451508,
  0x301c1eaf, 0x66001533, 0x660c15af, 0x15000b13,
  // [5790]
  0x660c0611, 0x03001520, 0x45002907, 0x0b034308,
  0x301e2520, 0x10154511, 0x38170f13, 0x03430507,
  0x38010611, 0x18291612, 0x22000809, 0x0d002708,
  0x401d2207, 0x18292760, 0x293f2709, 0x29052709,
  // [57a0]
  0x3f272960, 0x080f3f07, 0x08003f13, 0x161545af,
  0x40272933, 0x40272913, 0x01002212, 0x27402913,
  0x27403f13, 0x40002912, 0x050140bb, 0x06180b08,
  0x01191f11, 0x10021709, 0x16150812, 0x01223f11,
  // [57b0]
  0x020d1708, 0x04001708, 0x17001f14, 0x02001602,
  0x38190408, 0x0f051912, 0x661929af, 0x05001702,
  0x0f171f21, 0x05000420, 0x40120412, 0x1f3f4560,
  0x01170f60, 0x0f162b55, 0x192921af, 0x14451812,
  // [57c0]
  0x19296608, 0x0f001608, 0x140b12a4, 0x19040107,
  0x01660308, 0x150108a4, 0x16084008, 0x45100260,
  0x08061d07, 0x021045af, 0x0c050109, 0x03020baf,
  0x03661f09, 0x01432109, 0x30000e35, 0x022b1fcf,
  // [57d0]
  0x14160b02, 0x1d0b03ac, 0x04292714, 0x04000f12,
  0x0c036611, 0x16190407, 0x40000211, 0x21036623,
  0x040f29af, 0x400c4512, 0x100b0308, 0x08006611,
  0x19160dbc, 0x17012bad, 0x400f0802, 0x08170511,
  // [57e0]
  0x17061612, 0x14162907, 0x17103812, 0x17002111,
  0x401629a4, 0x18151612, 0x161d40a4, 0x042927be,
  0x0d020b12, 0x0b026614, 0x19380807, 0x05036611,
  0x101f0112, 0x250e3012, 0x032218ac, 0x0f060155,
  // [57f0]
  0x0f0d0107, 0x0f141f12, 0x0c020508, 0x0c174007,
  0x03296609, 0x29030112, 0x03002b22, 0x381d0dbe,
  0x380f0d22, 0x15160113, 0x011629ac, 0x180d0f07,
  0x05010d08, 0x1c231ece, 0x180b1014, 0x38431aaf,

  // [5800]
  0x1d100808, 0x2b001f09, 0x12101d09, 0x08010208,
  0x030506ac, 0x0b001812, 0x10661fad, 0x21020b09,
  0x0e301ebe, 0x19036621, 0x08270108, 0x0b1901a4,
  0x08013802, 0x14002213, 0x04452209, 0x17001411,
  // [5810]
  0x381d4507, 0x0f1d0407, 0x04222107, 0x1d12400b,
  0x06011008, 0x45124007, 0x080d0408, 0x29172709,
  0x06000d11, 0x231e256f, 0x22000107, 0x0c054008,
  0x01381708, 0x04000821, 0x14026612, 0x06381f12,
  // [5820]
  0x271f1709, 0x16272208, 0x01191707, 0x171f0109,
  0x05291708, 0x171f01a4, 0x27382113, 0x04060107,
  0x18001608, 0x08170309, 0x18002133, 0x40276608,
  0x230e3013, 0x0b020512, 0x272966be, 0x06271d13,
  // [5830]
  0x01081812, 0x081715a4, 0x01020baf, 0x0f0508a4,
  0x29222723, 0x29662714, 0x0f0143a4, 0x181d40ac,
  0x180d0f02, 0x120c0d12, 0x2b1f17af, 0x14100b21,
  0x02661009, 0x151017ac, 0x05143821, 0x2b001023,
  // [5840]
  0x0f0c1d13, 0x17052220, 0x0f0840a4, 0x380d51af,
  0x16083882, 0x120c4009, 0x220f0d6f, 0x21290409,
  0x16060408, 0x22660311, 0x0b013802, 0x17002222,
  0x01000622, 0x060121a4, 0x170d3809, 0x2b000c21,
  // [5850]
  0x01061555, 0x07005c0e, 0x401d4502, 0x3f0c01af,
  0x060c1507, 0x432b0811, 0x08380302, 0x12060d08,
  0x0d0f0107, 0x0f181d07, 0x1d382909, 0x0d194312,
  0x43000520, 0x141d3f09, 0x401d0c20, 0x1d150409,
  // [5860]
  0x0f1917af, 0x143f1f23, 0x14401909, 0x193f0412,
  0x10080560, 0x3f1d2109, 0x19212960, 0x2b050814,
  0x0f173f34, 0x22182107, 0x1d120809, 0x210c3f09,
  0x38040808, 0x05191f12, 0x01190f08, 0x452204a4,
  // [5870]
  0x0d001902, 0x18190509, 0x0b061023, 0x293f2122,
  0x293f2120, 0x10040607, 0x29272122, 0x02051960,
  0x060b1021, 0x0f180508, 0x03140607, 0x22191012,
  0x060b1007, 0x1d190109, 0x1e253013, 0x041d0b09,
  // [5880]
  0x2b002709, 0x0d011909, 0x220618ad, 0x18000502,
  0x014510ac, 0x38401d07, 0x06190209, 0x251e0e14,
  0x02000602, 0x19030ba4, 0x06010bad, 0x12451dbb,
  0x18191022, 0x2b0601af, 0x1e1c2582, 0x0b430107,
  // [5890]
  0x40083809, 0x12044512, 0x1d1204a4, 0x12030408,
  0x020b6621, 0x17004021, 0x121d2b09, 0x02100609,
  0x30001c22, 0x01456608, 0x402729ad, 0x21012b12,
  0x402b1dac, 0x08000b08, 0x0d040813, 0x1d0f0d11,
  // [58a0]
  0x06005108, 0x02100f09, 0x0b182b55, 0x30252311,
  0x212729a4, 0x17060cbb, 0x16151d12, 0x0b045112,
  0x2b272909, 0x030d1709, 0x40000111, 0x0c050108,
  0x0c001507, 0x042b4008, 0x38160f08, 0x1d124060,
  // [58b0]
  0x031910a4, 0x10222107, 0x220c1d08, 0x01083855,
  0x450f0109, 0x100b3f09, 0x3f002b13, 0x120302ad,
  0x0c084507, 0x06221012, 0x12270c12, 0x220b1011,
  0x1e230ebb, 0x050129ad, 0x0d0f3860, 0x040d0812,
  // [58c0]
  0x0c4512a4, 0x25300ebe, 0x01210560, 0x08012908,
  0x1d0445af, 0x25301ca4, 0x01172907, 0x1e251c20,
  0x451215af, 0x22004009, 0x06171212, 0x062203af,
  0x060522ad, 0x06120107, 0x0f005108, 0x0d064507,
  // [58d0]
  0x100104ac, 0x22062907, 0x18401955, 0x0d0b0f07,
  0x27002114, 0x14002908, 0x0c011007, 0x02030b02,
  0x1e251c02, 0x40451612, 0x151d0312, 0x03401d07,
  0x451d1611, 0x0c164008, 0x04193f09, 0x21162912,
  // [58e0]
  0x05003f12, 0x66211913, 0x380c1260, 0x04191fad,
  0x4519045e, 0x010d3fad, 0x014519a4, 0x06180411,
  0x1d0d2907, 0x2b010f09, 0x29011f60, 0x29212714,
  0x451d1612, 0x01120f07, 0x032729af, 0x1d403823,
  // [58f0]
  0x38660208, 0x1d062712, 0x29180cad, 0x08270308,
  0x18000409, 0x19060807, 0x0c190807, 0x2b181f21,
  0x17000111, 0x152b16ad, 0x010c08a4, 0x43040112,
  0x06140b6f, 0x22010612, 0x12106608, 0x03660109,
  // [5900]
  0x06452107, 0x02001711, 0x1e250e08, 0x27080f20,
  0x01180f02, 0x101d05a4, 0x0c401d02, 0x02430302,
  0x1f0f3f12, 0x27452909, 0x1d380f02, 0x45191607,
  0x03014309, 0x181d1907, 0x43000307, 0x00001403,
  // [5910]
  0x190204a4, 0x100651af, 0x430d2907, 0x02220b07,
  0x27293fa4, 0x1e233021, 0x04213faf, 0x06213fad,
  0x06430112, 0x16124520, 0x0b101f09, 0x17270812,
  0x081d0d12, 0x06011607, 0x0b140609, 0x1f292720,
  // [5920]
  0x0f0412bc, 0x08401d20, 0x164517a4, 0x66020312,
  0x40040cbc, 0x0c0f4514, 0x030201ac, 0x453f16af,
  0x27000d13, 0x06011d08, 0x1d4003a4, 0x0f170412,
  0x16191da4, 0x66000212, 0x04380307, 0x251e23ac,
  // [5930]
  0x03662bbb, 0x661f0baf, 0x02062121, 0x29271212,
  0x0d0f2123, 0x03001d08, 0x19213f12, 0x06141611,
  0x38271d12, 0x15000412, 0x011406ac, 0x1d002213,
  0x061651af, 0x181f1713, 0x290d2108, 0x0c000d22,
  // [5940]
  0x0c080d07, 0x14003f21, 0x012721a4, 0x12220ba4,
  0x1d102207, 0x182238af, 0x19170802, 0x40170f02,
  0x16401d14, 0x060b40ac, 0x22386607, 0x04401d09,
  0x40161d13, 0x1d0106af, 0x401d1614, 0x1d140609,
  // [5950]
  0x40151d60, 0x100b0ca4, 0x12011d11, 0x15401d12,
  0x17124508, 0x0f000b08, 0x15161d14, 0x01030413,
  0x01030414, 0x01190455, 0x15000622, 0x010d2709,
  0x04190f09, 0x03016655, 0x0d382912, 0x01290812,
  // [5960]
  0x080f3f60, 0x40000f08, 0x170c2ba4, 0x2b270809,
  0x0b021011, 0x020301a4, 0x021d12a4, 0x1e0e2314,
  0x21291708, 0x14004514, 0x2b080faf, 0x0f010b09,
  0x0c001720, 0x1d0b10af, 0x01221f07, 0x1d0619a4,
  // [5970]
  0x01030207, 0x03001521, 0x270d3f12, 0x19380f60,
  0x15080f09, 0x0d0805af, 0x02401212, 0x0d001f20,
  0x00001415, 0x14161513, 0x12051707, 0x01060512,
  0x380105ad, 0x12001614, 0x10192212, 0x40381da4,
  // [5980]
  0x042901a4, 0x03003809, 0x010c2708, 0x04061d07,
  0x40211607, 0x12450b09, 0x011619bc, 0x08181955,
  0x0f173f60, 0x0f173f09, 0x29170f09, 0x05221d02,
  0x0b451260, 0x0f171807, 0x38000b09, 0x400103a4,
  // [5990]
  0x302523af, 0x0e3025af, 0x01031808, 0x040666a4,
  0x04000c13, 0x061803a4, 0x16010fbb, 0x060f1009,
  0x190b0607, 0x1d16156f, 0x01271860, 0x29380f09,
  0x03193808, 0x06290111, 0x450301ad, 0x010b05a4,
  // [59a0]
  0x0f0d1613, 0x120345a4, 0x38170313, 0x1d000d08,
  0x16151d60, 0x17380108, 0x0e002533, 0x0f0d2b02,
  0x0d0f1daf, 0x05271dad, 0x05401d12, 0x05011708,
  0x01213f55, 0x1d293f08, 0x40661d09, 0x0d001414,
  // [59b0]
  0x0c0d2708, 0x1d3f40af, 0x0f401d11, 0x06101612,
  0x45180d08, 0x29401daf, 0x04161509, 0x05100112,
  0x40062b60, 0x051d2108, 0x213f0d12, 0x100106af,
  0x15000d02, 0x02380fa4, 0x01031007, 0x40161d55,
  // [59c0]
  0x10124560, 0x011d04a4, 0x180b2113, 0x15401dad,
  0x02060407, 0x010c2113, 0x2b003814, 0x06043f12,
  0x38010407, 0x042b0f14, 0x101219ad, 0x2b191faf,
  0x0c080609, 0x14000c14, 0x0c290312, 0x0f050d14,
  // [59d0]
  0x40153fac, 0x01100208, 0x38000110, 0x45051209,
  0x12000c13, 0x02050108, 0x450d0808, 0x17010808,
  0x380d45a4, 0x0f381421, 0x0f194507, 0x0b1701af,
  0x19020b13, 0x010c2907, 0x27020b13, 0x100251a4,
  // [59e0]
  0x061766a4, 0x02170809, 0x1e300e08, 0x100b06ac,
  0x14001613, 0x05013fa4, 0x270121be, 0x15080621,
  0x0f031fbe, 0x0d0f19af, 0x0b0214af, 0x050c0f07,
  0x050c1212, 0x27000408, 0x1d1819ac, 0x1c0e2555,
  // [59f0]
  0x12404508, 0x0f290cad, 0x04124508, 0x18000f02,
  0x12451813, 0x15000808, 0x1e1c2321, 0x1c0e3007,
  0x2b220808, 0x0f080d23, 0x0f222bad, 0x29271f12,
  0x0d220812, 0x270810a4, 0x0d083f21, 0x03180f11,
  // [5a00]
  0x170d29a4, 0x2b186609, 0x0c154055, 0x3f2208af,
  0x0f380114, 0x450d6609, 0x170f3802, 0x08011f55,
  0x06080412, 0x04100655, 0x08380d6f, 0x0f2201a4,
  0x08190112, 0x19000c08, 0x12171d20, 0x250e1c02,
  // [5a10]
  0x120306a4, 0x066603bc, 0x170508af, 0x100618ab,
  0x10401d09, 0x05181908, 0x1d0c4502, 0x380d17af,
  0x1e230e21, 0x01101d09, 0x0f050111, 0x14001708,
  0x0b021409, 0x0f010da4, 0x03192b08, 0x0d270cbc,
  // [5a20]
  0x15002b23, 0x45171d09, 0x0c2b1d09, 0x19041611,
  0x03010502, 0x226606af, 0x010227ac, 0x1d002b21,
  0x380119af, 0x15401d07, 0x171612af, 0x181615be,
  0x180440af, 0x120f0d08, 0x19160408, 0x301e23a4,
  // [5a30]
  0x06001d09, 0x0d043faf, 0x3f211f21, 0x1f000421,
  0x1f002113, 0x1d291f08, 0x0f011512, 0x16040508,
  0x150416a4, 0x01121d09, 0x100f0107, 0x010d4308,
  0x10146607, 0x180f0d02, 0x0f384311, 0x19003822,
  // [5a40]
  0x05001502, 0x180d1faf, 0x0f220daf, 0x38041f08,
  0x1f141814, 0x0c121407, 0x0d222755, 0x1d042955,
  0x141006af, 0x012718bc, 0x0b3f0109, 0x0d050155,
  0x22181f60, 0x66211012, 0x01061613, 0x210801af,
  // [5a50]
  0x3f380112, 0x06660409, 0x103f12a4, 0x0d001413,
  0x174303a4, 0x141f0611, 0x1d2b1912, 0x40101d09,
  0x2914216f, 0x1d0419ad, 0x452717bb, 0x43010baf,
  0x22001721, 0x3f2921af, 0x22062707, 0x0b1040a4,
  // [5a60]
  0x0c291708, 0x010266a4, 0x22011712, 0x22001711,
  0x01061907, 0x19211722, 0x292717bc, 0x10013860,
  0x030105ad, 0x401d0155, 0x013810ad, 0x2b000f09,
  0x66013812, 0x05190212, 0x1d001210, 0x0b222113,
  // [5a70]
  0x0f050302, 0x660c4560, 0x02220307, 0x0e251c23,
  0x27291913, 0x1d2701ad, 0x292719be, 0x29270621,
  0x29270622, 0x272906be, 0x16152712, 0x292b1412,
  0x05013f12, 0x22002914, 0x22212909, 0x100b40a4,
  // [5a80]
  0x292706cf, 0x220c2709, 0x29001d09, 0x1d27296f,
  0x0b041702, 0x2b0f0d13, 0x121d4010, 0x431f4512,
  0x16041d09, 0x270c2ba4, 0x273f0414, 0x15001002,
  0x0c120fa4, 0x1d0f17a4, 0x43401d02, 0x170d0121,
  // [5a90]
  0x06001809, 0x03046614, 0x0f065112, 0x060419ad,
  0x1f0f1760, 0x0b000236, 0x05010820, 0x22001d02,
  0x03001514, 0x080b1407, 0x08000411, 0x170b0402,
  0x020b1f22, 0x192101ad, 0x0f0117ad, 0x401d1612,
  // [5aa0]
  0x19052155, 0x06190812, 0x22000409, 0x300e2308,
  0x100b38a4, 0x0b0619ac, 0x031716a4, 0x041903bb,
  0x04060155, 0x0d2b1709, 0x301c2514, 0x14060ba4,
  0x45036609, 0x010f0d13, 0x191f0b09, 0x40003f13,
  // [5ab0]
  0x270d0f13, 0x1d004511, 0x2b0d0f12, 0x01060807,
  0x0f0d2113, 0x06191007, 0x1d400d08, 0x160f0d6f,
  0x0d0819ac, 0x210d0f6f, 0x0d381921, 0x40451560,
  0x08002112, 0x220b17a4, 0x38450f55, 0x10140b11,
  // [5ac0]
  0x10041912, 0x084301ac, 0x380408ad, 0x120c1902,
  0x06124055, 0x27452912, 0x18001921, 0x660c3fa4,
  0x27291914, 0x01192755, 0x08001002, 0x22102109,
  0x041914af, 0x03101407, 0x191608a4, 0x19401da4,
  // [5ad0]
  0x03106621, 0x101618a4, 0x08290209, 0x04432207,
  0x03001f07, 0x17120dad, 0x082b0509, 0x16001421,
  0x02011908, 0x45050109, 0x0f0d05ad, 0x14290109,
  0x2b170baf, 0x2b210112, 0x1d4540ad, 0x01380507,
  // [5ae0]
  0x1c0e1ebe, 0x010b29a4, 0x14181f12, 0x21010412,
  0x21001213, 0x15050607, 0x050f0d23, 0x660b5112,
  0x2b180412, 0x14404512, 0x30251e14, 0x024540a4,
  0x04022bac, 0x10196608, 0x12454011, 0x030106bb,
  // [5af0]
  0x060d1521, 0x29223f12, 0x45121fac, 0x0c001522,
  0x08001f11, 0x3f290421, 0x12020407, 0x14451207,
  0x101727bc, 0x0f0602af, 0x45164007, 0x050106bc,
  0x06000c21, 0x06002223, 0x22060808, 0x06292ba4,
  // [5b00]
  0x03190b12, 0x29011fbc, 0x19172109, 0x060b2260,
  0x172729be, 0x2b0302af, 0x19031607, 0x12001920,
  0x270f0809, 0x041410af, 0x02001413, 0x380b0208,
  0x2b012109, 0x190b16be, 0x40002213, 0x0b192712,
  // [5b10]
  0x01042912, 0x191629ad, 0x21060309, 0x12011760,
  0x0b100260, 0x010f0820, 0x100b19ce, 0x06001023,
  0x0e1e1cbb, 0x12142208, 0x0d1438a4, 0x034301af,
  0x662729af, 0x02661012, 0x02160b02, 0x03380d09,
  // [5b20]
  0x1d0104a4, 0x011d4055, 0x25230e12, 0x10180655,
  0x171f3808, 0x080115a4, 0x27173809, 0x0f042908,
  0x27294014, 0x0b120214, 0x401d04ad, 0x03292708,
  0x27001d08, 0x0b101409, 0x0c061012, 0x04190807,
  // [5b30]
  0x171901af, 0x01040da4, 0x38040d07, 0x0d0445af,
  0x010519af, 0x40000213, 0x0f0d2708, 0x04000d21,
  0x03661021, 0x03001f13, 0x161d6609, 0x18430808,
  0x10001620, 0x1f080112, 0x16452212, 0x220d0155,
  // [5b40]
  0x01001021, 0x45081208, 0x2b003807, 0x0b451008,
  0x14000c09, 0x0b100309, 0x16100b09, 0x030b1607,
  0x231e2522, 0x020b0808, 0x0c060509, 0x061d0d09,
  0x16451908, 0x38170daf, 0x22052bbb, 0x05040bad,
  // [5b50]
  0x0d270208, 0x0f2b38a4, 0x190866af, 0x251c1eac,
  0x2b145112, 0x010f2155, 0x38000b02, 0x301c0e22,
  0x15003f07, 0x18106660, 0x0f141711, 0x080603af,
  0x0c1840a4, 0x010f2209, 0x02001612, 0x451201af,
  // [5b60]
  0x45151d12, 0x01032108, 0x053f0fbc, 0x100614bc,
  0x120c0134, 0x151627af, 0x1d1610ad, 0x0b006621,
  0x17036609, 0x0d020107, 0x010603ad, 0x2b000821,
  0x16660faf, 0x1e0e25ac, 0x14066613, 0x19060408,
  // [5b70]
  0x14380f08, 0x08050f21, 0x03661560, 0x43192907,
  0x14041f13, 0x38431709, 0x0b066608, 0x10380ba4,
  0x0d0f3f14, 0x17003f20, 0x19000b09, 0x0d0f4008,
  0x10020655, 0x1d080f12, 0x010f27a4, 0x060b08a4,
  // [5b80]
  0x1d173faf, 0x0d003f21, 0x45120502, 0x060b01a4,
  0x15031612, 0x431f1421, 0x05660812, 0x08051909,
  0x0d1508af, 0x403f0509, 0x45140cad, 0x1c003035,
  0x012b2707, 0x0d0f0822, 0x080527af, 0x1f124560,
  // [5b90]
  0x15163860, 0x451243af, 0x150d0f12, 0x120645a4,
  0x0d401d55, 0x1c0e2520, 0x0d030812, 0x454312af,
  0x0f190808, 0x16080412, 0x17140d08, 0x101951a4,
  0x03161daf, 0x020b16a4, 0x03292109, 0x27101f09,
  // [5ba0]
  0x0d030807, 0x100f386f, 0x03012bbc, 0x12050809,
  0x291d1008, 0x0f001d13, 0x080f10be, 0x0f171d09,
  0x38100212, 0x121d40be, 0x380f1060, 0x40100313,
  0x05451d08, 0x660b0214, 0x0f0d1409, 0x1d000102,
  // [5bb0]
  0x050c0fa4, 0x05001011, 0x0f1d1021, 0x293f0d13,
  0x292710af, 0x05381021, 0x0f051012, 0x0c000f08,
  0x43142712, 0x0f0d1fa4, 0x15002209, 0x0d0c0112,
  0x40451d12, 0x27023808, 0x03011d12, 0x050838a4,
  // [5bc0]
  0x18041911, 0x19662b09, 0x1d102208, 0x1d4017bc,
  0x060d0409, 0x0f0851a4, 0x02100807, 0x431d1811,
  0x011f2955, 0x012102ad, 0x40101907, 0x17121d07,
  0x250e1e60, 0x140b08a4, 0x1d12406b, 0x45121dbb,
  // [5bd0]
  0x10180212, 0x23302521, 0x190245a4, 0x0f0401a4,
  0x05014511, 0x0b270609, 0x01053821, 0x0c141612,
  0x18162213, 0x18001420, 0x173f1920, 0x1d400b07,
  0x140b29a4, 0x18142112, 0x04145112, 0x221921ad,
  // [5be0]
  0x023f2111, 0x2b001422, 0x1f380409, 0x1f001434,
  0x04140112, 0x17272221, 0x0b140612, 0x0d012baf,
  0x14030d21, 0x060d0807, 0x102b01ac, 0x0d292208,
  0x45030611, 0x04161413, 0x04190621, 0x0d190414,
  // [5bf0]
  0x23001c23, 0x190151a4, 0x29006611, 0x38002111,
  0x01001909, 0x1e001c33, 0x021d6612, 0x160d2708,
  0x2b002708, 0x06051aa4, 0x04050f13, 0x270529a4,
  0x0c010802, 0x29010c12, 0x21151609, 0x0c002120,

  // [5c00]
  0x66003f20, 0x03011f08, 0x00002415, 0x143f0812,
  0x43186607, 0x45060107, 0x06010509, 0x0f173808,
  0x17383f09, 0x66000c13, 0x19140b60, 0x124301a4,
  0x061f0855, 0x2b272911, 0x0b040c60, 0x08041807,
  // [5c10]
  0x1d0b1012, 0x43190112, 0x19220307, 0x25231ead,
  0x011008ac, 0x66081921, 0x05030f11, 0x40041911,
  0x192210af, 0x0f001612, 0x05041612, 0x04001602,
  0x401d0608, 0x1d101907, 0x060b1013, 0x100419af,
  // [5c20]
  0x14002b23, 0x06010d55, 0x06101811, 0x03170660,
  0x18061912, 0x01400808, 0x030406ad, 0x08063fad,
  0x180c16ac, 0x12104009, 0x04001d07, 0x101d2208,
  0x0d2b05bc, 0x08191721, 0x01100809, 0x05171912,
  // [5c30]
  0x66190412, 0x03053807, 0x05083fa4, 0x25302321,
  0x19001734, 0x404327a4, 0x21001913, 0x0c220d09,
  0x0c080f14, 0x380f0109, 0x060c0812, 0x25003021,
  0x1c302320, 0x10040b12, 0x220219ad, 0x10140ba4,
  // [5c40]
  0x0b041807, 0x45154009, 0x06384302, 0x041d4055,
  0x05012b07, 0x271915af, 0x191d27a4, 0x06121faf,
  0x010814af, 0x66272bbb, 0x12190f02, 0x161d2212,
  0x0f292b08, 0x06012bad, 0x020419bb, 0x05011907,
  // [5c50]
  0x224501af, 0x0d190413, 0x080519ad, 0x0f220809,
  0x03062255, 0x0b1901af, 0x01190420, 0x0c292109,
  0x04161522, 0x0f170513, 0x15270308, 0x45121855,
  0x2b002121, 0x0c222909, 0x03170512, 0x01214060,
  // [5c60]
  0x190b2709, 0x08000120, 0x22040b09, 0x101d01a4,
  0x270419af, 0x40061daf, 0x12450355, 0x21290faf,
  0x0e251c6d, 0x19162111, 0x3f2204be, 0x662901af,
  0x2716216f, 0x02003812, 0x30230ece, 0x21040612,
  // [5c70]
  0x29100b13, 0x06041912, 0x0b042709, 0x0c101202,
  0x02151608, 0x0d170112, 0x012b0312, 0x194529a4,
  0x141040af, 0x19120b08, 0x45401913, 0x0f380512,
  0x29194008, 0x40190f55, 0x0f401d12, 0x151d4009,
  // [5c80]
  0x10002b14, 0x043f1921, 0x140b0207, 0x12141807,
  0x3f042909, 0x221619af, 0x1f000623, 0x051f1721,
  0x080d0f22, 0x0c020b60, 0x06081d08, 0x29272bad,
  0x08013809, 0x192701af, 0x0b030607, 0x0d211212,
  // [5c90]
  0x29012708, 0x45160612, 0x101d19ad, 0x182b0612,
  0x401d0208, 0x3f2901a4, 0x3f0c0121, 0x400b10bc,
  0x180805ad, 0x180c2112, 0x0b051013, 0x66020b09,
  0x300e2321, 0x22213f11, 0x100b2107, 0x0d045112,
  // [5ca0]
  0x0f002114, 0x21270f12, 0x0c0521a4, 0x27104013,
  0x011d1909, 0x15160fac, 0x1d000f13, 0x06292755,
  0x02080107, 0x66000f13, 0x0827296f, 0x060b0412,
  0x0f663812, 0x030c2b08, 0x0b102bac, 0x06024560,
  // [5cb0]
  0x192729bc, 0x3f160f21, 0x0d432107, 0x661d4060,
  0x663f2760, 0x19000f09, 0x29013f12, 0x22080d11,
  0x19012b07, 0x38140fac, 0x01000c20, 0x43010f08,
  0x191002a4, 0x010c0313, 0x21000512, 0x08040102,
  // [5cc0]
  0x06080f09, 0x0d0f1fa4, 0x051f01af, 0x02060102,
  0x0b140809, 0x03022109, 0x182b0420, 0x171d406f,
  0x450f0d09, 0x06002209, 0x05171da4, 0x251c1e11,
  0x401d1714, 0x19051dbe, 0x120d0f09, 0x06170d07,
  // [5cd0]
  0x081d4020, 0x0f0b1909, 0x220f2b12, 0x29001621,
  0x66401d60, 0x051f2155, 0x0c000d10, 0x45120d08,
  0x0f404512, 0x1d0f0caf, 0x1d294020, 0x1d0827af,
  0x38081609, 0x12160c12, 0x451427ac, 0x0c450502,
  // [5ce0]
  0x190d2112, 0x1f1d4060, 0x171d1907, 0x1d080509,
  0x0c000b09, 0x0f4512be, 0x052b1f21, 0x660827a4,
  0x1f004322, 0x66034012, 0x010b0220, 0x0b001d11,
  0x061219bb, 0x180602af, 0x010f4002, 0x1c1e2307,
  // [5cf0]
  0x221d3809, 0x01382708, 0x05083807, 0x401d2109,
  0x12184013, 0x661f0409, 0x29043faf, 0x2530236f,
  0x18041920, 0x19031408, 0x150116ac, 0x29002711,
  0x120f4312, 0x18451208, 0x101d2221, 0x020b0807,
  // [5d00]
  0x080f29a4, 0x40021d13, 0x01002211, 0x15292709,
  0x08004509, 0x03061708, 0x27103f13, 0x03186614,
  0x151d2209, 0x14035112, 0x05020807, 0x1d1951af,
  0x060b0212, 0x45181faf, 0x080f1009, 0x141d0421,
  // [5d10]
  0x160466a4, 0x29220412, 0x0f3818ac, 0x660b19af,
  0x1d2927a4, 0x0f001209, 0x1d0619af, 0x1e231c12,
  0x0c400407, 0x1d0f0412, 0x06041920, 0x05400807,
  0x0f210809, 0x120c40a4, 0x01660555, 0x19001d22,
  // [5d20]
  0x02101912, 0x10001921, 0x1d000420, 0x1d000511,
  0x04191d12, 0x0b052112, 0x08051f09, 0x03124007,
  0x2b010c12, 0x40000511, 0x1d010507, 0x17164013,
  0x38001721, 0x38102707, 0x04222112, 0x12451f08,
  // [5d30]
  0x15030baf, 0x1d1803af, 0x04031509, 0x2b081da4,
  0x082b01ac, 0x01002b21, 0x01190f55, 0x22040baf,
  0x08663fad, 0x05120134, 0x40002114, 0x16406608,
  0x450d0107, 0x080501ac, 0x18000b08, 0x43166607,
  // [5d40]
  0x181245bb, 0x06012bbb, 0x12001412, 0x270104bc,
  0x14001208, 0x15010312, 0x08000f13, 0x012729af,
  0x18124521, 0x16121dbb, 0x17012b07, 0x22012908,
  0x12064009, 0x451218bb, 0x4029276f, 0x1d3f1921,
  // [5d50]
  0x040129ad, 0x0b031921, 0x0c060308, 0x010f03a4,
  0x2b000309, 0x061701a4, 0x03000821, 0x03172712,
  0x0e1e1c20, 0x29124514, 0x05381660, 0x190c0408,
  0x2b060d08, 0x0b191007, 0x40171921, 0x06053f09,
  // [5d60]
  0x07005c30, 0x06180bad, 0x66001709, 0x013f1faf,
  0x100b06a4, 0x1f152160, 0x120f0d07, 0x12000d13,
  0x1d2238a4, 0x40151d07, 0x45001512, 0x02170109,
  0x0c0b0307, 0x010666a4, 0x0c0d0f55, 0x12000312,
  // [5d70]
  0x16030609, 0x0f060d08, 0x27060309, 0x17001212,
  0x060121bb, 0x0c061a12, 0x020f0dac, 0x0c2b0409,
  0x450d66be, 0x43124522, 0x1d1545af, 0x0d2b38be,
  0x142b3f21, 0x211614bc, 0x1d1629af, 0x17162baf,
  // [5d80]
  0x1f221d21, 0x151d1212, 0x27292260, 0x08660112,
  0x120c29af, 0x19140c10, 0x0f050808, 0x020b19af,
  0x190621af, 0x18192109, 0x0b0619a4, 0x0f2b3821,
  0x2b041913, 0x1c003002, 0x270c3812, 0x182b08be,
  // [5d90]
  0x250e1cbc, 0x450d03af, 0x163f10bc, 0x03063f21,
  0x01046609, 0x02222912, 0x020b12af, 0x10000f12,
  0x0c0d0fa4, 0x03401d13, 0x04000510, 0x084540ad,
  0x19050109, 0x170c0411, 0x020b19bb, 0x16152708,
  // [5da0]
  0x21120112, 0x08012b12, 0x06022bad, 0x06056609,
  0x14212908, 0x220410be, 0x150d0611, 0x2b0121ac,
  0x43060107, 0x0f060112, 0x01042907, 0x0b15166f,
  0x27002b13, 0x161d19bc, 0x03056622, 0x2b120f55,
  // [5db0]
  0x1f005113, 0x05222ba4, 0x01000409, 0x01272b09,
  0x0d1d406f, 0x43272955, 0x010b0612, 0x03010fad,
  0x153f19be, 0x041819bc, 0x03004002, 0x0c041907,
  0x14213f11, 0x12451912, 0x180c1609, 0x19160407,
  // [5dc0]
  0x40181955, 0x2b663f08, 0x17083809, 0x40271d12,
  0x010c1faf, 0x03404512, 0x38430402, 0x0e302323,
  0x15211821, 0x0b0c2bad, 0x10400ba4, 0x2b000408,
  0x66000409, 0x14060309, 0x0b0315ad, 0x03401d21,
  // [5dd0]
  0x221d3f12, 0x0b660208, 0x080538a4, 0x40171212,
  0x18451220, 0x021018bc, 0x010f29a4, 0x22212b07,
  0x04002b22, 0x05173808, 0x121445ac, 0x45000f09,
  0x29173f12, 0x1d0c1912, 0x012b0408, 0x042919ad,
  // [5de0]
  0x17272911, 0x010f66a4, 0x29002b08, 0x140f4512,
  0x012b6608, 0x220f38a4, 0x013808ac, 0x19022208,
  0x02292755, 0x1d0b0da4, 0x10211612, 0x03011709,
  0x380d1713, 0x38020121, 0x013817a4, 0x03386607,
  // [5df0]
  0x3f1f1921, 0x1f0521af, 0x05191f07, 0x40161dbe,
  0x2b222121, 0x38001f21, 0x011d0508, 0x160521ad,
  0x012119be, 0x0c1503af, 0x060105bc, 0x011f3822,
  0x220c2707, 0x43000120, 0x04013f11, 0x38002b20,
  // [5e00]
  0x21222912, 0x1f001614, 0x01000814, 0x3f162121,
  0x16215112, 0x222b21af, 0x10053809, 0x220221a4,
  0x222b2112, 0x66000d13, 0x19000b34, 0x182127af,
  0x15011fad, 0x27142212, 0x21272209, 0x16002121,
  // [5e10]
  0x66010f08, 0x171d0802, 0x19042708, 0x1d0112ac,
  0x06190355, 0x0c182212, 0x01430b07, 0x27212221,
  0x0b042108, 0x011d1612, 0x12020b12, 0x021d0f07,
  0x06170112, 0x401701af, 0x230e3009, 0x121418bc,
  // [5e20]
  0x06031508, 0x18000108, 0x40170112, 0x041d4007,
  0x14000421, 0x22140407, 0x01660312, 0x0b102b07,
  0x061703a4, 0x12012708, 0x040c2202, 0x0c000402,
  0x0b002207, 0x040d1407, 0x043f19bc, 0x0e2325bc,
  // [5e30]
  0x012b66ad, 0x452215bb, 0x660206be, 0x27211009,
  0x0d184509, 0x0f210d14, 0x0d452907, 0x1f272920,
  0x29042113, 0x0d0f2113, 0x272910af, 0x271f29af,
  0x010f0512, 0x2b272907, 0x05292721, 0x01380302,
  // [5e40]
  0x27660baf, 0x18222709, 0x301e0ead, 0x0b0f0d09,
  0x0f0c2709, 0x190406a4, 0x29211211, 0x0d001907,
  0x43290111, 0x0d001409, 0x01103802, 0x1d0117af,
  0x38051712, 0x010519a4, 0x19381f09, 0x450c4013,
  // [5e50]
  0x22010507, 0x431d4009, 0x190b1007, 0x043f2112,
  0x213f01af, 0x22170513, 0x450c1512, 0x193817bb,
  0x193f1721, 0x17160112, 0x03661714, 0x66031920,
  0x401d17bc, 0x290c27af, 0x22171921, 0x17192214,
  // [5e60]
  0x05221711, 0x181d0209, 0x661d1712, 0x401d1211,
  0x10040f11, 0x66191712, 0x10041422, 0x08382b12,
  0x66191721, 0x17001922, 0x040b1d09, 0x05002120,
  0x27011721, 0x2b270d12, 0x18000214, 0x10290b60,
  // [5e70]
  0x2b2127a4, 0x45120cbc, 0x0f101409, 0x1d1838a4,
  0x012b6611, 0x66050109, 0x17000d20, 0x0d450f12,
  0x05000312, 0x27190d12, 0x100b04a4, 0x38032755,
  0x43271d13, 0x030266a4, 0x05010f14, 0x12001622,
  // [5e80]
  0x38060360, 0x66042114, 0x3f004014, 0x04226607,
  0x16000613, 0x02406614, 0x22270112, 0x02086612,
  0x12021d12, 0x220b0212, 0x22006614, 0x19270212,
  0x0d080faf, 0x05061602, 0x1e3025ad, 0x3f000b21,
  // [5e90]
  0x15292708, 0x661f3813, 0x010d1712, 0x0d081709,
  0x06031012, 0x04001411, 0x300e1caf, 0x380106af,
  0x100503a4, 0x15013860, 0x080b17ad, 0x15001702,
  0x04102b08, 0x100b66af, 0x38011008, 0x02000133,
  // [5ea0]
  0x10292711, 0x18020baf, 0x050b0212, 0x010c2760,
  0x011705bc, 0x270f3821, 0x0b050111, 0x290c1712,
  0x04012712, 0x03066635, 0x66031812, 0x0b271612,
  0x40181755, 0x050f0807, 0x0b060255, 0x01272914,
  // [5eb0]
  0x010b02af, 0x05450d08, 0x45040521, 0x19043f14,
  0x01451521, 0x22143fac, 0x060d03ac, 0x02060b07,
  0x080301ad, 0x04010607, 0x04181914, 0x06221408,
  0x27211922, 0x0c040355, 0x04660209, 0x08002107,
  // [5ec0]
  0x292706bb, 0x3f1051af, 0x050f0d21, 0x1f000611,
  0x2b0501a4, 0x08001702, 0x0105226f, 0x03120109,
  0x22002b07, 0x0f000533, 0x38001411, 0x17151009,
  0x19660422, 0x171d4007, 0x66140309, 0x0d081609,
  // [5ed0]
  0x400f0d14, 0x45013809, 0x01052bad, 0x08004513,
  0x190b2107, 0x220d0ba4, 0x38011f12, 0x66011f08,
  0x08020302, 0x1c0e1e13, 0x384516ad, 0x3f012b21,
  0x0d000611, 0x154501a4, 0x08150d09, 0x0f0d29af,
  // [5ee0]
  0x01174007, 0x0b022b09, 0x1e233002, 0x06042107,
  0x14380d14, 0x10004008, 0x0c060209, 0x03060508,
  0x08270f09, 0x2b000522, 0x062b66ad, 0x08010f02,
  0x27660b13, 0x0f1738be, 0x19066607, 0x0f002b07,
  // [5ef0]
  0x401d19af, 0x17015112, 0x0f0d1912, 0x16182209,
  0x19451212, 0x38190608, 0x0f2266a4, 0x10272913,
  0x170f19af, 0x0d451012, 0x10000b20, 0x38061007,
  0x100c1d55, 0x16190608, 0x181d40be, 0x0b000c12,
  // [5f00]
  0x40191709, 0x010c2b07, 0x22450608, 0x29190460,
  0x27060308, 0x12172708, 0x1f3f1aa4, 0x06121d07,
  0x17000508, 0x21140112, 0x1d014302, 0x01270411,
  0x03000514, 0x0b012107, 0x0f0c3807, 0x03661f12,
  // [5f10]
  0x04142707, 0x04011207, 0x17380d13, 0x38004011,
  0x29001613, 0x011404af, 0x290b27be, 0x380801a4,
  0x401d45ad, 0x250e2355, 0x062b6608, 0x0d430f07,
  0x301c0e55, 0x0f450813, 0x0d401d14, 0x45161d09,
  // [5f20]
  0x2b124522, 0x0f400d13, 0x401d0f21, 0x45210808,
  0x40220f20, 0x03040107, 0x40001902, 0x0b020411,
  0x661903af, 0x1d080f6f, 0x45400da4, 0x05270c12,
  0x0f1d0802, 0x45170d09, 0x02660307, 0x291d2112,
  // [5f30]
  0x08170fbe, 0x0d171507, 0x020508a4, 0x06401008,
  0x14100ba4, 0x40162213, 0x04194014, 0x400b0214,
  0x66020b60, 0x1d000821, 0x04292721, 0x1d220109,
  0x100b66ad, 0x16402220, 0x27002935, 0x10272933,
  // [5f40]
  0x30001c23, 0x10272920, 0x0f053807, 0x04272108,
  0x0c172b12, 0x02102209, 0x0f040d12, 0x06152907,
  0x01172709, 0x38450ca4, 0x661016bb, 0x010f38ad,
  0x08052bbc, 0x38081902, 0x01050855, 0x01000408,
  // [5f50]
  0x014512af, 0x40036608, 0x160329a4, 0x1d060d07,
  0x080c2707, 0x01160fa4, 0x37001e14, 0x45160407,
  0x160c1d07, 0x050806bc, 0x080119bb, 0x04011909,
  0x0d000612, 0x180d1212, 0x04210112, 0x12436609,
  // [5f60]
  0x18122112, 0x27014312, 0x036604a4, 0x231e0e22,
  0x19210860, 0x03662221, 0x191516ce, 0x29270f14,
  0x1d050307, 0x17051fa4, 0x38663f08, 0x22212911,
  0x03660623, 0x18292722, 0x400c1221, 0x19001633,
  // [5f70]
  0x014306ad, 0x12271912, 0x0b060314, 0x403806a4,
  0x212b1daf, 0x271f1d09, 0x212b1d21, 0x1d012b12,
  0x661d2bbb, 0x02001f08, 0x43001920, 0x402b1dad,
  0x02211d14, 0x1d064512, 0x452b3fa4, 0x30230e20,
  // [5f80]
  0x2b400221, 0x1d293f12, 0x0e251cbe, 0x66170809,
  0x27152912, 0x01081913, 0x401008ad, 0x03081709,
  0x0c0122a4, 0x3f270821, 0x05170814, 0x030638a4,
  0x06180808, 0x030205ad, 0x02080b12, 0x016604af,
  // [5f90]
  0x17050821, 0x1f001735, 0x0c100355, 0x010666ad,
  0x27100411, 0x380f1f12, 0x1f001613, 0x0f004307,
  0x0f220d13, 0x0d0308a4, 0x14004307, 0x14000c08,
  0x12003808, 0x1d080109, 0x1e1c2520, 0x250e1e02,
  // [5fa0]
  0x0e231e14, 0x0b0851a4, 0x43193fac, 0x27660812,
  0x161d406f, 0x0c2b0821, 0x210f0808, 0x40101912,
  0x02104512, 0x10012907, 0x0f000821, 0x19271012,
  0x162108a4, 0x0c1d4020, 0x3f001f13, 0x0b661921,
  // [5fb0]
  0x01000d11, 0x0d0827a4, 0x190d1011, 0x19104512,
  0x160c0420, 0x191045af, 0x162b0cbe, 0x30002523,
  0x15000607, 0x020b1a12, 0x031f6655, 0x150c4508,
  0x22662912, 0x401d3f21, 0x02000f12, 0x1d0f0255,
  // [5fc0]
  0x1d401707, 0x0c3f40be, 0x171f0111, 0x12451da4,
  0x17001807, 0x060c01af, 0x1f0201af, 0x061f0309,
  0x01120309, 0x0e1e256f, 0x06000c02, 0x060c0108,
  0x03101409, 0x25002309, 0x05002911, 0x061510a4,
  // [5fd0]
  0x06002113, 0x380f0ba4, 0x05011713, 0x1d002111,
  0x43012121, 0x0b000109, 0x16152212, 0x012729ad,
  0x19001211, 0x030d0f55, 0x12150ba4, 0x40023807,
  0x2b210612, 0x2b0b1f12, 0x08162baf, 0x660121af,
  // [5fe0]
  0x38036608, 0x08002b22, 0x06432121, 0x2b0d0f14,
  0x17000f09, 0x026603af, 0x0d1d0821, 0x066640af,
  0x03663812, 0x29000313, 0x1d0f0112, 0x162b2712,
  0x2b0f16be, 0x17380d09, 0x01191508, 0x060b1008,
  // [5ff0]
  0x170f0309, 0x01171d07, 0x03401d08, 0x21401d12,
  0x03190407, 0x1d2b1007, 0x22041408, 0x38153f21,
  0x0d002b12, 0x272b29be, 0x151d40be, 0x0b1466ad,
  0x03210407, 0x04193807, 0x0c290812, 0x05001013,

  // [6000]
  0x050429af, 0x05012bad, 0x04102b07, 0x1d002b22,
  0x021d0b12, 0x02380b12, 0x40121813, 0x270210af,
  0x3f030621, 0x38100421, 0x06004009, 0x0f000122,
  0x1d121812, 0x170f0808, 0x05042912, 0x45191609,
  // [6010]
  0x1d214014, 0x0b041922, 0x01453809, 0x08056609,
  0x1d2b2708, 0x171d0112, 0x2b000611, 0x06400208,
  0x011708af, 0x0b6628af, 0x1f000620, 0x02062113,
  0x45190112, 0x08171613, 0x08051d09, 0x40170114,
  // [6020]
  0x12401dbc, 0x2b216613, 0x0b661612, 0x0b020d08,
  0x2b006621, 0x086602ad, 0x15003f11, 0x1e233060,
  0x05001802, 0x401d0308, 0x66013f08, 0x1d400307,
  0x10001d02, 0x21292212, 0x221451af, 0x010d2102,
  // [6030]
  0x1d001014, 0x221d1708, 0x03401d6f, 0x0d083f09,
  0x03020b23, 0x0c1d1f09, 0x120f0508, 0x01060314,
  0x196604ad, 0x02180b22, 0x021d0f60, 0x012b2112,
  0x170302be, 0x08041920, 0x010221a4, 0x451851a4,
  // [6040]
  0x17380214, 0x1f001221, 0x0d0f0607, 0x17053821,
  0x0c211611, 0x456605ad, 0x18124009, 0x160b0213,
  0x040f1907, 0x12016607, 0x1d001002, 0x18004313,
  0x05004513, 0x453f0f22, 0x02196609, 0x38010607,
  // [6050]
  0x10171912, 0x06013f09, 0x12401d22, 0x27060409,
  0x3f662bbe, 0x02000433, 0x0d4366a4, 0x1c2330af,
  0x01021907, 0x05292708, 0x14002712, 0x03062707,
  0x0f380d07, 0x10051409, 0x051051af, 0x22060360,
  // [6060]
  0x020305af, 0x1e302521, 0x01031911, 0x08001621,
  0x17406607, 0x01272108, 0x10211d08, 0x450b0c12,
  0x08181d09, 0x451566a4, 0x1d080fa4, 0x0d082b07,
  0x05001414, 0x08000f21, 0x1d0f0809, 0x04180baf,
  // [6070]
  0x0d000820, 0x0d011907, 0x03002113, 0x05031807,
  0x15000802, 0x01170502, 0x21193f60, 0x2b081712,
  0x08050309, 0x29192108, 0x453f4055, 0x40000c23,
  0x273f0460, 0x044016be, 0x0c1221a4, 0x053f2ba4,
  // [6080]
  0x380f1f11, 0x3f170121, 0x17160812, 0x5c000711,
  0x121d3f09, 0x14102221, 0x01221007, 0x38100f12,
  0x220d1708, 0x22170d21, 0x2b000212, 0x14220421,
  0x192b38ad, 0x12001821, 0x2b0c0108, 0x10002713,
  // [6090]
  0x060440a4, 0x010b29ad, 0x2b661f12, 0x02211609,
  0x021210a4, 0x231e2514, 0x15212212, 0x02001009,
  0x0e1e1c55, 0x30251ebe, 0x1c301e09, 0x150f01a4,
  0x01040608, 0x06100302, 0x0d060307, 0x05001713,
  // [60a0]
  0x173f2160, 0x2b036621, 0x38006613, 0x380203a4,
  0x6605386f, 0x08032108, 0x400d4313, 0x380d1aaf,
  0x0c101f09, 0x16006612, 0x29273f60, 0x0d063f11,
  0x17000623, 0x27052913, 0x430c0807, 0x0f0b0107,
  // [60b0]
  0x01270b09, 0x0c010355, 0x02080109, 0x0c011fa4,
  0x40002209, 0x161d0b08, 0x060b6607, 0x29270baf,
  0x100f0307, 0x060b1421, 0x06140baf, 0x38174002,
  0x40451daf, 0x16124509, 0x10004002, 0x19222b55,
  // [60c0]
  0x191422a4, 0x02002b20, 0x04211414, 0x14001f09,
  0x12000c1d, 0x1d3f4012, 0x06191060, 0x12144507,
  0x1f053f12, 0x0c001909, 0x431d0112, 0x220401af,
  0x011608ac, 0x38004009, 0x27293fbc, 0x0f0d1607,
  // [60d0]
  0x38402712, 0x0f1d3f12, 0x0f380507, 0x0f010212,
  0x062b0555, 0x0d170307, 0x3f0f2712, 0x230e2511,
  0x19042909, 0x0f401dad, 0x04052109, 0x10004009,
  0x171d4013, 0x0f174007, 0x06170d02, 0x450c1214,
  // [60e0]
  0x0c124511, 0x29063f21, 0x1c003014, 0x17011812,
  0x1d191812, 0x082b0b12, 0x102251a4, 0x0c220513,
  0x38270855, 0x02191409, 0x14150c12, 0x40001d32,
  0x062202bc, 0x10272912, 0x38141012, 0x0d0f3822,
  // [60f0]
  0x0d1d0113, 0x0d001411, 0x020b0da4, 0x38002b14,
  0x10143809, 0x08170f09, 0x1d000409, 0x03002711,
  0x0f0d1708, 0x0d381421, 0x66052b13, 0x38000c11,
  0x0c123808, 0x18021060, 0x2b001707, 0x104003ad,
  // [6100]
  0x022b6607, 0x10021d07, 0x060c1909, 0x101519af,
  0x01020809, 0x16023f11, 0x0b161512, 0x0d0f1209,
  0x03121d12, 0x0d452207, 0x12161d07, 0x080f0107,
  0x0d006613, 0x250e3060, 0x040f0d02, 0x1d164011,
  // [6110]
  0x06001207, 0x160119a4, 0x010821ad, 0x19036660,
  0x22020f09, 0x271238af, 0x1d2921a4, 0x0c1d0112,
  0x021d27a4, 0x0c400413, 0x38006612, 0x2b1d1609,
  0x02400b09, 0x451f1212, 0x05080f60, 0x01210b09,
  // [6120]
  0x12080112, 0x21010baf, 0x0d386614, 0x1d030112,
  0x66000d14, 0x0d0127af, 0x1f001212, 0x45126660,
  0x0f3851af, 0x16296611, 0x08660612, 0x3845126f,
  0x38290f07, 0x19000433, 0x05001008, 0x10001614,
  // [6130]
  0x1c252320, 0x16012baf, 0x161d4560, 0x380d5112,
  0x16001709, 0x0e301c55, 0x0f063807, 0x210617a4,
  0x0d030209, 0x27141009, 0x0d171012, 0x081003ad,
  0x2b0210af, 0x1c252302, 0x0f2b1709, 0x22063814,
  // [6140]
  0x223817af, 0x054504a4, 0x032b1455, 0x0d381712,
  0x17020b13, 0x032b0209, 0x0f0d17be, 0x38101721,
  0x38175112, 0x15401d23, 0x1d4008a4, 0x170b0209,
  0x0f381912, 0x12101da4, 0x0d080302, 0x0c1d08a4,
  // [6150]
  0x0c2921af, 0x40181912, 0x08102707, 0x43014007,
  0x100d03a4, 0x273f16af, 0x0f0d27a4, 0x191f0512,
  0x010b0209, 0x2b000d07, 0x04213f12, 0x0f084008,
  0x011f2712, 0x0d150f13, 0x01274312, 0x1f003814,
  // [6160]
  0x1d4043be, 0x2b010809, 0x1f210509, 0x01430512,
  0x172b4313, 0x38292b60, 0x0d1f0460, 0x01380307,
  0x01051f11, 0x01052b14, 0x21272bbb, 0x2b171611,
  0x170c04a4, 0x081604a4, 0x22000609, 0x140422bc,
  // [6170]
  0x14212260, 0x271f29bb, 0x43000502, 0x192214ad,
  0x03001212, 0x451619a4, 0x22061407, 0x01121007,
  0x17010fa4, 0x19060ba4, 0x210419be, 0x22040209,
  0x06142211, 0x04141922, 0x04190802, 0x14041908,
  // [6180]
  0x1c0e2511, 0x06100812, 0x100612af, 0x22020bad,
  0x020b3f09, 0x04181921, 0x03211908, 0x01001812,
  0x0b1051a4, 0x080f1909, 0x0f190509, 0x222b01a4,
  0x0b2b01af, 0x1404196f, 0x10190421, 0x1d001921,
  // [6190]
  0x1d4340a4, 0x0d381608, 0x1d001409, 0x0c036608,
  0x29380b09, 0x05011914, 0x66430108, 0x43012b07,
  0x03661914, 0x3f002135, 0x292704be, 0x04272922,
  0x19040311, 0x27042920, 0x03180255, 0x29270414,
  // [61a0]
  0x19661f60, 0x1c1e2520, 0x081002a4, 0x1d192155,
  0x03292760, 0x0e2325ac, 0x66060312, 0x03061012,
  0x06030f60, 0x03002911, 0x10386608, 0x04292708,
  0x06180312, 0x40000612, 0x03662908, 0x0b140608,
  // [61b0]
  0x100b1408, 0x0f142212, 0x011d0612, 0x0d066607,
  0x18451dad, 0x12451407, 0x45181dad, 0x1d120311,
  0x061d4008, 0x05451d13, 0x02180b55, 0x16660f08,
  0x0f083f21, 0x1d0c12a4, 0x021501a4, 0x19043fad,
  // [61c0]
  0x22050107, 0x1d0f0802, 0x1f0f0809, 0x0245126f,
  0x19001d14, 0x021d40ac, 0x21080fbc, 0x080f1f21,
  0x3f1d0814, 0x050d1708, 0x18100b20, 0x1c302312,
  0x10120b12, 0x0d1f0f55, 0x19044007, 0x0b1d4020,
  // [61d0]
  0x220c6612, 0x16030109, 0x380f1fbb, 0x161501af,
  0x0f0838be, 0x450c2b09, 0x15160f08, 0x0b400208,
  0x181d1508, 0x04160f09, 0x22273fad, 0x03101212,
  0x120c2b11, 0x1d1529a4, 0x050110a4, 0x19140ba4,
  // [61e0]
  0x083801a4, 0x0d381007, 0x27030612, 0x272918bc,
  0x020618a4, 0x251c2320, 0x142b51a4, 0x212b6660,
  0x18002b20, 0x2b0f2108, 0x02053807, 0x221d4060,
  0x38140f55, 0x2b1d4014, 0x17000d11, 0x031d66a4,
  // [61f0]
  0x15010508, 0x02180607, 0x436601a4, 0x100b1411,
  0x400f1d02, 0x17002b20, 0x0f0138a4, 0x430d2712,
  0x170538a4, 0x01431408, 0x16272108, 0x172b2712,
  0x043808a4, 0x0b170107, 0x10012bad, 0x0c2127af,
  // [6200]
  0x102719af, 0x013f2113, 0x12173802, 0x43001736,
  0x050d3812, 0x21000621, 0x0d020808, 0x1d220ca4,
  0x0d000814, 0x66010d09, 0x031d0409, 0x0f170207,
  0x66050309, 0x40040308, 0x222b66af, 0x17191da4,
  // [6210]
  0x0f0821af, 0x06016655, 0x380f1709, 0x1c1e23ad,
  0x0f066607, 0x400c29ac, 0x251c2355, 0x150d0809,
  0x012b27a4, 0x1c2530a4, 0x381004a4, 0x19100208,
  0x042719af, 0x18380612, 0x10190207, 0x03100509,
  // [6220]
  0x01024002, 0x10046612, 0x01061d07, 0x15010808,
  0x1d100b07, 0x40001008, 0x0c401614, 0x0c4016cf,
  0x060501ad, 0x270429a4, 0x1d0612ac, 0x0f0c0807,
  0x40150c12, 0x1d400112, 0x400c2121, 0x45190caf,
  // [6230]
  0x164501a4, 0x1d180308, 0x38080f08, 0x22170fa4,
  0x05010f55, 0x040f1509, 0x29273813, 0x17040f14,
  0x40043f12, 0x380f01a4, 0x12271aa4, 0x010c38af,
  0x1c0e23ad, 0x04011007, 0x21000f13, 0x3f000423,
  // [6240]
  0x04000d22, 0x12010cac, 0x01194007, 0x16660360,
  0x1f660321, 0x190108a4, 0x451d0b09, 0x121d0207,
  0x19000102, 0x0c451221, 0x12081da4, 0x1f0501af,
  0x04190509, 0x040d0f08, 0x020b0302, 0x041d0809,
  // [6250]
  0x040d0f60, 0x160f40af, 0x2b0c0d08, 0x0f0d3f34,
  0x0c0806ac, 0x190308a4, 0x1e1c23ad, 0x0b041f20,
  0x0b082108, 0x0d210f08, 0x0b001d08, 0x161d0fac,
  0x1d100209, 0x080d0fbe, 0x251c23af, 0x380f0107,
  // [6260]
  0x251e1cbc, 0x1f010821, 0x16121daf, 0x1e251c10,
  0x66001508, 0x03661d08, 0x22030655, 0x66212909,
  0x10000422, 0x16000409, 0x140b1012, 0x06126608,
  0x03661213, 0x1f003f11, 0x06100412, 0x03001414,
  // [6270]
  0x1f001214, 0x40451211, 0x380d0514, 0x1d160321,
  0x031d19a4, 0x10121d07, 0x19101812, 0x0c452755,
  0x400d3809, 0x0b003f11, 0x14170f09, 0x020b6614,
  0x40451d60, 0x101d66bc, 0x40451d21, 0x06191012,
  // [6280]
  0x0f1701a4, 0x1d003f07, 0x10031812, 0x66050621,
  0x1e0e2322, 0x12451607, 0x17001402, 0x14272960,
  0x12162b55, 0x22001922, 0x04051912, 0x06191fa4,
  0x03060b07, 0x14001911, 0x0f001908, 0x0b001908,
  // [6290]
  0x17011002, 0x0d000607, 0x020c0b07, 0x38012707,
  0x29060109, 0x22001423, 0x0f004020, 0x38221421,
  0x40272920, 0x27222908, 0x010417a4, 0x162717a4,
  0x0e301e60, 0x430c2109, 0x012b2207, 0x38030f07,
  // [62a0]
  0x450c2960, 0x181640ad, 0x15190208, 0x14222908,
  0x08450107, 0x45381808, 0x04100b07, 0x0f272911,
  0x08380d08, 0x66000209, 0x0d381907, 0x0d164512,
  0x12404507, 0x250e23bb, 0x401645ac, 0x15001f20,
  // [62b0]
  0x06032214, 0x0f060802, 0x0b140414, 0x22100202,
  0x0b080ca4, 0x0c400309, 0x03192207, 0x272b4512,
  0x010f2ba4, 0x660c2b13, 0x03002b13, 0x66041009,
  0x03000c23, 0x2b451212, 0x05020b07, 0x222714ad,
  // [62c0]
  0x08001402, 0x144027af, 0x0b062109, 0x10142b21,
  0x03172212, 0x08192707, 0x66001609, 0x10000d02,
  0x190b27af, 0x0d121907, 0x0d006609, 0x45161da4,
  0x43001702, 0x19152755, 0x190c4007, 0x15001408,
  // [62d0]
  0x19101608, 0x06001609, 0x21273faf, 0x011d4307,
  0x273f1dbc, 0x220f0d08, 0x080f0111, 0x124518ac,
  0x0f0d1d08, 0x06002911, 0x04191407, 0x0c121512,
  0x0f012107, 0x21001d14, 0x2b1f1421, 0x22033814,
  // [62e0]
  0x14432912, 0x0d1f2baf, 0x010b4012, 0x22020b09,
  0x080b6607, 0x2b0d0b12, 0x0d001834, 0x230e1cbc,
  0x22000d12, 0x660302bb, 0x0b2701ad, 0x29271f21,
  0x040f0d60, 0x170f0dbb, 0x062921af, 0x01430d07,
  // [62f0]
  0x0d004023, 0x01184507, 0x010b27a4, 0x12021008,
  0x0b021507, 0x08001f07, 0x0f221007, 0x06224009,
  0x172922be, 0x662921bb, 0x0d290108, 0x0c003802,
  0x100b0109, 0x251e3008, 0x382b1913, 0x0c051912,
  // [6300]
  0x231c3012, 0x0d190f08, 0x151d10ad, 0x14102b11,
  0x401d1002, 0x14060b07, 0x16010509, 0x19210f09,
  0x0b100daf, 0x0b0d02af, 0x010b0802, 0x1f2b21bb,
  0x400c0312, 0x43103f09, 0x0b050221, 0x10041411,
  // [6310]
  0x103808a4, 0x19043faf, 0x0c004009, 0x120c4509,
  0x021d0512, 0x050c1907, 0x06021021, 0x08170f07,
  0x21660212, 0x1f430111, 0x38102909, 0x0f211d12,
  0x0d171fbb, 0x06381007, 0x430f01a4, 0x053808a4,
  // [6320]
  0x10040612, 0x06270111, 0x16001012, 0x08170155,
  0x01270809, 0x0d663809, 0x03196660, 0x270f38af,
  0x0d080509, 0x01291f09, 0x1f041920, 0x210501af,
  0x381729a4, 0x04100660, 0x102b6608, 0x38001508,
  // [6330]
  0x27210113, 0x40003f33, 0x17452109, 0x01023802,
  0x400d0f09, 0x05040808, 0x17431d07, 0x16040809,
  0x1d172707, 0x401206a4, 0x0f001602, 0x66160112,
  0x66001013, 0x19010202, 0x020151af, 0x38170808,
  // [6340]
  0x081703a4, 0x12000f02, 0x380f0213, 0x2b220613,
  0x0c381dad, 0x16081d13, 0x16001f33, 0x0c060212,
  0x2b213809, 0x100f6612, 0x194003ad, 0x010f0d11,
  0x380104af, 0x0b1d04ac, 0x03080407, 0x10220209,
  // [6350]
  0x0d140f12, 0x180f38a4, 0x161804ad, 0x04141912,
  0x0c000820, 0x020b1612, 0x0c660314, 0x080c0d09,
  0x1c2330ac, 0x151405a4, 0x01120609, 0x45180855,
  0x10190b08, 0x05080cad, 0x0c450f12, 0x14451212,
  // [6360]
  0x12451507, 0x160f4560, 0x0f031612, 0x66081620,
  0x06401708, 0x301c1ea4, 0x03040512, 0x16061da4,
  0x161d45af, 0x01180f08, 0x066603a4, 0x0c0d4512,
  0x0f170dbe, 0x061d6612, 0x380c2155, 0x0c292760,
  // [6370]
  0x0b061014, 0x66100313, 0x141d01a4, 0x23301c22,
  0x386605af, 0x661f15bb, 0x660151af, 0x14003807,
  0x10141f12, 0x08171da4, 0x01020322, 0x182b0509,
  0x121805ad, 0x18450dad, 0x14000d07, 0x17270312,
  // [6380]
  0x031014a4, 0x0d080f55, 0x380f0d6f, 0x0d172ba4,
  0x03190107, 0x081921be, 0x40191d14, 0x18000d21,
  0x04271960, 0x45140dbb, 0x14000d11, 0x272919bc,
  0x01000821, 0x10191412, 0x29192160, 0x21661f21,
  // [6390]
  0x0d173823, 0x010c0fac, 0x03120112, 0x06002b33,
  0x06106607, 0x12380d13, 0x17002108, 0x0f001722,
  0x151d0809, 0x06186609, 0x38000d35, 0x03011607,
  0x17292721, 0x2b000d21, 0x010d2921, 0x38050f21,
  // [63a0]
  0x431d0f55, 0x2b0119bb, 0x1d0815bb, 0x2b003f08,
  0x060210af, 0x18004510, 0x0b080f07, 0x380608a4,
  0x16151021, 0x45002708, 0x1d451702, 0x15401608,
  0x37003009, 0x0d2b0fa4, 0x0d0f0514, 0x05184512,
  // [63b0]
  0x180f05af, 0x0d180509, 0x1d0129a4, 0x0b001421,
  0x1c1e3007, 0x450d0509, 0x01080412, 0x12050d08,
  0x0d000521, 0x0f1922ac, 0x191604af, 0x191d4021,
  0x08002123, 0x142b21af, 0x02151407, 0x45121aaf,
  // [63c0]
  0x01031008, 0x04151612, 0x141908a4, 0x0f160d14,
  0x190d0f08, 0x14010608, 0x18000607, 0x19061807,
  0x0d050808, 0x06193807, 0x04194060, 0x05430307,
  0x121d2912, 0x01380d09, 0x2b401daf, 0x2b161021,
  // [63d0]
  0x16181921, 0x0b0602a4, 0x19030607, 0x14101faf,
  0x17220f55, 0x23251e09, 0x0f1451af, 0x020b19ad,
  0x10030655, 0x12181da4, 0x66031908, 0x0f010309,
  0x45181002, 0x01182bad, 0x06004512, 0x01000614,
  // [63e0]
  0x151006a4, 0x0b020302, 0x020b12a4, 0x1d011709,
  0x02190bad, 0x2b0b0208, 0x38001011, 0x06000213,
  0x0d380fbe, 0x0c001f11, 0x060d2111, 0x401d0b13,
  0x1d121008, 0x10380f14, 0x3f002214, 0x12452213,
  // [63f0]
  0x0b010208, 0x45002202, 0x03041907, 0x12404514,
  0x03124514, 0x06221410, 0x45122b13, 0x14100b55,
  0x03001d11, 0x06221207, 0x040b5107, 0x45120b07,
  0x2b271f08, 0x03061d09, 0x1d124511, 0x1d005108,

  // [6400]
  0x22082b07, 0x01211808, 0x16003f34, 0x01140b12,
  0x0f381dac, 0x0b021aaf, 0x0f001514, 0x171d0609,
  0x151651af, 0x100f4009, 0x151602af, 0x08000208,
  0x184508a4, 0x04191f08, 0x0c381d13, 0x08271612,
  // [6410]
  0x450c4055, 0x012b0c22, 0x15124512, 0x1d034002,
  0x08180312, 0x0c2b2113, 0x04180809, 0x12454022,
  0x05012908, 0x27010309, 0x0b001d13, 0x2b272908,
  0x0f001920, 0x17010d07, 0x222b0da4, 0x03060b08,
  // [6420]
  0x40664512, 0x0d382b08, 0x0d162b21, 0x0b1d4014,
  0x291901bc, 0x0f002b21, 0x050f2b08, 0x16190860,
  0x01000402, 0x0c3f1f60, 0x29002b21, 0x0f0c2b22,
  0x124516ad, 0x030438ad, 0x45050608, 0x010d1fac,
  // [6430]
  0x031f2bbc, 0x04060209, 0x19086607, 0x01662b12,
  0x23301e11, 0x45002b07, 0x38030107, 0x052b0111,
  0x01020607, 0x10290609, 0x664508af, 0x401938a4,
  0x19084512, 0x301c2308, 0x01162b60, 0x05430102,
  // [6440]
  0x060b16ad, 0x01083802, 0x18121912, 0x010f3f12,
  0x22001d14, 0x01382b11, 0x38052b07, 0x1c250e02,
  0x0b014007, 0x2b0838af, 0x01192b02, 0x66030121,
  0x18040b08, 0x0c004507, 0x0c010812, 0x161d19bb,
  // [6450]
  0x1d160f09, 0x3f141921, 0x19161007, 0x190f21a4,
  0x22041007, 0x180d0f12, 0x06004020, 0x081916bb,
  0x27002213, 0x16003807, 0x03140f55, 0x29213f21,
  0x0c2227a4, 0x0f19046f, 0x140b0214, 0x08170f14,
  // [6460]
  0x02101421, 0x14001207, 0x3f1f6609, 0x171d0107,
  0x01001612, 0x0c0f0307, 0x22001520, 0x01053813,
  0x012714bb, 0x010838bc, 0x15003f14, 0x45124011,
  0x19001821, 0x060b02af, 0x380c1712, 0x061001ac,
  // [6470]
  0x05380d08, 0x174519ad, 0x19100b12, 0x0f170307,
  0x231c1e07, 0x38220802, 0x190b0214, 0x173819ad,
  0x38050813, 0x17001602, 0x17012207, 0x180d0812,
  0x040b3807, 0x0d080412, 0x06183809, 0x06043809,
  // [6480]
  0x0d0f1414, 0x0f401507, 0x22004013, 0x080119bc,
  0x1d0d1907, 0x0d0b0112, 0x16150409, 0x046621af,
  0x0c1d04a4, 0x21102712, 0x45401dbc, 0x18050807,
  0x19000d02, 0x1d272922, 0x141904af, 0x06002912,
  // [6490]
  0x66010322, 0x0f3f0d21, 0x01141011, 0x10051955,
  0x0b0310a4, 0x01053807, 0x08036660, 0x06000414,
  0x12180d13, 0x0c1927af, 0x1f004514, 0x04021007,
  0x18012112, 0x08000611, 0x01001020, 0x014002a4,
  // [64a0]
  0x0f000c02, 0x22000309, 0x1c250ebe, 0x21040faf,
  0x0d060209, 0x270f3809, 0x08212712, 0x0d052107,
  0x1d4521a4, 0x063810a4, 0x27001011, 0x250e1ead,
  0x180c0109, 0x1d400302, 0x210108a4, 0x17052109,
  // [64b0]
  0x27660313, 0x010421af, 0x04191660, 0x03002709,
  0x08180509, 0x17000409, 0x22661912, 0x062b0855,
  0x0b1402ad, 0x1d0d0fa4, 0x15065112, 0x38002208,
  0x1d063802, 0x18000602, 0x19661521, 0x1f180faf,
  // [64c0]
  0x08100d02, 0x40161d14, 0x0f012155, 0x172221ad,
  0x15221dbb, 0x17082912, 0x1d402907, 0x060843a4,
  0x01030509, 0x01213f60, 0x0b020655, 0x0d400f09,
  0x062b1009, 0x2b1806ad, 0x15000c09, 0x080f01ad,
  // [64d0]
  0x0c2104af, 0x27004513, 0x1d1217a4, 0x03100112,
  0x174045af, 0x171d4020, 0x381f0f6f, 0x3f010f14,
  0x042905bb, 0x0f270dbc, 0x190b1013, 0x040d08af,
  0x17160855, 0x18001014, 0x172101af, 0x19402755,
  // [64e0]
  0x06012112, 0x020b19a4, 0x16190113, 0x01000b20,
  0x10180b21, 0x08001507, 0x1c301e02, 0x051804ad,
  0x0b060412, 0x14042211, 0x0b020412, 0x030d0f12,
  0x21004512, 0x170d0107, 0x17064507, 0x0b020108,
  // [64f0]
  0x04380f13, 0x0d000c02, 0x191529af, 0x0e1e25ac,
  0x0b0204af, 0x013f2160, 0x08051f07, 0x19061609,
  0x06181909, 0x27191609, 0x10191d12, 0x05082107,
  0x0d042907, 0x380f29a4, 0x10013802, 0x1f142912,
  // [6500]
  0x03272911, 0x21163f12, 0x0d0b1009, 0x03011aa4,
  0x0d0129ac, 0x101927be, 0x05000411, 0x2b660313,
  0x080405af, 0x14000413, 0x400f0d08, 0x1e250ebe,
  0x14080d60, 0x03140b12, 0x1d000f09, 0x0f081709,
  // [6510]
  0x04000508, 0x0f1608ac, 0x050d0809, 0x03082907,
  0x161d4021, 0x04181909, 0x08050412, 0x38050408,
  0x05030f07, 0x0b1910a4, 0x290c2709, 0x0c180809,
  0x08066607, 0x66050809, 0x08210512, 0x17104002,
  // [6520]
  0x18660308, 0x0c000602, 0x16143f20, 0x0f380d21,
  0x19183fad, 0x14000314, 0x190403ad, 0x01400555,
  0x0f0c2912, 0x052108a4, 0x03080513, 0x08036620,
  0x03000b14, 0x100f01af, 0x660603a4, 0x15211612,
  // [6530]
  0x10001902, 0x21273809, 0x01380508, 0x08030112,
  0x04020502, 0x66170baf, 0x1d451223, 0x271d2908,
  0x0f100da4, 0x1c000e36, 0x01400f07, 0x02190312,
  0x051519ac, 0x1d2b12a4, 0x250e1e55, 0x38120809,
  // [6540]
  0x12041955, 0x041d16a4, 0x19451207, 0x180801ac,
  0x0c061955, 0x1d181620, 0x25301e07, 0x18271421,
  0x451216a4, 0x451d15af, 0x12450411, 0x1612456f,
  0x01121607, 0x40041412, 0x29211812, 0x1d100b08,
  // [6550]
  0x060b66ad, 0x0603666f, 0x401f6613, 0x19660baf,
  0x02001213, 0x060d0812, 0x04183f22, 0x021d6609,
  0x17190b09, 0x29180409, 0x03170507, 0x17050108,
  0x02036614, 0x0b046607, 0x08004011, 0x0f1f05af,
  // [6560]
  0x06040507, 0x05030609, 0x1f000422, 0x432b66ad,
  0x1d082108, 0x0f001909, 0x0d1008ad, 0x16150411,
  0x12381509, 0x0b012708, 0x0c151709, 0x271d66af,
  0x044566ac, 0x0d1916ad, 0x03660611, 0x66065112,
  // [6570]
  0x27036660, 0x0d380fac, 0x1d270d12, 0x04662160,
  0x0d046609, 0x190338a4, 0x03042911, 0x04002202,
  0x0f036620, 0x0f1d38a4, 0x100319a4, 0x45293809,
  0x1d020b11, 0x010f0d14, 0x05011702, 0x22380f55,
  // [6580]
  0x431f0811, 0x0c014507, 0x0d050809, 0x15000f09,
  0x0b011f12, 0x0c1d17a4, 0x3f001221, 0x43163802,
  0x27016612, 0x18190612, 0x1d0f0813, 0x06220b09,
  0x66001408, 0x05270607, 0x0645125e, 0x0c1d2112,
  // [6590]
  0x38060509, 0x16401d60, 0x01190812, 0x100b0607,
  0x0b2b1011, 0x050f3807, 0x100b0611, 0x100b1412,
  0x0d0c0f07, 0x02191512, 0x0b1d0209, 0x22010313,
  0x03220607, 0x38180baf, 0x03456608, 0x060b1412,
  // [65a0]
  0x2b031614, 0x401d15be, 0x2b060412, 0x18003813,
  0x03003813, 0x0d000f1a, 0x03150b21, 0x25301c60,
  0x400201a4, 0x01140baf, 0x0b016608, 0x10001702,
  0x16660ba4, 0x66190621, 0x061f0412, 0x032927a4,
  // [65b0]
  0x032b51af, 0x0d660107, 0x043f211f, 0x020b6612,
  0x12184021, 0x050306ac, 0x100f2714, 0x1f101921,
  0x19163f12, 0x12180f08, 0x272916af, 0x150d0f09,
  0x40001221, 0x451204be, 0x66053833, 0x0d1029af,
  // [65c0]
  0x0f183f09, 0x400d18ad, 0x0f1d27ac, 0x0f380813,
  0x0e001e32, 0x45030560, 0x0c006614, 0x04101812,
  0x220d3808, 0x05380d6f, 0x033f0112, 0x02386608,
  0x22380d60, 0x0d002208, 0x06194507, 0x030d1007,
  // [65d0]
  0x1f000b09, 0x1d154512, 0x21001921, 0x2b272960,
  0x0d0f1faf, 0x0d001714, 0x16400fa4, 0x21403fa4,
  0x05002b08, 0x273f12af, 0x0b103809, 0x193f2113,
  0x40450809, 0x3f222914, 0x19060b55, 0x0d001922,
  // [65e0]
  0x031829a4, 0x29223fa4, 0x38061008, 0x03056660,
  0x27292160, 0x062b0b12, 0x1d164507, 0x0c050809,
  0x0d050baf, 0x190f0daf, 0x12000504, 0x0d380511,
  0x16011f08, 0x38042212, 0x0c0f0da4, 0x0c451260,
  // [65f0]
  0x160d0f09, 0x160f0d22, 0x0d0f16bc, 0x080d1907,
  0x01380409, 0x45401d02, 0x031251af, 0x19400608,
  0x230e1e23, 0x0b001613, 0x040f0808, 0x29220421,
  0x0b660321, 0x2b001411, 0x2b1f0655, 0x03292709,
  // [6600]
  0x030f1455, 0x05172907, 0x060d1daf, 0x22032b55,
  0x03140555, 0x100614a4, 0x1d000613, 0x292114bc,
  0x22000208, 0x102b1611, 0x080d1709, 0x29143f13,
  0x191f3f60, 0x213f0612, 0x3f0c1421, 0x08050d09,
  // [6610]
  0x05191f22, 0x081d4012, 0x173829a4, 0x1445126d,
  0x0d0f2ba4, 0x10161408, 0x27290111, 0x3f0b0821,
  0x1800051d, 0x2b173812, 0x04161f6f, 0x0d180508,
  0x0f0d0214, 0x10050420, 0x0b10066f, 0x19100d02,
  // [6620]
  0x06021f13, 0x14040111, 0x1d000b13, 0x020b6620,
  0x0b661812, 0x17020baf, 0x06270baf, 0x040f0609,
  0x120f0555, 0x0b180413, 0x020f0b07, 0x2b060821,
  0x02380b09, 0x08053807, 0x270f22af, 0x3f22216f,
  // [6630]
  0x0b050807, 0x19272113, 0x0b002913, 0x0b000511,
  0x0f450d07, 0x180d0f21, 0x450b05a4, 0x0f190d09,
  0x0d173802, 0x06382107, 0x01170d55, 0x01042108,
  0x380366a4, 0x12030411, 0x21660312, 0x25301e11,
  // [6640]
  0x66042113, 0x2b0d1712, 0x430538af, 0x0f1740a4,
  0x02041912, 0x010d3812, 0x08380d55, 0x17380fbb,
  0x0f000208, 0x18036612, 0x0d0f1f20, 0x04142907,
  0x012b1f60, 0x29270508, 0x0d180512, 0x04210555,
  // [6650]
  0x0d382ba4, 0x192721af, 0x080f0d21, 0x196627af,
  0x010d0fbb, 0x22042114, 0x0b222707, 0x0c2b2155,
  0x06384007, 0x080c51a4, 0x02000611, 0x27226609,
  0x190b0421, 0x01062109, 0x45121f08, 0x010d3813,
  // [6660]
  0x270429af, 0x66292714, 0x0c021007, 0x010b1055,
  0x22062112, 0x141804a4, 0x03041812, 0x2b211f12,
  0x01292160, 0x0c061860, 0x380f1f08, 0x661f0f08,
  0x061551af, 0x25003007, 0x220421a4, 0x011205a4,
  // [6670]
  0x1d041912, 0x05180f08, 0x020b0112, 0x03450202,
  0x180f3808, 0x01120d08, 0x0c171555, 0x434505ac,
  0x15192909, 0x1c250eac, 0x210f3809, 0x2b002907,
  0x0b0c1007, 0x0f004021, 0x021d4012, 0x0f192160,
  // [6680]
  0x210c0f12, 0x02101d12, 0x14020b13, 0x193f0f12,
  0x380c2107, 0x27014013, 0x1d2b3860, 0x38270f55,
  0x160c1dac, 0x0f400ba4, 0x0b270f55, 0x0f170508,
  0x120f4012, 0x22043807, 0x10081413, 0x432b6608,
  // [6690]
  0x10660312, 0x10030ba4, 0x0d0f06af, 0x0b1d6613,
  0x05001d02, 0x0c1219ac, 0x10012121, 0x012229ad,
  0x04001f23, 0x0b0203ac, 0x16400dad, 0x38000f10,
  0x06050bad, 0x140d0f12, 0x21000f22, 0x1d0c2909,
  // [66a0]
  0x2b2204af, 0x40040812, 0x17000509, 0x0d400408,
  0x17010f07, 0x0f0d38af, 0x19043f13, 0x171906a4,
  0x0b380255, 0x0d2b0112, 0x1d660209, 0x100d0855,
  0x43004008, 0x1d004534, 0x02406660, 0x05124511,
  // [66b0]
  0x1d2212af, 0x0c451d12, 0x010f0308, 0x17042b12,
  0x290b51a4, 0x04151621, 0x292b1f11, 0x140108ad,
  0x0d0f2b08, 0x0b011707, 0x05041812, 0x0f042112,
  0x06190421, 0x04002114, 0x161519a4, 0x0c000808,
  // [66c0]
  0x151f2b12, 0x180d0612, 0x22210555, 0x190b0422,
  0x0d081812, 0x10291a12, 0x1c250e60, 0x0b0d0fa4,
  0x45001814, 0x40451d22, 0x02221902, 0x1d004522,
  0x18001d07, 0x17150613, 0x401619a4, 0x0b040309,
  // [66d0]
  0x01100611, 0x0b061021, 0x66002712, 0x2b006622,
  0x19061607, 0x27001609, 0x2b000c02, 0x01020d08,
  0x27006609, 0x19150855, 0x06081612, 0x17191512,
  0x66010609, 0x400b1d12, 0x03181911, 0x06160f12,
  // [66e0]
  0x0f0d17af, 0x0f431f12, 0x1d1205a4, 0x060d0108,
  0x03162107, 0x21380809, 0x06276612, 0x03292755,
  0x1d450212, 0x15193f13, 0x061608a4, 0x02191008,
  0x05292755, 0x381d40a4, 0x06661d12, 0x06196621,
  // [66f0]
  0x0b105107, 0x17001811, 0x16151809, 0x10146613,
  0x22011f12, 0x0c000311, 0x38001835, 0x05001810,
  0x0b292755, 0x66061908, 0x1d043f08, 0x1d1966be,
  0x1d041914, 0x40001908, 0x12015107, 0x0b000122,
  // [6700]
  0x12451512, 0x15002907, 0x0f0806af, 0x01435107,
  0x05451260, 0x1d6645af, 0x21430112, 0x01022911,
  0x43010ba4, 0x38012109, 0x12151d12, 0x660621af,
  0x45151d09, 0x0b002b13, 0x0f0d22a4, 0x02080409,
  // [6710]
  0x290b0260, 0x430c0307, 0x45122b12, 0x0e1e1c13,
  0x12451921, 0x01080513, 0x12100b14, 0x05060360,
  0x04000514, 0x2b0105ac, 0x0c030660, 0x06040512,
  0x27003812, 0x04161707, 0x380f0421, 0x0b040507,
  // [6720]
  0x050104af, 0x03141911, 0x16004033, 0x02102207,
  0x270301ad, 0x121d17af, 0x12010f09, 0x21001813,
  0x17121d21, 0x04000f08, 0x16170420, 0x014305a4,
  0x17121d12, 0x66005108, 0x29270814, 0x21193f12,
  // [6730]
  0x2b1f3860, 0x16030612, 0x06170808, 0x1f0651af,
  0x3f1f2712, 0x16001434, 0x041627af, 0x120117be,
  0x17006611, 0x010f0d12, 0x022b1060, 0x062b1f21,
  0x2b0616bb, 0x0d450f09, 0x10222909, 0x062b4022,
  // [6740]
  0x0c292708, 0x38060808, 0x0f0627af, 0x02061909,
  0x43000f08, 0x12001813, 0x38270508, 0x0d663812,
  0x15000612, 0x0d0821a4, 0x0d193808, 0x38272111,
  0x08170d07, 0x080d45af, 0x16210d13, 0x16214512,
  // [6750]
  0x082927a4, 0x12400821, 0x40222709, 0x0f044302,
  0x160c1260, 0x210f0d20, 0x08380dac, 0x1d013809,
  0x12221da4, 0x0f081712, 0x10170b12, 0x0c270111,
  0x0f2b0d14, 0x15100d09, 0x38102b11, 0x16000f13,
  // [6760]
  0x060802a4, 0x300e2360, 0x0e2523ad, 0x120114ac,
  0x43011912, 0x02002b08, 0x05081509, 0x40101d12,
  0x12212755, 0x08020b11, 0x01190821, 0x17010507,
  0x141d29af, 0x14292711, 0x12452909, 0x08182909,
  // [6770]
  0x2b190621, 0x064301ac, 0x060d6607, 0x29222708,
  0x142b0613, 0x05190112, 0x01160f07, 0x1d013807,
  0x40380f60, 0x2b0d2909, 0x660b27af, 0x041f19bc,
  0x16001923, 0x04060da4, 0x061f6614, 0x0f292708,
  // [6780]
  0x0d1419ad, 0x031f06af, 0x01450809, 0x18193f12,
  0x042921bc, 0x01270813, 0x06190808, 0x06380da4,
  0x18173822, 0x2b0616a4, 0x431422a4, 0x1d1240bb,
  0x121d45bc, 0x12451809, 0x0b100108, 0x03056614,
  // [6790]
  0x124540bb, 0x27290b21, 0x21001614, 0x15196613,
  0x29021960, 0x01004509, 0x163f1d09, 0x170608bc,
  0x19124521, 0x050366ce, 0x30231e22, 0x0f003f13,
  0x07005c18, 0x27002b20, 0x03010ba4, 0x27143f08,
  // [67a0]
  0x0f380807, 0x43013faf, 0x03061513, 0x38150112,
  0x2b003f20, 0x0f080307, 0x05080d07, 0x020d0809,
  0x45120f12, 0x19381007, 0x0d0f1f60, 0x17000114,
  0x0d0f1f12, 0x431f0112, 0x01036655, 0x38222107,
  // [67b0]
  0x032921ad, 0x01212955, 0x0f011f14, 0x1f190fad,
  0x29273fbe, 0x0b100421, 0x1f041913, 0x19140b14,
  0x05222112, 0x12140baf, 0x12450b08, 0x1d002b12,
  0x0c162713, 0x2b0d0f09, 0x21080f13, 0x451f1408,
  // [67c0]
  0x162b0812, 0x14060bbc, 0x17190112, 0x040f0d09,
  0x01380c07, 0x120d0809, 0x292b3812, 0x19660355,
  0x03272914, 0x17010c12, 0x380f1713, 0x021451af,
  0x03000211, 0x06026607, 0x0d053821, 0x43082108,
  // [67d0]
  0x45170d07, 0x01430809, 0x14000f11, 0x1d380fa4,
  0x45430612, 0x04196655, 0x061f0baf, 0x0d080f20,
  0x17000514, 0x14210108, 0x00001803, 0x66000c09,
  0x01451208, 0x16153f11, 0x45121512, 0x1e250e13,
  // [67e0]
  0x14121808, 0x04100b14, 0x19161520, 0x061904bc,
  0x0d190412, 0x19020807, 0x29382721, 0x1905046f,
  0x19180413, 0x43001f14, 0x06013812, 0x100f0d12,
  0x0f2b0d02, 0x02161dac, 0x16152208, 0x0b2202be,
  // [67f0]
  0x66220321, 0x14001807, 0x22290d09, 0x08060f09,
  0x06146609, 0x15164012, 0x450d38af, 0x210c6613,
  0x0f002b12, 0x0d0f1408, 0x0d220309, 0x0c1216af,
  0x061627a4, 0x10140b13, 0x66141609, 0x08001613,

  // [6800]
  0x0d000835, 0x19291421, 0x0f1d27af, 0x19292722,
  0x191d27af, 0x011f0855, 0x160f1722, 0x0d001810,
  0x22000c07, 0x0d001408, 0x0d4538af, 0x38190f09,
  0x211716be, 0x29270d09, 0x0f1445a4, 0x19180b09,
  // [6810]
  0x191051af, 0x0f183808, 0x0f1805bb, 0x1e0e1cbe,
  0x00000d0a, 0x0d0f18ad, 0x0e233002, 0x03150c12,
  0x40021021, 0x0c061509, 0x050c6613, 0x45041812,
  0x040c6609, 0x06160cac, 0x0c142707, 0x45046607,
  // [6820]
  0x66031212, 0x0c150313, 0x0f160b09, 0x190416bc,
  0x19151655, 0x38004508, 0x450f3807, 0x160f2908,
  0x121845ad, 0x1e0e1c11, 0x18004523, 0x12184513,
  0x40060107, 0x45011709, 0x0f451807, 0x12173f09,
  // [6830]
  0x01061807, 0x45141708, 0x45001721, 0x45181707,
  0x01452709, 0x401615a4, 0x01061455, 0x0b192b60,
  0x19082107, 0x06021921, 0x061721a4, 0x0b126607,
  0x19020b08, 0x02002113, 0x223f27af, 0x21001911,
  // [6840]
  0x38056607, 0x0b121007, 0x17452107, 0x03182907,
  0x03290209, 0x210c0112, 0x08001412, 0x03270455,
  0x15164514, 0x160c45af, 0x02000410, 0x16292711,
  0x43000108, 0x03663f13, 0x010f5107, 0x080d0f23,
  // [6850]
  0x060138af, 0x08003f14, 0x1d0619ad, 0x1d1601af,
  0x40083f12, 0x221d0c02, 0x01161f12, 0x0d0f2107,
  0x17080d12, 0x38170560, 0x10020c09, 0x270622a4,
  0x43050d12, 0x380d1421, 0x21162909, 0x16102707,
  // [6860]
  0x10080d09, 0x05006620, 0x0b0219a4, 0x0b272960,
  0x05001908, 0x19162b08, 0x401d4521, 0x08040112,
  0x16002109, 0x22190607, 0x450366a4, 0x0d000609,
  0x12061512, 0x10001809, 0x15051614, 0x2b151fa4,
  // [6870]
  0x0e1e23bc, 0x06051fad, 0x19004011, 0x40100213,
  0x2b161f13, 0x2b0d1509, 0x37004e35, 0x0f160dac,
  0x1f150d12, 0x060129a4, 0x40000d07, 0x151f0508,
  0x1f151614, 0x050d1f55, 0x0f272920, 0x051f0d14,
  // [6880]
  0x1f051614, 0x16380d12, 0x03664021, 0x18292721,
  0x1e302513, 0x05380f02, 0x0d191407, 0x38270d09,
  0x38140daf, 0x22100baf, 0x1f100b12, 0x29210112,
  0x0c000302, 0x0b141022, 0x140d51a4, 0x45120202,
  // [6890]
  0x14050808, 0x3f192721, 0x451216af, 0x06050823,
  0x662b3f60, 0x10002911, 0x660c0312, 0x2b1951af,
  0x03020d12, 0x1f001722, 0x10010da4, 0x382b17a4,
  0x011d0607, 0x022210af, 0x0b061002, 0x45220202,
  // [68a0]
  0x1c1e3009, 0x1d1966a4, 0x401804af, 0x18451221,
  0x45272911, 0x041022ad, 0x0c0529a4, 0x060421a4,
  0x10043f08, 0x66001812, 0x05381608, 0x01162908,
  0x1d660b12, 0x0c004307, 0x19001508, 0x1d120c09,
  // [68b0]
  0x22381408, 0x05120455, 0x1f1218bb, 0x0f0d2907,
  0x22000620, 0x12000413, 0x08140507, 0x2b270112,
  0x04222708, 0x0b000221, 0x0d4517af, 0x66000422,
  0x290f2212, 0x08140407, 0x0c0f2214, 0x0b040212,
  // [68c0]
  0x38272911, 0x27172908, 0x0b6651af, 0x301e2513,
  0x040c666f, 0x663f2bbc, 0x0b000802, 0x14004021,
  0x01000823, 0x062101ad, 0x06170111, 0x100143a4,
  0x122101ad, 0x02660321, 0x220d0f22, 0x02191007,
  // [68d0]
  0x45001502, 0x25233009, 0x02033f09, 0x050401ad,
  0x1d452b12, 0x14121812, 0x121d1907, 0x1d190307,
  0x0e3025ad, 0x0d0f2109, 0x141051a4, 0x101916ad,
  0x01002920, 0x100d0f02, 0x3f6601af, 0x251e0eac,
  // [68e0]
  0x38010bad, 0x06101409, 0x12012207, 0x10000d09,
  0x12036620, 0x211f0112, 0x1d003f08, 0x05010207,
  0x03012b08, 0x012127af, 0x032b01a4, 0x06012712,
  0x17401d09, 0x0d052709, 0x080145af, 0x042b1912,
  // [68f0]
  0x16001021, 0x121001ac, 0x0c1d0855, 0x08124512,
  0x1f001421, 0x152101af, 0x18084013, 0x66040308,
  0x060508a4, 0x45000b13, 0x06001522, 0x04150802,
  0x29085112, 0x020b1da4, 0x27001f09, 0x0c0b2707,
  // [6900]
  0x08050307, 0x2b292708, 0x221429a4, 0x1e302512,
  0x292127be, 0x43002907, 0x29002112, 0x22001909,
  0x122204a4, 0x0b012121, 0x270616bb, 0x1d041507,
  0x01004309, 0x381910a4, 0x43012712, 0x29183809,
  // [6910]
  0x1d450112, 0x29021009, 0x01431920, 0x0b160621,
  0x011943ac, 0x03086660, 0x03660809, 0x290127af,
  0x01296609, 0x18172208, 0x190203af, 0x21190411,
  0x05000b08, 0x22430f02, 0x1d014509, 0x16451202,
  // [6920]
  0x40380812, 0x05146607, 0x19001714, 0x05170f09,
  0x1d151702, 0x04221708, 0x10006611, 0x380f2908,
  0x01040b07, 0x19060112, 0x061922af, 0x01052121,
  0x030602ad, 0x05660212, 0x0b080107, 0x1d0b0202,
  // [6930]
  0x04194308, 0x380f51a4, 0x10000d21, 0x17660608,
  0x38272913, 0x43002108, 0x18050f21, 0x0d170f08,
  0x191d40af, 0x0f380d08, 0x140d51af, 0x10382255,
  0x08150509, 0x030f1907, 0x01001702, 0x190c1daf,
  // [6940]
  0x17000f12, 0x1c233011, 0x0c121912, 0x16271812,
  0x03012113, 0x0c121807, 0x12180208, 0x02000634,
  0x0f0d0407, 0x40063860, 0x02002911, 0x08031712,
  0x140651a4, 0x041445af, 0x080121ac, 0x041921a4,
  // [6950]
  0x02040611, 0x12052107, 0x01150508, 0x14060413,
  0x0c040b22, 0x041d2107, 0x12060209, 0x04196608,
  0x03050808, 0x0c030fa4, 0x0b0408af, 0x1f003f13,
  0x1d000211, 0x05062b13, 0x12002121, 0x2b1921af,
  // [6960]
  0x271f0809, 0x041f2b12, 0x1d270807, 0x3f662221,
  0x2721296f, 0x04380202, 0x0e251e21, 0x0d0c0fa4,
  0x01180408, 0x14190408, 0x40192208, 0x12024507,
  0x27150d09, 0x1c301e08, 0x120f03a4, 0x030f0512,
  // [6970]
  0x451205ad, 0x0c0416a4, 0x0c191407, 0x45663f12,
  0x191427a4, 0x12450512, 0x27000f09, 0x0c662baf,
  0x0b0306ad, 0x0d192907, 0x08153f12, 0x22661212,
  0x120129ad, 0x16403fad, 0x29162714, 0x40451d08,
  // [6980]
  0x0b0c02ac, 0x120301a4, 0x3f1d2121, 0x10120b55,
  0x0b060321, 0x0d3f0112, 0x04190f12, 0x40123f21,
  0x03662909, 0x403f45af, 0x3f1d4009, 0x011006bc,
  0x030b0508, 0x18401709, 0x080c1daf, 0x381d4014,
  // [6990]
  0x120c0207, 0x3f211d09, 0x02031608, 0x02160409,
  0x401d2121, 0x27001d12, 0x2b456608, 0x2b001f11,
  0x012b03a4, 0x17220112, 0x1e252307, 0x290d1f09,
  0x10661f09, 0x0b141009, 0x01041920, 0x06212712,
  // [69a0]
  0x18000b23, 0x40001407, 0x012b27af, 0x3f6601a4,
  0x10180111, 0x0b165107, 0x0c0f2912, 0x211801af,
  0x0d380807, 0x1d400811, 0x08003f21, 0x040d0809,
  0x21192709, 0x03156660, 0x08001913, 0x0c0d0807,
  // [69b0]
  0x1d401513, 0x04000822, 0x05001f1d, 0x02150b12,
  0x2b001f14, 0x0c1622a4, 0x301e2523, 0x192129af,
  0x14120fac, 0x01210f09, 0x08010412, 0x21011d09,
  0x020b1dad, 0x1d181007, 0x40056609, 0x1f380f12,
  // [69c0]
  0x3f004013, 0x0f122155, 0x401d51af, 0x214327af,
  0x03215111, 0x050f2107, 0x214301af, 0x06084012,
  0x19150820, 0x2b000809, 0x19664307, 0x162708af,
  0x100614ac, 0x29401212, 0x100603a4, 0x0f383f12,
  // [69d0]
  0x29001513, 0x141f0112, 0x060d0821, 0x151701af,
  0x38016609, 0x101f0b12, 0x190c2109, 0x45292720,
  0x451421a4, 0x0b000421, 0x14150812, 0x14272114,
  0x08000434, 0x0f381609, 0x38120faf, 0x04213fad,
  // [69e0]
  0x1d291912, 0x0c190602, 0x05120112, 0x08051211,
  0x17050fa4, 0x17050813, 0x14180f08, 0x30251c22,
  0x2b000f02, 0x0f150809, 0x17450f10, 0x22400807,
  0x10191d07, 0x38000b07, 0x14001f23, 0x173806af,
  // [69f0]
  0x08660b55, 0x10001422, 0x40170c12, 0x10180455,
  0x291d1213, 0x271d29af, 0x19663f13, 0x29401d23,
  0x08401d6f, 0x03190855, 0x12180614, 0x3f1d4021,
  0x02180112, 0x08001d13, 0x45120f13, 0x402129a4,
  // [6a00]
  0x29401d22, 0x3f003814, 0x291d4014, 0x12404522,
  0x1d45406f, 0x05380fa4, 0x0b024509, 0x15271908,
  0x14000b14, 0x17404511, 0x19450407, 0x03180609,
  0x1d4015ad, 0x1d080107, 0x020366a4, 0x17080307,
  // [6a10]
  0x45004023, 0x220c40a4, 0x08381912, 0x10000808,
  0x12164012, 0x012b0baf, 0x12002211, 0x66010509,
  0x01161d14, 0x0d0f43ab, 0x0d001012, 0x0b060302,
  0x17190855, 0x03100b02, 0x1d000f07, 0x031d17ac,
  // [6a20]
  0x04222134, 0x38140612, 0x16030809, 0x210422be,
  0x0d3845af, 0x04002135, 0x0f0d1f10, 0x1d3f2b09,
  0x042b2209, 0x042b06ad, 0x2b140514, 0x04291f14,
  0x0c162bad, 0x05023809, 0x430438af, 0x2b212712,
  // [6a30]
  0x17221d07, 0x042101af, 0x40161daf, 0x04225112,
  0x210c01af, 0x10196655, 0x27040112, 0x40211212,
  0x06011909, 0x06401d20, 0x01030821, 0x0f001708,
  0x180b0d12, 0x0f3f2160, 0x0d001911, 0x21001d13,
  // [6a40]
  0x18016608, 0x10190b12, 0x1d024021, 0x401d0460,
  0x14003802, 0x212b2712, 0x19184510, 0x0d162111,
  0x0d401d12, 0x0f0c3808, 0x16181909, 0x45121d55,
  0x14272112, 0x08222708, 0x14151612, 0x0c000d14,
  // [6a50]
  0x15191212, 0x0c0140a4, 0x0c010502, 0x302325bb,
  0x25230ebc, 0x1c0e30be, 0x06010407, 0x04183809,
  0x19153f13, 0x05380855, 0x0f011709, 0x02174509,
  0x0b1d2709, 0x06662709, 0x43003802, 0x050601a4,
  // [6a60]
  0x04190f07, 0x02041407, 0x12010307, 0x06001004,
  0x21000111, 0x27041f13, 0x100b0220, 0x292706be,
  0x06106612, 0x0d004510, 0x08142b11, 0x03021014,
  0x08061fbc, 0x380d2708, 0x29060b12, 0x06011f12,
  // [6a70]
  0x061910af, 0x2b170621, 0x0c0617af, 0x0c020613,
  0x0d010508, 0x27000614, 0x184540bc, 0x22100b55,
  0x04270809, 0x051908a4, 0x29052714, 0x160b0209,
  0x17062913, 0x050121a4, 0x66122708, 0x300d386d,
  // [6a80]
  0x05001711, 0x01030621, 0x400d2107, 0x21000422,
  0x08002120, 0x0c1d2121, 0x19140b07, 0x010866ad,
  0x021922ad, 0x19011007, 0x0b1904a4, 0x08100d09,
  0x18082113, 0x03040508, 0x191f0413, 0x181d4009,
  // [6a90]
  0x21140c12, 0x06180208, 0x221410af, 0x15041913,
  0x21001712, 0x1d101955, 0x0c140422, 0x180d0808,
  0x0b181412, 0x1f1001af, 0x053f01af, 0x301e0e12,
  0x29000320, 0x45271a12, 0x0b4012bc, 0x01043fac,
  // [6aa0]
  0x2b000d12, 0x0d1d4021, 0x45401d20, 0x0b2b38ad,
  0x010f14a4, 0x66140ba4, 0x0b1d4012, 0x171051a4,
  0x190217bb, 0x01171812, 0x0b0410a4, 0x050108af,
  0x030208ac, 0x21010860, 0x03011912, 0x142b0c14,
  // [6ab0]
  0x01030412, 0x082701af, 0x052b0109, 0x0b0206ad,
  0x01082202, 0x190466bb, 0x05000d11, 0x03222755,
  0x04061911, 0x022216be, 0x0d0f0521, 0x221d1621,
  0x032b14ad, 0x05080d09, 0x22161721, 0x06221521,
  // [6ac0]
  0x1d141620, 0x16002235, 0x1e0e2321, 0x15171912,
  0x182927af, 0x0b660355, 0x29275112, 0x38140509,
  0x01222907, 0x0b012bac, 0x01052b08, 0x290b66af,
  0x0d000411, 0x01060360, 0x0f173809, 0x1d014012,
  // [6ad0]
  0x38100807, 0x18012709, 0x00004e0a, 0x05060f09,
  0x10005112, 0x17001d20, 0x23300eac, 0x14382b02,
  0x1d00400d, 0x2b006623, 0x0f0b6608, 0x0c106607,
  0x0c034002, 0x03661812, 0x03156613, 0x43080507,
  // [6ae0]
  0x40036609, 0x66450313, 0x43000813, 0x05083820,
  0x036627af, 0x0d0538a4, 0x29162713, 0x0c036612,
  0x271229a4, 0x0d020f09, 0x100c0b09, 0x21080212,
  0x0f085112, 0x06021821, 0x45121413, 0x231e3008,
  // [6af0]
  0x0d3817af, 0x012229a4, 0x171905ac, 0x19001f22,
  0x27170f20, 0x2b021722, 0x171f1aaf, 0x2b001722,
  0x1f152b21, 0x38450fad, 0x16000509, 0x1d4012a4,
  0x0c0601af, 0x30001c33, 0x02066607, 0x181f45af,
  // [6b00]
  0x1d173f12, 0x04191dac, 0x0b0205be, 0x181f0f55,
  0x18450fad, 0x04171d08, 0x140f1f60, 0x0b081060,
  0x081d4013, 0x04002711, 0x10196607, 0x0c2b6660,
  0x020110ad, 0x450c2bac, 0x0f053802, 0x19010fad,
  // [6b10]
  0x1d161712, 0x05001209, 0x660b14af, 0x0c060155,
  0x23001e1f, 0x660327af, 0x451d04ad, 0x06380fac,
  0x03006634, 0x29662712, 0x0f1901ad, 0x43052907,
  0x04036623, 0x05431702, 0x0f030413, 0x430127a4,
  // [6b20]
  0x0f660311, 0x12456609, 0x660338af, 0x01182907,
  0x19220b12, 0x2b000314, 0x023f0baf, 0x21080d09,
  0x030d0fac, 0x0f143808, 0x1d224513, 0x194540af,
  0x0f0d2b07, 0x18402b09, 0x38001211, 0x08190da4,
  // [6b30]
  0x0f2701a4, 0x22181d13, 0x06662b14, 0x220329af,
  0x22660612, 0x402b2212, 0x40124520, 0x190b0202,
  0x29060f09, 0x231c2511, 0x0c0b02a4, 0x06150412,
  0x12014512, 0x17020b09, 0x02661008, 0x120c66ad,
  // [6b40]
  0x14001f1f, 0x030f0508, 0x660f0c60, 0x190d1fad,
  0x0f0d0109, 0x3f1d0baf, 0x0c170f08, 0x0c140f02,
  0x06014009, 0x170f3812, 0x2b2922af, 0x40221212,
  0x12160108, 0x1d002208, 0x16000c21, 0x1d0c1607,
  // [6b50]
  0x2b400812, 0x0d080f07, 0x046616ad, 0x401d6608,
  0x25300e13, 0x1f660221, 0x050b1023, 0x03222107,
  0x0c011509, 0x19020112, 0x170b1055, 0x0d0108bb,
  0x1d400cbe, 0x121d0c11, 0x0b010612, 0x380405a4,
  // [6b60]
  0x19381713, 0x1d001020, 0x05290109, 0x0f0d2b21,
  0x1d063f08, 0x15042955, 0x01041960, 0x0f190855,
  0x0e252321, 0x012b0b08, 0x08000d22, 0x0b2b0f09,
  0x04003811, 0x010519ad, 0x380d04bc, 0x1d0117a4,
  // [6b70]
  0x03041009, 0x3f194313, 0x38001709, 0x40194512,
  0x01450ba4, 0x040f1712, 0x0d0f1013, 0x02050d08,
  0x062b0f11, 0x021d0112, 0x380c4512, 0x38180808,
  0x1d1840af, 0x27291409, 0x121d6660, 0x22100d07,
  // [6b80]
  0x01062707, 0x0d1f0f21, 0x38161912, 0x40000302,
  0x10041911, 0x0b190560, 0x01101702, 0x150529af,
  0x301c25a4, 0x0d140fa4, 0x0c0b01af, 0x0d660112,
  0x45431222, 0x04014307, 0x29193f08, 0x27002220,
  // [6b90]
  0x08004502, 0x102102a4, 0x2b66036f, 0x0c0f4512,
  0x40001520, 0x270b0213, 0x0f0d66a4, 0x40000b13,
  0x29000620, 0x290251a4, 0x15003808, 0x08014012,
  0x122b086f, 0x452b0412, 0x03001213, 0x29221da4,
  // [6ba0]
  0x011705af, 0x1d154013, 0x15002212, 0x220d40a4,
  0x01272b12, 0x0f385112, 0x122701a4, 0x031f6608,
  0x27042209, 0x16001413, 0x011006ac, 0x0c022b60,
  0x1d221612, 0x02011007, 0x0c2b6655, 0x233025a4,
  // [6bb0]
  0x0c0116a4, 0x103803a4, 0x14183f09, 0x1d192212,
  0x174301a4, 0x01382955, 0x08171211, 0x14100608,
  0x3f1d1814, 0x29001f33, 0x381604bb, 0x012b17a4,
  0x0f190407, 0x401d1713, 0x40082212, 0x04271f09,
  // [6bc0]
  0x0c192b09, 0x02001908, 0x06291911, 0x0b3f0112,
  0x0f063808, 0x19661faf, 0x05160da4, 0x17382b09,
  0x1d164007, 0x031938a4, 0x020b1011, 0x0f382709,
  0x0d190f12, 0x1d0601ad, 0x0f0c1807, 0x02001021,
  // [6bd0]
  0x2b161521, 0x0b101908, 0x272918af, 0x38100d21,
  0x040351a4, 0x121d0d09, 0x230e1e22, 0x02291a12,
  0x3700301d, 0x081619ac, 0x01100c09, 0x140506a4,
  0x0f124508, 0x0b0d0f55, 0x19000208, 0x19210412,
  // [6be0]
  0x170f0d60, 0x0c210412, 0x031d1208, 0x19000d13,
  0x660b2712, 0x04380d07, 0x45084009, 0x15000f20,
  0x08380d07, 0x12011007, 0x0d1245ad, 0x21660b13,
  0x01210634, 0x400b04af, 0x0d170860, 0x2b220622,
  // [6bf0]
  0x0f180682, 0x06040f21, 0x18002113, 0x10002208,
  0x0f1d1612, 0x0f030512, 0x0f0522af, 0x10063821,
  0x40010334, 0x062b0321, 0x080f0d11, 0x100214af,
  0x10003820, 0x38000614, 0x0b060308, 0x181003af,

  // [6c00]
  0x020b0f08, 0x0c033812, 0x0d160f07, 0x08400f07,
  0x12400da4, 0x450f0d11, 0x0f0d04be, 0x25302312,
  0x020d51af, 0x10171d02, 0x381701a4, 0x010540a4,
  0x03053809, 0x150f01af, 0x38170f09, 0x162b6608,
  // [6c10]
  0x08120609, 0x1d080507, 0x1d061709, 0x40041d12,
  0x082701ad, 0x0b451212, 0x22140207, 0x031910ac,
  0x0f0d2755, 0x0f0d19ad, 0x06661009, 0x14382b12,
  0x100b0609, 0x010f0b07, 0x27000213, 0x22060309,
  // [6c20]
  0x0f011707, 0x22192755, 0x1d003802, 0x430b0202,
  0x66020309, 0x060b1012, 0x02100309, 0x1d154007,
  0x08000620, 0x06272909, 0x020b6613, 0x30001f1f,
  0x120c2709, 0x22000f07, 0x161240a4, 0x66150212,
  // [6c30]
  0x27050809, 0x10142908, 0x08380c21, 0x01023809,
  0x0f662108, 0x43040307, 0x66381412, 0x0c290355,
  0x22040655, 0x0f002209, 0x080d0faf, 0x0c061709,
  0x383f04bc, 0x0d052155, 0x3f2729cf, 0x03013808,
  // [6c40]
  0x22212709, 0x14061020, 0x3f222122, 0x45041612,
  0x1d0c2160, 0x052921af, 0x272b1621, 0x380d0baf,
  0x290c1d13, 0x270f21be, 0x27292211, 0x211527af,
  0x100d29a4, 0x01213fad, 0x0d143fad, 0x0f0b0355,
  // [6c50]
  0x022204bb, 0x0c1d1908, 0x40102ba4, 0x04452b08,
  0x0f1d2708, 0x181f1421, 0x10140607, 0x00001442,
  0x0d000402, 0x0c060112, 0x0e301cbe, 0x22061813,
  0x17002220, 0x013843a4, 0x050f0408, 0x180b04bb,
  // [6c60]
  0x0f100b07, 0x10190213, 0x38001912, 0x12050b08,
  0x221d0f09, 0x43401912, 0x01040507, 0x401245ad,
  0x06383f12, 0x15001711, 0x14050b09, 0x22031007,
  0x170b0202, 0x3f214512, 0x0d220834, 0x030d3809,
  // [6c70]
  0x40082912, 0x40012708, 0x22151612, 0x04401621,
  0x271d3f21, 0x08066609, 0x45123809, 0x0b1804ad,
  0x291d40a4, 0x270c3f13, 0x064301a4, 0x010f0813,
  0x081d4022, 0x18661912, 0x403f0814, 0x05290155,
  // [6c80]
  0x03190b55, 0x191d0107, 0x10011907, 0x38001f10,
  0x16061008, 0x12401d55, 0x02100b60, 0x050d0802,
  0x29002213, 0x0b1401bc, 0x220366cf, 0x021d45af,
  0x22034512, 0x032b6613, 0x171d0c21, 0x0c0801a4,
  // [6c90]
  0x38082bad, 0x0b380507, 0x220827a4, 0x1f012112,
  0x40450112, 0x38051709, 0x02014507, 0x08031f08,
  0x06001f21, 0x192729af, 0x66002707, 0x01082113,
  0x300e1e21, 0x14036612, 0x06053802, 0x43010802,
  // [6ca0]
  0x18401d08, 0x101f3821, 0x271901af, 0x04661912,
  0x38011208, 0x02101807, 0x05004334, 0x43000811,
  0x171d1255, 0x45160b02, 0x12450ca4, 0x06101509,
  0x04000f22, 0x0b024009, 0x17191502, 0x0f1d2b07,
  // [6cb0]
  0x1d100b09, 0x19010b09, 0x030d08af, 0x02190ba4,
  0x12002b08, 0x04000814, 0x01030808, 0x05001809,
  0x03180512, 0x0f016608, 0x27291412, 0x45210d09,
  0x120c2b07, 0x04021012, 0x27222109, 0x290f0112,
  // [6cc0]
  0x01213f08, 0x05170d08, 0x040b1008, 0x0f0d21a4,
  0x0d011702, 0x0d270f21, 0x0f451faf, 0x100201a4,
  0x450f1fa4, 0x01401da4, 0x08270107, 0x451f0f12,
  0x0d1f0f08, 0x27291621, 0x08002909, 0x0d051908,
  // [6cd0]
  0x1d290309, 0x102b38a4, 0x06101913, 0x12041d07,
  0x01051613, 0x27161922, 0x300e1c11, 0x17040fbb,
  0x19060412, 0x173f0112, 0x40004511, 0x30231caf,
  0x17192108, 0x190106af, 0x293801a4, 0x212908af,
  // [6ce0]
  0x29213fbb, 0x3f660121, 0x40153fce, 0x40001512,
  0x1d400813, 0x273f1d14, 0x18401d21, 0x04012907,
  0x19272955, 0x19151660, 0x08401d22, 0x1f002121,
  0x08191d09, 0x40081d23, 0x17401d6f, 0x38020b13,
  // [6cf0]
  0x01194012, 0x0d036614, 0x10080212, 0x2b010da4,
  0x050440ad, 0x05010202, 0x0d001520, 0x0b2b01ad,
  0x66180112, 0x10151613, 0x660f16af, 0x0d160808,
  0x150d16bc, 0x10151621, 0x10160baf, 0x450f0d07,
  // [6d00]
  0x271621a4, 0x16451509, 0x12171d09, 0x3f001813,
  0x161d456d, 0x0d0f16ad, 0x05101509, 0x10380b60,
  0x10292714, 0x27060109, 0x04190814, 0x0c221d12,
  0x1d292714, 0x191540a4, 0x66031912, 0x162101af,
  // [6d10]
  0x1d272907, 0x150119a4, 0x05062b60, 0x121640a4,
  0x121d3f12, 0x1d000b11, 0x27212923, 0x291727be,
  0x660f0309, 0x170f0121, 0x400f29af, 0x29222134,
  0x10010fa4, 0x401d046f, 0x17002912, 0x27172912,
  // [6d20]
  0x27290521, 0x1f006621, 0x14036611, 0x2b050809,
  0x380c1721, 0x17180608, 0x0d451708, 0x10182bbe,
  0x0f1401af, 0x29014309, 0x0b1814bc, 0x66190514,
  0x0d053813, 0x08000f20, 0x081904af, 0x16192909,
  // [6d30]
  0x222119ad, 0x19182712, 0x041d4011, 0x29151912,
  0x29276621, 0x01430da4, 0x08380fa4, 0x19003821,
  0x011940a4, 0x291d2714, 0x290b0112, 0x12061d11,
  0x662b2909, 0x1d001f08, 0x66120509, 0x021f0112,
  // [6d40]
  0x06143f12, 0x27430412, 0x172927a4, 0x02080308,
  0x0b1802af, 0x27012912, 0x16272913, 0x06031707,
  0x08011955, 0x0f1d0507, 0x08002222, 0x0d083814,
  0x141243a4, 0x27142209, 0x171d0ca4, 0x0e1c3011,
  // [6d50]
  0x02430107, 0x0c042b07, 0x0f0d06a4, 0x102b0455,
  0x05430d02, 0x45120c14, 0x01003f14, 0x082b1809,
  0x171245be, 0x01011207, 0x02190611, 0x08002109,
  0x02061908, 0x14000d10, 0x16030da4, 0x27001d09,
  // [6d60]
  0x0f0d10af, 0x10012709, 0x270f2914, 0x380f2114,
  0x0f100d13, 0x27382912, 0x0b1402ac, 0x17192955,
  0x0d0f19be, 0x0f0c0d07, 0x05000433, 0x050108ad,
  0x0d081fad, 0x08001814, 0x0f001813, 0x010805af,
  // [6d70]
  0x43061f12, 0x19051f11, 0x38040f07, 0x140f38ad,
  0x030208a4, 0x0d380608, 0x19121dac, 0x273829a4,
  0x01141607, 0x0f401da4, 0x10080f09, 0x22000f20,
  0x15271f13, 0x01194512, 0x1d121921, 0x181d19ac,
  // [6d80]
  0x06124512, 0x270f2908, 0x19172107, 0x25300e55,
  0x08011860, 0x08014507, 0x1c0e3013, 0x0d0f27af,
  0x0f0201ac, 0x30232560, 0x03140107, 0x08151402,
  0x16044013, 0x08030660, 0x160c15ac, 0x03001508,
  // [6d90]
  0x661201af, 0x29661a12, 0x051903a4, 0x15160112,
  0x05000b13, 0x100b38bb, 0x14000123, 0x150416ad,
  0x10020bbc, 0x15060314, 0x221f0212, 0x190c45af,
  0x220b1013, 0x171d01af, 0x40081609, 0x0d010b08,
  // [6da0]
  0x19122109, 0x10003808, 0x18271912, 0x3f170ca4,
  0x08380f60, 0x211d4512, 0x16030fa4, 0x15100d13,
  0x011945af, 0x050138af, 0x212719bb, 0x291622cf,
  0x0f023809, 0x16192108, 0x05010daf, 0x160415af,
  // [6db0]
  0x0d004013, 0x01222922, 0x0d051f09, 0x0f1d4008,
  0x0b0610a4, 0x17020b23, 0x22100dbc, 0x210427a4,
  0x12401d23, 0x06032b55, 0x381d2ba4, 0x17220512,
  0x0d0f3fa4, 0x660c1d12, 0x0d120309, 0x02004511,
  // [6dc0]
  0x011d0c09, 0x1d400f13, 0x0b080c07, 0x19160108,
  0x0f451d09, 0x05182b08, 0x160d0f12, 0x06032708,
  0x011705ad, 0x0c013faf, 0x0c00181f, 0x0f030dad,
  0x17454021, 0x160f1912, 0x190c1712, 0x190c1709,
  // [6dd0]
  0x0d0518ad, 0x21012909, 0x16031f11, 0x01021f11,
  0x0e231c22, 0x154540af, 0x0f3f0560, 0x380f1fad,
  0x29012714, 0x40080112, 0x18050daf, 0x14183fa4,
  0x40010608, 0x080c3f08, 0x220d3f13, 0x044001a4,
  // [6de0]
  0x100d2207, 0x05661fad, 0x00003742, 0x0f004002,
  0x01040607, 0x180d01af, 0x0d0866a4, 0x1d4512be,
  0x162b2108, 0x0e1c2314, 0x06182707, 0x10004012,
  0x30251c55, 0x080b0107, 0x0b161055, 0x020c2708,
  // [6df0]
  0x220c4055, 0x01160f02, 0x14451208, 0x1d0c40ad,
  0x0f272112, 0x100b1209, 0x272901a4, 0x05010813,
  0x194501af, 0x2104196f, 0x01004311, 0x16181d09,
  0x45161d12, 0x160f3802, 0x04060ba4, 0x124505af,
  // [6e00]
  0x3f160408, 0x06030111, 0x1d041660, 0x01040d55,
  0x04380521, 0x38060802, 0x140408be, 0x0e2330bb,
  0x050d18ba, 0x044027af, 0x151d4560, 0x15050655,
  0x23302513, 0x292b2114, 0x0f0d0260, 0x19041512,
  // [6e10]
  0x08004521, 0x06432207, 0x01402707, 0x0f001512,
  0x22000509, 0x66162b12, 0x120d0f02, 0x0f000d36,
  0x19453f08, 0x05170108, 0x27001613, 0x0c220808,
  0x03380502, 0x06191709, 0x01380821, 0x081601af,
  // [6e20]
  0x16141522, 0x170d1da4, 0x29142221, 0x27292bbe,
  0x4038056f, 0x27062908, 0x161d22ad, 0x151f19af,
  0x16001207, 0x18430612, 0x0e301c60, 0x30231e14,
  0x190206a4, 0x061066a4, 0x193f2120, 0x0f0d0855,
  // [6e30]
  0x25231e11, 0x30231e09, 0x10050202, 0x300e1e11,
  0x66010812, 0x060b03a4, 0x45121407, 0x21292707,
  0x220427af, 0x020366ac, 0x0d000407, 0x10061209,
  0x060f3802, 0x03171d07, 0x03060c60, 0x061910a4,
  // [6e40]
  0x1d000107, 0x03000509, 0x19011d55, 0x1c1e3014,
  0x18061021, 0x061851a4, 0x19060b12, 0x25301c55,
  0x06142b09, 0x16121da4, 0x0300381d, 0x0c001509,
  0x02031002, 0x0e30255e, 0x10002211, 0x142b0660,
  // [6e50]
  0x27193f13, 0x40161508, 0x12000420, 0x21001820,
  0x0c1d6621, 0x061f3f08, 0x06221812, 0x04001633,
  0x060c0807, 0x0d17086f, 0x300e2521, 0x1d192955,
  0x01224012, 0x12066612, 0x43160807, 0x1d661f08,
  // [6e60]
  0x100103af, 0x1d180812, 0x16000423, 0x66082709,
  0x04211621, 0x431701a4, 0x12000814, 0x19661008,
  0x1d170107, 0x220619af, 0x17000208, 0x1d454002,
  0x1d0c03af, 0x1c231e13, 0x3f040112, 0x38000823,
  // [6e70]
  0x082901a4, 0x400329af, 0x01060ba4, 0x12101912,
  0x03401d60, 0x040610ad, 0x18103f12, 0x10016608,
  0x04181620, 0x401218ad, 0x06020b55, 0x38060faf,
  0x0f380513, 0x150603a4, 0x03001910, 0x45020309,
  // [6e80]
  0x45001533, 0x06106608, 0x08180607, 0x04661512,
  0x05150112, 0x45150412, 0x020c2b55, 0x03060214,
  0x30230e02, 0x226619af, 0x12001402, 0x191504a4,
  0x190b1008, 0x020b40be, 0x1d024009, 0x1d001614,
  // [6e90]
  0x16020ba4, 0x10121d02, 0x27171508, 0x02190607,
  0x0b041907, 0x0b1d4007, 0x0b1d1912, 0x45121408,
  0x401d0b12, 0x05004512, 0x12214509, 0x17002109,
  0x0d151612, 0x02001d12, 0x22272960, 0x22001f22,
  // [6ea0]
  0x0b010f07, 0x0d030809, 0x04401dbc, 0x160f0d60,
  0x0c0f0daf, 0x02190112, 0x382b0102, 0x451412af,
  0x01030655, 0x06170307, 0x2b002208, 0x0d381709,
  0x01051707, 0x04061008, 0x2b020108, 0x02010609,
  // [6eb0]
  0x38050d09, 0x01173813, 0x19160207, 0x02380555,
  0x01221f09, 0x01381711, 0x15001811, 0x0b042207,
  0x19221dac, 0x0f402707, 0x10041955, 0x1f000f14,
  0x03000f02, 0x1d036655, 0x300e1cad, 0x120c3faf,
  // [6ec0]
  0x19030faf, 0x0f170502, 0x1d152707, 0x38660112,
  0x29272b12, 0x301c2522, 0x40173f07, 0x400610cf,
  0x030c6608, 0x1d293faf, 0x030604a4, 0x16124512,
  0x030604be, 0x171f51a4, 0x0c1d4055, 0x01170808,
  // [6ed0]
  0x1d271512, 0x02000423, 0x380501be, 0x1d1940be,
  0x0c121012, 0x18000414, 0x0c001008, 0x011908ad,
  0x0c0338a4, 0x120c3f09, 0x17456607, 0x100b14ad,
  0x224015af, 0x0f0c1d09, 0x1d0f1655, 0x38001913,
  // [6ee0]
  0x0b1d0fa4, 0x151d0fad, 0x08030621, 0x0b1427af,
  0x080306be, 0x16401512, 0x0f221420, 0x08030613,
  0x22210d12, 0x1e302507, 0x10000d20, 0x03080622,
  0x08030612, 0x40451222, 0x02001d02, 0x02041009,
  // [6ef0]
  0x010c06af, 0x38434509, 0x1c0e2355, 0x66001413,
  0x1d194012, 0x38182212, 0x66002b08, 0x17000102,
  0x0f050612, 0x01051fbc, 0x102b17ad, 0x031f1809,
  0x22661920, 0x0c0640bc, 0x050201af, 0x12100307,
  // [6f00]
  0x180b0214, 0x031014be, 0x011021a4, 0x19050d07,
  0x17083823, 0x153808a4, 0x0f221909, 0x401419a4,
  0x66005112, 0x191d0507, 0x160f0821, 0x0b190d07,
  0x19221d09, 0x08003833, 0x30231c13, 0x12661f08,
  // [6f10]
  0x10661655, 0x1c251ebb, 0x14001513, 0x141d04ad,
  0x0d010302, 0x1d0c1521, 0x15001907, 0x45401502,
  0x1d404513, 0x1d151412, 0x1d0f0da4, 0x041540a4,
  0x29403faf, 0x66151660, 0x0d0f1909, 0x06050334,
  // [6f20]
  0x1f0b1aa4, 0x0f030607, 0x29271814, 0x25230e22,
  0x381708a4, 0x0b036611, 0x150318a4, 0x03184009,
  0x05183807, 0x1d0503a4, 0x120d1f09, 0x1c300e55,
  0x103f0baf, 0x120218ad, 0x10380208, 0x292712af,
  // [6f30]
  0x451916ad, 0x03182212, 0x0212456d, 0x02450ba4,
  0x12450c20, 0x38080f07, 0x0f003f07, 0x0d0f0202,
  0x061d3f13, 0x0b271009, 0x401d3808, 0x22140ba4,
  0x0e1e30ac, 0x0c663fad, 0x050d38a4, 0x0d012ba4,
  // [6f40]
  0x01040308, 0x010617a4, 0x0f0102ac, 0x061f0111,
  0x40001720, 0x030c0155, 0x17080107, 0x0b001712,
  0x01100309, 0x03061921, 0x01192712, 0x38192707,
  0x14061012, 0x031d6607, 0x02100660, 0x170c4008,
  // [6f50]
  0x384017ad, 0x29221060, 0x12451608, 0x03663f12,
  0x05000c12, 0x1d1019a4, 0x38040807, 0x15400c12,
  0x45000b02, 0x43101aa4, 0x1d0c1812, 0x401d18af,
  0x22661f08, 0x010f2b07, 0x01080411, 0x030517a4,
  // [6f60]
  0x051706ad, 0x0e231ebc, 0x0d000414, 0x08000514,
  0x0d002b22, 0x0d380107, 0x124022a4, 0x040d1460,
  0x03046623, 0x21006612, 0x38050fbc, 0x010c6608,
  0x08172708, 0x1e300e12, 0x140d0f1f, 0x271d1912,
  // [6f70]
  0x2b066609, 0x1d272909, 0x1d1945a4, 0x12221408,
  0x0d143809, 0x10400209, 0x150c0f12, 0x16170f60,
  0x010b2912, 0x0c1d02a4, 0x02380d11, 0x18450d09,
  0x051d01a4, 0x051d08a4, 0x120d0fad, 0x0c162912,
  // [6f80]
  0x06276609, 0x1d171812, 0x010f0309, 0x030517ac,
  0x196603a4, 0x1e002533, 0x060b66af, 0x01450302,
  0x06101813, 0x01063f12, 0x0b000408, 0x0f272955,
  0x21002914, 0x0b005112, 0x3f401d09, 0x1d043f12,
  // [6f90]
  0x662b01af, 0x1d2729ad, 0x2b001022, 0x0c1229a4,
  0x0c1d2721, 0x1d153faf, 0x08012207, 0x0f0d51af,
  0x03010509, 0x38001908, 0x1d3801ad, 0x01051621,
  0x451f0112, 0x1f0d21be, 0x104008a4, 0x012927ad,
  // [6fa0]
  0x01102907, 0x05271708, 0x05190812, 0x14151922,
  0x271d2913, 0x14001907, 0x1d140312, 0x03041934,
  0x3f2101af, 0x021701af, 0x17014007, 0x101d2109,
  0x22150f07, 0x030b0255, 0x27000f08, 0x10221421,
  // [6fb0]
  0x080f2baf, 0x40190808, 0x01190d09, 0x170816a4,
  0x150b0314, 0x450d1811, 0x0f030609, 0x081d2112,
  0x2b1466ac, 0x10214055, 0x231e3007, 0x12180509,
  0x383f0d11, 0x290c1d09, 0x1d190c14, 0x29270f13,
  // [6fc0]
  0x38010202, 0x160666a4, 0x050b66af, 0x43052207,
  0x66160509, 0x0b100511, 0x041566be, 0x10160207,
  0x02384009, 0x0f0601a4, 0x04272921, 0x08053809,
  0x0b1d0212, 0x01051408, 0x0f183814, 0x2b041912,
  // [6fd0]
  0x080116af, 0x40123807, 0x06124560, 0x0f160109,
  0x041419af, 0x08001012, 0x380d1821, 0x04161721,
  0x19660b09, 0x66020b21, 0x661816af, 0x161422ac,
  0x290c2113, 0x160d08af, 0x19080513, 0x06040b12,
  // [6fe0]
  0x38062255, 0x18160baf, 0x66270112, 0x010f1dad,
  0x030412af, 0x18176613, 0x27193f09, 0x23301cbb,
  0x12012107, 0x0f1d1708, 0x663f0c60, 0x38152708,
  0x011d1755, 0x08141909, 0x08193f07, 0x27013faf,
  // [6ff0]
  0x1d272955, 0x22020307, 0x01270855, 0x29152721,
  0x43036608, 0x03182b09, 0x38050d22, 0x040f6607,
  0x3f290d14, 0x23253011, 0x10060412, 0x21401d21,
  0x21401da4, 0x43042955, 0x22401d22, 0x161d4020,

  // [7000]
  0x0f001508, 0x2b272160, 0x1d001808, 0x211d4023,
  0x0c1d1712, 0x290b10af, 0x0b191012, 0x25300e11,
  0x01170f55, 0x38192111, 0x27150813, 0x101f3f60,
  0x01081f08, 0x0f0d2112, 0x080140a4, 0x020129af,
  // [7010]
  0x38400112, 0x190d1009, 0x011819af, 0x010c0309,
  0x0b380112, 0x08191555, 0x06040fa4, 0x04023f11,
  0x432101af, 0x02066609, 0x06013802, 0x16224008,
  0x1d000f12, 0x10000d12, 0x05100613, 0x04000f13,
  // [7020]
  0x02051009, 0x05150f07, 0x45000c14, 0x140321a4,
  0x02030d08, 0x02000d07, 0x15011602, 0x301e2311,
  0x171027af, 0x1f292712, 0x29151faf, 0x03040d12,
  0x08272914, 0x0f430dad, 0x030d3f12, 0x66000d09,
  // [7030]
  0x2b012909, 0x210d27af, 0x172129af, 0x14191021,
  0x100c6609, 0x05190cac, 0x080c0507, 0x0c172107,
  0x0b0d05a4, 0x180501af, 0x0b184021, 0x080f386f,
  0x0c150621, 0x40060512, 0x0d0b0260, 0x12451612,
  // [7040]
  0x0b100321, 0x030b1012, 0x401d45ac, 0x08171fac,
  0x17452212, 0x01080512, 0x0b190808, 0x40451220,
  0x08451702, 0x100622af, 0x030618af, 0x15121d08,
  0x38012b08, 0x06151007, 0x21001814, 0x160622a4,
  // [7050]
  0x0d103809, 0x19001502, 0x14000c20, 0x04151608,
  0x18041608, 0x0c1d0421, 0x03040202, 0x184045a4,
  0x0b064009, 0x06122b21, 0x300e1e23, 0x40031faf,
  0x0c161012, 0x06454009, 0x0c060f13, 0x15011d12,
  // [7060]
  0x29162712, 0x01664308, 0x1f002b09, 0x2b000d02,
  0x0c0418ac, 0x380d1621, 0x220b0121, 0x04141612,
  0x01380809, 0x2b2901a4, 0x1c0e2523, 0x01001507,
  0x1d450d14, 0x02210120, 0x18012213, 0x221701af,
  // [7070]
  0x12451609, 0x142701bc, 0x02061907, 0x0e301c13,
  0x04020b55, 0x21102909, 0x43002908, 0x2b161f12,
  0x2b041f6f, 0x66030b21, 0x1f000522, 0x19151623,
  0x402b2109, 0x05002b13, 0x15001f11, 0x100c0f11,
  // [7080]
  0x15162b13, 0x121d0309, 0x06190121, 0x17060360,
  0x08121707, 0x01051f21, 0x0d386608, 0x19041f12,
  0x191804af, 0x0c220421, 0x66402909, 0x010621ac,
  0x18002207, 0x08170da4, 0x050817ad, 0x01450413,
  // [7090]
  0x03190421, 0x020b01a4, 0x060419af, 0x0d380f60,
  0x10060321, 0x290640af, 0x036622ad, 0x16274008,
  0x25301c02, 0x4e003733, 0x3f001920, 0x40061d09,
  0x66061008, 0x061f6621, 0x06180b12, 0x0b0c18a4,
  // [70a0]
  0x1d170faf, 0x061808af, 0x06000813, 0x191606ad,
  0x030c06ad, 0x030b0407, 0x12060baf, 0x06000820,
  0x06083f14, 0x45066612, 0x0c1508a4, 0x1d1708a4,
  0x1d456614, 0x0f030812, 0x1d060821, 0x6619046f,
  // [70b0]
  0x19040313, 0x03060820, 0x01004320, 0x66190411,
  0x04031912, 0x0b104312, 0x171d2907, 0x29001712,
  0x0e1e23ad, 0x0419666f, 0x081229a4, 0x270406af,
  0x40452907, 0x06290112, 0x0e232520, 0x66061060,
  // [70c0]
  0x01001d11, 0x03186607, 0x10061f21, 0x2b0538a4,
  0x400345a4, 0x451219af, 0x1d401207, 0x1d001922,
  0x40036614, 0x041d4008, 0x12453f12, 0x0c451512,
  0x020b45a4, 0x1e0e3013, 0x021910a4, 0x45002114,
  // [70d0]
  0x01052112, 0x03401dbb, 0x0b402221, 0x0c120b13,
  0x120c4522, 0x66060b12, 0x08001407, 0x0f043807,
  0x38042109, 0x0b062113, 0x170105ad, 0x170f0d20,
  0x1d380807, 0x451222ad, 0x45221822, 0x1d1621ad,
  // [70e0]
  0x27032221, 0x27062213, 0x010b1012, 0x1d662155,
  0x120c0508, 0x0c001407, 0x40273812, 0x050145ad,
  0x40120c13, 0x0d0f40af, 0x400f1009, 0x121d0cad,
  0x27220209, 0x0f120d08, 0x221904af, 0x0b102108,
  // [70f0]
  0x012205ad, 0x400c12ad, 0x03400d07, 0x05220f07,
  0x170f0d21, 0x22000421, 0x220f3813, 0x451d2712,
  0x27080f09, 0x160117a4, 0x101d40a4, 0x22000b08,
  0x060b22ad, 0x0f381707, 0x29211912, 0x01060508,
  // [7100]
  0x12160407, 0x45040307, 0x45016607, 0x1f002912,
  0x03104514, 0x401d4555, 0x03381907, 0x38170855,
  0x0f010511, 0x66080560, 0x08061912, 0x430f2b55,
  0x030f0b07, 0x0d2b0ba4, 0x22180455, 0x27170808,
  // [7110]
  0x29272bbc, 0x0d0122bb, 0x29192112, 0x0d020baf,
  0x213f29af, 0x27002133, 0x29454009, 0x29402113,
  0x121d2708, 0x660d0f60, 0x120d0b11, 0x0f1708af,
  0x0d0508bb, 0x22000d20, 0x43003f11, 0x0d001821,
  // [7120]
  0x38170d12, 0x042219be, 0x3f272911, 0x1d401221,
  0x27292b21, 0x021d0baf, 0x1d3f1913, 0x18061709,
  0x0f000811, 0x0d0f1760, 0x0f0338a4, 0x250e23ad,
  0x184512a4, 0x1d0b5112, 0x222b0607, 0x010d22a4,
  // [7130]
  0x19270655, 0x062b14ad, 0x10211412, 0x14400812,
  0x051606a4, 0x1d000822, 0x19292720, 0x21002211,
  0x06012b13, 0x083f2121, 0x02433807, 0x0f161721,
  0x250e1e33, 0x21010309, 0x16040808, 0x271908a4,
  // [7140]
  0x051f0860, 0x05170808, 0x0c1d0f02, 0x08174013,
  0x17382712, 0x1d170811, 0x082b1f12, 0x1d051712,
  0x10060bac, 0x05170821, 0x10030108, 0x19290109,
  0x06040513, 0x1d170f02, 0x2b3f0112, 0x0d063807,
  // [7150]
  0x08171507, 0x170827af, 0x30251ea4, 0x052b0108,
  0x43000508, 0x01172113, 0x06292707, 0x0b062908,
  0x19152909, 0x17150409, 0x43031fa4, 0x16191aa4,
  0x0f0c0307, 0x01030811, 0x0d270f12, 0x01030812,
  // [7160]
  0x18035111, 0x06003814, 0x38154012, 0x1d451912,
  0x042229af, 0x0c120612, 0x10004511, 0x05003f22,
  0x29040baf, 0x14220112, 0x29080521, 0x061d0855,
  0x08380f14, 0x29270d13, 0x02450b12, 0x221404be,
  // [7170]
  0x140645bc, 0x221945ad, 0x1f0601af, 0x17011faf,
  0x140601ad, 0x401d15a4, 0x0e30236f, 0x06011f09,
  0x2b0166a4, 0x01271d09, 0x01170d13, 0x15000112,
  0x301c1e82, 0x020166a4, 0x29193faf, 0x04002213,
  // [7180]
  0x272b0ba4, 0x0b161009, 0x29270b12, 0x121d0312,
  0x152b0312, 0x016603ad, 0x06660b08, 0x140d1d09,
  0x17270811, 0x04140611, 0x1d4540be, 0x0f276609,
  0x29381d08, 0x060f3807, 0x062b1408, 0x191406af,
  // [7190]
  0x450c0f33, 0x15050609, 0x080f0c09, 0x231e25be,
  0x17453faf, 0x27036612, 0x27152911, 0x1d214023,
  0x21292723, 0x04190809, 0x194514ac, 0x12380807,
  0x16021509, 0x270d21bb, 0x030401a4, 0x14180421,
  // [71a0]
  0x0c0f1f12, 0x08213fad, 0x0f1d1421, 0x1d140f08,
  0x141d4009, 0x032b0607, 0x1d0f0812, 0x1d080f13,
  0x01290d55, 0x400f0d09, 0x0d081faf, 0x0d1614bc,
  0x08003812, 0x0f0c1421, 0x083f0521, 0x381d2112,
  // [71b0]
  0x06290f12, 0x0b1d10bb, 0x0b220c12, 0x212b01ad,
  0x451f3f09, 0x01380f11, 0x1d004034, 0x081f1daf,
  0x0f1d4009, 0x124510ac, 0x400c0fa4, 0x0d0414a4,
  0x02104009, 0x0c170508, 0x272b01af, 0x231c0e02,
  // [71c0]
  0x40121612, 0x08210109, 0x1d034014, 0x0d451811,
  0x14080621, 0x21061412, 0x0d1845a4, 0x1f451821,
  0x0f000d04, 0x02001408, 0x10380111, 0x22042709,
  0x0f060812, 0x19272108, 0x0f3f0660, 0x0f060813,
  // [71d0]
  0x061d0807, 0x220b0255, 0x150c04a4, 0x1d062709,
  0x0f271d12, 0x27140814, 0x22170b14, 0x106629af,
  0x0c013f11, 0x0f0d1021, 0x3f001f20, 0x10003814,
  0x1c1e2311, 0x271f3f60, 0x0c0b1007, 0x301c1e08,
  // [71e0]
  0x100b06af, 0x21001f13, 0x061219ac, 0x06012755,
  0x2b003f22, 0x0f011a12, 0x010f1a07, 0x22000622,
  0x03010560, 0x19044507, 0x010f0c07, 0x164001a4,
  0x380401a4, 0x120c1812, 0x120c22af, 0x01181612,
  // [71f0]
  0x0c160512, 0x10060309, 0x2714296f, 0x03660d11,
  };

COMPILE_ASSERT(29172 < (1 << 16), k_indirectbits_too_small);

extern const cld::CLDTableSummary kQuadTable_obj = {
  kQuadTable,
  kQuadTableInd,
  kQuadTableSize,
  arraysize(kQuadTableInd),
  kQuadTableKeyMask,
  kQuadTableBuildDate,
};

// End of generated tables
